<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'BAE dirhemi',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Owgan afganisi',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Alban leki',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Ermeni dramy',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Niderland antil guldeni',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angola kwanzasy',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentin pesosy',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Awstraliýa dollary',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruba florini',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaýjan manady',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Konwertirlenýän Bosniýa we Gersegowina markasy',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados dollary',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladeş takasy',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bolgar lewi',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreýn dinary',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi franky',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda dollary',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Bruneý dollary',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliwiýa boliwianosy',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Brazil realy',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bagama dollary',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butan ngultrumy',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswana pulasy',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarus rubly',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Belorus rubly (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Beliz dollary',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanada dollary',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongo franky',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Şweýsar franky',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Çili pesosy',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Hytaý ýuany (ofşor)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Hytaý ýuany',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbiýa pesosy',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kosta-Rika kolony',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Konwertirlenýän kuba pesosy',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kuba pesosy',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kabo-Werde eskudosy',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Çeh kronasy',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Jibuti franky',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Daniýa kronasy',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikan pesosy',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Alžir dinary',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Müsür funty',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritreýa nakfasy',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Efiopiýa byry',
        ],
        'EUR' => [
            0 => 'EUR',
            1 => 'Ýewro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fiji dollary',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Folklend adalarynyň funty',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'Britan funt sterlingi',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gruzin larisi',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Gano sedisi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltar funty',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambiýa dalasisi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gwineý franky',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Gwatemala ketsaly',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Gaýana dollary',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Gonkong dollary',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Gonduras lempirasy',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Horwat kunasy',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gaiti gurdy',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Wenger forinti',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indoneziýa rupiýasy',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Täze Ysraýyl şekeli',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Hindi rupiýasy',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Yrak dinary',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Eýran rialy',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islandiýa kronasy',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ýamaýka dollary',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Iordan dinary',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Ýapon ýeni',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Keniýa şillingi',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Gyrgyz somy',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kamboja riýeli',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komor adalarynyň franky',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Demirgazyk Koreý wony',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Günorta Koreý wony',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuweýt dinary',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kaýman adalarynyň dollary',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Gazak teňňesi',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laos kipi',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Liwan funty',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Şri-Lanka rupiýasy',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberiýa dollary',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesoto lotisi',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Liwiýa dinary',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokko dirhamy',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldaw leýi',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagasiý ariarisi',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedon dinary',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Mýanma kýaty',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongol tugrigi',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao patakasy',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mawritan ugiýasy (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mawritan ugiýasy',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mawrikiý rupiýasy',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldiw rufiýasy',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawi kwaçasy',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksikan pesosy',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malaýziýa ringgiti',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambik metikaly',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibiýa dollary',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeriýa naýrasy',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragua kordobasy',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norwegiýa kronasy',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepal rupiýasy',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Täze Zelandiýa dollary',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Oman rialy',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panama balboasy',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru soly',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua - Täze Gwineýa kinasy',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filippin pesosy',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Päkistan rupiýasy',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polýak zlotysy',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paragwaý guaranisi',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katar rialy',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumyn leýi',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serb dinary',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rus rubly',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruanda franky',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saud rialy',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomon adalarynyň dollary',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seýşel rupiýasy',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudan funty',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Şwed kronasy',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapur dollary',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Keramatly Ýelena adasynyň funty',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sýerra-Leone leony',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somali şillingi',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinam dollary',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Günorta Sudan funty',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'San-Tome we Prinsipi dobrasy (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'San-Tome we Prinsipi dobrasy',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Siriýa funty',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazi lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Taýland baty',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Täjik somonisi',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Türkmen manady',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunis dinary',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tonga paangasy',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Türk lirasy',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trininad we Tobago dollary',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Täze Taýwan dollary',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniýa şillingi',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrain griwnasy',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Uganda şillingi',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'ABŞ dollary',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Urugwaý pesosy',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Özbek somy',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Wenesuela boliwary (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Wenesuela boliwary',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Wýetnam dongy',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Wanuatu watusy',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa talasy',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'KFA BEAC franky',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Gündogar karib dollary',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'KFA BCEAO franky',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Fransuz ýuwaş umman franky',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Ýemen rialy',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Günorta Afrika rendi',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambiýa kwaçasy',
        ],
    ],
];
