<?php

return [
    'Names' => [
        'Arab' => 'Isi-Arabhu',
        'Cyrl' => 'IsiCyrillic',
        'Hans' => 'IsiHans',
        'Hant' => 'IsiHant',
        'Jpan' => 'IsiJapanese',
        'Kore' => 'IsiKorean',
        'Latn' => 'IsiLatin',
        'Zxxx' => 'Engabhalwanga',
    ],
];
