<?php

return [
    'Names' => [
        'Arab' => 'erebî',
        'Armn' => 'ermenî',
        'Beng' => 'bengalî',
        'Cyrl' => 'kirîlî',
        'Deva' => 'devanagarî',
        'Geor' => 'gurcî',
        'Grek' => 'yewnanî',
        'Khmr' => 'ximêrî',
        'Latn' => 'latînî',
        'Mong' => 'mongolî',
        'Tibt' => 'tîbetî',
        'Zsym' => 'sembol',
        'Zxxx' => 'ne nivîsandî',
        'Zyyy' => 'hevpar',
    ],
];
