<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Вақти миёнаи Гринвич (Abidjan)',
        'Africa/Accra' => 'Вақти миёнаи Гринвич (Accra)',
        'Africa/Addis_Ababa' => 'Вақти Эфиопия (Addis Ababa)',
        'Africa/Algiers' => 'Вақти аврупоии марказӣ (Algiers)',
        'Africa/Asmera' => 'Вақти Эритрея (Asmara)',
        'Africa/Bamako' => 'Вақти миёнаи Гринвич (Bamako)',
        'Africa/Bangui' => 'Вақти Ҷумҳурии Африқои Марказӣ (Bangui)',
        'Africa/Banjul' => 'Вақти миёнаи Гринвич (Banjul)',
        'Africa/Bissau' => 'Вақти миёнаи Гринвич (Bissau)',
        'Africa/Blantyre' => 'Вақти Малави (Blantyre)',
        'Africa/Brazzaville' => 'Вақти Конго (Brazzaville)',
        'Africa/Bujumbura' => 'Вақти Бурунди (Bujumbura)',
        'Africa/Cairo' => 'Вақти аврупоии шарқӣ (Cairo)',
        'Africa/Casablanca' => 'Вақти аврупоии ғарбӣ (Casablanca)',
        'Africa/Ceuta' => 'Вақти аврупоии марказӣ (Ceuta)',
        'Africa/Conakry' => 'Вақти миёнаи Гринвич (Conakry)',
        'Africa/Dakar' => 'Вақти миёнаи Гринвич (Dakar)',
        'Africa/Dar_es_Salaam' => 'Вақти Танзания (Dar es Salaam)',
        'Africa/Djibouti' => 'Вақти Ҷибути (Djibouti)',
        'Africa/Douala' => 'Вақти Камерун (Douala)',
        'Africa/El_Aaiun' => 'Вақти аврупоии ғарбӣ (El Aaiun)',
        'Africa/Freetown' => 'Вақти миёнаи Гринвич (Freetown)',
        'Africa/Gaborone' => 'Вақти Ботсвана (Gaborone)',
        'Africa/Harare' => 'Вақти Зимбабве (Harare)',
        'Africa/Johannesburg' => 'Вақти Африкаи Ҷанубӣ (Johannesburg)',
        'Africa/Juba' => 'Вақти Судони Ҷанубӣ (Juba)',
        'Africa/Kampala' => 'Вақти Уганда (Kampala)',
        'Africa/Khartoum' => 'Вақти Судон (Khartoum)',
        'Africa/Kigali' => 'Вақти Руанда (Kigali)',
        'Africa/Kinshasa' => 'Вақти Конго (ҶДК) (Kinshasa)',
        'Africa/Lagos' => 'Вақти Нигерия (Lagos)',
        'Africa/Libreville' => 'Вақти Габон (Libreville)',
        'Africa/Lome' => 'Вақти миёнаи Гринвич (Lome)',
        'Africa/Luanda' => 'Вақти Ангола (Luanda)',
        'Africa/Lubumbashi' => 'Вақти Конго (ҶДК) (Lubumbashi)',
        'Africa/Lusaka' => 'Вақти Замбия (Lusaka)',
        'Africa/Malabo' => 'Вақти Гвинеяи Экваторӣ (Malabo)',
        'Africa/Maputo' => 'Вақти Мозамбик (Maputo)',
        'Africa/Maseru' => 'Вақти Лесото (Maseru)',
        'Africa/Mbabane' => 'Вақти Свазиленд (Mbabane)',
        'Africa/Mogadishu' => 'Вақти Сомалӣ (Mogadishu)',
        'Africa/Monrovia' => 'Вақти миёнаи Гринвич (Monrovia)',
        'Africa/Nairobi' => 'Вақти Кения (Nairobi)',
        'Africa/Ndjamena' => 'Вақти Чад (Ndjamena)',
        'Africa/Niamey' => 'Вақти Нигер (Niamey)',
        'Africa/Nouakchott' => 'Вақти миёнаи Гринвич (Nouakchott)',
        'Africa/Ouagadougou' => 'Вақти миёнаи Гринвич (Ouagadougou)',
        'Africa/Porto-Novo' => 'Вақти Бенин (Porto-Novo)',
        'Africa/Sao_Tome' => 'Вақти миёнаи Гринвич (Sao Tome)',
        'Africa/Tripoli' => 'Вақти аврупоии шарқӣ (Tripoli)',
        'Africa/Tunis' => 'Вақти аврупоии марказӣ (Tunis)',
        'Africa/Windhoek' => 'Вақти Намибия (Windhoek)',
        'America/Adak' => 'Вақти Иёлоти Муттаҳида (Adak)',
        'America/Anchorage' => 'Вақти Иёлоти Муттаҳида (Anchorage)',
        'America/Anguilla' => 'Вақти атлантикӣ (Anguilla)',
        'America/Antigua' => 'Вақти атлантикӣ (Antigua)',
        'America/Araguaina' => 'Вақти Бразилия (Araguaina)',
        'America/Argentina/La_Rioja' => 'Вақти Аргентина (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Вақти Аргентина (Rio Gallegos)',
        'America/Argentina/Salta' => 'Вақти Аргентина (Salta)',
        'America/Argentina/San_Juan' => 'Вақти Аргентина (San Juan)',
        'America/Argentina/San_Luis' => 'Вақти Аргентина (San Luis)',
        'America/Argentina/Tucuman' => 'Вақти Аргентина (Tucuman)',
        'America/Argentina/Ushuaia' => 'Вақти Аргентина (Ushuaia)',
        'America/Aruba' => 'Вақти атлантикӣ (Aruba)',
        'America/Asuncion' => 'Вақти Парагвай (Asuncion)',
        'America/Bahia' => 'Вақти Бразилия (Bahia)',
        'America/Bahia_Banderas' => 'Вақти марказӣ (Bahia Banderas)',
        'America/Barbados' => 'Вақти атлантикӣ (Barbados)',
        'America/Belem' => 'Вақти Бразилия (Belem)',
        'America/Belize' => 'Вақти марказӣ (Belize)',
        'America/Blanc-Sablon' => 'Вақти атлантикӣ (Blanc-Sablon)',
        'America/Boa_Vista' => 'Вақти Бразилия (Boa Vista)',
        'America/Bogota' => 'Вақти Колумбия (Bogota)',
        'America/Boise' => 'Вақти кӯҳӣ (Boise)',
        'America/Buenos_Aires' => 'Вақти Аргентина (Buenos Aires)',
        'America/Cambridge_Bay' => 'Вақти кӯҳӣ (Cambridge Bay)',
        'America/Campo_Grande' => 'Вақти Бразилия (Campo Grande)',
        'America/Cancun' => 'Вақти шарқӣ (Cancun)',
        'America/Caracas' => 'Вақти Венесуэла (Caracas)',
        'America/Catamarca' => 'Вақти Аргентина (Catamarca)',
        'America/Cayenne' => 'Вақти Гвианаи Фаронса (Cayenne)',
        'America/Cayman' => 'Вақти шарқӣ (Cayman)',
        'America/Chicago' => 'Вақти марказӣ (Chicago)',
        'America/Chihuahua' => 'Вақти Мексика (Chihuahua)',
        'America/Coral_Harbour' => 'Вақти шарқӣ (Atikokan)',
        'America/Cordoba' => 'Вақти Аргентина (Cordoba)',
        'America/Costa_Rica' => 'Вақти марказӣ (Costa Rica)',
        'America/Creston' => 'Вақти кӯҳӣ (Creston)',
        'America/Cuiaba' => 'Вақти Бразилия (Cuiaba)',
        'America/Curacao' => 'Вақти атлантикӣ (Curacao)',
        'America/Danmarkshavn' => 'Вақти миёнаи Гринвич (Danmarkshavn)',
        'America/Dawson' => 'Вақти Канада (Dawson)',
        'America/Dawson_Creek' => 'Вақти кӯҳӣ (Dawson Creek)',
        'America/Denver' => 'Вақти кӯҳӣ (Denver)',
        'America/Detroit' => 'Вақти шарқӣ (Detroit)',
        'America/Dominica' => 'Вақти атлантикӣ (Dominica)',
        'America/Edmonton' => 'Вақти кӯҳӣ (Edmonton)',
        'America/Eirunepe' => 'Вақти Бразилия (Eirunepe)',
        'America/El_Salvador' => 'Вақти марказӣ (El Salvador)',
        'America/Fort_Nelson' => 'Вақти кӯҳӣ (Fort Nelson)',
        'America/Fortaleza' => 'Вақти Бразилия (Fortaleza)',
        'America/Glace_Bay' => 'Вақти атлантикӣ (Glace Bay)',
        'America/Godthab' => 'Вақти Гренландия (Nuuk)',
        'America/Goose_Bay' => 'Вақти атлантикӣ (Goose Bay)',
        'America/Grand_Turk' => 'Вақти шарқӣ (Grand Turk)',
        'America/Grenada' => 'Вақти атлантикӣ (Grenada)',
        'America/Guadeloupe' => 'Вақти атлантикӣ (Guadeloupe)',
        'America/Guatemala' => 'Вақти марказӣ (Guatemala)',
        'America/Guayaquil' => 'Вақти Эквадор (Guayaquil)',
        'America/Guyana' => 'Вақти Гайана (Guyana)',
        'America/Halifax' => 'Вақти атлантикӣ (Halifax)',
        'America/Havana' => 'Вақти Куба (Havana)',
        'America/Hermosillo' => 'Вақти Мексика (Hermosillo)',
        'America/Indiana/Knox' => 'Вақти марказӣ (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Вақти шарқӣ (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Вақти шарқӣ (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Вақти марказӣ (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Вақти шарқӣ (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Вақти шарқӣ (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Вақти шарқӣ (Winamac, Indiana)',
        'America/Indianapolis' => 'Вақти шарқӣ (Indianapolis)',
        'America/Inuvik' => 'Вақти кӯҳӣ (Inuvik)',
        'America/Iqaluit' => 'Вақти шарқӣ (Iqaluit)',
        'America/Jamaica' => 'Вақти шарқӣ (Jamaica)',
        'America/Jujuy' => 'Вақти Аргентина (Jujuy)',
        'America/Juneau' => 'Вақти Иёлоти Муттаҳида (Juneau)',
        'America/Kentucky/Monticello' => 'Вақти шарқӣ (Monticello, Kentucky)',
        'America/Kralendijk' => 'Вақти атлантикӣ (Kralendijk)',
        'America/La_Paz' => 'Вақти Боливия (La Paz)',
        'America/Lima' => 'Вақти Перу (Lima)',
        'America/Los_Angeles' => 'Вақти Уқёнуси Ором (Los Angeles)',
        'America/Louisville' => 'Вақти шарқӣ (Louisville)',
        'America/Lower_Princes' => 'Вақти атлантикӣ (Lower Prince’s Quarter)',
        'America/Maceio' => 'Вақти Бразилия (Maceio)',
        'America/Managua' => 'Вақти марказӣ (Managua)',
        'America/Manaus' => 'Вақти Бразилия (Manaus)',
        'America/Marigot' => 'Вақти атлантикӣ (Marigot)',
        'America/Martinique' => 'Вақти атлантикӣ (Martinique)',
        'America/Matamoros' => 'Вақти марказӣ (Matamoros)',
        'America/Mazatlan' => 'Вақти Мексика (Mazatlan)',
        'America/Mendoza' => 'Вақти Аргентина (Mendoza)',
        'America/Menominee' => 'Вақти марказӣ (Menominee)',
        'America/Merida' => 'Вақти марказӣ (Merida)',
        'America/Metlakatla' => 'Вақти Иёлоти Муттаҳида (Metlakatla)',
        'America/Mexico_City' => 'Вақти марказӣ (Mexico City)',
        'America/Miquelon' => 'Вақти Сент-Пер ва Микелон (Miquelon)',
        'America/Moncton' => 'Вақти атлантикӣ (Moncton)',
        'America/Monterrey' => 'Вақти марказӣ (Monterrey)',
        'America/Montevideo' => 'Вақти Уругвай (Montevideo)',
        'America/Montreal' => 'Вақти Канада (Montreal)',
        'America/Montserrat' => 'Вақти атлантикӣ (Montserrat)',
        'America/Nassau' => 'Вақти шарқӣ (Nassau)',
        'America/New_York' => 'Вақти шарқӣ (New York)',
        'America/Nipigon' => 'Вақти шарқӣ (Nipigon)',
        'America/Nome' => 'Вақти Иёлоти Муттаҳида (Nome)',
        'America/Noronha' => 'Вақти Бразилия (Noronha)',
        'America/North_Dakota/Beulah' => 'Вақти марказӣ (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Вақти марказӣ (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Вақти марказӣ (New Salem, North Dakota)',
        'America/Ojinaga' => 'Вақти кӯҳӣ (Ojinaga)',
        'America/Panama' => 'Вақти шарқӣ (Panama)',
        'America/Pangnirtung' => 'Вақти шарқӣ (Pangnirtung)',
        'America/Paramaribo' => 'Вақти Суринам (Paramaribo)',
        'America/Phoenix' => 'Вақти кӯҳӣ (Phoenix)',
        'America/Port-au-Prince' => 'Вақти шарқӣ (Port-au-Prince)',
        'America/Port_of_Spain' => 'Вақти атлантикӣ (Port of Spain)',
        'America/Porto_Velho' => 'Вақти Бразилия (Porto Velho)',
        'America/Puerto_Rico' => 'Вақти атлантикӣ (Puerto Rico)',
        'America/Punta_Arenas' => 'Вақти Чили (Punta Arenas)',
        'America/Rainy_River' => 'Вақти марказӣ (Rainy River)',
        'America/Rankin_Inlet' => 'Вақти марказӣ (Rankin Inlet)',
        'America/Recife' => 'Вақти Бразилия (Recife)',
        'America/Regina' => 'Вақти марказӣ (Regina)',
        'America/Resolute' => 'Вақти марказӣ (Resolute)',
        'America/Rio_Branco' => 'Вақти Бразилия (Rio Branco)',
        'America/Santa_Isabel' => 'Вақти Мексика (Santa Isabel)',
        'America/Santarem' => 'Вақти Бразилия (Santarem)',
        'America/Santiago' => 'Вақти Чили (Santiago)',
        'America/Santo_Domingo' => 'Вақти атлантикӣ (Santo Domingo)',
        'America/Sao_Paulo' => 'Вақти Бразилия (Sao Paulo)',
        'America/Scoresbysund' => 'Вақти Гренландия (Ittoqqortoormiit)',
        'America/Sitka' => 'Вақти Иёлоти Муттаҳида (Sitka)',
        'America/St_Barthelemy' => 'Вақти атлантикӣ (St. Barthelemy)',
        'America/St_Johns' => 'Вақти Канада (St. John’s)',
        'America/St_Kitts' => 'Вақти атлантикӣ (St. Kitts)',
        'America/St_Lucia' => 'Вақти атлантикӣ (St. Lucia)',
        'America/St_Thomas' => 'Вақти атлантикӣ (St. Thomas)',
        'America/St_Vincent' => 'Вақти атлантикӣ (St. Vincent)',
        'America/Swift_Current' => 'Вақти марказӣ (Swift Current)',
        'America/Tegucigalpa' => 'Вақти марказӣ (Tegucigalpa)',
        'America/Thule' => 'Вақти атлантикӣ (Thule)',
        'America/Thunder_Bay' => 'Вақти шарқӣ (Thunder Bay)',
        'America/Tijuana' => 'Вақти Уқёнуси Ором (Tijuana)',
        'America/Toronto' => 'Вақти шарқӣ (Toronto)',
        'America/Tortola' => 'Вақти атлантикӣ (Tortola)',
        'America/Vancouver' => 'Вақти Уқёнуси Ором (Vancouver)',
        'America/Whitehorse' => 'Вақти Канада (Whitehorse)',
        'America/Winnipeg' => 'Вақти марказӣ (Winnipeg)',
        'America/Yakutat' => 'Вақти Иёлоти Муттаҳида (Yakutat)',
        'America/Yellowknife' => 'Вақти кӯҳӣ (Yellowknife)',
        'Antarctica/Casey' => 'Вақти Антарктида (Casey)',
        'Antarctica/Davis' => 'Вақти Антарктида (Davis)',
        'Antarctica/DumontDUrville' => 'Вақти Антарктида (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'Вақти Австралия (Macquarie)',
        'Antarctica/Mawson' => 'Вақти Антарктида (Mawson)',
        'Antarctica/McMurdo' => 'Вақти Антарктида (McMurdo)',
        'Antarctica/Palmer' => 'Вақти Антарктида (Palmer)',
        'Antarctica/Rothera' => 'Вақти Антарктида (Rothera)',
        'Antarctica/Syowa' => 'Вақти Антарктида (Syowa)',
        'Antarctica/Troll' => 'Вақти миёнаи Гринвич (Troll)',
        'Antarctica/Vostok' => 'Вақти Антарктида (Vostok)',
        'Arctic/Longyearbyen' => 'Вақти аврупоии марказӣ (Longyearbyen)',
        'Asia/Aden' => 'Вақти Яман (Aden)',
        'Asia/Almaty' => 'Вақти Қазоқистон (Almaty)',
        'Asia/Amman' => 'Вақти аврупоии шарқӣ (Amman)',
        'Asia/Anadyr' => 'Вақти Русия (Anadyr)',
        'Asia/Aqtau' => 'Вақти Қазоқистон (Aqtau)',
        'Asia/Aqtobe' => 'Вақти Қазоқистон (Aqtobe)',
        'Asia/Ashgabat' => 'Вақти Туркманистон (Ashgabat)',
        'Asia/Atyrau' => 'Вақти Қазоқистон (Atyrau)',
        'Asia/Baghdad' => 'Вақти Ироқ (Baghdad)',
        'Asia/Bahrain' => 'Вақти Баҳрайн (Bahrain)',
        'Asia/Baku' => 'Вақти Озарбойҷон (Baku)',
        'Asia/Bangkok' => 'Вақти Таиланд (Bangkok)',
        'Asia/Barnaul' => 'Вақти Русия (Barnaul)',
        'Asia/Beirut' => 'Вақти аврупоии шарқӣ (Beirut)',
        'Asia/Bishkek' => 'Вақти Қирғизистон (Bishkek)',
        'Asia/Brunei' => 'Вақти Бруней (Brunei)',
        'Asia/Calcutta' => 'Вақти Ҳиндустон (Kolkata)',
        'Asia/Chita' => 'Вақти Русия (Chita)',
        'Asia/Choibalsan' => 'Вақти Муғулистон (Choibalsan)',
        'Asia/Colombo' => 'Вақти Шри-Ланка (Colombo)',
        'Asia/Damascus' => 'Вақти аврупоии шарқӣ (Damascus)',
        'Asia/Dhaka' => 'Вақти Бангладеш (Dhaka)',
        'Asia/Dili' => 'Вақти Тимор-Лесте (Dili)',
        'Asia/Dubai' => 'Вақти Аморатҳои Муттаҳидаи Араб (Dubai)',
        'Asia/Dushanbe' => 'Вақти Тоҷикистон (Душанбе)',
        'Asia/Famagusta' => 'Вақти аврупоии шарқӣ (Famagusta)',
        'Asia/Gaza' => 'Вақти аврупоии шарқӣ (Gaza)',
        'Asia/Hebron' => 'Вақти аврупоии шарқӣ (Hebron)',
        'Asia/Hong_Kong' => 'Вақти Ҳонконг (МММ) (Hong Kong)',
        'Asia/Hovd' => 'Вақти Муғулистон (Hovd)',
        'Asia/Irkutsk' => 'Вақти Русия (Irkutsk)',
        'Asia/Jakarta' => 'Вақти Индонезия (Jakarta)',
        'Asia/Jayapura' => 'Вақти Индонезия (Jayapura)',
        'Asia/Jerusalem' => 'Вақти Исроил (Jerusalem)',
        'Asia/Kabul' => 'Вақти Афғонистон (Kabul)',
        'Asia/Kamchatka' => 'Вақти Русия (Kamchatka)',
        'Asia/Karachi' => 'Вақти Покистон (Karachi)',
        'Asia/Katmandu' => 'Вақти Непал (Kathmandu)',
        'Asia/Khandyga' => 'Вақти Русия (Khandyga)',
        'Asia/Krasnoyarsk' => 'Вақти Русия (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Вақти Малайзия (Kuala Lumpur)',
        'Asia/Kuching' => 'Вақти Малайзия (Kuching)',
        'Asia/Kuwait' => 'Вақти Қувайт (Kuwait)',
        'Asia/Macau' => 'Вақти Макао (МММ) (Macao)',
        'Asia/Magadan' => 'Вақти Русия (Magadan)',
        'Asia/Makassar' => 'Вақти Индонезия (Makassar)',
        'Asia/Manila' => 'Вақти Филиппин (Manila)',
        'Asia/Muscat' => 'Вақти Умон (Muscat)',
        'Asia/Nicosia' => 'Вақти аврупоии шарқӣ (Nicosia)',
        'Asia/Novokuznetsk' => 'Вақти Русия (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Вақти Русия (Novosibirsk)',
        'Asia/Omsk' => 'Вақти Русия (Omsk)',
        'Asia/Oral' => 'Вақти Қазоқистон (Oral)',
        'Asia/Phnom_Penh' => 'Вақти Камбоҷа (Phnom Penh)',
        'Asia/Pontianak' => 'Вақти Индонезия (Pontianak)',
        'Asia/Pyongyang' => 'Вақти Кореяи Шимолӣ (Pyongyang)',
        'Asia/Qatar' => 'Вақти Қатар (Qatar)',
        'Asia/Qostanay' => 'Вақти Қазоқистон (Qostanay)',
        'Asia/Qyzylorda' => 'Вақти Қазоқистон (Qyzylorda)',
        'Asia/Rangoon' => 'Вақти Мянма (Yangon)',
        'Asia/Riyadh' => 'Вақти Арабистони Саудӣ (Riyadh)',
        'Asia/Saigon' => 'Вақти Ветнам (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Вақти Русия (Sakhalin)',
        'Asia/Samarkand' => 'Вақти Ӯзбекистон (Samarkand)',
        'Asia/Shanghai' => 'Вақти Хитой (Shanghai)',
        'Asia/Singapore' => 'Вақти Сингапур (Singapore)',
        'Asia/Srednekolymsk' => 'Вақти Русия (Srednekolymsk)',
        'Asia/Taipei' => 'Вақти Тайван (Taipei)',
        'Asia/Tashkent' => 'Вақти Ӯзбекистон (Tashkent)',
        'Asia/Tbilisi' => 'Вақти Гурҷистон (Tbilisi)',
        'Asia/Tehran' => 'Вақти Эрон (Tehran)',
        'Asia/Thimphu' => 'Вақти Бутон (Thimphu)',
        'Asia/Tokyo' => 'Вақти Япония (Tokyo)',
        'Asia/Tomsk' => 'Вақти Русия (Tomsk)',
        'Asia/Ulaanbaatar' => 'Вақти Муғулистон (Ulaanbaatar)',
        'Asia/Urumqi' => 'Вақти Хитой (Urumqi)',
        'Asia/Ust-Nera' => 'Вақти Русия (Ust-Nera)',
        'Asia/Vientiane' => 'Вақти Лаос (Vientiane)',
        'Asia/Vladivostok' => 'Вақти Русия (Vladivostok)',
        'Asia/Yakutsk' => 'Вақти Русия (Yakutsk)',
        'Asia/Yekaterinburg' => 'Вақти Русия (Yekaterinburg)',
        'Asia/Yerevan' => 'Вақти Арманистон (Yerevan)',
        'Atlantic/Azores' => 'Вақти Португалия (Azores)',
        'Atlantic/Bermuda' => 'Вақти атлантикӣ (Bermuda)',
        'Atlantic/Canary' => 'Вақти аврупоии ғарбӣ (Canary)',
        'Atlantic/Cape_Verde' => 'Вақти Кабо-Верде (Cape Verde)',
        'Atlantic/Faeroe' => 'Вақти аврупоии ғарбӣ (Faroe)',
        'Atlantic/Madeira' => 'Вақти аврупоии ғарбӣ (Madeira)',
        'Atlantic/Reykjavik' => 'Вақти миёнаи Гринвич (Reykjavik)',
        'Atlantic/South_Georgia' => 'Вақти Ҷорҷияи Ҷанубӣ ва Ҷазираҳои Сандвич (South Georgia)',
        'Atlantic/St_Helena' => 'Вақти миёнаи Гринвич (St. Helena)',
        'Atlantic/Stanley' => 'Вақти Ҷазираҳои Фолкленд (Stanley)',
        'Australia/Adelaide' => 'Вақти Австралия (Adelaide)',
        'Australia/Brisbane' => 'Вақти Австралия (Brisbane)',
        'Australia/Broken_Hill' => 'Вақти Австралия (Broken Hill)',
        'Australia/Currie' => 'Вақти Австралия (Currie)',
        'Australia/Darwin' => 'Вақти Австралия (Darwin)',
        'Australia/Eucla' => 'Вақти Австралия (Eucla)',
        'Australia/Hobart' => 'Вақти Австралия (Hobart)',
        'Australia/Lindeman' => 'Вақти Австралия (Lindeman)',
        'Australia/Lord_Howe' => 'Вақти Австралия (Lord Howe)',
        'Australia/Melbourne' => 'Вақти Австралия (Melbourne)',
        'Australia/Perth' => 'Вақти Австралия (Perth)',
        'Australia/Sydney' => 'Вақти Австралия (Sydney)',
        'CST6CDT' => 'Вақти марказӣ',
        'EST5EDT' => 'Вақти шарқӣ',
        'Etc/GMT' => 'Вақти миёнаи Гринвич',
        'Etc/UTC' => 'Вақти ҷаҳонии ҳамоҳангсозӣ',
        'Europe/Amsterdam' => 'Вақти аврупоии марказӣ (Amsterdam)',
        'Europe/Andorra' => 'Вақти аврупоии марказӣ (Andorra)',
        'Europe/Astrakhan' => 'Вақти Русия (Astrakhan)',
        'Europe/Athens' => 'Вақти аврупоии шарқӣ (Athens)',
        'Europe/Belgrade' => 'Вақти аврупоии марказӣ (Belgrade)',
        'Europe/Berlin' => 'Вақти аврупоии марказӣ (Berlin)',
        'Europe/Bratislava' => 'Вақти аврупоии марказӣ (Bratislava)',
        'Europe/Brussels' => 'Вақти аврупоии марказӣ (Brussels)',
        'Europe/Bucharest' => 'Вақти аврупоии шарқӣ (Bucharest)',
        'Europe/Budapest' => 'Вақти аврупоии марказӣ (Budapest)',
        'Europe/Busingen' => 'Вақти аврупоии марказӣ (Busingen)',
        'Europe/Chisinau' => 'Вақти аврупоии шарқӣ (Chisinau)',
        'Europe/Copenhagen' => 'Вақти аврупоии марказӣ (Copenhagen)',
        'Europe/Dublin' => 'Вақти миёнаи Гринвич (Dublin)',
        'Europe/Gibraltar' => 'Вақти аврупоии марказӣ (Gibraltar)',
        'Europe/Guernsey' => 'Вақти миёнаи Гринвич (Guernsey)',
        'Europe/Helsinki' => 'Вақти аврупоии шарқӣ (Helsinki)',
        'Europe/Isle_of_Man' => 'Вақти миёнаи Гринвич (Isle of Man)',
        'Europe/Istanbul' => 'Вақти Туркия (Istanbul)',
        'Europe/Jersey' => 'Вақти миёнаи Гринвич (Jersey)',
        'Europe/Kaliningrad' => 'Вақти аврупоии шарқӣ (Kaliningrad)',
        'Europe/Kiev' => 'Вақти аврупоии шарқӣ (Kyiv)',
        'Europe/Kirov' => 'Вақти Русия (Kirov)',
        'Europe/Lisbon' => 'Вақти аврупоии ғарбӣ (Lisbon)',
        'Europe/Ljubljana' => 'Вақти аврупоии марказӣ (Ljubljana)',
        'Europe/London' => 'Вақти миёнаи Гринвич (London)',
        'Europe/Luxembourg' => 'Вақти аврупоии марказӣ (Luxembourg)',
        'Europe/Madrid' => 'Вақти аврупоии марказӣ (Madrid)',
        'Europe/Malta' => 'Вақти аврупоии марказӣ (Malta)',
        'Europe/Mariehamn' => 'Вақти аврупоии шарқӣ (Mariehamn)',
        'Europe/Minsk' => 'Вақти Белорус (Minsk)',
        'Europe/Monaco' => 'Вақти аврупоии марказӣ (Monaco)',
        'Europe/Moscow' => 'Вақти Русия (Moscow)',
        'Europe/Oslo' => 'Вақти аврупоии марказӣ (Oslo)',
        'Europe/Paris' => 'Вақти аврупоии марказӣ (Paris)',
        'Europe/Podgorica' => 'Вақти аврупоии марказӣ (Podgorica)',
        'Europe/Prague' => 'Вақти аврупоии марказӣ (Prague)',
        'Europe/Riga' => 'Вақти аврупоии шарқӣ (Riga)',
        'Europe/Rome' => 'Вақти аврупоии марказӣ (Rome)',
        'Europe/Samara' => 'Вақти Русия (Samara)',
        'Europe/San_Marino' => 'Вақти аврупоии марказӣ (San Marino)',
        'Europe/Sarajevo' => 'Вақти аврупоии марказӣ (Sarajevo)',
        'Europe/Saratov' => 'Вақти Русия (Saratov)',
        'Europe/Simferopol' => 'Вақти Украина (Simferopol)',
        'Europe/Skopje' => 'Вақти аврупоии марказӣ (Skopje)',
        'Europe/Sofia' => 'Вақти аврупоии шарқӣ (Sofia)',
        'Europe/Stockholm' => 'Вақти аврупоии марказӣ (Stockholm)',
        'Europe/Tallinn' => 'Вақти аврупоии шарқӣ (Tallinn)',
        'Europe/Tirane' => 'Вақти аврупоии марказӣ (Tirane)',
        'Europe/Ulyanovsk' => 'Вақти Русия (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Вақти аврупоии шарқӣ (Uzhgorod)',
        'Europe/Vaduz' => 'Вақти аврупоии марказӣ (Vaduz)',
        'Europe/Vatican' => 'Вақти аврупоии марказӣ (Vatican)',
        'Europe/Vienna' => 'Вақти аврупоии марказӣ (Vienna)',
        'Europe/Vilnius' => 'Вақти аврупоии шарқӣ (Vilnius)',
        'Europe/Volgograd' => 'Вақти Русия (Volgograd)',
        'Europe/Warsaw' => 'Вақти аврупоии марказӣ (Warsaw)',
        'Europe/Zagreb' => 'Вақти аврупоии марказӣ (Zagreb)',
        'Europe/Zaporozhye' => 'Вақти аврупоии шарқӣ (Zaporozhye)',
        'Europe/Zurich' => 'Вақти аврупоии марказӣ (Zurich)',
        'Indian/Antananarivo' => 'Вақти Мадагаскар (Antananarivo)',
        'Indian/Chagos' => 'Вақти Қаламрави Британия дар уқёнуси Ҳинд (Chagos)',
        'Indian/Christmas' => 'Вақти Ҷазираи Крисмас (Christmas)',
        'Indian/Cocos' => 'Вақти Ҷазираҳои Кокос (Килинг) (Cocos)',
        'Indian/Comoro' => 'Вақти Комор (Comoro)',
        'Indian/Kerguelen' => 'Вақти Минтақаҳои Ҷанубии Фаронса (Kerguelen)',
        'Indian/Mahe' => 'Вақти Сейшел (Mahe)',
        'Indian/Maldives' => 'Вақти Малдив (Maldives)',
        'Indian/Mauritius' => 'Вақти Маврикий (Mauritius)',
        'Indian/Mayotte' => 'Вақти Майотта (Mayotte)',
        'Indian/Reunion' => 'Вақти Реюнион (Reunion)',
        'MST7MDT' => 'Вақти кӯҳӣ',
        'PST8PDT' => 'Вақти Уқёнуси Ором',
        'Pacific/Apia' => 'Вақти Самоа (Apia)',
        'Pacific/Auckland' => 'Вақти Зеландияи Нав (Auckland)',
        'Pacific/Bougainville' => 'Вақти Папуа Гвинеяи Нав (Bougainville)',
        'Pacific/Chatham' => 'Вақти Зеландияи Нав (Chatham)',
        'Pacific/Easter' => 'Вақти Чили (Easter)',
        'Pacific/Efate' => 'Вақти Вануату (Efate)',
        'Pacific/Enderbury' => 'Вақти Кирибати (Enderbury)',
        'Pacific/Fakaofo' => 'Вақти Токелау (Fakaofo)',
        'Pacific/Fiji' => 'Вақти Фиҷи (Fiji)',
        'Pacific/Funafuti' => 'Вақти Тувалу (Funafuti)',
        'Pacific/Galapagos' => 'Вақти Эквадор (Galapagos)',
        'Pacific/Gambier' => 'Вақти Полинезияи Фаронса (Gambier)',
        'Pacific/Guadalcanal' => 'Вақти Ҷазираҳои Соломон (Guadalcanal)',
        'Pacific/Guam' => 'Вақти Гуам (Guam)',
        'Pacific/Honolulu' => 'Вақти Иёлоти Муттаҳида (Honolulu)',
        'Pacific/Johnston' => 'Вақти Ҷазираҳои Хурди Дурдасти ИМА (Johnston)',
        'Pacific/Kiritimati' => 'Вақти Кирибати (Kiritimati)',
        'Pacific/Kosrae' => 'Вақти Штатҳои Федеративии Микронезия (Kosrae)',
        'Pacific/Kwajalein' => 'Вақти Ҷазираҳои Маршалл (Kwajalein)',
        'Pacific/Majuro' => 'Вақти Ҷазираҳои Маршалл (Majuro)',
        'Pacific/Marquesas' => 'Вақти Полинезияи Фаронса (Marquesas)',
        'Pacific/Midway' => 'Вақти Ҷазираҳои Хурди Дурдасти ИМА (Midway)',
        'Pacific/Nauru' => 'Вақти Науру (Nauru)',
        'Pacific/Niue' => 'Вақти Ниуэ (Niue)',
        'Pacific/Norfolk' => 'Вақти Ҷазираи Норфолк (Norfolk)',
        'Pacific/Noumea' => 'Вақти Каледонияи Нав (Noumea)',
        'Pacific/Pago_Pago' => 'Вақти Самоаи Америка (Pago Pago)',
        'Pacific/Palau' => 'Вақти Палау (Palau)',
        'Pacific/Pitcairn' => 'Вақти Ҷазираҳои Питкейрн (Pitcairn)',
        'Pacific/Ponape' => 'Вақти Штатҳои Федеративии Микронезия (Pohnpei)',
        'Pacific/Port_Moresby' => 'Вақти Папуа Гвинеяи Нав (Port Moresby)',
        'Pacific/Rarotonga' => 'Вақти Ҷазираҳои Кук (Rarotonga)',
        'Pacific/Saipan' => 'Вақти Ҷазираҳои Марианаи Шимолӣ (Saipan)',
        'Pacific/Tahiti' => 'Вақти Полинезияи Фаронса (Tahiti)',
        'Pacific/Tarawa' => 'Вақти Кирибати (Tarawa)',
        'Pacific/Tongatapu' => 'Вақти Тонга (Tongatapu)',
        'Pacific/Truk' => 'Вақти Штатҳои Федеративии Микронезия (Chuuk)',
        'Pacific/Wake' => 'Вақти Ҷазираҳои Хурди Дурдасти ИМА (Wake)',
        'Pacific/Wallis' => 'Вақти Уоллис ва Футуна (Wallis)',
    ],
    'Meta' => [
        'GmtFormat' => 'Вақти GMT %s',
    ],
];
