<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Apvienoto Arābu Emirātu dirhēms',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afganistānas afgāns',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albānijas leks',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armēnijas drams',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Nīderlandes Antiļu guldenis',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolas kvanza',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentīnas peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Austrijas šiliņš',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Austrālijas dolārs',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Arubas guldenis',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbaidžānas manats (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaidžānas manats',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnijas un Hercogovinas konvertējamā marka',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadosas dolārs',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladešas taka',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Beļģijas franks',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgārijas leva',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreinas dinārs',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi franks',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermudu dolārs',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunejas dolārs',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolīvijas boliviano',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Brazīlijas reāls',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamu dolārs',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butānas ngultrums',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botsvanas pula',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Baltkrievijas rubelis',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Baltkrievijas rubelis (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belizas dolārs',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanādas dolārs',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'KDR franks',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Šveices franks',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Čīles peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Ķīnas juaņa (ofšors)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Ķīnas juaņs',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbijas peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Kolumbijas reāls',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kostarikas kolons',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kubas konvertējamais peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kubas peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kaboverdes eskudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Kipras mārciņa',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Čehijas krona',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Vācijas marka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Džibutijas franks',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Dānijas krona',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikānas peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Alžīrijas dinārs',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Igaunijas krona',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Ēģiptes mārciņa',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrejas nakfa',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Spānijas peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiopijas birs',
        ],
        'EUR' => [
            0 => '€',
            1 => 'eiro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Somijas marka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fidži dolārs',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Folklenda Salu mārciņa',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Francijas franks',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Lielbritānijas mārciņa',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gruzijas lari',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ganas sedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltāra mārciņa',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambijas dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gvinejas franks',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Grieķijas drahma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Gvatemalas ketsals',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Gajānas dolārs',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Honkongas dolārs',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Hondurasas lempīra',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Horvātijas kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haiti gurds',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Ungārijas forints',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonēzijas rūpija',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Īrijas mārciņa',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Izraēlas šekelis',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indijas rūpija',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irākas dinārs',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Irānas riāls',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islandes krona',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Itālijas lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaikas dolārs',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordānas dinārs',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Japānas jena',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenijas šiliņš',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgizstānas soms',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodžas riels',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komoru franks',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Ziemeļkorejas vona',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Dienvidkorejas vona',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuveitas dinārs',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kaimanu salu dolārs',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazahstānas tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laosas kips',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libānas mārciņa',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Šrilankas rūpija',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Libērijas dolārs',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesoto loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Lietuvas lits',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Luksemburgas franks',
        ],
        'LVL' => [
            0 => 'Ls',
            1 => 'Latvijas lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Latvijas rublis',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Lībijas dinārs',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokas dirhēms',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovas leja',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskaras ariari',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Maķedonijas denārs',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'CFA (Āfrikas) franks',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Mjanmas kjats',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolijas tugriks',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao pataka',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritānijas ugija (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritānijas ugija',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltas lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltas mārciņa',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Maurīcijas rūpija',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldīvijas rūfija',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malāvijas kvača',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksikas peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malaizijas ringits',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambikas eskudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mozambikas vecais metikals',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambikas metikals',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namībijas dolārs',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigērijas naira',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragvas kordoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Nīderlandes guldenis',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norvēģijas krona',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepālas rūpija',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Jaunzēlandes dolārs',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omānas riāls',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamas balboa',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru sols',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua-Jaungvinejas kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filipīnu peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistānas rūpija',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polijas zlots',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugāles eskudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paragvajas guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Kataras riāls',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rumānijas vecā leja',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumānijas leja',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbijas dinārs',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Krievijas rublis',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruandas franks',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saūda Arābijas riāls',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Zālamana Salu dolārs',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seišelu salu rūpija',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudānas mārciņa',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Zviedrijas krona',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapūras dolārs',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Sv.Helēnas salas mārciņa',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slovēnijas tolars',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovakijas krona',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sjerraleones leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somālijas šiliņš',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinamas dolārs',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinamas guldenis',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Dienvidsudānas mārciņa',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Santome un Prinsipi dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Santome un Prinsipi dobra',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Salvadoras kolons',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Sīrijas mārciņa',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svazilendas lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Taizemes bāts',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadžikistānas somons',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmenistānas manats (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistānas manats',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunisijas dinārs',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongas paanga',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turcijas lira (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turcijas lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidādas un Tobāgo dolārs',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Taivānas jaunais dolārs',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzānijas šiliņš',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrainas grivna',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandas šiliņš',
        ],
        'USD' => [
            0 => '$',
            1 => 'ASV dolārs',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Urugvajas peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Uzbekistānas sums',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venecuēlas bolivārs (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venecuēlas bolivārs (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venecuēlas bolivārs',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vjetnamas dongi',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Centrālāfrikas CFA franks',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Austrumkarību dolārs',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Eiropas norēķinu vienība',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Francijas zelta franks',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Francijas UIC franks',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Rietumāfrikas CFA franks',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP franks',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemenas riāls',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Dienvidāfrikas rends',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambijas kvača (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambijas kvača',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabves dolārs',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabves dolārs (2009)',
        ],
    ],
];
