<?php

return [
    'Names' => [
        'aa' => 'Afáiris',
        'ab' => 'Abcáisis',
        'ace' => 'Aicinéis',
        'ada' => 'Daingmis',
        'ady' => 'Adaigéis',
        'ae' => 'Aivéistis',
        'af' => 'Afracáinis',
        'agq' => 'Aigeimis',
        'ain' => 'Aidhniúis',
        'ak' => 'Acáinis',
        'akk' => 'Acáidis',
        'ale' => 'Ailiúitis',
        'alt' => 'Altaeis an Deiscirt',
        'am' => 'Amáiris',
        'an' => 'Aragóinis',
        'ang' => 'Sean-Bhéarla',
        'ann' => 'Obolo',
        'anp' => 'Aingícis',
        'ar' => 'Araibis',
        'arc' => 'Aramais',
        'arn' => 'Mapúitsis',
        'arp' => 'Arapachóis',
        'ars' => 'Araibis Najdi',
        'as' => 'Asaimis',
        'asa' => 'Asúis',
        'ast' => 'Astúiris',
        'atj' => 'Atikamekw',
        'av' => 'Aváiris',
        'awa' => 'Avaidis',
        'ay' => 'Aidhmiris',
        'az' => 'Asarbaiseáinis',
        'ba' => 'Baiscíris',
        'ban' => 'Bailís',
        'bar' => 'Baváiris',
        'bas' => 'Basáis',
        'be' => 'Bealarúisis',
        'bem' => 'Beimbis',
        'bez' => 'Beinis',
        'bg' => 'Bulgáiris',
        'bho' => 'Vóispiris',
        'bi' => 'Bioslaimis',
        'bin' => 'Binis',
        'bla' => 'Sicsicis',
        'bm' => 'Bambairis',
        'bn' => 'Beangáilis',
        'bo' => 'Tibéidis',
        'br' => 'Briotáinis',
        'brx' => 'Bódóis',
        'bs' => 'Boisnis',
        'bua' => 'Buiriáitis',
        'bug' => 'Buiginis',
        'byn' => 'Blinis',
        'ca' => 'Catalóinis',
        'cay' => 'teanga Cayuga',
        'ccp' => 'Seácmais',
        'ce' => 'Seisnis',
        'ceb' => 'Seabúáinis',
        'cgg' => 'Cígis',
        'ch' => 'Seamóiris',
        'chk' => 'Siúicísis',
        'chm' => 'Mairis',
        'cho' => 'Seactáis',
        'chp' => 'Siopúáinis',
        'chr' => 'Seiricis',
        'chy' => 'Siáinis',
        'ckb' => 'Coirdis Lárnach',
        'clc' => 'Chilcotin',
        'co' => 'Corsaicis',
        'cop' => 'Coptais',
        'cr' => 'Craís',
        'crg' => 'Michif',
        'crj' => 'Craís an Deiscirt Thoir',
        'crk' => 'Plains Cree',
        'crl' => 'Craís Thoir Thuaidh',
        'crm' => 'Moose Cree',
        'crr' => 'teanga Algancach Carolina',
        'crs' => 'Criól Fraincise Seselwa',
        'cs' => 'Seicis',
        'csb' => 'Caisiúibis',
        'csw' => 'Swampy Cree',
        'cu' => 'Slavais na hEaglaise',
        'cv' => 'Suvaisis',
        'cy' => 'Breatnais',
        'da' => 'Danmhairgis',
        'dak' => 'Dacótais',
        'dar' => 'Dargais',
        'dav' => 'Taita',
        'de' => 'Gearmáinis',
        'dgr' => 'Dograibis',
        'dje' => 'Zarmais',
        'doi' => 'Dóigris',
        'dsb' => 'Sorbais Íochtarach',
        'dua' => 'Duailis',
        'dum' => 'Meán-Ollainnis',
        'dv' => 'Divéihis',
        'dyo' => 'Jóla-Fainis',
        'dz' => 'Seoinicis',
        'dzg' => 'Dazaga',
        'ebu' => 'Ciambúis',
        'ee' => 'Éabhais',
        'efi' => 'Eificis',
        'egy' => 'Sean-Éigiptis',
        'eka' => 'Acaidiúcais',
        'el' => 'Gréigis',
        'en' => 'Béarla',
        'enm' => 'Meán-Bhéarla',
        'eo' => 'Esperanto',
        'es' => 'Spáinnis',
        'et' => 'Eastóinis',
        'eu' => 'Bascais',
        'ewo' => 'Éabhandóis',
        'fa' => 'Peirsis',
        'ff' => 'Fuláinis',
        'fi' => 'Fionlainnis',
        'fil' => 'Filipínis',
        'fj' => 'Fidsis',
        'fo' => 'Faróis',
        'fon' => 'Fonais',
        'fr' => 'Fraincis',
        'frc' => 'Fraincis Cajun',
        'frm' => 'Meán-Fhraincis',
        'fro' => 'Sean-Fhraincis',
        'frr' => 'Freaslainnis an Tuaiscirt',
        'fur' => 'Friúilis',
        'fy' => 'Freaslainnis Iartharach',
        'ga' => 'Gaeilge',
        'gaa' => 'Geáis',
        'gan' => 'Sínis Gan',
        'gd' => 'Gaeilge na hAlban',
        'gez' => 'Aetóipis',
        'gil' => 'Gilbeartais',
        'gl' => 'Gailísis',
        'gmh' => 'Meán-Ard-Ghearmáinis',
        'gn' => 'Guaráinis',
        'goh' => 'Sean-Ard-Ghearmáinis',
        'gor' => 'Gorantalais',
        'grc' => 'Sean-Ghréigis',
        'gsw' => 'Gearmáinis Eilvéiseach',
        'gu' => 'Gúisearáitis',
        'guc' => 'Uaúis',
        'guz' => 'Gúsaís',
        'gv' => 'Manainnis',
        'gwi' => 'Goitsinis',
        'ha' => 'Hásais',
        'hai' => 'Haídis',
        'hak' => 'Haicéis',
        'haw' => 'Haváis',
        'hax' => 'Haídis an Deiscirt',
        'he' => 'Eabhrais',
        'hi' => 'Hiondúis',
        'hif' => 'Hiondúis Fhidsí',
        'hil' => 'Hilgeanóinis',
        'hit' => 'Hitis',
        'hmn' => 'Hmongais',
        'ho' => 'Motúis Hírí',
        'hr' => 'Cróitis',
        'hsb' => 'Sorbais Uachtarach',
        'hsn' => 'Sínis Xiang',
        'ht' => 'Críol Háítí',
        'hu' => 'Ungáiris',
        'hup' => 'Húipis',
        'hur' => 'Halkomelem',
        'hy' => 'Airméinis',
        'hz' => 'Heiréiris',
        'ia' => 'Interlingua',
        'iba' => 'Ibeainis',
        'ibb' => 'Ibibis',
        'id' => 'Indinéisis',
        'ie' => 'Interlingue',
        'ig' => 'Íogbóis',
        'ii' => 'Ís Shichuan',
        'ik' => 'Iniúipiaicis',
        'ikt' => 'Ionúitis Iarthar Cheanada',
        'ilo' => 'Ileacáinis',
        'inh' => 'Iongúis',
        'io' => 'Ídis',
        'is' => 'Íoslainnis',
        'it' => 'Iodáilis',
        'iu' => 'Ionúitis',
        'ja' => 'Seapáinis',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jut' => 'Iútlainnis',
        'jv' => 'Iáivis',
        'ka' => 'Seoirsis',
        'kaa' => 'Cara-Chalpáis',
        'kab' => 'Caibílis',
        'kac' => 'Caitsinis',
        'kaj' => 'Jju',
        'kam' => 'Cambais',
        'kbd' => 'Cabairdis',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Criól Cabo Verde',
        'kfo' => 'Koro',
        'kg' => 'Congóis',
        'kgp' => 'Kaingang',
        'kha' => 'Caisis',
        'khq' => 'Songais Iartharach',
        'ki' => 'Ciocúis',
        'kj' => 'Cuainiáimis',
        'kk' => 'Casaicis',
        'kkj' => 'Cacóis',
        'kl' => 'Kalaallisut',
        'kln' => 'Kalenjin',
        'km' => 'Ciméiris',
        'kmb' => 'Ciombundais',
        'kn' => 'Cannadais',
        'ko' => 'Cóiréis',
        'kok' => 'Concáinis',
        'kpe' => 'Caipeilis',
        'kr' => 'Canúiris',
        'krc' => 'Caraicí-Balcáiris',
        'krl' => 'Cairéilis',
        'kru' => 'Curúicis',
        'ks' => 'Caismíris',
        'ksb' => 'Shambala',
        'ksf' => 'Baifiais',
        'ksh' => 'Coilsis',
        'ku' => 'Coirdis',
        'kum' => 'Cúimicis',
        'kv' => 'Coimis',
        'kw' => 'Coirnis',
        'kwk' => 'Kwakʼwala',
        'ky' => 'Cirgisis',
        'la' => 'Laidin',
        'lad' => 'Laidínis',
        'lag' => 'Ciolaingis',
        'lah' => 'Puinseáibis Iartharach',
        'lb' => 'Lucsambuirgis',
        'lez' => 'Leisgis',
        'lg' => 'Lugandais',
        'li' => 'Liombuirgis',
        'lij' => 'Liogúiris',
        'lil' => 'Lillooet',
        'liv' => 'Liovóinis',
        'lkt' => 'Lacótais',
        'lmo' => 'Lombairdis',
        'ln' => 'Liongáilis',
        'lo' => 'Laoisis',
        'lou' => 'Criól Louisiana',
        'loz' => 'Lóisis',
        'lrc' => 'Lúiris an Tuaiscirt',
        'lsm' => 'Saamia',
        'lt' => 'Liotuáinis',
        'lu' => 'Lúba-Cataingis',
        'lua' => 'Luba-Lulua',
        'lun' => 'Lundais',
        'luo' => 'Lúóis',
        'lus' => 'Míosóis',
        'luy' => 'Luyia',
        'lv' => 'Laitvis',
        'mad' => 'Maidiúiris',
        'mag' => 'Magaidis',
        'mai' => 'Maitilis',
        'mak' => 'Macasairis',
        'mas' => 'Másais',
        'mdf' => 'Mocsais',
        'men' => 'Meindis',
        'mer' => 'Meru',
        'mfe' => 'Morisyen',
        'mg' => 'Malagáisis',
        'mga' => 'Meán-Ghaeilge',
        'mgh' => 'Meiteo-Macuais',
        'mgo' => 'Metaʼ',
        'mh' => 'Mairsillis',
        'mi' => 'Maorais',
        'mic' => 'Micmeaicis',
        'min' => 'Míneangcababhais',
        'mk' => 'Macadóinis',
        'ml' => 'Mailéalaimis',
        'mn' => 'Mongóilis',
        'mni' => 'Manapúiris',
        'moe' => 'Innu-aimun',
        'moh' => 'Móháicis',
        'mos' => 'Mosais',
        'mr' => 'Maraitis',
        'mrj' => 'Mairis Iartharach',
        'ms' => 'Malaeis',
        'mt' => 'Máltais',
        'mua' => 'Mundang',
        'mus' => 'Muscogee',
        'mwl' => 'Mioraindéis',
        'mwr' => 'Marmhairis',
        'my' => 'Burmais',
        'myv' => 'Éirsis',
        'mzn' => 'Mázandaráinis',
        'na' => 'Nárúis',
        'nan' => 'Sínis Min Nan',
        'nap' => 'Napóilis',
        'naq' => 'Nama',
        'nb' => 'Bocmál',
        'nd' => 'N-deibéilis an Tuaiscirt',
        'nds' => 'Gearmáinis Íochtarach',
        'ne' => 'Neipeailis',
        'new' => 'Néamharais',
        'ng' => 'Ndongais',
        'nia' => 'Niaisis',
        'niu' => 'Níobhais',
        'nl' => 'Ollainnis',
        'nmg' => 'Cuaiseois',
        'nn' => 'Nua-Ioruais',
        'nnh' => 'Ngiemboon',
        'no' => 'Ioruais',
        'nog' => 'Nógaeis',
        'non' => 'Sean-Lochlainnis',
        'nqo' => 'N-cóis',
        'nr' => 'Ndeibéilis an Deiscirt',
        'nso' => 'Sútúis an Tuaiscirt',
        'nus' => 'Nuairis',
        'nv' => 'Navachóis',
        'ny' => 'Siséivis',
        'nyn' => 'Niancóilis',
        'oc' => 'Ocsatáinis',
        'oj' => 'Óisibis',
        'ojb' => 'Óisibis Iarthuiscirt',
        'ojc' => 'Óisibis Lárnach',
        'ojs' => 'Oji-Cree',
        'ojw' => 'Óisibis an Iarthar',
        'oka' => 'Okanagan',
        'om' => 'Oraimis',
        'or' => 'Odia',
        'os' => 'Oiséitis',
        'pa' => 'Puinseáibis',
        'pag' => 'Pangasaíneánais',
        'pam' => 'Pampaingis',
        'pap' => 'Paipeamaintis',
        'pau' => 'Palabhais',
        'pcm' => 'pidsean na Nigéire',
        'peo' => 'Sean-Pheirsis',
        'pi' => 'Páilis',
        'pis' => 'Pijin',
        'pl' => 'Polainnis',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'Prúisis',
        'ps' => 'Paistis',
        'pt' => 'Portaingéilis',
        'qu' => 'Ceatsuais',
        'quc' => 'Cuitséis',
        'rap' => 'Rapanúis',
        'rar' => 'Raratongais',
        'rhg' => 'Róihinis',
        'rm' => 'Rómainis',
        'rn' => 'Rúindis',
        'ro' => 'Rómáinis',
        'rof' => 'Rombo',
        'rom' => 'Romainis',
        'ru' => 'Rúisis',
        'rup' => 'Arómáinis',
        'rw' => 'Ciniaruaindis',
        'rwk' => 'Rwa',
        'sa' => 'Sanscrait',
        'sad' => 'Sandabhais',
        'sah' => 'Sachais',
        'sam' => 'Aramais Shamárach',
        'saq' => 'Samburu',
        'sat' => 'Santáilis',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sairdínis',
        'scn' => 'Sicilis',
        'sco' => 'Albainis',
        'sd' => 'Sindis',
        'se' => 'Sáimis an Tuaiscirt',
        'seh' => 'Sena',
        'ses' => 'Songais Oirthearach',
        'sg' => 'Sangóis',
        'sga' => 'Sean-Ghaeilge',
        'sh' => 'Seirbea-Chróitis',
        'shi' => 'Tachelhit',
        'shn' => 'Seánais',
        'si' => 'Siolóinis',
        'sk' => 'Slóvaicis',
        'sl' => 'Slóivéinis',
        'slh' => 'Lushootseed an Deiscirt',
        'sm' => 'Samóis',
        'sma' => 'Sáimis Theas',
        'smj' => 'Sáimis Lule',
        'smn' => 'Sáimis Inari',
        'sms' => 'Sáimis Skolt',
        'sn' => 'Seoinis',
        'snk' => 'Soinincéis',
        'so' => 'Somáilis',
        'sog' => 'Sogdánais',
        'sq' => 'Albáinis',
        'sr' => 'Seirbis',
        'srn' => 'Suranaimis',
        'ss' => 'Suaisis',
        'st' => 'Sútúis an Deiscirt',
        'str' => 'Straits Salish',
        'su' => 'Sundais',
        'suk' => 'Sucúimis',
        'sux' => 'Suiméiris',
        'sv' => 'Sualainnis',
        'sw' => 'Svahaílis',
        'swb' => 'teanga na gComórach',
        'syr' => 'Siricis',
        'szl' => 'Siléisis',
        'ta' => 'Tamailis',
        'tce' => 'Tutchone an Deiscirt',
        'te' => 'Teileagúis',
        'tem' => 'Teimnis',
        'teo' => 'Teso',
        'tet' => 'Teitimis',
        'tg' => 'Taidsícis',
        'tgx' => 'Tagish',
        'th' => 'Téalainnis',
        'tht' => 'Tahltan',
        'ti' => 'Tigrinis',
        'tig' => 'Tigréis',
        'tk' => 'Tuircméinis',
        'tl' => 'Tagálaigis',
        'tlh' => 'Klingon',
        'tli' => 'Clincitis',
        'tn' => 'Suáinis',
        'to' => 'Tongais',
        'tok' => 'Toki Pona',
        'tpi' => 'Tok Pisin',
        'tr' => 'Tuircis',
        'trv' => 'Taroko',
        'ts' => 'Songais',
        'tt' => 'Tatairis',
        'ttm' => 'Northern Tutchone',
        'tum' => 'Tumbúicis',
        'tvl' => 'Tuvalu',
        'tw' => 'Tíbhis',
        'twq' => 'Tasawaq',
        'ty' => 'Taihítis',
        'tyv' => 'Túvainis',
        'tzm' => 'Tamaisis Atlais Láir',
        'udm' => 'Udmairtis',
        'ug' => 'Uigiúiris',
        'uk' => 'Úcráinis',
        'umb' => 'Umbundais',
        'ur' => 'Urdúis',
        'uz' => 'Úisbéiceastáinis',
        'vai' => 'Vadhais',
        've' => 'Veindis',
        'vec' => 'Veinéisis',
        'vi' => 'Vítneaimis',
        'vls' => 'Pléimeannais Iartharach',
        'vo' => 'Volapük',
        'vun' => 'Vunjo',
        'wa' => 'Vallúnais',
        'wae' => 'Walser',
        'wal' => 'Uailéitis',
        'war' => 'Uairéis',
        'wo' => 'Volaifis',
        'wuu' => 'Sínis Wu',
        'xal' => 'Cailmícis',
        'xh' => 'Cóisis',
        'xog' => 'Soga',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Giúdais',
        'yo' => 'Iarúibis',
        'yrl' => 'Nheengatu',
        'yue' => 'Cantainis',
        'za' => 'Siuáingis',
        'zea' => 'Séalainnis',
        'zgh' => 'Tamaisis Chaighdeánach Mharacó',
        'zh' => 'Sínis',
        'zu' => 'Súlúis',
        'zun' => 'Zúinis',
        'zza' => 'Zázá',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Araibis Chaighdeánach',
        'de_AT' => 'Gearmáinis na hOstaire',
        'de_CH' => 'Ard-Ghearmáinis Eilvéiseach',
        'en_AU' => 'Béarla na hAstráile',
        'en_CA' => 'Béarla Cheanada',
        'en_GB' => 'Béarla na Breataine',
        'en_US' => 'Béarla Mheiriceá',
        'es_419' => 'Spáinnis Mheiriceá Laidinigh',
        'es_ES' => 'Spáinnis Eorpach',
        'es_MX' => 'Spáinnis Mheicsiceach',
        'fa_AF' => 'Dairis',
        'fr_CA' => 'Fraincis Cheanada',
        'fr_CH' => 'Fraincis na hEilvéise',
        'nds_NL' => 'Sacsainis Íochtarach',
        'nl_BE' => 'Pléimeannais',
        'pt_BR' => 'Portaingéilis Bhrasaíleach',
        'pt_PT' => 'Portaingéilis Ibéarach',
        'ro_MD' => 'Moldáivis',
        'sw_CD' => 'Svahaílis an Chongó',
        'zh_Hans' => 'Sínis Shimplithe',
        'zh_Hant' => 'Sínis Thraidisiúnta',
    ],
];
