<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گریٖن وِچ میٖن ٹایِم (عابِدجان)',
        'Africa/Accra' => 'گریٖن وِچ میٖن ٹایِم (اؠکرا)',
        'Africa/Addis_Ababa' => 'مشرقی افریٖقا ٹایِم (عدیس ابابا)',
        'Africa/Algiers' => 'مرکزی یوٗرپی ٹایِم (اَلجیٖرِیا)',
        'Africa/Asmera' => 'مشرقی افریٖقا ٹایِم (اَسمیرا)',
        'Africa/Bamako' => 'گریٖن وِچ میٖن ٹایِم (بماکو)',
        'Africa/Bangui' => 'مغربی افریٖقا ٹایِم (بؠنگوٗیی)',
        'Africa/Banjul' => 'گریٖن وِچ میٖن ٹایِم (بَنجوٗل)',
        'Africa/Bissau' => 'گریٖن وِچ میٖن ٹایِم (بِساؤں)',
        'Africa/Blantyre' => 'مرکزی افریٖقا ٹایِم (بلانتَیر)',
        'Africa/Brazzaville' => 'مغربی افریٖقا ٹایِم (برازاوِل)',
        'Africa/Bujumbura' => 'مرکزی افریٖقا ٹایِم (بُجُمبُرا)',
        'Africa/Cairo' => 'مشرقی یوٗرپی ٹایِم (کَیرو)',
        'Africa/Casablanca' => 'مغرِبی یوٗرپی ٹایِم (کؠسابلؠنکا)',
        'Africa/Ceuta' => 'مرکزی یوٗرپی ٹایِم (کیوٗٹا)',
        'Africa/Conakry' => 'گریٖن وِچ میٖن ٹایِم (کوناکری)',
        'Africa/Dakar' => 'گریٖن وِچ میٖن ٹایِم (دَکار)',
        'Africa/Dar_es_Salaam' => 'مشرقی افریٖقا ٹایِم (دارالسلام)',
        'Africa/Djibouti' => 'مشرقی افریٖقا ٹایِم (ڈِجیبوٹی)',
        'Africa/Douala' => 'مغربی افریٖقا ٹایِم (ڈوولا)',
        'Africa/El_Aaiun' => 'مغرِبی یوٗرپی ٹایِم (ال عیون)',
        'Africa/Freetown' => 'گریٖن وِچ میٖن ٹایِم (فری ٹاوُن)',
        'Africa/Gaborone' => 'مرکزی افریٖقا ٹایِم (گؠبورون)',
        'Africa/Harare' => 'مرکزی افریٖقا ٹایِم (ہَراریے)',
        'Africa/Johannesburg' => 'جنوٗبی افریقا ٹایِم (جوہانسبرگ)',
        'Africa/Juba' => 'مرکزی افریٖقا ٹایِم (جوبا)',
        'Africa/Kampala' => 'مشرقی افریٖقا ٹایِم (کَمپالا)',
        'Africa/Khartoum' => 'مرکزی افریٖقا ٹایِم (کھارتوم)',
        'Africa/Kigali' => 'مرکزی افریٖقا ٹایِم (کِگالی)',
        'Africa/Kinshasa' => 'مغربی افریٖقا ٹایِم (کِنشاسا)',
        'Africa/Lagos' => 'مغربی افریٖقا ٹایِم (لیگوس)',
        'Africa/Libreville' => 'مغربی افریٖقا ٹایِم (لِبَروِل)',
        'Africa/Lome' => 'گریٖن وِچ میٖن ٹایِم (لوم)',
        'Africa/Luanda' => 'مغربی افریٖقا ٹایِم (لیوانڈا)',
        'Africa/Lubumbashi' => 'مرکزی افریٖقا ٹایِم (لوبم باشی)',
        'Africa/Lusaka' => 'مرکزی افریٖقا ٹایِم (لوساکا)',
        'Africa/Malabo' => 'مغربی افریٖقا ٹایِم (مالابو)',
        'Africa/Maputo' => 'مرکزی افریٖقا ٹایِم (مَپوٗٹو)',
        'Africa/Maseru' => 'جنوٗبی افریقا ٹایِم (مَسیروٗ)',
        'Africa/Mbabane' => 'جنوٗبی افریقا ٹایِم (مابین)',
        'Africa/Mogadishu' => 'مشرقی افریٖقا ٹایِم (موگادِشوٗ)',
        'Africa/Monrovia' => 'گریٖن وِچ میٖن ٹایِم (مونرووِیا)',
        'Africa/Nairobi' => 'مشرقی افریٖقا ٹایِم (نیروبی)',
        'Africa/Ndjamena' => 'مغربی افریٖقا ٹایِم (جَمیٖنا)',
        'Africa/Niamey' => 'مغربی افریٖقا ٹایِم (نَیمیے)',
        'Africa/Nouakchott' => 'گریٖن وِچ میٖن ٹایِم (نوواکچھوت)',
        'Africa/Ouagadougou' => 'گریٖن وِچ میٖن ٹایِم (اوآگدوگو)',
        'Africa/Porto-Novo' => 'مغربی افریٖقا ٹایِم (پورٹو نووو)',
        'Africa/Sao_Tome' => 'گریٖن وِچ میٖن ٹایِم (ساو ٹوم)',
        'Africa/Tripoli' => 'مشرقی یوٗرپی ٹایِم (ترپولی)',
        'Africa/Tunis' => 'مرکزی یوٗرپی ٹایِم (ٹوٗنِس)',
        'Africa/Windhoek' => 'مرکزی افریٖقا ٹایِم (وِنڈہوک)',
        'America/Adak' => 'حَواے اؠلیوٗٹِیَن ٹایِم (ادک)',
        'America/Anchorage' => 'اؠلاسکا ٹایِم (اَنکوراج)',
        'America/Anguilla' => 'اؠٹلانٹِک ٹایِم (اؠنگِولا)',
        'America/Antigua' => 'اؠٹلانٹِک ٹایِم (اؠنٹِگُوا)',
        'America/Araguaina' => 'برؠسِلِیا ٹایِم (اؠریگُوینا)',
        'America/Argentina/La_Rioja' => 'ارجؠنٹیٖنا ٹایِم (لا رِیوجا)',
        'America/Argentina/Rio_Gallegos' => 'ارجؠنٹیٖنا ٹایِم (رِیو گالیگوس)',
        'America/Argentina/Salta' => 'ارجؠنٹیٖنا ٹایِم (سالٹا)',
        'America/Argentina/San_Juan' => 'ارجؠنٹیٖنا ٹایِم (سین جُواں)',
        'America/Argentina/San_Luis' => 'ارجؠنٹیٖنا ٹایِم (سین لوٗیِس)',
        'America/Argentina/Tucuman' => 'ارجؠنٹیٖنا ٹایِم (ٹوکوٗمَن)',
        'America/Argentina/Ushuaia' => 'ارجؠنٹیٖنا ٹایِم (اُشُوٗاییا)',
        'America/Aruba' => 'اؠٹلانٹِک ٹایِم (اَروٗبا)',
        'America/Asuncion' => 'پیرؠگوے ٹایِم (اَسُنچِیَن)',
        'America/Bahia' => 'برؠسِلِیا ٹایِم (بَہِیا)',
        'America/Bahia_Banderas' => 'مرکزی ٹایِم (باہیا بندارس)',
        'America/Barbados' => 'اؠٹلانٹِک ٹایِم (بارباڈوس)',
        'America/Belem' => 'برؠسِلِیا ٹایِم (بؠلؠم)',
        'America/Belize' => 'مرکزی ٹایِم (بؠلیٖز)',
        'America/Blanc-Sablon' => 'اؠٹلانٹِک ٹایِم (بلانک سؠبلَن)',
        'America/Boa_Vista' => 'اؠمَزَن ٹایِم (بوآ وِسٹا)',
        'America/Bogota' => 'کولومبِیا ٹایِم (بوگوٹا)',
        'America/Boise' => 'ماونٹین ٹایِم (بویِس)',
        'America/Buenos_Aires' => 'ارجؠنٹیٖنا ٹایِم (بیوٗنَس آیرَس)',
        'America/Cambridge_Bay' => 'ماونٹین ٹایِم (کیمبرِج خلیٖج)',
        'America/Campo_Grande' => 'اؠمَزَن ٹایِم (کؠمپو گرینڑ)',
        'America/Cancun' => 'مشرقی ٹایِم (کینکَن)',
        'America/Caracas' => 'وؠنؠزیوٗلا ٹایِم (کیرَکَس)',
        'America/Catamarca' => 'ارجؠنٹیٖنا ٹایِم (کیٹامارکا)',
        'America/Cayenne' => 'فرؠنچ گیوٗؠنا ٹایِم (کَیین)',
        'America/Cayman' => 'مشرقی ٹایِم (کیمَن)',
        'America/Chicago' => 'مرکزی ٹایِم (شِکاگو)',
        'America/Chihuahua' => 'میکسیکن پیسیفک ٹائم (چِہُوا ہُوا)',
        'America/Coral_Harbour' => 'مشرقی ٹایِم (اٹی کوکنٍ)',
        'America/Cordoba' => 'ارجؠنٹیٖنا ٹایِم (کورڑوبا)',
        'America/Costa_Rica' => 'مرکزی ٹایِم (کوسٹا ریٖکا)',
        'America/Creston' => 'ماونٹین ٹایِم (کریسٹن)',
        'America/Cuiaba' => 'اؠمَزَن ٹایِم (کوٗیابا)',
        'America/Curacao' => 'اؠٹلانٹِک ٹایِم (کیوٗراکااو)',
        'America/Danmarkshavn' => 'گریٖن وِچ میٖن ٹایِم (ڈنمارک شاون)',
        'America/Dawson' => 'یوکون ٹائم (ڈاوسن)',
        'America/Dawson_Creek' => 'ماونٹین ٹایِم (ڈواسَن کریٖک)',
        'America/Denver' => 'ماونٹین ٹایِم (ڈینوَر)',
        'America/Detroit' => 'مشرقی ٹایِم (ڈیٹرایِٹ)',
        'America/Dominica' => 'اؠٹلانٹِک ٹایِم (ڈومِنِکا)',
        'America/Edmonton' => 'ماونٹین ٹایِم (اؠڈمَنٹَن)',
        'America/Eirunepe' => 'اؠکرے ٹایِم (ایٖروٗنیپ)',
        'America/El_Salvador' => 'مرکزی ٹایِم (ایل سَلویدَر)',
        'America/Fort_Nelson' => 'ماونٹین ٹایِم (فورٹ نیلسن)',
        'America/Fortaleza' => 'برؠسِلِیا ٹایِم (فورٹیلیزا)',
        'America/Glace_Bay' => 'اؠٹلانٹِک ٹایِم (گلیس خلیٖج)',
        'America/Godthab' => 'مغرِبی گریٖن لینڈُک ٹایِم (نوٗک)',
        'America/Goose_Bay' => 'اؠٹلانٹِک ٹایِم (گوٗس خلیٖج)',
        'America/Grand_Turk' => 'مشرقی ٹایِم (گرینڈ تٔرک)',
        'America/Grenada' => 'اؠٹلانٹِک ٹایِم (گریناڈا)',
        'America/Guadeloupe' => 'اؠٹلانٹِک ٹایِم (گوڑلوپ)',
        'America/Guatemala' => 'مرکزی ٹایِم (گواٹیمالا)',
        'America/Guayaquil' => 'اِکویڑَر ٹایِم (گوایاکِوَل)',
        'America/Guyana' => 'گُیَنا ٹایِم (گُیانا)',
        'America/Halifax' => 'اؠٹلانٹِک ٹایِم (حیلِفؠکس)',
        'America/Havana' => 'کیوٗبا ٹایِم (حوانا)',
        'America/Hermosillo' => 'میکسیکن پیسیفک ٹائم (ۂرموسِلو)',
        'America/Indiana/Knox' => 'مرکزی ٹایِم (نوکس)',
        'America/Indiana/Marengo' => 'مشرقی ٹایِم (میرنگو، انڈیانا)',
        'America/Indiana/Petersburg' => 'مشرقی ٹایِم (پِٹس بٔرگ، انڈیانا)',
        'America/Indiana/Tell_City' => 'مرکزی ٹایِم (ٹیل سِٹی، انڈیانا)',
        'America/Indiana/Vevay' => 'مشرقی ٹایِم (ویویے، انڈیانا)',
        'America/Indiana/Vincennes' => 'مشرقی ٹایِم (وِنسینیس، انڈیانا)',
        'America/Indiana/Winamac' => 'مشرقی ٹایِم (وِنیمیک، انڈیانا)',
        'America/Indianapolis' => 'مشرقی ٹایِم (اِنڈیَن پولِس)',
        'America/Inuvik' => 'ماونٹین ٹایِم (اِنوٗوِک)',
        'America/Iqaluit' => 'مشرقی ٹایِم (اِقالیوٗیِت)',
        'America/Jamaica' => 'مشرقی ٹایِم (جَمَیکا)',
        'America/Jujuy' => 'ارجؠنٹیٖنا ٹایِم (جُجویے)',
        'America/Juneau' => 'اؠلاسکا ٹایِم (جوٗنی)',
        'America/Kentucky/Monticello' => 'مشرقی ٹایِم (مونٹِسیلو، کینٹوکی)',
        'America/Kralendijk' => 'اؠٹلانٹِک ٹایِم (کرالینڈِک)',
        'America/La_Paz' => 'بولِوِیا ٹایِم (لا پاز)',
        'America/Lima' => 'پٔروٗ ٹایِم (لِما)',
        'America/Los_Angeles' => 'پیسِفِک ٹایِم (لاس اینجٕلز)',
        'America/Louisville' => 'مشرقی ٹایِم (لوٗیِس وِل)',
        'America/Lower_Princes' => 'اؠٹلانٹِک ٹایِم (لوور پرنس کوارٹر)',
        'America/Maceio' => 'برؠسِلِیا ٹایِم (میسِیوو)',
        'America/Managua' => 'مرکزی ٹایِم (مَناگوا)',
        'America/Manaus' => 'اؠمَزَن ٹایِم (مَنوس)',
        'America/Marigot' => 'اؠٹلانٹِک ٹایِم (میریگوٹ)',
        'America/Martinique' => 'اؠٹلانٹِک ٹایِم (مارٹِنِک)',
        'America/Matamoros' => 'مرکزی ٹایِم (میٹاموروس)',
        'America/Mazatlan' => 'میکسیکن پیسیفک ٹائم (مَزَٹلان)',
        'America/Mendoza' => 'ارجؠنٹیٖنا ٹایِم (مؠنڑوزا)',
        'America/Menominee' => 'مرکزی ٹایِم (مینومِنی)',
        'America/Merida' => 'مرکزی ٹایِم (میرِڈا)',
        'America/Metlakatla' => 'اؠلاسکا ٹایِم (میٹلا کاٹلا)',
        'America/Mexico_City' => 'مرکزی ٹایِم (میکسِکو سِٹی)',
        'America/Miquelon' => 'سینٹ پَیری مِقیوٗلَن ٹایِم (مِکیٖلَن)',
        'America/Moncton' => 'اؠٹلانٹِک ٹایِم (مونکٹٕن)',
        'America/Monterrey' => 'مرکزی ٹایِم (موٹیری)',
        'America/Montevideo' => 'یوٗرؠگوَے ٹایِم (مونٹیوِڈیو)',
        'America/Montreal' => 'کینیڈا وَکھ (Montreal)',
        'America/Montserrat' => 'اؠٹلانٹِک ٹایِم (مونژیرات)',
        'America/Nassau' => 'مشرقی ٹایِم (نساؤں)',
        'America/New_York' => 'مشرقی ٹایِم (نِو یارک)',
        'America/Nipigon' => 'مشرقی ٹایِم (نِپِگَن)',
        'America/Nome' => 'اؠلاسکا ٹایِم (نوم)',
        'America/Noronha' => 'فرنینڈو ڈی نورونہا ٹائم',
        'America/North_Dakota/Beulah' => 'مرکزی ٹایِم (بیولاہ، شُمالی ڈیکوٹا)',
        'America/North_Dakota/Center' => 'مرکزی ٹایِم (مَرکزی جنوٗبی ڈکوٹا)',
        'America/North_Dakota/New_Salem' => 'مرکزی ٹایِم (نوو سیلٕم، شُمالی ڈیکوٹا)',
        'America/Ojinaga' => 'ماونٹین ٹایِم (اوجی ناگا)',
        'America/Panama' => 'مشرقی ٹایِم (پَناما)',
        'America/Pangnirtung' => 'مشرقی ٹایِم (پَنگنِرٹَنگ)',
        'America/Paramaribo' => 'سُرِنام ٹایِم (پَرامارِبو)',
        'America/Phoenix' => 'ماونٹین ٹایِم (پھِنِکس)',
        'America/Port-au-Prince' => 'مشرقی ٹایِم (پوٹ آؤں پرِنس)',
        'America/Port_of_Spain' => 'اؠٹلانٹِک ٹایِم (پوٹ آف سپین)',
        'America/Porto_Velho' => 'اؠمَزَن ٹایِم (پوٹو وؠلہو)',
        'America/Puerto_Rico' => 'اؠٹلانٹِک ٹایِم (پیٖٹو رِکو)',
        'America/Punta_Arenas' => 'چِلی ٹایِم (پونٹا اریناس)',
        'America/Rainy_River' => 'مرکزی ٹایِم (رینی رِوَر)',
        'America/Rankin_Inlet' => 'مرکزی ٹایِم (رینکِن اِنلؠٹ)',
        'America/Recife' => 'برؠسِلِیا ٹایِم (ریسیف)',
        'America/Regina' => 'مرکزی ٹایِم (رؠجیٖنا)',
        'America/Resolute' => 'مرکزی ٹایِم (رِسولیوٗٹ)',
        'America/Rio_Branco' => 'اؠکرے ٹایِم (رِیو برانکو)',
        'America/Santa_Isabel' => 'شُمال مغربی میکسیکو ٹائم (Santa Isabel)',
        'America/Santarem' => 'برؠسِلِیا ٹایِم (سانتاریم)',
        'America/Santiago' => 'چِلی ٹایِم (سینٹیاگو)',
        'America/Santo_Domingo' => 'اؠٹلانٹِک ٹایِم (سؠنٹو ڑومِنگو)',
        'America/Sao_Paulo' => 'برؠسِلِیا ٹایِم (ساؤ پالو)',
        'America/Scoresbysund' => 'مشرِقی گریٖن لینڈُک ٹایِم (سکورٕسباےسَنڑ)',
        'America/Sitka' => 'اؠلاسکا ٹایِم (سِٹکا)',
        'America/St_Barthelemy' => 'اؠٹلانٹِک ٹایِم (سینٹ بارتھیلمی)',
        'America/St_Johns' => 'نیو فاؤنڈ لینڈ ٹائم (سؠنٹ جونس)',
        'America/St_Kitts' => 'اؠٹلانٹِک ٹایِم (سینٹ کِٹس)',
        'America/St_Lucia' => 'اؠٹلانٹِک ٹایِم (سؠنٹ لوٗسِیا)',
        'America/St_Thomas' => 'اؠٹلانٹِک ٹایِم (سینٹ تھامَس)',
        'America/St_Vincent' => 'اؠٹلانٹِک ٹایِم (سینٹ وِنسینٹ)',
        'America/Swift_Current' => 'مرکزی ٹایِم (سٕوِفٹ کَرَنٹ)',
        'America/Tegucigalpa' => 'مرکزی ٹایِم (ٹیگوسی گالپا)',
        'America/Thule' => 'اؠٹلانٹِک ٹایِم (تھیوٗلے)',
        'America/Thunder_Bay' => 'مشرقی ٹایِم (تھَنڈر خلیٖج)',
        'America/Tijuana' => 'پیسِفِک ٹایِم (تِجُوانا)',
        'America/Toronto' => 'مشرقی ٹایِم (ٹورونٹو)',
        'America/Tortola' => 'اؠٹلانٹِک ٹایِم (ٹارٹولا)',
        'America/Vancouver' => 'پیسِفِک ٹایِم (وؠنکووَر)',
        'America/Whitehorse' => 'یوکون ٹائم (وایِٹ ہارٕس)',
        'America/Winnipeg' => 'مرکزی ٹایِم (وِنِپؠگ)',
        'America/Yakutat' => 'اؠلاسکا ٹایِم (یکوٗتات)',
        'America/Yellowknife' => 'ماونٹین ٹایِم (یؠلو نایِف)',
        'Antarctica/Casey' => 'اینٹارٹِکا وَکھ (کیسی)',
        'Antarctica/Davis' => 'ڑیوِس ٹایِم (ڈیوِس)',
        'Antarctica/DumontDUrville' => 'ڑمانٹ ڈی اُرویٖل ٹایِم (ڈُمونٹ ڈ اَروِل)',
        'Antarctica/Macquarie' => 'مشرِقی آسٹریلِیا ٹایِم (Macquarie)',
        'Antarctica/Mawson' => 'ماسَن ٹایِم',
        'Antarctica/McMurdo' => 'نِوزِلینڑ ٹایِم (مؠک مٲڑو)',
        'Antarctica/Palmer' => 'چِلی ٹایِم (پامَر)',
        'Antarctica/Rothera' => 'روتھؠرا ٹایِم (روتھیرا)',
        'Antarctica/Syowa' => 'سیووا ٹایِم',
        'Antarctica/Troll' => 'گریٖن وِچ میٖن ٹایِم (Troll)',
        'Antarctica/Vostok' => 'ووسٹوک ٹایِم (ووستوک)',
        'Arctic/Longyearbyen' => 'مرکزی یوٗرپی ٹایِم (لونگ ییئر بئین)',
        'Asia/Aden' => 'ارؠبِیَن ٹایِم (ایڈٕن)',
        'Asia/Almaty' => 'مشرقی قازقستان ٹائم (اَلماٹی)',
        'Asia/Amman' => 'مشرقی یوٗرپی ٹایِم (اَمان)',
        'Asia/Anadyr' => 'اؠنَڑیٖر ٹایِم (اَنَدیر)',
        'Asia/Aqtau' => 'مغربی قازقستان ٹائم (اکٹو)',
        'Asia/Aqtobe' => 'مغربی قازقستان ٹائم (اَقٹوب)',
        'Asia/Ashgabat' => 'ترکمانستان ٹائم (اَشگَبَت)',
        'Asia/Atyrau' => 'مغربی قازقستان ٹائم (اٹیرو)',
        'Asia/Baghdad' => 'ارؠبِیَن ٹایِم (بغداد)',
        'Asia/Bahrain' => 'ارؠبِیَن ٹایِم (بؠہریٖن)',
        'Asia/Baku' => 'ازربائیجان ٹائم (باقوٗ)',
        'Asia/Bangkok' => 'اِنڑوچَینا ٹایِم (بینگ کاک)',
        'Asia/Barnaul' => 'روٗس وَکھ (برنول)',
        'Asia/Beirut' => 'مشرقی یوٗرپی ٹایِم (بیرٹ)',
        'Asia/Bishkek' => 'کرغزستان ٹائم (بِشکیک)',
        'Asia/Brunei' => 'بروٗنَے دَروٗسَلَم ٹایِم',
        'Asia/Calcutta' => 'ہِندوستان (Kolkata)',
        'Asia/Chita' => 'یَکُٹسک ٹایِم (چیٹا)',
        'Asia/Choibalsan' => 'اولن باٹر ٹائم (چویبالسَن)',
        'Asia/Colombo' => 'ہِندوستان (کولَمبو)',
        'Asia/Damascus' => 'مشرقی یوٗرپی ٹایِم (دَمَسکَس)',
        'Asia/Dhaka' => 'بَنگلادیش ٹایِم (ڈھاکا)',
        'Asia/Dili' => 'ایٖسٹ ٹیٖمَر ٹایِم (دِلی)',
        'Asia/Dubai' => 'گَلف سٹینڈرڈ ٹایِم (دُبئی)',
        'Asia/Dushanbe' => 'تاجکستان ٹائم (دُشانبیے)',
        'Asia/Famagusta' => 'مشرقی یوٗرپی ٹایِم (فاما گوسٹا)',
        'Asia/Gaza' => 'مشرقی یوٗرپی ٹایِم (غزہ)',
        'Asia/Hebron' => 'مشرقی یوٗرپی ٹایِم (ہیبرون)',
        'Asia/Hong_Kong' => 'ہانگ کانگ ٹائم',
        'Asia/Hovd' => 'حووڑ ٹایِم',
        'Asia/Irkutsk' => 'اِرکُٹسک ٹایِم (اِرکُسک)',
        'Asia/Jakarta' => 'مغرِبی اِنڑونیشِیا ٹایِم (جکارتا)',
        'Asia/Jayapura' => 'مشرِقی اِنڑونیشِیا ٹایِم (جَیاپوٗرا)',
        'Asia/Jerusalem' => 'اِسرٲیِلی ٹایِم (یروشلم)',
        'Asia/Kabul' => 'افغانِستان ٹایِم (قابُل)',
        'Asia/Kamchatka' => 'کَمچَٹکا ٹایِم (کَمچھٹکا)',
        'Asia/Karachi' => 'پاکِستان ٹایِم (کَراچی)',
        'Asia/Katmandu' => 'نؠپٲلۍ ٹایِم (کاٹھمَنڈوٗ)',
        'Asia/Khandyga' => 'یَکُٹسک ٹایِم (کھانڈیگا)',
        'Asia/Krasnoyarsk' => 'کرؠسنوےیارسک ٹایِم (کرنسنویارسک)',
        'Asia/Kuala_Lumpur' => 'مَلیشِیا ٹایِم (کولالَمپوٗر)',
        'Asia/Kuching' => 'مَلیشِیا ٹایِم (کُچِنگ)',
        'Asia/Kuwait' => 'ارؠبِیَن ٹایِم (کُویت)',
        'Asia/Macau' => 'چَینا ٹایِم (مکو)',
        'Asia/Magadan' => 'مَگَدَن ٹایِم (مَگادَن)',
        'Asia/Makassar' => 'مرکزی اِنڑونیشِیا ٹایِم (مَکَسَر)',
        'Asia/Manila' => 'پھِلِپایِن ٹایِم (مَنیٖلا)',
        'Asia/Muscat' => 'گَلف سٹینڈرڈ ٹایِم (مسقط)',
        'Asia/Nicosia' => 'مشرقی یوٗرپی ٹایِم (نِکوسِیا)',
        'Asia/Novokuznetsk' => 'کرؠسنوےیارسک ٹایِم (نوووکُزنیٹسک)',
        'Asia/Novosibirsk' => 'نۄوۄسِبٔرسک ٹایِم (نوووسِبِرسک)',
        'Asia/Omsk' => 'اۄمسک ٹایِم (اومسک)',
        'Asia/Oral' => 'مغربی قازقستان ٹائم (اورَل)',
        'Asia/Phnom_Penh' => 'اِنڑوچَینا ٹایِم (نوم پؠنہہ)',
        'Asia/Pontianak' => 'مغرِبی اِنڑونیشِیا ٹایِم (پونتِعانک)',
        'Asia/Pyongyang' => 'کورِیا ٹایِم (پیونگیانگ)',
        'Asia/Qatar' => 'ارؠبِیَن ٹایِم (قطر)',
        'Asia/Qostanay' => 'مشرقی قازقستان ٹائم (کوسٹانے)',
        'Asia/Qyzylorda' => 'مغربی قازقستان ٹائم (قؠزؠلوڑا)',
        'Asia/Rangoon' => 'مِیانمَر ٹایِم (رنگوٗن)',
        'Asia/Riyadh' => 'ارؠبِیَن ٹایِم (ریاض)',
        'Asia/Saigon' => 'اِنڑوچَینا ٹایِم (سیگَن)',
        'Asia/Sakhalin' => 'سَکھؠلِن ٹایِم (سَکھالِن)',
        'Asia/Samarkand' => 'اُزبیکِستان ٹایِم (سَمَرکَند)',
        'Asia/Seoul' => 'کورِیا ٹایِم (سیول)',
        'Asia/Shanghai' => 'چَینا ٹایِم (شانگے)',
        'Asia/Singapore' => 'سِنگاپوٗر ٹایِم (سِنگاپور)',
        'Asia/Srednekolymsk' => 'مَگَدَن ٹایِم (سریڈنیکولیمسک)',
        'Asia/Taipei' => 'ٹے پے ٹائم (تَیپیے)',
        'Asia/Tashkent' => 'اُزبیکِستان ٹایِم (تاشکینٹ)',
        'Asia/Tbilisi' => 'جورجِیاہُک ٹایِم (بِلِسی)',
        'Asia/Tehran' => 'اِیٖرٲنۍ ٹایِم (تؠہران)',
        'Asia/Thimphu' => 'بوٗٹان ٹایِم (تھِمپوٗ)',
        'Asia/Tokyo' => 'جاپٲنۍ ٹایِم (ٹوکیو)',
        'Asia/Tomsk' => 'روٗس وَکھ (ٹومسک)',
        'Asia/Ulaanbaatar' => 'اولن باٹر ٹائم',
        'Asia/Urumqi' => 'چیٖن وَکھ (اُرومقی)',
        'Asia/Ust-Nera' => 'ولاڑِووسٹوک ٹایِم (اوسٹ-نیرا)',
        'Asia/Vientiane' => 'اِنڑوچَینا ٹایِم (وِیَنتِیین)',
        'Asia/Vladivostok' => 'ولاڑِووسٹوک ٹایِم (لادِووستوک)',
        'Asia/Yakutsk' => 'یَکُٹسک ٹایِم (یکوسک)',
        'Asia/Yekaterinburg' => 'یؠکَٹٔرِنبٔرگ ٹایِم (یَکاتِرِنبٔرگ)',
        'Asia/Yerevan' => 'ارمیٖنِیا ٹایِم (یےریوَن)',
        'Atlantic/Azores' => 'اؠزورٕس ٹایِم (اَزورَس)',
        'Atlantic/Bermuda' => 'اؠٹلانٹِک ٹایِم (برموٗڑا)',
        'Atlantic/Canary' => 'مغرِبی یوٗرپی ٹایِم (کؠنَری)',
        'Atlantic/Cape_Verde' => 'کیپ ؤرڑو ٹایِم (کیپ ؤرڑے)',
        'Atlantic/Faeroe' => 'مغرِبی یوٗرپی ٹایِم (فؠرو)',
        'Atlantic/Madeira' => 'مغرِبی یوٗرپی ٹایِم (مَڈیٖرا)',
        'Atlantic/Reykjavik' => 'گریٖن وِچ میٖن ٹایِم (رؠکیاوِک)',
        'Atlantic/South_Georgia' => 'شُمٲلی جورجِیا ٹایِم (جنوبی جارجیا)',
        'Atlantic/St_Helena' => 'گریٖن وِچ میٖن ٹایِم (سینٹ ہیلِنا)',
        'Atlantic/Stanley' => 'فالک لینڈ جزیرٕ ٹائم (سٹینلی)',
        'Australia/Adelaide' => 'مرکزی آسٹریلِیَن ٹایِم (اؠڑِلیڑ)',
        'Australia/Brisbane' => 'مشرِقی آسٹریلِیا ٹایِم (برسبین)',
        'Australia/Broken_Hill' => 'مرکزی آسٹریلِیَن ٹایِم (بروکٕن ہِل)',
        'Australia/Currie' => 'مشرِقی آسٹریلِیا ٹایِم (کیوٗری)',
        'Australia/Darwin' => 'مرکزی آسٹریلِیَن ٹایِم (ڈاروِن)',
        'Australia/Eucla' => 'آسٹریلِیَن مرکزی مغربی ٹایِم (یوٗکلا)',
        'Australia/Hobart' => 'مشرِقی آسٹریلِیا ٹایِم (حۄبٲٹ)',
        'Australia/Lindeman' => 'مشرِقی آسٹریلِیا ٹایِم (لِنڑیمان)',
        'Australia/Lord_Howe' => 'لعاڑ حووے ٹایِم (لعاڑ ہووے)',
        'Australia/Melbourne' => 'مشرِقی آسٹریلِیا ٹایِم (مؠلبعارن)',
        'Australia/Perth' => 'مغرِبی آسٹریلِیا ٹایِم (پٔرتھ)',
        'Australia/Sydney' => 'مشرِقی آسٹریلِیا ٹایِم (سِڑنی)',
        'CST6CDT' => 'مرکزی ٹایِم',
        'EST5EDT' => 'مشرقی ٹایِم',
        'Etc/GMT' => 'گریٖن وِچ میٖن ٹایِم',
        'Etc/UTC' => 'کوآرڈنیٹڈ یونیورسل وَکھ',
        'Europe/Amsterdam' => 'مرکزی یوٗرپی ٹایِم (ایمسٹَرڈیم)',
        'Europe/Andorra' => 'مرکزی یوٗرپی ٹایِم (اَنڈورا)',
        'Europe/Astrakhan' => 'ماسکَو ٹایِم (ایسٹرا کھان)',
        'Europe/Athens' => 'مشرقی یوٗرپی ٹایِم (اؠتھٕنس)',
        'Europe/Belgrade' => 'مرکزی یوٗرپی ٹایِم (بیلگریڈ)',
        'Europe/Berlin' => 'مرکزی یوٗرپی ٹایِم (بٔرلِن)',
        'Europe/Bratislava' => 'مرکزی یوٗرپی ٹایِم (بریٹیسلاوا)',
        'Europe/Brussels' => 'مرکزی یوٗرپی ٹایِم (برسٕلس)',
        'Europe/Bucharest' => 'مشرقی یوٗرپی ٹایِم (بَچاریسٹ)',
        'Europe/Budapest' => 'مرکزی یوٗرپی ٹایِم (بُڈاپیسٹ)',
        'Europe/Busingen' => 'مرکزی یوٗرپی ٹایِم (بوسِنگین)',
        'Europe/Chisinau' => 'مشرقی یوٗرپی ٹایِم (چِسیٖنو)',
        'Europe/Copenhagen' => 'مرکزی یوٗرپی ٹایِم (کوپن ہیگن)',
        'Europe/Dublin' => 'گریٖن وِچ میٖن ٹایِم (ڈَبلِن)',
        'Europe/Gibraltar' => 'مرکزی یوٗرپی ٹایِم (گِبرالٹَر)',
        'Europe/Guernsey' => 'گریٖن وِچ میٖن ٹایِم (گویرنسے)',
        'Europe/Helsinki' => 'مشرقی یوٗرپی ٹایِم (حؠلسِنکی)',
        'Europe/Isle_of_Man' => 'گریٖن وِچ میٖن ٹایِم (آئل آف مین)',
        'Europe/Istanbul' => 'تُرکی وَکھ (اِستانبُل)',
        'Europe/Jersey' => 'گریٖن وِچ میٖن ٹایِم (جرسی)',
        'Europe/Kaliningrad' => 'مشرقی یوٗرپی ٹایِم (کَلِناِنگرَد)',
        'Europe/Kiev' => 'مشرقی یوٗرپی ٹایِم (کیٖو)',
        'Europe/Kirov' => 'روٗس وَکھ (کیرو)',
        'Europe/Lisbon' => 'مغرِبی یوٗرپی ٹایِم (لِسبَن)',
        'Europe/Ljubljana' => 'مرکزی یوٗرپی ٹایِم (لِیوٗب لِیانا)',
        'Europe/London' => 'گریٖن وِچ میٖن ٹایِم (لَندَن)',
        'Europe/Luxembourg' => 'مرکزی یوٗرپی ٹایِم (لَکزٕمبٔرگ)',
        'Europe/Madrid' => 'مرکزی یوٗرپی ٹایِم (میڈریڈ)',
        'Europe/Malta' => 'مرکزی یوٗرپی ٹایِم (مالٹا)',
        'Europe/Mariehamn' => 'مشرقی یوٗرپی ٹایِم (میری ہیم)',
        'Europe/Minsk' => 'ماسکَو ٹایِم (مِنسک)',
        'Europe/Monaco' => 'مرکزی یوٗرپی ٹایِم (موناکو)',
        'Europe/Moscow' => 'ماسکَو ٹایِم (ماسکو)',
        'Europe/Oslo' => 'مرکزی یوٗرپی ٹایِم (اوسلو)',
        'Europe/Paris' => 'مرکزی یوٗرپی ٹایِم (پیرِس)',
        'Europe/Podgorica' => 'مرکزی یوٗرپی ٹایِم (پوڈگوریکا)',
        'Europe/Prague' => 'مرکزی یوٗرپی ٹایِم (پراگ)',
        'Europe/Riga' => 'مشرقی یوٗرپی ٹایِم (رِگا)',
        'Europe/Rome' => 'مرکزی یوٗرپی ٹایِم (روم)',
        'Europe/Samara' => 'سمؠرا ٹایِم (سَمارا)',
        'Europe/San_Marino' => 'مرکزی یوٗرپی ٹایِم (سین مرینو)',
        'Europe/Sarajevo' => 'مرکزی یوٗرپی ٹایِم (سارا جیوو)',
        'Europe/Saratov' => 'ماسکَو ٹایِم (ساراٹو)',
        'Europe/Simferopol' => 'ماسکَو ٹایِم (سِمفیروپول)',
        'Europe/Skopje' => 'مرکزی یوٗرپی ٹایِم (سِکوپیے)',
        'Europe/Sofia' => 'مشرقی یوٗرپی ٹایِم (سوفِیا)',
        'Europe/Stockholm' => 'مرکزی یوٗرپی ٹایِم (سٹاک ہولم)',
        'Europe/Tallinn' => 'مشرقی یوٗرپی ٹایِم (ٹؠلِن)',
        'Europe/Tirane' => 'مرکزی یوٗرپی ٹایِم (ٹِرین)',
        'Europe/Ulyanovsk' => 'ماسکَو ٹایِم (اولیانووسک)',
        'Europe/Uzhgorod' => 'مشرقی یوٗرپی ٹایِم (اُزگورود)',
        'Europe/Vaduz' => 'مرکزی یوٗرپی ٹایِم (وادُز)',
        'Europe/Vatican' => 'مرکزی یوٗرپی ٹایِم (ویٹیکن)',
        'Europe/Vienna' => 'مرکزی یوٗرپی ٹایِم (وِیَننا)',
        'Europe/Vilnius' => 'مشرقی یوٗرپی ٹایِم (وِلِنِیَس)',
        'Europe/Volgograd' => 'وولگوگریڑ ٹایِم (وولگوگرَد)',
        'Europe/Warsaw' => 'مرکزی یوٗرپی ٹایِم (وارسا)',
        'Europe/Zagreb' => 'مرکزی یوٗرپی ٹایِم (زگریب)',
        'Europe/Zaporozhye' => 'مشرقی یوٗرپی ٹایِم (زَپوروزَے)',
        'Europe/Zurich' => 'مرکزی یوٗرپی ٹایِم (زیوٗرِک)',
        'Indian/Antananarivo' => 'مشرقی افریٖقا ٹایِم (اؠنٹنانرِوو)',
        'Indian/Chagos' => 'ہِندوستٲنۍ اوشَن ٹائم (چاگوس)',
        'Indian/Christmas' => 'کرسمَس ٹایِم (کرِسمَس)',
        'Indian/Cocos' => 'کوکوز اَیلینڑز ٹایِم (کوکوس)',
        'Indian/Comoro' => 'مشرقی افریٖقا ٹایِم (کومورو)',
        'Indian/Kerguelen' => 'فرینچ جنوبی تٕہ انٹارکٹِک ٹائم (کیرگولِن)',
        'Indian/Mahe' => 'سیشؠلٕز ٹایِم (ماہیے)',
        'Indian/Maldives' => 'مالدیٖوٕز ٹایِم (مالدیٖوز)',
        'Indian/Mauritius' => 'مورِشَس ٹایِم (مورِشیس)',
        'Indian/Mayotte' => 'مشرقی افریٖقا ٹایِم (میوٹ)',
        'Indian/Reunion' => 'رِیوٗنِیَن ٹایِم (رِیوٗنیَن)',
        'MST7MDT' => 'ماونٹین ٹایِم',
        'PST8PDT' => 'پیسِفِک ٹایِم',
        'Pacific/Apia' => 'سامو وَکھ (آپِیا)',
        'Pacific/Auckland' => 'نِوزِلینڑ ٹایِم (آکلینڈ)',
        'Pacific/Bougainville' => 'پاپُعا نیوٗ گؠنی ٹایِم (Bougainville)',
        'Pacific/Chatham' => 'کؠتھَم ٹایِم (چَتھَم)',
        'Pacific/Easter' => 'ایٖسٹَر جزیرٕ ٹایِم',
        'Pacific/Efate' => 'وَنوٗاَٹوٗ ٹایِم (ایفاتیے)',
        'Pacific/Enderbury' => 'پھونِکس ججیٖرُک ٹایِم (اؠنڑربیری)',
        'Pacific/Fakaofo' => 'ٹوکؠلو ٹایِم (فَکَوفو)',
        'Pacific/Fiji' => 'فیٖجی ٹایِم (فِجی)',
        'Pacific/Funafuti' => 'ٹوٗوَلوٗ ٹایِم (فُنافوٗتی)',
        'Pacific/Galapagos' => 'گؠلؠپیگوز ٹایِم (گؠلَپگوس)',
        'Pacific/Gambier' => 'گؠمبِیَر ٹایِم (گیمبِیَر)',
        'Pacific/Guadalcanal' => 'سولومَن ججیٖرَن ہُند ٹایِم (گُوادَلچَنَل)',
        'Pacific/Guam' => 'کؠمورو سٹینڑاڑ ٹایِم (گوام)',
        'Pacific/Honolulu' => 'حَواے اؠلیوٗٹِیَن ٹایِم (ہونولو لو)',
        'Pacific/Johnston' => 'حَواے اؠلیوٗٹِیَن ٹایِم (جانسٹَن)',
        'Pacific/Kiritimati' => 'لایِٔن ججیٖرُک ٹایِم (کِرِتِماتی)',
        'Pacific/Kosrae' => 'کورسَے ٹایِم (کوسراے)',
        'Pacific/Kwajalein' => 'مارشَل ججیٖرُک ٹایِم (کُوجلین)',
        'Pacific/Majuro' => 'مارشَل ججیٖرُک ٹایِم (مَجوٗرو)',
        'Pacific/Marquesas' => 'مارقیوٗسَس ٹایِم (مارکیسَس)',
        'Pacific/Midway' => 'سؠموآ ٹایِم (مِڈویے)',
        'Pacific/Nauru' => 'نَعوٗروٗ ٹایِم (ناوروٗ)',
        'Pacific/Niue' => 'نِیوٗ ٹایِم (نِو)',
        'Pacific/Norfolk' => 'نورفعاک ٹایِم (نورفوک)',
        'Pacific/Noumea' => 'نِو کیلؠڑونِیا ٹایِم (نومیی)',
        'Pacific/Pago_Pago' => 'سؠموآ ٹایِم (پیگو پیگو)',
        'Pacific/Palau' => 'پَلاو ٹایِم',
        'Pacific/Pitcairn' => 'پِٹکیرٕن ٹایِم (پِٹکیرَن)',
        'Pacific/Ponape' => 'پونیپ ٹایِم (پوناپے)',
        'Pacific/Port_Moresby' => 'پاپُعا نیوٗ گؠنی ٹایِم (پوٹ مورسبی)',
        'Pacific/Rarotonga' => 'کُک اَیلینڑز ٹایِم (راروٹونگا)',
        'Pacific/Saipan' => 'کؠمورو سٹینڑاڑ ٹایِم (سَیپان)',
        'Pacific/Tahiti' => 'ٹاہِٹی ٹایِم (تَہِتی)',
        'Pacific/Tarawa' => 'گِلبٲٹ ججیٖرُک ٹایِم (ٹَراوا)',
        'Pacific/Tongatapu' => 'ٹعانگا ٹایِم (تونگاتَپوٗ)',
        'Pacific/Truk' => 'ٹٔرک ٹایِم (ٹرک)',
        'Pacific/Wake' => 'ویک ججیٖرُک ٹایِم',
        'Pacific/Wallis' => 'والِس تہٕ فیوٗٹیوٗنا ٹایِم (ویلِس)',
    ],
    'Meta' => [
    ],
];
