<?php
$attributemap = [

    // Generated Twitter Attributes
    'twitter_screen_n_realm' => 'eduPersonPrincipalName', // screen_name@twitter.com
    'twitter_targetedID'     => 'eduPersonTargetedID', // http://twitter.com!id_str

    // Attributes Returned by Twitter
    'twitter.screen_name'    => 'uid', // equivalent to twitter username without leading @
    'twitter.name'           => 'displayName',
    'twitter.url'            => 'labeledURI',
    'twitter.lang'           => 'preferredLanguage',
    'twitter.description'    => 'description',
];
