<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвичийн цаг (Абижан)',
        'Africa/Accra' => 'Гринвичийн цаг (Аккра)',
        'Africa/Addis_Ababa' => 'Зүүн Африкийн цаг (Аддис-Aбеба)',
        'Africa/Algiers' => 'Төв Европын цаг (Алжир)',
        'Africa/Asmera' => 'Зүүн Африкийн цаг (Асмара)',
        'Africa/Bamako' => 'Гринвичийн цаг (Бамако)',
        'Africa/Bangui' => 'Баруун Африкийн цаг (Бангуй)',
        'Africa/Banjul' => 'Гринвичийн цаг (Банжул)',
        'Africa/Bissau' => 'Гринвичийн цаг (Биссау)',
        'Africa/Blantyre' => 'Төв Африкийн цаг (Блантайр)',
        'Africa/Brazzaville' => 'Баруун Африкийн цаг (Браззавиль)',
        'Africa/Bujumbura' => 'Төв Африкийн цаг (Бужумбура)',
        'Africa/Cairo' => 'Зүүн Европын цаг (Каир)',
        'Africa/Casablanca' => 'Баруун Европын цаг (Касабланка)',
        'Africa/Ceuta' => 'Төв Европын цаг (Сеута)',
        'Africa/Conakry' => 'Гринвичийн цаг (Конакри)',
        'Africa/Dakar' => 'Гринвичийн цаг (Дакар)',
        'Africa/Dar_es_Salaam' => 'Зүүн Африкийн цаг (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Зүүн Африкийн цаг (Жибути)',
        'Africa/Douala' => 'Баруун Африкийн цаг (Дуала)',
        'Africa/El_Aaiun' => 'Баруун Европын цаг (Эль-Аюн)',
        'Africa/Freetown' => 'Гринвичийн цаг (Фритаун)',
        'Africa/Gaborone' => 'Төв Африкийн цаг (Габороне)',
        'Africa/Harare' => 'Төв Африкийн цаг (Хараре)',
        'Africa/Johannesburg' => 'Өмнөд Африкийн стандарт цаг (Йоханнесбург)',
        'Africa/Juba' => 'Төв Африкийн цаг (Жуба)',
        'Africa/Kampala' => 'Зүүн Африкийн цаг (Кампала)',
        'Africa/Khartoum' => 'Төв Африкийн цаг (Хартум)',
        'Africa/Kigali' => 'Төв Африкийн цаг (Кигали)',
        'Africa/Kinshasa' => 'Баруун Африкийн цаг (Киншаса)',
        'Africa/Lagos' => 'Баруун Африкийн цаг (Лагос)',
        'Africa/Libreville' => 'Баруун Африкийн цаг (Либревиль)',
        'Africa/Lome' => 'Гринвичийн цаг (Ломе)',
        'Africa/Luanda' => 'Баруун Африкийн цаг (Луанда)',
        'Africa/Lubumbashi' => 'Төв Африкийн цаг (Лубумбаши)',
        'Africa/Lusaka' => 'Төв Африкийн цаг (Лусака)',
        'Africa/Malabo' => 'Баруун Африкийн цаг (Малабо)',
        'Africa/Maputo' => 'Төв Африкийн цаг (Мапуто)',
        'Africa/Maseru' => 'Өмнөд Африкийн стандарт цаг (Масеру)',
        'Africa/Mbabane' => 'Өмнөд Африкийн стандарт цаг (Мбабане)',
        'Africa/Mogadishu' => 'Зүүн Африкийн цаг (Могадишу)',
        'Africa/Monrovia' => 'Гринвичийн цаг (Монровиа)',
        'Africa/Nairobi' => 'Зүүн Африкийн цаг (Найроби)',
        'Africa/Ndjamena' => 'Баруун Африкийн цаг (Нжамена)',
        'Africa/Niamey' => 'Баруун Африкийн цаг (Ниамей)',
        'Africa/Nouakchott' => 'Гринвичийн цаг (Нуакшот)',
        'Africa/Ouagadougou' => 'Гринвичийн цаг (Уагадугу)',
        'Africa/Porto-Novo' => 'Баруун Африкийн цаг (Порто-Ново)',
        'Africa/Sao_Tome' => 'Гринвичийн цаг (Сан-Томе)',
        'Africa/Tripoli' => 'Зүүн Европын цаг (Триполи)',
        'Africa/Tunis' => 'Төв Европын цаг (Тунис)',
        'Africa/Windhoek' => 'Төв Африкийн цаг (Виндхук)',
        'America/Adak' => 'Хавай-Алеутын цаг (Адак)',
        'America/Anchorage' => 'Аляскийн цаг (Анкораж)',
        'America/Anguilla' => 'Атлантын цаг (Ангилья)',
        'America/Antigua' => 'Атлантын цаг (Антигуа)',
        'America/Araguaina' => 'Бразилийн цаг (Арагуаяна)',
        'America/Argentina/La_Rioja' => 'Аргентины цаг (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентины цаг (Рио-Гальегос)',
        'America/Argentina/Salta' => 'Аргентины цаг (Салта)',
        'America/Argentina/San_Juan' => 'Аргентины цаг (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргентины цаг (Сан Луи)',
        'America/Argentina/Tucuman' => 'Аргентины цаг (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентины цаг (Ушуайя)',
        'America/Aruba' => 'Атлантын цаг (Аруба)',
        'America/Asuncion' => 'Парагвайн цаг (Асунсьон)',
        'America/Bahia' => 'Бразилийн цаг (Байя)',
        'America/Bahia_Banderas' => 'Төв цаг (Бахья Бандерас)',
        'America/Barbados' => 'Атлантын цаг (Барбадос)',
        'America/Belem' => 'Бразилийн цаг (Белем)',
        'America/Belize' => 'Төв цаг (Белизе)',
        'America/Blanc-Sablon' => 'Атлантын цаг (Блан-Саблон)',
        'America/Boa_Vista' => 'Амазоны цаг (Боа-Виста)',
        'America/Bogota' => 'Колумбын цаг (Богота)',
        'America/Boise' => 'Уулын цаг (Боисе)',
        'America/Buenos_Aires' => 'Аргентины цаг (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Уулын цаг (Кэмбрижийн булан)',
        'America/Campo_Grande' => 'Амазоны цаг (Кампо-Гранде)',
        'America/Cancun' => 'Зүүн эргийн цаг (Канкун)',
        'America/Caracas' => 'Венесуэлийн цаг (Каракас)',
        'America/Catamarca' => 'Аргентины цаг (Катамарка)',
        'America/Cayenne' => 'Францын Гвианагийн цаг (Кайенна)',
        'America/Cayman' => 'Зүүн эргийн цаг (Кайман)',
        'America/Chicago' => 'Төв цаг (Чикаго)',
        'America/Chihuahua' => 'Мексик-Номхон далайн цаг (Чихуахуа)',
        'America/Coral_Harbour' => 'Зүүн эргийн цаг (Атикокан)',
        'America/Cordoba' => 'Аргентины цаг (Кордова)',
        'America/Costa_Rica' => 'Төв цаг (Коста-Рика)',
        'America/Creston' => 'Уулын цаг (Крестон)',
        'America/Cuiaba' => 'Амазоны цаг (Куяба)',
        'America/Curacao' => 'Атлантын цаг (Кюрасао)',
        'America/Danmarkshavn' => 'Гринвичийн цаг (Данмаркшавн)',
        'America/Dawson' => 'Юкон цагийн бүс (Доусон)',
        'America/Dawson_Creek' => 'Уулын цаг (Доусон Крик)',
        'America/Denver' => 'Уулын цаг (Денвер)',
        'America/Detroit' => 'Зүүн эргийн цаг (Детройт)',
        'America/Dominica' => 'Атлантын цаг (Доминика)',
        'America/Edmonton' => 'Уулын цаг (Эдмонтон)',
        'America/Eirunepe' => 'Бразил-н цаг (Эйрунепе)',
        'America/El_Salvador' => 'Төв цаг (Эль Сальвадор)',
        'America/Fort_Nelson' => 'Уулын цаг (Форт Нэльсон)',
        'America/Fortaleza' => 'Бразилийн цаг (Форталеза)',
        'America/Glace_Bay' => 'Атлантын цаг (Глейс булан)',
        'America/Godthab' => 'Баруун Гренландын цаг (Нүүк)',
        'America/Goose_Bay' => 'Атлантын цаг (Гуус булан)',
        'America/Grand_Turk' => 'Зүүн эргийн цаг (Гранд Турк)',
        'America/Grenada' => 'Атлантын цаг (Гренада)',
        'America/Guadeloupe' => 'Атлантын цаг (Гваделуп)',
        'America/Guatemala' => 'Төв цаг (Гватемал)',
        'America/Guayaquil' => 'Эквадорын цаг (Гуаякиль)',
        'America/Guyana' => 'Гайанагийн цаг',
        'America/Halifax' => 'Атлантын цаг (Халифакс)',
        'America/Havana' => 'Кубын цаг (Хавана)',
        'America/Hermosillo' => 'Мексик-Номхон далайн цаг (Хермосилло)',
        'America/Indiana/Knox' => 'Төв цаг (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Зүүн эргийн цаг (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Зүүн эргийн цаг (Питерсбург, Индиана)',
        'America/Indiana/Tell_City' => 'Төв цаг (Тел Сити, Индиана)',
        'America/Indiana/Vevay' => 'Зүүн эргийн цаг (Вивей, Индиана)',
        'America/Indiana/Vincennes' => 'Зүүн эргийн цаг (Винсенес, Индиана)',
        'America/Indiana/Winamac' => 'Зүүн эргийн цаг (Винамак, Индиана)',
        'America/Indianapolis' => 'Зүүн эргийн цаг (Индианаполис)',
        'America/Inuvik' => 'Уулын цаг (Инувик)',
        'America/Iqaluit' => 'Зүүн эргийн цаг (Икалуит)',
        'America/Jamaica' => 'Зүүн эргийн цаг (Ямайка)',
        'America/Jujuy' => 'Аргентины цаг (Жужуй)',
        'America/Juneau' => 'Аляскийн цаг (Жуно)',
        'America/Kentucky/Monticello' => 'Зүүн эргийн цаг (Монтичелло, Кентаки)',
        'America/Kralendijk' => 'Атлантын цаг (Кралендик)',
        'America/La_Paz' => 'Боливийн цаг (Ла Паз)',
        'America/Lima' => 'Перугийн цаг (Лима)',
        'America/Los_Angeles' => 'Номхон далайн цаг (Лос-Анжелес)',
        'America/Louisville' => 'Зүүн эргийн цаг (Луисвилл)',
        'America/Lower_Princes' => 'Атлантын цаг (Ловер Принсес Квартер)',
        'America/Maceio' => 'Бразилийн цаг (Масейо)',
        'America/Managua' => 'Төв цаг (Манагуа)',
        'America/Manaus' => 'Амазоны цаг (Манаус)',
        'America/Marigot' => 'Атлантын цаг (Маригот)',
        'America/Martinique' => 'Атлантын цаг (Мартиник)',
        'America/Matamoros' => 'Төв цаг (Матаморос)',
        'America/Mazatlan' => 'Мексик-Номхон далайн цаг (Мазатлан)',
        'America/Mendoza' => 'Аргентины цаг (Мендоза)',
        'America/Menominee' => 'Төв цаг (Меномини)',
        'America/Merida' => 'Төв цаг (Мерида)',
        'America/Metlakatla' => 'Аляскийн цаг (Метлакатла)',
        'America/Mexico_City' => 'Төв цаг (Мехико)',
        'America/Miquelon' => 'Сент-Пьер ба Микелоны цаг',
        'America/Moncton' => 'Атлантын цаг (Монктон)',
        'America/Monterrey' => 'Төв цаг (Монтерей)',
        'America/Montevideo' => 'Уругвайн цаг (Монтевидео)',
        'America/Montreal' => 'Канад-н цаг (Montreal)',
        'America/Montserrat' => 'Атлантын цаг (Монтсеррат)',
        'America/Nassau' => 'Зүүн эргийн цаг (Нассау)',
        'America/New_York' => 'Зүүн эргийн цаг (Нью-Йорк)',
        'America/Nipigon' => 'Зүүн эргийн цаг (Нипигон)',
        'America/Nome' => 'Аляскийн цаг (Ном)',
        'America/Noronha' => 'Фернандо де Норонагийн цаг',
        'America/North_Dakota/Beulah' => 'Төв цаг (Била, Хойд Дакота)',
        'America/North_Dakota/Center' => 'Төв цаг (Төв, Хойд Дакота)',
        'America/North_Dakota/New_Salem' => 'Төв цаг (Нью-Салем, Хойд Дакота)',
        'America/Ojinaga' => 'Уулын цаг (Ожинага)',
        'America/Panama' => 'Зүүн эргийн цаг (Панама)',
        'America/Pangnirtung' => 'Зүүн эргийн цаг (Пангниртунг)',
        'America/Paramaribo' => 'Суринамын цаг (Парамарибо)',
        'America/Phoenix' => 'Уулын цаг (Феникс)',
        'America/Port-au-Prince' => 'Зүүн эргийн цаг (Порт-о-Принс)',
        'America/Port_of_Spain' => 'Атлантын цаг (Испаний боомт)',
        'America/Porto_Velho' => 'Амазоны цаг (Порто-Велью)',
        'America/Puerto_Rico' => 'Атлантын цаг (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чилийн цаг (Пунта Арена)',
        'America/Rainy_River' => 'Төв цаг (Рейни Ривер)',
        'America/Rankin_Inlet' => 'Төв цаг (Рэнкин Инлет)',
        'America/Recife' => 'Бразилийн цаг (Ресифи)',
        'America/Regina' => 'Төв цаг (Регина)',
        'America/Resolute' => 'Төв цаг (Резолют)',
        'America/Rio_Branco' => 'Бразил-н цаг (Рио-Бранко)',
        'America/Santa_Isabel' => 'Баруун хойд Мексикийн цаг (Санта Изабель)',
        'America/Santarem' => 'Бразилийн цаг (Сантарем)',
        'America/Santiago' => 'Чилийн цаг (Сантьяго)',
        'America/Santo_Domingo' => 'Атлантын цаг (Санто Доминго)',
        'America/Sao_Paulo' => 'Бразилийн цаг (Сан-Паулу)',
        'America/Scoresbysund' => 'Зүүн Гренландын цаг (Скорсбисунн)',
        'America/Sitka' => 'Аляскийн цаг (Ситка)',
        'America/St_Barthelemy' => 'Атлантын цаг (Сент-Бартельми)',
        'America/St_Johns' => 'Нью-Фаундлендын цаг (Сент-Жонс)',
        'America/St_Kitts' => 'Атлантын цаг (Сент-Киттс)',
        'America/St_Lucia' => 'Атлантын цаг (Сент Люсиа)',
        'America/St_Thomas' => 'Атлантын цаг (Сент Томас)',
        'America/St_Vincent' => 'Атлантын цаг (Сент Винсент)',
        'America/Swift_Current' => 'Төв цаг (Свифт Каррент)',
        'America/Tegucigalpa' => 'Төв цаг (Тегусигальпа)',
        'America/Thule' => 'Атлантын цаг (Туле)',
        'America/Thunder_Bay' => 'Зүүн эргийн цаг (Сандер Бэй)',
        'America/Tijuana' => 'Номхон далайн цаг (Тихуана)',
        'America/Toronto' => 'Зүүн эргийн цаг (Торонто)',
        'America/Tortola' => 'Атлантын цаг (Тортола)',
        'America/Vancouver' => 'Номхон далайн цаг (Ванкувер)',
        'America/Whitehorse' => 'Юкон цагийн бүс (Уайтхорз)',
        'America/Winnipeg' => 'Төв цаг (Виннипег)',
        'America/Yakutat' => 'Аляскийн цаг (Якутат)',
        'America/Yellowknife' => 'Уулын цаг (Йелоунайф)',
        'Antarctica/Casey' => 'Антарктид-н цаг (Кэсей)',
        'Antarctica/Davis' => 'Дэвисийн цаг',
        'Antarctica/DumontDUrville' => 'Дюмон д’Юрвилийн цаг (Дюмон д’Юрвиль)',
        'Antarctica/Macquarie' => 'Зүүн Австралийн цаг (Маккуори)',
        'Antarctica/Mawson' => 'Моусоны цаг',
        'Antarctica/McMurdo' => 'Шинэ Зеландын цаг (Мак-Мөрдо)',
        'Antarctica/Palmer' => 'Чилийн цаг (Палмер)',
        'Antarctica/Rothera' => 'Ротерагийн цаг',
        'Antarctica/Syowa' => 'Сёвагийн цаг',
        'Antarctica/Troll' => 'Гринвичийн цаг (Тролл)',
        'Antarctica/Vostok' => 'Востокийн цаг',
        'Arctic/Longyearbyen' => 'Төв Европын цаг (Лонгирбайен)',
        'Asia/Aden' => 'Арабын цаг (Аден)',
        'Asia/Almaty' => 'Зүүн Казахстаны цаг (Алматы)',
        'Asia/Amman' => 'Зүүн Европын цаг (Амман)',
        'Asia/Anadyr' => 'Орос-н цаг (Анадыр)',
        'Asia/Aqtau' => 'Баруун Казахстаны цаг (Актау)',
        'Asia/Aqtobe' => 'Баруун Казахстаны цаг (Актөбе)',
        'Asia/Ashgabat' => 'Туркменистаны цаг (Ашхабад)',
        'Asia/Atyrau' => 'Баруун Казахстаны цаг (Атырау)',
        'Asia/Baghdad' => 'Арабын цаг (Багдад)',
        'Asia/Bahrain' => 'Арабын цаг (Бахрейн)',
        'Asia/Baku' => 'Азербайжаны цаг (Баку)',
        'Asia/Bangkok' => 'Энэтхэг-Хятадын хойгийн цаг (Бангкок)',
        'Asia/Barnaul' => 'Орос-н цаг (Барнаул)',
        'Asia/Beirut' => 'Зүүн Европын цаг (Бейрут)',
        'Asia/Bishkek' => 'Киргизийн цаг (Бишкек)',
        'Asia/Brunei' => 'Бруней Даруссаламын цаг',
        'Asia/Calcutta' => 'Энэтхэгийн цаг (Калькутта)',
        'Asia/Chita' => 'Якутын цаг (Чита)',
        'Asia/Choibalsan' => 'Улаанбаатарын цаг (Чойбалсан)',
        'Asia/Colombo' => 'Энэтхэгийн цаг (Коломбо)',
        'Asia/Damascus' => 'Зүүн Европын цаг (Дамаск)',
        'Asia/Dhaka' => 'Бангладешийн цаг (Дака)',
        'Asia/Dili' => 'Зүүн Тиморын цаг (Дили)',
        'Asia/Dubai' => 'Персийн булангийн цаг (Дубай)',
        'Asia/Dushanbe' => 'Тажикистаны цаг (Душанбе)',
        'Asia/Famagusta' => 'Зүүн Европын цаг (Фамагуста)',
        'Asia/Gaza' => 'Зүүн Европын цаг (Газа)',
        'Asia/Hebron' => 'Зүүн Европын цаг (Хеброн)',
        'Asia/Hong_Kong' => 'Хонг Конгийн цаг',
        'Asia/Hovd' => 'Ховдын цаг',
        'Asia/Irkutsk' => 'Эрхүүгийн цаг',
        'Asia/Jakarta' => 'Баруун Индонезийн цаг (Жакарта)',
        'Asia/Jayapura' => 'Зүүн Индонезийн цаг (Жайпур)',
        'Asia/Jerusalem' => 'Израилийн цаг (Ерусалем)',
        'Asia/Kabul' => 'Афганистаны цаг (Кабул)',
        'Asia/Kamchatka' => 'Орос-н цаг (Камчатка)',
        'Asia/Karachi' => 'Пакистаны цаг (Карачи)',
        'Asia/Katmandu' => 'Балбын цаг (Катманду)',
        'Asia/Khandyga' => 'Якутын цаг (Кандыга)',
        'Asia/Krasnoyarsk' => 'Красноярскийн цаг',
        'Asia/Kuala_Lumpur' => 'Малайзын цаг (Куала Лумпур)',
        'Asia/Kuching' => 'Малайзын цаг (Кучин)',
        'Asia/Kuwait' => 'Арабын цаг (Кувейт)',
        'Asia/Macau' => 'Хятадын цаг (Макао)',
        'Asia/Magadan' => 'Магаданы цаг',
        'Asia/Makassar' => 'Төв Индонезийн цаг (Макассар)',
        'Asia/Manila' => 'Филиппиний цаг (Манила)',
        'Asia/Muscat' => 'Персийн булангийн цаг (Мускат)',
        'Asia/Nicosia' => 'Зүүн Европын цаг (Никосия)',
        'Asia/Novokuznetsk' => 'Красноярскийн цаг (Новокузнецк)',
        'Asia/Novosibirsk' => 'Новосибирскийн цаг',
        'Asia/Omsk' => 'Омскийн цаг',
        'Asia/Oral' => 'Баруун Казахстаны цаг (Орал)',
        'Asia/Phnom_Penh' => 'Энэтхэг-Хятадын хойгийн цаг (Пномпень)',
        'Asia/Pontianak' => 'Баруун Индонезийн цаг (Понтианак)',
        'Asia/Pyongyang' => 'Солонгосын цаг (Пёньян)',
        'Asia/Qatar' => 'Арабын цаг (Катар)',
        'Asia/Qostanay' => 'Зүүн Казахстаны цаг (Костанай)',
        'Asia/Qyzylorda' => 'Баруун Казахстаны цаг (Кызылорд)',
        'Asia/Rangoon' => 'Мьянмарын цаг (Рангун)',
        'Asia/Riyadh' => 'Арабын цаг (Рияд)',
        'Asia/Saigon' => 'Энэтхэг-Хятадын хойгийн цаг (Хо Ши Мин хот)',
        'Asia/Sakhalin' => 'Сахалины цаг',
        'Asia/Samarkand' => 'Узбекистаны цаг (Самарканд)',
        'Asia/Seoul' => 'Солонгосын цаг (Сөүл)',
        'Asia/Shanghai' => 'Хятадын цаг (Шанхай)',
        'Asia/Singapore' => 'Сингапурын цаг',
        'Asia/Srednekolymsk' => 'Магаданы цаг (Среднеколымск)',
        'Asia/Taipei' => 'Тайпейн цаг',
        'Asia/Tashkent' => 'Узбекистаны цаг (Ташкент)',
        'Asia/Tbilisi' => 'Гүржийн цаг (Тбилиси)',
        'Asia/Tehran' => 'Ираны цаг (Тегеран)',
        'Asia/Thimphu' => 'Бутаны цаг (Тхимпху)',
        'Asia/Tokyo' => 'Японы цаг (Токио)',
        'Asia/Tomsk' => 'Орос-н цаг (Томск)',
        'Asia/Ulaanbaatar' => 'Улаанбаатарын цаг',
        'Asia/Urumqi' => 'Хятад-н цаг (Үрүмчи)',
        'Asia/Ust-Nera' => 'Владивостокийн цаг (Уст-Нера)',
        'Asia/Vientiane' => 'Энэтхэг-Хятадын хойгийн цаг (Вьентьян)',
        'Asia/Vladivostok' => 'Владивостокийн цаг',
        'Asia/Yakutsk' => 'Якутын цаг (Якутск)',
        'Asia/Yekaterinburg' => 'Екатеринбургийн цаг',
        'Asia/Yerevan' => 'Арменийн цаг (Ереван)',
        'Atlantic/Azores' => 'Азорын цаг',
        'Atlantic/Bermuda' => 'Атлантын цаг (Бермуда)',
        'Atlantic/Canary' => 'Баруун Европын цаг (Канари)',
        'Atlantic/Cape_Verde' => 'Кабо-Вердийн цаг (Кабо-Верде)',
        'Atlantic/Faeroe' => 'Баруун Европын цаг (Фарер)',
        'Atlantic/Madeira' => 'Баруун Европын цаг (Мадейра)',
        'Atlantic/Reykjavik' => 'Гринвичийн цаг (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Өмнөд Жоржиагийн цаг',
        'Atlantic/St_Helena' => 'Гринвичийн цаг (Сент Хелена)',
        'Atlantic/Stanley' => 'Фолклендийн арлуудын цаг (Стэнли)',
        'Australia/Adelaide' => 'Төв Австралийн цаг (Аделаида)',
        'Australia/Brisbane' => 'Зүүн Австралийн цаг (Брисбен)',
        'Australia/Broken_Hill' => 'Төв Австралийн цаг (Брокен Хилл)',
        'Australia/Currie' => 'Зүүн Австралийн цаг (Кюрри)',
        'Australia/Darwin' => 'Төв Австралийн цаг (Дарвин)',
        'Australia/Eucla' => 'Австралийн төв баруун эргийн цаг (Еукла)',
        'Australia/Hobart' => 'Зүүн Австралийн цаг (Хобарт)',
        'Australia/Lindeman' => 'Зүүн Австралийн цаг (Линдемэн)',
        'Australia/Lord_Howe' => 'Лорд Хоугийн цаг',
        'Australia/Melbourne' => 'Зүүн Австралийн цаг (Мельбурн)',
        'Australia/Perth' => 'Баруун Австралийн цаг (Перс)',
        'Australia/Sydney' => 'Зүүн Австралийн цаг (Сидней)',
        'CST6CDT' => 'Төв цаг',
        'EST5EDT' => 'Зүүн эргийн цаг',
        'Etc/GMT' => 'Гринвичийн цаг',
        'Etc/UTC' => 'Олон улсын зохицуулалттай цаг',
        'Europe/Amsterdam' => 'Төв Европын цаг (Амстердам)',
        'Europe/Andorra' => 'Төв Европын цаг (Андорра)',
        'Europe/Astrakhan' => 'Москвагийн цаг (Астрахань)',
        'Europe/Athens' => 'Зүүн Европын цаг (Афин)',
        'Europe/Belgrade' => 'Төв Европын цаг (Белград)',
        'Europe/Berlin' => 'Төв Европын цаг (Берлин)',
        'Europe/Bratislava' => 'Төв Европын цаг (Братислав)',
        'Europe/Brussels' => 'Төв Европын цаг (Брюссель)',
        'Europe/Bucharest' => 'Зүүн Европын цаг (Бухарест)',
        'Europe/Budapest' => 'Төв Европын цаг (Будапешт)',
        'Europe/Busingen' => 'Төв Европын цаг (Бусинген)',
        'Europe/Chisinau' => 'Зүүн Европын цаг (Кишинёв)',
        'Europe/Copenhagen' => 'Төв Европын цаг (Копенгаген)',
        'Europe/Dublin' => 'Гринвичийн цаг (Дублин)',
        'Europe/Gibraltar' => 'Төв Европын цаг (Гибралтар)',
        'Europe/Guernsey' => 'Гринвичийн цаг (Гернси)',
        'Europe/Helsinki' => 'Зүүн Европын цаг (Хельсинк)',
        'Europe/Isle_of_Man' => 'Гринвичийн цаг (Мэн Арал)',
        'Europe/Istanbul' => 'Турк-н цаг (Истанбул)',
        'Europe/Jersey' => 'Гринвичийн цаг (Жерси)',
        'Europe/Kaliningrad' => 'Зүүн Европын цаг (Калининград)',
        'Europe/Kiev' => 'Зүүн Европын цаг (Киев)',
        'Europe/Kirov' => 'Орос-н цаг (Киров)',
        'Europe/Lisbon' => 'Баруун Европын цаг (Лиссабон)',
        'Europe/Ljubljana' => 'Төв Европын цаг (Любляна)',
        'Europe/London' => 'Гринвичийн цаг (Лондон)',
        'Europe/Luxembourg' => 'Төв Европын цаг (Люксембург)',
        'Europe/Madrid' => 'Төв Европын цаг (Мадрид)',
        'Europe/Malta' => 'Төв Европын цаг (Мальта)',
        'Europe/Mariehamn' => 'Зүүн Европын цаг (Марихамн)',
        'Europe/Minsk' => 'Москвагийн цаг (Минск)',
        'Europe/Monaco' => 'Төв Европын цаг (Монако)',
        'Europe/Moscow' => 'Москвагийн цаг',
        'Europe/Oslo' => 'Төв Европын цаг (Осло)',
        'Europe/Paris' => 'Төв Европын цаг (Парис)',
        'Europe/Podgorica' => 'Төв Европын цаг (Подгорица)',
        'Europe/Prague' => 'Төв Европын цаг (Прага)',
        'Europe/Riga' => 'Зүүн Европын цаг (Рига)',
        'Europe/Rome' => 'Төв Европын цаг (Ром)',
        'Europe/Samara' => 'Орос-н цаг (Самара)',
        'Europe/San_Marino' => 'Төв Европын цаг (Сан-Марино)',
        'Europe/Sarajevo' => 'Төв Европын цаг (Сараево)',
        'Europe/Saratov' => 'Москвагийн цаг (Саратов)',
        'Europe/Simferopol' => 'Москвагийн цаг (Симферополь)',
        'Europe/Skopje' => 'Төв Европын цаг (Скопье)',
        'Europe/Sofia' => 'Зүүн Европын цаг (София)',
        'Europe/Stockholm' => 'Төв Европын цаг (Стокольм)',
        'Europe/Tallinn' => 'Зүүн Европын цаг (Таллин)',
        'Europe/Tirane' => 'Төв Европын цаг (Тирана)',
        'Europe/Ulyanovsk' => 'Москвагийн цаг (Ульяновск)',
        'Europe/Uzhgorod' => 'Зүүн Европын цаг (Ужгород)',
        'Europe/Vaduz' => 'Төв Европын цаг (Вадуз)',
        'Europe/Vatican' => 'Төв Европын цаг (Ватикан)',
        'Europe/Vienna' => 'Төв Европын цаг (Вена)',
        'Europe/Vilnius' => 'Зүүн Европын цаг (Вильнюс)',
        'Europe/Volgograd' => 'Волгоградын цаг',
        'Europe/Warsaw' => 'Төв Европын цаг (Варшав)',
        'Europe/Zagreb' => 'Төв Европын цаг (Загреб)',
        'Europe/Zaporozhye' => 'Зүүн Европын цаг (Запорожье)',
        'Europe/Zurich' => 'Төв Европын цаг (Цюрих)',
        'Indian/Antananarivo' => 'Зүүн Африкийн цаг (Антананариво)',
        'Indian/Chagos' => 'Энэтхэгийн далайн цаг (Чагос)',
        'Indian/Christmas' => 'Крисмас арлын цаг',
        'Indian/Cocos' => 'Кокос арлын цаг',
        'Indian/Comoro' => 'Зүүн Африкийн цаг (Коморо)',
        'Indian/Kerguelen' => 'Францын Өмнөд ба Антарктидийн цаг (Кергелен)',
        'Indian/Mahe' => 'Сейшелийн арлуудын цаг (Махе)',
        'Indian/Maldives' => 'Мальдивийн цаг',
        'Indian/Mauritius' => 'Маврикийн цаг',
        'Indian/Mayotte' => 'Зүүн Африкийн цаг (Майотта)',
        'Indian/Reunion' => 'Реюнионы цаг',
        'MST7MDT' => 'Уулын цаг',
        'PST8PDT' => 'Номхон далайн цаг',
        'Pacific/Apia' => 'Апиагийн цаг',
        'Pacific/Auckland' => 'Шинэ Зеландын цаг (Оукленд)',
        'Pacific/Bougainville' => 'Папуа Шинэ Гвинейн цаг (Бугенвиль)',
        'Pacific/Chatham' => 'Чатемын цаг',
        'Pacific/Easter' => 'Зүүн Исландын цаг (Истер)',
        'Pacific/Efate' => 'Вануатугийн цаг (Эфате)',
        'Pacific/Enderbury' => 'Феникс арлын цаг (Эндербери)',
        'Pacific/Fakaofo' => 'Токелаугийн цаг (Факаофо)',
        'Pacific/Fiji' => 'Фижигийн цаг',
        'Pacific/Funafuti' => 'Тувалугийн цаг (Фунафути)',
        'Pacific/Galapagos' => 'Галапагосын цаг',
        'Pacific/Gambier' => 'Гамбьегийн цаг (Гамбьер)',
        'Pacific/Guadalcanal' => 'Соломоны арлуудын цаг (Гуадалканал)',
        'Pacific/Guam' => 'Чаморрогийн цаг (Гуам)',
        'Pacific/Honolulu' => 'Хавай-Алеутын цаг (Хонолулу)',
        'Pacific/Johnston' => 'Хавай-Алеутын цаг (Жонстон)',
        'Pacific/Kiritimati' => 'Лайн арлуудын цаг (Киритимати)',
        'Pacific/Kosrae' => 'Косрэгийн цаг',
        'Pacific/Kwajalein' => 'Маршаллын арлуудын цаг (Кважалейн)',
        'Pacific/Majuro' => 'Маршаллын арлуудын цаг (Мажуро)',
        'Pacific/Marquesas' => 'Маркезын арлуудын цаг',
        'Pacific/Midway' => 'Самоагийн цаг (Мидуэй)',
        'Pacific/Nauru' => 'Науругийн цаг',
        'Pacific/Niue' => 'Ниуэгийн цаг',
        'Pacific/Norfolk' => 'Норфолк арлын цаг',
        'Pacific/Noumea' => 'Шинэ Каледонийн цаг (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоагийн цаг (Паго Паго)',
        'Pacific/Palau' => 'Палаугийн цаг',
        'Pacific/Pitcairn' => 'Питкернийн цаг (Питкэрн)',
        'Pacific/Ponape' => 'Понапегийн цаг (Понпей)',
        'Pacific/Port_Moresby' => 'Папуа Шинэ Гвинейн цаг (Порт-Морсби)',
        'Pacific/Rarotonga' => 'Күүкийн арлуудын цаг (Раротонга)',
        'Pacific/Saipan' => 'Чаморрогийн цаг (Сайпан)',
        'Pacific/Tahiti' => 'Таитигийн цаг',
        'Pacific/Tarawa' => 'Гильбертийн арлуудын цаг (Тарава)',
        'Pacific/Tongatapu' => 'Тонгагийн цаг (Тонгатапу)',
        'Pacific/Truk' => 'Чүүкийн цаг',
        'Pacific/Wake' => 'Уэкийн арлуудын цаг',
        'Pacific/Wallis' => 'Уоллис ба Футунагийн цаг',
    ],
    'Meta' => [
    ],
];
