<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Peseta de Andorra',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Dirham dos Emirados Árabes Unidos',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afegane (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afegane afegão',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Lek Albanês (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lek albanês',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dram armênio',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Florim das Antilhas Holandesas',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza angolano',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Cuanza angolano (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Novo cuanza angolano (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Cuanza angolano reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Austral argentino',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Peso lei argentino (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Peso argentino (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Peso argentino (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Peso argentino',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Xelim austríaco',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Dólar australiano',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Florim arubano',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Manat azerbaijano (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manat azeri',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Dinar da Bósnia-Herzegovina (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Marco conversível da Bósnia e Herzegovina',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Novo dinar da Bósnia-Herzegovina (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dólar barbadense',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka bengali',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Franco belga (conversível)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Franco belga',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Franco belga (financeiro)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Lev forte búlgaro',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Lev socialista búlgaro',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Lev búlgaro',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Lev búlgaro (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinar bareinita',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Franco burundiano',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dólar bermudense',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dólar bruneano',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviano da Bolívia',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Peso boliviano',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Mvdol boliviano',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Cruzeiro novo brasileiro (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Cruzado brasileiro (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Cruzeiro brasileiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Real brasileiro',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Cruzado novo brasileiro (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Cruzeiro brasileiro (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Cruzeiro brasileiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dólar bahamense',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrum butanês',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Kyat birmanês',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula botsuanesa',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Rublo novo bielo-russo (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rublo bielorrusso',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Rublo bielorrusso (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dólar belizenho',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dólar canadense',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Franco congolês',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'Euro WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Franco suíço',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'Franco WIR',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Escudo chileno',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Unidades de Fomento chilenas',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Peso chileno',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuan chinês (offshore)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Dólar do Banco Popular da China',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan chinês',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Peso colombiano',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Unidade de Valor Real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Colón costarriquenho',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Dinar sérvio (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Coroa Forte checoslovaca',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Peso cubano conversível',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Peso cubano',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo cabo-verdiano',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Libra cipriota',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Coroa tcheca',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Ostmark da Alemanha Oriental',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Marco alemão',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Franco djiboutiano',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Coroa dinamarquesa',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Peso dominicano',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinar argelino',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Sucre equatoriano',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Unidade de Valor Constante (UVC) do Equador',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Coroa estoniana',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Libra egípcia',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa da Eritreia',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Peseta espanhola (conta A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Peseta espanhola (conta conversível)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Peseta espanhola',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birr etíope',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Marca finlandesa',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dólar fijiano',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Libra malvinense',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franco francês',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Libra esterlina',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Cupom Lari georgiano',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lari georgiano',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Cedi de Gana (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Cedi ganês',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Libra de Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi gambiano',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Franco guineano',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Syli da Guiné',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ekwele da Guiné Equatorial',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Dracma grego',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Quetzal guatemalteco',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Escudo da Guiné Portuguesa',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Peso da Guiné-Bissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dólar guianense',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dólar de Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira hondurenha',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Dinar croata',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna croata',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gourde haitiano',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Florim húngaro',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupia indonésia',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Libra irlandesa',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Libra israelita',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'Sheqel antigo israelita',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Novo shekel israelense',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupia indiana',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinar iraquiano',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Rial iraniano',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'Coroa antiga islandesa',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Coroa islandesa',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Lira italiana',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dólar jamaicano',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinar jordaniano',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Iene japonês',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Xelim queniano',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Som quirguiz',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riel cambojano',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Franco comoriano',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Won norte-coreano',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Hwan da Coreia do Sul (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Won da Coreia do Sul (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Won sul-coreano',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinar kuwaitiano',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dólar das Ilhas Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge cazaque',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kip laosiano',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libra libanesa',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rupia cingalesa',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dólar liberiano',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti lesotiano',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litas lituano',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Talonas lituano',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Franco conversível de Luxemburgo',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Franco luxemburguês',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Franco financeiro de Luxemburgo',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lats letão',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Rublo letão',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinar líbio',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham marroquino',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Franco marroquino',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Franco monegasco',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Cupon moldávio',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leu moldávio',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariary malgaxe',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Franco de Madagascar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Dinar macedônio',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Dinar macedônio (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Franco de Mali',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Quiate mianmarense',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrik mongol',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataca macaense',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya mauritana (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya mauritana',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Lira maltesa',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Libra maltesa',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupia mauriciana',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rupia maldivana',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha malauiana',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Peso mexicano',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Peso Prata mexicano (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Unidade Mexicana de Investimento (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringgit malaio',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Escudo de Moçambique',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metical de Moçambique (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metical moçambicano',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dólar namibiano',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira nigeriana',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Córdoba nicaraguense (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Córdoba nicaraguense',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Florim holandês',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Coroa norueguesa',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupia nepalesa',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dólar neozelandês',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Rial omanense',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa panamenho',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Inti peruano',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Novo sol peruano',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Sol peruano (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina papuásia',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Peso filipino',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupia paquistanesa',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Zloty polonês',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Zloti polonês (1950–1995)',
        ],
        'PTE' => [
            0 => 'Esc.',
            1 => 'Escudo português',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guarani paraguaio',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Rial catariano',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Dólar rodesiano',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Leu romeno (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Leu romeno',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinar sérvio',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rublo russo',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rublo russo (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Franco ruandês',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal saudita',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dólar das Ilhas Salomão',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupia seichelense',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Dinar sudanês (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Libra sudanesa',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Libra sudanesa (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Coroa sueca',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dólar singapuriano',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Libra de Santa Helena',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Tolar Bons esloveno',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Coroa eslovaca',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone de Serra Leoa',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Xelim somali',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dólar surinamês',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Florim do Suriname',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Libra sul-sudanesa',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra de São Tomé e Príncipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra de São Tomé e Príncipe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Rublo soviético',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Colom salvadorenho',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Libra síria',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni suazi',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Baht tailandês',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Rublo do Tadjiquistão',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni tadjique',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Manat do Turcomenistão (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manat turcomeno',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinar tunisiano',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Paʻanga tonganesa',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Escudo timorense',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Lira turca (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lira turca',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dólar de Trinidad e Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Novo dólar taiwanês',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Xelim tanzaniano',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Hryvnia ucraniano',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Karbovanetz ucraniano',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Xelim ugandense (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Xelim ugandense',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dólar americano',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Dólar norte-americano (Dia seguinte)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Dólar norte-americano (Mesmo dia)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Peso uruguaio en unidades indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Peso uruguaio (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso uruguaio',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Som uzbeque',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Bolívar venezuelano (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolívar venezuelano (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolívar venezuelano',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dong vietnamita',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Dong vietnamita (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatu de Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala samoano',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Franco CFA de BEAC',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dólar do Caribe Oriental',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Unidade de Moeda Europeia',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franco-ouro francês',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Franco UIC francês',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Franco CFA de BCEAO',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Franco CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'Fundos RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Dinar iemenita',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Rial iemenita',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Dinar forte iugoslavo (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Dinar noviy iugoslavo (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Dinar conversível iugoslavo (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Dinar reformado iugoslavo (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Rand sul-africano (financeiro)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rand sul-africano',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Cuacha zambiano (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha zambiano',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zaire Novo zairense (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zaire zairense (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dólar do Zimbábue (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Dólar do Zimbábue (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Dólar do Zimbábue (2008)',
        ],
    ],
];
