<?php

return [
    'Names' => [
        'Adlm' => 'адламанско писмо',
        'Aghb' => 'бијело албанско писмо',
        'Ahom' => 'ахом писмо',
        'Arab' => 'арапско писмо',
        'Aran' => 'насталик писмо',
        'Armi' => 'империјско арамејско писмо',
        'Armn' => 'јерменско писмо',
        'Avst' => 'авестанско писмо',
        'Bali' => 'балијско писмо',
        'Bamu' => 'бамум писмо',
        'Bass' => 'баса вах писмо',
        'Batk' => 'батак писмо',
        'Beng' => 'бенгалско писмо',
        'Bhks' => 'баиксуки писмо',
        'Blis' => 'блисимболично писмо',
        'Bopo' => 'бопомофо писмо',
        'Brah' => 'браманско писмо',
        'Brai' => 'брајево писмо',
        'Bugi' => 'бугинско писмо',
        'Buhd' => 'бухидско писмо',
        'Cakm' => 'чакманско писмо',
        'Cans' => 'уједињени канадски абориџински силабици',
        'Cari' => 'каријско писмо',
        'Cham' => 'чамско писмо',
        'Cher' => 'Чероки',
        'Chrs' => 'чорамсианско писмо',
        'Cirt' => 'цирт писмо',
        'Copt' => 'коптичко писмо',
        'Cpmn' => 'кипро-миноанско писмо',
        'Cprt' => 'кипарско писмо',
        'Cyrl' => 'ћирилица',
        'Cyrs' => 'старословенска црквена ћирилица',
        'Deva' => 'деванагари',
        'Diak' => 'дивес акуру писмо',
        'Dogr' => 'догра писмо',
        'Dsrt' => 'Дезерет',
        'Dupl' => 'дуплојанska stenografija',
        'Egyd' => 'египатско народно писмо',
        'Egyh' => 'египатско хијератско писмо',
        'Egyp' => 'египатски хијероглифи',
        'Elba' => 'елбасан писмо',
        'Elym' => 'елимаик писмо',
        'Ethi' => 'етиопско писмо',
        'Geok' => 'грузијско кхутсури писмо',
        'Geor' => 'грузијско писмо',
        'Glag' => 'глагољица',
        'Gong' => 'гуњала гонди писмо',
        'Gonm' => 'масарам гонди писмо',
        'Goth' => 'готика',
        'Gran' => 'гранта писмо',
        'Grek' => 'грчко писмо',
        'Gujr' => 'гуџарати',
        'Guru' => 'гурмуки писмо',
        'Hanb' => 'хан с бопомофо писмом',
        'Hang' => 'хангул',
        'Hani' => 'хан',
        'Hano' => 'хануно',
        'Hans' => 'поједностављени',
        'Hant' => 'традиционални',
        'Hatr' => 'хатран писмо',
        'Hebr' => 'хебрејско писмо',
        'Hira' => 'хирагана',
        'Hluw' => 'анатолијски хијероглифи',
        'Hmng' => 'пахав хмонг писмо',
        'Hmnp' => 'нјакенг пауче хмонг писмо',
        'Hrkt' => 'јапанско слоговно писмо',
        'Hung' => 'старомађарско писмо',
        'Inds' => 'индушко писмо',
        'Ital' => 'стари италик',
        'Jamo' => 'џамо',
        'Java' => 'јаванско писмо',
        'Jpan' => 'јапанско писмо',
        'Kali' => 'кајах-ли писмо',
        'Kana' => 'катакана',
        'Kawi' => 'кави писмо',
        'Khar' => 'карошти писмо',
        'Khmr' => 'кмерско писмо',
        'Khoj' => 'којки писмо',
        'Kits' => 'китан мала слова',
        'Knda' => 'канада писмо',
        'Kore' => 'корејско писмо',
        'Kthi' => 'каити',
        'Lana' => 'ланна писмо',
        'Laoo' => 'лаоско писмо',
        'Latf' => 'латиница (фрактур варијанта)',
        'Latg' => 'галска латиница',
        'Latn' => 'латиница',
        'Lepc' => 'лепча писмо',
        'Limb' => 'лимбу писмо',
        'Lina' => 'линеарно А писмо',
        'Linb' => 'линеарно Б писмо',
        'Lisu' => 'фрасер писмо',
        'Lyci' => 'лисијско писмо',
        'Lydi' => 'лидијско писмо',
        'Mahj' => 'махајани писмо',
        'Maka' => 'макасар писмо',
        'Mand' => 'мандеанско писмо',
        'Mani' => 'манихејско писмо',
        'Marc' => 'марчен писмо',
        'Maya' => 'мајански хијероглифи',
        'Medf' => 'медефаидрин писмо',
        'Mend' => 'менде писмо',
        'Merc' => 'меоитиц курзив',
        'Mero' => 'мероитик писмо',
        'Mlym' => 'малајалам писмо',
        'Modi' => 'моди писмо',
        'Mong' => 'монголско писмо',
        'Moon' => 'месечево писмо',
        'Mroo' => 'мро писмо',
        'Mtei' => 'меитеи мајек писмо',
        'Mult' => 'мултани писмо',
        'Mymr' => 'мијанмарско писмо',
        'Nagm' => 'наг мундари писмо',
        'Nand' => 'нандинагари писмо',
        'Narb' => 'старо сјеверно арапско писмо',
        'Nbat' => 'набатаен писмо',
        'Newa' => 'нева писмо',
        'Nkoo' => 'н’ко писмо',
        'Nshu' => 'нушу писмо',
        'Ogam' => 'огамско писмо',
        'Olck' => 'ол чики писмо',
        'Orkh' => 'орконско писмо',
        'Orya' => 'одија писмо',
        'Osge' => 'осаге писмо',
        'Osma' => 'осмањанско писмо',
        'Ougr' => 'старо ујгур писмо',
        'Palm' => 'палмѕрене писмо',
        'Pauc' => 'пау цин хау писмо',
        'Perm' => 'старо пермикско писмо',
        'Phag' => 'пагс-па писмо',
        'Phli' => 'писани пахлави',
        'Phlp' => 'псалтер пахлави',
        'Phlv' => 'пахлави писмо',
        'Phnx' => 'феничанско писмо',
        'Plrd' => 'поралд фонетско писмо',
        'Prti' => 'писани партиан',
        'Qaag' => 'завгји писмо',
        'Rjng' => 'рејанг писмо',
        'Rohg' => 'ханифи писмо',
        'Roro' => 'ронгоронго писмо',
        'Runr' => 'рунско писмо',
        'Samr' => 'самаританско писмо',
        'Sara' => 'сарати писмо',
        'Sarb' => 'старо јужно арапско писмо',
        'Saur' => 'саураштра писмо',
        'Sgnw' => 'знаковно писмо',
        'Shaw' => 'шавијанско писмо',
        'Shrd' => 'шарада писмо',
        'Sidd' => 'сидхам писмо',
        'Sind' => 'кудавади писмо',
        'Sinh' => 'синхалско писмо',
        'Sogd' => 'согдиан писмо',
        'Sogo' => 'старо согдиан писмо',
        'Sora' => 'сора сомпенг писмо',
        'Soyo' => 'сојомбо писмо',
        'Sund' => 'сунданесе писмо',
        'Sylo' => 'силоти нагри писмо',
        'Syrc' => 'сиријско писмо',
        'Syre' => 'сиријско естрангело писмо',
        'Syrj' => 'западносиријско писмо',
        'Syrn' => 'писмо источне Сирије',
        'Tagb' => 'тагбанва писмо',
        'Takr' => 'такри писмо',
        'Tale' => 'таи ле писмо',
        'Talu' => 'нови таи луе',
        'Taml' => 'тамилско писмо',
        'Tang' => 'тангут писмо',
        'Tavt' => 'таи виет писмо',
        'Telu' => 'телугу писмо',
        'Teng' => 'тенгвар писмо',
        'Tfng' => 'тифинаг писмо',
        'Tglg' => 'тагалог',
        'Thaa' => 'тана писмо',
        'Thai' => 'тајландско писмо',
        'Tibt' => 'тибетанско писмо',
        'Tirh' => 'тирхута писмо',
        'Tnsa' => 'тангса писмо',
        'Toto' => 'тото писмо',
        'Ugar' => 'угаритско писмо',
        'Vaii' => 'ваи писмо',
        'Visp' => 'видљиви говор',
        'Vith' => 'виткуки писмо',
        'Wara' => 'варанг кшити писмо',
        'Wcho' => 'ванчо',
        'Xpeo' => 'староперсијско писмо',
        'Xsux' => 'сумерско-акадско кунеиформ писмо',
        'Yezi' => 'језиди писмо',
        'Yiii' => 'ји писмо',
        'Zanb' => 'занабазар клинасто писмо',
        'Zinh' => 'наследно писмо',
        'Zmth' => 'математичка нотација',
        'Zsye' => 'емоџи',
        'Zsym' => 'симболи',
        'Zxxx' => 'неписани језик',
        'Zyyy' => 'заједничко писмо',
    ],
];
