<?php

return [
    'Names' => [
        'CRC' => [
            0 => 'CRC',
            1 => 'کوسٹا ریکا کولون',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'قابل منتقلی کیوبائی پیسو',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'کیوبائی پیسو',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'کیپ ورڈی اسکیوڈو',
        ],
        'GBP' => [
            0 => '£',
            1 => 'برطانوی پاونڈ سٹرلنگ',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'گھانی سیڈی',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'پاکستانی روپیہ',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'ساموآئی ٹالا',
        ],
    ],
];
