<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Verenigde Arabiese Emirate-dirham',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afgaanse afgani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanese lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armeense dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Nederlands-Antilliaanse gulde',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolese kwanza',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentynse peso',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Australiese dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Arubaanse floryn',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbeidjaanse manat',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnies-Herzegowiniese omskakelbare marka',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados-dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladesjiese taka',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgaarse lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreinse dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundiese frank',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda-dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Broeneise dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviaanse boliviano',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Brasilliaanse reaal',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamiaanse dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhoetanese ngoeltroem',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswana-pula',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarusiese roebel',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Belo-Russiese roebel (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Beliziese dollar',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Kanadese dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongolese frank',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Switserse frank',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chileense peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Chinese joean (buiteland)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Chinese joean',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Colombiaanse peso',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Costa Ricaanse colón',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kubaanse omskakelbare peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kubaanse peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kaap Verdiese escudo',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Tsjeggiese kroon',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djiboeti-frank',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Deense kroon',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikaanse peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algeriese dinar',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egiptiese pond',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrese nakfa',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiopiese birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fidjiaanse dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falkland-eilandse pond',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Britse pond',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgiese lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ghanese cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanese cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltarese pond',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambiese dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinese frank',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guinese syli',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemalaanse quetzal',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyanese dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hongkongse dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Hondurese lempira',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatiese kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haïtiaanse gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Hongaarse florint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesiese roepia',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Israeliese nuwe sikkel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indiese roepee',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irakse dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iranse rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Yslandse kroon',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italiaanse lier',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaikaanse dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordaniese dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Japannese jen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Keniaanse sjieling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgisiese som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodjaanse riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Comoraanse frank',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Noord-Koreaanse won',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Suid-Koreaanse won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Koeweitse dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Cayman-eilandse dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazakse tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laosiaanse kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libanese pond',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lankaanse roepee',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberiese dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesotho loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litause litas',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lettiese lats',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libiese dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokkaanse dirham',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldowiese leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malgassiese ariary',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Macedoniese denar',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Mianmese kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongoolse toegrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macaose pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritaniese ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritaniese ouguiya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritiaanse roepee',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Malediviese rufia',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawiese kwacha',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Meksikaanse peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Maleisiese ringgit',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mosambiekse metical (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mosambiekse metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibiese dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeriese naira',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nicaraguaanse córdoba',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Noorse kroon',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalese roepee',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Nieu-Seelandse dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omaanse rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamese balboa',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruaanse sol',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papoea-Nieu-Guinese kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filippynse peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistanse roepee',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Poolse zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguaanse guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katarrese rial',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Roemeense leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serwiese dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russiese roebel',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Rwandese frank',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saoedi-Arabiese riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Salomonseilandse dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seychellese roepee',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Soedannese pond',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Soedannese pond (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Sweedse kroon',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapoer-dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Sint Helena-pond',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra Leoniese leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somaliese sjieling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinaamse dollar',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Suid-Soedanese pond',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'São Tomé en Príncipe dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'São Tomé en Príncipe-dobra',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Siriese pond',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazilandse lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Thaise baht',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadjikse somoni',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmeense manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunisiese dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongaanse pa’anga',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turkse lier (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkse lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad en Tobago-dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Nuwe Taiwanese dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniese sjieling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Oekraïnse hriwna',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandese sjieling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'VSA-dollar',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguaanse peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Oezbekiese som',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezolaanse bolivar',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venezolaanse bolívar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Viëtnamese dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatuse vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoaanse tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Sentraal Afrikaanse CFA-frank',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Oos-Karibiese dollar',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Wes-Afrikaanse CFA-frank',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP-frank',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemenitiese rial',
        ],
        'ZAR' => [
            0 => 'R',
            1 => 'Suid-Afrikaanse rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambiese kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambiese kwacha',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabwiese dollar',
        ],
    ],
];
