<?php

return [
    'Names' => [
        'Adlm' => 'ایڈلم',
        'Arab' => 'عربی',
        'Aran' => 'نستعلیق',
        'Armn' => 'آرمینیائی',
        'Beng' => 'بنگالی',
        'Bopo' => 'بوپوموفو',
        'Brai' => 'بریل',
        'Cakm' => 'چکما',
        'Cans' => 'متحدہ کینیڈین ایبوریجنل سلیبکس',
        'Cher' => 'چیروکی',
        'Cyrl' => 'سیریلک',
        'Deva' => 'دیوناگری',
        'Ethi' => 'ایتھوپیائی',
        'Geor' => 'جارجیائی',
        'Grek' => 'یونانی',
        'Gujr' => 'گجراتی',
        'Guru' => 'گرمکھی',
        'Hanb' => 'ہینب',
        'Hang' => 'ہنگول',
        'Hani' => 'ہان',
        'Hans' => 'آسان',
        'Hant' => 'روایتی',
        'Hebr' => 'عبرانی',
        'Hira' => 'ہیراگینا',
        'Hrkt' => 'جاپانی سیلابریز',
        'Jamo' => 'جامو',
        'Jpan' => 'جاپانی',
        'Kana' => 'کٹاکانا',
        'Khmr' => 'خمیر',
        'Knda' => 'کنڑ',
        'Kore' => 'کوریائی',
        'Laoo' => 'لاؤ',
        'Latn' => 'لاطینی',
        'Mlym' => 'ملیالم',
        'Mong' => 'منگولیائی',
        'Mtei' => 'میتی مئیک',
        'Mymr' => 'میانمار',
        'Nkoo' => 'نکو',
        'Olck' => 'اول چکی',
        'Orya' => 'اڑیہ',
        'Rohg' => 'حنیفی',
        'Sinh' => 'سنہالا',
        'Sund' => 'سوڈانی',
        'Syrc' => 'سریانی',
        'Taml' => 'تمل',
        'Telu' => 'تیلگو',
        'Tfng' => 'ٹفناگ',
        'Thaa' => 'تھانا',
        'Thai' => 'تھائی',
        'Tibt' => 'تبتی',
        'Vaii' => 'وائی',
        'Yiii' => 'یی',
        'Zmth' => 'ریاضی کی علامتیں',
        'Zsye' => 'ایموجی',
        'Zsym' => 'علامات',
        'Zxxx' => 'غیر تحریر شدہ',
        'Zyyy' => 'عام',
    ],
];
