<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirham ya Falme za Kiarabu',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghani ya Afghanistan',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lek ya Albania',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dram ya Armenia',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Guilder ya Antili za Kiholanzi',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza ya Angola',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Peso ya Ajentina',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dola ya Australia',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Florin ya Aruba',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manat ya Azerbaijan',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Convertible Mark ya Bosnia na Hezegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dola ya Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka ya Bangladesh',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Lev ya Bulgaria',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinari ya Bahareni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Faranga ya Burundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dola ya Bermuda',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dola ya Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviano ya Bolivia',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Real ya Brazil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dola ya Bahamas',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrum ya Bhutan',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula ya Botswana',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Ruble ya Belarus',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Ruble ya Belarusi (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dola ya Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dola ya Canada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Faranga ya Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Faranga ya Uswisi',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Peso ya Chile',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuan ya Uchina (huru)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan ya Uchina',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Peso ya Kolombia',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Colon ya Kostarika',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Peso ya Kuba Inayoweza Kubadilishwa',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Peso ya Kuba',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Eskudo ya Cape Verde',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna ya Jamhuri ya Czech',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Faranga ya Jibuti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Krone ya Denmark',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Peso ya Dominika',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinar ya Aljeria',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Pauni ya Misri',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa ya Eritrea',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birr ya Uhabeshi',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dola ya Fiji',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Pauni ya Visiwa vya Falkland',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Pauni ya Uingereza',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lari ya Jojia',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi ya Ghana',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Cedi ya Ghana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Pauni ya Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi ya Gambia',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Faranga ya Guinea',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Faranga ya Gine',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Quetzal ya Guatemala',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dola ya Guyana',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dola ya Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira ya Hondurasi',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna ya Korasia',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gourde ya Haiti',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Forint ya Hungaria',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupiah ya Indonesia',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Shekeli Mpya ya Israel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupia ya India',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinari ya Iraki',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Rial ya Iran',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Krona ya Aisilandi',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dola ya Jamaika',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinari ya Jordan',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yen ya Japani',
        ],
        'KES' => [
            0 => 'Ksh',
            1 => 'Shilingi ya Kenya',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Som ya Kyrgystan',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riel ya Kambodia',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Faranga ya Komoro',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Won ya Korea Kaskazini',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Won ya Korea Kusini',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinari ya Kuwait',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dola ya Visiwa vya Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge ya Kazakhstan',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kip ya Laosi',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Pauni ya Lebanon',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rupia ya Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dola ya Liberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ya Lesoto',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litas ya Lithuania',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lats ya Lativia',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinari ya Libya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham ya Moroko',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leu ya Moldova',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariari ya Madagaska',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Denar ya Masedonia',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kyat ya Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrik ya Mongolia',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataca ya Macau',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya ya Mauritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya ya Moritania',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupia ya Morisi',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiyaa ya Maldives',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha ya Malawi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Peso ya Meksiko',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringgit ya Malaysia',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikali ya Msumbiji (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metikali ya Msumbiji',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dola ya Namibia',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira ya Nigeria',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Cordoba ya Nikaragwa',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Krone ya Norwe',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupia ya Nepal',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dola ya Nyuzilandi',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Rial ya Omani',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa ya Panama',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Sol ya Peru',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina ya Papua New Guinea',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Peso ya Ufilipino',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupia ya Pakistan',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Zloty ya Poland',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guarani ya Paragwai',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Rial ya Qatar',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Leu ya Romania',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinar ya Serbia',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Ruble ya Urusi',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Faranga ya Rwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal ya Saudia',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dola ya Visiwa vya Solomon',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupia ya Ushelisheli',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Pauni ya Sudan',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Pauni ya Sudani (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Krona ya Uswidi',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dola ya Singapore',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Pauni ya St. Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone ya Siera Leoni',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shilingi ya Somalia',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dola ya Suriname',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Pauni ya Sudan Kusini',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra ya Sao Tome na Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra ya Sao Tome na Principe',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Pauni ya Syria',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni ya Uswazi',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Baht ya Tailandi',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni ya Tajikistan',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manat ya Turkmenistan',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinari ya Tunisia',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Paʻanga ya Tonga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lira ya Uturuki',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dola ya Trinidad na Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dola ya Taiwan',
        ],
        'TZS' => [
            0 => 'TSh',
            1 => 'Shilingi ya Tanzania',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Hryvnia ya Ukraine',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilingi ya Uganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dola ya Marekani',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso ya Urugwai',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Som ya Uzbekistan',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolivar ya Venezuela (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolivar ya Venezuela',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dong ya Vietnam',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatu ya Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala ya Samoa',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Faranga ya Afrika ya Kati CFA',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dola ya Karibi Mashariki',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faranga ya Afrika Magharibi CFA',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Faranga ya CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Rial ya Yemen',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randi ya Afrika Kusini',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha ya Zambia (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha ya Zambia',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dola ya Zimbabwe',
        ],
    ],
];
