<?php

return [
    'Names' => [
        'ady' => 'adygué',
        'ang' => 'vieil anglais',
        'asa' => 'asou',
        'bbj' => 'ghomala',
        'bik' => 'bicol',
        'byn' => 'bilen',
        'byv' => 'medumba',
        'chg' => 'tchagatay',
        'chn' => 'chinook',
        'ckb' => 'kurde central',
        'cr' => 'cri',
        'crg' => 'michif',
        'crl' => 'cri du Nord-Est',
        'crr' => 'algonquin de la Caroline',
        'den' => 'slave',
        'dgr' => 'tlicho',
        'ebu' => 'embou',
        'esu' => 'yupik central',
        'ewo' => 'ewondo',
        'frc' => 'cajun',
        'frp' => 'franco-provençal',
        'goh' => 'vieux haut-allemand',
        'gu' => 'gujarati',
        'ii' => 'yi de Sichuan',
        'ken' => 'kenyang',
        'kg' => 'kongo',
        'kl' => 'kalaallisut',
        'ks' => 'kashmiri',
        'ksb' => 'chambala',
        'liv' => 'live',
        'lu' => 'luba-katanga',
        'lzh' => 'chinois classique',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mr' => 'marathe',
        'mwr' => 'marwari',
        'mwv' => 'mentawai',
        'njo' => 'ao naga',
        'nmg' => 'kwasio',
        'nwc' => 'newari classique',
        'nyn' => 'nkole',
        'oka' => 'okanagan',
        'pau' => 'palauan',
        'pdc' => 'allemand de Pennsylvanie',
        'pdt' => 'bas allemand mennonite',
        'peo' => 'vieux perse',
        'pfl' => 'palatin',
        'pis' => 'pidgin',
        'pro' => 'ancien occitan',
        'quc' => 'k’iche’',
        'rar' => 'rarotonga',
        'sbp' => 'sangu',
        'sdh' => 'kurde méridional',
        'sei' => 'seri',
        'sga' => 'vieil irlandais',
        'sly' => 'selayar',
        'smn' => 'sami d’Inari',
        'stq' => 'frison de Saterland',
        'sus' => 'sosso',
        'tru' => 'turoyo',
        'tzm' => 'tamazight',
    ],
    'LocalizedNames' => [
        'nds_NL' => 'bas saxon',
        'sw_CD' => 'swahili congolais',
    ],
];
