<?php

return [
    'Names' => [
        'Bali' => 'Baali',
        'Beng' => 'Bangla',
        'Inds' => 'Sindhu',
        'Mymr' => 'Burmese',
        'Orya' => 'Odia',
        'Talu' => 'Naya Tai Lue',
    ],
];
