<?php

return [
    'Names' => [
        'Africa/Kigali' => 'U Rwanda (Kigali)',
        'Antarctica/Troll' => 'Troll',
        'Europe/Skopje' => 'Masedoniya y’Amajyaruguru (Skopje)',
        'Pacific/Tongatapu' => 'Tonga (Tongatapu)',
    ],
    'Meta' => [
    ],
];
