<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abhază',
        'ace' => 'aceh',
        'ach' => 'acoli',
        'ada' => 'adangme',
        'ady' => 'adyghe',
        'ae' => 'avestană',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'akkadiană',
        'ale' => 'aleută',
        'alt' => 'altaică meridională',
        'am' => 'amharică',
        'an' => 'aragoneză',
        'ang' => 'engleză veche',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabă',
        'arc' => 'aramaică',
        'arn' => 'mapuche',
        'arp' => 'arapaho',
        'ars' => 'arabă najdi',
        'arw' => 'arawak',
        'as' => 'asameză',
        'asa' => 'asu',
        'ast' => 'asturiană',
        'atj' => 'atikamekw',
        'av' => 'avară',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'azeră',
        'ba' => 'bașkiră',
        'bal' => 'baluchi',
        'ban' => 'balineză',
        'bas' => 'basaa',
        'bax' => 'bamun',
        'bbj' => 'ghomala',
        'be' => 'belarusă',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bg' => 'bulgară',
        'bgn' => 'baluchi occidentală',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bengaleză',
        'bo' => 'tibetană',
        'br' => 'bretonă',
        'bra' => 'braj',
        'brx' => 'bodo',
        'bs' => 'bosniacă',
        'bss' => 'akoose',
        'bua' => 'buriat',
        'bug' => 'bugineză',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumba',
        'ca' => 'catalană',
        'cad' => 'caddo',
        'car' => 'carib',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'cecenă',
        'ceb' => 'cebuană',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'chibcha',
        'chg' => 'chagatai',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'chn' => 'jargon chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'kurdă centrală',
        'clc' => 'chilcotin',
        'co' => 'corsicană',
        'cop' => 'coptă',
        'cr' => 'cree',
        'crg' => 'michif',
        'crh' => 'turcă crimeeană',
        'crj' => 'cree de sud-est',
        'crk' => 'cree (Prerii)',
        'crl' => 'cree de nord-est',
        'crm' => 'cree (Moose)',
        'crr' => 'algonquiană Carolina',
        'crs' => 'creolă franceză seselwa',
        'cs' => 'cehă',
        'csb' => 'cașubiană',
        'csw' => 'cree (Mlaștini)',
        'cu' => 'slavonă',
        'cv' => 'ciuvașă',
        'cy' => 'galeză',
        'da' => 'daneză',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'germană',
        'del' => 'delaware',
        'den' => 'slave',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'sorabă de jos',
        'dua' => 'duala',
        'dum' => 'neerlandeză medie',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dyu' => 'dyula',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egy' => 'egipteană veche',
        'eka' => 'ekajuk',
        'el' => 'greacă',
        'elx' => 'elamită',
        'en' => 'engleză',
        'enm' => 'engleză medie',
        'eo' => 'esperanto',
        'es' => 'spaniolă',
        'et' => 'estonă',
        'eu' => 'bască',
        'ewo' => 'ewondo',
        'fa' => 'persană',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulah',
        'fi' => 'finlandeză',
        'fil' => 'filipineză',
        'fj' => 'fijiană',
        'fo' => 'feroeză',
        'fon' => 'fon',
        'fr' => 'franceză',
        'frc' => 'franceză cajun',
        'frm' => 'franceză medie',
        'fro' => 'franceză veche',
        'frr' => 'frizonă nordică',
        'frs' => 'frizonă orientală',
        'fur' => 'friulană',
        'fy' => 'frizonă occidentală',
        'ga' => 'irlandeză',
        'gaa' => 'ga',
        'gag' => 'găgăuză',
        'gan' => 'chineză gan',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gd' => 'gaelică scoțiană',
        'gez' => 'geez',
        'gil' => 'gilbertină',
        'gl' => 'galiciană',
        'gmh' => 'germană înaltă medie',
        'gn' => 'guarani',
        'goh' => 'germană înaltă veche',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gotică',
        'grb' => 'grebo',
        'grc' => 'greacă veche',
        'gsw' => 'germană (Elveția)',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwichʼin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'hak' => 'chineză hakka',
        'haw' => 'hawaiiană',
        'hax' => 'haida de sud',
        'he' => 'ebraică',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hit' => 'hitită',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'croată',
        'hsb' => 'sorabă de sus',
        'hsn' => 'chineză xiang',
        'ht' => 'haitiană',
        'hu' => 'maghiară',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armeană',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indoneziană',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'yi din Sichuan',
        'ik' => 'inupiak',
        'ikt' => 'inuktitut canadiană occidentală',
        'ilo' => 'iloko',
        'inh' => 'ingușă',
        'io' => 'ido',
        'is' => 'islandeză',
        'it' => 'italiană',
        'iu' => 'inuktitut',
        'ja' => 'japoneză',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'iudeo-persană',
        'jrb' => 'iudeo-arabă',
        'jv' => 'javaneză',
        'ka' => 'georgiană',
        'kaa' => 'karakalpak',
        'kab' => 'kabyle',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardian',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kabuverdianu',
        'kfo' => 'koro',
        'kg' => 'congoleză',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'kho' => 'khotaneză',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kazahă',
        'kkj' => 'kako',
        'kl' => 'kalaallisut',
        'kln' => 'kalenjin',
        'km' => 'khmeră',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'coreeană',
        'koi' => 'komi-permiak',
        'kok' => 'konkani',
        'kos' => 'kosrae',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karaceai-balkar',
        'krl' => 'kareliană',
        'kru' => 'kurukh',
        'ks' => 'cașmiră',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'kurdă',
        'kum' => 'kumyk',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'cornică',
        'kwk' => 'kwakʼwala',
        'ky' => 'kârgâză',
        'la' => 'latină',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxemburgheză',
        'lez' => 'lezghian',
        'lg' => 'ganda',
        'li' => 'limburgheză',
        'lij' => 'liguriană',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'laoțiană',
        'lol' => 'mongo',
        'lou' => 'creolă (Louisiana)',
        'loz' => 'lozi',
        'lrc' => 'luri de nord',
        'lsm' => 'saamia',
        'lt' => 'lituaniană',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'letonă',
        'mad' => 'madureză',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'man' => 'mandingo',
        'mas' => 'masai',
        'mde' => 'maba',
        'mdf' => 'moksha',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malgașă',
        'mga' => 'irlandeză medie',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshalleză',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'macedoneană',
        'ml' => 'malayalam',
        'mn' => 'mongolă',
        'mnc' => 'manciuriană',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malaeză',
        'mt' => 'malteză',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandeză',
        'mwr' => 'marwari',
        'my' => 'birmană',
        'mye' => 'myene',
        'myv' => 'erzya',
        'mzn' => 'mazanderani',
        'na' => 'nauru',
        'nan' => 'chineză min nan',
        'nap' => 'napolitană',
        'naq' => 'nama',
        'nb' => 'norvegiană bokmål',
        'nd' => 'ndebele de nord',
        'nds' => 'germana de jos',
        'ne' => 'nepaleză',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niueană',
        'nl' => 'neerlandeză',
        'nmg' => 'kwasio',
        'nn' => 'norvegiană nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norvegiană',
        'nog' => 'nogai',
        'non' => 'nordică veche',
        'nqo' => 'n’ko',
        'nr' => 'ndebele de sud',
        'nso' => 'sotho de nord',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'nwc' => 'newari clasică',
        'ny' => 'nyanja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'occitană',
        'oj' => 'ojibwa',
        'ojb' => 'ojibwa de nord-vest',
        'ojc' => 'ojibwa centrală',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwa de vest',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'odia',
        'os' => 'osetă',
        'osa' => 'osage',
        'ota' => 'turcă otomană',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauană',
        'pcm' => 'pidgin nigerian',
        'peo' => 'persană veche',
        'phn' => 'feniciană',
        'pi' => 'pali',
        'pis' => 'pijin',
        'pl' => 'poloneză',
        'pon' => 'pohnpeiană',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'prusacă',
        'pro' => 'provensală veche',
        'ps' => 'paștună',
        'pt' => 'portugheză',
        'qu' => 'quechua',
        'quc' => 'quiché',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotongan',
        'rhg' => 'rohingya',
        'rm' => 'romanșă',
        'rn' => 'kirundi',
        'ro' => 'română',
        'rof' => 'rombo',
        'rom' => 'romani',
        'ru' => 'rusă',
        'rup' => 'aromână',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanscrită',
        'sad' => 'sandawe',
        'sah' => 'sakha',
        'sam' => 'aramaică samariteană',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardiniană',
        'scn' => 'siciliană',
        'sco' => 'scots',
        'sd' => 'sindhi',
        'sdh' => 'kurdă de sud',
        'se' => 'sami de nord',
        'see' => 'seneca',
        'seh' => 'sena',
        'sel' => 'selkup',
        'ses' => 'koyraboro Senni',
        'sg' => 'sango',
        'sga' => 'irlandeză veche',
        'sh' => 'sârbo-croată',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'shu' => 'arabă ciadiană',
        'si' => 'singhaleză',
        'sid' => 'sidamo',
        'sk' => 'slovacă',
        'sl' => 'slovenă',
        'slh' => 'lushootseed de usd',
        'sm' => 'samoană',
        'sma' => 'sami de sud',
        'smj' => 'sami lule',
        'smn' => 'sami inari',
        'sms' => 'sami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somaleză',
        'sog' => 'sogdien',
        'sq' => 'albaneză',
        'sr' => 'sârbă',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'swati',
        'ssy' => 'saho',
        'st' => 'sesotho',
        'str' => 'salish (Strâmtori)',
        'su' => 'sundaneză',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumeriană',
        'sv' => 'suedeză',
        'sw' => 'swahili',
        'swb' => 'comoreză',
        'syc' => 'siriacă clasică',
        'syr' => 'siriacă',
        'ta' => 'tamilă',
        'tce' => 'tutchone de sud',
        'te' => 'telugu',
        'tem' => 'timne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tadjică',
        'tgx' => 'tagish',
        'th' => 'thailandeză',
        'tht' => 'tahltan',
        'ti' => 'tigrină',
        'tig' => 'tigre',
        'tiv' => 'tiv',
        'tk' => 'turkmenă',
        'tkl' => 'tokelau',
        'tl' => 'tagalog',
        'tlh' => 'klingoniană',
        'tli' => 'tlingit',
        'tmh' => 'tamashek',
        'tn' => 'setswana',
        'to' => 'tongană',
        'tog' => 'nyasa tonga',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turcă',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsi' => 'tsimshian',
        'tt' => 'tătară',
        'ttm' => 'tutchone de nord',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitiană',
        'tyv' => 'tuvană',
        'tzm' => 'tamazight din Atlasul Central',
        'udm' => 'udmurt',
        'ug' => 'uigură',
        'uga' => 'ugaritică',
        'uk' => 'ucraineană',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbecă',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'venetă',
        'vi' => 'vietnameză',
        'vo' => 'volapuk',
        'vot' => 'votică',
        'vun' => 'vunjo',
        'wa' => 'valonă',
        'wae' => 'walser',
        'wal' => 'wolaita',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'wolof',
        'wuu' => 'chineză wu',
        'xal' => 'calmucă',
        'xh' => 'xhosa',
        'xog' => 'soga',
        'yao' => 'yao',
        'yap' => 'yapeză',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'idiș',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'cantoneză',
        'za' => 'zhuang',
        'zap' => 'zapotecă',
        'zbl' => 'simboluri Bilss',
        'zen' => 'zenaga',
        'zgh' => 'tamazight standard marocană',
        'zh' => 'chineză',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabă standard modernă',
        'de_CH' => 'germană standard (Elveția)',
        'es_ES' => 'spaniolă (Europa)',
        'fa_AF' => 'dari',
        'nds_NL' => 'saxona de jos',
        'nl_BE' => 'flamandă',
        'pt_PT' => 'portugheză (Europa)',
        'sw_CD' => 'swahili (R.D. Congo)',
        'zh_Hans' => 'chineză simplificată',
        'zh_Hant' => 'chineză tradițională',
    ],
];
