<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andora Pesetası',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Birləşmiş Ərəb Əmirlikləri Dirhəmi',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Əfqanıstan Əfqanisi (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Əfqanıstan Əfqanisi',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Albaniya Leki (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albaniya Leki',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Ermənistan Dramı',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Niderland Antilyası Gilderi',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Anqola Kvanzası',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Anqola Kvanzasi (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Anqola Yeni Kvanzası (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Anqola Kvanzası (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentina avstralı',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentina pesosu (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentina Pesosu',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Avstriya Şillinqi',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Avstraliya Dolları',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruba Florini',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azərbaycan Manatı (1993–2006)',
        ],
        'AZN' => [
            0 => '₼',
            1 => 'Azərbaycan Manatı',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosniya-Herseqovina Dinarı',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosniya-Herseqovina Markası',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados Dolları',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Banqladeş Takası',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belçika Frankı (deyşirik)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belçika Frankı',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belçika Frankı (finans)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bolqarıstan Levası',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bolqarıstan Levi',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bəhreyn Dinarı',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi Frankı',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda Dolları',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Bruney Dolları',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviya Bolivianosu',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Boliviya pesosu',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Boliviya mvdolı',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Braziliya kruzeyro novası',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Braziliya kruzadosu',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Braziliya kruzeyrosu (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Braziliya Realı',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Braziliya kruzado novası',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Braziliya kruzeyrosu',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Baham Dolları',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butan Nqultrumu',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Burmis Kyatı',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botsvana Pulası',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Belarus Yeni Rublu (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarus Rublu',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Belarus Rublu (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Beliz Dolları',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanada Dolları',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Konqo Frankı',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR Avro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'İsveçrə Frankı',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR Frankası',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Çili Pesosu',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Çin Yuanı (ofşor)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Çin Yuanı',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbiya Pesosu',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kosta Rika Kolonu',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Serbiya Dinarı (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Çexoslavakiya Korunası',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kuba Çevrilən Pesosu',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kuba Pesosu',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kape Verde Eskudosu',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Kipr Paundu',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Çexiya Korunası',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Şərq Almaniya Ostmarkı',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Alman Markası',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Cibuti Frankı',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Danimarka Kronu',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominika Pesosu',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Əlcəzair Dinarı',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ekvador Sukresi',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estoniya Krunu',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Misir Funtu',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritreya Nakfası',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'İspan Pesetası (A account)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'İspan Pesetası (dəyşirik)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'İspan Pesetası',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Efiopiya Bırrı',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Avro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Fin Markası',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fici Dolları',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Folklend Adaları Funtu',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Fransız Markası',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Britaniya Funtu',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Gürcüstan Kupon Lariti',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gürcüstan Larisi',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Qana Sedisi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Qana Sedisi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Cəbəli-Tariq Funtu',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Qambiya Dalasisi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Qvineya Frankı',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Qvineya Sulisi',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ekvatoriya Gvineya Ekvele Quneanası',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Yunan Draçması',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Qvatemala Küetzalı',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugal Qvineya Eskudosu',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Qvineya-Bisau Pesosu',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Qayana Dolları',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Honq Konq Dolları',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Honduras Lempirası',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Xorvatiya Dinarı',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Xorvatiya Kunası',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haiti Qourdu',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Macarıstan Forinti',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'İndoneziya Rupisi',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'İrlandiya Paundu',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'İzrail Paundu',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'İsrail Şekeli (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'İsrail Yeni Şekeli',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Hindistan Rupisi',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'İraq Dinarı',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'İran Rialı',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'İslandiya Kronu (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'İslandiya Kronu',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'İtaliya Lirası',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Yamayka Dolları',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'İordaniya Dinarı',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yaponiya Yeni',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Keniya Şillinqi',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Qırğızıstan Somu',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kamboca Rieli',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komor Frankı',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Şimali Koreya Vonu',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Cənubi Koreya Vonu',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Küveyt Dinarı',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kayman Adaları Dolları',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Qazaxıstan Tengesi',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laos Kipi',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Livan Funtu',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Şri Lanka Rupisi',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberiya Dolları',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesoto Lotisi',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litva Liti',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litva Talonası',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Luksemburq Frankası (dəyişik)',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Luksemburq Frankası',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Luksemburq Frankası (finans)',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Latviya Latı',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Latviya Rublu',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Liviya Dinarı',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Mərakeş Dirhəmi',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Mərakeş Frankası',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldova Leyi',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madaqaskar Ariarisi',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madaqaskar Frankası',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedoniya Dinarı',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Makedoniya Dinarı (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Mali Frankı',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanma Kiyatı',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Monqoliya Tuqriki',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao Patakası',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mavritaniya Ugiyası (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mavritaniya Ugiyası',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltiz Paundu',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mavriki Rupisi',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldiv Rufiyası',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malavi Kvaçası',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksika Pesosu',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Meksika gümüş pesosu',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malayziya Ringiti',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambik Eskudosu',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mozambik Metikalı (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambik Metikalı',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibiya Dolları',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeriya Nairası',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nikaraqua kordobu',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaraqua Kordobası',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Hollandiya Gilderi',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norveç Kronu',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepal Rupisi',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Yeni Zelandiya Dolları',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Oman Rialı',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panama Balboası',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peru Inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru Solu',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peru Solu (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua Yeni Qvineya Kinası',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filippin Pesosu',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistan Rupisi',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polşa Zlotısı',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Polşa Zlotısı (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portuqal Eskudosu',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraqvay Quaranisi',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Qatar Rialı',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rodezian Dolları',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rumıniya Leyi (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumıniya Leyi',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbiya Dinarı',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rusiya Rublu',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rusiya Rublu (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruanda Frankı',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Səudiyyə Riyalı',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomon Adaları Dolları',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seyşel Rupisi',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudan Funtu',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'İsveç Kronu',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Sinqapur Dolları',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Müqəddəs Yelena Funtu',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Sloveniya Toları',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovak Korunası',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra Leon Leonu',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somali Şillinqi',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinam Dolları',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Cənubi Sudan Funtu',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'San Tom və Prinsip Dobrası (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'San Tom və Prinsip Dobrası',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovet Rublu',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'El Salvador kolonu',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Suriya Funtu',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svazilend Lilangenini',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Tayland Batı',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tacikistan Rublu',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tacikistan Somonisi',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Türkmənistan Manatı (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Türkmənistan Manatı',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunis Dinarı',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tonqa Panqası',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timor Eskudu',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Türkiyə Lirəsi (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Türkiyə Lirəsi',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad və Tobaqo Dolları',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Tayvan Yeni Dolları',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniya Şillinqi',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrayna Qrivnası',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrayna Karbovenesası',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Uqanda Şillinqi (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Uqanda Şillinqi',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'ABŞ Dolları',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'ABŞ dolları (yeni gün)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'ABŞ dolları (həmin gün)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Uruqvay pesosu Unidades Indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruqvay Pesosu (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruqvay Pesosu',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Özbəkistan Somu',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venesuela Bolivarı (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venesuela Bolivarı (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venesuela Bolivarı',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vyetnam Donqu',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Vyetnam Donqu (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu Vatusu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa Talası',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Kamerun Frankı',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Şərqi Karib Dolları',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Fransız Gızıl Frankı',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Fransız UİC Frankı',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Fil Dişi Sahili Frankı',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Fransız Polineziyası Frankı',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Yəmən Dinarı',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Yəmən Rialı',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Yuqoslaviya Dinarı (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Yuqoslaviya Yeni Dinarı (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Yuqoslaviya Dinarı (1990–1992)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Cənubi Afrika Randı (finans)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Cənubi Afrika Randı',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambiya Kvaçası (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambiya Kvaçası',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zair Yeni Zairi (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zair Zairi (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabve Dolları (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabve Dolları (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabve Dolları (2008)',
        ],
    ],
];
