<?php

return [
    'Names' => [
        'ar_001' => 'арапски (свијет)',
        'ar_KM' => 'арапски (Комори)',
        'ar_PS' => 'арапски (палестинске територије)',
        'be' => 'бјелоруски',
        'be_BY' => 'бјелоруски (Бјелорусија)',
        'bm' => 'бамананкан',
        'bm_ML' => 'бамананкан (Мали)',
        'bn' => 'бангла',
        'bn_BD' => 'бангла (Бангладеш)',
        'bn_IN' => 'бангла (Индија)',
        'cs_CZ' => 'чешки (Чешка Република)',
        'de' => 'њемачки',
        'de_AT' => 'њемачки (Аустрија)',
        'de_BE' => 'њемачки (Белгија)',
        'de_CH' => 'њемачки (Швајцарска)',
        'de_DE' => 'њемачки (Њемачка)',
        'de_IT' => 'њемачки (Италија)',
        'de_LI' => 'њемачки (Лихтенштајн)',
        'de_LU' => 'њемачки (Луксембург)',
        'en_001' => 'енглески (свијет)',
        'en_CC' => 'енглески (Кокосова [Килинг] острва)',
        'en_DE' => 'енглески (Њемачка)',
        'en_FK' => 'енглески (Фокландска острва)',
        'en_GU' => 'енглески (Гвам)',
        'en_HK' => 'енглески (Хонгконг [САО Кине])',
        'en_MP' => 'енглески (Сјеверна Маријанска острва)',
        'en_NF' => 'енглески (острво Норфок)',
        'en_NU' => 'енглески (Нијуе)',
        'en_UM' => 'енглески (Спољна острва САД)',
        'en_VC' => 'енглески (Свети Винсент и Гренадини)',
        'en_VG' => 'енглески (Британска Дјевичанска острва)',
        'en_VI' => 'енглески (Америчка Дјевичанска острва)',
        'eo_001' => 'есперанто (свијет)',
        'ff_Adlm_GW' => 'фула (адлам, Гвинеја Бисао)',
        'ff_Latn_GW' => 'фула (латиница, Гвинеја Бисао)',
        'fo_FO' => 'фарски (Фарска острва)',
        'fr_BL' => 'француски (Сен Бартелеми)',
        'fr_KM' => 'француски (Комори)',
        'fr_RE' => 'француски (Реунион)',
        'ia_001' => 'интерлингва (свијет)',
        'ko_KP' => 'корејски (Сјеверна Кореја)',
        'mk_MK' => 'македонски (Сјеверна Македонија)',
        'ms_BN' => 'малајски (Брунеји)',
        'my_MM' => 'бурмански (Мјанмар [Бурма])',
        'nd' => 'сјеверни ндебеле',
        'nd_ZW' => 'сјеверни ндебеле (Зимбабве)',
        'pt_GW' => 'португалски (Гвинеја Бисао)',
        'ru_BY' => 'руски (Бјелорусија)',
        'se' => 'сјеверни сами',
        'se_FI' => 'сјеверни сами (Финска)',
        'se_NO' => 'сјеверни сами (Норвешка)',
        'se_SE' => 'сјеверни сами (Шведска)',
        'sq_MK' => 'албански (Сјеверна Македонија)',
        'sv_AX' => 'шведски (Оландска острва)',
        'yi_001' => 'јидиш (свијет)',
        'zh_HK' => 'кинески (Хонгконг [САО Кине])',
        'zh_Hans_HK' => 'кинески (поједностављено кинеско писмо, Хонгконг [САО Кине])',
        'zh_Hant_HK' => 'кинески (традиционално кинеско писмо, Хонгконг [САО Кине])',
    ],
];
