<?php

return [
    'Names' => [
        'BN' => 'Brunei',
        'BW' => 'Botswana',
        'CV' => 'Kapverden',
        'SB' => 'Salomon-Inseln',
        'TL' => 'Osttimor',
        'ZW' => 'Zimbabwe',
    ],
];
