<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Ora de Greenwhich (Abidjan)',
        'Africa/Accra' => 'Ora de Greenwhich (Accra)',
        'Africa/Addis_Ababa' => 'Ora Africii Orientale (Addis Abeba)',
        'Africa/Algiers' => 'Ora Europei Centrale (Alger)',
        'Africa/Asmera' => 'Ora Africii Orientale (Asmara)',
        'Africa/Bamako' => 'Ora de Greenwhich (Bamako)',
        'Africa/Bangui' => 'Ora Africii Occidentale (Bangui)',
        'Africa/Banjul' => 'Ora de Greenwhich (Banjul)',
        'Africa/Bissau' => 'Ora de Greenwhich (Bissau)',
        'Africa/Blantyre' => 'Ora Africii Centrale (Blantyre)',
        'Africa/Brazzaville' => 'Ora Africii Occidentale (Brazzaville)',
        'Africa/Bujumbura' => 'Ora Africii Centrale (Bujumbura)',
        'Africa/Cairo' => 'Ora Europei de Est (Cairo)',
        'Africa/Casablanca' => 'Ora Europei de Vest (Casablanca)',
        'Africa/Ceuta' => 'Ora Europei Centrale (Ceuta)',
        'Africa/Conakry' => 'Ora de Greenwhich (Conakry)',
        'Africa/Dakar' => 'Ora de Greenwhich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ora Africii Orientale (Dar es Salaam)',
        'Africa/Djibouti' => 'Ora Africii Orientale (Djibouti)',
        'Africa/Douala' => 'Ora Africii Occidentale (Douala)',
        'Africa/El_Aaiun' => 'Ora Europei de Vest (El Aaiun)',
        'Africa/Freetown' => 'Ora de Greenwhich (Freetown)',
        'Africa/Gaborone' => 'Ora Africii Centrale (Gaborone)',
        'Africa/Harare' => 'Ora Africii Centrale (Harare)',
        'Africa/Johannesburg' => 'Ora Africii Meridionale (Johannesburg)',
        'Africa/Juba' => 'Ora Africii Centrale (Juba)',
        'Africa/Kampala' => 'Ora Africii Orientale (Kampala)',
        'Africa/Khartoum' => 'Ora Africii Centrale (Khartoum)',
        'Africa/Kigali' => 'Ora Africii Centrale (Kigali)',
        'Africa/Kinshasa' => 'Ora Africii Occidentale (Kinshasa)',
        'Africa/Lagos' => 'Ora Africii Occidentale (Lagos)',
        'Africa/Libreville' => 'Ora Africii Occidentale (Libreville)',
        'Africa/Lome' => 'Ora de Greenwhich (Lome)',
        'Africa/Luanda' => 'Ora Africii Occidentale (Luanda)',
        'Africa/Lubumbashi' => 'Ora Africii Centrale (Lubumbashi)',
        'Africa/Lusaka' => 'Ora Africii Centrale (Lusaka)',
        'Africa/Malabo' => 'Ora Africii Occidentale (Malabo)',
        'Africa/Maputo' => 'Ora Africii Centrale (Maputo)',
        'Africa/Maseru' => 'Ora Africii Meridionale (Maseru)',
        'Africa/Mbabane' => 'Ora Africii Meridionale (Mbabane)',
        'Africa/Mogadishu' => 'Ora Africii Orientale (Mogadiscio)',
        'Africa/Monrovia' => 'Ora de Greenwhich (Monrovia)',
        'Africa/Nairobi' => 'Ora Africii Orientale (Nairobi)',
        'Africa/Ndjamena' => 'Ora Africii Occidentale (N’Djamena)',
        'Africa/Niamey' => 'Ora Africii Occidentale (Niamey)',
        'Africa/Nouakchott' => 'Ora de Greenwhich (Nouakchott)',
        'Africa/Ouagadougou' => 'Ora de Greenwhich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Ora Africii Occidentale (Porto-Novo)',
        'Africa/Sao_Tome' => 'Ora de Greenwhich (Sao Tomé)',
        'Africa/Tripoli' => 'Ora Europei de Est (Tripoli)',
        'Africa/Tunis' => 'Ora Europei Centrale (Tunis)',
        'Africa/Windhoek' => 'Ora Africii Centrale (Windhoek)',
        'America/Adak' => 'Ora din Hawaii-Aleutine (Adak)',
        'America/Anchorage' => 'Ora din Alaska (Anchorage)',
        'America/Anguilla' => 'Ora zonei Atlantic nord-americane (Anguilla)',
        'America/Antigua' => 'Ora zonei Atlantic nord-americane (Antigua)',
        'America/Araguaina' => 'Ora Brasiliei (Araguaina)',
        'America/Argentina/La_Rioja' => 'Ora Argentinei (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Ora Argentinei (Rio Gallegos)',
        'America/Argentina/Salta' => 'Ora Argentinei (Salta)',
        'America/Argentina/San_Juan' => 'Ora Argentinei (San Juan)',
        'America/Argentina/San_Luis' => 'Ora Argentinei (San Luis)',
        'America/Argentina/Tucuman' => 'Ora Argentinei (Tucuman)',
        'America/Argentina/Ushuaia' => 'Ora Argentinei (Ushuaia)',
        'America/Aruba' => 'Ora zonei Atlantic nord-americane (Aruba)',
        'America/Asuncion' => 'Ora din Paraguay (Asunción)',
        'America/Bahia' => 'Ora Brasiliei (Bahia)',
        'America/Bahia_Banderas' => 'Ora centrală nord-americană (Bahia Banderas)',
        'America/Barbados' => 'Ora zonei Atlantic nord-americane (Barbados)',
        'America/Belem' => 'Ora Brasiliei (Belem)',
        'America/Belize' => 'Ora centrală nord-americană (Belize)',
        'America/Blanc-Sablon' => 'Ora zonei Atlantic nord-americane (Blanc-Sablon)',
        'America/Boa_Vista' => 'Ora Amazonului (Boa Vista)',
        'America/Bogota' => 'Ora Columbiei (Bogota)',
        'America/Boise' => 'Ora zonei montane nord-americane (Boise)',
        'America/Buenos_Aires' => 'Ora Argentinei (Buenos Aires)',
        'America/Cambridge_Bay' => 'Ora zonei montane nord-americane (Cambridge Bay)',
        'America/Campo_Grande' => 'Ora Amazonului (Campo Grande)',
        'America/Cancun' => 'Ora orientală nord-americană (Cancun)',
        'America/Caracas' => 'Ora Venezuelei (Caracas)',
        'America/Catamarca' => 'Ora Argentinei (Catamarca)',
        'America/Cayenne' => 'Ora din Guyana Franceză (Cayenne)',
        'America/Cayman' => 'Ora orientală nord-americană (Cayman)',
        'America/Chicago' => 'Ora centrală nord-americană (Chicago)',
        'America/Chihuahua' => 'Ora zonei Pacific mexicane (Chihuahua)',
        'America/Coral_Harbour' => 'Ora orientală nord-americană (Atikokan)',
        'America/Cordoba' => 'Ora Argentinei (Cordoba)',
        'America/Costa_Rica' => 'Ora centrală nord-americană (Costa Rica)',
        'America/Creston' => 'Ora zonei montane nord-americane (Creston)',
        'America/Cuiaba' => 'Ora Amazonului (Cuiaba)',
        'America/Curacao' => 'Ora zonei Atlantic nord-americane (Curaçao)',
        'America/Danmarkshavn' => 'Ora de Greenwhich (Danmarkshavn)',
        'America/Dawson' => 'Ora din Yukon (Dawson)',
        'America/Dawson_Creek' => 'Ora zonei montane nord-americane (Dawson Creek)',
        'America/Denver' => 'Ora zonei montane nord-americane (Denver)',
        'America/Detroit' => 'Ora orientală nord-americană (Detroit)',
        'America/Dominica' => 'Ora zonei Atlantic nord-americane (Dominica)',
        'America/Edmonton' => 'Ora zonei montane nord-americane (Edmonton)',
        'America/Eirunepe' => 'Ora Acre (Eirunepe)',
        'America/El_Salvador' => 'Ora centrală nord-americană (El Salvador)',
        'America/Fort_Nelson' => 'Ora zonei montane nord-americane (Fort Nelson)',
        'America/Fortaleza' => 'Ora Brasiliei (Fortaleza)',
        'America/Glace_Bay' => 'Ora zonei Atlantic nord-americane (Glace Bay)',
        'America/Godthab' => 'Ora Groenlandei occidentale (Nuuk)',
        'America/Goose_Bay' => 'Ora zonei Atlantic nord-americane (Goose Bay)',
        'America/Grand_Turk' => 'Ora orientală nord-americană (Grand Turk)',
        'America/Grenada' => 'Ora zonei Atlantic nord-americane (Grenada)',
        'America/Guadeloupe' => 'Ora zonei Atlantic nord-americane (Guadelupa)',
        'America/Guatemala' => 'Ora centrală nord-americană (Guatemala)',
        'America/Guayaquil' => 'Ora Ecuadorului (Guayaquil)',
        'America/Guyana' => 'Ora din Guyana',
        'America/Halifax' => 'Ora zonei Atlantic nord-americane (Halifax)',
        'America/Havana' => 'Ora Cubei (Havana)',
        'America/Hermosillo' => 'Ora zonei Pacific mexicane (Hermosillo)',
        'America/Indiana/Knox' => 'Ora centrală nord-americană (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Ora orientală nord-americană (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ora orientală nord-americană (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ora centrală nord-americană (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Ora orientală nord-americană (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Ora orientală nord-americană (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Ora orientală nord-americană (Winamac, Indiana)',
        'America/Indianapolis' => 'Ora orientală nord-americană (Indianapolis)',
        'America/Inuvik' => 'Ora zonei montane nord-americane (Inuvik)',
        'America/Iqaluit' => 'Ora orientală nord-americană (Iqaluit)',
        'America/Jamaica' => 'Ora orientală nord-americană (Jamaica)',
        'America/Jujuy' => 'Ora Argentinei (Jujuy)',
        'America/Juneau' => 'Ora din Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Ora orientală nord-americană (Monticello, Kentucky)',
        'America/Kralendijk' => 'Ora zonei Atlantic nord-americane (Kralendijk)',
        'America/La_Paz' => 'Ora Boliviei (La Paz)',
        'America/Lima' => 'Ora din Peru (Lima)',
        'America/Los_Angeles' => 'Ora zonei Pacific nord-americane (Los Angeles)',
        'America/Louisville' => 'Ora orientală nord-americană (Louisville)',
        'America/Lower_Princes' => 'Ora zonei Atlantic nord-americane (Lower Prince’s Quarter)',
        'America/Maceio' => 'Ora Brasiliei (Maceio)',
        'America/Managua' => 'Ora centrală nord-americană (Managua)',
        'America/Manaus' => 'Ora Amazonului (Manaus)',
        'America/Marigot' => 'Ora zonei Atlantic nord-americane (Marigot)',
        'America/Martinique' => 'Ora zonei Atlantic nord-americane (Martinica)',
        'America/Matamoros' => 'Ora centrală nord-americană (Matamoros)',
        'America/Mazatlan' => 'Ora zonei Pacific mexicane (Mazatlan)',
        'America/Mendoza' => 'Ora Argentinei (Mendoza)',
        'America/Menominee' => 'Ora centrală nord-americană (Menominee)',
        'America/Merida' => 'Ora centrală nord-americană (Merida)',
        'America/Metlakatla' => 'Ora din Alaska (Metlakatla)',
        'America/Mexico_City' => 'Ora centrală nord-americană (Ciudad de Mexico)',
        'America/Miquelon' => 'Ora din Saint-Pierre și Miquelon',
        'America/Moncton' => 'Ora zonei Atlantic nord-americane (Moncton)',
        'America/Monterrey' => 'Ora centrală nord-americană (Monterrey)',
        'America/Montevideo' => 'Ora Uruguayului (Montevideo)',
        'America/Montreal' => 'Ora din Canada (Montreal)',
        'America/Montserrat' => 'Ora zonei Atlantic nord-americane (Montserrat)',
        'America/Nassau' => 'Ora orientală nord-americană (Nassau)',
        'America/New_York' => 'Ora orientală nord-americană (New York)',
        'America/Nipigon' => 'Ora orientală nord-americană (Nipigon)',
        'America/Nome' => 'Ora din Alaska (Nome)',
        'America/Noronha' => 'Ora din Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Ora centrală nord-americană (Beulah, Dakota de Nord)',
        'America/North_Dakota/Center' => 'Ora centrală nord-americană (Center, Dakota de Nord)',
        'America/North_Dakota/New_Salem' => 'Ora centrală nord-americană (New Salem, Dakota de Nord)',
        'America/Ojinaga' => 'Ora zonei montane nord-americane (Ojinaga)',
        'America/Panama' => 'Ora orientală nord-americană (Panama)',
        'America/Pangnirtung' => 'Ora orientală nord-americană (Pangnirtung)',
        'America/Paramaribo' => 'Ora Surinamului (Paramaribo)',
        'America/Phoenix' => 'Ora zonei montane nord-americane (Phoenix)',
        'America/Port-au-Prince' => 'Ora orientală nord-americană (Port-au-Prince)',
        'America/Port_of_Spain' => 'Ora zonei Atlantic nord-americane (Port of Spain)',
        'America/Porto_Velho' => 'Ora Amazonului (Porto Velho)',
        'America/Puerto_Rico' => 'Ora zonei Atlantic nord-americane (Puerto Rico)',
        'America/Punta_Arenas' => 'Ora din Chile (Punta Arenas)',
        'America/Rainy_River' => 'Ora centrală nord-americană (Rainy River)',
        'America/Rankin_Inlet' => 'Ora centrală nord-americană (Rankin Inlet)',
        'America/Recife' => 'Ora Brasiliei (Recife)',
        'America/Regina' => 'Ora centrală nord-americană (Regina)',
        'America/Resolute' => 'Ora centrală nord-americană (Resolute)',
        'America/Rio_Branco' => 'Ora Acre (Rio Branco)',
        'America/Santa_Isabel' => 'Ora Mexicului de nord-vest (Santa Isabel)',
        'America/Santarem' => 'Ora Brasiliei (Santarem)',
        'America/Santiago' => 'Ora din Chile (Santiago)',
        'America/Santo_Domingo' => 'Ora zonei Atlantic nord-americane (Santo Domingo)',
        'America/Sao_Paulo' => 'Ora Brasiliei (Sao Paulo)',
        'America/Scoresbysund' => 'Ora Groenlandei orientale (Ittoqqortoormiit)',
        'America/Sitka' => 'Ora din Alaska (Sitka)',
        'America/St_Barthelemy' => 'Ora zonei Atlantic nord-americane (Saint Barthélemy)',
        'America/St_Johns' => 'Ora din Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Ora zonei Atlantic nord-americane (St. Kitts)',
        'America/St_Lucia' => 'Ora zonei Atlantic nord-americane (St. Lucia)',
        'America/St_Thomas' => 'Ora zonei Atlantic nord-americane (St. Thomas)',
        'America/St_Vincent' => 'Ora zonei Atlantic nord-americane (St. Vincent)',
        'America/Swift_Current' => 'Ora centrală nord-americană (Swift Current)',
        'America/Tegucigalpa' => 'Ora centrală nord-americană (Tegucigalpa)',
        'America/Thule' => 'Ora zonei Atlantic nord-americane (Thule)',
        'America/Thunder_Bay' => 'Ora orientală nord-americană (Thunder Bay)',
        'America/Tijuana' => 'Ora zonei Pacific nord-americane (Tijuana)',
        'America/Toronto' => 'Ora orientală nord-americană (Toronto)',
        'America/Tortola' => 'Ora zonei Atlantic nord-americane (Tortola)',
        'America/Vancouver' => 'Ora zonei Pacific nord-americane (Vancouver)',
        'America/Whitehorse' => 'Ora din Yukon (Whitehorse)',
        'America/Winnipeg' => 'Ora centrală nord-americană (Winnipeg)',
        'America/Yakutat' => 'Ora din Alaska (Yakutat)',
        'America/Yellowknife' => 'Ora zonei montane nord-americane (Yellowknife)',
        'Antarctica/Casey' => 'Ora din Antarctica (Casey)',
        'Antarctica/Davis' => 'Ora din Davis',
        'Antarctica/DumontDUrville' => 'Ora din Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Ora Australiei Orientale (Macquarie)',
        'Antarctica/Mawson' => 'Ora din Mawson',
        'Antarctica/McMurdo' => 'Ora Noii Zeelande (McMurdo)',
        'Antarctica/Palmer' => 'Ora din Chile (Palmer)',
        'Antarctica/Rothera' => 'Ora din Rothera',
        'Antarctica/Syowa' => 'Ora din Syowa (Showa)',
        'Antarctica/Troll' => 'Ora de Greenwhich (Troll)',
        'Antarctica/Vostok' => 'Ora din Vostok',
        'Arctic/Longyearbyen' => 'Ora Europei Centrale (Longyearbyen)',
        'Asia/Aden' => 'Ora arabă (Aden)',
        'Asia/Almaty' => 'Ora din Kazahstanul de Est (Almatî)',
        'Asia/Amman' => 'Ora Europei de Est (Amman)',
        'Asia/Anadyr' => 'Ora din Anadyr (Anadir)',
        'Asia/Aqtau' => 'Ora din Kazahstanul de Vest (Aktau)',
        'Asia/Aqtobe' => 'Ora din Kazahstanul de Vest (Aktobe)',
        'Asia/Ashgabat' => 'Ora din Turkmenistan (Așgabat)',
        'Asia/Atyrau' => 'Ora din Kazahstanul de Vest (Atîrau)',
        'Asia/Baghdad' => 'Ora arabă (Bagdad)',
        'Asia/Bahrain' => 'Ora arabă (Bahrain)',
        'Asia/Baku' => 'Ora Azerbaidjanului (Baku)',
        'Asia/Bangkok' => 'Ora Indochinei (Bangkok)',
        'Asia/Barnaul' => 'Ora din Rusia (Barnaul)',
        'Asia/Beirut' => 'Ora Europei de Est (Beirut)',
        'Asia/Bishkek' => 'Ora din Kârgâzstan (Bișkek)',
        'Asia/Brunei' => 'Ora din Brunei Darussalam',
        'Asia/Calcutta' => 'Ora Indiei (Calcutta)',
        'Asia/Chita' => 'Ora din Iakuțk (Cita)',
        'Asia/Choibalsan' => 'Ora din Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Ora Indiei (Colombo)',
        'Asia/Damascus' => 'Ora Europei de Est (Damasc)',
        'Asia/Dhaka' => 'Ora din Bangladesh (Dacca)',
        'Asia/Dili' => 'Ora Timorului de Est (Dili)',
        'Asia/Dubai' => 'Ora standard a Golfului (Dubai)',
        'Asia/Dushanbe' => 'Ora din Tadjikistan (Dușanbe)',
        'Asia/Famagusta' => 'Ora Europei de Est (Famagusta)',
        'Asia/Gaza' => 'Ora Europei de Est (Gaza)',
        'Asia/Hebron' => 'Ora Europei de Est (Hebron)',
        'Asia/Hong_Kong' => 'Ora din Hong Kong',
        'Asia/Hovd' => 'Ora din Hovd',
        'Asia/Irkutsk' => 'Ora din Irkuțk',
        'Asia/Jakarta' => 'Ora Indoneziei de Vest (Jakarta)',
        'Asia/Jayapura' => 'Ora Indoneziei de Est (Jayapura)',
        'Asia/Jerusalem' => 'Ora Israelului (Ierusalim)',
        'Asia/Kabul' => 'Ora Afganistanului (Kabul)',
        'Asia/Kamchatka' => 'Ora din Petropavlovsk-Kamciațki (Kamciatka)',
        'Asia/Karachi' => 'Ora Pakistanului (Karachi)',
        'Asia/Katmandu' => 'Ora Nepalului (Kathmandu)',
        'Asia/Khandyga' => 'Ora din Iakuțk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Ora din Krasnoiarsk',
        'Asia/Kuala_Lumpur' => 'Ora din Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Ora din Malaysia (Kuching)',
        'Asia/Kuwait' => 'Ora arabă (Kuweit)',
        'Asia/Macau' => 'Ora Chinei (Macao)',
        'Asia/Magadan' => 'Ora din Magadan',
        'Asia/Makassar' => 'Ora Indoneziei Centrale (Makassar)',
        'Asia/Manila' => 'Ora din Filipine (Manila)',
        'Asia/Muscat' => 'Ora standard a Golfului (Muscat)',
        'Asia/Nicosia' => 'Ora Europei de Est (Nicosia)',
        'Asia/Novokuznetsk' => 'Ora din Krasnoiarsk (Novokuznețk)',
        'Asia/Novosibirsk' => 'Ora din Novosibirsk',
        'Asia/Omsk' => 'Ora din Omsk',
        'Asia/Oral' => 'Ora din Kazahstanul de Vest (Uralsk)',
        'Asia/Phnom_Penh' => 'Ora Indochinei (Phnom Penh)',
        'Asia/Pontianak' => 'Ora Indoneziei de Vest (Pontianak)',
        'Asia/Pyongyang' => 'Ora Coreei (Phenian)',
        'Asia/Qatar' => 'Ora arabă (Qatar)',
        'Asia/Qostanay' => 'Ora din Kazahstanul de Est (Kostanay)',
        'Asia/Qyzylorda' => 'Ora din Kazahstanul de Vest (Kyzylorda)',
        'Asia/Rangoon' => 'Ora Myanmarului (Yangon)',
        'Asia/Riyadh' => 'Ora arabă (Riad)',
        'Asia/Saigon' => 'Ora Indochinei (Ho Și Min)',
        'Asia/Sakhalin' => 'Ora din Sahalin',
        'Asia/Samarkand' => 'Ora din Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'Ora Coreei (Seoul)',
        'Asia/Shanghai' => 'Ora Chinei (Shanghai)',
        'Asia/Singapore' => 'Ora din Singapore',
        'Asia/Srednekolymsk' => 'Ora din Magadan (Srednekolimsk)',
        'Asia/Taipei' => 'Ora din Taipei',
        'Asia/Tashkent' => 'Ora din Uzbekistan (Tașkent)',
        'Asia/Tbilisi' => 'Ora Georgiei (Tbilisi)',
        'Asia/Tehran' => 'Ora Iranului (Teheran)',
        'Asia/Thimphu' => 'Ora Bhutanului (Thimphu)',
        'Asia/Tokyo' => 'Ora Japoniei (Tokyo)',
        'Asia/Tomsk' => 'Ora din Rusia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ora din Ulan Bator',
        'Asia/Urumqi' => 'Ora din China (Urumqi)',
        'Asia/Ust-Nera' => 'Ora din Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Ora Indochinei (Vientiane)',
        'Asia/Vladivostok' => 'Ora din Vladivostok',
        'Asia/Yakutsk' => 'Ora din Iakuțk',
        'Asia/Yekaterinburg' => 'Ora din Ekaterinburg',
        'Asia/Yerevan' => 'Ora Armeniei (Erevan)',
        'Atlantic/Azores' => 'Ora din Azore',
        'Atlantic/Bermuda' => 'Ora zonei Atlantic nord-americane (Bermuda)',
        'Atlantic/Canary' => 'Ora Europei de Vest (Canare)',
        'Atlantic/Cape_Verde' => 'Ora din Capul Verde',
        'Atlantic/Faeroe' => 'Ora Europei de Vest (Feroe)',
        'Atlantic/Madeira' => 'Ora Europei de Vest (Madeira)',
        'Atlantic/Reykjavik' => 'Ora de Greenwhich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Ora Georgiei de Sud (Georgia de Sud)',
        'Atlantic/St_Helena' => 'Ora de Greenwhich (Sf. Elena)',
        'Atlantic/Stanley' => 'Ora din Insulele Falkland (Stanley)',
        'Australia/Adelaide' => 'Ora Australiei Centrale (Adelaide)',
        'Australia/Brisbane' => 'Ora Australiei Orientale (Brisbane)',
        'Australia/Broken_Hill' => 'Ora Australiei Centrale (Broken Hill)',
        'Australia/Currie' => 'Ora Australiei Orientale (Currie)',
        'Australia/Darwin' => 'Ora Australiei Centrale (Darwin)',
        'Australia/Eucla' => 'Ora Australiei Central Occidentale (Eucla)',
        'Australia/Hobart' => 'Ora Australiei Orientale (Hobart)',
        'Australia/Lindeman' => 'Ora Australiei Orientale (Lindeman)',
        'Australia/Lord_Howe' => 'Ora din Lord Howe',
        'Australia/Melbourne' => 'Ora Australiei Orientale (Melbourne)',
        'Australia/Perth' => 'Ora Australiei Occidentale (Perth)',
        'Australia/Sydney' => 'Ora Australiei Orientale (Sydney)',
        'CST6CDT' => 'Ora centrală nord-americană',
        'EST5EDT' => 'Ora orientală nord-americană',
        'Etc/GMT' => 'Ora de Greenwhich',
        'Etc/UTC' => 'Timpul universal coordonat',
        'Europe/Amsterdam' => 'Ora Europei Centrale (Amsterdam)',
        'Europe/Andorra' => 'Ora Europei Centrale (Andorra)',
        'Europe/Astrakhan' => 'Ora Moscovei (Astrahan)',
        'Europe/Athens' => 'Ora Europei de Est (Atena)',
        'Europe/Belgrade' => 'Ora Europei Centrale (Belgrad)',
        'Europe/Berlin' => 'Ora Europei Centrale (Berlin)',
        'Europe/Bratislava' => 'Ora Europei Centrale (Bratislava)',
        'Europe/Brussels' => 'Ora Europei Centrale (Bruxelles)',
        'Europe/Bucharest' => 'Ora Europei de Est (București)',
        'Europe/Budapest' => 'Ora Europei Centrale (Budapesta)',
        'Europe/Busingen' => 'Ora Europei Centrale (Busingen)',
        'Europe/Chisinau' => 'Ora Europei de Est (Chișinău)',
        'Europe/Copenhagen' => 'Ora Europei Centrale (Copenhaga)',
        'Europe/Dublin' => 'Ora de Greenwhich (Dublin)',
        'Europe/Gibraltar' => 'Ora Europei Centrale (Gibraltar)',
        'Europe/Guernsey' => 'Ora de Greenwhich (Guernsey)',
        'Europe/Helsinki' => 'Ora Europei de Est (Helsinki)',
        'Europe/Isle_of_Man' => 'Ora de Greenwhich (Insula Man)',
        'Europe/Istanbul' => 'Ora din Turcia (Istanbul)',
        'Europe/Jersey' => 'Ora de Greenwhich (Jersey)',
        'Europe/Kaliningrad' => 'Ora Europei de Est (Kaliningrad)',
        'Europe/Kiev' => 'Ora Europei de Est (Kiev)',
        'Europe/Kirov' => 'Ora din Rusia (Kirov)',
        'Europe/Lisbon' => 'Ora Europei de Vest (Lisabona)',
        'Europe/Ljubljana' => 'Ora Europei Centrale (Ljubljana)',
        'Europe/London' => 'Ora de Greenwhich (Londra)',
        'Europe/Luxembourg' => 'Ora Europei Centrale (Luxemburg)',
        'Europe/Madrid' => 'Ora Europei Centrale (Madrid)',
        'Europe/Malta' => 'Ora Europei Centrale (Malta)',
        'Europe/Mariehamn' => 'Ora Europei de Est (Mariehamn)',
        'Europe/Minsk' => 'Ora Moscovei (Minsk)',
        'Europe/Monaco' => 'Ora Europei Centrale (Monaco)',
        'Europe/Moscow' => 'Ora Moscovei (Moscova)',
        'Europe/Oslo' => 'Ora Europei Centrale (Oslo)',
        'Europe/Paris' => 'Ora Europei Centrale (Paris)',
        'Europe/Podgorica' => 'Ora Europei Centrale (Podgorița)',
        'Europe/Prague' => 'Ora Europei Centrale (Praga)',
        'Europe/Riga' => 'Ora Europei de Est (Riga)',
        'Europe/Rome' => 'Ora Europei Centrale (Roma)',
        'Europe/Samara' => 'Ora din Samara',
        'Europe/San_Marino' => 'Ora Europei Centrale (San Marino)',
        'Europe/Sarajevo' => 'Ora Europei Centrale (Sarajevo)',
        'Europe/Saratov' => 'Ora Moscovei (Saratov)',
        'Europe/Simferopol' => 'Ora Moscovei (Simferopol)',
        'Europe/Skopje' => 'Ora Europei Centrale (Skopje)',
        'Europe/Sofia' => 'Ora Europei de Est (Sofia)',
        'Europe/Stockholm' => 'Ora Europei Centrale (Stockholm)',
        'Europe/Tallinn' => 'Ora Europei de Est (Tallinn)',
        'Europe/Tirane' => 'Ora Europei Centrale (Tirana)',
        'Europe/Ulyanovsk' => 'Ora Moscovei (Ulianovsk)',
        'Europe/Uzhgorod' => 'Ora Europei de Est (Ujhorod)',
        'Europe/Vaduz' => 'Ora Europei Centrale (Vaduz)',
        'Europe/Vatican' => 'Ora Europei Centrale (Vatican)',
        'Europe/Vienna' => 'Ora Europei Centrale (Viena)',
        'Europe/Vilnius' => 'Ora Europei de Est (Vilnius)',
        'Europe/Volgograd' => 'Ora din Volgograd',
        'Europe/Warsaw' => 'Ora Europei Centrale (Varșovia)',
        'Europe/Zagreb' => 'Ora Europei Centrale (Zagreb)',
        'Europe/Zaporozhye' => 'Ora Europei de Est (Zaporoje)',
        'Europe/Zurich' => 'Ora Europei Centrale (Zürich)',
        'Indian/Antananarivo' => 'Ora Africii Orientale (Antananarivo)',
        'Indian/Chagos' => 'Ora Oceanului Indian (Chagos)',
        'Indian/Christmas' => 'Ora din Insula Christmas',
        'Indian/Cocos' => 'Ora Insulelor Cocos',
        'Indian/Comoro' => 'Ora Africii Orientale (Comore)',
        'Indian/Kerguelen' => 'Ora din Teritoriile Australe și Antarctice Franceze (Kerguelen)',
        'Indian/Mahe' => 'Ora din Seychelles (Mahe)',
        'Indian/Maldives' => 'Ora din Maldive',
        'Indian/Mauritius' => 'Ora din Mauritius',
        'Indian/Mayotte' => 'Ora Africii Orientale (Mayotte)',
        'Indian/Reunion' => 'Ora din Reunion (Réunion)',
        'MST7MDT' => 'Ora zonei montane nord-americane',
        'PST8PDT' => 'Ora zonei Pacific nord-americane',
        'Pacific/Apia' => 'Ora din Apia',
        'Pacific/Auckland' => 'Ora Noii Zeelande (Auckland)',
        'Pacific/Bougainville' => 'Ora din Papua Noua Guinee (Bougainville)',
        'Pacific/Chatham' => 'Ora din Chatham',
        'Pacific/Easter' => 'Ora din Insula Paștelui',
        'Pacific/Efate' => 'Ora din Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Ora Insulelor Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Ora din Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Ora din Fiji',
        'Pacific/Funafuti' => 'Ora din Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Ora din Galapagos',
        'Pacific/Gambier' => 'Ora din Gambier',
        'Pacific/Guadalcanal' => 'Ora Insulelor Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Ora din Chamorro (Guam)',
        'Pacific/Honolulu' => 'Ora din Hawaii-Aleutine (Honolulu)',
        'Pacific/Johnston' => 'Ora din Hawaii-Aleutine (Johnston)',
        'Pacific/Kiritimati' => 'Ora din Insulele Line (Kiritimati)',
        'Pacific/Kosrae' => 'Ora din Kosrae',
        'Pacific/Kwajalein' => 'Ora Insulelor Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Ora Insulelor Marshall (Majuro)',
        'Pacific/Marquesas' => 'Ora Insulelor Marchize',
        'Pacific/Midway' => 'Ora din Samoa (Midway)',
        'Pacific/Nauru' => 'Ora din Nauru',
        'Pacific/Niue' => 'Ora din Niue',
        'Pacific/Norfolk' => 'Ora Insulei Norfolk',
        'Pacific/Noumea' => 'Ora Noii Caledonii (Noumea)',
        'Pacific/Pago_Pago' => 'Ora din Samoa (Pago Pago)',
        'Pacific/Palau' => 'Ora din Palau',
        'Pacific/Pitcairn' => 'Ora din Pitcairn (Insula Pitcairn)',
        'Pacific/Ponape' => 'Ora din Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Ora din Papua Noua Guinee (Port Moresby)',
        'Pacific/Rarotonga' => 'Ora Insulelor Cook (Rarotonga)',
        'Pacific/Saipan' => 'Ora din Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Ora din Tahiti',
        'Pacific/Tarawa' => 'Ora Insulelor Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Ora din Tonga (Tongatapu)',
        'Pacific/Truk' => 'Ora din Chuuk',
        'Pacific/Wake' => 'Ora Insulei Wake',
        'Pacific/Wallis' => 'Ora din Wallis și Futuna',
    ],
    'Meta' => [
    ],
];
