<?php

return [
    'Names' => [
        'en_MS' => 'الإنجليزية (مونتيسيرات)',
        'es_UY' => 'الإسبانية (أوروغواي)',
        'lo' => 'اللاوو',
        'lo_LA' => 'اللاوو (لاوس)',
        'sh' => 'الكرواتية الصربية',
        'sh_BA' => 'الكرواتية الصربية (البوسنة والهرسك)',
        'sw' => 'السواحيلية',
        'sw_CD' => 'السواحيلية (الكونغو - كينشاسا)',
        'sw_KE' => 'السواحيلية (كينيا)',
        'sw_TZ' => 'السواحيلية (تنزانيا)',
        'sw_UG' => 'السواحيلية (أوغندا)',
        'ti' => 'التيغرينية',
        'ti_ER' => 'التيغرينية (إريتريا)',
        'ti_ET' => 'التيغرينية (إثيوبيا)',
    ],
];
