<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ග්‍රිනිච් මධ්‍යම වේලාව (අබිජාන්)',
        'Africa/Accra' => 'ග්‍රිනිච් මධ්‍යම වේලාව (අක්රා)',
        'Africa/Addis_Ababa' => 'නැගෙනහිර අප්‍රිකානු වේලාව (අඩිස් අබාබා)',
        'Africa/Algiers' => 'මධ්‍යම යුරෝපීය වේලාව (ඇල්ජියර්ස්)',
        'Africa/Asmera' => 'නැගෙනහිර අප්‍රිකානු වේලාව (අස්මාරා)',
        'Africa/Bamako' => 'ග්‍රිනිච් මධ්‍යම වේලාව (බමකො)',
        'Africa/Bangui' => 'බටහිර අප්‍රිකානු වේලාව (බන්ගුයි)',
        'Africa/Banjul' => 'ග්‍රිනිච් මධ්‍යම වේලාව (බන්ජුල්)',
        'Africa/Bissau' => 'ග්‍රිනිච් මධ්‍යම වේලාව (බිසෝ)',
        'Africa/Blantyre' => 'මධ්‍යම අප්‍රිකානු වේලාව (බ්ලන්ටයර්)',
        'Africa/Brazzaville' => 'බටහිර අප්‍රිකානු වේලාව (බ්‍රසාවිල්)',
        'Africa/Bujumbura' => 'මධ්‍යම අප්‍රිකානු වේලාව (බුජුම්බුරා)',
        'Africa/Cairo' => 'නැගෙනහිර යුරෝපීය වේලාව (කයිරෝ)',
        'Africa/Casablanca' => 'බටහිර යුරෝපීය වේලාව (කැසබ්ලන්කා)',
        'Africa/Ceuta' => 'මධ්‍යම යුරෝපීය වේලාව (සෙයුටා)',
        'Africa/Conakry' => 'ග්‍රිනිච් මධ්‍යම වේලාව (කොනක්‍රි)',
        'Africa/Dakar' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ඩකර්)',
        'Africa/Dar_es_Salaam' => 'නැගෙනහිර අප්‍රිකානු වේලාව (දාර් එස් සලාම්)',
        'Africa/Djibouti' => 'නැගෙනහිර අප්‍රිකානු වේලාව (ජිබුටි)',
        'Africa/Douala' => 'බටහිර අප්‍රිකානු වේලාව (දෞඅලා)',
        'Africa/El_Aaiun' => 'බටහිර යුරෝපීය වේලාව (එල් ආයුන්)',
        'Africa/Freetown' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ෆ්‍රීටවුන්)',
        'Africa/Gaborone' => 'මධ්‍යම අප්‍රිකානු වේලාව (ගැබරෝන්)',
        'Africa/Harare' => 'මධ්‍යම අප්‍රිකානු වේලාව (හරාරේ)',
        'Africa/Johannesburg' => 'දකුණු අප්‍රිකානු වේලාව (ජොහන්නස්බර්ග්)',
        'Africa/Juba' => 'මධ්‍යම අප්‍රිකානු වේලාව (ජුබා)',
        'Africa/Kampala' => 'නැගෙනහිර අප්‍රිකානු වේලාව (කම්පාලා)',
        'Africa/Khartoum' => 'මධ්‍යම අප්‍රිකානු වේලාව (කාර්ටොම්)',
        'Africa/Kigali' => 'මධ්‍යම අප්‍රිකානු වේලාව (කිගාලි)',
        'Africa/Kinshasa' => 'බටහිර අප්‍රිකානු වේලාව (කින්ශාසා)',
        'Africa/Lagos' => 'බටහිර අප්‍රිකානු වේලාව (ලාගෝස්)',
        'Africa/Libreville' => 'බටහිර අප්‍රිකානු වේලාව (ලිබ්රවිල්)',
        'Africa/Lome' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ලෝම්)',
        'Africa/Luanda' => 'බටහිර අප්‍රිකානු වේලාව (ලුවන්ඩා)',
        'Africa/Lubumbashi' => 'මධ්‍යම අප්‍රිකානු වේලාව (ලුබුම්බාශි)',
        'Africa/Lusaka' => 'මධ්‍යම අප්‍රිකානු වේලාව (ලුසාකා)',
        'Africa/Malabo' => 'බටහිර අප්‍රිකානු වේලාව (මලබෝ)',
        'Africa/Maputo' => 'මධ්‍යම අප්‍රිකානු වේලාව (මපුටෝ)',
        'Africa/Maseru' => 'දකුණු අප්‍රිකානු වේලාව (මසේරු)',
        'Africa/Mbabane' => 'දකුණු අප්‍රිකානු වේලාව (ම්බබානේ)',
        'Africa/Mogadishu' => 'නැගෙනහිර අප්‍රිකානු වේලාව (මොගඩිෂු)',
        'Africa/Monrovia' => 'ග්‍රිනිච් මධ්‍යම වේලාව (මොන්රොවියා)',
        'Africa/Nairobi' => 'නැගෙනහිර අප්‍රිකානු වේලාව (නයිරෝබි)',
        'Africa/Ndjamena' => 'බටහිර අප්‍රිකානු වේලාව (ද්ජමෙනා)',
        'Africa/Niamey' => 'බටහිර අප්‍රිකානු වේලාව (නියාමේ)',
        'Africa/Nouakchott' => 'ග්‍රිනිච් මධ්‍යම වේලාව (නුආක්චොට්)',
        'Africa/Ouagadougou' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ඔආගඩොගො)',
        'Africa/Porto-Novo' => 'බටහිර අප්‍රිකානු වේලාව (පොර්තෝ-නොවෝ)',
        'Africa/Sao_Tome' => 'ග්‍රිනිච් මධ්‍යම වේලාව (සාඕ තෝම්)',
        'Africa/Tripoli' => 'නැගෙනහිර යුරෝපීය වේලාව (ට්‍රිපොලි)',
        'Africa/Tunis' => 'මධ්‍යම යුරෝපීය වේලාව (ටියුනිස්)',
        'Africa/Windhoek' => 'මධ්‍යම අප්‍රිකානු වේලාව (වින්ඩ්හොඑක්)',
        'America/Adak' => 'හවායි-අලෙයුතියාන් වේලාව (ඇඩක්)',
        'America/Anchorage' => 'ඇලස්කා වේලාව (ඇනකොරාජ්)',
        'America/Anguilla' => 'අත්ලාන්තික් වේලාව (ඇන්ගුයිලාව)',
        'America/Antigua' => 'අත්ලාන්තික් වේලාව (ඇන්ටිගුවා)',
        'America/Araguaina' => 'බ්‍රසීල වේලාව (ඇරගුඅයිනා)',
        'America/Argentina/La_Rioja' => 'ආර්ජන්ටිනා වේලාව (ලා රිජෝලා)',
        'America/Argentina/Rio_Gallegos' => 'ආර්ජන්ටිනා වේලාව (රියෝ ගලෙගොස්)',
        'America/Argentina/Salta' => 'ආර්ජන්ටිනා වේලාව (සොල්ටා)',
        'America/Argentina/San_Juan' => 'ආර්ජන්ටිනා වේලාව (සැන් ජුවාන්)',
        'America/Argentina/San_Luis' => 'ආර්ජන්ටිනා වේලාව (සැන් ලුවිස්)',
        'America/Argentina/Tucuman' => 'ආර්ජන්ටිනා වේලාව (ටුකුමන්)',
        'America/Argentina/Ushuaia' => 'ආර්ජන්ටිනා වේලාව (උෂුඅයියා)',
        'America/Aruba' => 'අත්ලාන්තික් වේලාව (අරූබා)',
        'America/Asuncion' => 'පැරගුවේ වේලාව (අසුන්සියොන්)',
        'America/Bahia' => 'බ්‍රසීල වේලාව (බහියා)',
        'America/Bahia_Banderas' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (බහියා බන්දෙරාස්)',
        'America/Barbados' => 'අත්ලාන්තික් වේලාව (බාබඩෝස්)',
        'America/Belem' => 'බ්‍රසීල වේලාව (බෙලෙම්)',
        'America/Belize' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (බෙලීස්)',
        'America/Blanc-Sablon' => 'අත්ලාන්තික් වේලාව (බ්ලැන්ක්-සැබ්ලන්)',
        'America/Boa_Vista' => 'ඇමර්සන් වේලාව (බොආ විස්ටා)',
        'America/Bogota' => 'කොලොම්බියා වේලාව (බොගොටා)',
        'America/Boise' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (බොයිසි)',
        'America/Buenos_Aires' => 'ආර්ජන්ටිනා වේලාව (බුවනෝස් අයර්ස්)',
        'America/Cambridge_Bay' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (කේම්බ්‍රිජ් බොක්ක)',
        'America/Campo_Grande' => 'ඇමර්සන් වේලාව (කම්පෝ ග්‍රෑන්ඩ්)',
        'America/Cancun' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (කැන්කුන්)',
        'America/Caracas' => 'වෙනිසියුලා වේලාව (කරකස්)',
        'America/Catamarca' => 'ආර්ජන්ටිනා වේලාව (කටමර්කා)',
        'America/Cayenne' => 'ප්‍රංශ ගයනා වේලාව (කේයෙන්)',
        'America/Cayman' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (කේමන්)',
        'America/Chicago' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (චිකාගෝ)',
        'America/Chihuahua' => 'මෙක්සිකෝ පැසිෆික් වේලාව (චිහුආහුආ)',
        'America/Coral_Harbour' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ඇටිකොකන්)',
        'America/Cordoba' => 'ආර්ජන්ටිනා වේලාව (කොර්දොබා)',
        'America/Costa_Rica' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (කොස්ටරිකා)',
        'America/Creston' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ක්‍රෙස්ටන්)',
        'America/Cuiaba' => 'ඇමර්සන් වේලාව (කුයිඅබා)',
        'America/Curacao' => 'අත්ලාන්තික් වේලාව (කුරකාවෝ)',
        'America/Danmarkshavn' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ඩෙන්මාර්ක්ශව්න්)',
        'America/Dawson' => 'යුකොන් වේලාව (ඩෝසන්)',
        'America/Dawson_Creek' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ඩෝසන් ක්‍රීක්)',
        'America/Denver' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ඩෙන්වර්)',
        'America/Detroit' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ඩෙත්රුවා)',
        'America/Dominica' => 'අත්ලාන්තික් වේලාව (ඩොමිනිකා)',
        'America/Edmonton' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (එඩ්මන්ටන්)',
        'America/Eirunepe' => 'බ්‍රසීලය වේලාව (එයිරුනේප්)',
        'America/El_Salvador' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (එල්සැල්වදෝර්)',
        'America/Fort_Nelson' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ෆෝට් නෙල්සන්)',
        'America/Fortaleza' => 'බ්‍රසීල වේලාව (ෆොර්ටලේසා)',
        'America/Glace_Bay' => 'අත්ලාන්තික් වේලාව (ග්ලේස් බොක්ක)',
        'America/Godthab' => 'බටහිර ග්‍රීන්ලන්ත වේලාව (නූක්)',
        'America/Goose_Bay' => 'අත්ලාන්තික් වේලාව (ගූස් බොක්ක)',
        'America/Grand_Turk' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ග්රෑන්ඩ් ටර්ක්)',
        'America/Grenada' => 'අත්ලාන්තික් වේලාව (ග්‍රැනඩා)',
        'America/Guadeloupe' => 'අත්ලාන්තික් වේලාව (ග්වාඩ්ලෝප්)',
        'America/Guatemala' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (ගෝතමාලාව)',
        'America/Guayaquil' => 'ඉක්වදෝර් වේලාව (ගුඅයාකුයිල්)',
        'America/Guyana' => 'ගයනා වේලාව (ගයනාව)',
        'America/Halifax' => 'අත්ලාන්තික් වේලාව (හලිෆැක්ස්)',
        'America/Havana' => 'කියුබානු වේලාව (හවානා)',
        'America/Hermosillo' => 'මෙක්සිකෝ පැසිෆික් වේලාව (හෙමොසිලෝ)',
        'America/Indiana/Knox' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (නොක්ස්, ඉන්දියානා)',
        'America/Indiana/Marengo' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (මරෙන්ගෝ, ඉන්දියානා)',
        'America/Indiana/Petersburg' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (පීටර්ස්බර්ග්, ඉන්දියානා)',
        'America/Indiana/Tell_City' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (ටෙල් නගරය, ඉන්දියානා)',
        'America/Indiana/Vevay' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (වෙවේ, ඉන්දියානා)',
        'America/Indiana/Vincennes' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (වින්සනස්, ඉන්දියානා)',
        'America/Indiana/Winamac' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (විනමැක්, ඉන්දියානා)',
        'America/Indianapolis' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ඉන්ඩියානපොලිස්)',
        'America/Inuvik' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ඉනුවික්)',
        'America/Iqaluit' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ඉකාලුයිට්)',
        'America/Jamaica' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ජැමෙයිකා)',
        'America/Jujuy' => 'ආර්ජන්ටිනා වේලාව (ජුජුයි)',
        'America/Juneau' => 'ඇලස්කා වේලාව (ජූනෝ)',
        'America/Kentucky/Monticello' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (මොන්ටිසෙලෝ, කෙන්ටකි)',
        'America/Kralendijk' => 'අත්ලාන්තික් වේලාව (ක්‍රලෙන්දිජ්ක්)',
        'America/La_Paz' => 'බොලිවියා වේලාව (ලා පස්)',
        'America/Lima' => 'පේරු වේලාව (ලීමා)',
        'America/Los_Angeles' => 'උතුරු ඇමරිකානු පැසිෆික් වේලාව (ලොස් ඇන්ජලීස්)',
        'America/Louisville' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ලුවිස්විල්)',
        'America/Lower_Princes' => 'අත්ලාන්තික් වේලාව (ලෝවර් ප්‍රින්සස් ක්වාටර්)',
        'America/Maceio' => 'බ්‍රසීල වේලාව (මසේයියෝ)',
        'America/Managua' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මනගුආ)',
        'America/Manaus' => 'ඇමර්සන් වේලාව (මැනෝස්)',
        'America/Marigot' => 'අත්ලාන්තික් වේලාව (මැරිගොට්)',
        'America/Martinique' => 'අත්ලාන්තික් වේලාව (මාටිනික්)',
        'America/Matamoros' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මටමොරොස්)',
        'America/Mazatlan' => 'මෙක්සිකෝ පැසිෆික් වේලාව (මසට්ලාන්)',
        'America/Mendoza' => 'ආර්ජන්ටිනා වේලාව (මෙන්ඩෝසා)',
        'America/Menominee' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මෙනොමිනී)',
        'America/Merida' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මෙරිඩා)',
        'America/Metlakatla' => 'ඇලස්කා වේලාව (මෙට්ලකට්ලා)',
        'America/Mexico_City' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මෙක්සිකෝ නගරය)',
        'America/Miquelon' => 'ශාන්ත පියරේ සහ මැකෝලන් වේලාව (මිකියුලන්)',
        'America/Moncton' => 'අත්ලාන්තික් වේලාව (මොන්ක්ටන්)',
        'America/Monterrey' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මොන්ටෙරේ)',
        'America/Montevideo' => 'උරුගුවේ වේලාව (මොන්ටෙවිඩියෝ)',
        'America/Montreal' => 'කැනඩාව වේලාව (Montreal)',
        'America/Montserrat' => 'අත්ලාන්තික් වේලාව (මොන්ට්සේරාට්)',
        'America/Nassau' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (නස්සෝ)',
        'America/New_York' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (නිව්යෝක්)',
        'America/Nipigon' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (නිපිගන්)',
        'America/Nome' => 'ඇලස්කා වේලාව (නෝම්)',
        'America/Noronha' => 'ෆර්නැන්ඩෝ ඩි නොරොන්හා වේලාව',
        'America/North_Dakota/Beulah' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (බියුලා, උතුරු ඩකෝටා)',
        'America/North_Dakota/Center' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (මධ්‍යම, උතුරු ඩකෝටා)',
        'America/North_Dakota/New_Salem' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (නව සලෙම්ම, උතුරු ඩකෝටා)',
        'America/Ojinaga' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ඔජිනගා)',
        'America/Panama' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (පැනමා)',
        'America/Pangnirtung' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (පැන්නීටන්)',
        'America/Paramaribo' => 'සුරිනාම වේලාව (පැරාමරිබෝ)',
        'America/Phoenix' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (ෆීනික්ස්)',
        'America/Port-au-Prince' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (පොර්ට්-ඕ-ප්‍රින්ස්)',
        'America/Port_of_Spain' => 'අත්ලාන්තික් වේලාව (පොර්ට් ඔෆ් ස්පෙයින්)',
        'America/Porto_Velho' => 'ඇමර්සන් වේලාව (පොර්තෝ වෙල්හෝ)',
        'America/Puerto_Rico' => 'අත්ලාන්තික් වේලාව (පුවටොරිකෝව)',
        'America/Punta_Arenas' => 'චිලී වේලාව (පුන්ටා ඇරිනාස්)',
        'America/Rainy_River' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (රෙයිනි ගඟ)',
        'America/Rankin_Inlet' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (රැන්කින් පිවිසුම)',
        'America/Recife' => 'බ්‍රසීල වේලාව (රෙසිෆ්)',
        'America/Regina' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (රෙජිනා)',
        'America/Resolute' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (රෙසොලුට්)',
        'America/Rio_Branco' => 'බ්‍රසීලය වේලාව (රියෝ බ්‍රන්කෝ)',
        'America/Santa_Isabel' => 'වයඹ මෙක්සිකෝ වේලාව (සැන්ටා ඉසබෙල්)',
        'America/Santarem' => 'බ්‍රසීල වේලාව (සන්ටරේම්)',
        'America/Santiago' => 'චිලී වේලාව (සන්තියාගෝ)',
        'America/Santo_Domingo' => 'අත්ලාන්තික් වේලාව (සැන්ටෝ ඩොමින්ගෝ)',
        'America/Sao_Paulo' => 'බ්‍රසීල වේලාව (සාවෝ පෝලො)',
        'America/Scoresbysund' => 'නැගෙනහිර ග්‍රීන්ලන්ත වේලාව (ඉටොකොර්ටෝමිට්)',
        'America/Sitka' => 'ඇලස්කා වේලාව (සිට්කා)',
        'America/St_Barthelemy' => 'අත්ලාන්තික් වේලාව (ශාන්ත බර්තලෙමි)',
        'America/St_Johns' => 'නිව්ෆවුන්ලන්ත වේලාව (ශාන්ත ජෝන්ගේ)',
        'America/St_Kitts' => 'අත්ලාන්තික් වේලාව (ශාන්ත කිට්ස්)',
        'America/St_Lucia' => 'අත්ලාන්තික් වේලාව (ශාන්ත ලුසියා)',
        'America/St_Thomas' => 'අත්ලාන්තික් වේලාව (ශාන්ත තෝමස්)',
        'America/St_Vincent' => 'අත්ලාන්තික් වේලාව (ශාන්ත වින්ට්සන්)',
        'America/Swift_Current' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (ස්විෆ්ට් කරන්ට්)',
        'America/Tegucigalpa' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (ටෙගුසිගල්පා)',
        'America/Thule' => 'අත්ලාන්තික් වේලාව (තුලේ)',
        'America/Thunder_Bay' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (තන්ඩර් බොක්ක)',
        'America/Tijuana' => 'උතුරු ඇමරිකානු පැසිෆික් වේලාව (ටිජුආනා)',
        'America/Toronto' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව (ටොරන්ටෝ)',
        'America/Tortola' => 'අත්ලාන්තික් වේලාව (ටොර්ටෝලා)',
        'America/Vancouver' => 'උතුරු ඇමරිකානු පැසිෆික් වේලාව (වැන්කුවර්)',
        'America/Whitehorse' => 'යුකොන් වේලාව (වයිට්හෝර්ස්)',
        'America/Winnipeg' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව (විනිපෙග්)',
        'America/Yakutat' => 'ඇලස්කා වේලාව (යකුටට්)',
        'America/Yellowknife' => 'උතුරු ඇමරිකානු කඳුකර වේලාව (යෙලෝනයිෆ්)',
        'Antarctica/Casey' => 'ඇන්ටාක්ටිකාව වේලාව (කැසේ)',
        'Antarctica/Davis' => 'ඩාවිස් වේලාව (ඩේවිස්)',
        'Antarctica/DumontDUrville' => 'දුමොන්ත්-ඩ්උර්විල් වේලාව (ඩුමොන්ට් ඩු‘ර්විල්)',
        'Antarctica/Macquarie' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (මක්කුවරි)',
        'Antarctica/Mawson' => 'මොව්සන් වේලාව (මව්සන්)',
        'Antarctica/McMurdo' => 'නවසීලන්ත වේලාව (මැක්මුර්ඩෝ)',
        'Antarctica/Palmer' => 'චිලී වේලාව (පැල්මර්)',
        'Antarctica/Rothera' => 'රොතෙරා වේලාව',
        'Antarctica/Syowa' => 'ස්යෝවා වේලාව (සියෝවා)',
        'Antarctica/Troll' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ට්‍රෝල්)',
        'Antarctica/Vostok' => 'වොස්ටොක් වේලාව',
        'Arctic/Longyearbyen' => 'මධ්‍යම යුරෝපීය වේලාව (ලෝන්ග්ඉයර්බියෙන්)',
        'Asia/Aden' => 'අරාබි වේලාව (ඒඩ්න්)',
        'Asia/Almaty' => 'නැගෙනහිර කසකස්තාන වේලාව (අල්මටි)',
        'Asia/Amman' => 'නැගෙනහිර යුරෝපීය වේලාව (අම්මාන්)',
        'Asia/Anadyr' => 'රුසියාව වේලාව (ඇනාදිය්ර්)',
        'Asia/Aqtau' => 'බටහිර කසකස්තාන වේලාව (අක්ටෝ)',
        'Asia/Aqtobe' => 'බටහිර කසකස්තාන වේලාව (අක්ටෝබ්)',
        'Asia/Ashgabat' => 'ටර්ක්මෙනිස්තාන වේලාව (අශ්ගබැට්)',
        'Asia/Atyrau' => 'බටහිර කසකස්තාන වේලාව (ඇටිරවු)',
        'Asia/Baghdad' => 'අරාබි වේලාව (බැග්ඩෑඩ්)',
        'Asia/Bahrain' => 'අරාබි වේලාව (බහරේන්)',
        'Asia/Baku' => 'අසර්බයිජාන් වේලාව (බාකු)',
        'Asia/Bangkok' => 'ඉන්දුචීන වේලාව (බැංකොක්)',
        'Asia/Barnaul' => 'රුසියාව වේලාව (බර්නෞල්)',
        'Asia/Beirut' => 'නැගෙනහිර යුරෝපීය වේලාව (බීරුට්)',
        'Asia/Bishkek' => 'කිර්ගිස්තාන වේලාව (බිශ්කෙක්)',
        'Asia/Brunei' => 'බෘනායි දරුස්සලාම් වේලාව (බෲනායි)',
        'Asia/Calcutta' => 'ඉන්දියානු වේලාව (කල්කටා)',
        'Asia/Chita' => 'යකුට්ස්ක් වේලාව (චිටා)',
        'Asia/Choibalsan' => 'උලාන් බාටර් වේලාව (චොයිබල්සාන්)',
        'Asia/Colombo' => 'ඉන්දියානු වේලාව (කොළඹ)',
        'Asia/Damascus' => 'නැගෙනහිර යුරෝපීය වේලාව (ඩැමස්කස්)',
        'Asia/Dhaka' => 'බංගලාදේශ වේලාව (ඩකා)',
        'Asia/Dili' => 'නැගෙනහිර ටිමෝර් වේලාව (ඩිලි)',
        'Asia/Dubai' => 'ගල්ෆ් වේලාව (ඩුබායි)',
        'Asia/Dushanbe' => 'ටජිකිස්තාන වේලාව (ඩුශන්බේ)',
        'Asia/Famagusta' => 'නැගෙනහිර යුරෝපීය වේලාව (ෆැමගුස්ටා)',
        'Asia/Gaza' => 'නැගෙනහිර යුරෝපීය වේලාව (ගාසා)',
        'Asia/Hebron' => 'නැගෙනහිර යුරෝපීය වේලාව (හෙබ්රෝන්)',
        'Asia/Hong_Kong' => 'හොංකොං වේලාව',
        'Asia/Hovd' => 'හොව්ඩ් වේලාව',
        'Asia/Irkutsk' => 'ඉර්කුට්ස්ක් වේලාව (ඉරකුට්ස්ක්)',
        'Asia/Jakarta' => 'බටහිර ඉන්දුනීසියානු වේලාව (ජකර්තා)',
        'Asia/Jayapura' => 'නැගෙනහිර ඉන්දුනීසියානු වේලාව (ජයපුර)',
        'Asia/Jerusalem' => 'ඊශ්‍රායල වේලාව (ජෙරුසලම)',
        'Asia/Kabul' => 'ඇෆ්ගනිස්ථාන වේලාව (කාබුල්)',
        'Asia/Kamchatka' => 'රුසියාව වේලාව (කම්චට්කා)',
        'Asia/Karachi' => 'පාකිස්ථාන වේලාව (කරච්චිචි)',
        'Asia/Katmandu' => 'නේපාල වේලාව (කත්මන්ඩු)',
        'Asia/Khandyga' => 'යකුට්ස්ක් වේලාව (ඛන්ඩිගා)',
        'Asia/Krasnoyarsk' => 'ක්‍රස්නොයාර්ස්ක් වේලාව (ක්‍රස්නෝයාර්ස්ක්)',
        'Asia/Kuala_Lumpur' => 'මැලේසියානු වේලාව (ක්වාලාලම්පූර්)',
        'Asia/Kuching' => 'මැලේසියානු වේලාව (කුචිං)',
        'Asia/Kuwait' => 'අරාබි වේලාව (කුවේට්)',
        'Asia/Macau' => 'චීන වේලාව (මැකාවු)',
        'Asia/Magadan' => 'මෙගඩන් වේලාව (මගඩන්)',
        'Asia/Makassar' => 'මධ්‍යම ඉන්දුනීසියානු වේලාව (මක්ස්සාර්)',
        'Asia/Manila' => 'පිලිපීන වේලාව (මැනිලා)',
        'Asia/Muscat' => 'ගල්ෆ් වේලාව (මස්කට්)',
        'Asia/Nicosia' => 'නැගෙනහිර යුරෝපීය වේලාව (නිකෝසියා)',
        'Asia/Novokuznetsk' => 'ක්‍රස්නොයාර්ස්ක් වේලාව (නොවොකුස්නේට්ස්ක්)',
        'Asia/Novosibirsk' => 'නොවසිබිර්ස්ක් වේලාව (නොවොසිබර්ස්ක්)',
        'Asia/Omsk' => 'ඔම්ස්ක් වේලාව',
        'Asia/Oral' => 'බටහිර කසකස්තාන වේලාව (ඔරාල්)',
        'Asia/Phnom_Penh' => 'ඉන්දුචීන වේලාව (නොම් පෙන්)',
        'Asia/Pontianak' => 'බටහිර ඉන්දුනීසියානු වේලාව (පොන්ටියනක්)',
        'Asia/Pyongyang' => 'කොරියානු වේලාව (ප්යෝන්ග්යැන්ග්)',
        'Asia/Qatar' => 'අරාබි වේලාව (කටාර්)',
        'Asia/Qostanay' => 'නැගෙනහිර කසකස්තාන වේලාව (කොස්තානේ)',
        'Asia/Qyzylorda' => 'බටහිර කසකස්තාන වේලාව (ක්යිසිලෝර්ඩා)',
        'Asia/Rangoon' => 'මියන්මාර් වේලාව (රැංගුන්)',
        'Asia/Riyadh' => 'අරාබි වේලාව (රියාද්)',
        'Asia/Saigon' => 'ඉන්දුචීන වේලාව (හෝචි මිං නගරය)',
        'Asia/Sakhalin' => 'සඛලින් වේලාව (සක්හලින්)',
        'Asia/Samarkand' => 'උස්බෙකිස්තාන වේලාව (සාමාර්කන්ඩ්)',
        'Asia/Seoul' => 'කොරියානු වේලාව (සෝල්)',
        'Asia/Shanghai' => 'චීන වේලාව (ෂැන්හයි)',
        'Asia/Singapore' => 'සිංගප්පුරු වේලාව (සිංගප්පූරුව)',
        'Asia/Srednekolymsk' => 'මෙගඩන් වේලාව (ශ්‍රෙඩ්නෙකෝලිම්සක්)',
        'Asia/Taipei' => 'තායිපේ වේලාව (තායිපෙ)',
        'Asia/Tashkent' => 'උස්බෙකිස්තාන වේලාව (ටෂ්කෙන්ට්)',
        'Asia/Tbilisi' => 'ජෝර්ජියානු වේලාව (ට්බිලිසි)',
        'Asia/Tehran' => 'ඉරාන වේලාව (ටෙහෙරාන්)',
        'Asia/Thimphu' => 'භුතාන වේලාව (තිම්පු)',
        'Asia/Tokyo' => 'ජපාන වේලාව (ටෝකියෝ)',
        'Asia/Tomsk' => 'රුසියාව වේලාව (ටොම්ස්ක්)',
        'Asia/Ulaanbaatar' => 'උලාන් බාටර් වේලාව (උලාන්බාටර්)',
        'Asia/Urumqi' => 'චීනය වේලාව (උරුම්කි)',
        'Asia/Ust-Nera' => 'ව්ලදිවෝස්ටෝක් වේලාව (උස්ට්-නෙරා)',
        'Asia/Vientiane' => 'ඉන්දුචීන වේලාව (වියැන්ටියන්)',
        'Asia/Vladivostok' => 'ව්ලදිවෝස්ටෝක් වේලාව (ව්ලඩිවොස්ටොක්)',
        'Asia/Yakutsk' => 'යකුට්ස්ක් වේලාව',
        'Asia/Yekaterinburg' => 'යෙකටෙරින්බර්ග් වේලාව (යෙකටරින්බර්ග්)',
        'Asia/Yerevan' => 'ආමේනියානු වේලාව (යෙරෙවන්)',
        'Atlantic/Azores' => 'ඇසොර්ස් වේලාව (ඇසොරේ)',
        'Atlantic/Bermuda' => 'අත්ලාන්තික් වේලාව (බර්මියුඩා)',
        'Atlantic/Canary' => 'බටහිර යුරෝපීය වේලාව (කැනරි)',
        'Atlantic/Cape_Verde' => 'කේප්වේඩ් වේලාව (කේප් වර්ඩ්)',
        'Atlantic/Faeroe' => 'බටහිර යුරෝපීය වේලාව (ෆාරෝ)',
        'Atlantic/Madeira' => 'බටහිර යුරෝපීය වේලාව (මඩෙයිරා)',
        'Atlantic/Reykjavik' => 'ග්‍රිනිච් මධ්‍යම වේලාව (රෙයික්ජාවික්)',
        'Atlantic/South_Georgia' => 'දකුණු ජෝජියා වේලාව (දකුණු ජෝර්ජියාව)',
        'Atlantic/St_Helena' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ශා. හෙලේනා)',
        'Atlantic/Stanley' => 'ෆෝක්ලන්ඩ් දූපත් වේලාව (ස්ටැන්ලි)',
        'Australia/Adelaide' => 'මධ්‍යම ඕස්ට්‍රේලියානු වේලාව (ඇඩිලේඩ්)',
        'Australia/Brisbane' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (බ්‍රිස්බේන්)',
        'Australia/Broken_Hill' => 'මධ්‍යම ඕස්ට්‍රේලියානු වේලාව (බ්‍රෝකන් හිල්)',
        'Australia/Currie' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (කුරී)',
        'Australia/Darwin' => 'මධ්‍යම ඕස්ට්‍රේලියානු වේලාව (ඩාවින්)',
        'Australia/Eucla' => 'මධ්‍යම බටහිර ඔස්ට්‍රේලියානු වේලාව (ඉයුක්ලා)',
        'Australia/Hobart' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (හෝබාර්ට්)',
        'Australia/Lindeman' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (ලින්ඩේමන්)',
        'Australia/Lord_Howe' => 'ලෝර්ඩ් හෝව් වේලාව',
        'Australia/Melbourne' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (මෙල්බෝර්න්)',
        'Australia/Perth' => 'බටහිර ඕස්ට්‍රේලියානු වේලාව (පර්ත්)',
        'Australia/Sydney' => 'නැගෙනහිර ඕස්ට්‍රේලියානු වේලාව (සිඩ්නි)',
        'CST6CDT' => 'උතුරු ඇමරිකානු මධ්‍යම වේලාව',
        'EST5EDT' => 'උතුරු ඇමරිකානු නැගෙනහිර වේලාව',
        'Etc/GMT' => 'ග්‍රිනිච් මධ්‍යම වේලාව',
        'Etc/UTC' => 'සමකක්ෂ සාර්ව වේලාව',
        'Europe/Amsterdam' => 'මධ්‍යම යුරෝපීය වේලාව (ඇම්ස්ටර්ඩෑම්)',
        'Europe/Andorra' => 'මධ්‍යම යුරෝපීය වේලාව (ඇන්ඩෝරාව)',
        'Europe/Astrakhan' => 'මොස්කව් වේලාව (අස්ට්‍රඛාන්)',
        'Europe/Athens' => 'නැගෙනහිර යුරෝපීය වේලාව (ඇතැන්ස්)',
        'Europe/Belgrade' => 'මධ්‍යම යුරෝපීය වේලාව (බෙල්ග්‍රේඩ්ඩ්)',
        'Europe/Berlin' => 'මධ්‍යම යුරෝපීය වේලාව (බර්ලින්)',
        'Europe/Bratislava' => 'මධ්‍යම යුරෝපීය වේලාව (බ්‍රටිස්ලවා)',
        'Europe/Brussels' => 'මධ්‍යම යුරෝපීය වේලාව (බ්‍රසල්ස්)',
        'Europe/Bucharest' => 'නැගෙනහිර යුරෝපීය වේලාව (බුකාරෙස්ට්)',
        'Europe/Budapest' => 'මධ්‍යම යුරෝපීය වේලාව (බුඩාපෙස්ට්)',
        'Europe/Busingen' => 'මධ්‍යම යුරෝපීය වේලාව (බුසින්ජෙන්)',
        'Europe/Chisinau' => 'නැගෙනහිර යුරෝපීය වේලාව (චිසිනෝ)',
        'Europe/Copenhagen' => 'මධ්‍යම යුරෝපීය වේලාව (කෝපන්හේගන්)',
        'Europe/Dublin' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ඩබ්ලින්)',
        'Europe/Gibraltar' => 'මධ්‍යම යුරෝපීය වේලාව (ජිබ්රෝල්ටා)',
        'Europe/Guernsey' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ගුවන්සේ)',
        'Europe/Helsinki' => 'නැගෙනහිර යුරෝපීය වේලාව (හෙල්සින්කි)',
        'Europe/Isle_of_Man' => 'ග්‍රිනිච් මධ්‍යම වේලාව (අයිල් ඔෆ් මෑන්)',
        'Europe/Istanbul' => 'තුර්කිය වේලාව (ඉස්තාන්බුල්)',
        'Europe/Jersey' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ජර්සි)',
        'Europe/Kaliningrad' => 'නැගෙනහිර යුරෝපීය වේලාව (කලිනින්ග්‍රෑඩ්)',
        'Europe/Kiev' => 'නැගෙනහිර යුරෝපීය වේලාව (කිව්)',
        'Europe/Kirov' => 'රුසියාව වේලාව (කිරොව්)',
        'Europe/Lisbon' => 'බටහිර යුරෝපීය වේලාව (ලිස්බන්)',
        'Europe/Ljubljana' => 'මධ්‍යම යුරෝපීය වේලාව (ල්ජුබුල්ජනා)',
        'Europe/London' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ලන්ඩන්)',
        'Europe/Luxembourg' => 'මධ්‍යම යුරෝපීය වේලාව (ලක්සැම්බර්ග්)',
        'Europe/Madrid' => 'මධ්‍යම යුරෝපීය වේලාව (මැඩ්රිඩ්)',
        'Europe/Malta' => 'මධ්‍යම යුරෝපීය වේලාව (මෝල්ටා)',
        'Europe/Mariehamn' => 'නැගෙනහිර යුරෝපීය වේලාව (මරියෙහම්න්)',
        'Europe/Minsk' => 'මොස්කව් වේලාව (මින්ස්ක්)',
        'Europe/Monaco' => 'මධ්‍යම යුරෝපීය වේලාව (මොනැකෝ)',
        'Europe/Moscow' => 'මොස්කව් වේලාව',
        'Europe/Oslo' => 'මධ්‍යම යුරෝපීය වේලාව (ඔස්ලෝ)',
        'Europe/Paris' => 'මධ්‍යම යුරෝපීය වේලාව (පැරිස්)',
        'Europe/Podgorica' => 'මධ්‍යම යුරෝපීය වේලාව (පොඩ්ගොරිකා)',
        'Europe/Prague' => 'මධ්‍යම යුරෝපීය වේලාව (ප්‍රෙග්)',
        'Europe/Riga' => 'නැගෙනහිර යුරෝපීය වේලාව (රිගා)',
        'Europe/Rome' => 'මධ්‍යම යුරෝපීය වේලාව (රෝමය)',
        'Europe/Samara' => 'රුසියාව වේලාව (සමරා)',
        'Europe/San_Marino' => 'මධ්‍යම යුරෝපීය වේලාව (සැන් මැරිනෝ)',
        'Europe/Sarajevo' => 'මධ්‍යම යුරෝපීය වේලාව (සරාජෙවෝ)',
        'Europe/Saratov' => 'මොස්කව් වේලාව (සරටොව්)',
        'Europe/Simferopol' => 'මොස්කව් වේලාව (සිම්ෆෙරෝපොල්)',
        'Europe/Skopje' => 'මධ්‍යම යුරෝපීය වේලාව (ස්කොප්ජේ)',
        'Europe/Sofia' => 'නැගෙනහිර යුරෝපීය වේලාව (සොෆියා)',
        'Europe/Stockholm' => 'මධ්‍යම යුරෝපීය වේලාව (ස්ටොක්හෝම්)',
        'Europe/Tallinn' => 'නැගෙනහිර යුරෝපීය වේලාව (ටලින්)',
        'Europe/Tirane' => 'මධ්‍යම යුරෝපීය වේලාව (ටිරානේ)',
        'Europe/Ulyanovsk' => 'මොස්කව් වේලාව (උල්යනොව්ස්ක්)',
        'Europe/Uzhgorod' => 'නැගෙනහිර යුරෝපීය වේලාව (උස්ගොරෝඩ්)',
        'Europe/Vaduz' => 'මධ්‍යම යුරෝපීය වේලාව (වඩුස්)',
        'Europe/Vatican' => 'මධ්‍යම යුරෝපීය වේලාව (වතිකානුව)',
        'Europe/Vienna' => 'මධ්‍යම යුරෝපීය වේලාව (වියනා)',
        'Europe/Vilnius' => 'නැගෙනහිර යුරෝපීය වේලාව (විල්නියුස්)',
        'Europe/Volgograd' => 'වොල්ගොග්‍රාඩ් වේලාව (වොල්ගොග්‍රෑඩ්)',
        'Europe/Warsaw' => 'මධ්‍යම යුරෝපීය වේලාව (වර්සෝ)',
        'Europe/Zagreb' => 'මධ්‍යම යුරෝපීය වේලාව (සග්රෙබ්)',
        'Europe/Zaporozhye' => 'නැගෙනහිර යුරෝපීය වේලාව (සපොරෝසියේ)',
        'Europe/Zurich' => 'මධ්‍යම යුරෝපීය වේලාව (සූරිච්)',
        'Indian/Antananarivo' => 'නැගෙනහිර අප්‍රිකානු වේලාව (ඇන්ටනානරිවෝ)',
        'Indian/Chagos' => 'ඉන්දියන් සාගර වේලාව (චාගොස්)',
        'Indian/Christmas' => 'ක්‍රිස්මස් දුපත් වේලාව',
        'Indian/Cocos' => 'කොකෝස් දුපත් වේලාව (කොකොස්)',
        'Indian/Comoro' => 'නැගෙනහිර අප්‍රිකානු වේලාව (කොමොරෝ)',
        'Indian/Kerguelen' => 'ප්‍රංශ දකුණුදිග සහ ඇන්ටාර්ක්ටික් වේලාව (කෙර්ගුඑලෙන්)',
        'Indian/Mahe' => 'සීෂෙල්ස් වේලාව (මාහේ)',
        'Indian/Maldives' => 'මාලදිවයින් වේලාව (මාල දිවයින)',
        'Indian/Mauritius' => 'මුරුසි වේලාව (මුරුසිය)',
        'Indian/Mayotte' => 'නැගෙනහිර අප්‍රිකානු වේලාව (මයෝටි)',
        'Indian/Reunion' => 'රියුනියන් වේලාව',
        'MST7MDT' => 'උතුරු ඇමරිකානු කඳුකර වේලාව',
        'PST8PDT' => 'උතුරු ඇමරිකානු පැසිෆික් වේලාව',
        'Pacific/Apia' => 'අපියා වේලාව (ඇපියා)',
        'Pacific/Auckland' => 'නවසීලන්ත වේලාව (ඕක්ලන්ඩ්)',
        'Pacific/Bougainville' => 'පැපුවා නිව් ගිනීයා වේලාව (බෝගන්විලා)',
        'Pacific/Chatham' => 'චැතම් වේලාව',
        'Pacific/Easter' => 'ඊස්ටර් දූපත් වේලාව',
        'Pacific/Efate' => 'වනුආටු වේලාව (එෆාත්)',
        'Pacific/Enderbury' => 'ෆීනික්ස් දුපත් වේලාව (එන්ඩර්බරි)',
        'Pacific/Fakaofo' => 'ටොකෙලාවු වේලාව (ෆාකාඕෆෝ)',
        'Pacific/Fiji' => 'ෆිජි වේලාව (ෆීජි)',
        'Pacific/Funafuti' => 'ටුවාලු වේලාව (ෆුනෆුටි)',
        'Pacific/Galapagos' => 'ගලපගොස් වේලාව (ගලපගෝස්)',
        'Pacific/Gambier' => 'ගැම්බියර් වේලාව (ගම්බියෙර්)',
        'Pacific/Guadalcanal' => 'සොලොමන් දූපත් වේලාව (ගුවාඩල්කැනල්)',
        'Pacific/Guam' => 'චමොරෝ වේලාව (ගුවාම්)',
        'Pacific/Honolulu' => 'හවායි-අලෙයුතියාන් වේලාව (හොනොලුලු)',
        'Pacific/Johnston' => 'හවායි-අලෙයුතියාන් වේලාව (ජොන්ස්ටන්)',
        'Pacific/Kiritimati' => 'ලයින් දුපත් වේලාව (කිරිමටි)',
        'Pacific/Kosrae' => 'කොස්රේ වේලාව',
        'Pacific/Kwajalein' => 'මාර්ෂල් දුපත් වේලාව (ක්වාජලෙයින්)',
        'Pacific/Majuro' => 'මාර්ෂල් දුපත් වේලාව (මජුරෝ)',
        'Pacific/Marquesas' => 'මාර්කුඑසාස් වේලාව (මාකුවෙසාස්)',
        'Pacific/Midway' => 'සැමෝවා වේලාව (මිඩ්වේ)',
        'Pacific/Nauru' => 'නාවුරු වේලාව (නවුරු)',
        'Pacific/Niue' => 'නියු වේලාව',
        'Pacific/Norfolk' => 'නොෆොල්ක් දුපත් වේලාව (නෝෆෝක්)',
        'Pacific/Noumea' => 'නව සෙලඩොනියානු වේලාව (නෝමියා)',
        'Pacific/Pago_Pago' => 'සැමෝවා වේලාව (පගෝ පගෝ)',
        'Pacific/Palau' => 'පලාවු වේලාව',
        'Pacific/Pitcairn' => 'පිට්කෙයාන් වේලාව',
        'Pacific/Ponape' => 'පොනපේ වේලාව (පොන්පෙයි)',
        'Pacific/Port_Moresby' => 'පැපුවා නිව් ගිනීයා වේලාව (පොර්ට් මොරෙස්බි)',
        'Pacific/Rarotonga' => 'කුක් දුපත් වේලාව (රරෝටෝන්ගා)',
        'Pacific/Saipan' => 'චමොරෝ වේලාව (සයිපාන්)',
        'Pacific/Tahiti' => 'ටාහිටි වේලාව (ටහිති)',
        'Pacific/Tarawa' => 'ගිල්බර්ට් දුපත් වේලාව (ටරාවා)',
        'Pacific/Tongatapu' => 'ටොංගා වේලාව (ටොන්ගටාපු)',
        'Pacific/Truk' => 'චුක් වේලාව (චූක්)',
        'Pacific/Wake' => 'වේක් දූපත් වේලාව',
        'Pacific/Wallis' => 'වැලිස් සහ ෆුටුනා වේලාව',
    ],
    'Meta' => [
        'GmtFormat' => 'ග්‍රිමවේ%s',
        'HourFormatPos' => '+%02d.%02d',
        'HourFormatNeg' => '-%02d.%02d',
    ],
];
