<?php

return [
    'Names' => [
        'as_IN' => 'اسٲمۍ (हिंदोस्तान)',
        'az_Cyrl' => 'اَزَربیجانی (सिरिलिक)',
        'az_Cyrl_AZ' => 'اَزَربیجانی (सिरिलिक, آذربائیجان)',
        'az_Latn' => 'اَزَربیجانی (लातिनी)',
        'az_Latn_AZ' => 'اَزَربیجانی (लातिनी, آذربائیجان)',
        'bn_IN' => 'بَنگٲلۍ (हिंदोस्तान)',
        'bo_CN' => 'تِبتی (चीन)',
        'bo_IN' => 'تِبتی (हिंदोस्तान)',
        'br_FR' => 'بریٹَن (फ्रांस)',
        'bs_Cyrl' => 'بوسنِیَن (सिरिलिक)',
        'bs_Cyrl_BA' => 'بوسنِیَن (सिरिलिक, بوسنِیا تہٕ ہَرزِگووِنا)',
        'bs_Latn' => 'بوسنِیَن (लातिनी)',
        'bs_Latn_BA' => 'بوسنِیَن (लातिनी, بوسنِیا تہٕ ہَرزِگووِنا)',
        'ca_FR' => 'کَتلان (फ्रांस)',
        'ca_IT' => 'کَتلان (इटली)',
        'ce_RU' => 'چیچَن (रूस)',
        'cv_RU' => 'چُواش (रूस)',
        'cy_GB' => 'ویلش (मुतहीद बादशाहत)',
        'de' => 'जर्मन',
        'de_AT' => 'जर्मन (آسٹریا)',
        'de_BE' => 'जर्मन (بیلجِیَم)',
        'de_CH' => 'जर्मन (سُوِزَرلینڑ)',
        'de_DE' => 'जर्मन (जर्मन)',
        'de_IT' => 'जर्मन (इटली)',
        'de_LI' => 'जर्मन (لِکٹیسٹیٖن)',
        'de_LU' => 'जर्मन (لَکسَمبٔرٕگ)',
        'en' => 'अंगरिज़ी',
        'en_001' => 'अंगरिज़ी (دُنیا)',
        'en_150' => 'अंगरिज़ी (یوٗرَپ)',
        'en_AE' => 'अंगरिज़ी (مُتحدہ عرَب امارات)',
        'en_AG' => 'अंगरिज़ी (اؠنٹِگُوا تہٕ باربوڑا)',
        'en_AI' => 'अंगरिज़ी (انگوئیلا)',
        'en_AS' => 'अंगरिज़ी (اَمریٖکَن سَموا)',
        'en_AT' => 'अंगरिज़ी (آسٹریا)',
        'en_AU' => 'अंगरिज़ी (آسٹریلِیا)',
        'en_BB' => 'अंगरिज़ी (باربیڈوس)',
        'en_BE' => 'अंगरिज़ी (بیلجِیَم)',
        'en_BI' => 'अंगरिज़ी (بورَنڈِ)',
        'en_BM' => 'अंगरिज़ी (برمودا)',
        'en_BS' => 'अंगरिज़ी (بَہامَس)',
        'en_BW' => 'अंगरिज़ी (بوتَسوانا)',
        'en_BZ' => 'अंगरिज़ी (بیلز)',
        'en_CA' => 'अंगरिज़ी (کینیڈا)',
        'en_CC' => 'अंगरिज़ी (کوکَس [کیٖلِنگ] جٔزیٖرٕ)',
        'en_CH' => 'अंगरिज़ी (سُوِزَرلینڑ)',
        'en_CK' => 'अंगरिज़ी (کُک جٔزیٖرٕ)',
        'en_CM' => 'अंगरिज़ी (کیمِروٗن)',
        'en_CX' => 'अंगरिज़ी (کرِسمَس جٔزیٖرٕ)',
        'en_CY' => 'अंगरिज़ी (سائپرس)',
        'en_DE' => 'अंगरिज़ी (जर्मन)',
        'en_DK' => 'अंगरिज़ी (ڈینمارٕک)',
        'en_DM' => 'अंगरिज़ी (ڈومِنِکا)',
        'en_ER' => 'अंगरिज़ी (اِرٕٹِیا)',
        'en_FI' => 'अंगरिज़ी (فِن لینڈ)',
        'en_FJ' => 'अंगरिज़ी (فِجی)',
        'en_FK' => 'अंगरिज़ी (فٕلاکلینڑ جٔزیٖرٕ)',
        'en_FM' => 'अंगरिज़ी (مائیکرونیشیا)',
        'en_GB' => 'अंगरिज़ी (मुतहीद बादशाहत)',
        'en_GD' => 'अंगरिज़ी (گرینیڈا)',
        'en_GG' => 'अंगरिज़ी (گورنسے)',
        'en_GH' => 'अंगरिज़ी (گانا)',
        'en_GI' => 'अंगरिज़ी (جِبرالٹَر)',
        'en_GM' => 'अंगरिज़ी (گَمبِیا)',
        'en_GU' => 'अंगरिज़ी (گُوام)',
        'en_GY' => 'अंगरिज़ी (گُیانا)',
        'en_HK' => 'अंगरिज़ी (ہانگ کانگ ایس اے آر چیٖن)',
        'en_IE' => 'अंगरिज़ी (اَیَرلینڑ)',
        'en_IL' => 'अंगरिज़ी (اسرا ییل)',
        'en_IM' => 'अंगरिज़ी (آیِل آف مین)',
        'en_IN' => 'अंगरिज़ी (हिंदोस्तान)',
        'en_IO' => 'अंगरिज़ी (برطانوی بحرِ ہِندۍ علاقہٕ)',
        'en_JE' => 'अंगरिज़ी (جٔرسی)',
        'en_JM' => 'अंगरिज़ी (جَمایکا)',
        'en_KE' => 'अंगरिज़ी (کِنیا)',
        'en_KI' => 'अंगरिज़ी (کِرٕباتی)',
        'en_KN' => 'अंगरिज़ी (سینٹ کِٹَس تہٕ نیوِس)',
        'en_KY' => 'अंगरिज़ी (کیمَن جٔزیٖرٕ)',
        'en_LC' => 'अंगरिज़ी (سینٹ لوٗسِیا)',
        'en_LR' => 'अंगरिज़ी (لایبیرِیا)',
        'en_LS' => 'अंगरिज़ी (لیسوتھو)',
        'en_MG' => 'अंगरिज़ी (میڈاگاسکار)',
        'en_MH' => 'अंगरिज़ी (مارشَل جٔزیٖرٕ)',
        'en_MO' => 'अंगरिज़ी (مَکاوو ایس اے آر چیٖن)',
        'en_MP' => 'अंगरिज़ी (شُمٲلی مارِیانا جٔزیٖرٕ)',
        'en_MS' => 'अंगरिज़ी (مانٹسیراٹ)',
        'en_MT' => 'अंगरिज़ी (مالٹا)',
        'en_MU' => 'अंगरिज़ी (مورِشَس)',
        'en_MV' => 'अंगरिज़ी (مالدیٖو)',
        'en_MW' => 'अंगरिज़ी (ملاوی)',
        'en_MY' => 'अंगरिज़ी (مَلیشِیا)',
        'en_NA' => 'अंगरिज़ी (نامِبِیا)',
        'en_NF' => 'अंगरिज़ी (نارفاک جٔزیٖرٕ)',
        'en_NG' => 'अंगरिज़ी (نایجیرِیا)',
        'en_NL' => 'अंगरिज़ी (نیٖدَرلینڑ)',
        'en_NR' => 'अंगरिज़ी (نارووٗ)',
        'en_NU' => 'अंगरिज़ी (نیوٗ)',
        'en_NZ' => 'अंगरिज़ी (نیوزی لینڈ)',
        'en_PG' => 'अंगरिज़ी (پاپُوا نیوٗ گیٖنی)',
        'en_PH' => 'अंगरिज़ी (فلپائن)',
        'en_PK' => 'अंगरिज़ी (پاکِستان)',
        'en_PN' => 'अंगरिज़ी (پِٹکیرٕنۍ جٔزیٖرٕ)',
        'en_PR' => 'अंगरिज़ी (پٔرٹو رِکو)',
        'en_PW' => 'अंगरिज़ी (پَلاو)',
        'en_RW' => 'अंगरिज़ी (روٗوانڈا)',
        'en_SB' => 'अंगरिज़ी (سولامان جٔزیٖرٕ)',
        'en_SC' => 'अंगरिज़ी (سیشَلِس)',
        'en_SD' => 'अंगरिज़ी (سوٗڈان)',
        'en_SE' => 'अंगरिज़ी (سویڈن)',
        'en_SG' => 'अंगरिज़ी (سِنگاپوٗر)',
        'en_SH' => 'अंगरिज़ी (سینٹ ہؠلِنا)',
        'en_SI' => 'अंगरिज़ी (سَلووینِیا)',
        'en_SL' => 'अंगरिज़ी (سیرا لیون)',
        'en_SS' => 'अंगरिज़ी (جنوبی سوڈان)',
        'en_SX' => 'अंगरिज़ी (سِنٹ مارٹِن)',
        'en_SZ' => 'अंगरिज़ी (ایسواتنی)',
        'en_TC' => 'अंगरिज़ी (تُرکس تٕہ کیکو جزیرٕ)',
        'en_TK' => 'अंगरिज़ी (ٹوکلو)',
        'en_TO' => 'अंगरिज़ी (ٹونگا)',
        'en_TT' => 'अंगरिज़ी (ٹرنِنداد تہٕ ٹوبیگو)',
        'en_TV' => 'अंगरिज़ी (توٗوالوٗ)',
        'en_TZ' => 'अंगरिज़ी (تَنجانِیا)',
        'en_UG' => 'अंगरिज़ी (یوٗگانڑا)',
        'en_UM' => 'अंगरिज़ी (یوٗنایٹِڑ سِٹیٹِس ماینَر آوُٹلییِنگ جٔزیٖرٕ)',
        'en_US' => 'अंगरिज़ी (मूतहीद रियासत)',
        'en_VC' => 'अंगरिज़ी (سینٹ وینسؠٹ تہٕ گریناڑاینٕز)',
        'en_VG' => 'अंगरिज़ी (بَرطانوی ؤرجِن جٔزیٖرٕ)',
        'en_VI' => 'अंगरिज़ी (یوٗ ایس ؤرجِن جٔزیٖرٕ)',
        'en_VU' => 'अंगरिज़ी (وانوٗتوٗ)',
        'en_WS' => 'अंगरिज़ी (سامو)',
        'en_ZA' => 'अंगरिज़ी (جنوبی افریقہ)',
        'en_ZM' => 'अंगरिज़ी (زیمبیا)',
        'en_ZW' => 'अंगरिज़ी (زِمبابے)',
        'es' => 'हसपानवी',
        'es_419' => 'हसपानवी (لاطیٖنی اَمریٖکا)',
        'es_AR' => 'हसपानवी (أرجَنٹینا)',
        'es_BO' => 'हसपानवी (بولِوِیا)',
        'es_BR' => 'हसपानवी (ब्राज़ील)',
        'es_BZ' => 'हसपानवी (بیلز)',
        'es_CL' => 'हसपानवी (چِلی)',
        'es_CO' => 'हसपानवी (کولَمبِیا)',
        'es_CR' => 'हसपानवी (کوسٹا ریکا)',
        'es_CU' => 'हसपानवी (کیوٗبا)',
        'es_DO' => 'हसपानवी (ڈومِنِکَن جموٗرِیَت)',
        'es_EC' => 'हसपानवी (اِکواڑور)',
        'es_ES' => 'हसपानवी (سٕپین)',
        'es_GQ' => 'हसपानवी (اِکوِٹورِیَل گِنی)',
        'es_GT' => 'हसपानवी (گواٹمالا)',
        'es_HN' => 'हसपानवी (ہونڈورس)',
        'es_MX' => 'हसपानवी (مؠکسِکو)',
        'es_NI' => 'हसपानवी (ناکاراگُوا)',
        'es_PA' => 'हसपानवी (پَناما)',
        'es_PE' => 'हसपानवी (پیٖروٗ)',
        'es_PH' => 'हसपानवी (فلپائن)',
        'es_PR' => 'हसपानवी (پٔرٹو رِکو)',
        'es_PY' => 'हसपानवी (پَراگُے)',
        'es_SV' => 'हसपानवी (ایل سلویڈر)',
        'es_US' => 'हसपानवी (मूतहीद रियासत)',
        'es_UY' => 'हसपानवी (یوٗروگے)',
        'es_VE' => 'हसपानवी (وینازوٗلا)',
        'ff_Latn' => 'فُلاہ (लातिनी)',
        'ff_Latn_BF' => 'فُلاہ (लातिनी, بُرکِنا فیسو)',
        'ff_Latn_CM' => 'فُلاہ (लातिनी, کیمِروٗن)',
        'ff_Latn_GH' => 'فُلاہ (लातिनी, گانا)',
        'ff_Latn_GM' => 'فُلاہ (लातिनी, گَمبِیا)',
        'ff_Latn_GN' => 'فُلاہ (लातिनी, گِنی)',
        'ff_Latn_GW' => 'فُلاہ (लातिनी, گیٖنی بِساو)',
        'ff_Latn_LR' => 'فُلاہ (लातिनी, لایبیرِیا)',
        'ff_Latn_MR' => 'فُلاہ (लातिनी, مارٕٹانِیا)',
        'ff_Latn_NE' => 'فُلاہ (लातिनी, نایجَر)',
        'ff_Latn_NG' => 'فُلاہ (लातिनी, نایجیرِیا)',
        'ff_Latn_SL' => 'فُلاہ (लातिनी, سیرا لیون)',
        'ff_Latn_SN' => 'فُلاہ (लातिनी, سینیگَل)',
        'fr' => 'फ्रांसीसी',
        'fr_BE' => 'फ्रांसीसी (بیلجِیَم)',
        'fr_BF' => 'फ्रांसीसी (بُرکِنا فیسو)',
        'fr_BI' => 'फ्रांसीसी (بورَنڈِ)',
        'fr_BJ' => 'फ्रांसीसी (بِنِن)',
        'fr_BL' => 'फ्रांसीसी (سینٹ بارتَھیلمی)',
        'fr_CA' => 'फ्रांसीसी (کینیڈا)',
        'fr_CD' => 'फ्रांसीसी (کونگو کِنشاسا)',
        'fr_CF' => 'फ्रांसीसी (مرکٔزی اَفریٖکی جموٗریَت)',
        'fr_CG' => 'फ्रांसीसी (کونگو بٔرزاوِلی)',
        'fr_CH' => 'फ्रांसीसी (سُوِزَرلینڑ)',
        'fr_CI' => 'फ्रांसीसी (کوٹ ڈلوائر)',
        'fr_CM' => 'फ्रांसीसी (کیمِروٗن)',
        'fr_DJ' => 'फ्रांसीसी (جِبوٗتی)',
        'fr_DZ' => 'फ्रांसीसी (اؠلجیرِیا)',
        'fr_FR' => 'फ्रांसीसी (फ्रांस)',
        'fr_GA' => 'फ्रांसीसी (گیبان)',
        'fr_GF' => 'फ्रांसीसी (فرانسِسی گِانا)',
        'fr_GN' => 'फ्रांसीसी (گِنی)',
        'fr_GP' => 'फ्रांसीसी (گواڈلوپ)',
        'fr_GQ' => 'फ्रांसीसी (اِکوِٹورِیَل گِنی)',
        'fr_HT' => 'फ्रांसीसी (ہیتی)',
        'fr_KM' => 'फ्रांसीसी (کَمورَس)',
        'fr_LU' => 'फ्रांसीसी (لَکسَمبٔرٕگ)',
        'fr_MA' => 'फ्रांसीसी (موروکو)',
        'fr_MC' => 'फ्रांसीसी (مونیکو)',
        'fr_MF' => 'फ्रांसीसी (سینٹ مارٹِن)',
        'fr_MG' => 'फ्रांसीसी (میڈاگاسکار)',
        'fr_ML' => 'फ्रांसीसी (مالی)',
        'fr_MQ' => 'फ्रांसीसी (مارٹِنِک)',
        'fr_MR' => 'फ्रांसीसी (مارٕٹانِیا)',
        'fr_MU' => 'फ्रांसीसी (مورِشَس)',
        'fr_NC' => 'फ्रांसीसी (نِو کیلِڑونِیا)',
        'fr_NE' => 'फ्रांसीसी (نایجَر)',
        'fr_PF' => 'फ्रांसीसी (فرانسی پولِنیشِیا)',
        'fr_PM' => 'फ्रांसीसी (سینٹ پیٖری تہٕ موکیلِیَن)',
        'fr_RE' => 'फ्रांसीसी (رِیوٗنِیَن)',
        'fr_RW' => 'फ्रांसीसी (روٗوانڈا)',
        'fr_SC' => 'फ्रांसीसी (سیشَلِس)',
        'fr_SN' => 'फ्रांसीसी (سینیگَل)',
        'fr_SY' => 'फ्रांसीसी (شام)',
        'fr_TD' => 'फ्रांसीसी (چاڑ)',
        'fr_TG' => 'फ्रांसीसी (ٹوگو)',
        'fr_TN' => 'फ्रांसीसी (ٹونیشِیا)',
        'fr_VU' => 'फ्रांसीसी (وانوٗتوٗ)',
        'fr_WF' => 'फ्रांसीसी (والِس تہٕ فیوٗچوٗنا)',
        'fr_YT' => 'फ्रांसीसी (مَییٹ)',
        'ga_GB' => 'اَیرِش (मुतहीद बादशाहत)',
        'gd_GB' => 'سکوٹِش گیےلِک (मुतहीद बादशाहत)',
        'gu_IN' => 'گُجرٲتی (हिंदोस्तान)',
        'hi_IN' => 'ہِندی (हिंदोस्तान)',
        'hi_Latn' => 'ہِندی (लातिनी)',
        'hi_Latn_IN' => 'ہِندی (लातिनी, हिंदोस्तान)',
        'ii_CN' => 'سِچوان یٖی (चीन)',
        'it' => 'इतालवी',
        'it_CH' => 'इतालवी (سُوِزَرلینڑ)',
        'it_IT' => 'इतालवी (इटली)',
        'it_SM' => 'इतालवी (سین میرِنو)',
        'it_VA' => 'इतालवी (ویٹِکَن سِٹی)',
        'ja' => 'जापानी',
        'ja_JP' => 'जापानी (जापान)',
        'kn_IN' => 'کَنَڑ (हिंदोस्तान)',
        'ks' => 'कॉशुर',
        'ks_Arab' => 'कॉशुर (अरबी)',
        'ks_Arab_IN' => 'कॉशुर (अरबी, हिंदोस्तान)',
        'ks_Deva' => 'कॉशुर (देवनागरी)',
        'ks_Deva_IN' => 'कॉशुर (देवनागरी, हिंदोस्तान)',
        'ks_IN' => 'कॉशुर (हिंदोस्तान)',
        'kw_GB' => 'کورنِش (मुतहीद बादशाहत)',
        'ml_IN' => 'مٔلیالَم (हिंदोस्तान)',
        'mr_IN' => 'مَرٲٹھۍ (हिंदोस्तान)',
        'ne_IN' => 'نیپٲلۍ (हिंदोस्तान)',
        'or_IN' => 'اۆرِیا (हिंदोस्तान)',
        'os_RU' => 'اۆسیٹِک (रूस)',
        'pa_Arab' => 'پَنجٲبۍ (अरबी)',
        'pa_Arab_PK' => 'پَنجٲبۍ (अरबी, پاکِستان)',
        'pa_Guru_IN' => 'پَنجٲبۍ (گُجرٲتۍ, हिंदोस्तान)',
        'pa_IN' => 'پَنجٲبۍ (हिंदोस्तान)',
        'pt' => 'पुरतउगाली',
        'pt_AO' => 'पुरतउगाली (انگولا)',
        'pt_BR' => 'पुरतउगाली (ब्राज़ील)',
        'pt_CH' => 'पुरतउगाली (سُوِزَرلینڑ)',
        'pt_CV' => 'पुरतउगाली (کیپ ؤرڑی)',
        'pt_GQ' => 'पुरतउगाली (اِکوِٹورِیَل گِنی)',
        'pt_GW' => 'पुरतउगाली (گیٖنی بِساو)',
        'pt_LU' => 'पुरतउगाली (لَکسَمبٔرٕگ)',
        'pt_MO' => 'पुरतउगाली (مَکاوو ایس اے آر چیٖن)',
        'pt_MZ' => 'पुरतउगाली (موزَمبِک)',
        'pt_PT' => 'पुरतउगाली (پُرتِگال)',
        'pt_ST' => 'पुरतउगाली (ساو توم تہٕ پرنسِپی)',
        'pt_TL' => 'पुरतउगाली (تیمور-لیسٹ)',
        'ru' => 'रूसी',
        'ru_BY' => 'रूसी (بیلاروٗس)',
        'ru_KG' => 'रूसी (کرغزستان)',
        'ru_KZ' => 'रूसी (قازقستان)',
        'ru_MD' => 'रूसी (مولڈووا)',
        'ru_RU' => 'रूसी (रूस)',
        'ru_UA' => 'रूसी (یوٗرِکین)',
        'sa_IN' => 'سَنسکرٕت (हिंदोस्तान)',
        'sc_IT' => 'سراڈیٖنی (इटली)',
        'sd_Arab' => 'سِندی (अरबी)',
        'sd_Arab_PK' => 'سِندی (अरबी, پاکِستان)',
        'sd_Deva' => 'سِندی (देवनागरी)',
        'sd_Deva_IN' => 'سِندی (देवनागरी, हिंदोस्तान)',
        'sd_IN' => 'سِندی (हिंदोस्तान)',
        'sr_Cyrl' => 'سٔربِیَن (सिरिलिक)',
        'sr_Cyrl_BA' => 'سٔربِیَن (सिरिलिक, بوسنِیا تہٕ ہَرزِگووِنا)',
        'sr_Cyrl_ME' => 'سٔربِیَن (सिरिलिक, موٹونیگِریو)',
        'sr_Cyrl_RS' => 'سٔربِیَن (सिरिलिक, سَربِیا)',
        'sr_Latn' => 'سٔربِیَن (लातिनी)',
        'sr_Latn_BA' => 'سٔربِیَن (लातिनी, بوسنِیا تہٕ ہَرزِگووِنا)',
        'sr_Latn_ME' => 'سٔربِیَن (लातिनी, موٹونیگِریو)',
        'sr_Latn_RS' => 'سٔربِیَن (लातिनी, سَربِیا)',
        'su_Latn' => 'سَنڈَنیٖز (लातिनी)',
        'su_Latn_ID' => 'سَنڈَنیٖز (लातिनी, انڈونیشیا)',
        'ta_IN' => 'تَمِل (हिंदोस्तान)',
        'te_IN' => 'تیلگوٗ (हिंदोस्तान)',
        'tt_RU' => 'تَتار (रूस)',
        'ur_IN' => 'اُردوٗ (हिंदोस्तान)',
        'uz_Arab' => 'اُزبیک (अरबी)',
        'uz_Arab_AF' => 'اُزبیک (अरबी, اَفغانَستان)',
        'uz_Cyrl' => 'اُزبیک (सिरिलिक)',
        'uz_Cyrl_UZ' => 'اُزبیک (सिरिलिक, اُزبِکِستان)',
        'uz_Latn' => 'اُزبیک (लातिनी)',
        'uz_Latn_UZ' => 'اُزبیک (लातिनी, اُزبِکِستان)',
        'zh' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।]',
        'zh_CN' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (चीन)',
        'zh_HK' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (ہانگ کانگ ایس اے آر چیٖن)',
        'zh_Hans' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (आसान [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।])',
        'zh_Hans_CN' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (आसान [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], चीन)',
        'zh_Hans_HK' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (आसान [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], ہانگ کانگ ایس اے آر چیٖن)',
        'zh_Hans_MO' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (आसान [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], مَکاوو ایس اے آر چیٖن)',
        'zh_Hans_SG' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (आसान [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], سِنگاپوٗر)',
        'zh_Hant' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (रिवायाती [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।])',
        'zh_Hant_HK' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (रिवायाती [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], ہانگ کانگ ایس اے آر چیٖن)',
        'zh_Hant_MO' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (रिवायाती [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], مَکاوو ایس اے آر چیٖن)',
        'zh_Hant_TW' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (रिवायाती [तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।], تایوان)',
        'zh_MO' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (مَکاوو ایس اے آر چیٖن)',
        'zh_SG' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (سِنگاپوٗر)',
        'zh_TW' => 'चीनी [तरजुम इशार: खास तोर, मैन्डरिन चीनी।] (تایوان)',
    ],
];
