<?php

return [
    'Names' => [
        'af' => 'Awherikāna',
        'af_NA' => 'Awherikāna (Namīpia)',
        'af_ZA' => 'Awherikāna (Āwherika ki te Tonga)',
        'ak' => 'Ākana',
        'ak_GH' => 'Ākana (Kāna)',
        'am' => 'Amahereka',
        'am_ET' => 'Amahereka (Etiopia)',
        'ar' => 'Ārapi',
        'ar_001' => 'Ārapi (te ao)',
        'ar_DJ' => 'Ārapi (Tipūti)',
        'ar_DZ' => 'Ārapi (Aratiria)',
        'ar_EG' => 'Ārapi (Īhipa)',
        'ar_EH' => 'Ārapi (Hahāra ki te Tonga)',
        'ar_ER' => 'Ārapi (Eritēria)',
        'ar_KM' => 'Ārapi (Komoro)',
        'ar_LY' => 'Ārapi (Rīpia)',
        'ar_MA' => 'Ārapi (Moroko)',
        'ar_MR' => 'Ārapi (Mauritānia)',
        'ar_SD' => 'Ārapi (Hūtāne)',
        'ar_SO' => 'Ārapi (Hūmārie)',
        'ar_SS' => 'Ārapi (Hūtāne ki te Tonga)',
        'ar_TD' => 'Ārapi (Kāta)',
        'ar_TN' => 'Ārapi (Tūnihia)',
        'as' => 'Āhamēhi',
        'as_IN' => 'Āhamēhi (Inia)',
        'az' => 'Ahapahāna',
        'az_Cyrl' => 'Ahapahāna (Hīririki)',
        'az_Latn' => 'Ahapahāna (Rātina)',
        'be' => 'Perarūhiana',
        'bg' => 'Pukēriana',
        'bm' => 'Pāpara',
        'bm_ML' => 'Pāpara (Māri)',
        'bn' => 'Pāngara',
        'bn_IN' => 'Pāngara (Inia)',
        'bo' => 'Tipete',
        'bo_CN' => 'Tipete (Haina)',
        'bo_IN' => 'Tipete (Inia)',
        'br' => 'Peretana',
        'br_FR' => 'Peretana (Wīwī)',
        'bs' => 'Pōngiana',
        'bs_Cyrl' => 'Pōngiana (Hīririki)',
        'bs_Latn' => 'Pōngiana (Rātina)',
        'ca' => 'Katarana',
        'ca_FR' => 'Katarana (Wīwī)',
        'ca_IT' => 'Katarana (Itāria)',
        'ce' => 'Tietiene',
        'ce_RU' => 'Tietiene (Rūhia)',
        'cs' => 'Tiekerowākiana',
        'cv' => 'Tiuwhā',
        'cv_RU' => 'Tiuwhā (Rūhia)',
        'cy' => 'Werehi',
        'cy_GB' => 'Werehi (Te Hononga o Piritene)',
        'da' => 'Teina',
        'da_DK' => 'Teina (Tenemāka)',
        'da_GL' => 'Teina (Kirīrangi)',
        'de' => 'Tiamana',
        'de_AT' => 'Tiamana (Ateria)',
        'de_BE' => 'Tiamana (Paratiamu)',
        'de_CH' => 'Tiamana (Huiterangi)',
        'de_DE' => 'Tiamana (Tiamani)',
        'de_IT' => 'Tiamana (Itāria)',
        'de_LI' => 'Tiamana (Rīkeneteina)',
        'de_LU' => 'Tiamana (Rakimipēki)',
        'dz' => 'Tonoka',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Kāna)',
        'ee_TG' => 'Ewe (Toko)',
        'el' => 'Kiriki',
        'en' => 'Ingarihi',
        'en_001' => 'Ingarihi (te ao)',
        'en_150' => 'Ingarihi (Ūropi)',
        'en_AG' => 'Ingarihi (Anatikua me Pāpura)',
        'en_AI' => 'Ingarihi (Ākuira)',
        'en_AT' => 'Ingarihi (Ateria)',
        'en_BB' => 'Ingarihi (Pāpetō)',
        'en_BE' => 'Ingarihi (Paratiamu)',
        'en_BI' => 'Ingarihi (Puruniti)',
        'en_BM' => 'Ingarihi (Pemiuta)',
        'en_BS' => 'Ingarihi (Pahāma)',
        'en_BW' => 'Ingarihi (Poriwana)',
        'en_BZ' => 'Ingarihi (Perīhi)',
        'en_CA' => 'Ingarihi (Kānata)',
        'en_CH' => 'Ingarihi (Huiterangi)',
        'en_CM' => 'Ingarihi (Kamarūna)',
        'en_DE' => 'Ingarihi (Tiamani)',
        'en_DK' => 'Ingarihi (Tenemāka)',
        'en_DM' => 'Ingarihi (Tominika)',
        'en_ER' => 'Ingarihi (Eritēria)',
        'en_FI' => 'Ingarihi (Whinirana)',
        'en_FK' => 'Ingarihi (Motu Whākarangi)',
        'en_GB' => 'Ingarihi (Te Hononga o Piritene)',
        'en_GD' => 'Ingarihi (Kerenāta)',
        'en_GG' => 'Ingarihi (Kēni)',
        'en_GH' => 'Ingarihi (Kāna)',
        'en_GM' => 'Ingarihi (Te Kamopia)',
        'en_GY' => 'Ingarihi (Kaiana)',
        'en_IE' => 'Ingarihi (Aerana)',
        'en_IM' => 'Ingarihi (Motu Tangata)',
        'en_IN' => 'Ingarihi (Inia)',
        'en_IO' => 'Ingarihi (Te Rohe o te Moana Īniana Piritihi)',
        'en_JE' => 'Ingarihi (Tiehe)',
        'en_JM' => 'Ingarihi (Hemeika)',
        'en_KE' => 'Ingarihi (Kēnia)',
        'en_KN' => 'Ingarihi (Hato Kiti me Newhi)',
        'en_KY' => 'Ingarihi (Ngā Motu Keimana)',
        'en_LC' => 'Ingarihi (Hato Ruhia)',
        'en_LR' => 'Ingarihi (Raipiri)',
        'en_LS' => 'Ingarihi (Teroto)',
        'en_MG' => 'Ingarihi (Marakāhia)',
        'en_MS' => 'Ingarihi (Monoterā)',
        'en_MU' => 'Ingarihi (Mōrihi)',
        'en_MW' => 'Ingarihi (Marāwi)',
        'en_NA' => 'Ingarihi (Namīpia)',
        'en_NG' => 'Ingarihi (Ngāitiria)',
        'en_NL' => 'Ingarihi (Hōrana)',
        'en_NZ' => 'Ingarihi (Aotearoa)',
        'en_PR' => 'Ingarihi (Pōta Riko)',
        'en_RW' => 'Ingarihi (Rāwana)',
        'en_SC' => 'Ingarihi (Heihere)',
        'en_SD' => 'Ingarihi (Hūtāne)',
        'en_SE' => 'Ingarihi (Huītene)',
        'en_SH' => 'Ingarihi (Hato Harīna)',
        'en_SL' => 'Ingarihi (Te Araone)',
        'en_SS' => 'Ingarihi (Hūtāne ki te Tonga)',
        'en_SX' => 'Ingarihi (Hiti Mātene)',
        'en_SZ' => 'Ingarihi (Ewatini)',
        'en_TC' => 'Ingarihi (Tāke me ngā Motu o Keiko)',
        'en_TT' => 'Ingarihi (Tinitātā me Topēko)',
        'en_TZ' => 'Ingarihi (Tānahia)',
        'en_UG' => 'Ingarihi (Ukāna)',
        'en_US' => 'Ingarihi (Hononga o Amerika)',
        'en_VC' => 'Ingarihi (Hato Wetene me Keretīni)',
        'en_VG' => 'Ingarihi (Ngā Motu o Tātāhou Piritene)',
        'en_VI' => 'Ingarihi (Ngā Motu o Tātāhou Amerika)',
        'en_ZA' => 'Ingarihi (Āwherika ki te Tonga)',
        'en_ZM' => 'Ingarihi (Tāmipia)',
        'en_ZW' => 'Ingarihi (Timuwawe)',
        'eo' => 'Eheperāto',
        'eo_001' => 'Eheperāto (te ao)',
        'es' => 'Pāniora',
        'es_419' => 'Pāniora (Amerika Rātini)',
        'es_AR' => 'Pāniora (Āketina)',
        'es_BO' => 'Pāniora (Poriwia)',
        'es_BR' => 'Pāniora (Parīhi)',
        'es_BZ' => 'Pāniora (Perīhi)',
        'es_CL' => 'Pāniora (Hiri)',
        'es_CO' => 'Pāniora (Koromōpia)',
        'es_CR' => 'Pāniora (Kota Rīka)',
        'es_CU' => 'Pāniora (Kiupa)',
        'es_DO' => 'Pāniora (Te Whenua Tominika)',
        'es_EC' => 'Pāniora (Ekuatoa)',
        'es_GQ' => 'Pāniora (Kini Ekuatoria)',
        'es_GT' => 'Pāniora (Kuatamāra)',
        'es_HN' => 'Pāniora (Honūra)',
        'es_MX' => 'Pāniora (Mēhiko)',
        'es_NI' => 'Pāniora (Nikarakua)',
        'es_PA' => 'Pāniora (Panama)',
        'es_PE' => 'Pāniora (Peru)',
        'es_PR' => 'Pāniora (Pōta Riko)',
        'es_PY' => 'Pāniora (Parakai)',
        'es_SV' => 'Pāniora (Ere Hāwhatō)',
        'es_US' => 'Pāniora (Hononga o Amerika)',
        'es_UY' => 'Pāniora (Urukoi)',
        'es_VE' => 'Pāniora (Wenehūera)',
        'et' => 'Ehetōniana',
        'et_EE' => 'Ehetōniana (Etōnia)',
        'eu' => 'Pāka',
        'fa' => 'Pāhiana',
        'ff' => 'Wharā',
        'ff_Adlm' => 'Wharā (Arāma)',
        'ff_Adlm_BF' => 'Wharā (Arāma, Pēkina Waho)',
        'ff_Adlm_CM' => 'Wharā (Arāma, Kamarūna)',
        'ff_Adlm_GH' => 'Wharā (Arāma, Kāna)',
        'ff_Adlm_GM' => 'Wharā (Arāma, Te Kamopia)',
        'ff_Adlm_GN' => 'Wharā (Arāma, Kini)',
        'ff_Adlm_GW' => 'Wharā (Arāma, Kini-Pihao)',
        'ff_Adlm_LR' => 'Wharā (Arāma, Raipiri)',
        'ff_Adlm_MR' => 'Wharā (Arāma, Mauritānia)',
        'ff_Adlm_NE' => 'Wharā (Arāma, Ngāika)',
        'ff_Adlm_NG' => 'Wharā (Arāma, Ngāitiria)',
        'ff_Adlm_SL' => 'Wharā (Arāma, Te Araone)',
        'ff_Adlm_SN' => 'Wharā (Arāma, Henekara)',
        'ff_CM' => 'Wharā (Kamarūna)',
        'ff_GN' => 'Wharā (Kini)',
        'ff_Latn' => 'Wharā (Rātina)',
        'ff_Latn_BF' => 'Wharā (Rātina, Pēkina Waho)',
        'ff_Latn_CM' => 'Wharā (Rātina, Kamarūna)',
        'ff_Latn_GH' => 'Wharā (Rātina, Kāna)',
        'ff_Latn_GM' => 'Wharā (Rātina, Te Kamopia)',
        'ff_Latn_GN' => 'Wharā (Rātina, Kini)',
        'ff_Latn_GW' => 'Wharā (Rātina, Kini-Pihao)',
        'ff_Latn_LR' => 'Wharā (Rātina, Raipiri)',
        'ff_Latn_MR' => 'Wharā (Rātina, Mauritānia)',
        'ff_Latn_NE' => 'Wharā (Rātina, Ngāika)',
        'ff_Latn_NG' => 'Wharā (Rātina, Ngāitiria)',
        'ff_Latn_SL' => 'Wharā (Rātina, Te Araone)',
        'ff_Latn_SN' => 'Wharā (Rātina, Henekara)',
        'ff_MR' => 'Wharā (Mauritānia)',
        'ff_SN' => 'Wharā (Henekara)',
        'fi' => 'Whinirānia',
        'fi_FI' => 'Whinirānia (Whinirana)',
        'fo' => 'Wharoīhi',
        'fo_DK' => 'Wharoīhi (Tenemāka)',
        'fo_FO' => 'Wharoīhi (Motu Wharo)',
        'fr' => 'Wīwī',
        'fr_BE' => 'Wīwī (Paratiamu)',
        'fr_BF' => 'Wīwī (Pēkina Waho)',
        'fr_BI' => 'Wīwī (Puruniti)',
        'fr_BJ' => 'Wīwī (Penīna)',
        'fr_BL' => 'Wīwī (Hato Pāteremi)',
        'fr_CA' => 'Wīwī (Kānata)',
        'fr_CD' => 'Wīwī (Kōngo - Kingihāha)',
        'fr_CF' => 'Wīwī (Te Puku o Āwherika)',
        'fr_CG' => 'Wīwī (Kōngo - Parāwhe)',
        'fr_CH' => 'Wīwī (Huiterangi)',
        'fr_CI' => 'Wīwī (Te Tai Rei)',
        'fr_CM' => 'Wīwī (Kamarūna)',
        'fr_DJ' => 'Wīwī (Tipūti)',
        'fr_DZ' => 'Wīwī (Aratiria)',
        'fr_FR' => 'Wīwī (Wīwī)',
        'fr_GA' => 'Wīwī (Kāpona)',
        'fr_GF' => 'Wīwī (Kaiana Wīwī)',
        'fr_GN' => 'Wīwī (Kini)',
        'fr_GP' => 'Wīwī (Kuatarū)',
        'fr_GQ' => 'Wīwī (Kini Ekuatoria)',
        'fr_HT' => 'Wīwī (Haiti)',
        'fr_KM' => 'Wīwī (Komoro)',
        'fr_LU' => 'Wīwī (Rakimipēki)',
        'fr_MA' => 'Wīwī (Moroko)',
        'fr_MC' => 'Wīwī (Manako)',
        'fr_MF' => 'Wīwī (Hato Mātene)',
        'fr_MG' => 'Wīwī (Marakāhia)',
        'fr_ML' => 'Wīwī (Māri)',
        'fr_MQ' => 'Wīwī (Māteniki)',
        'fr_MR' => 'Wīwī (Mauritānia)',
        'fr_MU' => 'Wīwī (Mōrihi)',
        'fr_NE' => 'Wīwī (Ngāika)',
        'fr_PM' => 'Wīwī (Hato Piere & Mikarona)',
        'fr_RE' => 'Wīwī (Rēnio)',
        'fr_RW' => 'Wīwī (Rāwana)',
        'fr_SC' => 'Wīwī (Heihere)',
        'fr_SN' => 'Wīwī (Henekara)',
        'fr_TD' => 'Wīwī (Kāta)',
        'fr_TG' => 'Wīwī (Toko)',
        'fr_TN' => 'Wīwī (Tūnihia)',
        'fr_YT' => 'Wīwī (Maio)',
        'fy' => 'Whirīhiana ki te Uru',
        'fy_NL' => 'Whirīhiana ki te Uru (Hōrana)',
        'ga' => 'Airihi',
        'ga_GB' => 'Airihi (Te Hononga o Piritene)',
        'ga_IE' => 'Airihi (Aerana)',
        'gd' => 'Kotimana Keiriki',
        'gd_GB' => 'Kotimana Keiriki (Te Hononga o Piritene)',
        'gl' => 'Karīhia',
        'gu' => 'Kutarāti',
        'gu_IN' => 'Kutarāti (Inia)',
        'gv' => 'Manaki',
        'gv_IM' => 'Manaki (Motu Tangata)',
        'ha' => 'Hauha',
        'ha_GH' => 'Hauha (Kāna)',
        'ha_NE' => 'Hauha (Ngāika)',
        'ha_NG' => 'Hauha (Ngāitiria)',
        'he' => 'Hīperu',
        'hi' => 'Hīni',
        'hi_IN' => 'Hīni (Inia)',
        'hi_Latn' => 'Hīni (Rātina)',
        'hi_Latn_IN' => 'Hīni (Rātina, Inia)',
        'hr' => 'Koroātiana',
        'hu' => 'Hanakariana',
        'hy' => 'Āmeiniana',
        'ia' => 'Inarīngua',
        'ia_001' => 'Inarīngua (te ao)',
        'id' => 'Initonīhiana',
        'ig' => 'Ingo',
        'ig_NG' => 'Ingo (Ngāitiria)',
        'ii' => 'Hīhuana Eī',
        'ii_CN' => 'Hīhuana Eī (Haina)',
        'is' => 'Tiorangiana',
        'is_IS' => 'Tiorangiana (Tiorangi)',
        'it' => 'Itāriana',
        'it_CH' => 'Itāriana (Huiterangi)',
        'it_IT' => 'Itāriana (Itāria)',
        'ja' => 'Hapanihi',
        'ja_JP' => 'Hapanihi (Hapani)',
        'jv' => 'Hāwhanihi',
        'ka' => 'Hōriana',
        'ki' => 'Kikiu',
        'ki_KE' => 'Kikiu (Kēnia)',
        'kk' => 'Kahāka',
        'kl' => 'Karārihutu',
        'kl_GL' => 'Karārihutu (Kirīrangi)',
        'km' => 'Kimei',
        'kn' => 'Kanara',
        'kn_IN' => 'Kanara (Inia)',
        'ko' => 'Kōreana',
        'ks' => 'Kahimiri',
        'ks_Arab' => 'Kahimiri (Arapika)',
        'ks_Arab_IN' => 'Kahimiri (Arapika, Inia)',
        'ks_Deva' => 'Kahimiri (Tewhangāngari)',
        'ks_Deva_IN' => 'Kahimiri (Tewhangāngari, Inia)',
        'ks_IN' => 'Kahimiri (Inia)',
        'ku' => 'Kūrihi',
        'kw' => 'Kōnihi',
        'kw_GB' => 'Kōnihi (Te Hononga o Piritene)',
        'ky' => 'Kēkete',
        'lb' => 'Rakimipēkihi',
        'lb_LU' => 'Rakimipēkihi (Rakimipēki)',
        'lg' => 'Kanāta',
        'lg_UG' => 'Kanāta (Ukāna)',
        'ln' => 'Ringarā',
        'ln_AO' => 'Ringarā (Anakora)',
        'ln_CD' => 'Ringarā (Kōngo - Kingihāha)',
        'ln_CF' => 'Ringarā (Te Puku o Āwherika)',
        'ln_CG' => 'Ringarā (Kōngo - Parāwhe)',
        'lo' => 'Rao',
        'lt' => 'Rihuainiana',
        'lt_LT' => 'Rihuainiana (Rituānia)',
        'lu' => 'Rupa Katanga',
        'lu_CD' => 'Rupa Katanga (Kōngo - Kingihāha)',
        'lv' => 'Rātiana',
        'lv_LV' => 'Rātiana (Ratawia)',
        'mg' => 'Marakāhi',
        'mg_MG' => 'Marakāhi (Marakāhia)',
        'mi' => 'Māori',
        'mi_NZ' => 'Māori (Aotearoa)',
        'mk' => 'Makatōniana',
        'mk_MK' => 'Makatōniana (Makerōnia ki te Raki)',
        'ml' => 'Mareiarama',
        'ml_IN' => 'Mareiarama (Inia)',
        'mn' => 'Mongōriana',
        'mr' => 'Marati',
        'mr_IN' => 'Marati (Inia)',
        'ms' => 'Marei',
        'mt' => 'Mōtīhi',
        'my' => 'Pūmīhī',
        'nb' => 'Pakamō Nōwītiana',
        'nb_NO' => 'Pakamō Nōwītiana (Nōwei)',
        'nb_SJ' => 'Pakamō Nōwītiana (Heopāra me Ia Maiana)',
        'nd' => 'Enetepēra ki te Raki',
        'nd_ZW' => 'Enetepēra ki te Raki (Timuwawe)',
        'ne' => 'Nepari',
        'ne_IN' => 'Nepari (Inia)',
        'nl' => 'Tati',
        'nl_AW' => 'Tati (Arūpa)',
        'nl_BE' => 'Tati (Paratiamu)',
        'nl_BQ' => 'Tati (Karepeana Hōrana)',
        'nl_CW' => 'Tati (Kurahao)',
        'nl_NL' => 'Tati (Hōrana)',
        'nl_SR' => 'Tati (Hurināme)',
        'nl_SX' => 'Tati (Hiti Mātene)',
        'nn' => 'Nīnōka Nōwītiana',
        'nn_NO' => 'Nīnōka Nōwītiana (Nōwei)',
        'no' => 'Nōwītiana',
        'no_NO' => 'Nōwītiana (Nōwei)',
        'om' => 'Ōromo',
        'om_ET' => 'Ōromo (Etiopia)',
        'om_KE' => 'Ōromo (Kēnia)',
        'or' => 'Ōtia',
        'or_IN' => 'Ōtia (Inia)',
        'os' => 'Ōtītiki',
        'os_RU' => 'Ōtītiki (Rūhia)',
        'pa' => 'Punutapi',
        'pa_Arab' => 'Punutapi (Arapika)',
        'pa_Guru' => 'Punutapi (Kūmuki)',
        'pa_Guru_IN' => 'Punutapi (Kūmuki, Inia)',
        'pa_IN' => 'Punutapi (Inia)',
        'pl' => 'Pōrīhi',
        'ps' => 'Pātio',
        'pt' => 'Pōtukīhi',
        'pt_AO' => 'Pōtukīhi (Anakora)',
        'pt_BR' => 'Pōtukīhi (Parīhi)',
        'pt_CH' => 'Pōtukīhi (Huiterangi)',
        'pt_CV' => 'Pōtukīhi (Te Kūrae Matomato)',
        'pt_GQ' => 'Pōtukīhi (Kini Ekuatoria)',
        'pt_GW' => 'Pōtukīhi (Kini-Pihao)',
        'pt_LU' => 'Pōtukīhi (Rakimipēki)',
        'pt_MZ' => 'Pōtukīhi (Mohapiki)',
        'pt_ST' => 'Pōtukīhi (Hao Tomei me Pirinipei)',
        'qu' => 'Kētua',
        'qu_BO' => 'Kētua (Poriwia)',
        'qu_EC' => 'Kētua (Ekuatoa)',
        'qu_PE' => 'Kētua (Peru)',
        'rm' => 'Romānihi',
        'rm_CH' => 'Romānihi (Huiterangi)',
        'rn' => 'Rūniti',
        'rn_BI' => 'Rūniti (Puruniti)',
        'ro' => 'Romēniana',
        'ru' => 'Ruhiana',
        'ru_RU' => 'Ruhiana (Rūhia)',
        'rw' => 'Kiniawāna',
        'rw_RW' => 'Kiniawāna (Rāwana)',
        'sa' => 'Hanahiti',
        'sa_IN' => 'Hanahiti (Inia)',
        'sc' => 'Hātīriana',
        'sc_IT' => 'Hātīriana (Itāria)',
        'sd' => 'Hiniti',
        'sd_Arab' => 'Hiniti (Arapika)',
        'sd_Deva' => 'Hiniti (Tewhangāngari)',
        'sd_Deva_IN' => 'Hiniti (Tewhangāngari, Inia)',
        'sd_IN' => 'Hiniti (Inia)',
        'se' => 'Hami ki te Raki',
        'se_FI' => 'Hami ki te Raki (Whinirana)',
        'se_NO' => 'Hami ki te Raki (Nōwei)',
        'se_SE' => 'Hami ki te Raki (Huītene)',
        'sg' => 'Hāngo',
        'sg_CF' => 'Hāngo (Te Puku o Āwherika)',
        'si' => 'Hinihāra',
        'sk' => 'Horowākia',
        'sl' => 'Horowēniana',
        'sn' => 'Hōna',
        'sn_ZW' => 'Hōna (Timuwawe)',
        'so' => 'Hamāri',
        'so_DJ' => 'Hamāri (Tipūti)',
        'so_ET' => 'Hamāri (Etiopia)',
        'so_KE' => 'Hamāri (Kēnia)',
        'so_SO' => 'Hamāri (Hūmārie)',
        'sq' => 'Arapeiniana',
        'sq_MK' => 'Arapeiniana (Makerōnia ki te Raki)',
        'sr' => 'Hēpiana',
        'sr_Cyrl' => 'Hēpiana (Hīririki)',
        'sr_Latn' => 'Hēpiana (Rātina)',
        'su' => 'Hunanīhi',
        'su_Latn' => 'Hunanīhi (Rātina)',
        'sv' => 'Huīteneana',
        'sv_AX' => 'Huīteneana (Motu Ōrana)',
        'sv_FI' => 'Huīteneana (Whinirana)',
        'sv_SE' => 'Huīteneana (Huītene)',
        'sw' => 'Wāhīri',
        'sw_CD' => 'Wāhīri (Kōngo - Kingihāha)',
        'sw_KE' => 'Wāhīri (Kēnia)',
        'sw_TZ' => 'Wāhīri (Tānahia)',
        'sw_UG' => 'Wāhīri (Ukāna)',
        'ta' => 'Tamira',
        'ta_IN' => 'Tamira (Inia)',
        'te' => 'Teruku',
        'te_IN' => 'Teruku (Inia)',
        'tg' => 'Tāhiki',
        'th' => 'Tai',
        'ti' => 'Tekirina',
        'ti_ER' => 'Tekirina (Eritēria)',
        'ti_ET' => 'Tekirina (Etiopia)',
        'tk' => 'Tākamana',
        'to' => 'Tonga',
        'tr' => 'Tākei',
        'tt' => 'Tatā',
        'tt_RU' => 'Tatā (Rūhia)',
        'ug' => 'Wīkura',
        'ug_CN' => 'Wīkura (Haina)',
        'uk' => 'Ukarainiana',
        'ur' => 'Ūru',
        'ur_IN' => 'Ūru (Inia)',
        'uz' => 'Ūpeke',
        'uz_Arab' => 'Ūpeke (Arapika)',
        'uz_Cyrl' => 'Ūpeke (Hīririki)',
        'uz_Latn' => 'Ūpeke (Rātina)',
        'vi' => 'Witināmiana',
        'wo' => 'Warawhe',
        'wo_SN' => 'Warawhe (Henekara)',
        'xh' => 'Tōha',
        'xh_ZA' => 'Tōha (Āwherika ki te Tonga)',
        'yi' => 'Irihi',
        'yi_001' => 'Irihi (te ao)',
        'yo' => 'Ōrūpa',
        'yo_BJ' => 'Ōrūpa (Penīna)',
        'yo_NG' => 'Ōrūpa (Ngāitiria)',
        'zh' => 'Hainamana',
        'zh_CN' => 'Hainamana (Haina)',
        'zh_Hans' => 'Hainamana (Māmā)',
        'zh_Hans_CN' => 'Hainamana (Māmā, Haina)',
        'zh_Hant' => 'Hainamana (Tuku iho)',
        'zu' => 'Tūru',
        'zu_ZA' => 'Tūru (Āwherika ki te Tonga)',
    ],
];
