<?php

return [
    'Names' => [
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albanese',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'florino antillan',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolan',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'peso argentin',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'dollar australian',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'florino aruban',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'marco convertibile de Bosnia-Herzegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dollar barbadian',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lev bulgare',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'franco burundese',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dollar bermudan',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviano bolivian',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'real brasilian',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dollar bahamian',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula botswanese',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rublo bielorusse',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dollar belizan',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'dollar canadian',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'franco congolese',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'franco suisse',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso chilen',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'yuan chinese',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso colombian',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colon costarican',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso cuban convertibile',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso cuban',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo capoverdian',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'corona chec',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Marco geman',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'franco djibutian',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'corona danese',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominican',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinar algerin',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Corona estonian',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'libra egyptie',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nakfa eritree',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr ethiope',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Marco finnese',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dollar fijian',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'libra falklandese',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franco francese',
        ],
        'GBP' => [
            0 => '£',
            1 => 'libra sterling',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cedi ghanese',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'libra de Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambian',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'franco guinean',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal guatemaltec',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dollar guyanese',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira hondurese',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna croate',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haitian',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'forint hungare',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Libra irlandese',
        ],
        'INR' => [
            0 => '₹',
            1 => 'rupia indian',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'corona islandese',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dollar jamaican',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'yen japonese',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'shilling kenyan',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'franco comorian',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dollar del Insulas Caiman',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dollar liberian',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinar libyc',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marocchin',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'leu moldave',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary malgache',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'denar macedonie',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ouguiya mauritan (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ouguiya mauritan',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupia mauritian',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha malawian',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'peso mexican',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical mozambican',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dollar namibian',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nigerian',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'cordoba nicaraguan',
        ],
        'NLG' => [
            0 => 'ƒ',
            1 => 'Florino nederlandese',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'corona norvegian',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'dollar neozelandese',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa panamen',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol peruvian',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina papuan',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'zloty polonese',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guarani paraguayan',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'leu romanian',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinar serbe',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'rublo russe',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'franco ruandese',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dollar del insulas Salomon',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupia seychellese',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'libra sudanese',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'corona svedese',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'libra de St. Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone sierraleonese',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'shilling somali',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dollar surinamese',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'libra sud-sudanese',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra de São Tomé e Príncipe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni swazilandese',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinar tunisian',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'paʻanga tongan',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dollar de Trinidad e Tobago',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'shilling tanzanian',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'hryvnia ukrainian',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'shilling ugandese',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'dollar statounitese',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso uruguayan',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'bolivar venezuelan (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'bolivar venezuelan',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu vanuatuan',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala samoan',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'franco CFA de Africa Central',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'dollar del Caribes Oriental',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'franco CFA de Africa Occidental',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'franco CFP',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand sudafrican',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha zambian',
        ],
    ],
];
