<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Arab',
        'Aran' => 'Nasztalik',
        'Armi' => 'Birodalmi arámi',
        'Armn' => 'Örmény',
        'Avst' => 'Avesztán',
        'Bali' => 'Balinéz',
        'Batk' => 'Batak',
        'Beng' => 'Bengáli',
        'Blis' => 'Bliss jelképrendszer',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brámi',
        'Brai' => 'Vakírás',
        'Bugi' => 'Buginéz',
        'Buhd' => 'Buhid',
        'Cakm' => 'Csakma',
        'Cans' => 'Egyesített kanadai őslakos jelek',
        'Cari' => 'Kari',
        'Cham' => 'Csám',
        'Cher' => 'Cseroki',
        'Copt' => 'Kopt',
        'Cprt' => 'Ciprusi',
        'Cyrl' => 'Cirill',
        'Cyrs' => 'Óegyházi szláv cirill',
        'Deva' => 'Devanagári',
        'Dsrt' => 'Deseret',
        'Egyd' => 'Egyiptomi demotikus',
        'Egyh' => 'Egyiptomi hieratikus',
        'Egyp' => 'Egyiptomi hieroglifák',
        'Ethi' => 'Etióp',
        'Geok' => 'Grúz kucsuri',
        'Geor' => 'Grúz',
        'Glag' => 'Glagolitikus',
        'Goth' => 'Gót',
        'Grek' => 'Görög',
        'Gujr' => 'Gudzsaráti',
        'Guru' => 'Gurmuki',
        'Hanb' => 'Han bopomofóval',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'Egyszerűsített',
        'Hant' => 'Hagyományos',
        'Hebr' => 'Héber',
        'Hira' => 'Hiragana',
        'Hmng' => 'Pahawh hmong',
        'Hrkt' => 'Katakana vagy hiragana',
        'Hung' => 'Ómagyar',
        'Inds' => 'Indus',
        'Ital' => 'Régi olasz',
        'Jamo' => 'Jamo',
        'Java' => 'Jávai',
        'Jpan' => 'Japán',
        'Kali' => 'Kajah li',
        'Kana' => 'Katakana',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Khmer',
        'Knda' => 'Kannada',
        'Kore' => 'Koreai',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Lao',
        'Latf' => 'Fraktur latin',
        'Latg' => 'Gael latin',
        'Latn' => 'Latin',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Lineáris A',
        'Linb' => 'Lineáris B',
        'Lyci' => 'Líciai',
        'Lydi' => 'Lídiai',
        'Mand' => 'Mandai',
        'Mani' => 'Manicheus',
        'Maya' => 'Maja hieroglifák',
        'Mero' => 'Meroitikus',
        'Mlym' => 'Malajálam',
        'Mong' => 'Mongol',
        'Moon' => 'Moon',
        'Mtei' => 'Meitei mayek',
        'Mymr' => 'Burmai',
        'Nkoo' => 'N’ko',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol chiki',
        'Orkh' => 'Orhon',
        'Orya' => 'Oriya',
        'Osma' => 'Oszmán',
        'Perm' => 'Ópermikus',
        'Phag' => 'Phags-pa',
        'Phli' => 'Felriatos pahlavi',
        'Phlp' => 'Psalter pahlavi',
        'Phlv' => 'Könyv pahlavi',
        'Phnx' => 'Főniciai',
        'Plrd' => 'Pollard fonetikus',
        'Prti' => 'Feliratos parthian',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Redzsang',
        'Rohg' => 'Hanifi',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runikus',
        'Samr' => 'Szamaritán',
        'Sara' => 'Szarati',
        'Saur' => 'Szaurastra',
        'Sgnw' => 'Jelírás',
        'Shaw' => 'Shaw ábécé',
        'Sidd' => 'Sziddham',
        'Sinh' => 'Szingaléz',
        'Sogd' => 'Szogd',
        'Sogo' => 'Ószogd',
        'Sund' => 'Szundanéz',
        'Sylo' => 'Sylheti nagári',
        'Syrc' => 'Szíriai',
        'Syre' => 'Estrangelo szíriai',
        'Syrj' => 'Nyugat-szíriai',
        'Syrn' => 'Kelet-szíriai',
        'Tagb' => 'Tagbanwa',
        'Tale' => 'Tai Le',
        'Talu' => 'Új tai lue',
        'Taml' => 'Tamil',
        'Tavt' => 'Tai viet',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Berber',
        'Tglg' => 'Tagalog',
        'Thaa' => 'Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Tibeti',
        'Ugar' => 'Ugari',
        'Vaii' => 'Vai',
        'Visp' => 'Látható beszéd',
        'Xpeo' => 'Óperzsa',
        'Xsux' => 'Ékírásos suméro-akkád',
        'Yiii' => 'Ji',
        'Zinh' => 'Származtatott',
        'Zmth' => 'Matematikai jelrendszer',
        'Zsye' => 'Emoji',
        'Zsym' => 'Szimbólum',
        'Zxxx' => 'Íratlan nyelvek kódja',
        'Zyyy' => 'Meghatározatlan',
    ],
];
