<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Afak' => 'afaka',
        'Aghb' => 'kaukasus-albansk',
        'Ahom' => 'ahom',
        'Arab' => 'arabisk',
        'Aran' => 'nastaliq',
        'Armi' => 'arameisk',
        'Armn' => 'armensk',
        'Avst' => 'avestisk',
        'Bali' => 'balinesisk',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bengalsk',
        'Blis' => 'blissymbol',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'punktskrift',
        'Bugi' => 'buginesisk',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'felles kanadiske urspråksstavelser',
        'Cari' => 'karisk',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'koptisk',
        'Cprt' => 'kypriotisk',
        'Cyrl' => 'kyrillisk',
        'Cyrs' => 'kirkeslavisk kyrillisk',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Dupl' => 'duployan stenografi',
        'Egyd' => 'egyptisk demotisk',
        'Egyh' => 'egyptisk hieratisk',
        'Egyp' => 'egyptiske hieroglyfer',
        'Elba' => 'elbasisk',
        'Ethi' => 'etiopisk',
        'Geok' => 'georgisk khutsuri',
        'Geor' => 'georgisk',
        'Glag' => 'glagolittisk',
        'Goth' => 'gotisk',
        'Gran' => 'gammeltamilsk',
        'Grek' => 'gresk',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han-kinesisk med bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'forenklet',
        'Hant' => 'tradisjonell',
        'Hatr' => 'hatransk armensk',
        'Hebr' => 'hebraisk',
        'Hira' => 'hiragana',
        'Hluw' => 'anatoliske hieroglyfer',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'japanske stavelsesskrifter',
        'Hung' => 'gammelungarsk',
        'Inds' => 'indus',
        'Ital' => 'gammelitalisk',
        'Jamo' => 'jamo',
        'Java' => 'javanesisk',
        'Jpan' => 'japansk',
        'Jurc' => 'jurchen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khojki',
        'Knda' => 'kannada',
        'Kore' => 'koreansk',
        'Kpel' => 'kpelle',
        'Kthi' => 'kaithisk',
        'Lana' => 'lanna',
        'Laoo' => 'laotisk',
        'Latf' => 'frakturlatinsk',
        'Latg' => 'gælisk latinsk',
        'Latn' => 'latinsk',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineær A',
        'Linb' => 'lineær B',
        'Lisu' => 'fraser',
        'Loma' => 'loma',
        'Lyci' => 'lykisk',
        'Lydi' => 'lydisk',
        'Mahj' => 'mahajani',
        'Mand' => 'mandaisk',
        'Mani' => 'manikeisk',
        'Maya' => 'maya-hieroglyfer',
        'Mend' => 'mende',
        'Merc' => 'meroitisk kursiv',
        'Mero' => 'meroitisk',
        'Mlym' => 'malayalam',
        'Modi' => 'modi',
        'Mong' => 'mongolsk',
        'Moon' => 'moon',
        'Mroo' => 'mro',
        'Mtei' => 'meitei-mayek',
        'Mult' => 'multani',
        'Mymr' => 'burmesisk',
        'Narb' => 'gammelnordarabisk',
        'Nbat' => 'nabataeansk',
        'Nkgb' => 'naxi geba',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogham',
        'Olck' => 'ol-chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'odia',
        'Osma' => 'osmanya',
        'Palm' => 'palmyrensk',
        'Pauc' => 'pau cin hau',
        'Perm' => 'gammelpermisk',
        'Phag' => 'phags-pa',
        'Phli' => 'inskripsjonspahlavi',
        'Phlp' => 'psalter pahlavi',
        'Phlv' => 'pahlavi',
        'Phnx' => 'fønikisk',
        'Plrd' => 'pollard-fonetisk',
        'Prti' => 'inskripsjonsparthisk',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'runer',
        'Samr' => 'samaritansk',
        'Sara' => 'sarati',
        'Sarb' => 'gammelsørarabisk',
        'Saur' => 'saurashtra',
        'Sgnw' => 'tegnskrift',
        'Shaw' => 'shavisk',
        'Shrd' => 'sharada',
        'Sidd' => 'siddham',
        'Sind' => 'khudawadi',
        'Sinh' => 'singalesisk',
        'Sora' => 'sora sompeng',
        'Sund' => 'sundanesisk',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'syrisk',
        'Syre' => 'estrangelosyriakisk',
        'Syrj' => 'vestlig syriakisk',
        'Syrn' => 'østlig syriakisk',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'ny tai lue',
        'Taml' => 'tamilsk',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'taana',
        'Thai' => 'thai',
        'Tibt' => 'tibetansk',
        'Tirh' => 'tirhuta',
        'Ugar' => 'ugaritisk',
        'Vaii' => 'vai',
        'Visp' => 'synlig tale',
        'Wara' => 'varang kshiti',
        'Wole' => 'woleai',
        'Xpeo' => 'gammelpersisk',
        'Xsux' => 'sumersk-akkadisk kileskrift',
        'Yiii' => 'yi',
        'Zinh' => 'nedarvet',
        'Zmth' => 'matematisk notasjon',
        'Zsye' => 'emoji',
        'Zsym' => 'symboler',
        'Zxxx' => 'språk uten skrift',
        'Zyyy' => 'felles',
    ],
];
