<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Ngonga ya Kotídivualɛ (Abidjan)',
        'Africa/Accra' => 'Ngonga ya Gana (Accra)',
        'Africa/Addis_Ababa' => 'Ngonga ya Etsíopi (Addis Ababa)',
        'Africa/Algiers' => 'Ngonga ya Alizɛri (Algiers)',
        'Africa/Asmera' => 'Ngonga ya Elitelɛ (Asmara)',
        'Africa/Bamako' => 'Ngonga ya Malí (Bamako)',
        'Africa/Bangui' => 'Ngonga ya Repibiki ya Afríka ya Káti (Bangui)',
        'Africa/Banjul' => 'Ngonga ya Gambi (Banjul)',
        'Africa/Bissau' => 'Ngonga ya Ginɛbisau (Bissau)',
        'Africa/Blantyre' => 'Ngonga ya Malawi (Blantyre)',
        'Africa/Brazzaville' => 'Ngonga ya Kongo (Brazzaville)',
        'Africa/Bujumbura' => 'Ngonga ya Burundi (Bujumbura)',
        'Africa/Cairo' => 'Ngonga ya Ezípite (Cairo)',
        'Africa/Casablanca' => 'Ngonga ya Marokɛ (Casablanca)',
        'Africa/Ceuta' => 'Ngonga ya Esipanye (Ceuta)',
        'Africa/Conakry' => 'Ngonga ya Ginɛ (Conakry)',
        'Africa/Dakar' => 'Ngonga ya Senegalɛ (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ngonga ya Tanzani (Dar es Salaam)',
        'Africa/Djibouti' => 'Ngonga ya Dzibuti (Djibouti)',
        'Africa/Douala' => 'Ngonga ya Kamɛrune (Douala)',
        'Africa/Freetown' => 'Ngonga ya Siera Leonɛ (Freetown)',
        'Africa/Gaborone' => 'Ngonga ya Botswana (Gaborone)',
        'Africa/Harare' => 'Ngonga ya Zimbabwe (Harare)',
        'Africa/Johannesburg' => 'Ngonga ya Afríka ya Súdi (Johannesburg)',
        'Africa/Kampala' => 'Ngonga ya Uganda (Kampala)',
        'Africa/Khartoum' => 'Ngonga ya Sudá (Khartoum)',
        'Africa/Kigali' => 'Ngonga ya Rwanda (Kigali)',
        'Africa/Kinshasa' => 'Ngonga ya Republíki ya Kongó Demokratíki (Kinshasa)',
        'Africa/Lagos' => 'Ngonga ya Nizerya (Lagos)',
        'Africa/Libreville' => 'Ngonga ya Gabɔ (Libreville)',
        'Africa/Lome' => 'Ngonga ya Togo (Lome)',
        'Africa/Luanda' => 'Ngonga ya Angóla (Luanda)',
        'Africa/Lubumbashi' => 'Ngonga ya Republíki ya Kongó Demokratíki (Lubumbashi)',
        'Africa/Lusaka' => 'Ngonga ya Zambi (Lusaka)',
        'Africa/Malabo' => 'Ngonga ya Ginɛ́kwatɛ́lɛ (Malabo)',
        'Africa/Maputo' => 'Ngonga ya Mozambíki (Maputo)',
        'Africa/Maseru' => 'Ngonga ya Lesoto (Maseru)',
        'Africa/Mbabane' => 'Ngonga ya Swazilandi (Mbabane)',
        'Africa/Mogadishu' => 'Ngonga ya Somali (Mogadishu)',
        'Africa/Monrovia' => 'Ngonga ya Libériya (Monrovia)',
        'Africa/Nairobi' => 'Ngonga ya Kenya (Nairobi)',
        'Africa/Ndjamena' => 'Ngonga ya Tsádi (Ndjamena)',
        'Africa/Niamey' => 'Ngonga ya Nizɛrɛ (Niamey)',
        'Africa/Nouakchott' => 'Ngonga ya Moritani (Nouakchott)',
        'Africa/Ouagadougou' => 'Ngonga ya Bukina Faso (Ouagadougou)',
        'Africa/Porto-Novo' => 'Ngonga ya Benɛ (Porto-Novo)',
        'Africa/Sao_Tome' => 'Ngonga ya Sao Tomé mpé Presipɛ (Sao Tome)',
        'Africa/Tripoli' => 'Ngonga ya Libí (Tripoli)',
        'Africa/Tunis' => 'Ngonga ya Tinizi (Tunis)',
        'Africa/Windhoek' => 'Ngonga ya Namibi (Windhoek)',
        'America/Adak' => 'Ngonga ya Ameriki (Adak)',
        'America/Anchorage' => 'Ngonga ya Ameriki (Anchorage)',
        'America/Anguilla' => 'Ngonga ya Angiyɛ (Anguilla)',
        'America/Antigua' => 'Ngonga ya Antiga mpé Barbuda (Antigua)',
        'America/Araguaina' => 'Ngonga ya Brezílɛ (Araguaina)',
        'America/Argentina/La_Rioja' => 'Ngonga ya Arizantinɛ (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Ngonga ya Arizantinɛ (Rio Gallegos)',
        'America/Argentina/Salta' => 'Ngonga ya Arizantinɛ (Salta)',
        'America/Argentina/San_Juan' => 'Ngonga ya Arizantinɛ (San Juan)',
        'America/Argentina/San_Luis' => 'Ngonga ya Arizantinɛ (San Luis)',
        'America/Argentina/Tucuman' => 'Ngonga ya Arizantinɛ (Tucuman)',
        'America/Argentina/Ushuaia' => 'Ngonga ya Arizantinɛ (Ushuaia)',
        'America/Aruba' => 'Ngonga ya Aruba (Aruba)',
        'America/Asuncion' => 'Ngonga ya Palagwei (Asuncion)',
        'America/Bahia' => 'Ngonga ya Brezílɛ (Bahia)',
        'America/Bahia_Banderas' => 'Ngonga ya Meksike (Bahia Banderas)',
        'America/Barbados' => 'Ngonga ya Barɛbadɛ (Barbados)',
        'America/Belem' => 'Ngonga ya Brezílɛ (Belem)',
        'America/Belize' => 'Ngonga ya Belizɛ (Belize)',
        'America/Blanc-Sablon' => 'Ngonga ya Kanada (Blanc-Sablon)',
        'America/Boa_Vista' => 'Ngonga ya Brezílɛ (Boa Vista)',
        'America/Bogota' => 'Ngonga ya Kolombi (Bogota)',
        'America/Boise' => 'Ngonga ya Ameriki (Boise)',
        'America/Buenos_Aires' => 'Ngonga ya Arizantinɛ (Buenos Aires)',
        'America/Cambridge_Bay' => 'Ngonga ya Kanada (Cambridge Bay)',
        'America/Campo_Grande' => 'Ngonga ya Brezílɛ (Campo Grande)',
        'America/Cancun' => 'Ngonga ya Meksike (Cancun)',
        'America/Caracas' => 'Ngonga ya Venézuela (Caracas)',
        'America/Catamarca' => 'Ngonga ya Arizantinɛ (Catamarca)',
        'America/Cayenne' => 'Ngonga ya Giyanɛ ya Falánsɛ (Cayenne)',
        'America/Cayman' => 'Ngonga ya Bisanga bya Kayíma (Cayman)',
        'America/Chicago' => 'Ngonga ya Ameriki (Chicago)',
        'America/Chihuahua' => 'Ngonga ya Meksike (Chihuahua)',
        'America/Coral_Harbour' => 'Ngonga ya Kanada (Atikokan)',
        'America/Cordoba' => 'Ngonga ya Arizantinɛ (Cordoba)',
        'America/Costa_Rica' => 'Ngonga ya Kositarika (Costa Rica)',
        'America/Creston' => 'Ngonga ya Kanada (Creston)',
        'America/Cuiaba' => 'Ngonga ya Brezílɛ (Cuiaba)',
        'America/Danmarkshavn' => 'Ngonga ya Gowelande (Danmarkshavn)',
        'America/Dawson' => 'Ngonga ya Kanada (Dawson)',
        'America/Dawson_Creek' => 'Ngonga ya Kanada (Dawson Creek)',
        'America/Denver' => 'Ngonga ya Ameriki (Denver)',
        'America/Detroit' => 'Ngonga ya Ameriki (Detroit)',
        'America/Dominica' => 'Ngonga ya Domínike (Dominica)',
        'America/Edmonton' => 'Ngonga ya Kanada (Edmonton)',
        'America/Eirunepe' => 'Ngonga ya Brezílɛ (Eirunepe)',
        'America/El_Salvador' => 'Ngonga ya Savadɔrɛ (El Salvador)',
        'America/Fort_Nelson' => 'Ngonga ya Kanada (Fort Nelson)',
        'America/Fortaleza' => 'Ngonga ya Brezílɛ (Fortaleza)',
        'America/Glace_Bay' => 'Ngonga ya Kanada (Glace Bay)',
        'America/Godthab' => 'Ngonga ya Gowelande (Nuuk)',
        'America/Goose_Bay' => 'Ngonga ya Kanada (Goose Bay)',
        'America/Grand_Turk' => 'Ngonga ya Bisanga bya Turki mpé Kaiko (Grand Turk)',
        'America/Grenada' => 'Ngonga ya Gelenadɛ (Grenada)',
        'America/Guadeloupe' => 'Ngonga ya Gwadɛlupɛ (Guadeloupe)',
        'America/Guatemala' => 'Ngonga ya Gwatémala (Guatemala)',
        'America/Guayaquil' => 'Ngonga ya Ekwatɛ́lɛ (Guayaquil)',
        'America/Guyana' => 'Ngonga ya Giyane (Guyana)',
        'America/Halifax' => 'Ngonga ya Kanada (Halifax)',
        'America/Havana' => 'Ngonga ya Kiba (Havana)',
        'America/Hermosillo' => 'Ngonga ya Meksike (Hermosillo)',
        'America/Indiana/Knox' => 'Ngonga ya Ameriki (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Ngonga ya Ameriki (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ngonga ya Ameriki (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ngonga ya Ameriki (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Ngonga ya Ameriki (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Ngonga ya Ameriki (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Ngonga ya Ameriki (Winamac, Indiana)',
        'America/Indianapolis' => 'Ngonga ya Ameriki (Indianapolis)',
        'America/Inuvik' => 'Ngonga ya Kanada (Inuvik)',
        'America/Iqaluit' => 'Ngonga ya Kanada (Iqaluit)',
        'America/Jamaica' => 'Ngonga ya Zamaiki (Jamaica)',
        'America/Jujuy' => 'Ngonga ya Arizantinɛ (Jujuy)',
        'America/Juneau' => 'Ngonga ya Ameriki (Juneau)',
        'America/Kentucky/Monticello' => 'Ngonga ya Ameriki (Monticello, Kentucky)',
        'America/La_Paz' => 'Ngonga ya Bolivi (La Paz)',
        'America/Lima' => 'Ngonga ya Péru (Lima)',
        'America/Los_Angeles' => 'Ngonga ya Ameriki (Los Angeles)',
        'America/Louisville' => 'Ngonga ya Ameriki (Louisville)',
        'America/Maceio' => 'Ngonga ya Brezílɛ (Maceio)',
        'America/Managua' => 'Ngonga ya Nikaragwa (Managua)',
        'America/Manaus' => 'Ngonga ya Brezílɛ (Manaus)',
        'America/Martinique' => 'Ngonga ya Martiniki (Martinique)',
        'America/Matamoros' => 'Ngonga ya Meksike (Matamoros)',
        'America/Mazatlan' => 'Ngonga ya Meksike (Mazatlan)',
        'America/Mendoza' => 'Ngonga ya Arizantinɛ (Mendoza)',
        'America/Menominee' => 'Ngonga ya Ameriki (Menominee)',
        'America/Merida' => 'Ngonga ya Meksike (Merida)',
        'America/Metlakatla' => 'Ngonga ya Ameriki (Metlakatla)',
        'America/Mexico_City' => 'Ngonga ya Meksike (Mexico City)',
        'America/Miquelon' => 'Ngonga ya Sántu pététo mpé Mikelɔ (Miquelon)',
        'America/Moncton' => 'Ngonga ya Kanada (Moncton)',
        'America/Monterrey' => 'Ngonga ya Meksike (Monterrey)',
        'America/Montevideo' => 'Ngonga ya Irigwei (Montevideo)',
        'America/Montreal' => 'Ngonga ya Kanada (Montreal)',
        'America/Montserrat' => 'Ngonga ya Mɔsera (Montserrat)',
        'America/Nassau' => 'Ngonga ya Bahamasɛ (Nassau)',
        'America/New_York' => 'Ngonga ya Ameriki (New York)',
        'America/Nipigon' => 'Ngonga ya Kanada (Nipigon)',
        'America/Nome' => 'Ngonga ya Ameriki (Nome)',
        'America/Noronha' => 'Ngonga ya Brezílɛ (Noronha)',
        'America/North_Dakota/Beulah' => 'Ngonga ya Ameriki (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Ngonga ya Ameriki (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Ngonga ya Ameriki (New Salem, North Dakota)',
        'America/Ojinaga' => 'Ngonga ya Meksike (Ojinaga)',
        'America/Panama' => 'Ngonga ya Panama (Panama)',
        'America/Pangnirtung' => 'Ngonga ya Kanada (Pangnirtung)',
        'America/Paramaribo' => 'Ngonga ya Surinamɛ (Paramaribo)',
        'America/Phoenix' => 'Ngonga ya Ameriki (Phoenix)',
        'America/Port-au-Prince' => 'Ngonga ya Ayiti (Port-au-Prince)',
        'America/Port_of_Spain' => 'Ngonga ya Tinidadɛ mpé Tobago (Port of Spain)',
        'America/Porto_Velho' => 'Ngonga ya Brezílɛ (Porto Velho)',
        'America/Puerto_Rico' => 'Ngonga ya Pɔtoriko (Puerto Rico)',
        'America/Punta_Arenas' => 'Ngonga ya Síli (Punta Arenas)',
        'America/Rainy_River' => 'Ngonga ya Kanada (Rainy River)',
        'America/Rankin_Inlet' => 'Ngonga ya Kanada (Rankin Inlet)',
        'America/Recife' => 'Ngonga ya Brezílɛ (Recife)',
        'America/Regina' => 'Ngonga ya Kanada (Regina)',
        'America/Resolute' => 'Ngonga ya Kanada (Resolute)',
        'America/Rio_Branco' => 'Ngonga ya Brezílɛ (Rio Branco)',
        'America/Santa_Isabel' => 'Ngonga ya Meksike (Santa Isabel)',
        'America/Santarem' => 'Ngonga ya Brezílɛ (Santarem)',
        'America/Santiago' => 'Ngonga ya Síli (Santiago)',
        'America/Santo_Domingo' => 'Ngonga ya Repibiki ya Domínikɛ (Santo Domingo)',
        'America/Sao_Paulo' => 'Ngonga ya Brezílɛ (Sao Paulo)',
        'America/Scoresbysund' => 'Ngonga ya Gowelande (Ittoqqortoormiit)',
        'America/Sitka' => 'Ngonga ya Ameriki (Sitka)',
        'America/St_Johns' => 'Ngonga ya Kanada (St. John’s)',
        'America/St_Kitts' => 'Ngonga ya Sántu krístofe mpé Nevɛ̀s (St. Kitts)',
        'America/St_Lucia' => 'Ngonga ya Sántu lisi (St. Lucia)',
        'America/St_Thomas' => 'Ngonga ya Bisanga bya Vierzi ya Ameriki (St. Thomas)',
        'America/St_Vincent' => 'Ngonga ya Sántu vesá mpé Gelenadinɛ (St. Vincent)',
        'America/Swift_Current' => 'Ngonga ya Kanada (Swift Current)',
        'America/Tegucigalpa' => 'Ngonga ya Ondurasɛ (Tegucigalpa)',
        'America/Thule' => 'Ngonga ya Gowelande (Thule)',
        'America/Thunder_Bay' => 'Ngonga ya Kanada (Thunder Bay)',
        'America/Tijuana' => 'Ngonga ya Meksike (Tijuana)',
        'America/Toronto' => 'Ngonga ya Kanada (Toronto)',
        'America/Tortola' => 'Ngonga ya Bisanga bya Vierzi ya Angɛlɛtɛ́lɛ (Tortola)',
        'America/Vancouver' => 'Ngonga ya Kanada (Vancouver)',
        'America/Whitehorse' => 'Ngonga ya Kanada (Whitehorse)',
        'America/Winnipeg' => 'Ngonga ya Kanada (Winnipeg)',
        'America/Yakutat' => 'Ngonga ya Ameriki (Yakutat)',
        'America/Yellowknife' => 'Ngonga ya Kanada (Yellowknife)',
        'Antarctica/Casey' => 'Ngonga ya Antarctique (Casey)',
        'Antarctica/Davis' => 'Ngonga ya Antarctique (Davis)',
        'Antarctica/DumontDUrville' => 'Ngonga ya Antarctique (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'Ngonga ya Ositáli (Macquarie)',
        'Antarctica/Mawson' => 'Ngonga ya Antarctique (Mawson)',
        'Antarctica/McMurdo' => 'Ngonga ya Antarctique (McMurdo)',
        'Antarctica/Palmer' => 'Ngonga ya Antarctique (Palmer)',
        'Antarctica/Rothera' => 'Ngonga ya Antarctique (Rothera)',
        'Antarctica/Syowa' => 'Ngonga ya Antarctique (Syowa)',
        'Antarctica/Troll' => 'Ngonga ya Troll',
        'Antarctica/Vostok' => 'Ngonga ya Antarctique (Vostok)',
        'Asia/Aden' => 'Ngonga ya Yemɛnɛ (Aden)',
        'Asia/Almaty' => 'Ngonga ya Kazakisitá (Almaty)',
        'Asia/Amman' => 'Ngonga ya Zɔdani (Amman)',
        'Asia/Anadyr' => 'Ngonga ya Risí (Anadyr)',
        'Asia/Aqtau' => 'Ngonga ya Kazakisitá (Aqtau)',
        'Asia/Aqtobe' => 'Ngonga ya Kazakisitá (Aqtobe)',
        'Asia/Ashgabat' => 'Ngonga ya Tikɛménisitá (Ashgabat)',
        'Asia/Atyrau' => 'Ngonga ya Kazakisitá (Atyrau)',
        'Asia/Baghdad' => 'Ngonga ya Iraki (Baghdad)',
        'Asia/Bahrain' => 'Ngonga ya Bahrɛnɛ (Bahrain)',
        'Asia/Baku' => 'Ngonga ya Azɛlɛbaizá (Baku)',
        'Asia/Bangkok' => 'Ngonga ya Tailandɛ (Bangkok)',
        'Asia/Barnaul' => 'Ngonga ya Risí (Barnaul)',
        'Asia/Beirut' => 'Ngonga ya Libá (Beirut)',
        'Asia/Bishkek' => 'Ngonga ya Kigizisitá (Bishkek)',
        'Asia/Brunei' => 'Ngonga ya Brineyi (Brunei)',
        'Asia/Calcutta' => 'Ngonga ya Índɛ (Kolkata)',
        'Asia/Chita' => 'Ngonga ya Risí (Chita)',
        'Asia/Choibalsan' => 'Ngonga ya Mongolí (Choibalsan)',
        'Asia/Colombo' => 'Ngonga ya Sirilanka (Colombo)',
        'Asia/Damascus' => 'Ngonga ya Sirí (Damascus)',
        'Asia/Dhaka' => 'Ngonga ya Bengalidɛsi (Dhaka)',
        'Asia/Dili' => 'Ngonga ya Timorɛ ya Moniɛlɛ (Dili)',
        'Asia/Dubai' => 'Ngonga ya Lɛmila alabo (Dubai)',
        'Asia/Dushanbe' => 'Ngonga ya Tazikisitá (Dushanbe)',
        'Asia/Famagusta' => 'Ngonga ya Sípɛlɛ (Famagusta)',
        'Asia/Gaza' => 'Ngonga ya Palɛsine (Gaza)',
        'Asia/Hebron' => 'Ngonga ya Palɛsine (Hebron)',
        'Asia/Hovd' => 'Ngonga ya Mongolí (Hovd)',
        'Asia/Irkutsk' => 'Ngonga ya Risí (Irkutsk)',
        'Asia/Jakarta' => 'Ngonga ya Indonezi (Jakarta)',
        'Asia/Jayapura' => 'Ngonga ya Indonezi (Jayapura)',
        'Asia/Jerusalem' => 'Ngonga ya Isirayelɛ (Jerusalem)',
        'Asia/Kabul' => 'Ngonga ya Afiganisitá (Kabul)',
        'Asia/Kamchatka' => 'Ngonga ya Risí (Kamchatka)',
        'Asia/Karachi' => 'Ngonga ya Pakisitá (Karachi)',
        'Asia/Katmandu' => 'Ngonga ya Nepálɛ (Kathmandu)',
        'Asia/Khandyga' => 'Ngonga ya Risí (Khandyga)',
        'Asia/Krasnoyarsk' => 'Ngonga ya Risí (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Ngonga ya Malezi (Kuala Lumpur)',
        'Asia/Kuching' => 'Ngonga ya Malezi (Kuching)',
        'Asia/Kuwait' => 'Ngonga ya Koweti (Kuwait)',
        'Asia/Magadan' => 'Ngonga ya Risí (Magadan)',
        'Asia/Makassar' => 'Ngonga ya Indonezi (Makassar)',
        'Asia/Manila' => 'Ngonga ya Filipinɛ (Manila)',
        'Asia/Muscat' => 'Ngonga ya Ománɛ (Muscat)',
        'Asia/Nicosia' => 'Ngonga ya Sípɛlɛ (Nicosia)',
        'Asia/Novokuznetsk' => 'Ngonga ya Risí (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Ngonga ya Risí (Novosibirsk)',
        'Asia/Omsk' => 'Ngonga ya Risí (Omsk)',
        'Asia/Oral' => 'Ngonga ya Kazakisitá (Oral)',
        'Asia/Phnom_Penh' => 'Ngonga ya Kambodza (Phnom Penh)',
        'Asia/Pontianak' => 'Ngonga ya Indonezi (Pontianak)',
        'Asia/Pyongyang' => 'Ngonga ya Korɛ ya nɔ́rdi (Pyongyang)',
        'Asia/Qatar' => 'Ngonga ya Katari (Qatar)',
        'Asia/Qostanay' => 'Ngonga ya Kazakisitá (Qostanay)',
        'Asia/Qyzylorda' => 'Ngonga ya Kazakisitá (Qyzylorda)',
        'Asia/Rangoon' => 'Ngonga ya Birmanie (Yangon)',
        'Asia/Riyadh' => 'Ngonga ya Alabi Sawuditɛ (Riyadh)',
        'Asia/Saigon' => 'Ngonga ya Viyetinamɛ (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Ngonga ya Risí (Sakhalin)',
        'Asia/Samarkand' => 'Ngonga ya Uzibɛkisitá (Samarkand)',
        'Asia/Seoul' => 'Ngonga ya Korɛ ya súdi (Seoul)',
        'Asia/Shanghai' => 'Ngonga ya Sinɛ (Shanghai)',
        'Asia/Singapore' => 'Ngonga ya Singapurɛ (Singapore)',
        'Asia/Srednekolymsk' => 'Ngonga ya Risí (Srednekolymsk)',
        'Asia/Taipei' => 'Ngonga ya Taiwanin (Taipei)',
        'Asia/Tashkent' => 'Ngonga ya Uzibɛkisitá (Tashkent)',
        'Asia/Tbilisi' => 'Ngonga ya Zorzi (Tbilisi)',
        'Asia/Tehran' => 'Ngonga ya Irâ (Tehran)',
        'Asia/Thimphu' => 'Ngonga ya Butáni (Thimphu)',
        'Asia/Tokyo' => 'Ngonga ya Zapɔ (Tokyo)',
        'Asia/Tomsk' => 'Ngonga ya Risí (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ngonga ya Mongolí (Ulaanbaatar)',
        'Asia/Urumqi' => 'Ngonga ya Sinɛ (Urumqi)',
        'Asia/Ust-Nera' => 'Ngonga ya Risí (Ust-Nera)',
        'Asia/Vientiane' => 'Ngonga ya Lawosi (Vientiane)',
        'Asia/Vladivostok' => 'Ngonga ya Risí (Vladivostok)',
        'Asia/Yakutsk' => 'Ngonga ya Risí (Yakutsk)',
        'Asia/Yekaterinburg' => 'Ngonga ya Risí (Yekaterinburg)',
        'Asia/Yerevan' => 'Ngonga ya Amɛni (Yerevan)',
        'Atlantic/Azores' => 'Ngonga ya Putúlugɛsi (Azores)',
        'Atlantic/Bermuda' => 'Ngonga ya Bermuda (Bermuda)',
        'Atlantic/Canary' => 'Ngonga ya Esipanye (Canary)',
        'Atlantic/Cape_Verde' => 'Ngonga ya Bisanga bya Kapevɛrɛ (Cape Verde)',
        'Atlantic/Madeira' => 'Ngonga ya Putúlugɛsi (Madeira)',
        'Atlantic/Reykjavik' => 'Ngonga ya Isilandɛ (Reykjavik)',
        'Atlantic/South_Georgia' => 'Ngonga ya Îles de Géorgie du Sud et Sandwich du Sud (South Georgia)',
        'Atlantic/St_Helena' => 'Ngonga ya Sántu eleni (St. Helena)',
        'Atlantic/Stanley' => 'Ngonga ya Bisanga bya Maluni (Stanley)',
        'Australia/Adelaide' => 'Ngonga ya Ositáli (Adelaide)',
        'Australia/Brisbane' => 'Ngonga ya Ositáli (Brisbane)',
        'Australia/Broken_Hill' => 'Ngonga ya Ositáli (Broken Hill)',
        'Australia/Currie' => 'Ngonga ya Ositáli (Currie)',
        'Australia/Darwin' => 'Ngonga ya Ositáli (Darwin)',
        'Australia/Eucla' => 'Ngonga ya Ositáli (Eucla)',
        'Australia/Hobart' => 'Ngonga ya Ositáli (Hobart)',
        'Australia/Lindeman' => 'Ngonga ya Ositáli (Lindeman)',
        'Australia/Lord_Howe' => 'Ngonga ya Ositáli (Lord Howe)',
        'Australia/Melbourne' => 'Ngonga ya Ositáli (Melbourne)',
        'Australia/Perth' => 'Ngonga ya Ositáli (Perth)',
        'Australia/Sydney' => 'Ngonga ya Ositáli (Sydney)',
        'Europe/Amsterdam' => 'Ngonga ya Olandɛ (Amsterdam)',
        'Europe/Andorra' => 'Ngonga ya Andorɛ (Andorra)',
        'Europe/Astrakhan' => 'Ngonga ya Risí (Astrakhan)',
        'Europe/Athens' => 'Ngonga ya Geleki (Athens)',
        'Europe/Belgrade' => 'Ngonga ya Serbie (Belgrade)',
        'Europe/Berlin' => 'Ngonga ya Alemani (Berlin)',
        'Europe/Bratislava' => 'Ngonga ya Silovaki (Bratislava)',
        'Europe/Brussels' => 'Ngonga ya Beleziki (Brussels)',
        'Europe/Bucharest' => 'Ngonga ya Romani (Bucharest)',
        'Europe/Budapest' => 'Ngonga ya Ongili (Budapest)',
        'Europe/Busingen' => 'Ngonga ya Alemani (Busingen)',
        'Europe/Chisinau' => 'Ngonga ya Molidavi (Chisinau)',
        'Europe/Copenhagen' => 'Ngonga ya Danɛmarike (Copenhagen)',
        'Europe/Dublin' => 'Ngonga ya Irelandɛ (Dublin)',
        'Europe/Gibraltar' => 'Ngonga ya Zibatalɛ (Gibraltar)',
        'Europe/Guernsey' => 'Ngonga ya Guernesey (Guernsey)',
        'Europe/Helsinki' => 'Ngonga ya Filandɛ (Helsinki)',
        'Europe/Istanbul' => 'Ngonga ya Tiliki (Istanbul)',
        'Europe/Kaliningrad' => 'Ngonga ya Risí (Kaliningrad)',
        'Europe/Kiev' => 'Ngonga ya Ikrɛni (Kyiv)',
        'Europe/Kirov' => 'Ngonga ya Risí (Kirov)',
        'Europe/Lisbon' => 'Ngonga ya Putúlugɛsi (Lisbon)',
        'Europe/Ljubljana' => 'Ngonga ya Siloveni (Ljubljana)',
        'Europe/London' => 'Ngonga ya Angɛlɛtɛ́lɛ (London)',
        'Europe/Luxembourg' => 'Ngonga ya Likisambulu (Luxembourg)',
        'Europe/Madrid' => 'Ngonga ya Esipanye (Madrid)',
        'Europe/Malta' => 'Ngonga ya Malitɛ (Malta)',
        'Europe/Minsk' => 'Ngonga ya Byelorisi (Minsk)',
        'Europe/Monaco' => 'Ngonga ya Monako (Monaco)',
        'Europe/Moscow' => 'Ngonga ya Risí (Moscow)',
        'Europe/Oslo' => 'Ngonga ya Norivezɛ (Oslo)',
        'Europe/Paris' => 'Ngonga ya Falánsɛ (Paris)',
        'Europe/Podgorica' => 'Ngonga ya Monténégro (Podgorica)',
        'Europe/Prague' => 'Ngonga ya Shekia (Prague)',
        'Europe/Riga' => 'Ngonga ya Letoni (Riga)',
        'Europe/Rome' => 'Ngonga ya Itali (Rome)',
        'Europe/Samara' => 'Ngonga ya Risí (Samara)',
        'Europe/San_Marino' => 'Ngonga ya Sántu Marinɛ (San Marino)',
        'Europe/Sarajevo' => 'Ngonga ya Bosini mpé Hezegovine (Sarajevo)',
        'Europe/Saratov' => 'Ngonga ya Risí (Saratov)',
        'Europe/Simferopol' => 'Ngonga ya Ikrɛni (Simferopol)',
        'Europe/Sofia' => 'Ngonga ya Biligari (Sofia)',
        'Europe/Stockholm' => 'Ngonga ya Swédɛ (Stockholm)',
        'Europe/Tallinn' => 'Ngonga ya Esitoni (Tallinn)',
        'Europe/Tirane' => 'Ngonga ya Alibani (Tirane)',
        'Europe/Ulyanovsk' => 'Ngonga ya Risí (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Ngonga ya Ikrɛni (Uzhgorod)',
        'Europe/Vaduz' => 'Ngonga ya Lishɛteni (Vaduz)',
        'Europe/Vatican' => 'Ngonga ya Vatiká (Vatican)',
        'Europe/Vienna' => 'Ngonga ya Otilisi (Vienna)',
        'Europe/Vilnius' => 'Ngonga ya Litwani (Vilnius)',
        'Europe/Volgograd' => 'Ngonga ya Risí (Volgograd)',
        'Europe/Warsaw' => 'Ngonga ya Poloni (Warsaw)',
        'Europe/Zagreb' => 'Ngonga ya Krowasi (Zagreb)',
        'Europe/Zaporozhye' => 'Ngonga ya Ikrɛni (Zaporozhye)',
        'Europe/Zurich' => 'Ngonga ya Swisɛ (Zurich)',
        'Indian/Antananarivo' => 'Ngonga ya Madagasikari (Antananarivo)',
        'Indian/Chagos' => 'Ngonga ya Mabelé ya Angɛlɛtɛ́lɛ na mbú ya Indiya (Chagos)',
        'Indian/Comoro' => 'Ngonga ya Komorɛ (Comoro)',
        'Indian/Kerguelen' => 'Ngonga ya Terres australes et antarctiques françaises (Kerguelen)',
        'Indian/Mahe' => 'Ngonga ya Sɛshɛlɛ (Mahe)',
        'Indian/Maldives' => 'Ngonga ya Madívɛ (Maldives)',
        'Indian/Mauritius' => 'Ngonga ya Morisɛ (Mauritius)',
        'Indian/Mayotte' => 'Ngonga ya Mayotɛ (Mayotte)',
        'Indian/Reunion' => 'Ngonga ya Lenyo (Reunion)',
        'Pacific/Apia' => 'Ngonga ya Samoa (Apia)',
        'Pacific/Auckland' => 'Ngonga ya Zelandɛ ya sika (Auckland)',
        'Pacific/Bougainville' => 'Ngonga ya Papwazi Ginɛ ya sika (Bougainville)',
        'Pacific/Chatham' => 'Ngonga ya Zelandɛ ya sika (Chatham)',
        'Pacific/Easter' => 'Ngonga ya Síli (Easter)',
        'Pacific/Efate' => 'Ngonga ya Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Ngonga ya Kiribati (Enderbury)',
        'Pacific/Fakaofo' => 'Ngonga ya Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Ngonga ya Fidzi (Fiji)',
        'Pacific/Funafuti' => 'Ngonga ya Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Ngonga ya Ekwatɛ́lɛ (Galapagos)',
        'Pacific/Gambier' => 'Ngonga ya Polinezi ya Falánsɛ (Gambier)',
        'Pacific/Guadalcanal' => 'Ngonga ya Bisanga Solomɔ (Guadalcanal)',
        'Pacific/Guam' => 'Ngonga ya Gwamɛ (Guam)',
        'Pacific/Honolulu' => 'Ngonga ya Ameriki (Honolulu)',
        'Pacific/Kiritimati' => 'Ngonga ya Kiribati (Kiritimati)',
        'Pacific/Kosrae' => 'Ngonga ya Mikronezi (Kosrae)',
        'Pacific/Kwajalein' => 'Ngonga ya Bisanga bya Marishalɛ (Kwajalein)',
        'Pacific/Majuro' => 'Ngonga ya Bisanga bya Marishalɛ (Majuro)',
        'Pacific/Marquesas' => 'Ngonga ya Polinezi ya Falánsɛ (Marquesas)',
        'Pacific/Nauru' => 'Ngonga ya Nauru (Nauru)',
        'Pacific/Niue' => 'Ngonga ya Nyué (Niue)',
        'Pacific/Norfolk' => 'Ngonga ya Esanga Norfokɛ (Norfolk)',
        'Pacific/Noumea' => 'Ngonga ya Kaledoni ya sika (Noumea)',
        'Pacific/Pago_Pago' => 'Ngonga ya Samoa ya Ameriki (Pago Pago)',
        'Pacific/Palau' => 'Ngonga ya Palau (Palau)',
        'Pacific/Pitcairn' => 'Ngonga ya Pikairni (Pitcairn)',
        'Pacific/Ponape' => 'Ngonga ya Mikronezi (Pohnpei)',
        'Pacific/Port_Moresby' => 'Ngonga ya Papwazi Ginɛ ya sika (Port Moresby)',
        'Pacific/Rarotonga' => 'Ngonga ya Bisanga bya Kookɛ (Rarotonga)',
        'Pacific/Saipan' => 'Ngonga ya Bisanga bya Marianɛ ya nɔ́rdi (Saipan)',
        'Pacific/Tahiti' => 'Ngonga ya Polinezi ya Falánsɛ (Tahiti)',
        'Pacific/Tarawa' => 'Ngonga ya Kiribati (Tarawa)',
        'Pacific/Tongatapu' => 'Ngonga ya Tonga (Tongatapu)',
        'Pacific/Truk' => 'Ngonga ya Mikronezi (Chuuk)',
        'Pacific/Wallis' => 'Ngonga ya Walisɛ mpé Futuna (Wallis)',
    ],
    'Meta' => [
    ],
];
