<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвичпа вӑтам вӑхӑчӗ (Абиджан)',
        'Africa/Accra' => 'Гринвичпа вӑтам вӑхӑчӗ (Аккра)',
        'Africa/Addis_Ababa' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Аддис-Абеба)',
        'Africa/Algiers' => 'Тӗп Европа вӑхӑчӗ (Алжир)',
        'Africa/Asmera' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Асмэра)',
        'Africa/Bamako' => 'Гринвичпа вӑтам вӑхӑчӗ (Бамако)',
        'Africa/Bangui' => 'Анӑҫ Африка вӑхӑчӗ (Банги)',
        'Africa/Banjul' => 'Гринвичпа вӑтам вӑхӑчӗ (Банжул)',
        'Africa/Bissau' => 'Гринвичпа вӑтам вӑхӑчӗ (Бисау)',
        'Africa/Blantyre' => 'Тӗп Африка вӑхӑчӗ (Блантайр)',
        'Africa/Brazzaville' => 'Анӑҫ Африка вӑхӑчӗ (Браззавиль)',
        'Africa/Bujumbura' => 'Тӗп Африка вӑхӑчӗ (Бужумбура)',
        'Africa/Cairo' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Каир)',
        'Africa/Casablanca' => 'Анӑҫ Европа вӑхӑчӗ (Касабланка)',
        'Africa/Ceuta' => 'Тӗп Европа вӑхӑчӗ (Сеута)',
        'Africa/Conakry' => 'Гринвичпа вӑтам вӑхӑчӗ (Конакри)',
        'Africa/Dakar' => 'Гринвичпа вӑтам вӑхӑчӗ (Дакар)',
        'Africa/Dar_es_Salaam' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Джибути)',
        'Africa/Douala' => 'Анӑҫ Африка вӑхӑчӗ (Дуала)',
        'Africa/El_Aaiun' => 'Анӑҫ Европа вӑхӑчӗ (Эль-Аюн)',
        'Africa/Freetown' => 'Гринвичпа вӑтам вӑхӑчӗ (Фритаун)',
        'Africa/Gaborone' => 'Тӗп Африка вӑхӑчӗ (Габороне)',
        'Africa/Harare' => 'Тӗп Африка вӑхӑчӗ (Хараре)',
        'Africa/Johannesburg' => 'Кӑнтӑр Африка вӑхӑчӗ (Йоханнесбург)',
        'Africa/Juba' => 'Тӗп Африка вӑхӑчӗ (Джуба)',
        'Africa/Kampala' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Кампала)',
        'Africa/Khartoum' => 'Тӗп Африка вӑхӑчӗ (Хартум)',
        'Africa/Kigali' => 'Тӗп Африка вӑхӑчӗ (Кигали)',
        'Africa/Kinshasa' => 'Анӑҫ Африка вӑхӑчӗ (Киншаса)',
        'Africa/Lagos' => 'Анӑҫ Африка вӑхӑчӗ (Лагос)',
        'Africa/Libreville' => 'Анӑҫ Африка вӑхӑчӗ (Либревиль)',
        'Africa/Lome' => 'Гринвичпа вӑтам вӑхӑчӗ (Ломе)',
        'Africa/Luanda' => 'Анӑҫ Африка вӑхӑчӗ (Луанда)',
        'Africa/Lubumbashi' => 'Тӗп Африка вӑхӑчӗ (Лубумбаши)',
        'Africa/Lusaka' => 'Тӗп Африка вӑхӑчӗ (Лусака)',
        'Africa/Malabo' => 'Анӑҫ Африка вӑхӑчӗ (Малабо)',
        'Africa/Maputo' => 'Тӗп Африка вӑхӑчӗ (Мапуту)',
        'Africa/Maseru' => 'Кӑнтӑр Африка вӑхӑчӗ (Масеру)',
        'Africa/Mbabane' => 'Кӑнтӑр Африка вӑхӑчӗ (Мбабане)',
        'Africa/Mogadishu' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Могадишо)',
        'Africa/Monrovia' => 'Гринвичпа вӑтам вӑхӑчӗ (Монрови)',
        'Africa/Nairobi' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Найроби)',
        'Africa/Ndjamena' => 'Анӑҫ Африка вӑхӑчӗ (Нджамена)',
        'Africa/Niamey' => 'Анӑҫ Африка вӑхӑчӗ (Ниамей)',
        'Africa/Nouakchott' => 'Гринвичпа вӑтам вӑхӑчӗ (Нуакшот)',
        'Africa/Ouagadougou' => 'Гринвичпа вӑтам вӑхӑчӗ (Уагадугу)',
        'Africa/Porto-Novo' => 'Анӑҫ Африка вӑхӑчӗ (Порто-Ново)',
        'Africa/Sao_Tome' => 'Гринвичпа вӑтам вӑхӑчӗ (Сан-Томе Сан-Томе)',
        'Africa/Tripoli' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Триполи)',
        'Africa/Tunis' => 'Тӗп Европа вӑхӑчӗ (Тунис)',
        'Africa/Windhoek' => 'Тӗп Африка вӑхӑчӗ (Виндхук)',
        'America/Adak' => 'Гавайи Алеут вӑхӑчӗ (Адак)',
        'America/Anchorage' => 'Аляска вӑхӑчӗ (Анкоридж)',
        'America/Anguilla' => 'Атлантика вӑхӑчӗ (Ангилья)',
        'America/Antigua' => 'Атлантика вӑхӑчӗ (Антигуа)',
        'America/Araguaina' => 'Бразили вӑхӑчӗ (Арагуаина)',
        'America/Argentina/La_Rioja' => 'Аргентина вӑхӑчӗ (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина вӑхӑчӗ (Рио-Гальегос)',
        'America/Argentina/Salta' => 'Аргентина вӑхӑчӗ (Сальта)',
        'America/Argentina/San_Juan' => 'Аргентина вӑхӑчӗ (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина вӑхӑчӗ (Сан-Луис Сан-Луис)',
        'America/Argentina/Tucuman' => 'Аргентина вӑхӑчӗ (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина вӑхӑчӗ (Ушуая)',
        'America/Aruba' => 'Атлантика вӑхӑчӗ (Аруба)',
        'America/Asuncion' => 'Парагвай вӑхӑчӗ (Асунсьон)',
        'America/Bahia' => 'Бразили вӑхӑчӗ (Баия)',
        'America/Bahia_Banderas' => 'Тӗп Америка вӑхӑчӗ (Баия-де-Бандерас)',
        'America/Barbados' => 'Атлантика вӑхӑчӗ (Барбадос)',
        'America/Belem' => 'Бразили вӑхӑчӗ (Белен)',
        'America/Belize' => 'Тӗп Америка вӑхӑчӗ (Белиз)',
        'America/Blanc-Sablon' => 'Атлантика вӑхӑчӗ (Бланк-Саблон)',
        'America/Boa_Vista' => 'Амазонка вӑхӑчӗ (Боа-Виста)',
        'America/Bogota' => 'Колумби вӑхӑчӗ (Богота)',
        'America/Boise' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Бойсе)',
        'America/Buenos_Aires' => 'Аргентина вӑхӑчӗ (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Кеймбридж-Бей)',
        'America/Campo_Grande' => 'Амазонка вӑхӑчӗ (Кампу-Гранди)',
        'America/Cancun' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Канкун)',
        'America/Caracas' => 'Венесуэла вӑхӑчӗ (Каракас)',
        'America/Catamarca' => 'Аргентина вӑхӑчӗ (Катамарка)',
        'America/Cayenne' => 'Франци Гвиана вӑхӑчӗ (Кайенна)',
        'America/Cayman' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Кайман утравӗсем)',
        'America/Chicago' => 'Тӗп Америка вӑхӑчӗ (Чикаго)',
        'America/Chihuahua' => 'Мексика Лӑпкӑ океан вӑхӑчӗ (Чиуауа)',
        'America/Coral_Harbour' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Корал-Харбор)',
        'America/Cordoba' => 'Аргентина вӑхӑчӗ (Кордова)',
        'America/Costa_Rica' => 'Тӗп Америка вӑхӑчӗ (Коста-Рика)',
        'America/Creston' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Крестон)',
        'America/Cuiaba' => 'Амазонка вӑхӑчӗ (Куяба)',
        'America/Curacao' => 'Атлантика вӑхӑчӗ (Кюрасао)',
        'America/Danmarkshavn' => 'Гринвичпа вӑтам вӑхӑчӗ (Денмарксхавн)',
        'America/Dawson' => 'Юкон вӑхӑчӗ (Доусон)',
        'America/Dawson_Creek' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Доусон-Крик)',
        'America/Denver' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Денвер)',
        'America/Detroit' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Детройт)',
        'America/Dominica' => 'Атлантика вӑхӑчӗ (Доминика)',
        'America/Edmonton' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Эдмонтон)',
        'America/Eirunepe' => 'Бразили (Эйрунепе)',
        'America/El_Salvador' => 'Тӗп Америка вӑхӑчӗ (Сальвадор)',
        'America/Fort_Nelson' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Форт Нельсон)',
        'America/Fortaleza' => 'Бразили вӑхӑчӗ (Форталеза)',
        'America/Glace_Bay' => 'Атлантика вӑхӑчӗ (Глейс-Бей)',
        'America/Godthab' => 'Анӑҫ Гринланди вӑхӑчӗ (Нуук)',
        'America/Goose_Bay' => 'Атлантика вӑхӑчӗ (Гус-Бей)',
        'America/Grand_Turk' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Гранд-Терк)',
        'America/Grenada' => 'Атлантика вӑхӑчӗ (Гренада)',
        'America/Guadeloupe' => 'Атлантика вӑхӑчӗ (Гваделупа)',
        'America/Guatemala' => 'Тӗп Америка вӑхӑчӗ (Гватемала)',
        'America/Guayaquil' => 'Эквадор вӑхӑчӗ (Гуаякиль)',
        'America/Guyana' => 'Гайана вӑхӑчӗ',
        'America/Halifax' => 'Атлантика вӑхӑчӗ (Галифакс)',
        'America/Havana' => 'Куба вӑхӑчӗ (Гавана)',
        'America/Hermosillo' => 'Мексика Лӑпкӑ океан вӑхӑчӗ (Эрмосильо)',
        'America/Indiana/Knox' => 'Тӗп Америка вӑхӑчӗ (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Питерсберг, Индиана)',
        'America/Indiana/Tell_City' => 'Тӗп Америка вӑхӑчӗ (Телл-Сити, Индиана)',
        'America/Indiana/Vevay' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Вевей, Индиана)',
        'America/Indiana/Vincennes' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Винсеннес, Индиана)',
        'America/Indiana/Winamac' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Уинамак, Индиана)',
        'America/Indianapolis' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Индианаполис)',
        'America/Inuvik' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Инувик)',
        'America/Iqaluit' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Икалуит)',
        'America/Jamaica' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Ямайка)',
        'America/Jujuy' => 'Аргентина вӑхӑчӗ (Жужуй)',
        'America/Juneau' => 'Аляска вӑхӑчӗ (Джуно)',
        'America/Kentucky/Monticello' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Монтиселло, Кентукки)',
        'America/Kralendijk' => 'Атлантика вӑхӑчӗ (Кралендейк)',
        'America/La_Paz' => 'Боливи вӑхӑчӗ (Ла-Пас)',
        'America/Lima' => 'Перу вӑхӑчӗ (Лима)',
        'America/Los_Angeles' => 'Лӑпкӑ океан вӑхӑчӗ (Лос-Анджелес)',
        'America/Louisville' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Луисвилл)',
        'America/Lower_Princes' => 'Атлантика вӑхӑчӗ (Лоуэр-Принс-Куотер)',
        'America/Maceio' => 'Бразили вӑхӑчӗ (Масейо)',
        'America/Managua' => 'Тӗп Америка вӑхӑчӗ (Манагуа)',
        'America/Manaus' => 'Амазонка вӑхӑчӗ (Манаус)',
        'America/Marigot' => 'Атлантика вӑхӑчӗ (Мариго)',
        'America/Martinique' => 'Атлантика вӑхӑчӗ (Мартиника)',
        'America/Matamoros' => 'Тӗп Америка вӑхӑчӗ (Матаморос)',
        'America/Mazatlan' => 'Мексика Лӑпкӑ океан вӑхӑчӗ (Масатлан)',
        'America/Mendoza' => 'Аргентина вӑхӑчӗ (Мендоса)',
        'America/Menominee' => 'Тӗп Америка вӑхӑчӗ (Меномини)',
        'America/Merida' => 'Тӗп Америка вӑхӑчӗ (Мерида)',
        'America/Metlakatla' => 'Аляска вӑхӑчӗ (Метлакатла)',
        'America/Mexico_City' => 'Тӗп Америка вӑхӑчӗ (Мехико)',
        'America/Miquelon' => 'Сен-Пьер тата Микелон вӑхӑчӗ',
        'America/Moncton' => 'Атлантика вӑхӑчӗ (Монктон)',
        'America/Monterrey' => 'Тӗп Америка вӑхӑчӗ (Монтеррей)',
        'America/Montevideo' => 'Уругвай вӑхӑчӗ (Монтевидео)',
        'America/Montreal' => 'Канада (Montreal)',
        'America/Montserrat' => 'Атлантика вӑхӑчӗ (Монтсеррат)',
        'America/Nassau' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Нассау)',
        'America/New_York' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Нью-Йорк)',
        'America/Nipigon' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Нипигон)',
        'America/Nome' => 'Аляска вӑхӑчӗ (Ном)',
        'America/Noronha' => 'Фернанду-ди-Норонья вӑхӑчӗ',
        'America/North_Dakota/Beulah' => 'Тӗп Америка вӑхӑчӗ (Бойла, Ҫурҫӗр Дакота)',
        'America/North_Dakota/Center' => 'Тӗп Америка вӑхӑчӗ (Центр, Ҫурҫӗр Дакота)',
        'America/North_Dakota/New_Salem' => 'Тӗп Америка вӑхӑчӗ (Нью-Сейлем, Ҫурҫӗр Дакота)',
        'America/Ojinaga' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Охинага)',
        'America/Panama' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Панама)',
        'America/Pangnirtung' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Пангниртанг)',
        'America/Paramaribo' => 'Суринам вӑхӑчӗ (Парамарибо)',
        'America/Phoenix' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Финикс)',
        'America/Port-au-Prince' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атлантика вӑхӑчӗ (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'Амазонка вӑхӑчӗ (Порту-Велью)',
        'America/Puerto_Rico' => 'Атлантика вӑхӑчӗ (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чили вӑхӑчӗ (Пунта-Аренас)',
        'America/Rainy_River' => 'Тӗп Америка вӑхӑчӗ (Рейни-Ривер)',
        'America/Rankin_Inlet' => 'Тӗп Америка вӑхӑчӗ (Ранкин-Инлет)',
        'America/Recife' => 'Бразили вӑхӑчӗ (Ресифи)',
        'America/Regina' => 'Тӗп Америка вӑхӑчӗ (Реджайна)',
        'America/Resolute' => 'Тӗп Америка вӑхӑчӗ (Резольют)',
        'America/Rio_Branco' => 'Бразили (Риу-Бранку)',
        'America/Santa_Isabel' => 'Ҫурҫӗр-анӑҫ Мексика вӑхӑчӗ (Santa Isabel)',
        'America/Santarem' => 'Бразили вӑхӑчӗ (Сантарен)',
        'America/Santiago' => 'Чили вӑхӑчӗ (Сантьяго)',
        'America/Santo_Domingo' => 'Атлантика вӑхӑчӗ (Санто-Доминго)',
        'America/Sao_Paulo' => 'Бразили вӑхӑчӗ (Сан-Паулу Сан-Паулу)',
        'America/Scoresbysund' => 'Хӗвелтухӑҫ Гринланди вӑхӑчӗ (Скорсбисунн)',
        'America/Sitka' => 'Аляска вӑхӑчӗ (Ситка)',
        'America/St_Barthelemy' => 'Атлантика вӑхӑчӗ (Сен-Бартелеми)',
        'America/St_Johns' => 'Ньюфаундленд вӑхӑчӗ (Сент-Джонс)',
        'America/St_Kitts' => 'Атлантика вӑхӑчӗ (Сент-Китс)',
        'America/St_Lucia' => 'Атлантика вӑхӑчӗ (Сент-Люсия)',
        'America/St_Thomas' => 'Атлантика вӑхӑчӗ (Сент-Томас)',
        'America/St_Vincent' => 'Атлантика вӑхӑчӗ (Сент-Винсент)',
        'America/Swift_Current' => 'Тӗп Америка вӑхӑчӗ (Свифт-Керрент)',
        'America/Tegucigalpa' => 'Тӗп Америка вӑхӑчӗ (Тегусигальпа)',
        'America/Thule' => 'Атлантика вӑхӑчӗ (Туле)',
        'America/Thunder_Bay' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Тандер-Бей)',
        'America/Tijuana' => 'Лӑпкӑ океан вӑхӑчӗ (Тихуана)',
        'America/Toronto' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ (Торонто)',
        'America/Tortola' => 'Атлантика вӑхӑчӗ (Тортола)',
        'America/Vancouver' => 'Лӑпкӑ океан вӑхӑчӗ (Ванкувер)',
        'America/Whitehorse' => 'Юкон вӑхӑчӗ (Уайтхорс)',
        'America/Winnipeg' => 'Тӗп Америка вӑхӑчӗ (Виннипег)',
        'America/Yakutat' => 'Аляска вӑхӑчӗ (Якутат)',
        'America/Yellowknife' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка) (Йеллоунайф)',
        'Antarctica/Casey' => 'Антарктида (Кейси)',
        'Antarctica/Davis' => 'Дейвис вӑхӑчӗ',
        'Antarctica/DumontDUrville' => 'Дюмон-д’Юрвиль вӑхӑчӗ (Дюмон-д’Юрвиль Дюмон-д’Юрвиль)',
        'Antarctica/Macquarie' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Маккуори)',
        'Antarctica/Mawson' => 'Моусон вӑхӑчӗ',
        'Antarctica/McMurdo' => 'Ҫӗнӗ Зеланди вӑхӑчӗ (Мак-Мердо)',
        'Antarctica/Palmer' => 'Чили вӑхӑчӗ (Палмер)',
        'Antarctica/Rothera' => 'Ротера вӑхӑчӗ',
        'Antarctica/Syowa' => 'Сёва вӑхӑчӗ',
        'Antarctica/Troll' => 'Гринвичпа вӑтам вӑхӑчӗ (Тролль)',
        'Antarctica/Vostok' => 'Восток вӑхӑчӗ',
        'Arctic/Longyearbyen' => 'Тӗп Европа вӑхӑчӗ (Лонгйир)',
        'Asia/Aden' => 'Арап вӑхӑчӗ (Аден)',
        'Asia/Almaty' => 'Хӗвелтухӑҫ Казахстан вӑхӑчӗ (Алматы)',
        'Asia/Amman' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Амман)',
        'Asia/Anadyr' => 'Раҫҫей (Анадырь)',
        'Asia/Aqtau' => 'Анӑҫ Казахстан вӑхӑчӗ (Актау)',
        'Asia/Aqtobe' => 'Анӑҫ Казахстан вӑхӑчӗ (Актобе)',
        'Asia/Ashgabat' => 'Туркменистан вӑхӑчӗ (Ашхабад)',
        'Asia/Atyrau' => 'Анӑҫ Казахстан вӑхӑчӗ (Атырау)',
        'Asia/Baghdad' => 'Арап вӑхӑчӗ (Багдад)',
        'Asia/Bahrain' => 'Арап вӑхӑчӗ (Бахрейн)',
        'Asia/Baku' => 'Азербайджан вӑхӑчӗ (Баку)',
        'Asia/Bangkok' => 'Индокитай вӑхӑчӗ (Бангкок)',
        'Asia/Barnaul' => 'Раҫҫей (Барнаул)',
        'Asia/Beirut' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Бейрут)',
        'Asia/Bishkek' => 'Киргизи вӑхӑчӗ (Бишкек)',
        'Asia/Brunei' => 'Бруней-Даруссалам вӑхӑчӗ',
        'Asia/Calcutta' => 'Инди вӑхӑчӗ (Калькутта)',
        'Asia/Chita' => 'Якутск вӑхӑчӗ (Чита)',
        'Asia/Choibalsan' => 'Улан-Батор вӑхӑчӗ (Чойбалсан)',
        'Asia/Colombo' => 'Инди вӑхӑчӗ (Коломбо)',
        'Asia/Damascus' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Дамаск)',
        'Asia/Dhaka' => 'Бангладеш вӑхӑчӗ (Дакка)',
        'Asia/Dili' => 'Хӗвелтухӑҫ Тимор вӑхӑчӗ (Дили)',
        'Asia/Dubai' => 'Перси залив вӑхӑчӗ (Дубай)',
        'Asia/Dushanbe' => 'Таджикистан вӑхӑчӗ (Душанбе)',
        'Asia/Famagusta' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Фамагуста)',
        'Asia/Gaza' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Газа)',
        'Asia/Hebron' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Хеврон)',
        'Asia/Hong_Kong' => 'Гонконг вӑхӑчӗ',
        'Asia/Hovd' => 'Ховд вӑхӑчӗ',
        'Asia/Irkutsk' => 'Иркутск вӑхӑчӗ',
        'Asia/Jakarta' => 'Анӑҫ Индонези вӑхӑчӗ (Джакарта)',
        'Asia/Jayapura' => 'Хӗвелтухӑҫ Индонези вӑхӑчӗ (Джаяпура)',
        'Asia/Jerusalem' => 'Израиль вӑхӑчӗ (Иерусалим)',
        'Asia/Kabul' => 'Афганистан вӑхӑчӗ (Кабул)',
        'Asia/Kamchatka' => 'Раҫҫей (Петропавловск-Камчатски)',
        'Asia/Karachi' => 'Пакистан вӑхӑчӗ (Карачи)',
        'Asia/Katmandu' => 'Непал вӑхӑчӗ (Катманду)',
        'Asia/Khandyga' => 'Якутск вӑхӑчӗ (Хандыга)',
        'Asia/Krasnoyarsk' => 'Красноярск вӑхӑчӗ',
        'Asia/Kuala_Lumpur' => 'Малайзи вӑхӑчӗ (Куала-Лумпур)',
        'Asia/Kuching' => 'Малайзи вӑхӑчӗ (Кучинг)',
        'Asia/Kuwait' => 'Арап вӑхӑчӗ (Кувейт)',
        'Asia/Macau' => 'Китай вӑхӑчӗ (Макао)',
        'Asia/Magadan' => 'Магадан вӑхӑчӗ',
        'Asia/Makassar' => 'Тӗп Индонези вӑхӑчӗ (Макасар)',
        'Asia/Manila' => 'Филиппинсем вӑхӑчӗ (Манила)',
        'Asia/Muscat' => 'Перси залив вӑхӑчӗ (Маскат)',
        'Asia/Nicosia' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Никоси)',
        'Asia/Novokuznetsk' => 'Красноярск вӑхӑчӗ (Новокузнецк)',
        'Asia/Novosibirsk' => 'Новосибирск вӑхӑчӗ',
        'Asia/Omsk' => 'Омск вӑхӑчӗ',
        'Asia/Oral' => 'Анӑҫ Казахстан вӑхӑчӗ (Уральск)',
        'Asia/Phnom_Penh' => 'Индокитай вӑхӑчӗ (Пномпень)',
        'Asia/Pontianak' => 'Анӑҫ Индонези вӑхӑчӗ (Понтианак)',
        'Asia/Pyongyang' => 'Корей вӑхӑчӗ (Пхеньян)',
        'Asia/Qatar' => 'Арап вӑхӑчӗ (Катар)',
        'Asia/Qostanay' => 'Хӗвелтухӑҫ Казахстан вӑхӑчӗ (Костанай)',
        'Asia/Qyzylorda' => 'Анӑҫ Казахстан вӑхӑчӗ (Кызылорда)',
        'Asia/Rangoon' => 'Мьянма вӑхӑчӗ (Янгон)',
        'Asia/Riyadh' => 'Арап вӑхӑчӗ (Эр-Рияд)',
        'Asia/Saigon' => 'Индокитай вӑхӑчӗ (Хошимин)',
        'Asia/Sakhalin' => 'Сахалин вӑхӑчӗ (Сахалин утравӗ)',
        'Asia/Samarkand' => 'Узбекистан вӑхӑчӗ (Самарканд)',
        'Asia/Seoul' => 'Корей вӑхӑчӗ (Сеул)',
        'Asia/Shanghai' => 'Китай вӑхӑчӗ (Шанхай)',
        'Asia/Singapore' => 'Сингапур вӑхӑчӗ',
        'Asia/Srednekolymsk' => 'Магадан вӑхӑчӗ (Среднеколымск)',
        'Asia/Taipei' => 'Тайпей вӑхӑчӗ (Тайбэй)',
        'Asia/Tashkent' => 'Узбекистан вӑхӑчӗ (Ташкент)',
        'Asia/Tbilisi' => 'Грузи вӑхӑчӗ (Тбилиси)',
        'Asia/Tehran' => 'Иран вӑхӑчӗ (Тегеран)',
        'Asia/Thimphu' => 'Бутан вӑхӑчӗ (Тхимпху)',
        'Asia/Tokyo' => 'Япони вӑхӑчӗ (Токио)',
        'Asia/Tomsk' => 'Раҫҫей (Томск)',
        'Asia/Ulaanbaatar' => 'Улан-Батор вӑхӑчӗ',
        'Asia/Urumqi' => 'Китай (Урумчи)',
        'Asia/Ust-Nera' => 'Владивосток вӑхӑчӗ (Усть-Нера)',
        'Asia/Vientiane' => 'Индокитай вӑхӑчӗ (Вьентьян)',
        'Asia/Vladivostok' => 'Владивосток вӑхӑчӗ',
        'Asia/Yakutsk' => 'Якутск вӑхӑчӗ',
        'Asia/Yekaterinburg' => 'Екатеринбург вӑхӑчӗ',
        'Asia/Yerevan' => 'Армени вӑхӑчӗ (Ереван)',
        'Atlantic/Azores' => 'Азор утравӗсен вӑхӑчӗ (Азор утравӗсем)',
        'Atlantic/Bermuda' => 'Атлантика вӑхӑчӗ (Бермуд утравӗсем)',
        'Atlantic/Canary' => 'Анӑҫ Европа вӑхӑчӗ (Канар утравӗсем)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде вӑхӑчӗ',
        'Atlantic/Faeroe' => 'Анӑҫ Европа вӑхӑчӗ (Фарер утравӗсем)',
        'Atlantic/Madeira' => 'Анӑҫ Европа вӑхӑчӗ (Мадейра)',
        'Atlantic/Reykjavik' => 'Гринвичпа вӑтам вӑхӑчӗ (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Кӑнтӑр Георги вӑхӑчӗ',
        'Atlantic/St_Helena' => 'Гринвичпа вӑтам вӑхӑчӗ (Сӑваплӑ Елена утравӗ)',
        'Atlantic/Stanley' => 'Фолкленд утравӗсен вӑхӑчӗ (Стэнли)',
        'Australia/Adelaide' => 'Тӗп Австрали вӑхӑчӗ (Аделаида)',
        'Australia/Brisbane' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Брисбен)',
        'Australia/Broken_Hill' => 'Тӗп Австрали вӑхӑчӗ (Брокен-Хилл)',
        'Australia/Currie' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Currie)',
        'Australia/Darwin' => 'Тӗп Австрали вӑхӑчӗ (Дарвин)',
        'Australia/Eucla' => 'Тӗп Австрали анӑҫ вӑхӑчӗ (Юкла)',
        'Australia/Hobart' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Хобарт)',
        'Australia/Lindeman' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд-Хау вӑхӑчӗ',
        'Australia/Melbourne' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Мельбурн)',
        'Australia/Perth' => 'Анӑҫ Австрали вӑхӑчӗ (Перт)',
        'Australia/Sydney' => 'Хӗвелтухӑҫ Австрали вӑхӑчӗ (Сидней)',
        'CST6CDT' => 'Тӗп Америка вӑхӑчӗ',
        'EST5EDT' => 'Хӗвелтухӑҫ Америка вӑхӑчӗ',
        'Etc/GMT' => 'Гринвичпа вӑтам вӑхӑчӗ',
        'Etc/UTC' => 'Пӗтӗм тӗнчери координацилене вӑхӑчӗ',
        'Europe/Amsterdam' => 'Тӗп Европа вӑхӑчӗ (Амстердам)',
        'Europe/Andorra' => 'Тӗп Европа вӑхӑчӗ (Андорра)',
        'Europe/Astrakhan' => 'Мускав вӑхӑчӗ (Астрахань)',
        'Europe/Athens' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Афинсем)',
        'Europe/Belgrade' => 'Тӗп Европа вӑхӑчӗ (Белград)',
        'Europe/Berlin' => 'Тӗп Европа вӑхӑчӗ (Берлин)',
        'Europe/Bratislava' => 'Тӗп Европа вӑхӑчӗ (Братислава)',
        'Europe/Brussels' => 'Тӗп Европа вӑхӑчӗ (Брюссель)',
        'Europe/Bucharest' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Бухарест)',
        'Europe/Budapest' => 'Тӗп Европа вӑхӑчӗ (Будапешт)',
        'Europe/Busingen' => 'Тӗп Европа вӑхӑчӗ (Бюзинген)',
        'Europe/Chisinau' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Кишинев)',
        'Europe/Copenhagen' => 'Тӗп Европа вӑхӑчӗ (Копенгаген)',
        'Europe/Dublin' => 'Гринвичпа вӑтам вӑхӑчӗ (Дублин)',
        'Europe/Gibraltar' => 'Тӗп Европа вӑхӑчӗ (Гибралтар)',
        'Europe/Guernsey' => 'Гринвичпа вӑтам вӑхӑчӗ (Гернси)',
        'Europe/Helsinki' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Хельсинки)',
        'Europe/Isle_of_Man' => 'Гринвичпа вӑтам вӑхӑчӗ (Мэн утравӗ)',
        'Europe/Istanbul' => 'Турци (Стамбул)',
        'Europe/Jersey' => 'Гринвичпа вӑтам вӑхӑчӗ (Джерси)',
        'Europe/Kaliningrad' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Калининград)',
        'Europe/Kiev' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Киев)',
        'Europe/Kirov' => 'Раҫҫей (Киров)',
        'Europe/Lisbon' => 'Анӑҫ Европа вӑхӑчӗ (Лиссабон)',
        'Europe/Ljubljana' => 'Тӗп Европа вӑхӑчӗ (Любляна)',
        'Europe/London' => 'Гринвичпа вӑтам вӑхӑчӗ (Лондон)',
        'Europe/Luxembourg' => 'Тӗп Европа вӑхӑчӗ (Люксембург)',
        'Europe/Madrid' => 'Тӗп Европа вӑхӑчӗ (Мадрид)',
        'Europe/Malta' => 'Тӗп Европа вӑхӑчӗ (Мальта)',
        'Europe/Mariehamn' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Мариехамн)',
        'Europe/Minsk' => 'Мускав вӑхӑчӗ (Минск)',
        'Europe/Monaco' => 'Тӗп Европа вӑхӑчӗ (Монако)',
        'Europe/Moscow' => 'Мускав вӑхӑчӗ',
        'Europe/Oslo' => 'Тӗп Европа вӑхӑчӗ (Осло)',
        'Europe/Paris' => 'Тӗп Европа вӑхӑчӗ (Париж)',
        'Europe/Podgorica' => 'Тӗп Европа вӑхӑчӗ (Подгорица)',
        'Europe/Prague' => 'Тӗп Европа вӑхӑчӗ (Прага)',
        'Europe/Riga' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Рига)',
        'Europe/Rome' => 'Тӗп Европа вӑхӑчӗ (Рим)',
        'Europe/Samara' => 'Раҫҫей (Самара)',
        'Europe/San_Marino' => 'Тӗп Европа вӑхӑчӗ (Сан-Марино)',
        'Europe/Sarajevo' => 'Тӗп Европа вӑхӑчӗ (Сараево)',
        'Europe/Saratov' => 'Мускав вӑхӑчӗ (Саратов)',
        'Europe/Simferopol' => 'Мускав вӑхӑчӗ (Симферополь)',
        'Europe/Skopje' => 'Тӗп Европа вӑхӑчӗ (Скопье)',
        'Europe/Sofia' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Софи)',
        'Europe/Stockholm' => 'Тӗп Европа вӑхӑчӗ (Стокгольм)',
        'Europe/Tallinn' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Таллин)',
        'Europe/Tirane' => 'Тӗп Европа вӑхӑчӗ (Тирана)',
        'Europe/Ulyanovsk' => 'Мускав вӑхӑчӗ (Ульяновск)',
        'Europe/Uzhgorod' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Ужгород)',
        'Europe/Vaduz' => 'Тӗп Европа вӑхӑчӗ (Вадуц)',
        'Europe/Vatican' => 'Тӗп Европа вӑхӑчӗ (Ватикан)',
        'Europe/Vienna' => 'Тӗп Европа вӑхӑчӗ (Вена)',
        'Europe/Vilnius' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Вильнюс)',
        'Europe/Volgograd' => 'Волгоград вӑхӑчӗ',
        'Europe/Warsaw' => 'Тӗп Европа вӑхӑчӗ (Варшава)',
        'Europe/Zagreb' => 'Тӗп Европа вӑхӑчӗ (Загреб)',
        'Europe/Zaporozhye' => 'Хӗвелтухӑҫ Европа вӑхӑчӗ (Запорожье)',
        'Europe/Zurich' => 'Тӗп Европа вӑхӑчӗ (Цюрих)',
        'Indian/Antananarivo' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Антананариву)',
        'Indian/Chagos' => 'Инди океанӗ вӑхӑчӗ (Чагос)',
        'Indian/Christmas' => 'Раштав утравӗн вӑхӑчӗ',
        'Indian/Cocos' => 'Кокос утравӗсен вӑхӑчӗ (Кокос утравӗсем)',
        'Indian/Comoro' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Коморсем)',
        'Indian/Kerguelen' => 'Франци Кӑнтӑрпа Антарктика территорийӗсен вӑхӑчӗ (Кергелен)',
        'Indian/Mahe' => 'Сейшел утравӗсен вӑхӑчӗ (Маэ)',
        'Indian/Maldives' => 'Мальдивсем вӑхӑчӗ',
        'Indian/Mauritius' => 'Маврикий вӑхӑчӗ',
        'Indian/Mayotte' => 'Хӗвелтухӑҫ Африка вӑхӑчӗ (Майотта)',
        'Indian/Reunion' => 'Реюньон вӑхӑчӗ',
        'MST7MDT' => 'Ту вӑхӑчӗ (Ҫурҫӗр Америка)',
        'PST8PDT' => 'Лӑпкӑ океан вӑхӑчӗ',
        'Pacific/Apia' => 'Апиа вӑхӑчӗ',
        'Pacific/Auckland' => 'Ҫӗнӗ Зеланди вӑхӑчӗ (Окленд)',
        'Pacific/Bougainville' => 'Папуа — Ҫӗнӗ Гвиней вӑхӑчӗ (Бугенвиль)',
        'Pacific/Chatham' => 'Чатем вӑхӑчӗ',
        'Pacific/Easter' => 'Мӑнкун утравӗн вӑхӑчӗ',
        'Pacific/Efate' => 'Вануату вӑхӑчӗ (Эфате)',
        'Pacific/Enderbury' => 'Феникс вӑхӑчӗ (Enderbury)',
        'Pacific/Fakaofo' => 'Токелау вӑхӑчӗ (Факаофо)',
        'Pacific/Fiji' => 'Фиджи вӑхӑчӗ',
        'Pacific/Funafuti' => 'Тувалу вӑхӑчӗ (Фунафути)',
        'Pacific/Galapagos' => 'Галапагос утравӗсен вӑхӑчӗ (Галапагос утравӗсем)',
        'Pacific/Gambier' => 'Гамбье вӑхӑчӗ (Гамбье утравӗсем)',
        'Pacific/Guadalcanal' => 'Соломон вӑхӑчӗ (Гуадалканал)',
        'Pacific/Guam' => 'Чаморро вӑхӑчӗ (Гуам)',
        'Pacific/Honolulu' => 'Гавайи Алеут вӑхӑчӗ (Honolulu)',
        'Pacific/Johnston' => 'Гавайи Алеут вӑхӑчӗ (Джонстон)',
        'Pacific/Kiritimati' => 'Лайн утравӗсен вӑхӑчӗ (Киритимати)',
        'Pacific/Kosrae' => 'Косрае вӑхӑчӗ',
        'Pacific/Kwajalein' => 'Маршалл утравӗсен вӑхӑчӗ (Кваджалейн)',
        'Pacific/Majuro' => 'Маршалл утравӗсен вӑхӑчӗ (Маджуро)',
        'Pacific/Marquesas' => 'Маркизас утравӗсен вӑхӑчӗ (Маркизас утравӗсем)',
        'Pacific/Midway' => 'Самоа вӑхӑчӗ (Мидуэй)',
        'Pacific/Nauru' => 'Науру вӑхӑчӗ',
        'Pacific/Niue' => 'Ниуэ вӑхӑчӗ',
        'Pacific/Norfolk' => 'Норфолк вӑхӑчӗ',
        'Pacific/Noumea' => 'Ҫӗнӗ Каледони вӑхӑчӗ (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа вӑхӑчӗ (Паго-Паго)',
        'Pacific/Palau' => 'Палау вӑхӑчӗ',
        'Pacific/Pitcairn' => 'Питкэрн вӑхӑчӗ',
        'Pacific/Ponape' => 'Понпеи вӑхӑчӗ',
        'Pacific/Port_Moresby' => 'Папуа — Ҫӗнӗ Гвиней вӑхӑчӗ (Порт-Морсби)',
        'Pacific/Rarotonga' => 'Кукӑн утравӗсен вӑхӑчӗ (Раротонга)',
        'Pacific/Saipan' => 'Чаморро вӑхӑчӗ (Сайпан)',
        'Pacific/Tahiti' => 'Таити вӑхӑчӗ',
        'Pacific/Tarawa' => 'Гилбертӑн утравӗсен вӑхӑчӗ (Тарава)',
        'Pacific/Tongatapu' => 'Тонга вӑхӑчӗ (Тонгатапу)',
        'Pacific/Truk' => 'Трук вӑхӑчӗ',
        'Pacific/Wake' => 'Уэйк вӑхӑчӗ',
        'Pacific/Wallis' => 'Уоллис тата Футуна вӑхӑчӗ',
    ],
    'Meta' => [
    ],
];
