<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвич уртача вакыты (Abidjan)',
        'Africa/Accra' => 'Гринвич уртача вакыты (Accra)',
        'Africa/Addis_Ababa' => 'Эфиопия вакыты (Addis Ababa)',
        'Africa/Algiers' => 'Үзәк Европа вакыты (Algiers)',
        'Africa/Asmera' => 'Эритрея вакыты (Asmara)',
        'Africa/Bamako' => 'Гринвич уртача вакыты (Bamako)',
        'Africa/Bangui' => 'Үзәк Африка Республикасы вакыты (Bangui)',
        'Africa/Banjul' => 'Гринвич уртача вакыты (Banjul)',
        'Africa/Bissau' => 'Гринвич уртача вакыты (Bissau)',
        'Africa/Blantyre' => 'Малави вакыты (Blantyre)',
        'Africa/Bujumbura' => 'Бурунди вакыты (Bujumbura)',
        'Africa/Cairo' => 'Көнчыгыш Европа вакыты (Cairo)',
        'Africa/Casablanca' => 'Көнбатыш Европа вакыты (Casablanca)',
        'Africa/Ceuta' => 'Үзәк Европа вакыты (Ceuta)',
        'Africa/Conakry' => 'Гринвич уртача вакыты (Conakry)',
        'Africa/Dakar' => 'Гринвич уртача вакыты (Dakar)',
        'Africa/Dar_es_Salaam' => 'Танзания вакыты (Dar es Salaam)',
        'Africa/Djibouti' => 'Җибүти вакыты (Djibouti)',
        'Africa/Douala' => 'Камерун вакыты (Douala)',
        'Africa/El_Aaiun' => 'Көнбатыш Европа вакыты (El Aaiun)',
        'Africa/Freetown' => 'Гринвич уртача вакыты (Freetown)',
        'Africa/Gaborone' => 'Ботсвана вакыты (Gaborone)',
        'Africa/Harare' => 'Зимбабве вакыты (Harare)',
        'Africa/Johannesburg' => 'Көньяк Африка вакыты (Johannesburg)',
        'Africa/Juba' => 'Көньяк Судан вакыты (Juba)',
        'Africa/Kampala' => 'Уганда вакыты (Kampala)',
        'Africa/Khartoum' => 'Судан вакыты (Khartoum)',
        'Africa/Kigali' => 'Руанда вакыты (Kigali)',
        'Africa/Kinshasa' => 'Конго (КДР) вакыты (Kinshasa)',
        'Africa/Lagos' => 'Нигерия вакыты (Lagos)',
        'Africa/Libreville' => 'Габон вакыты (Libreville)',
        'Africa/Lome' => 'Гринвич уртача вакыты (Lome)',
        'Africa/Luanda' => 'Ангола вакыты (Luanda)',
        'Africa/Lubumbashi' => 'Конго (КДР) вакыты (Lubumbashi)',
        'Africa/Lusaka' => 'Замбия вакыты (Lusaka)',
        'Africa/Malabo' => 'Экваториаль Гвинея вакыты (Malabo)',
        'Africa/Maputo' => 'Мозамбик вакыты (Maputo)',
        'Africa/Maseru' => 'Лесото вакыты (Maseru)',
        'Africa/Mbabane' => 'Свазиленд вакыты (Mbabane)',
        'Africa/Mogadishu' => 'Сомали вакыты (Mogadishu)',
        'Africa/Monrovia' => 'Гринвич уртача вакыты (Monrovia)',
        'Africa/Nairobi' => 'Кения вакыты (Nairobi)',
        'Africa/Ndjamena' => 'Чад вакыты (Ndjamena)',
        'Africa/Niamey' => 'Нигер вакыты (Niamey)',
        'Africa/Nouakchott' => 'Гринвич уртача вакыты (Nouakchott)',
        'Africa/Ouagadougou' => 'Гринвич уртача вакыты (Ouagadougou)',
        'Africa/Porto-Novo' => 'Бенин вакыты (Porto-Novo)',
        'Africa/Sao_Tome' => 'Гринвич уртача вакыты (Sao Tome)',
        'Africa/Tripoli' => 'Көнчыгыш Европа вакыты (Tripoli)',
        'Africa/Tunis' => 'Үзәк Европа вакыты (Tunis)',
        'Africa/Windhoek' => 'Намибия вакыты (Windhoek)',
        'America/Adak' => 'АКШ вакыты (Adak)',
        'America/Anchorage' => 'АКШ вакыты (Anchorage)',
        'America/Anguilla' => 'Төньяк Америка атлантик вакыты (Anguilla)',
        'America/Antigua' => 'Төньяк Америка атлантик вакыты (Antigua)',
        'America/Araguaina' => 'Бразилия вакыты (Araguaina)',
        'America/Argentina/La_Rioja' => 'Аргентина вакыты (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина вакыты (Rio Gallegos)',
        'America/Argentina/Salta' => 'Аргентина вакыты (Salta)',
        'America/Argentina/San_Juan' => 'Аргентина вакыты (San Juan)',
        'America/Argentina/San_Luis' => 'Аргентина вакыты (San Luis)',
        'America/Argentina/Tucuman' => 'Аргентина вакыты (Tucuman)',
        'America/Argentina/Ushuaia' => 'Аргентина вакыты (Ushuaia)',
        'America/Aruba' => 'Төньяк Америка атлантик вакыты (Aruba)',
        'America/Asuncion' => 'Парагвай вакыты (Asuncion)',
        'America/Bahia' => 'Бразилия вакыты (Bahia)',
        'America/Bahia_Banderas' => 'Төньяк Америка үзәк вакыты (Bahia Banderas)',
        'America/Barbados' => 'Төньяк Америка атлантик вакыты (Barbados)',
        'America/Belem' => 'Бразилия вакыты (Belem)',
        'America/Belize' => 'Төньяк Америка үзәк вакыты (Belize)',
        'America/Blanc-Sablon' => 'Төньяк Америка атлантик вакыты (Blanc-Sablon)',
        'America/Boa_Vista' => 'Бразилия вакыты (Boa Vista)',
        'America/Bogota' => 'Колумбия вакыты (Bogota)',
        'America/Boise' => 'Төньяк Америка тау вакыты (Boise)',
        'America/Buenos_Aires' => 'Аргентина вакыты (Buenos Aires)',
        'America/Cambridge_Bay' => 'Төньяк Америка тау вакыты (Cambridge Bay)',
        'America/Campo_Grande' => 'Бразилия вакыты (Campo Grande)',
        'America/Cancun' => 'Төньяк Америка көнчыгыш вакыты (Cancun)',
        'America/Caracas' => 'Венесуэла вакыты (Caracas)',
        'America/Catamarca' => 'Аргентина вакыты (Catamarca)',
        'America/Cayenne' => 'Француз Гвианасы вакыты (Cayenne)',
        'America/Cayman' => 'Төньяк Америка көнчыгыш вакыты (Cayman)',
        'America/Chicago' => 'Төньяк Америка үзәк вакыты (Chicago)',
        'America/Chihuahua' => 'Мексика вакыты (Chihuahua)',
        'America/Coral_Harbour' => 'Төньяк Америка көнчыгыш вакыты (Atikokan)',
        'America/Cordoba' => 'Аргентина вакыты (Cordoba)',
        'America/Costa_Rica' => 'Төньяк Америка үзәк вакыты (Costa Rica)',
        'America/Creston' => 'Төньяк Америка тау вакыты (Creston)',
        'America/Cuiaba' => 'Бразилия вакыты (Cuiaba)',
        'America/Curacao' => 'Төньяк Америка атлантик вакыты (Curacao)',
        'America/Danmarkshavn' => 'Гринвич уртача вакыты (Danmarkshavn)',
        'America/Dawson' => 'Канада вакыты (Dawson)',
        'America/Dawson_Creek' => 'Төньяк Америка тау вакыты (Dawson Creek)',
        'America/Denver' => 'Төньяк Америка тау вакыты (Denver)',
        'America/Detroit' => 'Төньяк Америка көнчыгыш вакыты (Detroit)',
        'America/Dominica' => 'Төньяк Америка атлантик вакыты (Dominica)',
        'America/Edmonton' => 'Төньяк Америка тау вакыты (Edmonton)',
        'America/Eirunepe' => 'Бразилия вакыты (Eirunepe)',
        'America/El_Salvador' => 'Төньяк Америка үзәк вакыты (El Salvador)',
        'America/Fort_Nelson' => 'Төньяк Америка тау вакыты (Fort Nelson)',
        'America/Fortaleza' => 'Бразилия вакыты (Fortaleza)',
        'America/Glace_Bay' => 'Төньяк Америка атлантик вакыты (Glace Bay)',
        'America/Godthab' => 'Гренландия вакыты (Nuuk)',
        'America/Goose_Bay' => 'Төньяк Америка атлантик вакыты (Goose Bay)',
        'America/Grand_Turk' => 'Төньяк Америка көнчыгыш вакыты (Grand Turk)',
        'America/Grenada' => 'Төньяк Америка атлантик вакыты (Grenada)',
        'America/Guadeloupe' => 'Төньяк Америка атлантик вакыты (Guadeloupe)',
        'America/Guatemala' => 'Төньяк Америка үзәк вакыты (Guatemala)',
        'America/Guayaquil' => 'Эквадор вакыты (Guayaquil)',
        'America/Guyana' => 'Гайана вакыты (Guyana)',
        'America/Halifax' => 'Төньяк Америка атлантик вакыты (Halifax)',
        'America/Havana' => 'Куба вакыты (Havana)',
        'America/Hermosillo' => 'Мексика вакыты (Hermosillo)',
        'America/Indiana/Knox' => 'Төньяк Америка үзәк вакыты (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Төньяк Америка көнчыгыш вакыты (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Төньяк Америка көнчыгыш вакыты (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Төньяк Америка үзәк вакыты (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Төньяк Америка көнчыгыш вакыты (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Төньяк Америка көнчыгыш вакыты (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Төньяк Америка көнчыгыш вакыты (Winamac, Indiana)',
        'America/Indianapolis' => 'Төньяк Америка көнчыгыш вакыты (Indianapolis)',
        'America/Inuvik' => 'Төньяк Америка тау вакыты (Inuvik)',
        'America/Iqaluit' => 'Төньяк Америка көнчыгыш вакыты (Iqaluit)',
        'America/Jamaica' => 'Төньяк Америка көнчыгыш вакыты (Jamaica)',
        'America/Jujuy' => 'Аргентина вакыты (Jujuy)',
        'America/Juneau' => 'АКШ вакыты (Juneau)',
        'America/Kentucky/Monticello' => 'Төньяк Америка көнчыгыш вакыты (Monticello, Kentucky)',
        'America/Kralendijk' => 'Төньяк Америка атлантик вакыты (Kralendijk)',
        'America/La_Paz' => 'Боливия вакыты (La Paz)',
        'America/Lima' => 'Перу вакыты (Lima)',
        'America/Los_Angeles' => 'Төньяк Америка Тын океан вакыты (Los Angeles)',
        'America/Louisville' => 'Төньяк Америка көнчыгыш вакыты (Louisville)',
        'America/Lower_Princes' => 'Төньяк Америка атлантик вакыты (Lower Prince’s Quarter)',
        'America/Maceio' => 'Бразилия вакыты (Maceio)',
        'America/Managua' => 'Төньяк Америка үзәк вакыты (Managua)',
        'America/Manaus' => 'Бразилия вакыты (Manaus)',
        'America/Marigot' => 'Төньяк Америка атлантик вакыты (Marigot)',
        'America/Martinique' => 'Төньяк Америка атлантик вакыты (Martinique)',
        'America/Matamoros' => 'Төньяк Америка үзәк вакыты (Matamoros)',
        'America/Mazatlan' => 'Мексика вакыты (Mazatlan)',
        'America/Mendoza' => 'Аргентина вакыты (Mendoza)',
        'America/Menominee' => 'Төньяк Америка үзәк вакыты (Menominee)',
        'America/Merida' => 'Төньяк Америка үзәк вакыты (Merida)',
        'America/Metlakatla' => 'АКШ вакыты (Metlakatla)',
        'America/Mexico_City' => 'Төньяк Америка үзәк вакыты (Mexico City)',
        'America/Miquelon' => 'Сен-Пьер һәм Микелон вакыты (Miquelon)',
        'America/Moncton' => 'Төньяк Америка атлантик вакыты (Moncton)',
        'America/Monterrey' => 'Төньяк Америка үзәк вакыты (Monterrey)',
        'America/Montevideo' => 'Уругвай вакыты (Montevideo)',
        'America/Montreal' => 'Канада вакыты (Montreal)',
        'America/Montserrat' => 'Төньяк Америка атлантик вакыты (Montserrat)',
        'America/Nassau' => 'Төньяк Америка көнчыгыш вакыты (Nassau)',
        'America/New_York' => 'Төньяк Америка көнчыгыш вакыты (New York)',
        'America/Nipigon' => 'Төньяк Америка көнчыгыш вакыты (Nipigon)',
        'America/Nome' => 'АКШ вакыты (Nome)',
        'America/Noronha' => 'Бразилия вакыты (Noronha)',
        'America/North_Dakota/Beulah' => 'Төньяк Америка үзәк вакыты (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Төньяк Америка үзәк вакыты (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Төньяк Америка үзәк вакыты (New Salem, North Dakota)',
        'America/Ojinaga' => 'Төньяк Америка тау вакыты (Ojinaga)',
        'America/Panama' => 'Төньяк Америка көнчыгыш вакыты (Panama)',
        'America/Pangnirtung' => 'Төньяк Америка көнчыгыш вакыты (Pangnirtung)',
        'America/Paramaribo' => 'Суринам вакыты (Paramaribo)',
        'America/Phoenix' => 'Төньяк Америка тау вакыты (Phoenix)',
        'America/Port-au-Prince' => 'Төньяк Америка көнчыгыш вакыты (Port-au-Prince)',
        'America/Port_of_Spain' => 'Төньяк Америка атлантик вакыты (Port of Spain)',
        'America/Porto_Velho' => 'Бразилия вакыты (Porto Velho)',
        'America/Puerto_Rico' => 'Төньяк Америка атлантик вакыты (Puerto Rico)',
        'America/Punta_Arenas' => 'Чили вакыты (Punta Arenas)',
        'America/Rainy_River' => 'Төньяк Америка үзәк вакыты (Rainy River)',
        'America/Rankin_Inlet' => 'Төньяк Америка үзәк вакыты (Rankin Inlet)',
        'America/Recife' => 'Бразилия вакыты (Recife)',
        'America/Regina' => 'Төньяк Америка үзәк вакыты (Regina)',
        'America/Resolute' => 'Төньяк Америка үзәк вакыты (Resolute)',
        'America/Rio_Branco' => 'Бразилия вакыты (Rio Branco)',
        'America/Santa_Isabel' => 'Мексика вакыты (Santa Isabel)',
        'America/Santarem' => 'Бразилия вакыты (Santarem)',
        'America/Santiago' => 'Чили вакыты (Santiago)',
        'America/Santo_Domingo' => 'Төньяк Америка атлантик вакыты (Santo Domingo)',
        'America/Sao_Paulo' => 'Бразилия вакыты (Sao Paulo)',
        'America/Scoresbysund' => 'Гренландия вакыты (Ittoqqortoormiit)',
        'America/Sitka' => 'АКШ вакыты (Sitka)',
        'America/St_Barthelemy' => 'Төньяк Америка атлантик вакыты (St. Barthelemy)',
        'America/St_Johns' => 'Канада вакыты (St. John’s)',
        'America/St_Kitts' => 'Төньяк Америка атлантик вакыты (St. Kitts)',
        'America/St_Lucia' => 'Төньяк Америка атлантик вакыты (St. Lucia)',
        'America/St_Thomas' => 'Төньяк Америка атлантик вакыты (St. Thomas)',
        'America/St_Vincent' => 'Төньяк Америка атлантик вакыты (St. Vincent)',
        'America/Swift_Current' => 'Төньяк Америка үзәк вакыты (Swift Current)',
        'America/Tegucigalpa' => 'Төньяк Америка үзәк вакыты (Tegucigalpa)',
        'America/Thule' => 'Төньяк Америка атлантик вакыты (Thule)',
        'America/Thunder_Bay' => 'Төньяк Америка көнчыгыш вакыты (Thunder Bay)',
        'America/Tijuana' => 'Төньяк Америка Тын океан вакыты (Tijuana)',
        'America/Toronto' => 'Төньяк Америка көнчыгыш вакыты (Toronto)',
        'America/Tortola' => 'Төньяк Америка атлантик вакыты (Tortola)',
        'America/Vancouver' => 'Төньяк Америка Тын океан вакыты (Vancouver)',
        'America/Whitehorse' => 'Канада вакыты (Whitehorse)',
        'America/Winnipeg' => 'Төньяк Америка үзәк вакыты (Winnipeg)',
        'America/Yakutat' => 'АКШ вакыты (Yakutat)',
        'America/Yellowknife' => 'Төньяк Америка тау вакыты (Yellowknife)',
        'Antarctica/Casey' => 'Антарктика вакыты (Casey)',
        'Antarctica/Davis' => 'Антарктика вакыты (Davis)',
        'Antarctica/DumontDUrville' => 'Антарктика вакыты (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'Австралия вакыты (Macquarie)',
        'Antarctica/Mawson' => 'Антарктика вакыты (Mawson)',
        'Antarctica/McMurdo' => 'Антарктика вакыты (McMurdo)',
        'Antarctica/Palmer' => 'Антарктика вакыты (Palmer)',
        'Antarctica/Rothera' => 'Антарктика вакыты (Rothera)',
        'Antarctica/Syowa' => 'Антарктика вакыты (Syowa)',
        'Antarctica/Troll' => 'Гринвич уртача вакыты (Troll)',
        'Antarctica/Vostok' => 'Антарктика вакыты (Vostok)',
        'Arctic/Longyearbyen' => 'Үзәк Европа вакыты (Longyearbyen)',
        'Asia/Aden' => 'Йәмән вакыты (Aden)',
        'Asia/Almaty' => 'Казахстан вакыты (Almaty)',
        'Asia/Amman' => 'Көнчыгыш Европа вакыты (Amman)',
        'Asia/Anadyr' => 'Россия вакыты (Anadyr)',
        'Asia/Aqtau' => 'Казахстан вакыты (Aqtau)',
        'Asia/Aqtobe' => 'Казахстан вакыты (Aqtobe)',
        'Asia/Ashgabat' => 'Төркмәнстан вакыты (Ashgabat)',
        'Asia/Atyrau' => 'Казахстан вакыты (Atyrau)',
        'Asia/Baghdad' => 'Гыйрак вакыты (Baghdad)',
        'Asia/Bahrain' => 'Бәхрәйн вакыты (Bahrain)',
        'Asia/Baku' => 'Әзәрбайҗан вакыты (Baku)',
        'Asia/Bangkok' => 'Тайланд вакыты (Bangkok)',
        'Asia/Barnaul' => 'Россия вакыты (Barnaul)',
        'Asia/Beirut' => 'Көнчыгыш Европа вакыты (Beirut)',
        'Asia/Bishkek' => 'Кыргызстан вакыты (Bishkek)',
        'Asia/Brunei' => 'Бруней вакыты (Brunei)',
        'Asia/Calcutta' => 'Индия вакыты (Kolkata)',
        'Asia/Chita' => 'Россия вакыты (Chita)',
        'Asia/Choibalsan' => 'Монголия вакыты (Choibalsan)',
        'Asia/Colombo' => 'Шри-Ланка вакыты (Colombo)',
        'Asia/Damascus' => 'Көнчыгыш Европа вакыты (Damascus)',
        'Asia/Dhaka' => 'Бангладеш вакыты (Dhaka)',
        'Asia/Dili' => 'Тимор-Лесте вакыты (Dili)',
        'Asia/Dubai' => 'Берләшкән Гарәп Әмирлекләре вакыты (Dubai)',
        'Asia/Dushanbe' => 'Таҗикстан вакыты (Dushanbe)',
        'Asia/Famagusta' => 'Көнчыгыш Европа вакыты (Famagusta)',
        'Asia/Gaza' => 'Көнчыгыш Европа вакыты (Gaza)',
        'Asia/Hebron' => 'Көнчыгыш Европа вакыты (Hebron)',
        'Asia/Hong_Kong' => 'Гонконг Махсус Идарәле Төбәге вакыты (Hong Kong)',
        'Asia/Hovd' => 'Монголия вакыты (Hovd)',
        'Asia/Irkutsk' => 'Россия вакыты (Irkutsk)',
        'Asia/Jakarta' => 'Индонезия вакыты (Jakarta)',
        'Asia/Jayapura' => 'Индонезия вакыты (Jayapura)',
        'Asia/Jerusalem' => 'Израиль вакыты (Jerusalem)',
        'Asia/Kabul' => 'Әфганстан вакыты (Kabul)',
        'Asia/Kamchatka' => 'Россия вакыты (Kamchatka)',
        'Asia/Karachi' => 'Пакистан вакыты (Karachi)',
        'Asia/Katmandu' => 'Непал вакыты (Kathmandu)',
        'Asia/Khandyga' => 'Россия вакыты (Khandyga)',
        'Asia/Krasnoyarsk' => 'Россия вакыты (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Малайзия вакыты (Kuala Lumpur)',
        'Asia/Kuching' => 'Малайзия вакыты (Kuching)',
        'Asia/Kuwait' => 'Күвәйт вакыты (Kuwait)',
        'Asia/Macau' => 'Макао Махсус Идарәле Төбәге вакыты (Macao)',
        'Asia/Magadan' => 'Россия вакыты (Magadan)',
        'Asia/Makassar' => 'Индонезия вакыты (Makassar)',
        'Asia/Manila' => 'Филиппин вакыты (Manila)',
        'Asia/Muscat' => 'Оман вакыты (Muscat)',
        'Asia/Nicosia' => 'Көнчыгыш Европа вакыты (Nicosia)',
        'Asia/Novokuznetsk' => 'Россия вакыты (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Россия вакыты (Novosibirsk)',
        'Asia/Omsk' => 'Россия вакыты (Omsk)',
        'Asia/Oral' => 'Казахстан вакыты (Oral)',
        'Asia/Phnom_Penh' => 'Камбоджа вакыты (Phnom Penh)',
        'Asia/Pontianak' => 'Индонезия вакыты (Pontianak)',
        'Asia/Pyongyang' => 'Төньяк Корея вакыты (Pyongyang)',
        'Asia/Qatar' => 'Катар вакыты (Qatar)',
        'Asia/Qostanay' => 'Казахстан вакыты (Qostanay)',
        'Asia/Qyzylorda' => 'Казахстан вакыты (Qyzylorda)',
        'Asia/Riyadh' => 'Согуд Гарәбстаны вакыты (Riyadh)',
        'Asia/Saigon' => 'Вьетнам вакыты (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Россия вакыты (Sakhalin)',
        'Asia/Samarkand' => 'Үзбәкстан вакыты (Samarkand)',
        'Asia/Shanghai' => 'Кытай вакыты (Shanghai)',
        'Asia/Singapore' => 'Сингапур вакыты (Singapore)',
        'Asia/Srednekolymsk' => 'Россия вакыты (Srednekolymsk)',
        'Asia/Taipei' => 'Тайвань вакыты (Taipei)',
        'Asia/Tashkent' => 'Үзбәкстан вакыты (Tashkent)',
        'Asia/Tbilisi' => 'Грузия вакыты (Tbilisi)',
        'Asia/Tehran' => 'Иран вакыты (Tehran)',
        'Asia/Thimphu' => 'Бутан вакыты (Thimphu)',
        'Asia/Tokyo' => 'Япония вакыты (Tokyo)',
        'Asia/Tomsk' => 'Россия вакыты (Tomsk)',
        'Asia/Ulaanbaatar' => 'Монголия вакыты (Ulaanbaatar)',
        'Asia/Urumqi' => 'Кытай вакыты (Urumqi)',
        'Asia/Ust-Nera' => 'Россия вакыты (Ust-Nera)',
        'Asia/Vientiane' => 'Лаос вакыты (Vientiane)',
        'Asia/Vladivostok' => 'Россия вакыты (Vladivostok)',
        'Asia/Yakutsk' => 'Россия вакыты (Yakutsk)',
        'Asia/Yekaterinburg' => 'Россия вакыты (Yekaterinburg)',
        'Asia/Yerevan' => 'Әрмәнстан вакыты (Yerevan)',
        'Atlantic/Azores' => 'Португалия вакыты (Azores)',
        'Atlantic/Bermuda' => 'Төньяк Америка атлантик вакыты (Bermuda)',
        'Atlantic/Canary' => 'Көнбатыш Европа вакыты (Canary)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде вакыты (Cape Verde)',
        'Atlantic/Faeroe' => 'Көнбатыш Европа вакыты (Faroe)',
        'Atlantic/Madeira' => 'Көнбатыш Европа вакыты (Madeira)',
        'Atlantic/Reykjavik' => 'Гринвич уртача вакыты (Reykjavik)',
        'Atlantic/South_Georgia' => 'Көньяк Георгия һәм Көньяк Сандвич утраулары вакыты (South Georgia)',
        'Atlantic/St_Helena' => 'Гринвич уртача вакыты (St. Helena)',
        'Atlantic/Stanley' => 'Фолкленд утраулары вакыты (Stanley)',
        'Australia/Adelaide' => 'Австралия вакыты (Adelaide)',
        'Australia/Brisbane' => 'Австралия вакыты (Brisbane)',
        'Australia/Broken_Hill' => 'Австралия вакыты (Broken Hill)',
        'Australia/Currie' => 'Австралия вакыты (Currie)',
        'Australia/Darwin' => 'Австралия вакыты (Darwin)',
        'Australia/Eucla' => 'Австралия вакыты (Eucla)',
        'Australia/Hobart' => 'Австралия вакыты (Hobart)',
        'Australia/Lindeman' => 'Австралия вакыты (Lindeman)',
        'Australia/Lord_Howe' => 'Австралия вакыты (Lord Howe)',
        'Australia/Melbourne' => 'Австралия вакыты (Melbourne)',
        'Australia/Perth' => 'Австралия вакыты (Perth)',
        'Australia/Sydney' => 'Австралия вакыты (Sydney)',
        'CST6CDT' => 'Төньяк Америка үзәк вакыты',
        'EST5EDT' => 'Төньяк Америка көнчыгыш вакыты',
        'Etc/GMT' => 'Гринвич уртача вакыты',
        'Etc/UTC' => 'Бөтендөнья килештерелгән вакыты',
        'Europe/Amsterdam' => 'Үзәк Европа вакыты (Amsterdam)',
        'Europe/Andorra' => 'Үзәк Европа вакыты (Andorra)',
        'Europe/Astrakhan' => 'Россия вакыты (Astrakhan)',
        'Europe/Athens' => 'Көнчыгыш Европа вакыты (Athens)',
        'Europe/Belgrade' => 'Үзәк Европа вакыты (Belgrade)',
        'Europe/Berlin' => 'Үзәк Европа вакыты (Berlin)',
        'Europe/Bratislava' => 'Үзәк Европа вакыты (Bratislava)',
        'Europe/Brussels' => 'Үзәк Европа вакыты (Brussels)',
        'Europe/Bucharest' => 'Көнчыгыш Европа вакыты (Bucharest)',
        'Europe/Budapest' => 'Үзәк Европа вакыты (Budapest)',
        'Europe/Busingen' => 'Үзәк Европа вакыты (Busingen)',
        'Europe/Chisinau' => 'Көнчыгыш Европа вакыты (Chisinau)',
        'Europe/Copenhagen' => 'Үзәк Европа вакыты (Copenhagen)',
        'Europe/Dublin' => 'Гринвич уртача вакыты (Dublin)',
        'Europe/Gibraltar' => 'Үзәк Европа вакыты (Gibraltar)',
        'Europe/Guernsey' => 'Гринвич уртача вакыты (Guernsey)',
        'Europe/Helsinki' => 'Көнчыгыш Европа вакыты (Helsinki)',
        'Europe/Isle_of_Man' => 'Гринвич уртача вакыты (Isle of Man)',
        'Europe/Istanbul' => 'Төркия вакыты (Istanbul)',
        'Europe/Jersey' => 'Гринвич уртача вакыты (Jersey)',
        'Europe/Kaliningrad' => 'Көнчыгыш Европа вакыты (Kaliningrad)',
        'Europe/Kiev' => 'Көнчыгыш Европа вакыты (Kyiv)',
        'Europe/Kirov' => 'Россия вакыты (Kirov)',
        'Europe/Lisbon' => 'Көнбатыш Европа вакыты (Lisbon)',
        'Europe/Ljubljana' => 'Үзәк Европа вакыты (Ljubljana)',
        'Europe/London' => 'Гринвич уртача вакыты (London)',
        'Europe/Luxembourg' => 'Үзәк Европа вакыты (Luxembourg)',
        'Europe/Madrid' => 'Үзәк Европа вакыты (Madrid)',
        'Europe/Malta' => 'Үзәк Европа вакыты (Malta)',
        'Europe/Mariehamn' => 'Көнчыгыш Европа вакыты (Mariehamn)',
        'Europe/Minsk' => 'Беларусь вакыты (Minsk)',
        'Europe/Monaco' => 'Үзәк Европа вакыты (Monaco)',
        'Europe/Moscow' => 'Россия вакыты (Moscow)',
        'Europe/Oslo' => 'Үзәк Европа вакыты (Oslo)',
        'Europe/Paris' => 'Үзәк Европа вакыты (Paris)',
        'Europe/Podgorica' => 'Үзәк Европа вакыты (Podgorica)',
        'Europe/Prague' => 'Үзәк Европа вакыты (Prague)',
        'Europe/Riga' => 'Көнчыгыш Европа вакыты (Riga)',
        'Europe/Rome' => 'Үзәк Европа вакыты (Rome)',
        'Europe/Samara' => 'Россия вакыты (Samara)',
        'Europe/San_Marino' => 'Үзәк Европа вакыты (San Marino)',
        'Europe/Sarajevo' => 'Үзәк Европа вакыты (Sarajevo)',
        'Europe/Saratov' => 'Россия вакыты (Saratov)',
        'Europe/Simferopol' => 'Украина вакыты (Simferopol)',
        'Europe/Skopje' => 'Үзәк Европа вакыты (Skopje)',
        'Europe/Sofia' => 'Көнчыгыш Европа вакыты (Sofia)',
        'Europe/Stockholm' => 'Үзәк Европа вакыты (Stockholm)',
        'Europe/Tallinn' => 'Көнчыгыш Европа вакыты (Tallinn)',
        'Europe/Tirane' => 'Үзәк Европа вакыты (Tirane)',
        'Europe/Ulyanovsk' => 'Россия вакыты (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Көнчыгыш Европа вакыты (Uzhgorod)',
        'Europe/Vaduz' => 'Үзәк Европа вакыты (Vaduz)',
        'Europe/Vatican' => 'Үзәк Европа вакыты (Vatican)',
        'Europe/Vienna' => 'Үзәк Европа вакыты (Vienna)',
        'Europe/Vilnius' => 'Көнчыгыш Европа вакыты (Vilnius)',
        'Europe/Volgograd' => 'Россия вакыты (Volgograd)',
        'Europe/Warsaw' => 'Үзәк Европа вакыты (Warsaw)',
        'Europe/Zagreb' => 'Үзәк Европа вакыты (Zagreb)',
        'Europe/Zaporozhye' => 'Көнчыгыш Европа вакыты (Zaporozhye)',
        'Europe/Zurich' => 'Үзәк Европа вакыты (Zurich)',
        'Indian/Antananarivo' => 'Мадагаскар вакыты (Antananarivo)',
        'Indian/Chagos' => 'Британиянең Һинд Океанындагы Территориясе вакыты (Chagos)',
        'Indian/Christmas' => 'Раштуа утравы вакыты (Christmas)',
        'Indian/Cocos' => 'Кокос (Килинг) утраулары вакыты (Cocos)',
        'Indian/Comoro' => 'Комор утраулары вакыты (Comoro)',
        'Indian/Kerguelen' => 'Франциянең Көньяк Территорияләре вакыты (Kerguelen)',
        'Indian/Mahe' => 'Сейшел утраулары вакыты (Mahe)',
        'Indian/Maldives' => 'Мальдив утраулары вакыты (Maldives)',
        'Indian/Mauritius' => 'Маврикий вакыты (Mauritius)',
        'Indian/Mayotte' => 'Майотта вакыты (Mayotte)',
        'Indian/Reunion' => 'Реюньон вакыты (Reunion)',
        'MST7MDT' => 'Төньяк Америка тау вакыты',
        'PST8PDT' => 'Төньяк Америка Тын океан вакыты',
        'Pacific/Apia' => 'Самоа вакыты (Apia)',
        'Pacific/Auckland' => 'Яңа Зеландия вакыты (Auckland)',
        'Pacific/Bougainville' => 'Папуа - Яңа Гвинея вакыты (Bougainville)',
        'Pacific/Chatham' => 'Яңа Зеландия вакыты (Chatham)',
        'Pacific/Easter' => 'Чили вакыты (Easter)',
        'Pacific/Efate' => 'Вануату вакыты (Efate)',
        'Pacific/Enderbury' => 'Кирибати вакыты (Enderbury)',
        'Pacific/Fakaofo' => 'Токелау вакыты (Fakaofo)',
        'Pacific/Fiji' => 'Фиджи вакыты (Fiji)',
        'Pacific/Funafuti' => 'Тувалу вакыты (Funafuti)',
        'Pacific/Galapagos' => 'Эквадор вакыты (Galapagos)',
        'Pacific/Gambier' => 'Француз Полинезиясе вакыты (Gambier)',
        'Pacific/Guadalcanal' => 'Сөләйман утраулары вакыты (Guadalcanal)',
        'Pacific/Guam' => 'Гуам вакыты (Guam)',
        'Pacific/Honolulu' => 'АКШ вакыты (Honolulu)',
        'Pacific/Johnston' => 'АКШ Кече Читтәге утраулары вакыты (Johnston)',
        'Pacific/Kiritimati' => 'Кирибати вакыты (Kiritimati)',
        'Pacific/Kosrae' => 'Микронезия вакыты (Kosrae)',
        'Pacific/Kwajalein' => 'Маршалл утраулары вакыты (Kwajalein)',
        'Pacific/Majuro' => 'Маршалл утраулары вакыты (Majuro)',
        'Pacific/Marquesas' => 'Француз Полинезиясе вакыты (Marquesas)',
        'Pacific/Midway' => 'АКШ Кече Читтәге утраулары вакыты (Midway)',
        'Pacific/Nauru' => 'Науру вакыты (Nauru)',
        'Pacific/Niue' => 'Ниуэ вакыты (Niue)',
        'Pacific/Norfolk' => 'Норфолк утравы вакыты (Norfolk)',
        'Pacific/Noumea' => 'Яңа Каледония вакыты (Noumea)',
        'Pacific/Pago_Pago' => 'Америка Самоасы вакыты (Pago Pago)',
        'Pacific/Palau' => 'Палау вакыты (Palau)',
        'Pacific/Pitcairn' => 'Питкэрн утраулары вакыты (Pitcairn)',
        'Pacific/Ponape' => 'Микронезия вакыты (Pohnpei)',
        'Pacific/Port_Moresby' => 'Папуа - Яңа Гвинея вакыты (Port Moresby)',
        'Pacific/Rarotonga' => 'Кук утраулары вакыты (Rarotonga)',
        'Pacific/Saipan' => 'Төньяк Мариана утраулары вакыты (Saipan)',
        'Pacific/Tahiti' => 'Француз Полинезиясе вакыты (Tahiti)',
        'Pacific/Tarawa' => 'Кирибати вакыты (Tarawa)',
        'Pacific/Tongatapu' => 'Тонга вакыты (Tongatapu)',
        'Pacific/Truk' => 'Микронезия вакыты (Chuuk)',
        'Pacific/Wake' => 'АКШ Кече Читтәге утраулары вакыты (Wake)',
        'Pacific/Wallis' => 'Уоллис һәм Футуна вакыты (Wallis)',
    ],
    'Meta' => [
    ],
];
