<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намибия)',
        'af_ZA' => 'африкаанс (Африкаи Ҷанубӣ)',
        'am' => 'амҳарӣ',
        'am_ET' => 'амҳарӣ (Эфиопия)',
        'ar' => 'арабӣ',
        'ar_AE' => 'арабӣ (Аморатҳои Муттаҳидаи Араб)',
        'ar_BH' => 'арабӣ (Баҳрайн)',
        'ar_DJ' => 'арабӣ (Ҷибути)',
        'ar_DZ' => 'арабӣ (Алҷазоир)',
        'ar_EG' => 'арабӣ (Миср)',
        'ar_ER' => 'арабӣ (Эритрея)',
        'ar_IL' => 'арабӣ (Исроил)',
        'ar_IQ' => 'арабӣ (Ироқ)',
        'ar_JO' => 'арабӣ (Урдун)',
        'ar_KM' => 'арабӣ (Комор)',
        'ar_KW' => 'арабӣ (Қувайт)',
        'ar_LB' => 'арабӣ (Лубнон)',
        'ar_LY' => 'арабӣ (Либия)',
        'ar_MA' => 'арабӣ (Марокаш)',
        'ar_MR' => 'арабӣ (Мавритания)',
        'ar_OM' => 'арабӣ (Умон)',
        'ar_QA' => 'арабӣ (Қатар)',
        'ar_SA' => 'арабӣ (Арабистони Саудӣ)',
        'ar_SD' => 'арабӣ (Судон)',
        'ar_SO' => 'арабӣ (Сомалӣ)',
        'ar_SS' => 'арабӣ (Судони Ҷанубӣ)',
        'ar_SY' => 'арабӣ (Сурия)',
        'ar_TD' => 'арабӣ (Чад)',
        'ar_TN' => 'арабӣ (Тунис)',
        'ar_YE' => 'арабӣ (Яман)',
        'as' => 'ассомӣ',
        'as_IN' => 'ассомӣ (Ҳиндустон)',
        'az' => 'озарбойҷонӣ',
        'az_AZ' => 'озарбойҷонӣ (Озарбойҷон)',
        'az_Cyrl' => 'озарбойҷонӣ (Кириллӣ)',
        'az_Cyrl_AZ' => 'озарбойҷонӣ (Кириллӣ, Озарбойҷон)',
        'az_Latn' => 'озарбойҷонӣ (Лотинӣ)',
        'az_Latn_AZ' => 'озарбойҷонӣ (Лотинӣ, Озарбойҷон)',
        'be' => 'белорусӣ',
        'be_BY' => 'белорусӣ (Белорус)',
        'bg' => 'булғорӣ',
        'bg_BG' => 'булғорӣ (Булғория)',
        'bn' => 'бинғолӣ',
        'bn_BD' => 'бинғолӣ (Бангладеш)',
        'bn_IN' => 'бинғолӣ (Ҳиндустон)',
        'bo' => 'тибетӣ',
        'bo_CN' => 'тибетӣ (Хитой)',
        'bo_IN' => 'тибетӣ (Ҳиндустон)',
        'br' => 'бретонӣ',
        'br_FR' => 'бретонӣ (Фаронса)',
        'bs' => 'босниягӣ',
        'bs_BA' => 'босниягӣ (Босния ва Ҳерсеговина)',
        'bs_Cyrl' => 'босниягӣ (Кириллӣ)',
        'bs_Cyrl_BA' => 'босниягӣ (Кириллӣ, Босния ва Ҳерсеговина)',
        'bs_Latn' => 'босниягӣ (Лотинӣ)',
        'bs_Latn_BA' => 'босниягӣ (Лотинӣ, Босния ва Ҳерсеговина)',
        'ca' => 'каталонӣ',
        'ca_AD' => 'каталонӣ (Андорра)',
        'ca_ES' => 'каталонӣ (Испания)',
        'ca_FR' => 'каталонӣ (Фаронса)',
        'ca_IT' => 'каталонӣ (Италия)',
        'cs' => 'чехӣ',
        'cs_CZ' => 'чехӣ (Ҷумҳурии Чех)',
        'cy' => 'валлӣ',
        'cy_GB' => 'валлӣ (Шоҳигарии Муттаҳида)',
        'da' => 'даниягӣ',
        'da_DK' => 'даниягӣ (Дания)',
        'da_GL' => 'даниягӣ (Гренландия)',
        'de' => 'немисӣ',
        'de_AT' => 'немисӣ (Австрия)',
        'de_BE' => 'немисӣ (Белгия)',
        'de_CH' => 'немисӣ (Швейтсария)',
        'de_DE' => 'немисӣ (Германия)',
        'de_IT' => 'немисӣ (Италия)',
        'de_LI' => 'немисӣ (Лихтенштейн)',
        'de_LU' => 'немисӣ (Люксембург)',
        'dz' => 'дзонгха',
        'dz_BT' => 'дзонгха (Бутон)',
        'el' => 'юнонӣ',
        'el_CY' => 'юнонӣ (Кипр)',
        'el_GR' => 'юнонӣ (Юнон)',
        'en' => 'Англисӣ',
        'en_AE' => 'Англисӣ (Аморатҳои Муттаҳидаи Араб)',
        'en_AG' => 'Англисӣ (Антигуа ва Барбуда)',
        'en_AI' => 'Англисӣ (Ангилия)',
        'en_AS' => 'Англисӣ (Самоаи Америка)',
        'en_AT' => 'Англисӣ (Австрия)',
        'en_AU' => 'Англисӣ (Австралия)',
        'en_BB' => 'Англисӣ (Барбадос)',
        'en_BE' => 'Англисӣ (Белгия)',
        'en_BI' => 'Англисӣ (Бурунди)',
        'en_BM' => 'Англисӣ (Бермуда)',
        'en_BS' => 'Англисӣ (Багам)',
        'en_BW' => 'Англисӣ (Ботсвана)',
        'en_BZ' => 'Англисӣ (Белиз)',
        'en_CA' => 'Англисӣ (Канада)',
        'en_CC' => 'Англисӣ (Ҷазираҳои Кокос [Килинг])',
        'en_CH' => 'Англисӣ (Швейтсария)',
        'en_CK' => 'Англисӣ (Ҷазираҳои Кук)',
        'en_CM' => 'Англисӣ (Камерун)',
        'en_CX' => 'Англисӣ (Ҷазираи Крисмас)',
        'en_CY' => 'Англисӣ (Кипр)',
        'en_DE' => 'Англисӣ (Германия)',
        'en_DK' => 'Англисӣ (Дания)',
        'en_DM' => 'Англисӣ (Доминика)',
        'en_ER' => 'Англисӣ (Эритрея)',
        'en_FI' => 'Англисӣ (Финляндия)',
        'en_FJ' => 'Англисӣ (Фиҷи)',
        'en_FK' => 'Англисӣ (Ҷазираҳои Фолкленд)',
        'en_FM' => 'Англисӣ (Штатҳои Федеративии Микронезия)',
        'en_GB' => 'Англисӣ (Шоҳигарии Муттаҳида)',
        'en_GD' => 'Англисӣ (Гренада)',
        'en_GG' => 'Англисӣ (Гернси)',
        'en_GH' => 'Англисӣ (Гана)',
        'en_GI' => 'Англисӣ (Гибралтар)',
        'en_GM' => 'Англисӣ (Гамбия)',
        'en_GU' => 'Англисӣ (Гуам)',
        'en_GY' => 'Англисӣ (Гайана)',
        'en_HK' => 'Англисӣ (Ҳонконг [МММ])',
        'en_IE' => 'Англисӣ (Ирландия)',
        'en_IL' => 'Англисӣ (Исроил)',
        'en_IM' => 'Англисӣ (Ҷазираи Мэн)',
        'en_IN' => 'Англисӣ (Ҳиндустон)',
        'en_IO' => 'Англисӣ (Қаламрави Британия дар уқёнуси Ҳинд)',
        'en_JE' => 'Англисӣ (Ҷерси)',
        'en_JM' => 'Англисӣ (Ямайка)',
        'en_KE' => 'Англисӣ (Кения)',
        'en_KI' => 'Англисӣ (Кирибати)',
        'en_KN' => 'Англисӣ (Сент-Китс ва Невис)',
        'en_KY' => 'Англисӣ (Ҷазираҳои Кайман)',
        'en_LC' => 'Англисӣ (Сент-Люсия)',
        'en_LR' => 'Англисӣ (Либерия)',
        'en_LS' => 'Англисӣ (Лесото)',
        'en_MG' => 'Англисӣ (Мадагаскар)',
        'en_MH' => 'Англисӣ (Ҷазираҳои Маршалл)',
        'en_MO' => 'Англисӣ (Макао [МММ])',
        'en_MP' => 'Англисӣ (Ҷазираҳои Марианаи Шимолӣ)',
        'en_MS' => 'Англисӣ (Монтсеррат)',
        'en_MT' => 'Англисӣ (Малта)',
        'en_MU' => 'Англисӣ (Маврикий)',
        'en_MV' => 'Англисӣ (Малдив)',
        'en_MW' => 'Англисӣ (Малави)',
        'en_MY' => 'Англисӣ (Малайзия)',
        'en_NA' => 'Англисӣ (Намибия)',
        'en_NF' => 'Англисӣ (Ҷазираи Норфолк)',
        'en_NG' => 'Англисӣ (Нигерия)',
        'en_NL' => 'Англисӣ (Нидерландия)',
        'en_NR' => 'Англисӣ (Науру)',
        'en_NU' => 'Англисӣ (Ниуэ)',
        'en_NZ' => 'Англисӣ (Зеландияи Нав)',
        'en_PG' => 'Англисӣ (Папуа Гвинеяи Нав)',
        'en_PH' => 'Англисӣ (Филиппин)',
        'en_PK' => 'Англисӣ (Покистон)',
        'en_PN' => 'Англисӣ (Ҷазираҳои Питкейрн)',
        'en_PR' => 'Англисӣ (Пуэрто-Рико)',
        'en_PW' => 'Англисӣ (Палау)',
        'en_RW' => 'Англисӣ (Руанда)',
        'en_SB' => 'Англисӣ (Ҷазираҳои Соломон)',
        'en_SC' => 'Англисӣ (Сейшел)',
        'en_SD' => 'Англисӣ (Судон)',
        'en_SE' => 'Англисӣ (Шветсия)',
        'en_SG' => 'Англисӣ (Сингапур)',
        'en_SH' => 'Англисӣ (Сент Елена)',
        'en_SI' => 'Англисӣ (Словения)',
        'en_SL' => 'Англисӣ (Сиерра-Леоне)',
        'en_SS' => 'Англисӣ (Судони Ҷанубӣ)',
        'en_SX' => 'Англисӣ (Синт-Маартен)',
        'en_SZ' => 'Англисӣ (Свазиленд)',
        'en_TC' => 'Англисӣ (Ҷазираҳои Теркс ва Кайкос)',
        'en_TK' => 'Англисӣ (Токелау)',
        'en_TO' => 'Англисӣ (Тонга)',
        'en_TT' => 'Англисӣ (Тринидад ва Тобаго)',
        'en_TV' => 'Англисӣ (Тувалу)',
        'en_TZ' => 'Англисӣ (Танзания)',
        'en_UG' => 'Англисӣ (Уганда)',
        'en_UM' => 'Англисӣ (Ҷазираҳои Хурди Дурдасти ИМА)',
        'en_US' => 'Англисӣ (Иёлоти Муттаҳида)',
        'en_VC' => 'Англисӣ (Сент-Винсент ва Гренадина)',
        'en_VG' => 'Англисӣ (Ҷазираҳои Виргини Британия)',
        'en_VI' => 'Англисӣ (Ҷазираҳои Виргини ИМА)',
        'en_VU' => 'Англисӣ (Вануату)',
        'en_WS' => 'Англисӣ (Самоа)',
        'en_ZA' => 'Англисӣ (Африкаи Ҷанубӣ)',
        'en_ZM' => 'Англисӣ (Замбия)',
        'en_ZW' => 'Англисӣ (Зимбабве)',
        'eo' => 'эсперанто',
        'es' => 'испанӣ',
        'es_AR' => 'испанӣ (Аргентина)',
        'es_BO' => 'испанӣ (Боливия)',
        'es_BR' => 'испанӣ (Бразилия)',
        'es_BZ' => 'испанӣ (Белиз)',
        'es_CL' => 'испанӣ (Чили)',
        'es_CO' => 'испанӣ (Колумбия)',
        'es_CR' => 'испанӣ (Коста-Рика)',
        'es_CU' => 'испанӣ (Куба)',
        'es_DO' => 'испанӣ (Ҷумҳурии Доминикан)',
        'es_EC' => 'испанӣ (Эквадор)',
        'es_ES' => 'испанӣ (Испания)',
        'es_GQ' => 'испанӣ (Гвинеяи Экваторӣ)',
        'es_GT' => 'испанӣ (Гватемала)',
        'es_HN' => 'испанӣ (Гондурас)',
        'es_MX' => 'испанӣ (Мексика)',
        'es_NI' => 'испанӣ (Никарагуа)',
        'es_PA' => 'испанӣ (Панама)',
        'es_PE' => 'испанӣ (Перу)',
        'es_PH' => 'испанӣ (Филиппин)',
        'es_PR' => 'испанӣ (Пуэрто-Рико)',
        'es_PY' => 'испанӣ (Парагвай)',
        'es_SV' => 'испанӣ (Эл-Салвадор)',
        'es_US' => 'испанӣ (Иёлоти Муттаҳида)',
        'es_UY' => 'испанӣ (Уругвай)',
        'es_VE' => 'испанӣ (Венесуэла)',
        'et' => 'эстонӣ',
        'et_EE' => 'эстонӣ (Эстония)',
        'eu' => 'баскӣ',
        'eu_ES' => 'баскӣ (Испания)',
        'fa' => 'форсӣ',
        'fa_AF' => 'форсӣ (Афғонистон)',
        'fa_IR' => 'форсӣ (Эрон)',
        'ff' => 'фулаҳ',
        'ff_CM' => 'фулаҳ (Камерун)',
        'ff_GN' => 'фулаҳ (Гвинея)',
        'ff_Latn' => 'фулаҳ (Лотинӣ)',
        'ff_Latn_BF' => 'фулаҳ (Лотинӣ, Буркина-Фасо)',
        'ff_Latn_CM' => 'фулаҳ (Лотинӣ, Камерун)',
        'ff_Latn_GH' => 'фулаҳ (Лотинӣ, Гана)',
        'ff_Latn_GM' => 'фулаҳ (Лотинӣ, Гамбия)',
        'ff_Latn_GN' => 'фулаҳ (Лотинӣ, Гвинея)',
        'ff_Latn_GW' => 'фулаҳ (Лотинӣ, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фулаҳ (Лотинӣ, Либерия)',
        'ff_Latn_MR' => 'фулаҳ (Лотинӣ, Мавритания)',
        'ff_Latn_NE' => 'фулаҳ (Лотинӣ, Нигер)',
        'ff_Latn_NG' => 'фулаҳ (Лотинӣ, Нигерия)',
        'ff_Latn_SL' => 'фулаҳ (Лотинӣ, Сиерра-Леоне)',
        'ff_Latn_SN' => 'фулаҳ (Лотинӣ, Сенегал)',
        'ff_MR' => 'фулаҳ (Мавритания)',
        'ff_SN' => 'фулаҳ (Сенегал)',
        'fi' => 'финӣ',
        'fi_FI' => 'финӣ (Финляндия)',
        'fo' => 'фарерӣ',
        'fo_DK' => 'фарерӣ (Дания)',
        'fo_FO' => 'фарерӣ (Ҷазираҳои Фарер)',
        'fr' => 'франсузӣ',
        'fr_BE' => 'франсузӣ (Белгия)',
        'fr_BF' => 'франсузӣ (Буркина-Фасо)',
        'fr_BI' => 'франсузӣ (Бурунди)',
        'fr_BJ' => 'франсузӣ (Бенин)',
        'fr_BL' => 'франсузӣ (Сент-Бартелми)',
        'fr_CA' => 'франсузӣ (Канада)',
        'fr_CD' => 'франсузӣ (Конго [ҶДК])',
        'fr_CF' => 'франсузӣ (Ҷумҳурии Африқои Марказӣ)',
        'fr_CG' => 'франсузӣ (Конго)',
        'fr_CH' => 'франсузӣ (Швейтсария)',
        'fr_CI' => 'франсузӣ (Кот-д’Ивуар)',
        'fr_CM' => 'франсузӣ (Камерун)',
        'fr_DJ' => 'франсузӣ (Ҷибути)',
        'fr_DZ' => 'франсузӣ (Алҷазоир)',
        'fr_FR' => 'франсузӣ (Фаронса)',
        'fr_GA' => 'франсузӣ (Габон)',
        'fr_GF' => 'франсузӣ (Гвианаи Фаронса)',
        'fr_GN' => 'франсузӣ (Гвинея)',
        'fr_GP' => 'франсузӣ (Гваделупа)',
        'fr_GQ' => 'франсузӣ (Гвинеяи Экваторӣ)',
        'fr_HT' => 'франсузӣ (Гаити)',
        'fr_KM' => 'франсузӣ (Комор)',
        'fr_LU' => 'франсузӣ (Люксембург)',
        'fr_MA' => 'франсузӣ (Марокаш)',
        'fr_MC' => 'франсузӣ (Монако)',
        'fr_MF' => 'франсузӣ (Ҷазираи Сент-Мартин)',
        'fr_MG' => 'франсузӣ (Мадагаскар)',
        'fr_ML' => 'франсузӣ (Мали)',
        'fr_MQ' => 'франсузӣ (Мартиника)',
        'fr_MR' => 'франсузӣ (Мавритания)',
        'fr_MU' => 'франсузӣ (Маврикий)',
        'fr_NC' => 'франсузӣ (Каледонияи Нав)',
        'fr_NE' => 'франсузӣ (Нигер)',
        'fr_PF' => 'франсузӣ (Полинезияи Фаронса)',
        'fr_PM' => 'франсузӣ (Сент-Пер ва Микелон)',
        'fr_RE' => 'франсузӣ (Реюнион)',
        'fr_RW' => 'франсузӣ (Руанда)',
        'fr_SC' => 'франсузӣ (Сейшел)',
        'fr_SN' => 'франсузӣ (Сенегал)',
        'fr_SY' => 'франсузӣ (Сурия)',
        'fr_TD' => 'франсузӣ (Чад)',
        'fr_TG' => 'франсузӣ (Того)',
        'fr_TN' => 'франсузӣ (Тунис)',
        'fr_VU' => 'франсузӣ (Вануату)',
        'fr_WF' => 'франсузӣ (Уоллис ва Футуна)',
        'fr_YT' => 'франсузӣ (Майотта)',
        'fy' => 'фризии ғарбӣ',
        'fy_NL' => 'фризии ғарбӣ (Нидерландия)',
        'ga' => 'ирландӣ',
        'ga_GB' => 'ирландӣ (Шоҳигарии Муттаҳида)',
        'ga_IE' => 'ирландӣ (Ирландия)',
        'gd' => 'шотландии гэлӣ',
        'gd_GB' => 'шотландии гэлӣ (Шоҳигарии Муттаҳида)',
        'gl' => 'галисиягӣ',
        'gl_ES' => 'галисиягӣ (Испания)',
        'gu' => 'гуҷаротӣ',
        'gu_IN' => 'гуҷаротӣ (Ҳиндустон)',
        'ha' => 'ҳауса',
        'ha_GH' => 'ҳауса (Гана)',
        'ha_NE' => 'ҳауса (Нигер)',
        'ha_NG' => 'ҳауса (Нигерия)',
        'he' => 'ибронӣ',
        'he_IL' => 'ибронӣ (Исроил)',
        'hi' => 'ҳиндӣ',
        'hi_IN' => 'ҳиндӣ (Ҳиндустон)',
        'hi_Latn' => 'ҳиндӣ (Лотинӣ)',
        'hi_Latn_IN' => 'ҳиндӣ (Лотинӣ, Ҳиндустон)',
        'hr' => 'хорватӣ',
        'hr_BA' => 'хорватӣ (Босния ва Ҳерсеговина)',
        'hr_HR' => 'хорватӣ (Хорватия)',
        'hu' => 'маҷорӣ',
        'hu_HU' => 'маҷорӣ (Маҷористон)',
        'hy' => 'арманӣ',
        'hy_AM' => 'арманӣ (Арманистон)',
        'id' => 'индонезӣ',
        'id_ID' => 'индонезӣ (Индонезия)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерия)',
        'is' => 'исландӣ',
        'is_IS' => 'исландӣ (Исландия)',
        'it' => 'италиявӣ',
        'it_CH' => 'италиявӣ (Швейтсария)',
        'it_IT' => 'италиявӣ (Италия)',
        'it_SM' => 'италиявӣ (Сан-Марино)',
        'it_VA' => 'италиявӣ (Шаҳри Вотикон)',
        'ja' => 'японӣ',
        'ja_JP' => 'японӣ (Япония)',
        'ka' => 'гурҷӣ',
        'ka_GE' => 'гурҷӣ (Гурҷистон)',
        'kk' => 'қазоқӣ',
        'kk_KZ' => 'қазоқӣ (Қазоқистон)',
        'km' => 'кхмерӣ',
        'km_KH' => 'кхмерӣ (Камбоҷа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Ҳиндустон)',
        'ko' => 'кореягӣ',
        'ko_KP' => 'кореягӣ (Кореяи Шимолӣ)',
        'ks' => 'кашмирӣ',
        'ks_Arab' => 'кашмирӣ (Арабӣ)',
        'ks_Arab_IN' => 'кашмирӣ (Арабӣ, Ҳиндустон)',
        'ks_IN' => 'кашмирӣ (Ҳиндустон)',
        'ku' => 'курдӣ',
        'ku_TR' => 'курдӣ (Туркия)',
        'ky' => 'қирғизӣ',
        'ky_KG' => 'қирғизӣ (Қирғизистон)',
        'lb' => 'люксембургӣ',
        'lb_LU' => 'люксембургӣ (Люксембург)',
        'lo' => 'лаосӣ',
        'lo_LA' => 'лаосӣ (Лаос)',
        'lt' => 'литвонӣ',
        'lt_LT' => 'литвонӣ (Литва)',
        'lv' => 'латишӣ',
        'lv_LV' => 'латишӣ (Латвия)',
        'mg' => 'малагасӣ',
        'mg_MG' => 'малагасӣ (Мадагаскар)',
        'mi' => 'маорӣ',
        'mi_NZ' => 'маорӣ (Зеландияи Нав)',
        'mk' => 'мақдунӣ',
        'mk_MK' => 'мақдунӣ (Македонияи Шимолӣ)',
        'ml' => 'малаяламӣ',
        'ml_IN' => 'малаяламӣ (Ҳиндустон)',
        'mn' => 'муғулӣ',
        'mn_MN' => 'муғулӣ (Муғулистон)',
        'mr' => 'маратҳӣ',
        'mr_IN' => 'маратҳӣ (Ҳиндустон)',
        'ms' => 'малайӣ',
        'ms_BN' => 'малайӣ (Бруней)',
        'ms_ID' => 'малайӣ (Индонезия)',
        'ms_MY' => 'малайӣ (Малайзия)',
        'ms_SG' => 'малайӣ (Сингапур)',
        'mt' => 'малтӣ',
        'mt_MT' => 'малтӣ (Малта)',
        'my' => 'бирманӣ',
        'my_MM' => 'бирманӣ (Мянма)',
        'ne' => 'непалӣ',
        'ne_IN' => 'непалӣ (Ҳиндустон)',
        'ne_NP' => 'непалӣ (Непал)',
        'nl' => 'голландӣ',
        'nl_AW' => 'голландӣ (Аруба)',
        'nl_BE' => 'голландӣ (Белгия)',
        'nl_CW' => 'голландӣ (Кюрасао)',
        'nl_NL' => 'голландӣ (Нидерландия)',
        'nl_SR' => 'голландӣ (Суринам)',
        'nl_SX' => 'голландӣ (Синт-Маартен)',
        'no' => 'норвегӣ',
        'no_NO' => 'норвегӣ (Норвегия)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Эфиопия)',
        'om_KE' => 'оромо (Кения)',
        'or' => 'одия',
        'or_IN' => 'одия (Ҳиндустон)',
        'pa' => 'панҷобӣ',
        'pa_Arab' => 'панҷобӣ (Арабӣ)',
        'pa_Arab_PK' => 'панҷобӣ (Арабӣ, Покистон)',
        'pa_IN' => 'панҷобӣ (Ҳиндустон)',
        'pa_PK' => 'панҷобӣ (Покистон)',
        'pl' => 'лаҳистонӣ',
        'pl_PL' => 'лаҳистонӣ (Лаҳистон)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Афғонистон)',
        'ps_PK' => 'пушту (Покистон)',
        'pt' => 'португалӣ',
        'pt_AO' => 'португалӣ (Ангола)',
        'pt_BR' => 'португалӣ (Бразилия)',
        'pt_CH' => 'португалӣ (Швейтсария)',
        'pt_CV' => 'португалӣ (Кабо-Верде)',
        'pt_GQ' => 'португалӣ (Гвинеяи Экваторӣ)',
        'pt_GW' => 'португалӣ (Гвинея-Бисау)',
        'pt_LU' => 'португалӣ (Люксембург)',
        'pt_MO' => 'португалӣ (Макао [МММ])',
        'pt_MZ' => 'португалӣ (Мозамбик)',
        'pt_PT' => 'португалӣ (Португалия)',
        'pt_ST' => 'португалӣ (Сан Томе ва Принсипи)',
        'pt_TL' => 'португалӣ (Тимор-Лесте)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливия)',
        'qu_EC' => 'кечуа (Эквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'ретороманӣ',
        'rm_CH' => 'ретороманӣ (Швейтсария)',
        'ro' => 'руминӣ',
        'ro_MD' => 'руминӣ (Молдова)',
        'ro_RO' => 'руминӣ (Руминия)',
        'ru' => 'русӣ',
        'ru_BY' => 'русӣ (Белорус)',
        'ru_KG' => 'русӣ (Қирғизистон)',
        'ru_KZ' => 'русӣ (Қазоқистон)',
        'ru_MD' => 'русӣ (Молдова)',
        'ru_RU' => 'русӣ (Русия)',
        'ru_UA' => 'русӣ (Украина)',
        'rw' => 'киняруанда',
        'rw_RW' => 'киняруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Ҳиндустон)',
        'sd' => 'синдӣ',
        'sd_Arab' => 'синдӣ (Арабӣ)',
        'sd_Arab_PK' => 'синдӣ (Арабӣ, Покистон)',
        'sd_IN' => 'синдӣ (Ҳиндустон)',
        'sd_PK' => 'синдӣ (Покистон)',
        'se' => 'самии шимолӣ',
        'se_FI' => 'самии шимолӣ (Финляндия)',
        'se_NO' => 'самии шимолӣ (Норвегия)',
        'se_SE' => 'самии шимолӣ (Шветсия)',
        'si' => 'сингалӣ',
        'si_LK' => 'сингалӣ (Шри-Ланка)',
        'sk' => 'словакӣ',
        'sk_SK' => 'словакӣ (Словакия)',
        'sl' => 'словенӣ',
        'sl_SI' => 'словенӣ (Словения)',
        'so' => 'сомалӣ',
        'so_DJ' => 'сомалӣ (Ҷибути)',
        'so_ET' => 'сомалӣ (Эфиопия)',
        'so_KE' => 'сомалӣ (Кения)',
        'so_SO' => 'сомалӣ (Сомалӣ)',
        'sq' => 'албанӣ',
        'sq_AL' => 'албанӣ (Албания)',
        'sq_MK' => 'албанӣ (Македонияи Шимолӣ)',
        'sr' => 'сербӣ',
        'sr_BA' => 'сербӣ (Босния ва Ҳерсеговина)',
        'sr_Cyrl' => 'сербӣ (Кириллӣ)',
        'sr_Cyrl_BA' => 'сербӣ (Кириллӣ, Босния ва Ҳерсеговина)',
        'sr_Cyrl_ME' => 'сербӣ (Кириллӣ, Черногория)',
        'sr_Cyrl_RS' => 'сербӣ (Кириллӣ, Сербия)',
        'sr_Latn' => 'сербӣ (Лотинӣ)',
        'sr_Latn_BA' => 'сербӣ (Лотинӣ, Босния ва Ҳерсеговина)',
        'sr_Latn_ME' => 'сербӣ (Лотинӣ, Черногория)',
        'sr_Latn_RS' => 'сербӣ (Лотинӣ, Сербия)',
        'sr_ME' => 'сербӣ (Черногория)',
        'sr_RS' => 'сербӣ (Сербия)',
        'sv' => 'шведӣ',
        'sv_AX' => 'шведӣ (Ҷазираҳои Аланд)',
        'sv_FI' => 'шведӣ (Финляндия)',
        'sv_SE' => 'шведӣ (Шветсия)',
        'ta' => 'тамилӣ',
        'ta_IN' => 'тамилӣ (Ҳиндустон)',
        'ta_LK' => 'тамилӣ (Шри-Ланка)',
        'ta_MY' => 'тамилӣ (Малайзия)',
        'ta_SG' => 'тамилӣ (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Ҳиндустон)',
        'tg' => 'тоҷикӣ',
        'tg_TJ' => 'тоҷикӣ (Тоҷикистон)',
        'th' => 'тайӣ',
        'th_TH' => 'тайӣ (Таиланд)',
        'ti' => 'тигриня',
        'ti_ER' => 'тигриня (Эритрея)',
        'ti_ET' => 'тигриня (Эфиопия)',
        'tk' => 'туркманӣ',
        'tk_TM' => 'туркманӣ (Туркманистон)',
        'to' => 'тонганӣ',
        'to_TO' => 'тонганӣ (Тонга)',
        'tr' => 'туркӣ',
        'tr_CY' => 'туркӣ (Кипр)',
        'tr_TR' => 'туркӣ (Туркия)',
        'tt' => 'тоторӣ',
        'tt_RU' => 'тоторӣ (Русия)',
        'ug' => 'ӯйғурӣ',
        'ug_CN' => 'ӯйғурӣ (Хитой)',
        'uk' => 'украинӣ',
        'uk_UA' => 'украинӣ (Украина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Ҳиндустон)',
        'ur_PK' => 'урду (Покистон)',
        'uz' => 'ӯзбекӣ',
        'uz_AF' => 'ӯзбекӣ (Афғонистон)',
        'uz_Arab' => 'ӯзбекӣ (Арабӣ)',
        'uz_Arab_AF' => 'ӯзбекӣ (Арабӣ, Афғонистон)',
        'uz_Cyrl' => 'ӯзбекӣ (Кириллӣ)',
        'uz_Cyrl_UZ' => 'ӯзбекӣ (Кириллӣ, Ӯзбекистон)',
        'uz_Latn' => 'ӯзбекӣ (Лотинӣ)',
        'uz_Latn_UZ' => 'ӯзбекӣ (Лотинӣ, Ӯзбекистон)',
        'uz_UZ' => 'ӯзбекӣ (Ӯзбекистон)',
        'vi' => 'ветнамӣ',
        'vi_VN' => 'ветнамӣ (Ветнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенин)',
        'yo_NG' => 'йоруба (Нигерия)',
        'zh' => 'хитоӣ',
        'zh_CN' => 'хитоӣ (Хитой)',
        'zh_HK' => 'хитоӣ (Ҳонконг [МММ])',
        'zh_Hans' => 'хитоӣ (Осонфаҳм)',
        'zh_Hans_CN' => 'хитоӣ (Осонфаҳм, Хитой)',
        'zh_Hans_HK' => 'хитоӣ (Осонфаҳм, Ҳонконг [МММ])',
        'zh_Hans_MO' => 'хитоӣ (Осонфаҳм, Макао [МММ])',
        'zh_Hans_SG' => 'хитоӣ (Осонфаҳм, Сингапур)',
        'zh_Hant' => 'хитоӣ (Анъанавӣ)',
        'zh_Hant_HK' => 'хитоӣ (Анъанавӣ, Ҳонконг [МММ])',
        'zh_Hant_MO' => 'хитоӣ (Анъанавӣ, Макао [МММ])',
        'zh_Hant_TW' => 'хитоӣ (Анъанавӣ, Тайван)',
        'zh_MO' => 'хитоӣ (Макао [МММ])',
        'zh_SG' => 'хитоӣ (Сингапур)',
        'zh_TW' => 'хитоӣ (Тайван)',
    ],
];
