<?php

return [
    'Names' => [
        'ak' => 'Kiakan',
        'ak_GH' => 'Kiakan (Ngana)',
        'am' => 'Kiamhari',
        'am_ET' => 'Kiamhari (Uhabeshi)',
        'ar' => 'Kĩarabu',
        'ar_AE' => 'Kĩarabu (Falme za Kiarabu)',
        'ar_BH' => 'Kĩarabu (Bahareni)',
        'ar_DJ' => 'Kĩarabu (Jibuti)',
        'ar_DZ' => 'Kĩarabu (Aljeria)',
        'ar_EG' => 'Kĩarabu (Misri)',
        'ar_ER' => 'Kĩarabu (Eritrea)',
        'ar_IL' => 'Kĩarabu (Israeli)',
        'ar_IQ' => 'Kĩarabu (Iraki)',
        'ar_JO' => 'Kĩarabu (Njorondani)',
        'ar_KM' => 'Kĩarabu (Komoro)',
        'ar_KW' => 'Kĩarabu (Kuwaiti)',
        'ar_LB' => 'Kĩarabu (Lebanoni)',
        'ar_LY' => 'Kĩarabu (Libya)',
        'ar_MA' => 'Kĩarabu (Moroko)',
        'ar_MR' => 'Kĩarabu (Moritania)',
        'ar_OM' => 'Kĩarabu (Omani)',
        'ar_PS' => 'Kĩarabu (Ukingo wa Magharibi na Ukanda wa Gaza wa Palestina)',
        'ar_QA' => 'Kĩarabu (Katari)',
        'ar_SA' => 'Kĩarabu (Saudi)',
        'ar_SD' => 'Kĩarabu (Sudani)',
        'ar_SO' => 'Kĩarabu (Somaria)',
        'ar_SY' => 'Kĩarabu (Siria)',
        'ar_TD' => 'Kĩarabu (Chadi)',
        'ar_TN' => 'Kĩarabu (Tunisia)',
        'ar_YE' => 'Kĩarabu (Yemeni)',
        'be' => 'Kibelarusi',
        'be_BY' => 'Kibelarusi (Belarusi)',
        'bg' => 'Kibulgaria',
        'bg_BG' => 'Kibulgaria (Bulgaria)',
        'bn' => 'Kibangla',
        'bn_BD' => 'Kibangla (Bangladeshi)',
        'bn_IN' => 'Kibangla (India)',
        'cs' => 'Kichecki',
        'cs_CZ' => 'Kichecki (Jamhuri ya Cheki)',
        'de' => 'Kĩnjeremani',
        'de_AT' => 'Kĩnjeremani (Austria)',
        'de_BE' => 'Kĩnjeremani (Ubelgiji)',
        'de_CH' => 'Kĩnjeremani (Uswisi)',
        'de_DE' => 'Kĩnjeremani (Njeremani)',
        'de_IT' => 'Kĩnjeremani (Italia)',
        'de_LI' => 'Kĩnjeremani (Lishenteni)',
        'de_LU' => 'Kĩnjeremani (Lasembagi)',
        'el' => 'Kigiriki',
        'el_CY' => 'Kigiriki (Kuprosi)',
        'el_GR' => 'Kigiriki (Ugiriki)',
        'en' => 'Gĩthungũ',
        'en_AE' => 'Gĩthungũ (Falme za Kiarabu)',
        'en_AG' => 'Gĩthungũ (Antigua na Barbuda)',
        'en_AI' => 'Gĩthungũ (Anguilla)',
        'en_AS' => 'Gĩthungũ (Samoa ya Marekani)',
        'en_AT' => 'Gĩthungũ (Austria)',
        'en_AU' => 'Gĩthungũ (Australia)',
        'en_BB' => 'Gĩthungũ (Babadosi)',
        'en_BE' => 'Gĩthungũ (Ubelgiji)',
        'en_BI' => 'Gĩthungũ (Mburundi)',
        'en_BM' => 'Gĩthungũ (Bermuda)',
        'en_BS' => 'Gĩthungũ (Bahama)',
        'en_BW' => 'Gĩthungũ (Botswana)',
        'en_BZ' => 'Gĩthungũ (Belize)',
        'en_CA' => 'Gĩthungũ (Kanada)',
        'en_CH' => 'Gĩthungũ (Uswisi)',
        'en_CK' => 'Gĩthungũ (Visiwa vya Cook)',
        'en_CM' => 'Gĩthungũ (Kameruni)',
        'en_CY' => 'Gĩthungũ (Kuprosi)',
        'en_DE' => 'Gĩthungũ (Njeremani)',
        'en_DK' => 'Gĩthungũ (Denmaki)',
        'en_DM' => 'Gĩthungũ (Dominika)',
        'en_ER' => 'Gĩthungũ (Eritrea)',
        'en_FI' => 'Gĩthungũ (Ufini)',
        'en_FJ' => 'Gĩthungũ (Fiji)',
        'en_FK' => 'Gĩthungũ (Visiwa vya Falkland)',
        'en_FM' => 'Gĩthungũ (Mikronesia)',
        'en_GB' => 'Gĩthungũ (Ngeretha)',
        'en_GD' => 'Gĩthungũ (Grenada)',
        'en_GH' => 'Gĩthungũ (Ngana)',
        'en_GI' => 'Gĩthungũ (Jibralta)',
        'en_GM' => 'Gĩthungũ (Gambia)',
        'en_GU' => 'Gĩthungũ (Gwam)',
        'en_GY' => 'Gĩthungũ (Guyana)',
        'en_IE' => 'Gĩthungũ (Ayalandi)',
        'en_IL' => 'Gĩthungũ (Israeli)',
        'en_IN' => 'Gĩthungũ (India)',
        'en_IO' => 'Gĩthungũ (Eneo la Uingereza katika Bahari Hindi)',
        'en_JM' => 'Gĩthungũ (Jamaika)',
        'en_KE' => 'Gĩthungũ (Kenya)',
        'en_KI' => 'Gĩthungũ (Kiribati)',
        'en_KN' => 'Gĩthungũ (Santakitzi na Nevis)',
        'en_KY' => 'Gĩthungũ (Visiwa vya Kayman)',
        'en_LC' => 'Gĩthungũ (Santalusia)',
        'en_LR' => 'Gĩthungũ (Liberia)',
        'en_LS' => 'Gĩthungũ (Lesoto)',
        'en_MG' => 'Gĩthungũ (Bukini)',
        'en_MH' => 'Gĩthungũ (Visiwa vya Marshal)',
        'en_MP' => 'Gĩthungũ (Visiwa vya Mariana vya Kaskazini)',
        'en_MS' => 'Gĩthungũ (Montserrati)',
        'en_MT' => 'Gĩthungũ (Malta)',
        'en_MU' => 'Gĩthungũ (Morisi)',
        'en_MV' => 'Gĩthungũ (Modivu)',
        'en_MW' => 'Gĩthungũ (Malawi)',
        'en_MY' => 'Gĩthungũ (Malesia)',
        'en_NA' => 'Gĩthungũ (Namimbia)',
        'en_NF' => 'Gĩthungũ (Kisiwa cha Norfok)',
        'en_NG' => 'Gĩthungũ (Nainjeria)',
        'en_NL' => 'Gĩthungũ (Uholanzi)',
        'en_NR' => 'Gĩthungũ (Nauru)',
        'en_NU' => 'Gĩthungũ (Niue)',
        'en_NZ' => 'Gĩthungũ (Nyuzilandi)',
        'en_PG' => 'Gĩthungũ (Papua)',
        'en_PH' => 'Gĩthungũ (Filipino)',
        'en_PK' => 'Gĩthungũ (Pakistani)',
        'en_PN' => 'Gĩthungũ (Pitkairni)',
        'en_PR' => 'Gĩthungũ (Pwetoriko)',
        'en_PW' => 'Gĩthungũ (Palau)',
        'en_RW' => 'Gĩthungũ (Rwanda)',
        'en_SB' => 'Gĩthungũ (Visiwa vya Solomon)',
        'en_SC' => 'Gĩthungũ (Shelisheli)',
        'en_SD' => 'Gĩthungũ (Sudani)',
        'en_SE' => 'Gĩthungũ (Uswidi)',
        'en_SG' => 'Gĩthungũ (Singapoo)',
        'en_SH' => 'Gĩthungũ (Santahelena)',
        'en_SI' => 'Gĩthungũ (Slovenia)',
        'en_SL' => 'Gĩthungũ (Siera Leoni)',
        'en_SZ' => 'Gĩthungũ (Uswazi)',
        'en_TC' => 'Gĩthungũ (Visiwa vya Turki na Kaiko)',
        'en_TK' => 'Gĩthungũ (Tokelau)',
        'en_TO' => 'Gĩthungũ (Tonga)',
        'en_TT' => 'Gĩthungũ (Trinidad na Tobago)',
        'en_TV' => 'Gĩthungũ (Tuvalu)',
        'en_TZ' => 'Gĩthungũ (Tanzania)',
        'en_UG' => 'Gĩthungũ (Uganda)',
        'en_US' => 'Gĩthungũ (Amerika)',
        'en_VC' => 'Gĩthungũ (Santavisenti na Grenadini)',
        'en_VG' => 'Gĩthungũ (Visiwa vya Virgin vya Uingereza)',
        'en_VI' => 'Gĩthungũ (Visiwa vya Virgin vya Marekani)',
        'en_VU' => 'Gĩthungũ (Vanuatu)',
        'en_WS' => 'Gĩthungũ (Samoa)',
        'en_ZA' => 'Gĩthungũ (Afrika Kusini)',
        'en_ZM' => 'Gĩthungũ (Zambia)',
        'en_ZW' => 'Gĩthungũ (Zimbabwe)',
        'es' => 'Kihispania',
        'es_AR' => 'Kihispania (Ajentina)',
        'es_BO' => 'Kihispania (Bolivia)',
        'es_BR' => 'Kihispania (Brazili)',
        'es_BZ' => 'Kihispania (Belize)',
        'es_CL' => 'Kihispania (Chile)',
        'es_CO' => 'Kihispania (Kolombia)',
        'es_CR' => 'Kihispania (Kostarika)',
        'es_CU' => 'Kihispania (Kiumba)',
        'es_DO' => 'Kihispania (Jamhuri ya Dominika)',
        'es_EC' => 'Kihispania (Ekwado)',
        'es_ES' => 'Kihispania (Hispania)',
        'es_GQ' => 'Kihispania (Ginekweta)',
        'es_GT' => 'Kihispania (Gwatemala)',
        'es_HN' => 'Kihispania (Hondurasi)',
        'es_MX' => 'Kihispania (Meksiko)',
        'es_NI' => 'Kihispania (Nikaragwa)',
        'es_PA' => 'Kihispania (Panama)',
        'es_PE' => 'Kihispania (Peru)',
        'es_PH' => 'Kihispania (Filipino)',
        'es_PR' => 'Kihispania (Pwetoriko)',
        'es_PY' => 'Kihispania (Paragwai)',
        'es_SV' => 'Kihispania (Elsavado)',
        'es_US' => 'Kihispania (Amerika)',
        'es_UY' => 'Kihispania (Urugwai)',
        'es_VE' => 'Kihispania (Venezuela)',
        'fa' => 'Kiajemi',
        'fa_AF' => 'Kiajemi (Afuganistani)',
        'fa_IR' => 'Kiajemi (Uajemi)',
        'fr' => 'Kĩbaranja',
        'fr_BE' => 'Kĩbaranja (Ubelgiji)',
        'fr_BF' => 'Kĩbaranja (Bukinafaso)',
        'fr_BI' => 'Kĩbaranja (Mburundi)',
        'fr_BJ' => 'Kĩbaranja (Benini)',
        'fr_CA' => 'Kĩbaranja (Kanada)',
        'fr_CD' => 'Kĩbaranja (Jamhuri ya Kidemokrasia ya Kongo)',
        'fr_CF' => 'Kĩbaranja (Jamhuri ya Afrika ya Kati)',
        'fr_CG' => 'Kĩbaranja (Kongo)',
        'fr_CH' => 'Kĩbaranja (Uswisi)',
        'fr_CI' => 'Kĩbaranja (Kodivaa)',
        'fr_CM' => 'Kĩbaranja (Kameruni)',
        'fr_DJ' => 'Kĩbaranja (Jibuti)',
        'fr_DZ' => 'Kĩbaranja (Aljeria)',
        'fr_FR' => 'Kĩbaranja (Ubaranja)',
        'fr_GA' => 'Kĩbaranja (Gaboni)',
        'fr_GF' => 'Kĩbaranja (Gwiyana ya Ufaransa)',
        'fr_GN' => 'Kĩbaranja (Gine)',
        'fr_GP' => 'Kĩbaranja (Gwadelupe)',
        'fr_GQ' => 'Kĩbaranja (Ginekweta)',
        'fr_HT' => 'Kĩbaranja (Haiti)',
        'fr_KM' => 'Kĩbaranja (Komoro)',
        'fr_LU' => 'Kĩbaranja (Lasembagi)',
        'fr_MA' => 'Kĩbaranja (Moroko)',
        'fr_MC' => 'Kĩbaranja (Monako)',
        'fr_MG' => 'Kĩbaranja (Bukini)',
        'fr_ML' => 'Kĩbaranja (Mali)',
        'fr_MQ' => 'Kĩbaranja (Martiniki)',
        'fr_MR' => 'Kĩbaranja (Moritania)',
        'fr_MU' => 'Kĩbaranja (Morisi)',
        'fr_NC' => 'Kĩbaranja (Nyukaledonia)',
        'fr_NE' => 'Kĩbaranja (Nijeri)',
        'fr_PF' => 'Kĩbaranja (Polinesia ya Ufaransa)',
        'fr_PM' => 'Kĩbaranja (Santapieri na Mikeloni)',
        'fr_RE' => 'Kĩbaranja (Riyunioni)',
        'fr_RW' => 'Kĩbaranja (Rwanda)',
        'fr_SC' => 'Kĩbaranja (Shelisheli)',
        'fr_SN' => 'Kĩbaranja (Senegali)',
        'fr_SY' => 'Kĩbaranja (Siria)',
        'fr_TD' => 'Kĩbaranja (Chadi)',
        'fr_TG' => 'Kĩbaranja (Togo)',
        'fr_TN' => 'Kĩbaranja (Tunisia)',
        'fr_VU' => 'Kĩbaranja (Vanuatu)',
        'fr_WF' => 'Kĩbaranja (Walis na Futuna)',
        'fr_YT' => 'Kĩbaranja (Mayotte)',
        'ha' => 'Kihausa',
        'ha_GH' => 'Kihausa (Ngana)',
        'ha_NE' => 'Kihausa (Nijeri)',
        'ha_NG' => 'Kihausa (Nainjeria)',
        'hi' => 'Kĩhĩndĩ',
        'hi_IN' => 'Kĩhĩndĩ (India)',
        'hu' => 'Kihungari',
        'hu_HU' => 'Kihungari (Hungaria)',
        'id' => 'Kiindonesia',
        'id_ID' => 'Kiindonesia (Indonesia)',
        'ig' => 'Kiigbo',
        'ig_NG' => 'Kiigbo (Nainjeria)',
        'it' => 'Kĩtaliano',
        'it_CH' => 'Kĩtaliano (Uswisi)',
        'it_IT' => 'Kĩtaliano (Italia)',
        'it_SM' => 'Kĩtaliano (Samarino)',
        'it_VA' => 'Kĩtaliano (Vatikani)',
        'ja' => 'Kĩnjabani',
        'ja_JP' => 'Kĩnjabani (Njabani)',
        'jv' => 'Kijava',
        'jv_ID' => 'Kijava (Indonesia)',
        'ki' => 'Gikuyu',
        'ki_KE' => 'Gikuyu (Kenya)',
        'km' => 'Kikambodia',
        'km_KH' => 'Kikambodia (Kambodia)',
        'ko' => 'Kikorea',
        'ko_KP' => 'Kikorea (Korea Kaskazini)',
        'ko_KR' => 'Kikorea (Korea Kusini)',
        'ms' => 'Kimalesia',
        'ms_BN' => 'Kimalesia (Brunei)',
        'ms_ID' => 'Kimalesia (Indonesia)',
        'ms_MY' => 'Kimalesia (Malesia)',
        'ms_SG' => 'Kimalesia (Singapoo)',
        'my' => 'Kiburma',
        'my_MM' => 'Kiburma (Myama)',
        'ne' => 'Kinepali',
        'ne_IN' => 'Kinepali (India)',
        'ne_NP' => 'Kinepali (Nepali)',
        'nl' => 'Kiholanzi',
        'nl_AW' => 'Kiholanzi (Aruba)',
        'nl_BE' => 'Kiholanzi (Ubelgiji)',
        'nl_NL' => 'Kiholanzi (Uholanzi)',
        'nl_SR' => 'Kiholanzi (Surinamu)',
        'pa' => 'Kipunjabi',
        'pa_IN' => 'Kipunjabi (India)',
        'pa_PK' => 'Kipunjabi (Pakistani)',
        'pl' => 'Kipolandi',
        'pl_PL' => 'Kipolandi (Polandi)',
        'pt' => 'Kireno',
        'pt_AO' => 'Kireno (Angola)',
        'pt_BR' => 'Kireno (Brazili)',
        'pt_CH' => 'Kireno (Uswisi)',
        'pt_CV' => 'Kireno (Kepuvede)',
        'pt_GQ' => 'Kireno (Ginekweta)',
        'pt_GW' => 'Kireno (Ginebisau)',
        'pt_LU' => 'Kireno (Lasembagi)',
        'pt_MZ' => 'Kireno (Msumbiji)',
        'pt_PT' => 'Kireno (Ureno)',
        'pt_ST' => 'Kireno (Sao Tome na Principe)',
        'pt_TL' => 'Kireno (Timori ya Mashariki)',
        'ro' => 'Kiromania',
        'ro_MD' => 'Kiromania (Moldova)',
        'ro_RO' => 'Kiromania (Romania)',
        'ru' => 'Kĩracia',
        'ru_BY' => 'Kĩracia (Belarusi)',
        'ru_KG' => 'Kĩracia (Kirigizistani)',
        'ru_KZ' => 'Kĩracia (Kazakistani)',
        'ru_MD' => 'Kĩracia (Moldova)',
        'ru_RU' => 'Kĩracia (Urusi)',
        'ru_UA' => 'Kĩracia (Ukraini)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'so' => 'Kĩcumarĩ',
        'so_DJ' => 'Kĩcumarĩ (Jibuti)',
        'so_ET' => 'Kĩcumarĩ (Uhabeshi)',
        'so_KE' => 'Kĩcumarĩ (Kenya)',
        'so_SO' => 'Kĩcumarĩ (Somaria)',
        'sv' => 'Kiswidi',
        'sv_FI' => 'Kiswidi (Ufini)',
        'sv_SE' => 'Kiswidi (Uswidi)',
        'ta' => 'Kitamil',
        'ta_IN' => 'Kitamil (India)',
        'ta_LK' => 'Kitamil (Sirilanka)',
        'ta_MY' => 'Kitamil (Malesia)',
        'ta_SG' => 'Kitamil (Singapoo)',
        'th' => 'Kitailandi',
        'th_TH' => 'Kitailandi (Tailandi)',
        'tr' => 'Kituruki',
        'tr_CY' => 'Kituruki (Kuprosi)',
        'tr_TR' => 'Kituruki (Uturuki)',
        'uk' => 'Kiukrania',
        'uk_UA' => 'Kiukrania (Ukraini)',
        'ur' => 'Kiurdu',
        'ur_IN' => 'Kiurdu (India)',
        'ur_PK' => 'Kiurdu (Pakistani)',
        'vi' => 'Kivietinamu',
        'vi_VN' => 'Kivietinamu (Vietinamu)',
        'yo' => 'Kiyoruba',
        'yo_BJ' => 'Kiyoruba (Benini)',
        'yo_NG' => 'Kiyoruba (Nainjeria)',
        'zh' => 'Kĩcaina',
        'zh_CN' => 'Kĩcaina (Caina)',
        'zh_SG' => 'Kĩcaina (Singapoo)',
        'zh_TW' => 'Kĩcaina (Taiwani)',
        'zu' => 'Kizulu',
        'zu_ZA' => 'Kizulu (Afrika Kusini)',
    ],
];
