<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Գրինվիչի ժամանակ (Աբիջան)',
        'Africa/Accra' => 'Գրինվիչի ժամանակ (Աքրա)',
        'Africa/Addis_Ababa' => 'Արևելյան Աֆրիկայի ժամանակ (Ադիս Աբեբա)',
        'Africa/Algiers' => 'Կենտրոնական Եվրոպայի ժամանակ (Ալժիր)',
        'Africa/Asmera' => 'Արևելյան Աֆրիկայի ժամանակ (Ասմերա)',
        'Africa/Bamako' => 'Գրինվիչի ժամանակ (Բամակո)',
        'Africa/Bangui' => 'Արևմտյան Աֆրիկայի ժամանակ (Բանգի)',
        'Africa/Banjul' => 'Գրինվիչի ժամանակ (Բանժուլ)',
        'Africa/Bissau' => 'Գրինվիչի ժամանակ (Բիսաու)',
        'Africa/Blantyre' => 'Կենտրոնական Աֆրիկայի ժամանակ (Բլանթայր)',
        'Africa/Brazzaville' => 'Արևմտյան Աֆրիկայի ժամանակ (Բրազավիլ)',
        'Africa/Bujumbura' => 'Կենտրոնական Աֆրիկայի ժամանակ (Բուժումբուրա)',
        'Africa/Cairo' => 'Արևելյան Եվրոպայի ժամանակ (Կահիրե)',
        'Africa/Casablanca' => 'Արևմտյան Եվրոպայի ժամանակ (Կասաբլանկա)',
        'Africa/Ceuta' => 'Կենտրոնական Եվրոպայի ժամանակ (Սեուտա)',
        'Africa/Conakry' => 'Գրինվիչի ժամանակ (Կոնակրի)',
        'Africa/Dakar' => 'Գրինվիչի ժամանակ (Դաքար)',
        'Africa/Dar_es_Salaam' => 'Արևելյան Աֆրիկայի ժամանակ (Դար-Էս-Սալամ)',
        'Africa/Djibouti' => 'Արևելյան Աֆրիկայի ժամանակ (Ջիբութի)',
        'Africa/Douala' => 'Արևմտյան Աֆրիկայի ժամանակ (Դուալա)',
        'Africa/El_Aaiun' => 'Արևմտյան Եվրոպայի ժամանակ (Էլ Այուն)',
        'Africa/Freetown' => 'Գրինվիչի ժամանակ (Ֆրիթաուն)',
        'Africa/Gaborone' => 'Կենտրոնական Աֆրիկայի ժամանակ (Գաբորոնե)',
        'Africa/Harare' => 'Կենտրոնական Աֆրիկայի ժամանակ (Հարարե)',
        'Africa/Johannesburg' => 'Հարավային Աֆրիկայի ժամանակ (Յոհանեսբուրգ)',
        'Africa/Juba' => 'Կենտրոնական Աֆրիկայի ժամանակ (Ջուբա)',
        'Africa/Kampala' => 'Արևելյան Աֆրիկայի ժամանակ (Կամպալա)',
        'Africa/Khartoum' => 'Կենտրոնական Աֆրիկայի ժամանակ (Խարթում)',
        'Africa/Kigali' => 'Կենտրոնական Աֆրիկայի ժամանակ (Կիգալի)',
        'Africa/Kinshasa' => 'Արևմտյան Աֆրիկայի ժամանակ (Կինշասա)',
        'Africa/Lagos' => 'Արևմտյան Աֆրիկայի ժամանակ (Լագոս)',
        'Africa/Libreville' => 'Արևմտյան Աֆրիկայի ժամանակ (Լիբրևիլ)',
        'Africa/Lome' => 'Գրինվիչի ժամանակ (Լոմե)',
        'Africa/Luanda' => 'Արևմտյան Աֆրիկայի ժամանակ (Լուանդա)',
        'Africa/Lubumbashi' => 'Կենտրոնական Աֆրիկայի ժամանակ (Լուբումբաշի)',
        'Africa/Lusaka' => 'Կենտրոնական Աֆրիկայի ժամանակ (Լուսակա)',
        'Africa/Malabo' => 'Արևմտյան Աֆրիկայի ժամանակ (Մալաբո)',
        'Africa/Maputo' => 'Կենտրոնական Աֆրիկայի ժամանակ (Մապուտու)',
        'Africa/Maseru' => 'Հարավային Աֆրիկայի ժամանակ (Մասերու)',
        'Africa/Mbabane' => 'Հարավային Աֆրիկայի ժամանակ (Մբաբանե)',
        'Africa/Mogadishu' => 'Արևելյան Աֆրիկայի ժամանակ (Մոգադիշո)',
        'Africa/Monrovia' => 'Գրինվիչի ժամանակ (Մոնրովիա)',
        'Africa/Nairobi' => 'Արևելյան Աֆրիկայի ժամանակ (Նայրոբի)',
        'Africa/Ndjamena' => 'Արևմտյան Աֆրիկայի ժամանակ (Նջամենա)',
        'Africa/Niamey' => 'Արևմտյան Աֆրիկայի ժամանակ (Նիամեյ)',
        'Africa/Nouakchott' => 'Գրինվիչի ժամանակ (Նուակշոտ)',
        'Africa/Ouagadougou' => 'Գրինվիչի ժամանակ (Ուագադուգու)',
        'Africa/Porto-Novo' => 'Արևմտյան Աֆրիկայի ժամանակ (Պորտո Նովո)',
        'Africa/Sao_Tome' => 'Գրինվիչի ժամանակ (Սան Տոմե)',
        'Africa/Tripoli' => 'Արևելյան Եվրոպայի ժամանակ (Տրիպոլի)',
        'Africa/Tunis' => 'Կենտրոնական Եվրոպայի ժամանակ (Թունիս)',
        'Africa/Windhoek' => 'Կենտրոնական Աֆրիկայի ժամանակ (Վինդհուկ)',
        'America/Adak' => 'Հավայան-ալեության ժամանակ (Ադակ կղզի)',
        'America/Anchorage' => 'Ալյասկայի ժամանակ (Անքորիջ)',
        'America/Anguilla' => 'Ատլանտյան ժամանակ (Անգուիլա)',
        'America/Antigua' => 'Ատլանտյան ժամանակ (Անտիգուա)',
        'America/Araguaina' => 'Բրազիլիայի ժամանակ (Արագուաինա)',
        'America/Argentina/La_Rioja' => 'Արգենտինայի ժամանակ (Լա Ռիոխա)',
        'America/Argentina/Rio_Gallegos' => 'Արգենտինայի ժամանակ (Ռիո Գալյեգոս)',
        'America/Argentina/Salta' => 'Արգենտինայի ժամանակ (Սալտա)',
        'America/Argentina/San_Juan' => 'Արգենտինայի ժամանակ (Սան Խուան)',
        'America/Argentina/San_Luis' => 'Արգենտինայի ժամանակ (Սան Լուիս)',
        'America/Argentina/Tucuman' => 'Արգենտինայի ժամանակ (Տուկուման)',
        'America/Argentina/Ushuaia' => 'Արգենտինայի ժամանակ (Ուշուայա)',
        'America/Aruba' => 'Ատլանտյան ժամանակ (Արուբա)',
        'America/Asuncion' => 'Պարագվայի ժամանակ (Ասունսյոն)',
        'America/Bahia' => 'Բրազիլիայի ժամանակ (Բաիյա)',
        'America/Bahia_Banderas' => 'Կենտրոնական Ամերիկայի ժամանակ (Բաիյա Բանդերաս)',
        'America/Barbados' => 'Ատլանտյան ժամանակ (Բարբադոս)',
        'America/Belem' => 'Բրազիլիայի ժամանակ (Բելեմ)',
        'America/Belize' => 'Կենտրոնական Ամերիկայի ժամանակ (Բելիզ)',
        'America/Blanc-Sablon' => 'Ատլանտյան ժամանակ (Բլանկ-Սաբլոն)',
        'America/Boa_Vista' => 'Ամազոնյան ժամանակ (Բոա Վիստա)',
        'America/Bogota' => 'Կոլումբիայի ժամանակ (Բոգոտա)',
        'America/Boise' => 'Լեռնային ժամանակ (ԱՄՆ) (Բոյսե)',
        'America/Buenos_Aires' => 'Արգենտինայի ժամանակ (Բուենոս Այրես)',
        'America/Cambridge_Bay' => 'Լեռնային ժամանակ (ԱՄՆ) (Քեմբրիջ Բեյ)',
        'America/Campo_Grande' => 'Ամազոնյան ժամանակ (Կամպու Գրանդի)',
        'America/Cancun' => 'Արևելյան Ամերիկայի ժամանակ (Կանկուն)',
        'America/Caracas' => 'Վենեսուելայի ժամանակ (Կարակաս)',
        'America/Catamarca' => 'Արգենտինայի ժամանակ (Կատամարկա)',
        'America/Cayenne' => 'Ֆրանսիական Գվիանայի ժամանակ (Կայեն)',
        'America/Cayman' => 'Արևելյան Ամերիկայի ժամանակ (Կայման կղզիներ)',
        'America/Chicago' => 'Կենտրոնական Ամերիկայի ժամանակ (Չիկագո)',
        'America/Chihuahua' => 'Մեքսիկայի խաղաղօվկիանոսյան ժամանակ (Չիուաուա)',
        'America/Coral_Harbour' => 'Արևելյան Ամերիկայի ժամանակ (Ատիկոկան)',
        'America/Cordoba' => 'Արգենտինայի ժամանակ (Կորդովա)',
        'America/Costa_Rica' => 'Կենտրոնական Ամերիկայի ժամանակ (Կոստա Ռիկա)',
        'America/Creston' => 'Լեռնային ժամանակ (ԱՄՆ) (Քրեսթոն)',
        'America/Cuiaba' => 'Ամազոնյան ժամանակ (Կույաբա)',
        'America/Curacao' => 'Ատլանտյան ժամանակ (Կյուրասաո)',
        'America/Danmarkshavn' => 'Գրինվիչի ժամանակ (Դենմարքսհավն)',
        'America/Dawson' => 'Յուկոնի ժամանակ (Դոուսոն)',
        'America/Dawson_Creek' => 'Լեռնային ժամանակ (ԱՄՆ) (Դոուսոն Քրիք)',
        'America/Denver' => 'Լեռնային ժամանակ (ԱՄՆ) (Դենվեր)',
        'America/Detroit' => 'Արևելյան Ամերիկայի ժամանակ (Դետրոյթ)',
        'America/Dominica' => 'Ատլանտյան ժամանակ (Դոմինիկա)',
        'America/Edmonton' => 'Լեռնային ժամանակ (ԱՄՆ) (Էդմոնտոն)',
        'America/Eirunepe' => 'Բրազիլիա (Էյրունեպե)',
        'America/El_Salvador' => 'Կենտրոնական Ամերիկայի ժամանակ (Սալվադոր)',
        'America/Fort_Nelson' => 'Լեռնային ժամանակ (ԱՄՆ) (Ֆորտ Նելսոն)',
        'America/Fortaleza' => 'Բրազիլիայի ժամանակ (Ֆորտալեզա)',
        'America/Glace_Bay' => 'Ատլանտյան ժամանակ (Գլեյս Բեյ)',
        'America/Godthab' => 'Արևմտյան Գրենլանդիայի ժամանակ (Նուուկ)',
        'America/Goose_Bay' => 'Ատլանտյան ժամանակ (Գուս Բեյ)',
        'America/Grand_Turk' => 'Արևելյան Ամերիկայի ժամանակ (Գրանդ Տյորք)',
        'America/Grenada' => 'Ատլանտյան ժամանակ (Գրենադա)',
        'America/Guadeloupe' => 'Ատլանտյան ժամանակ (Գվադելուպա)',
        'America/Guatemala' => 'Կենտրոնական Ամերիկայի ժամանակ (Գվատեմալա)',
        'America/Guayaquil' => 'Էկվադորի ժամանակ (Գուայակիլ)',
        'America/Guyana' => 'Գայանայի ժամանակ',
        'America/Halifax' => 'Ատլանտյան ժամանակ (Հալիֆաքս)',
        'America/Havana' => 'Կուբայի ժամանակ (Հավանա)',
        'America/Hermosillo' => 'Մեքսիկայի խաղաղօվկիանոսյան ժամանակ (Էրմոսիլյո)',
        'America/Indiana/Knox' => 'Կենտրոնական Ամերիկայի ժամանակ (Նոքս, Ինդիանա)',
        'America/Indiana/Marengo' => 'Արևելյան Ամերիկայի ժամանակ (Մարենգո, Ինդիանա)',
        'America/Indiana/Petersburg' => 'Արևելյան Ամերիկայի ժամանակ (Պետերսբուրգ, Ինդիանա)',
        'America/Indiana/Tell_City' => 'Կենտրոնական Ամերիկայի ժամանակ (Թել Սիթի, Ինդիանա)',
        'America/Indiana/Vevay' => 'Արևելյան Ամերիկայի ժամանակ (Վիվեյ, Ինդիանա)',
        'America/Indiana/Vincennes' => 'Արևելյան Ամերիկայի ժամանակ (Վինսենս, Ինդիանա)',
        'America/Indiana/Winamac' => 'Արևելյան Ամերիկայի ժամանակ (Վինամակ, Ինդիանա)',
        'America/Indianapolis' => 'Արևելյան Ամերիկայի ժամանակ (Ինդիանապոլիս)',
        'America/Inuvik' => 'Լեռնային ժամանակ (ԱՄՆ) (Ինուվիկ)',
        'America/Iqaluit' => 'Արևելյան Ամերիկայի ժամանակ (Իկալուիտ)',
        'America/Jamaica' => 'Արևելյան Ամերիկայի ժամանակ (Ճամայկա)',
        'America/Jujuy' => 'Արգենտինայի ժամանակ (Ժուժույ)',
        'America/Juneau' => 'Ալյասկայի ժամանակ (Ջունո)',
        'America/Kentucky/Monticello' => 'Արևելյան Ամերիկայի ժամանակ (Մոնտիսելո, Կենտուկի)',
        'America/Kralendijk' => 'Ատլանտյան ժամանակ (Կրալենդեյկ)',
        'America/La_Paz' => 'Բոլիվիայի ժամանակ (Լա Պաս)',
        'America/Lima' => 'Պերուի ժամանակ (Լիմա)',
        'America/Los_Angeles' => 'Խաղաղօվկիանոսյան ժամանակ (Լոս Անջելես)',
        'America/Louisville' => 'Արևելյան Ամերիկայի ժամանակ (Լուիսվիլ)',
        'America/Lower_Princes' => 'Ատլանտյան ժամանակ (Լոուեր Պրինսես Քվորթեր)',
        'America/Maceio' => 'Բրազիլիայի ժամանակ (Մասեյո)',
        'America/Managua' => 'Կենտրոնական Ամերիկայի ժամանակ (Մանագուա)',
        'America/Manaus' => 'Ամազոնյան ժամանակ (Մանաուս)',
        'America/Marigot' => 'Ատլանտյան ժամանակ (Մարիգո)',
        'America/Martinique' => 'Ատլանտյան ժամանակ (Մարտինիկա)',
        'America/Matamoros' => 'Կենտրոնական Ամերիկայի ժամանակ (Մատամորոս)',
        'America/Mazatlan' => 'Մեքսիկայի խաղաղօվկիանոսյան ժամանակ (Մազաթլան)',
        'America/Mendoza' => 'Արգենտինայի ժամանակ (Մենդոսա)',
        'America/Menominee' => 'Կենտրոնական Ամերիկայի ժամանակ (Մենոմինի)',
        'America/Merida' => 'Կենտրոնական Ամերիկայի ժամանակ (Մերիդա)',
        'America/Metlakatla' => 'Ալյասկայի ժամանակ (Մետլակատլա)',
        'America/Mexico_City' => 'Կենտրոնական Ամերիկայի ժամանակ (Մեխիկո)',
        'America/Miquelon' => 'Սեն Պիեռ և Միքելոնի ժամանակ',
        'America/Moncton' => 'Ատլանտյան ժամանակ (Մոնկտոն)',
        'America/Monterrey' => 'Կենտրոնական Ամերիկայի ժամանակ (Մոնտեռեյ)',
        'America/Montevideo' => 'Ուրուգվայի ժամանակ (Մոնտեվիդեո)',
        'America/Montreal' => 'Կանադա (Montreal)',
        'America/Montserrat' => 'Ատլանտյան ժամանակ (Մոնսեռատ)',
        'America/Nassau' => 'Արևելյան Ամերիկայի ժամանակ (Նասաու)',
        'America/New_York' => 'Արևելյան Ամերիկայի ժամանակ (Նյու Յորք)',
        'America/Nipigon' => 'Արևելյան Ամերիկայի ժամանակ (Նիպիգոն)',
        'America/Nome' => 'Ալյասկայի ժամանակ (Նոմ)',
        'America/Noronha' => 'Ֆերնանդու դի Նորոնյայի ժամանակ',
        'America/North_Dakota/Beulah' => 'Կենտրոնական Ամերիկայի ժամանակ (Բոյլա, Հյուսիսային Դակոտա)',
        'America/North_Dakota/Center' => 'Կենտրոնական Ամերիկայի ժամանակ (Հյուսիսային Դակոտա - Կենտրոն)',
        'America/North_Dakota/New_Salem' => 'Կենտրոնական Ամերիկայի ժամանակ (Նյու Սալեմ, Հյուսիսային Դակոտա)',
        'America/Ojinaga' => 'Լեռնային ժամանակ (ԱՄՆ) (Օխինագա)',
        'America/Panama' => 'Արևելյան Ամերիկայի ժամանակ (Պանամա)',
        'America/Pangnirtung' => 'Արևելյան Ամերիկայի ժամանակ (Պանգնիրտանգ)',
        'America/Paramaribo' => 'Սուրինամի ժամանակ (Պարամարիբո)',
        'America/Phoenix' => 'Լեռնային ժամանակ (ԱՄՆ) (Ֆինիքս)',
        'America/Port-au-Prince' => 'Արևելյան Ամերիկայի ժամանակ (Պորտ-օ-Պրենս)',
        'America/Port_of_Spain' => 'Ատլանտյան ժամանակ (Պորտ-օֆ-Սփեյն)',
        'America/Porto_Velho' => 'Ամազոնյան ժամանակ (Պորտու Վելյու)',
        'America/Puerto_Rico' => 'Ատլանտյան ժամանակ (Պուերտո Ռիկո)',
        'America/Punta_Arenas' => 'Չիլիի ժամանակ (Պունտա Արենաս)',
        'America/Rainy_River' => 'Կենտրոնական Ամերիկայի ժամանակ (Ռեյնի Ռիվեր)',
        'America/Rankin_Inlet' => 'Կենտրոնական Ամերիկայի ժամանակ (Ռանկին Ինլեթ)',
        'America/Recife' => 'Բրազիլիայի ժամանակ (Ռեսիֆի)',
        'America/Regina' => 'Կենտրոնական Ամերիկայի ժամանակ (Ռեջայնա)',
        'America/Resolute' => 'Կենտրոնական Ամերիկայի ժամանակ (Ռեզոլյուտ)',
        'America/Rio_Branco' => 'Բրազիլիա (Ռիու Բրանկու)',
        'America/Santa_Isabel' => 'Հյուսիսարևմտյան Մեքսիկայի ժամանակ (Սանտա Իզաբել)',
        'America/Santarem' => 'Բրազիլիայի ժամանակ (Սանտարեմ)',
        'America/Santiago' => 'Չիլիի ժամանակ (Սանտյագո)',
        'America/Santo_Domingo' => 'Ատլանտյան ժամանակ (Սանտո Դոմինգո)',
        'America/Sao_Paulo' => 'Բրազիլիայի ժամանակ (Սան Պաուլու)',
        'America/Scoresbysund' => 'Արևելյան Գրենլանդիայի ժամանակ (Սկորսբիսուն)',
        'America/Sitka' => 'Ալյասկայի ժամանակ (Սիտկա)',
        'America/St_Barthelemy' => 'Ատլանտյան ժամանակ (Սեն Բարտելմի)',
        'America/St_Johns' => 'Նյուֆաունդլենդի ժամանակ (Սենթ Ջոնս)',
        'America/St_Kitts' => 'Ատլանտյան ժամանակ (Սենթ Քիտս)',
        'America/St_Lucia' => 'Ատլանտյան ժամանակ (Սենթ Լյուսիա)',
        'America/St_Thomas' => 'Ատլանտյան ժամանակ (Սենթ Թոմաս)',
        'America/St_Vincent' => 'Ատլանտյան ժամանակ (Սենթ Վինսենթ)',
        'America/Swift_Current' => 'Կենտրոնական Ամերիկայի ժամանակ (Սվիֆթ Քարենթ)',
        'America/Tegucigalpa' => 'Կենտրոնական Ամերիկայի ժամանակ (Տեգուսիգալպա)',
        'America/Thule' => 'Ատլանտյան ժամանակ (Տուլե)',
        'America/Thunder_Bay' => 'Արևելյան Ամերիկայի ժամանակ (Թանդեր Բեյ)',
        'America/Tijuana' => 'Խաղաղօվկիանոսյան ժամանակ (Տիխուանա)',
        'America/Toronto' => 'Արևելյան Ամերիկայի ժամանակ (Տորոնտո)',
        'America/Tortola' => 'Ատլանտյան ժամանակ (Թորթոլա)',
        'America/Vancouver' => 'Խաղաղօվկիանոսյան ժամանակ (Վանկուվեր)',
        'America/Whitehorse' => 'Յուկոնի ժամանակ (Ուայթհորս)',
        'America/Winnipeg' => 'Կենտրոնական Ամերիկայի ժամանակ (Վինիպեգ)',
        'America/Yakutat' => 'Ալյասկայի ժամանակ (Յակուտատ)',
        'America/Yellowknife' => 'Լեռնային ժամանակ (ԱՄՆ) (Յելոունայֆ)',
        'Antarctica/Casey' => 'Անտարկտիդա (Քեյսի)',
        'Antarctica/Davis' => 'Դեյվիսի ժամանակ',
        'Antarctica/DumontDUrville' => 'Դյումոն դ’Յուրվիլի ժամանակ',
        'Antarctica/Macquarie' => 'Արևելյան Ավստրալիայի ժամանակ (Մակկուորի կղզի)',
        'Antarctica/Mawson' => 'Մոուսոնի ժամանակ',
        'Antarctica/McMurdo' => 'Նոր Զելանդիայի ժամանակ (Մակ-Մերդո)',
        'Antarctica/Palmer' => 'Չիլիի ժամանակ (Պալմեր)',
        'Antarctica/Rothera' => 'Ռոտերայի ժամանակ',
        'Antarctica/Syowa' => 'Սյովայի ժամանակ',
        'Antarctica/Troll' => 'Գրինվիչի ժամանակ (Տրոլլ)',
        'Antarctica/Vostok' => 'Վոստոկի ժամանակ',
        'Arctic/Longyearbyen' => 'Կենտրոնական Եվրոպայի ժամանակ (Լոնգյիր)',
        'Asia/Aden' => 'Սաուդյան Արաբիայի ժամանակ (Ադեն)',
        'Asia/Almaty' => 'Արևելյան Ղազախստանի ժամանակ (Ալմաթի)',
        'Asia/Amman' => 'Արևելյան Եվրոպայի ժամանակ (Ամման)',
        'Asia/Anadyr' => 'Ռուսաստան (Անադիր)',
        'Asia/Aqtau' => 'Արևմտյան Ղազախստանի ժամանակ (Ակտաու)',
        'Asia/Aqtobe' => 'Արևմտյան Ղազախստանի ժամանակ (Ակտոբե)',
        'Asia/Ashgabat' => 'Թուրքմենստանի ժամանակ (Աշխաբադ)',
        'Asia/Atyrau' => 'Արևմտյան Ղազախստանի ժամանակ (Ատիրաու)',
        'Asia/Baghdad' => 'Սաուդյան Արաբիայի ժամանակ (Բաղդադ)',
        'Asia/Bahrain' => 'Սաուդյան Արաբիայի ժամանակ (Բահրեյն)',
        'Asia/Baku' => 'Ադրբեջանի ժամանակ (Բաքու)',
        'Asia/Bangkok' => 'Հնդկաչինական ժամանակ (Բանգկոկ)',
        'Asia/Barnaul' => 'Ռուսաստան (Բառնաուլ)',
        'Asia/Beirut' => 'Արևելյան Եվրոպայի ժամանակ (Բեյրութ)',
        'Asia/Bishkek' => 'Ղրղզստանի ժամանակ (Բիշքեկ)',
        'Asia/Brunei' => 'Բրունեյի ժամանակ',
        'Asia/Calcutta' => 'Հնդկաստանի ստանդարտ ժամանակ (Կալկուտա)',
        'Asia/Chita' => 'Յակուտսկի ժամանակ (Չիտա)',
        'Asia/Choibalsan' => 'Ուլան Բատորի ժամանակ (Չոյբալսան)',
        'Asia/Colombo' => 'Հնդկաստանի ստանդարտ ժամանակ (Կոլոմբո)',
        'Asia/Damascus' => 'Արևելյան Եվրոպայի ժամանակ (Դամասկոս)',
        'Asia/Dhaka' => 'Բանգլադեշի ժամանակ (Դաքքա)',
        'Asia/Dili' => 'Արևելյան Թիմորի ժամանակ (Դիլի)',
        'Asia/Dubai' => 'Պարսից ծոցի ստանդարտ ժամանակ (Դուբայ)',
        'Asia/Dushanbe' => 'Տաջիկստանի ժամանակ (Դուշանբե)',
        'Asia/Famagusta' => 'Արևելյան Եվրոպայի ժամանակ (Ֆամագուստա)',
        'Asia/Gaza' => 'Արևելյան Եվրոպայի ժամանակ (Գազա)',
        'Asia/Hebron' => 'Արևելյան Եվրոպայի ժամանակ (Հեբրոն)',
        'Asia/Hong_Kong' => 'Հոնկոնգի ժամանակ',
        'Asia/Hovd' => 'Հովդի ժամանակ',
        'Asia/Irkutsk' => 'Իրկուտսկի ժամանակ',
        'Asia/Jakarta' => 'Արևմտյան Ինդոնեզիայի ժամանակ (Ջակարտա)',
        'Asia/Jayapura' => 'Արևելյան Ինդոնեզիայի ժամանակ (Ջայպուրա)',
        'Asia/Jerusalem' => 'Իսրայելի ժամանակ (Երուսաղեմ)',
        'Asia/Kabul' => 'Աֆղանստանի ժամանակ (Քաբուլ)',
        'Asia/Kamchatka' => 'Ռուսաստան (Կամչատկա)',
        'Asia/Karachi' => 'Պակիստանի ժամանակ (Կարաչի)',
        'Asia/Katmandu' => 'Նեպալի ժամանակ (Կատմանդու)',
        'Asia/Khandyga' => 'Յակուտսկի ժամանակ (Խանդիգա)',
        'Asia/Krasnoyarsk' => 'Կրասնոյարսկի ժամանակ',
        'Asia/Kuala_Lumpur' => 'Մալայզիայի ժամանակ (Կուալա Լումպուր)',
        'Asia/Kuching' => 'Մալայզիայի ժամանակ (Կուչինգ)',
        'Asia/Kuwait' => 'Սաուդյան Արաբիայի ժամանակ (Քուվեյթ)',
        'Asia/Macau' => 'Չինաստանի ժամանակ (Մակաո)',
        'Asia/Magadan' => 'Մագադանի ժամանակ',
        'Asia/Makassar' => 'Կենտրոնական Ինդոնեզիայի ժամանակ (Մակասար)',
        'Asia/Manila' => 'Ֆիլիպինների ժամանակ (Մանիլա)',
        'Asia/Muscat' => 'Պարսից ծոցի ստանդարտ ժամանակ (Մասկատ)',
        'Asia/Nicosia' => 'Արևելյան Եվրոպայի ժամանակ (Նիկոսիա)',
        'Asia/Novokuznetsk' => 'Կրասնոյարսկի ժամանակ (Նովոկուզնեցկ)',
        'Asia/Novosibirsk' => 'Նովոսիբիրսկի ժամանակ',
        'Asia/Omsk' => 'Օմսկի ժամանակ',
        'Asia/Oral' => 'Արևմտյան Ղազախստանի ժամանակ (Ուրալսկ)',
        'Asia/Phnom_Penh' => 'Հնդկաչինական ժամանակ (Պնոմպեն)',
        'Asia/Pontianak' => 'Արևմտյան Ինդոնեզիայի ժամանակ (Պոնտիանակ)',
        'Asia/Pyongyang' => 'Կորեայի ժամանակ (Փխենյան)',
        'Asia/Qatar' => 'Սաուդյան Արաբիայի ժամանակ (Կատար)',
        'Asia/Qostanay' => 'Արևելյան Ղազախստանի ժամանակ (Կոստանայ)',
        'Asia/Qyzylorda' => 'Արևմտյան Ղազախստանի ժամանակ (Կիզիլորդա)',
        'Asia/Rangoon' => 'Մյանմայի ժամանակ (Ռանգուն)',
        'Asia/Riyadh' => 'Սաուդյան Արաբիայի ժամանակ (Էր Ռիադ)',
        'Asia/Saigon' => 'Հնդկաչինական ժամանակ (Հոշիմին)',
        'Asia/Sakhalin' => 'Սախալինի ժամանակ',
        'Asia/Samarkand' => 'Ուզբեկստանի ժամանակ (Սամարղանդ)',
        'Asia/Seoul' => 'Կորեայի ժամանակ (Սեուլ)',
        'Asia/Shanghai' => 'Չինաստանի ժամանակ (Շանհայ)',
        'Asia/Singapore' => 'Սինգապուրի ժամանակ',
        'Asia/Srednekolymsk' => 'Մագադանի ժամանակ (Սրեդնեկոլիմսկ)',
        'Asia/Taipei' => 'Թայպեյի ժամանակ',
        'Asia/Tashkent' => 'Ուզբեկստանի ժամանակ (Տաշքենդ)',
        'Asia/Tbilisi' => 'Վրաստանի ժամանակ (Թբիլիսի)',
        'Asia/Tehran' => 'Իրանի ժամանակ (Թեհրան)',
        'Asia/Thimphu' => 'Բութանի ժամանակ (Տհիմպհու)',
        'Asia/Tokyo' => 'Ճապոնիայի ժամանակ (Տոկիո)',
        'Asia/Tomsk' => 'Ռուսաստան (Տոմսկ)',
        'Asia/Ulaanbaatar' => 'Ուլան Բատորի ժամանակ',
        'Asia/Urumqi' => 'Չինաստան (Ուրումչի)',
        'Asia/Ust-Nera' => 'Վլադիվոստոկի ժամանակ (Ուստ-Ներա)',
        'Asia/Vientiane' => 'Հնդկաչինական ժամանակ (Վյենտյան)',
        'Asia/Vladivostok' => 'Վլադիվոստոկի ժամանակ',
        'Asia/Yakutsk' => 'Յակուտսկի ժամանակ',
        'Asia/Yekaterinburg' => 'Եկատերինբուրգի ժամանակ',
        'Asia/Yerevan' => 'Հայաստանի ժամանակ (Երևան)',
        'Atlantic/Azores' => 'Ազորյան կղզիների ժամանակ',
        'Atlantic/Bermuda' => 'Ատլանտյան ժամանակ (Բերմուդներ)',
        'Atlantic/Canary' => 'Արևմտյան Եվրոպայի ժամանակ (Կանարյան կղզիներ)',
        'Atlantic/Cape_Verde' => 'Կաբո Վերդեի ժամանակ',
        'Atlantic/Faeroe' => 'Արևմտյան Եվրոպայի ժամանակ (Ֆարերյան կղզիներ)',
        'Atlantic/Madeira' => 'Արևմտյան Եվրոպայի ժամանակ (Մադեյրա)',
        'Atlantic/Reykjavik' => 'Գրինվիչի ժամանակ (Ռեյկյավիկ)',
        'Atlantic/South_Georgia' => 'Հարավային Ջորջիայի ժամանակ',
        'Atlantic/St_Helena' => 'Գրինվիչի ժամանակ (Սուրբ Հեղինեի կղզի)',
        'Atlantic/Stanley' => 'Ֆոլքլենդյան կղզիների ժամանակ (Սթենլի)',
        'Australia/Adelaide' => 'Կենտրոնական Ավստրալիայի ժամանակ (Ադելաիդա)',
        'Australia/Brisbane' => 'Արևելյան Ավստրալիայի ժամանակ (Բրիսբեն)',
        'Australia/Broken_Hill' => 'Կենտրոնական Ավստրալիայի ժամանակ (Բրոքեն Հիլ)',
        'Australia/Currie' => 'Արևելյան Ավստրալիայի ժամանակ (Քերի)',
        'Australia/Darwin' => 'Կենտրոնական Ավստրալիայի ժամանակ (Դարվին)',
        'Australia/Eucla' => 'Կենտրոնական Ավստրալիայի արևմտյան ժամանակ (Յուկլա)',
        'Australia/Hobart' => 'Արևելյան Ավստրալիայի ժամանակ (Հոբարտ)',
        'Australia/Lindeman' => 'Արևելյան Ավստրալիայի ժամանակ (Լինդեման)',
        'Australia/Lord_Howe' => 'Լորդ Հաուի ժամանակ (Լորդ Հաու կղզի)',
        'Australia/Melbourne' => 'Արևելյան Ավստրալիայի ժամանակ (Մելբուրն)',
        'Australia/Perth' => 'Արևմտյան Ավստրալիայի ժամանակ (Պերթ)',
        'Australia/Sydney' => 'Արևելյան Ավստրալիայի ժամանակ (Սիդնեյ)',
        'CST6CDT' => 'Կենտրոնական Ամերիկայի ժամանակ',
        'EST5EDT' => 'Արևելյան Ամերիկայի ժամանակ',
        'Etc/GMT' => 'Գրինվիչի ժամանակ',
        'Etc/UTC' => 'Համաշխարհային կոորդինացված ժամանակ',
        'Europe/Amsterdam' => 'Կենտրոնական Եվրոպայի ժամանակ (Ամստերդամ)',
        'Europe/Andorra' => 'Կենտրոնական Եվրոպայի ժամանակ (Անդորրա)',
        'Europe/Astrakhan' => 'Մոսկվայի ժամանակ (Աստրախան)',
        'Europe/Athens' => 'Արևելյան Եվրոպայի ժամանակ (Աթենք)',
        'Europe/Belgrade' => 'Կենտրոնական Եվրոպայի ժամանակ (Բելգրադ)',
        'Europe/Berlin' => 'Կենտրոնական Եվրոպայի ժամանակ (Բեռլին)',
        'Europe/Bratislava' => 'Կենտրոնական Եվրոպայի ժամանակ (Բրատիսլավա)',
        'Europe/Brussels' => 'Կենտրոնական Եվրոպայի ժամանակ (Բրյուսել)',
        'Europe/Bucharest' => 'Արևելյան Եվրոպայի ժամանակ (Բուխարեստ)',
        'Europe/Budapest' => 'Կենտրոնական Եվրոպայի ժամանակ (Բուդապեշտ)',
        'Europe/Busingen' => 'Կենտրոնական Եվրոպայի ժամանակ (Բյուզինգեն)',
        'Europe/Chisinau' => 'Արևելյան Եվրոպայի ժամանակ (Քիշնև)',
        'Europe/Copenhagen' => 'Կենտրոնական Եվրոպայի ժամանակ (Կոպենհագեն)',
        'Europe/Dublin' => 'Գրինվիչի ժամանակ (Դուբլին)',
        'Europe/Gibraltar' => 'Կենտրոնական Եվրոպայի ժամանակ (Ջիբրալթար)',
        'Europe/Guernsey' => 'Գրինվիչի ժամանակ (Գերնսի)',
        'Europe/Helsinki' => 'Արևելյան Եվրոպայի ժամանակ (Հելսինկի)',
        'Europe/Isle_of_Man' => 'Գրինվիչի ժամանակ (Մեն կղզի)',
        'Europe/Istanbul' => 'Թուրքիա (Ստամբուլ)',
        'Europe/Jersey' => 'Գրինվիչի ժամանակ (Ջերսի)',
        'Europe/Kaliningrad' => 'Արևելյան Եվրոպայի ժամանակ (Կալինինգրադ)',
        'Europe/Kiev' => 'Արևելյան Եվրոպայի ժամանակ (Կիև)',
        'Europe/Kirov' => 'Ռուսաստան (Կիրով)',
        'Europe/Lisbon' => 'Արևմտյան Եվրոպայի ժամանակ (Լիսաբոն)',
        'Europe/Ljubljana' => 'Կենտրոնական Եվրոպայի ժամանակ (Լյուբլյանա)',
        'Europe/London' => 'Գրինվիչի ժամանակ (Լոնդոն)',
        'Europe/Luxembourg' => 'Կենտրոնական Եվրոպայի ժամանակ (Լյուքսեմբուրգ)',
        'Europe/Madrid' => 'Կենտրոնական Եվրոպայի ժամանակ (Մադրիդ)',
        'Europe/Malta' => 'Կենտրոնական Եվրոպայի ժամանակ (Մալթա)',
        'Europe/Mariehamn' => 'Արևելյան Եվրոպայի ժամանակ (Մարիեհամն)',
        'Europe/Minsk' => 'Մոսկվայի ժամանակ (Մինսկ)',
        'Europe/Monaco' => 'Կենտրոնական Եվրոպայի ժամանակ (Մոնակո)',
        'Europe/Moscow' => 'Մոսկվայի ժամանակ',
        'Europe/Oslo' => 'Կենտրոնական Եվրոպայի ժամանակ (Օսլո)',
        'Europe/Paris' => 'Կենտրոնական Եվրոպայի ժամանակ (Փարիզ)',
        'Europe/Podgorica' => 'Կենտրոնական Եվրոպայի ժամանակ (Պոդգորիցա)',
        'Europe/Prague' => 'Կենտրոնական Եվրոպայի ժամանակ (Պրահա)',
        'Europe/Riga' => 'Արևելյան Եվրոպայի ժամանակ (Ռիգա)',
        'Europe/Rome' => 'Կենտրոնական Եվրոպայի ժամանակ (Հռոմ)',
        'Europe/Samara' => 'Ռուսաստան (Սամարա)',
        'Europe/San_Marino' => 'Կենտրոնական Եվրոպայի ժամանակ (Սան Մարինո)',
        'Europe/Sarajevo' => 'Կենտրոնական Եվրոպայի ժամանակ (Սարաևո)',
        'Europe/Saratov' => 'Մոսկվայի ժամանակ (Սարատով)',
        'Europe/Simferopol' => 'Մոսկվայի ժամանակ (Սիմֆերոպոլ)',
        'Europe/Skopje' => 'Կենտրոնական Եվրոպայի ժամանակ (Սկոպյե)',
        'Europe/Sofia' => 'Արևելյան Եվրոպայի ժամանակ (Սոֆիա)',
        'Europe/Stockholm' => 'Կենտրոնական Եվրոպայի ժամանակ (Ստոկհոլմ)',
        'Europe/Tallinn' => 'Արևելյան Եվրոպայի ժամանակ (Տալլին)',
        'Europe/Tirane' => 'Կենտրոնական Եվրոպայի ժամանակ (Տիրանա)',
        'Europe/Ulyanovsk' => 'Մոսկվայի ժամանակ (Ուլյանովսկ)',
        'Europe/Uzhgorod' => 'Արևելյան Եվրոպայի ժամանակ (Ուժգորոդ)',
        'Europe/Vaduz' => 'Կենտրոնական Եվրոպայի ժամանակ (Վադուց)',
        'Europe/Vatican' => 'Կենտրոնական Եվրոպայի ժամանակ (Վատիկան)',
        'Europe/Vienna' => 'Կենտրոնական Եվրոպայի ժամանակ (Վիեննա)',
        'Europe/Vilnius' => 'Արևելյան Եվրոպայի ժամանակ (Վիլնյուս)',
        'Europe/Volgograd' => 'Վոլգոգրադի ժամանակ',
        'Europe/Warsaw' => 'Կենտրոնական Եվրոպայի ժամանակ (Վարշավա)',
        'Europe/Zagreb' => 'Կենտրոնական Եվրոպայի ժամանակ (Զագրեբ)',
        'Europe/Zaporozhye' => 'Արևելյան Եվրոպայի ժամանակ (Զապոռոժյե)',
        'Europe/Zurich' => 'Կենտրոնական Եվրոպայի ժամանակ (Ցյուրիխ)',
        'Indian/Antananarivo' => 'Արևելյան Աֆրիկայի ժամանակ (Անտանանարիվու)',
        'Indian/Chagos' => 'Հնդկական օվկիանոսի ժամանակ (Չագոս)',
        'Indian/Christmas' => 'Սուրբ Ծննդյան կղզու ժամանակ (Սուրբ Ծննդյան կղզի)',
        'Indian/Cocos' => 'Կոկոսյան կղզիների ժամանակ',
        'Indian/Comoro' => 'Արևելյան Աֆրիկայի ժամանակ (Կոմորյան կղզիներ)',
        'Indian/Kerguelen' => 'Ֆրանսիական հարավային և անտարկտիդյան ժամանակ (Կերգելեն)',
        'Indian/Mahe' => 'Սեյշելյան կղզիների ժամանակ (Մաէ)',
        'Indian/Maldives' => 'Մալդիվների ժամանակ',
        'Indian/Mauritius' => 'Մավրիկիոսի ժամանակ',
        'Indian/Mayotte' => 'Արևելյան Աֆրիկայի ժամանակ (Մայոթ)',
        'Indian/Reunion' => 'Ռեյունիոնի ժամանակ',
        'MST7MDT' => 'Լեռնային ժամանակ (ԱՄՆ)',
        'PST8PDT' => 'Խաղաղօվկիանոսյան ժամանակ',
        'Pacific/Apia' => 'Ապիայի ժամանակ',
        'Pacific/Auckland' => 'Նոր Զելանդիայի ժամանակ (Օքլենդ)',
        'Pacific/Bougainville' => 'Պապուա Նոր Գվինեայի ժամանակ (Բուգենվիլ)',
        'Pacific/Chatham' => 'Չաթեմ կղզու ժամանակ (Չաթեմ կղզի)',
        'Pacific/Easter' => 'Զատկի կղզու ժամանակ (Զատկի կղզի)',
        'Pacific/Efate' => 'Վանուատույի ժամանակ (Էֆատե)',
        'Pacific/Enderbury' => 'Ֆինիքս կղզիների ժամանակ (Էնդերբերի կղզի)',
        'Pacific/Fakaofo' => 'Տոկելաույի ժամանակ (Ֆակաոֆո)',
        'Pacific/Fiji' => 'Ֆիջիի ժամանակ',
        'Pacific/Funafuti' => 'Տուվալույի ժամանակ (Ֆունաֆուտի)',
        'Pacific/Galapagos' => 'Գալապագոսյան կղզիների ժամանակ',
        'Pacific/Gambier' => 'Գամբյե կղզիների ժամանակ',
        'Pacific/Guadalcanal' => 'Սողոմոնի կղզիների ժամանակ (Գուադալկանալ)',
        'Pacific/Guam' => 'Չամոռոյի ժամանակ (Գուամ)',
        'Pacific/Honolulu' => 'Հավայան-ալեության ժամանակ (Հոնոլուլու)',
        'Pacific/Johnston' => 'Հավայան-ալեության ժամանակ (Ջոնսթոն)',
        'Pacific/Kiritimati' => 'Լայն կղզիների ժամանակ (Կիրիտիմատի)',
        'Pacific/Kosrae' => 'Կոսրաեյի ժամանակ',
        'Pacific/Kwajalein' => 'Մարշալյան կղզիների ժամանակ (Քվաջալեյն)',
        'Pacific/Majuro' => 'Մարշալյան կղզիների ժամանակ (Մաջուրո)',
        'Pacific/Marquesas' => 'Մարկիզյան կղզիների ժամանակ',
        'Pacific/Midway' => 'Սամոայի ժամանակ (Միդուեյ կղզի)',
        'Pacific/Nauru' => 'Նաուրուի ժամանակ',
        'Pacific/Niue' => 'Նիուեյի ժամանակ',
        'Pacific/Norfolk' => 'Նորֆոլկ կղզու ժամանակ',
        'Pacific/Noumea' => 'Նոր Կալեդոնիայի ժամանակ (Նումեա)',
        'Pacific/Pago_Pago' => 'Սամոայի ժամանակ (Պագո Պագո)',
        'Pacific/Palau' => 'Պալաույի ժամանակ',
        'Pacific/Pitcairn' => 'Պիտկեռնի ժամանակ',
        'Pacific/Ponape' => 'Պոնապե կղզու ժամանակ (Պոնպեի)',
        'Pacific/Port_Moresby' => 'Պապուա Նոր Գվինեայի ժամանակ (Պորտ Մորսբի)',
        'Pacific/Rarotonga' => 'Կուկի կղզիների ժամանակ (Ռարոտոնգա)',
        'Pacific/Saipan' => 'Չամոռոյի ժամանակ (Սայպան)',
        'Pacific/Tahiti' => 'Թաիթիի ժամանակ',
        'Pacific/Tarawa' => 'Ջիլբերթի կղզիների ժամանակ (Տարավա)',
        'Pacific/Tongatapu' => 'Տոնգայի ժամանակ (Տոնգատապու)',
        'Pacific/Truk' => 'Տրուկի ժամանակ (Չուուկ)',
        'Pacific/Wake' => 'Ուեյք կղզու ժամանակ (Ուեյք կղզի)',
        'Pacific/Wallis' => 'Ուոլիս և Ֆուտունայի ժամանակ',
    ],
    'Meta' => [
    ],
];
