<?php

return [
    'Names' => [
        'AX' => 'Aland Islands',
        'BL' => 'St. Barthelemy',
        'CI' => 'Cote d’Ivoire',
        'CW' => 'Curacao',
        'KN' => 'St. Kitts & Nevis',
        'LC' => 'St. Lucia',
        'MF' => 'St. Martin',
        'PM' => 'St. Pierre & Miquelon',
        'RE' => 'Reunion',
        'SH' => 'St. Helena',
        'ST' => 'Sao Tome & Principe',
        'UM' => 'U.S. Outlying Islands',
        'VC' => 'St. Vincent & Grenadines',
        'VI' => 'U.S. Virgin Islands',
    ],
];
