<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirham de Emiratos Árabes Unidos',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afgani Afgano',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lek albanés',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dram Armenio',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Florín Antillano Neerlandés',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza Angoleño',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Peso Argentino',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dólar Australiano',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Florín Arubeño',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manat Azerbaiyano',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Marco Bosnioherzegovino',
        ],
        'BBD' => [
            0 => 'BBG',
            1 => 'Dólar de Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka Bangladesí',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinar Bareiní',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Franco Burundés',
        ],
        'BMD' => [
            0 => 'DBM',
            1 => 'Dólar Bermudeño',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dólar de Brunéi',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviano',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Real Brasileño',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dólar Bahameño',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrum Butanés',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula Botswano',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Nuevo Rublo Bielorruso',
        ],
        'BZD' => [
            0 => 'DBZ',
            1 => 'Dólar Beliceño',
        ],
        'CAD' => [
            0 => '$CA',
            1 => 'Dólar Canadiense',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Franco Congoleño',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Franco Suizo',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Peso Chileno',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuan Chino (offshore)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan Chino',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Peso Colombiano',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Colón Costarricense',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Peso Cubano Convertible',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Peso Cubano',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo Caboverdiano',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Corona Checa',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Franco Yibutiano',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Corona Danesa',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Peso Dominicano',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinar Argelino',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Libra Egipcia',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa Eritreano',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birr Etíope',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dólar Fiyiano',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Libra Malvinense',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Libra Esterlina',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lari Georgiano',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Cedi Ganés',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Libra Gibraltareña',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Franco Guineano',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Quetzal Guatemalteco',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dólar Guyanés',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dólar de Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira Hondureño',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna Croata',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gourde Haitiano',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Florín Húngaro',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupia Indonesia',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Nuevo Séquel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupia India',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinar Iraquí',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Rial Iraní',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Corona Islandesa',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dólar Jamaiquino',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinar Jordano',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yen Japonés',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Chelín Keniano',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Som Kirguís',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riel Camboyano',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Franco Comorense',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Won Norcoreano',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Won Surcoreano',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinar Kuwaití',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dólar de las Islas Caimán',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge Kazajo',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kip Laosiano',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libra Libanesa',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rupia de Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dólar Liberiano',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesoto Loti Qullqi',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinar Libio',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dírham Marroquí',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leu Moldavo',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariary Malgache',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Dinar Macedonio',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kyat Birmano',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrik Mongol',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataca Macaense',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Uguiya Mauritano',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupia de Mauricio',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rupia de Maldivas',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha Malauí',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Peso Mexicano',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringgit Malayo',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metical Mozambiqueño',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dólar Namibio',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira Nigeriano',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Córdova Nicaragüense',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Corona Noruega',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupia Nepalí',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dólar Neozelandés',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Rial Omaní',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa Panameño',
        ],
        'PEN' => [
            0 => 'S/',
            1 => 'Sol Peruano',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina Papuano',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Peso Filipino',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupia Pakistaní',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guaraní Paraguayo',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Riyal Catarí',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Leu Rumano',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinar Serbio',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rublo Ruso',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Franco Ruandés',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal Saudí',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dólar de las Islas Salomón',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupia de Seychelles',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Libra Sudanesa',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Corona Sueca',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dólar de Singapur',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Libra de Santa Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone de Sierra Leona',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Chelín Somalí',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dólar Surinamés',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Libra Sursudanesa',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra Santotomense',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Libra Siria',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni Swazi',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Baht Tailandés',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni Tayiko',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manat Turcomano',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinar Tunecino',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Paʻanga Tongano',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lira Turca',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dólar de Trinidad y Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Nuevo Dólar Taiwanés',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Chelín Tanzano',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Grivna',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Chelín Ugandés',
        ],
        'USD' => [
            0 => '$US',
            1 => 'Dólar Americano',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso Uruguayo',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Som Ubzeko',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolívar Venezolano',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dong Vietnamita',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatu Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala Samoano',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Franco CFA de África Central',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dólar del Caribe Oriental',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Franco CFA de África Occidental',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Franco CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Rial Yemení',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rand Sudafricano',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha Zambiano',
        ],
    ],
];
