<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'czas uniwersalny (Abidżan)',
        'Africa/Accra' => 'czas uniwersalny (Akra)',
        'Africa/Addis_Ababa' => 'czas wschodnioafrykański (Addis Abeba)',
        'Africa/Algiers' => 'czas środkowoeuropejski (Algier)',
        'Africa/Asmera' => 'czas wschodnioafrykański (Asmara)',
        'Africa/Bamako' => 'czas uniwersalny (Bamako)',
        'Africa/Bangui' => 'czas zachodnioafrykański (Bangi)',
        'Africa/Banjul' => 'czas uniwersalny (Bandżul)',
        'Africa/Bissau' => 'czas uniwersalny (Bissau)',
        'Africa/Blantyre' => 'czas środkowoafrykański (Blantyre)',
        'Africa/Brazzaville' => 'czas zachodnioafrykański (Brazzaville)',
        'Africa/Bujumbura' => 'czas środkowoafrykański (Bużumbura)',
        'Africa/Cairo' => 'czas wschodnioeuropejski (Kair)',
        'Africa/Casablanca' => 'czas zachodnioeuropejski (Casablanca)',
        'Africa/Ceuta' => 'czas środkowoeuropejski (Ceuta)',
        'Africa/Conakry' => 'czas uniwersalny (Konakry)',
        'Africa/Dakar' => 'czas uniwersalny (Dakar)',
        'Africa/Dar_es_Salaam' => 'czas wschodnioafrykański (Dar es Salaam)',
        'Africa/Djibouti' => 'czas wschodnioafrykański (Dżibuti)',
        'Africa/Douala' => 'czas zachodnioafrykański (Duala)',
        'Africa/El_Aaiun' => 'czas zachodnioeuropejski (Al-Ujun)',
        'Africa/Freetown' => 'czas uniwersalny (Freetown)',
        'Africa/Gaborone' => 'czas środkowoafrykański (Gaborone)',
        'Africa/Harare' => 'czas środkowoafrykański (Harare)',
        'Africa/Johannesburg' => 'czas południowoafrykański (Johannesburg)',
        'Africa/Juba' => 'czas środkowoafrykański (Dżuba)',
        'Africa/Kampala' => 'czas wschodnioafrykański (Kampala)',
        'Africa/Khartoum' => 'czas środkowoafrykański (Chartum)',
        'Africa/Kigali' => 'czas środkowoafrykański (Kigali)',
        'Africa/Kinshasa' => 'czas zachodnioafrykański (Kinszasa)',
        'Africa/Lagos' => 'czas zachodnioafrykański (Lagos)',
        'Africa/Libreville' => 'czas zachodnioafrykański (Libreville)',
        'Africa/Lome' => 'czas uniwersalny (Lomé)',
        'Africa/Luanda' => 'czas zachodnioafrykański (Luanda)',
        'Africa/Lubumbashi' => 'czas środkowoafrykański (Lubumbashi)',
        'Africa/Lusaka' => 'czas środkowoafrykański (Lusaka)',
        'Africa/Malabo' => 'czas zachodnioafrykański (Malabo)',
        'Africa/Maputo' => 'czas środkowoafrykański (Maputo)',
        'Africa/Maseru' => 'czas południowoafrykański (Maseru)',
        'Africa/Mbabane' => 'czas południowoafrykański (Mbabane)',
        'Africa/Mogadishu' => 'czas wschodnioafrykański (Mogadiszu)',
        'Africa/Monrovia' => 'czas uniwersalny (Monrovia)',
        'Africa/Nairobi' => 'czas wschodnioafrykański (Nairobi)',
        'Africa/Ndjamena' => 'czas zachodnioafrykański (Ndżamena)',
        'Africa/Niamey' => 'czas zachodnioafrykański (Niamey)',
        'Africa/Nouakchott' => 'czas uniwersalny (Nawakszut)',
        'Africa/Ouagadougou' => 'czas uniwersalny (Wagadugu)',
        'Africa/Porto-Novo' => 'czas zachodnioafrykański (Porto Novo)',
        'Africa/Sao_Tome' => 'czas uniwersalny (São Tomé)',
        'Africa/Tripoli' => 'czas wschodnioeuropejski (Trypolis)',
        'Africa/Tunis' => 'czas środkowoeuropejski (Tunis)',
        'Africa/Windhoek' => 'czas środkowoafrykański (Windhuk)',
        'America/Adak' => 'czas Hawaje-Aleuty (Adak)',
        'America/Anchorage' => 'czas Alaska (Anchorage)',
        'America/Anguilla' => 'czas atlantycki (Anguilla)',
        'America/Antigua' => 'czas atlantycki (Antigua)',
        'America/Araguaina' => 'czas Brasília (Araguaina)',
        'America/Argentina/La_Rioja' => 'czas Argentyna (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'czas Argentyna (Rio Gallegos)',
        'America/Argentina/Salta' => 'czas Argentyna (Salta)',
        'America/Argentina/San_Juan' => 'czas Argentyna (San Juan)',
        'America/Argentina/San_Luis' => 'czas Argentyna (San Luis)',
        'America/Argentina/Tucuman' => 'czas Argentyna (Tucuman)',
        'America/Argentina/Ushuaia' => 'czas Argentyna (Ushuaia)',
        'America/Aruba' => 'czas atlantycki (Aruba)',
        'America/Asuncion' => 'czas Paragwaj (Asunción)',
        'America/Bahia' => 'czas Brasília (Salvador)',
        'America/Bahia_Banderas' => 'czas środkowoamerykański (Bahia Banderas)',
        'America/Barbados' => 'czas atlantycki (Barbados)',
        'America/Belem' => 'czas Brasília (Belém)',
        'America/Belize' => 'czas środkowoamerykański (Belize)',
        'America/Blanc-Sablon' => 'czas atlantycki (Blanc-Sablon)',
        'America/Boa_Vista' => 'czas amazoński (Boa Vista)',
        'America/Bogota' => 'czas Kolumbia (Bogota)',
        'America/Boise' => 'czas górski (Boise)',
        'America/Buenos_Aires' => 'czas Argentyna (Buenos Aires)',
        'America/Cambridge_Bay' => 'czas górski (Cambridge Bay)',
        'America/Campo_Grande' => 'czas amazoński (Campo Grande)',
        'America/Cancun' => 'czas wschodnioamerykański (Cancún)',
        'America/Caracas' => 'czas Wenezuela (Caracas)',
        'America/Catamarca' => 'czas Argentyna (Catamarca)',
        'America/Cayenne' => 'czas Gujana Francuska (Kajenna)',
        'America/Cayman' => 'czas wschodnioamerykański (Kajmany)',
        'America/Chicago' => 'czas środkowoamerykański (Chicago)',
        'America/Chihuahua' => 'Meksyk (czas pacyficzny) (Chihuahua)',
        'America/Coral_Harbour' => 'czas wschodnioamerykański (Atikokan)',
        'America/Cordoba' => 'czas Argentyna (Córdoba)',
        'America/Costa_Rica' => 'czas środkowoamerykański (Kostaryka)',
        'America/Creston' => 'czas górski (Creston)',
        'America/Cuiaba' => 'czas amazoński (Cuiabá)',
        'America/Curacao' => 'czas atlantycki (Curaçao)',
        'America/Danmarkshavn' => 'czas uniwersalny (Danmarkshavn)',
        'America/Dawson' => 'czas Jukon (Dawson)',
        'America/Dawson_Creek' => 'czas górski (Dawson Creek)',
        'America/Denver' => 'czas górski (Denver)',
        'America/Detroit' => 'czas wschodnioamerykański (Detroit)',
        'America/Dominica' => 'czas atlantycki (Dominika)',
        'America/Edmonton' => 'czas górski (Edmonton)',
        'America/Eirunepe' => 'czas: Brazylia (Eirunepe)',
        'America/El_Salvador' => 'czas środkowoamerykański (Salwador)',
        'America/Fort_Nelson' => 'czas górski (Fort Nelson)',
        'America/Fortaleza' => 'czas Brasília (Fortaleza)',
        'America/Glace_Bay' => 'czas atlantycki (Glace Bay)',
        'America/Godthab' => 'czas Grenlandia Zachodnia (Nuuk)',
        'America/Goose_Bay' => 'czas atlantycki (Goose Bay)',
        'America/Grand_Turk' => 'czas wschodnioamerykański (Grand Turk)',
        'America/Grenada' => 'czas atlantycki (Grenada)',
        'America/Guadeloupe' => 'czas atlantycki (Gwadelupa)',
        'America/Guatemala' => 'czas środkowoamerykański (Gwatemala)',
        'America/Guayaquil' => 'czas Ekwador (Guayaquil)',
        'America/Guyana' => 'czas Gujana',
        'America/Halifax' => 'czas atlantycki (Halifax)',
        'America/Havana' => 'czas Kuba (Hawana)',
        'America/Hermosillo' => 'Meksyk (czas pacyficzny) (Hermosillo)',
        'America/Indiana/Knox' => 'czas środkowoamerykański (Knox, Indiana)',
        'America/Indiana/Marengo' => 'czas wschodnioamerykański (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'czas wschodnioamerykański (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'czas środkowoamerykański (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'czas wschodnioamerykański (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'czas wschodnioamerykański (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'czas wschodnioamerykański (Winamac, Indiana)',
        'America/Indianapolis' => 'czas wschodnioamerykański (Indianapolis)',
        'America/Inuvik' => 'czas górski (Inuvik)',
        'America/Iqaluit' => 'czas wschodnioamerykański (Iqaluit)',
        'America/Jamaica' => 'czas wschodnioamerykański (Jamajka)',
        'America/Jujuy' => 'czas Argentyna (Jujuy)',
        'America/Juneau' => 'czas Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'czas wschodnioamerykański (Monticello)',
        'America/Kralendijk' => 'czas atlantycki (Kralendijk)',
        'America/La_Paz' => 'czas Boliwia (La Paz)',
        'America/Lima' => 'czas Peru (Lima)',
        'America/Los_Angeles' => 'czas pacyficzny (Los Angeles)',
        'America/Louisville' => 'czas wschodnioamerykański (Louisville)',
        'America/Lower_Princes' => 'czas atlantycki (Lower Prince’s Quarter)',
        'America/Maceio' => 'czas Brasília (Maceió)',
        'America/Managua' => 'czas środkowoamerykański (Managua)',
        'America/Manaus' => 'czas amazoński (Manaus)',
        'America/Marigot' => 'czas atlantycki (Marigot)',
        'America/Martinique' => 'czas atlantycki (Martynika)',
        'America/Matamoros' => 'czas środkowoamerykański (Matamoros)',
        'America/Mazatlan' => 'Meksyk (czas pacyficzny) (Mazatlan)',
        'America/Mendoza' => 'czas Argentyna (Mendoza)',
        'America/Menominee' => 'czas środkowoamerykański (Menominee)',
        'America/Merida' => 'czas środkowoamerykański (Merida)',
        'America/Metlakatla' => 'czas Alaska (Metlakatla)',
        'America/Mexico_City' => 'czas środkowoamerykański (Meksyk (miasto))',
        'America/Miquelon' => 'czas Saint-Pierre i Miquelon',
        'America/Moncton' => 'czas atlantycki (Moncton)',
        'America/Monterrey' => 'czas środkowoamerykański (Monterrey)',
        'America/Montevideo' => 'czas Urugwaj (Montevideo)',
        'America/Montreal' => 'czas: Kanada (Montreal)',
        'America/Montserrat' => 'czas atlantycki (Montserrat)',
        'America/Nassau' => 'czas wschodnioamerykański (Nassau)',
        'America/New_York' => 'czas wschodnioamerykański (Nowy Jork)',
        'America/Nipigon' => 'czas wschodnioamerykański (Nipigon)',
        'America/Nome' => 'czas Alaska (Nome)',
        'America/Noronha' => 'czas Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'czas środkowoamerykański (Beulah, Dakota Północna)',
        'America/North_Dakota/Center' => 'czas środkowoamerykański (Center, Dakota Północna)',
        'America/North_Dakota/New_Salem' => 'czas środkowoamerykański (New Salem, Dakota Północna)',
        'America/Ojinaga' => 'czas górski (Ojinaga)',
        'America/Panama' => 'czas wschodnioamerykański (Panama)',
        'America/Pangnirtung' => 'czas wschodnioamerykański (Pangnirtung)',
        'America/Paramaribo' => 'czas Surinam (Paramaribo)',
        'America/Phoenix' => 'czas górski (Phoenix)',
        'America/Port-au-Prince' => 'czas wschodnioamerykański (Port-au-Prince)',
        'America/Port_of_Spain' => 'czas atlantycki (Port-of-Spain)',
        'America/Porto_Velho' => 'czas amazoński (Porto Velho)',
        'America/Puerto_Rico' => 'czas atlantycki (Portoryko)',
        'America/Punta_Arenas' => 'czas Chile (Punta Arenas)',
        'America/Rainy_River' => 'czas środkowoamerykański (Rainy River)',
        'America/Rankin_Inlet' => 'czas środkowoamerykański (Rankin Inlet)',
        'America/Recife' => 'czas Brasília (Recife)',
        'America/Regina' => 'czas środkowoamerykański (Regina)',
        'America/Resolute' => 'czas środkowoamerykański (Resolute)',
        'America/Rio_Branco' => 'czas: Brazylia (Rio Branco)',
        'America/Santa_Isabel' => 'czas Meksyk Północno-Zachodni (Santa Isabel)',
        'America/Santarem' => 'czas Brasília (Santarem)',
        'America/Santiago' => 'czas Chile (Santiago)',
        'America/Santo_Domingo' => 'czas atlantycki (Santo Domingo)',
        'America/Sao_Paulo' => 'czas Brasília (Sao Paulo)',
        'America/Scoresbysund' => 'czas Grenlandia Wschodnia (Ittoqqortoormiit)',
        'America/Sitka' => 'czas Alaska (Sitka)',
        'America/St_Barthelemy' => 'czas atlantycki (Saint-Barthélemy)',
        'America/St_Johns' => 'czas Nowa Fundlandia (St. John’s)',
        'America/St_Kitts' => 'czas atlantycki (Saint Kitts)',
        'America/St_Lucia' => 'czas atlantycki (Saint Lucia)',
        'America/St_Thomas' => 'czas atlantycki (Saint Thomas)',
        'America/St_Vincent' => 'czas atlantycki (Saint Vincent)',
        'America/Swift_Current' => 'czas środkowoamerykański (Swift Current)',
        'America/Tegucigalpa' => 'czas środkowoamerykański (Tegucigalpa)',
        'America/Thule' => 'czas atlantycki (Qaanaaq)',
        'America/Thunder_Bay' => 'czas wschodnioamerykański (Thunder Bay)',
        'America/Tijuana' => 'czas pacyficzny (Tijuana)',
        'America/Toronto' => 'czas wschodnioamerykański (Toronto)',
        'America/Tortola' => 'czas atlantycki (Tortola)',
        'America/Vancouver' => 'czas pacyficzny (Vancouver)',
        'America/Whitehorse' => 'czas Jukon (Whitehorse)',
        'America/Winnipeg' => 'czas środkowoamerykański (Winnipeg)',
        'America/Yakutat' => 'czas Alaska (Yakutat)',
        'America/Yellowknife' => 'czas górski (Yellowknife)',
        'Antarctica/Casey' => 'czas: Antarktyda (Casey)',
        'Antarctica/Davis' => 'czas Davis',
        'Antarctica/DumontDUrville' => 'czas Dumont-d’Urville',
        'Antarctica/Macquarie' => 'czas wschodnioaustralijski (Macquarie)',
        'Antarctica/Mawson' => 'czas Mawson',
        'Antarctica/McMurdo' => 'czas Nowa Zelandia (McMurdo)',
        'Antarctica/Palmer' => 'czas Chile (Palmer)',
        'Antarctica/Rothera' => 'czas Rothera',
        'Antarctica/Syowa' => 'czas Syowa',
        'Antarctica/Troll' => 'czas uniwersalny (Troll)',
        'Antarctica/Vostok' => 'czas Wostok',
        'Arctic/Longyearbyen' => 'czas środkowoeuropejski (Longyearbyen)',
        'Asia/Aden' => 'czas Półwysep Arabski (Aden)',
        'Asia/Almaty' => 'czas Kazachstan Wschodni (Ałmaty)',
        'Asia/Amman' => 'czas wschodnioeuropejski (Amman)',
        'Asia/Anadyr' => 'czas Anadyr',
        'Asia/Aqtau' => 'czas Kazachstan Zachodni (Aktau)',
        'Asia/Aqtobe' => 'czas Kazachstan Zachodni (Aktiubińsk)',
        'Asia/Ashgabat' => 'czas Turkmenistan (Aszchabad)',
        'Asia/Atyrau' => 'czas Kazachstan Zachodni (Atyrau)',
        'Asia/Baghdad' => 'czas Półwysep Arabski (Bagdad)',
        'Asia/Bahrain' => 'czas Półwysep Arabski (Bahrajn)',
        'Asia/Baku' => 'czas Azerbejdżan (Baku)',
        'Asia/Bangkok' => 'czas indochiński (Bangkok)',
        'Asia/Barnaul' => 'czas: Rosja (Barnauł)',
        'Asia/Beirut' => 'czas wschodnioeuropejski (Bejrut)',
        'Asia/Bishkek' => 'czas Kirgistan (Biszkek)',
        'Asia/Brunei' => 'czas Brunei',
        'Asia/Calcutta' => 'czas indyjski standardowy (Kalkuta)',
        'Asia/Chita' => 'czas Jakuck (Czyta)',
        'Asia/Choibalsan' => 'czas Ułan Bator (Czojbalsan)',
        'Asia/Colombo' => 'czas indyjski standardowy (Kolombo)',
        'Asia/Damascus' => 'czas wschodnioeuropejski (Damaszek)',
        'Asia/Dhaka' => 'czas Bangladesz (Dhaka)',
        'Asia/Dili' => 'czas Timor Wschodni (Dili)',
        'Asia/Dubai' => 'czas Zatoka Perska (Dubaj)',
        'Asia/Dushanbe' => 'czas Tadżykistan (Duszanbe)',
        'Asia/Famagusta' => 'czas wschodnioeuropejski (Famagusta)',
        'Asia/Gaza' => 'czas wschodnioeuropejski (Gaza)',
        'Asia/Hebron' => 'czas wschodnioeuropejski (Hebron)',
        'Asia/Hong_Kong' => 'czas Hongkong',
        'Asia/Hovd' => 'czas Kobdo',
        'Asia/Irkutsk' => 'czas Irkuck',
        'Asia/Jakarta' => 'czas Indonezja Zachodnia (Dżakarta)',
        'Asia/Jayapura' => 'czas Indonezja Wschodnia (Jayapura)',
        'Asia/Jerusalem' => 'czas Izrael (Jerozolima)',
        'Asia/Kabul' => 'czas Afganistan (Kabul)',
        'Asia/Kamchatka' => 'czas Pietropawłowsk Kamczacki (Kamczatka)',
        'Asia/Karachi' => 'czas Pakistan (Karaczi)',
        'Asia/Katmandu' => 'czas Nepal (Katmandu)',
        'Asia/Khandyga' => 'czas Jakuck (Chandyga)',
        'Asia/Krasnoyarsk' => 'czas Krasnojarsk',
        'Asia/Kuala_Lumpur' => 'czas Malezja (Kuala Lumpur)',
        'Asia/Kuching' => 'czas Malezja (Kuching)',
        'Asia/Kuwait' => 'czas Półwysep Arabski (Kuwejt)',
        'Asia/Macau' => 'czas Chiny (Makau)',
        'Asia/Magadan' => 'czas Magadan',
        'Asia/Makassar' => 'czas Indonezja Środkowa (Makassar)',
        'Asia/Manila' => 'czas Filipiny (Manila)',
        'Asia/Muscat' => 'czas Zatoka Perska (Maskat)',
        'Asia/Nicosia' => 'czas wschodnioeuropejski (Nikozja)',
        'Asia/Novokuznetsk' => 'czas Krasnojarsk (Nowokuźnieck)',
        'Asia/Novosibirsk' => 'czas Nowosybirsk',
        'Asia/Omsk' => 'czas Omsk',
        'Asia/Oral' => 'czas Kazachstan Zachodni (Uralsk)',
        'Asia/Phnom_Penh' => 'czas indochiński (Phnom Penh)',
        'Asia/Pontianak' => 'czas Indonezja Zachodnia (Pontianak)',
        'Asia/Pyongyang' => 'czas Korea (Pjongjang)',
        'Asia/Qatar' => 'czas Półwysep Arabski (Katar)',
        'Asia/Qostanay' => 'czas Kazachstan Wschodni (Kustanaj)',
        'Asia/Qyzylorda' => 'czas Kazachstan Zachodni (Kyzyłorda)',
        'Asia/Rangoon' => 'czas Mjanma (Rangun)',
        'Asia/Riyadh' => 'czas Półwysep Arabski (Rijad)',
        'Asia/Saigon' => 'czas indochiński (Ho Chi Minh)',
        'Asia/Sakhalin' => 'czas Sachalin',
        'Asia/Samarkand' => 'czas Uzbekistan (Samarkanda)',
        'Asia/Seoul' => 'czas Korea (Seul)',
        'Asia/Shanghai' => 'czas Chiny (Szanghaj)',
        'Asia/Singapore' => 'czas Singapur',
        'Asia/Srednekolymsk' => 'czas Magadan (Sriedniekołymsk)',
        'Asia/Taipei' => 'czas Tajpej',
        'Asia/Tashkent' => 'czas Uzbekistan (Taszkient)',
        'Asia/Tbilisi' => 'czas Gruzja (Tbilisi)',
        'Asia/Tehran' => 'czas Iran (Teheran)',
        'Asia/Thimphu' => 'czas Bhutan (Thimphu)',
        'Asia/Tokyo' => 'czas Japonia (Tokio)',
        'Asia/Tomsk' => 'czas: Rosja (Tomsk)',
        'Asia/Ulaanbaatar' => 'czas Ułan Bator',
        'Asia/Urumqi' => 'czas: Chiny (Urumczi)',
        'Asia/Ust-Nera' => 'czas Władywostok (Ust-Niera)',
        'Asia/Vientiane' => 'czas indochiński (Wientian)',
        'Asia/Vladivostok' => 'czas Władywostok',
        'Asia/Yakutsk' => 'czas Jakuck',
        'Asia/Yekaterinburg' => 'czas Jekaterynburg',
        'Asia/Yerevan' => 'czas Armenia (Erywań)',
        'Atlantic/Azores' => 'czas Azory',
        'Atlantic/Bermuda' => 'czas atlantycki (Bermudy)',
        'Atlantic/Canary' => 'czas zachodnioeuropejski (Wyspy Kanaryjskie)',
        'Atlantic/Cape_Verde' => 'czas Wyspy Zielonego Przylądka (Republika Zielonego Przylądka)',
        'Atlantic/Faeroe' => 'czas zachodnioeuropejski (Wyspy Owcze)',
        'Atlantic/Madeira' => 'czas zachodnioeuropejski (Madera)',
        'Atlantic/Reykjavik' => 'czas uniwersalny (Reykjavik)',
        'Atlantic/South_Georgia' => 'czas Georgia Południowa',
        'Atlantic/St_Helena' => 'czas uniwersalny (Święta Helena)',
        'Atlantic/Stanley' => 'czas Falklandy (Stanley)',
        'Australia/Adelaide' => 'czas środkowoaustralijski (Adelaide)',
        'Australia/Brisbane' => 'czas wschodnioaustralijski (Brisbane)',
        'Australia/Broken_Hill' => 'czas środkowoaustralijski (Broken Hill)',
        'Australia/Currie' => 'czas wschodnioaustralijski (Currie)',
        'Australia/Darwin' => 'czas środkowoaustralijski (Darwin)',
        'Australia/Eucla' => 'czas środkowo-zachodnioaustralijski (Eucla)',
        'Australia/Hobart' => 'czas wschodnioaustralijski (Hobart)',
        'Australia/Lindeman' => 'czas wschodnioaustralijski (Lindeman)',
        'Australia/Lord_Howe' => 'czas Lord Howe',
        'Australia/Melbourne' => 'czas wschodnioaustralijski (Melbourne)',
        'Australia/Perth' => 'czas zachodnioaustralijski (Perth)',
        'Australia/Sydney' => 'czas wschodnioaustralijski (Sydney)',
        'CST6CDT' => 'czas środkowoamerykański',
        'EST5EDT' => 'czas wschodnioamerykański',
        'Etc/GMT' => 'czas uniwersalny',
        'Etc/UTC' => 'uniwersalny czas koordynowany',
        'Europe/Amsterdam' => 'czas środkowoeuropejski (Amsterdam)',
        'Europe/Andorra' => 'czas środkowoeuropejski (Andora)',
        'Europe/Astrakhan' => 'czas Moskwa (Astrachań)',
        'Europe/Athens' => 'czas wschodnioeuropejski (Ateny)',
        'Europe/Belgrade' => 'czas środkowoeuropejski (Belgrad)',
        'Europe/Berlin' => 'czas środkowoeuropejski (Berlin)',
        'Europe/Bratislava' => 'czas środkowoeuropejski (Bratysława)',
        'Europe/Brussels' => 'czas środkowoeuropejski (Bruksela)',
        'Europe/Bucharest' => 'czas wschodnioeuropejski (Bukareszt)',
        'Europe/Budapest' => 'czas środkowoeuropejski (Budapeszt)',
        'Europe/Busingen' => 'czas środkowoeuropejski (Büsingen am Hochrhein)',
        'Europe/Chisinau' => 'czas wschodnioeuropejski (Kiszyniów)',
        'Europe/Copenhagen' => 'czas środkowoeuropejski (Kopenhaga)',
        'Europe/Dublin' => 'czas uniwersalny (Dublin)',
        'Europe/Gibraltar' => 'czas środkowoeuropejski (Gibraltar)',
        'Europe/Guernsey' => 'czas uniwersalny (Guernsey)',
        'Europe/Helsinki' => 'czas wschodnioeuropejski (Helsinki)',
        'Europe/Isle_of_Man' => 'czas uniwersalny (Wyspa Man)',
        'Europe/Istanbul' => 'czas: Turcja (Stambuł)',
        'Europe/Jersey' => 'czas uniwersalny (Jersey)',
        'Europe/Kaliningrad' => 'czas wschodnioeuropejski (Kaliningrad)',
        'Europe/Kiev' => 'czas wschodnioeuropejski (Kijów)',
        'Europe/Kirov' => 'czas: Rosja (Kirow)',
        'Europe/Lisbon' => 'czas zachodnioeuropejski (Lizbona)',
        'Europe/Ljubljana' => 'czas środkowoeuropejski (Lublana)',
        'Europe/London' => 'czas uniwersalny (Londyn)',
        'Europe/Luxembourg' => 'czas środkowoeuropejski (Luksemburg)',
        'Europe/Madrid' => 'czas środkowoeuropejski (Madryt)',
        'Europe/Malta' => 'czas środkowoeuropejski (Malta)',
        'Europe/Mariehamn' => 'czas wschodnioeuropejski (Maarianhamina)',
        'Europe/Minsk' => 'czas Moskwa (Mińsk)',
        'Europe/Monaco' => 'czas środkowoeuropejski (Monako)',
        'Europe/Moscow' => 'czas Moskwa',
        'Europe/Oslo' => 'czas środkowoeuropejski (Oslo)',
        'Europe/Paris' => 'czas środkowoeuropejski (Paryż)',
        'Europe/Podgorica' => 'czas środkowoeuropejski (Podgorica)',
        'Europe/Prague' => 'czas środkowoeuropejski (Praga)',
        'Europe/Riga' => 'czas wschodnioeuropejski (Ryga)',
        'Europe/Rome' => 'czas środkowoeuropejski (Rzym)',
        'Europe/Samara' => 'czas Samara',
        'Europe/San_Marino' => 'czas środkowoeuropejski (San Marino)',
        'Europe/Sarajevo' => 'czas środkowoeuropejski (Sarajewo)',
        'Europe/Saratov' => 'czas Moskwa (Saratów)',
        'Europe/Simferopol' => 'czas Moskwa (Symferopol)',
        'Europe/Skopje' => 'czas środkowoeuropejski (Skopje)',
        'Europe/Sofia' => 'czas wschodnioeuropejski (Sofia)',
        'Europe/Stockholm' => 'czas środkowoeuropejski (Sztokholm)',
        'Europe/Tallinn' => 'czas wschodnioeuropejski (Tallin)',
        'Europe/Tirane' => 'czas środkowoeuropejski (Tirana)',
        'Europe/Ulyanovsk' => 'czas Moskwa (Uljanowsk)',
        'Europe/Uzhgorod' => 'czas wschodnioeuropejski (Użgorod)',
        'Europe/Vaduz' => 'czas środkowoeuropejski (Vaduz)',
        'Europe/Vatican' => 'czas środkowoeuropejski (Watykan)',
        'Europe/Vienna' => 'czas środkowoeuropejski (Wiedeń)',
        'Europe/Vilnius' => 'czas wschodnioeuropejski (Wilno)',
        'Europe/Volgograd' => 'czas Wołgograd',
        'Europe/Warsaw' => 'czas środkowoeuropejski (Warszawa)',
        'Europe/Zagreb' => 'czas środkowoeuropejski (Zagrzeb)',
        'Europe/Zaporozhye' => 'czas wschodnioeuropejski (Zaporoże)',
        'Europe/Zurich' => 'czas środkowoeuropejski (Zurych)',
        'Indian/Antananarivo' => 'czas wschodnioafrykański (Antananarywa)',
        'Indian/Chagos' => 'czas Ocean Indyjski (Czagos)',
        'Indian/Christmas' => 'czas Wyspa Bożego Narodzenia',
        'Indian/Cocos' => 'czas Wyspy Kokosowe',
        'Indian/Comoro' => 'czas wschodnioafrykański (Komory)',
        'Indian/Kerguelen' => 'czas Francuskie Terytoria Południowe i Antarktyczne (Wyspy Kerguelena)',
        'Indian/Mahe' => 'czas Seszele (Mahé)',
        'Indian/Maldives' => 'czas Malediwy',
        'Indian/Mauritius' => 'czas Mauritius',
        'Indian/Mayotte' => 'czas wschodnioafrykański (Majotta)',
        'Indian/Reunion' => 'czas Reunion (Réunion)',
        'MST7MDT' => 'czas górski',
        'PST8PDT' => 'czas pacyficzny',
        'Pacific/Apia' => 'czas Apia',
        'Pacific/Auckland' => 'czas Nowa Zelandia (Auckland)',
        'Pacific/Bougainville' => 'czas Papua-Nowa Gwinea (Wyspa Bougainville’a)',
        'Pacific/Chatham' => 'czas Chatham',
        'Pacific/Easter' => 'czas Wyspa Wielkanocna',
        'Pacific/Efate' => 'czas Vanuatu (Efate)',
        'Pacific/Enderbury' => 'czas Feniks (Enderbury)',
        'Pacific/Fakaofo' => 'czas Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'czas Fidżi',
        'Pacific/Funafuti' => 'czas Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'czas Galapagos',
        'Pacific/Gambier' => 'czas Wyspy Gambiera',
        'Pacific/Guadalcanal' => 'czas Wyspy Salomona (Guadalcanal)',
        'Pacific/Guam' => 'czas Czamorro (Guam)',
        'Pacific/Honolulu' => 'czas Hawaje-Aleuty (Honolulu)',
        'Pacific/Johnston' => 'czas Hawaje-Aleuty (Johnston)',
        'Pacific/Kiritimati' => 'czas Line Islands (Kiritimati)',
        'Pacific/Kosrae' => 'czas Kosrae',
        'Pacific/Kwajalein' => 'czas Wyspy Marshalla (Kwajalein)',
        'Pacific/Majuro' => 'czas Wyspy Marshalla (Majuro)',
        'Pacific/Marquesas' => 'czas Markizy',
        'Pacific/Midway' => 'czas Samoa (Midway)',
        'Pacific/Nauru' => 'czas Nauru',
        'Pacific/Niue' => 'czas Niue',
        'Pacific/Norfolk' => 'czas Norfolk',
        'Pacific/Noumea' => 'czas Nowa Kaledonia (Numea)',
        'Pacific/Pago_Pago' => 'czas Samoa (Pago Pago)',
        'Pacific/Palau' => 'czas Palau',
        'Pacific/Pitcairn' => 'czas Pitcairn',
        'Pacific/Ponape' => 'czas Pohnpei',
        'Pacific/Port_Moresby' => 'czas Papua-Nowa Gwinea (Port Moresby)',
        'Pacific/Rarotonga' => 'czas Wyspy Cooka (Rarotonga)',
        'Pacific/Saipan' => 'czas Czamorro (Saipan)',
        'Pacific/Tahiti' => 'czas Tahiti',
        'Pacific/Tarawa' => 'czas Wyspy Gilberta (Tarawa)',
        'Pacific/Tongatapu' => 'czas Tonga (Tongatapu)',
        'Pacific/Truk' => 'czas Chuuk',
        'Pacific/Wake' => 'czas Wake',
        'Pacific/Wallis' => 'czas Wallis i Futuna',
    ],
    'Meta' => [
    ],
];
