<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'העלפֿאַ נדביין בארטן (אַבידזשאַן)',
        'Africa/Accra' => 'גהאַנע (Accra)',
        'Africa/Addis_Ababa' => 'עטיאפּיע (Addis Ababa)',
        'Africa/Asmera' => 'עריטרעע (אַסמאַראַ)',
        'Africa/Bamako' => 'מאַלי (Bamako)',
        'Africa/Bangui' => 'צענטראַל־אַפֿריקאַנישע רעפּובליק (Bangui)',
        'Africa/Banjul' => 'גאַמביע (Banjul)',
        'Africa/Bissau' => 'גינע־ביסאַו (Bissau)',
        'Africa/Blantyre' => 'מאַלאַווי (Blantyre)',
        'Africa/Bujumbura' => 'בורונדי (Bujumbura)',
        'Africa/Cairo' => 'עגיפּטן (Cairo)',
        'Africa/Casablanca' => 'מאַראקא (Casablanca)',
        'Africa/Ceuta' => 'שפּאַניע (Ceuta)',
        'Africa/Conakry' => 'גינע (Conakry)',
        'Africa/Dakar' => 'סענעגאַל (Dakar)',
        'Africa/Dar_es_Salaam' => 'טאַנזאַניע (Dar es Salaam)',
        'Africa/Djibouti' => 'דזשיבוטי (Djibouti)',
        'Africa/Douala' => 'קאַמערון (Douala)',
        'Africa/Freetown' => 'סיערע לעאנע (Freetown)',
        'Africa/Gaborone' => 'באצוואַנע (Gaborone)',
        'Africa/Harare' => 'זימבאַבווע (Harare)',
        'Africa/Johannesburg' => 'דרום־אַפֿריקע (Johannesburg)',
        'Africa/Juba' => 'דרום־סודאַן (Juba)',
        'Africa/Kampala' => 'אוגאַנדע (Kampala)',
        'Africa/Khartoum' => 'סודאַן (Khartoum)',
        'Africa/Kigali' => 'רוואַנדע (Kigali)',
        'Africa/Kinshasa' => 'קאנגא־קינשאַזע (Kinshasa)',
        'Africa/Lagos' => 'ניגעריע (Lagos)',
        'Africa/Libreville' => 'גאַבאן (Libreville)',
        'Africa/Lome' => 'טאגא (Lome)',
        'Africa/Luanda' => 'אַנגאלע (Luanda)',
        'Africa/Lubumbashi' => 'קאנגא־קינשאַזע (Lubumbashi)',
        'Africa/Lusaka' => 'זאַמביע (Lusaka)',
        'Africa/Malabo' => 'עקוואַטארישע גינע (Malabo)',
        'Africa/Maputo' => 'מאזאַמביק (Maputo)',
        'Africa/Maseru' => 'לעסאטא (Maseru)',
        'Africa/Mbabane' => 'סוואַזילאַנד (Mbabane)',
        'Africa/Mogadishu' => 'סאמאַליע (Mogadishu)',
        'Africa/Monrovia' => 'ליבעריע (Monrovia)',
        'Africa/Nairobi' => 'קעניע (Nairobi)',
        'Africa/Ndjamena' => 'טשאַד (Ndjamena)',
        'Africa/Niamey' => 'ניזשער (Niamey)',
        'Africa/Nouakchott' => 'מאַריטאַניע (Nouakchott)',
        'Africa/Ouagadougou' => 'בורקינע פֿאַסא (Ouagadougou)',
        'Africa/Porto-Novo' => 'בענין (Porto-Novo)',
        'Africa/Sao_Tome' => 'סאַא טאמע און פּרינסיפּע (Sao Tome)',
        'Africa/Tripoli' => 'ליביע (Tripoli)',
        'Africa/Tunis' => 'טוניסיע (טוניס)',
        'Africa/Windhoek' => 'נאַמיביע (ווינטהוק)',
        'America/Adak' => 'פֿאַראייניגטע שטאַטן (Adak)',
        'America/Anchorage' => 'פֿאַראייניגטע שטאַטן (Anchorage)',
        'America/Antigua' => 'אַנטיגוע און באַרבודע (Antigua)',
        'America/Araguaina' => 'בראַזיל (Araguaina)',
        'America/Argentina/La_Rioja' => 'אַרגענטינע (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'אַרגענטינע (Rio Gallegos)',
        'America/Argentina/Salta' => 'אַרגענטינע (Salta)',
        'America/Argentina/San_Juan' => 'אַרגענטינע (San Juan)',
        'America/Argentina/San_Luis' => 'אַרגענטינע (San Luis)',
        'America/Argentina/Tucuman' => 'אַרגענטינע (Tucuman)',
        'America/Argentina/Ushuaia' => 'אַרגענטינע (Ushuaia)',
        'America/Aruba' => 'אַרובאַ (Aruba)',
        'America/Asuncion' => 'פּאַראַגווײַ (Asuncion)',
        'America/Bahia' => 'בראַזיל (Bahia)',
        'America/Bahia_Banderas' => 'מעקסיקע (Bahia Banderas)',
        'America/Barbados' => 'באַרבאַדאס (Barbados)',
        'America/Belem' => 'בראַזיל (Belem)',
        'America/Belize' => 'בעליז (Belize)',
        'America/Blanc-Sablon' => 'קאַנאַדע (Blanc-Sablon)',
        'America/Boa_Vista' => 'בראַזיל (Boa Vista)',
        'America/Bogota' => 'קאלאמביע (Bogota)',
        'America/Boise' => 'פֿאַראייניגטע שטאַטן (Boise)',
        'America/Buenos_Aires' => 'אַרגענטינע (Buenos Aires)',
        'America/Cambridge_Bay' => 'קאַנאַדע (Cambridge Bay)',
        'America/Campo_Grande' => 'בראַזיל (Campo Grande)',
        'America/Cancun' => 'מעקסיקע (Cancun)',
        'America/Caracas' => 'ווענעזועלע (Caracas)',
        'America/Catamarca' => 'אַרגענטינע (Catamarca)',
        'America/Cayenne' => 'פֿראַנצויזישע גויאַנע (Cayenne)',
        'America/Cayman' => 'קיימאַן אינזלען (Cayman)',
        'America/Chicago' => 'פֿאַראייניגטע שטאַטן (Chicago)',
        'America/Chihuahua' => 'מעקסיקע (Chihuahua)',
        'America/Coral_Harbour' => 'קאַנאַדע (Atikokan)',
        'America/Cordoba' => 'אַרגענטינע (Cordoba)',
        'America/Costa_Rica' => 'קאסטאַ ריקאַ (Costa Rica)',
        'America/Creston' => 'קאַנאַדע (Creston)',
        'America/Cuiaba' => 'בראַזיל (Cuiaba)',
        'America/Curacao' => 'קוראַסאַא (Curacao)',
        'America/Danmarkshavn' => 'גרינלאַנד (Danmarkshavn)',
        'America/Dawson' => 'קאַנאַדע (Dawson)',
        'America/Dawson_Creek' => 'קאַנאַדע (Dawson Creek)',
        'America/Denver' => 'פֿאַראייניגטע שטאַטן (Denver)',
        'America/Detroit' => 'פֿאַראייניגטע שטאַטן (Detroit)',
        'America/Dominica' => 'דאמיניקע (Dominica)',
        'America/Edmonton' => 'קאַנאַדע (Edmonton)',
        'America/Eirunepe' => 'בראַזיל (Eirunepe)',
        'America/El_Salvador' => 'על סאַלוואַדאר (El Salvador)',
        'America/Fort_Nelson' => 'קאַנאַדע (Fort Nelson)',
        'America/Fortaleza' => 'בראַזיל (Fortaleza)',
        'America/Glace_Bay' => 'קאַנאַדע (Glace Bay)',
        'America/Godthab' => 'גרינלאַנד (Nuuk)',
        'America/Goose_Bay' => 'קאַנאַדע (Goose Bay)',
        'America/Grenada' => 'גרענאַדאַ (Grenada)',
        'America/Guadeloupe' => 'גוואַדעלופ (Guadeloupe)',
        'America/Guatemala' => 'גוואַטעמאַלע (Guatemala)',
        'America/Guayaquil' => 'עקוואַדאר (Guayaquil)',
        'America/Guyana' => 'גויאַנע (Guyana)',
        'America/Halifax' => 'קאַנאַדע (Halifax)',
        'America/Havana' => 'קובאַ (Havana)',
        'America/Hermosillo' => 'מעקסיקע (Hermosillo)',
        'America/Indiana/Knox' => 'פֿאַראייניגטע שטאַטן (Knox, Indiana)',
        'America/Indiana/Marengo' => 'פֿאַראייניגטע שטאַטן (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'פֿאַראייניגטע שטאַטן (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'פֿאַראייניגטע שטאַטן (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'פֿאַראייניגטע שטאַטן (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'פֿאַראייניגטע שטאַטן (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'פֿאַראייניגטע שטאַטן (Winamac, Indiana)',
        'America/Indianapolis' => 'פֿאַראייניגטע שטאַטן (Indianapolis)',
        'America/Inuvik' => 'קאַנאַדע (Inuvik)',
        'America/Iqaluit' => 'קאַנאַדע (Iqaluit)',
        'America/Jamaica' => 'דזשאַמייקע (Jamaica)',
        'America/Jujuy' => 'אַרגענטינע (Jujuy)',
        'America/Juneau' => 'פֿאַראייניגטע שטאַטן (Juneau)',
        'America/Kentucky/Monticello' => 'פֿאַראייניגטע שטאַטן (Monticello, Kentucky)',
        'America/La_Paz' => 'באליוויע (La Paz)',
        'America/Lima' => 'פּערו (Lima)',
        'America/Los_Angeles' => 'פֿאַראייניגטע שטאַטן (Los Angeles)',
        'America/Louisville' => 'פֿאַראייניגטע שטאַטן (Louisville)',
        'America/Maceio' => 'בראַזיל (Maceio)',
        'America/Managua' => 'ניקאַראַגוע (Managua)',
        'America/Manaus' => 'בראַזיל (Manaus)',
        'America/Martinique' => 'מאַרטיניק (Martinique)',
        'America/Matamoros' => 'מעקסיקע (Matamoros)',
        'America/Mazatlan' => 'מעקסיקע (Mazatlan)',
        'America/Mendoza' => 'אַרגענטינע (Mendoza)',
        'America/Menominee' => 'פֿאַראייניגטע שטאַטן (Menominee)',
        'America/Merida' => 'מעקסיקע (Merida)',
        'America/Metlakatla' => 'פֿאַראייניגטע שטאַטן (Metlakatla)',
        'America/Mexico_City' => 'מעקסיקע (Mexico City)',
        'America/Moncton' => 'קאַנאַדע (Moncton)',
        'America/Monterrey' => 'מעקסיקע (Monterrey)',
        'America/Montevideo' => 'אורוגוויי (Montevideo)',
        'America/Montreal' => 'קאַנאַדע (Montreal)',
        'America/Montserrat' => 'מאנטסעראַט (Montserrat)',
        'America/Nassau' => 'באַהאַמאַס (Nassau)',
        'America/New_York' => 'פֿאַראייניגטע שטאַטן (New York)',
        'America/Nipigon' => 'קאַנאַדע (Nipigon)',
        'America/Nome' => 'פֿאַראייניגטע שטאַטן (Nome)',
        'America/Noronha' => 'בראַזיל (Noronha)',
        'America/North_Dakota/Beulah' => 'פֿאַראייניגטע שטאַטן (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'פֿאַראייניגטע שטאַטן (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'פֿאַראייניגטע שטאַטן (New Salem, North Dakota)',
        'America/Ojinaga' => 'מעקסיקע (Ojinaga)',
        'America/Panama' => 'פּאַנאַמאַ (Panama)',
        'America/Pangnirtung' => 'קאַנאַדע (Pangnirtung)',
        'America/Paramaribo' => 'סורינאַם (Paramaribo)',
        'America/Phoenix' => 'פֿאַראייניגטע שטאַטן (Phoenix)',
        'America/Port-au-Prince' => 'האַיטי (Port-au-Prince)',
        'America/Port_of_Spain' => 'טרינידאַד און טאבאַגא (Port of Spain)',
        'America/Porto_Velho' => 'בראַזיל (Porto Velho)',
        'America/Puerto_Rico' => 'פּארטא־ריקא (Puerto Rico)',
        'America/Punta_Arenas' => 'טשילע (Punta Arenas)',
        'America/Rainy_River' => 'קאַנאַדע (Rainy River)',
        'America/Rankin_Inlet' => 'קאַנאַדע (Rankin Inlet)',
        'America/Recife' => 'בראַזיל (Recife)',
        'America/Regina' => 'קאַנאַדע (Regina)',
        'America/Resolute' => 'קאַנאַדע (Resolute)',
        'America/Rio_Branco' => 'בראַזיל (Rio Branco)',
        'America/Santa_Isabel' => 'מעקסיקע (Santa Isabel)',
        'America/Santarem' => 'בראַזיל (Santarem)',
        'America/Santiago' => 'טשילע (Santiago)',
        'America/Santo_Domingo' => 'דאמיניקאַנישע רעפּובליק (Santo Domingo)',
        'America/Sao_Paulo' => 'בראַזיל (Sao Paulo)',
        'America/Scoresbysund' => 'גרינלאַנד (Ittoqqortoormiit)',
        'America/Sitka' => 'פֿאַראייניגטע שטאַטן (Sitka)',
        'America/St_Johns' => 'קאַנאַדע (St. John’s)',
        'America/Swift_Current' => 'קאַנאַדע (Swift Current)',
        'America/Tegucigalpa' => 'האנדוראַס (Tegucigalpa)',
        'America/Thule' => 'גרינלאַנד (Thule)',
        'America/Thunder_Bay' => 'קאַנאַדע (Thunder Bay)',
        'America/Tijuana' => 'מעקסיקע (Tijuana)',
        'America/Toronto' => 'קאַנאַדע (Toronto)',
        'America/Vancouver' => 'קאַנאַדע (Vancouver)',
        'America/Whitehorse' => 'קאַנאַדע (Whitehorse)',
        'America/Winnipeg' => 'קאַנאַדע (Winnipeg)',
        'America/Yakutat' => 'פֿאַראייניגטע שטאַטן (Yakutat)',
        'America/Yellowknife' => 'קאַנאַדע (Yellowknife)',
        'Antarctica/Casey' => 'אַנטאַרקטיקע (Casey)',
        'Antarctica/Davis' => 'אַנטאַרקטיקע (Davis)',
        'Antarctica/DumontDUrville' => 'אַנטאַרקטיקע (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'אויסטראַליע (Macquarie)',
        'Antarctica/Mawson' => 'אַנטאַרקטיקע (Mawson)',
        'Antarctica/McMurdo' => 'אַנטאַרקטיקע (McMurdo)',
        'Antarctica/Palmer' => 'אַנטאַרקטיקע (Palmer)',
        'Antarctica/Rothera' => 'אַנטאַרקטיקע (Rothera)',
        'Antarctica/Syowa' => 'אַנטאַרקטיקע (Syowa)',
        'Antarctica/Troll' => 'Troll',
        'Antarctica/Vostok' => 'אַנטאַרקטיקע (Vostok)',
        'Asia/Aden' => 'תימן (Aden)',
        'Asia/Anadyr' => 'רוסלאַנד (Anadyr)',
        'Asia/Ashgabat' => 'טורקמעניסטאַן (Ashgabat)',
        'Asia/Bangkok' => 'טיילאַנד (Bangkok)',
        'Asia/Barnaul' => 'רוסלאַנד (Barnaul)',
        'Asia/Beirut' => 'לבנון (Beirut)',
        'Asia/Brunei' => 'ברוניי (Brunei)',
        'Asia/Calcutta' => 'אינדיע (Kolkata)',
        'Asia/Chita' => 'רוסלאַנד (Chita)',
        'Asia/Choibalsan' => 'מאנגאליי (Choibalsan)',
        'Asia/Colombo' => 'סרי־לאַנקאַ (Colombo)',
        'Asia/Damascus' => 'סיריע (Damascus)',
        'Asia/Dhaka' => 'באַנגלאַדעש (Dhaka)',
        'Asia/Dili' => 'מזרח טימאר (Dili)',
        'Asia/Hovd' => 'מאנגאליי (Hovd)',
        'Asia/Irkutsk' => 'רוסלאַנד (Irkutsk)',
        'Asia/Jakarta' => 'אינדאנעזיע (Jakarta)',
        'Asia/Jayapura' => 'אינדאנעזיע (Jayapura)',
        'Asia/Jerusalem' => 'ישראל (Jerusalem)',
        'Asia/Kabul' => 'אַפֿגהאַניסטאַן (Kabul)',
        'Asia/Kamchatka' => 'רוסלאַנד (Kamchatka)',
        'Asia/Karachi' => 'פּאַקיסטאַן (Karachi)',
        'Asia/Katmandu' => 'נעפּאַל (Kathmandu)',
        'Asia/Khandyga' => 'רוסלאַנד (Khandyga)',
        'Asia/Krasnoyarsk' => 'רוסלאַנד (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'מאַלייזיע (Kuala Lumpur)',
        'Asia/Kuching' => 'מאַלייזיע (Kuching)',
        'Asia/Magadan' => 'רוסלאַנד (Magadan)',
        'Asia/Makassar' => 'אינדאנעזיע (Makassar)',
        'Asia/Manila' => 'פֿיליפּינען (Manila)',
        'Asia/Novokuznetsk' => 'רוסלאַנד (Novokuznetsk)',
        'Asia/Novosibirsk' => 'רוסלאַנד (Novosibirsk)',
        'Asia/Omsk' => 'רוסלאַנד (Omsk)',
        'Asia/Phnom_Penh' => 'קאַמבאדיע (Phnom Penh)',
        'Asia/Pontianak' => 'אינדאנעזיע (Pontianak)',
        'Asia/Qatar' => 'קאַטאַר (Qatar)',
        'Asia/Rangoon' => 'מיאַנמאַר (Yangon)',
        'Asia/Saigon' => 'וויעטנאַם (הא טשי מין שטאָט)',
        'Asia/Sakhalin' => 'רוסלאַנד (Sakhalin)',
        'Asia/Shanghai' => 'כינע (Shanghai)',
        'Asia/Singapore' => 'סינגאַפּור (Singapore)',
        'Asia/Srednekolymsk' => 'רוסלאַנד (Srednekolymsk)',
        'Asia/Tbilisi' => 'גרוזיע (Tbilisi)',
        'Asia/Tehran' => 'איראַן (Tehran)',
        'Asia/Thimphu' => 'בהוטאַן (Thimphu)',
        'Asia/Tokyo' => 'יאַפּאַן (Tokyo)',
        'Asia/Tomsk' => 'רוסלאַנד (Tomsk)',
        'Asia/Ulaanbaatar' => 'מאנגאליי (Ulaanbaatar)',
        'Asia/Urumqi' => 'כינע (Urumqi)',
        'Asia/Ust-Nera' => 'רוסלאַנד (Ust-Nera)',
        'Asia/Vientiane' => 'לאַאס (Vientiane)',
        'Asia/Vladivostok' => 'רוסלאַנד (Vladivostok)',
        'Asia/Yakutsk' => 'רוסלאַנד (Yakutsk)',
        'Asia/Yekaterinburg' => 'רוסלאַנד (Yekaterinburg)',
        'Asia/Yerevan' => 'אַרמעניע (Yerevan)',
        'Atlantic/Azores' => 'פּארטוגאַל (Azores)',
        'Atlantic/Bermuda' => 'בערמודע (Bermuda)',
        'Atlantic/Canary' => 'שפּאַניע (Canary)',
        'Atlantic/Cape_Verde' => 'קאַפּווערדישע אינזלען (Cape Verde)',
        'Atlantic/Faeroe' => 'פֿאַרא אינזלען (Faroe)',
        'Atlantic/Madeira' => 'פּארטוגאַל (Madeira)',
        'Atlantic/Reykjavik' => 'איסלאַנד (Reykjavik)',
        'Atlantic/St_Helena' => 'סט העלענע (St. Helena)',
        'Atlantic/Stanley' => 'פֿאַלקלאַנד אינזלען (Stanley)',
        'Australia/Adelaide' => 'אויסטראַליע (Adelaide)',
        'Australia/Brisbane' => 'אויסטראַליע (Brisbane)',
        'Australia/Broken_Hill' => 'אויסטראַליע (Broken Hill)',
        'Australia/Currie' => 'אויסטראַליע (Currie)',
        'Australia/Darwin' => 'אויסטראַליע (Darwin)',
        'Australia/Eucla' => 'אויסטראַליע (Eucla)',
        'Australia/Hobart' => 'אויסטראַליע (Hobart)',
        'Australia/Lindeman' => 'אויסטראַליע (Lindeman)',
        'Australia/Lord_Howe' => 'אויסטראַליע (Lord Howe)',
        'Australia/Melbourne' => 'אויסטראַליע (Melbourne)',
        'Australia/Perth' => 'אויסטראַליע (Perth)',
        'Australia/Sydney' => 'אויסטראַליע (Sydney)',
        'Europe/Amsterdam' => 'האלאַנד (Amsterdam)',
        'Europe/Andorra' => 'אַנדארע (Andorra)',
        'Europe/Astrakhan' => 'רוסלאַנד (Astrakhan)',
        'Europe/Athens' => 'גריכנלאַנד (Athens)',
        'Europe/Belgrade' => 'סערביע (Belgrade)',
        'Europe/Berlin' => 'דייטשלאַנד (Berlin)',
        'Europe/Bratislava' => 'סלאוואַקיי (Bratislava)',
        'Europe/Brussels' => 'בעלגיע (Brussels)',
        'Europe/Bucharest' => 'רומעניע (Bucharest)',
        'Europe/Budapest' => 'אונגערן (Budapest)',
        'Europe/Busingen' => 'דייטשלאַנד (Busingen)',
        'Europe/Chisinau' => 'מאלדאווע (Chisinau)',
        'Europe/Copenhagen' => 'דענמאַרק (Copenhagen)',
        'Europe/Dublin' => 'אירלאַנד (Dublin)',
        'Europe/Gibraltar' => 'גיבראַלטאַר (Gibraltar)',
        'Europe/Guernsey' => 'גערנזי (Guernsey)',
        'Europe/Helsinki' => 'פֿינלאַנד (Helsinki)',
        'Europe/Istanbul' => 'טערקיי (Istanbul)',
        'Europe/Jersey' => 'דזשערזי (Jersey)',
        'Europe/Kaliningrad' => 'רוסלאַנד (Kaliningrad)',
        'Europe/Kiev' => 'אוקראַינע (Kyiv)',
        'Europe/Kirov' => 'רוסלאַנד (Kirov)',
        'Europe/Lisbon' => 'פּארטוגאַל (Lisbon)',
        'Europe/Ljubljana' => 'סלאוועניע (Ljubljana)',
        'Europe/London' => 'פֿאַראייניגטע קעניגרייך (London)',
        'Europe/Luxembourg' => 'לוקסעמבורג (Luxembourg)',
        'Europe/Madrid' => 'שפּאַניע (Madrid)',
        'Europe/Malta' => 'מאַלטאַ (Malta)',
        'Europe/Minsk' => 'בעלאַרוס (Minsk)',
        'Europe/Monaco' => 'מאנאַקא (Monaco)',
        'Europe/Moscow' => 'רוסלאַנד (Moscow)',
        'Europe/Oslo' => 'נארוועגיע (Oslo)',
        'Europe/Paris' => 'פֿראַנקרייך (Paris)',
        'Europe/Podgorica' => 'מאנטענעגרא (Podgorica)',
        'Europe/Prague' => 'טשעכיי (Prague)',
        'Europe/Riga' => 'לעטלאַנד (Riga)',
        'Europe/Rome' => 'איטאַליע (Rome)',
        'Europe/Samara' => 'רוסלאַנד (Samara)',
        'Europe/San_Marino' => 'סאַן מאַרינא (San Marino)',
        'Europe/Sarajevo' => 'באסניע הערצעגאווינע (Sarajevo)',
        'Europe/Saratov' => 'רוסלאַנד (Saratov)',
        'Europe/Simferopol' => 'אוקראַינע (Simferopol)',
        'Europe/Sofia' => 'בולגאַריע (Sofia)',
        'Europe/Stockholm' => 'שוועדן (Stockholm)',
        'Europe/Tallinn' => 'עסטלאַנד (Tallinn)',
        'Europe/Tirane' => 'אַלבאַניע (Tirane)',
        'Europe/Ulyanovsk' => 'רוסלאַנד (Ulyanovsk)',
        'Europe/Uzhgorod' => 'אוקראַינע (Uzhgorod)',
        'Europe/Vaduz' => 'ליכטנשטיין (Vaduz)',
        'Europe/Vatican' => 'וואַטיקאַן שטאָט (Vatican)',
        'Europe/Vienna' => 'עסטרייך (Vienna)',
        'Europe/Vilnius' => 'ליטע (Vilnius)',
        'Europe/Volgograd' => 'רוסלאַנד (Volgograd)',
        'Europe/Warsaw' => 'פּוילן (Warsaw)',
        'Europe/Zagreb' => 'קראאַטיע (Zagreb)',
        'Europe/Zaporozhye' => 'אוקראַינע (Zaporozhye)',
        'Europe/Zurich' => 'שווייץ (Zurich)',
        'Indian/Antananarivo' => 'מאַדאַגאַסקאַר (Antananarivo)',
        'Indian/Comoro' => 'קאמאראס (Comoro)',
        'Indian/Mahe' => 'סיישעל (Mahe)',
        'Indian/Maldives' => 'מאַלדיוון (Maldives)',
        'Indian/Mauritius' => 'מאריציוס (Mauritius)',
        'Indian/Mayotte' => 'מאַיאט (Mayotte)',
        'Indian/Reunion' => 'רעאוניאן (Reunion)',
        'Pacific/Apia' => 'סאַמאאַ (Apia)',
        'Pacific/Auckland' => 'ניו זילאַנד (Auckland)',
        'Pacific/Bougainville' => 'פּאַפּואַ נײַ גינע (Bougainville)',
        'Pacific/Chatham' => 'ניו זילאַנד (Chatham)',
        'Pacific/Easter' => 'טשילע (Easter)',
        'Pacific/Efate' => 'וואַנואַטו (Efate)',
        'Pacific/Enderbury' => 'קיריבאַטי (Enderbury)',
        'Pacific/Fiji' => 'פֿידזשי (Fiji)',
        'Pacific/Funafuti' => 'טואוואַלו (Funafuti)',
        'Pacific/Galapagos' => 'עקוואַדאר (Galapagos)',
        'Pacific/Gambier' => 'פֿראַנצויזישע פּאלינעזיע (Gambier)',
        'Pacific/Guadalcanal' => 'סאלאמאן אינזלען (Guadalcanal)',
        'Pacific/Guam' => 'גוואַם (Guam)',
        'Pacific/Honolulu' => 'פֿאַראייניגטע שטאַטן (Honolulu)',
        'Pacific/Kiritimati' => 'קיריבאַטי (Kiritimati)',
        'Pacific/Kosrae' => 'מיקראנעזיע (Kosrae)',
        'Pacific/Kwajalein' => 'מאַרשאַל אינזלען (Kwajalein)',
        'Pacific/Majuro' => 'מאַרשאַל אינזלען (Majuro)',
        'Pacific/Marquesas' => 'פֿראַנצויזישע פּאלינעזיע (Marquesas)',
        'Pacific/Norfolk' => 'נארפֿאלק אינזל (Norfolk)',
        'Pacific/Noumea' => 'נײַ קאַלעדאניע (Noumea)',
        'Pacific/Pitcairn' => 'פּיטקערן אינזלען (Pitcairn)',
        'Pacific/Ponape' => 'מיקראנעזיע (Pohnpei)',
        'Pacific/Port_Moresby' => 'פּאַפּואַ נײַ גינע (Port Moresby)',
        'Pacific/Rarotonga' => 'קוק אינזלען (Rarotonga)',
        'Pacific/Tahiti' => 'פֿראַנצויזישע פּאלינעזיע (Tahiti)',
        'Pacific/Tarawa' => 'קיריבאַטי (Tarawa)',
        'Pacific/Tongatapu' => 'טאנגאַ (Tongatapu)',
        'Pacific/Truk' => 'מיקראנעזיע (Chuuk)',
    ],
    'Meta' => [
    ],
];
