<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abkhazo',
        'ace' => 'acehnese',
        'ada' => 'adangme',
        'ady' => 'adygeano',
        'af' => 'afrikaans',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'ale' => 'aleuto',
        'alt' => 'altai del sud',
        'am' => 'amharico',
        'an' => 'aragonese',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabe',
        'arn' => 'mapuche',
        'arp' => 'arapaho',
        'ars' => 'arabe najdi',
        'as' => 'assamese',
        'asa' => 'asu',
        'ast' => 'asturiano',
        'atj' => 'atikamekw',
        'av' => 'avaro',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'azerbaidzhano',
        'ba' => 'bashkir',
        'ban' => 'balinese',
        'bas' => 'basaa',
        'be' => 'bielorusso',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bulgaro',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bin' => 'bini',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bengalese',
        'bo' => 'tibetano',
        'br' => 'breton',
        'brx' => 'bodo',
        'bs' => 'bosniaco',
        'bug' => 'buginese',
        'byn' => 'blin',
        'ca' => 'catalano',
        'cay' => 'cayuga',
        'ccp' => 'chakma',
        'ce' => 'checheno',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'kurdo central',
        'clc' => 'chilcotin',
        'co' => 'corso',
        'crg' => 'mitchif',
        'crj' => 'cree del sud-est',
        'crk' => 'cree del planas',
        'crl' => 'cree del nord-est',
        'crm' => 'cree moose',
        'crr' => 'algonquino de Carolina',
        'crs' => 'creolo seychellese',
        'cs' => 'checo',
        'csw' => 'cree del paludes',
        'cu' => 'slavo ecclesiastic',
        'cv' => 'chuvash',
        'cy' => 'gallese',
        'da' => 'danese',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'germano',
        'dgr' => 'dogrib',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'basse sorabo',
        'dua' => 'duala',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'eka' => 'ekajuk',
        'el' => 'greco',
        'en' => 'anglese',
        'eo' => 'esperanto',
        'es' => 'espaniol',
        'et' => 'estoniano',
        'eu' => 'basco',
        'ewo' => 'ewondo',
        'fa' => 'persa',
        'ff' => 'fula',
        'fi' => 'finnese',
        'fil' => 'filipino',
        'fj' => 'fijiano',
        'fo' => 'feroese',
        'fon' => 'fon',
        'fr' => 'francese',
        'frc' => 'francese cajun',
        'frr' => 'frison septentrional',
        'fur' => 'friulano',
        'fy' => 'frison occidental',
        'ga' => 'irlandese',
        'gaa' => 'ga',
        'gd' => 'gaelico scotese',
        'gez' => 'ge’ez',
        'gil' => 'gilbertese',
        'gl' => 'galleco',
        'gn' => 'guarani',
        'gor' => 'gorontalo',
        'gsw' => 'germano suisse',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'mannese',
        'gwi' => 'gwich’in',
        'ha' => 'hausa',
        'hai' => 'haida',
        'haw' => 'hawaiano',
        'hax' => 'haida del sud',
        'he' => 'hebreo',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hmn' => 'hmong',
        'hr' => 'croato',
        'hsb' => 'alte sorabo',
        'ht' => 'creolo haitian',
        'hu' => 'hungaro',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armenio',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesiano',
        'ig' => 'igbo',
        'ii' => 'yi de Sichuan',
        'ikt' => 'inuktitut del west canadian',
        'ilo' => 'ilocano',
        'inh' => 'ingush',
        'io' => 'ido',
        'is' => 'islandese',
        'it' => 'italiano',
        'iu' => 'inuktitut',
        'ja' => 'japonese',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'javanese',
        'ka' => 'georgiano',
        'kab' => 'kabylo',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kbd' => 'cabardiano',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'capoverdiano',
        'kfo' => 'koro',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kazakh',
        'kkj' => 'kako',
        'kl' => 'groenlandese',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'coreano',
        'kok' => 'konkani',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karachay-balkaro',
        'krl' => 'careliano',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'coloniese',
        'ku' => 'kurdo',
        'kum' => 'kumyko',
        'kv' => 'komi',
        'kw' => 'cornico',
        'kwk' => 'kwakwala',
        'ky' => 'kirghizo',
        'la' => 'latino',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lb' => 'luxemburgese',
        'lez' => 'lezghiano',
        'lg' => 'luganda',
        'li' => 'limburgese',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'laotiano',
        'lou' => 'creolo louisianese',
        'loz' => 'lozi',
        'lrc' => 'luri del nord',
        'lsm' => 'samia',
        'lt' => 'lithuano',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'letton',
        'mad' => 'madurese',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'macassarese',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'men' => 'mende',
        'mer' => 'meri',
        'mfe' => 'creolo mauritian',
        'mg' => 'malgache',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'metaʼ',
        'mh' => 'marshallese',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'macedone',
        'ml' => 'malayalam',
        'mn' => 'mongol',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malay',
        'mt' => 'maltese',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandese',
        'my' => 'birmano',
        'myv' => 'erzya',
        'mzn' => 'mazanderani',
        'na' => 'nauru',
        'nap' => 'napolitano',
        'naq' => 'nama',
        'nb' => 'norvegiano bokmål',
        'nd' => 'ndebele del nord',
        'nds' => 'basse germano',
        'ne' => 'nepalese',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'nieuano',
        'nl' => 'nederlandese',
        'nmg' => 'kwasio',
        'nn' => 'norvegiano nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norvegiano',
        'nog' => 'nogai',
        'nqo' => 'n’ko',
        'nr' => 'ndebele del sud',
        'nso' => 'sotho del nord',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'ny' => 'nyanja',
        'nyn' => 'nyankole',
        'oc' => 'occitano',
        'ojb' => 'ojibwa del nord-west',
        'ojc' => 'ojibwa central',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwa del west',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'oriya',
        'os' => 'osseto',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauano',
        'pcm' => 'pidgin nigerian',
        'pis' => 'pijin',
        'pl' => 'polonese',
        'pqm' => 'malecite-passamaquoddy',
        'prg' => 'prussiano',
        'ps' => 'pashto',
        'pt' => 'portugese',
        'qu' => 'quechua',
        'quc' => 'kʼicheʼ',
        'rap' => 'rapanui',
        'rar' => 'rarotongano',
        'rhg' => 'rohingya',
        'rm' => 'romanche',
        'rn' => 'rundi',
        'ro' => 'romaniano',
        'rof' => 'rombo',
        'ru' => 'russo',
        'rup' => 'aromaniano',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanscrito',
        'sad' => 'sandawe',
        'sah' => 'yakuto',
        'saq' => 'samburu',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardo',
        'scn' => 'siciliano',
        'sco' => 'scotese',
        'sd' => 'sindhi',
        'se' => 'sami del nord',
        'seh' => 'sena',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'si' => 'cingalese',
        'sk' => 'slovaco',
        'sl' => 'sloveno',
        'slh' => 'lushootseed del sud',
        'sm' => 'samoano',
        'sma' => 'sami del sud',
        'smj' => 'sami de Lule',
        'smn' => 'sami de Inari',
        'sms' => 'sami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somali',
        'sq' => 'albanese',
        'sr' => 'serbo',
        'srn' => 'sranan tongo',
        'ss' => 'swati',
        'ssy' => 'saho',
        'st' => 'sotho del sud',
        'str' => 'salish del strictos',
        'su' => 'sundanese',
        'suk' => 'sukuma',
        'sv' => 'svedese',
        'sw' => 'swahili',
        'swb' => 'comoriano',
        'syr' => 'syriaco',
        'ta' => 'tamil',
        'tce' => 'tutchone del sud',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'tet' => 'tetum',
        'tg' => 'tajiko',
        'tgx' => 'tagish',
        'th' => 'thai',
        'tht' => 'tahltan',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tk' => 'turkmeno',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tn' => 'tswana',
        'to' => 'tongano',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turco',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tt' => 'tataro',
        'ttm' => 'tutchone del nord',
        'tum' => 'tumbuka',
        'tvl' => 'tuvaluano',
        'twq' => 'tasawaq',
        'ty' => 'tahitiano',
        'tyv' => 'tuvano',
        'tzm' => 'tamazight del Atlas Central',
        'udm' => 'udmurto',
        'ug' => 'uighur',
        'uk' => 'ukrainiano',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbeko',
        'vai' => 'vai',
        've' => 'venda',
        'vi' => 'vietnamese',
        'vo' => 'volapük',
        'vun' => 'vunjo',
        'wa' => 'wallon',
        'wae' => 'walser',
        'wal' => 'wolaytta',
        'war' => 'waray',
        'wo' => 'wolof',
        'wuu' => 'wu',
        'xal' => 'calmuco',
        'xh' => 'xhosa',
        'xog' => 'soga',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'yiddish',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'cantonese',
        'zgh' => 'tamazight marocchin standard',
        'zh' => 'chinese',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabe standard moderne',
        'de_AT' => 'germano austriac',
        'de_CH' => 'alte germano suisse',
        'en_AU' => 'anglese australian',
        'en_CA' => 'anglese canadian',
        'en_GB' => 'anglese britannic',
        'en_US' => 'anglese american',
        'es_419' => 'espaniol latinoamerican',
        'es_ES' => 'espaniol europee',
        'es_MX' => 'espaniol mexican',
        'fa_AF' => 'dari',
        'fr_CA' => 'francese canadian',
        'fr_CH' => 'francese suisse',
        'nl_BE' => 'flamingo',
        'pt_BR' => 'portugese de Brasil',
        'pt_PT' => 'portugese de Portugal',
        'ro_MD' => 'moldavo',
        'sw_CD' => 'swahili del Congo',
        'zh_Hans' => 'chinese simplificate',
        'zh_Hant' => 'chinese traditional',
    ],
];
