<?php

return [
    'Names' => [
        'AD' => 'Andore',
        'AE' => 'Lemila alabu',
        'AF' => 'Afuganisita',
        'AG' => 'Antiga ne Barbuda',
        'AI' => 'Angiye',
        'AL' => 'Alubani',
        'AM' => 'Ameni',
        'AO' => 'Angola',
        'AR' => 'Alijantine',
        'AS' => 'Samoa wa Ameriki',
        'AT' => 'Otilisi',
        'AU' => 'Ositali',
        'AW' => 'Aruba',
        'AZ' => 'Ajelbayidja',
        'BA' => 'Mbosini ne Hezegovine',
        'BB' => 'Barebade',
        'BD' => 'Benguladeshi',
        'BE' => 'Belejiki',
        'BF' => 'Bukinafaso',
        'BG' => 'Biligari',
        'BH' => 'Bahrene',
        'BI' => 'Burundi',
        'BJ' => 'Bene',
        'BM' => 'Bermuda',
        'BN' => 'Brineyi',
        'BO' => 'Mbolivi',
        'BR' => 'Mnulezile',
        'BS' => 'Bahamase',
        'BT' => 'Butani',
        'BW' => 'Mbotswana',
        'BY' => 'Byelorisi',
        'BZ' => 'Belize',
        'CA' => 'Kanada',
        'CD' => 'Ditunga wa Kongu',
        'CF' => 'Ditunga dya Afrika wa munkatshi',
        'CG' => 'Kongu',
        'CH' => 'Swise',
        'CI' => 'Kotedivuale',
        'CK' => 'Lutanda lua Kookɛ',
        'CL' => 'Shili',
        'CM' => 'Kamerune',
        'CN' => 'Shine',
        'CO' => 'Kolombi',
        'CR' => 'Kositarika',
        'CU' => 'Kuba',
        'CV' => 'Lutanda lua Kapevele',
        'CY' => 'Shipele',
        'CZ' => 'Ditunga dya Tsheka',
        'DE' => 'Alemanu',
        'DJ' => 'Djibuti',
        'DK' => 'Danemalaku',
        'DM' => 'Duminiku',
        'DO' => 'Ditunga wa Duminiku',
        'DZ' => 'Alijeri',
        'EC' => 'Ekwatele',
        'EE' => 'Esitoni',
        'EG' => 'Mushidi',
        'ER' => 'Elitele',
        'ES' => 'Nsipani',
        'ET' => 'Etshiopi',
        'FI' => 'Filande',
        'FJ' => 'Fuji',
        'FK' => 'Lutanda lua Maluni',
        'FM' => 'Mikronezi',
        'FR' => 'Nfalanse',
        'GA' => 'Ngabu',
        'GB' => 'Angeletele',
        'GD' => 'Ngelenade',
        'GE' => 'Joriji',
        'GF' => 'Giyane wa Nfalanse',
        'GH' => 'Ngana',
        'GI' => 'Jibeletale',
        'GL' => 'Ngowelande',
        'GM' => 'Gambi',
        'GN' => 'Ngine',
        'GP' => 'Ngwadelupe',
        'GQ' => 'Gine Ekwatele',
        'GR' => 'Ngeleka',
        'GT' => 'Ngwatemala',
        'GU' => 'Ngwame',
        'GW' => 'Nginebisau',
        'GY' => 'Ngiyane',
        'HN' => 'Ondurase',
        'HR' => 'Krowasi',
        'HT' => 'Ayiti',
        'HU' => 'Ongili',
        'ID' => 'Indonezi',
        'IE' => 'Irelande',
        'IL' => 'Isirayele',
        'IN' => 'Inde',
        'IO' => 'Lutanda lwa Angeletele ku mbu wa Indiya',
        'IQ' => 'Iraki',
        'IR' => 'Ira',
        'IS' => 'Isilande',
        'IT' => 'Itali',
        'JM' => 'Jamaiki',
        'JO' => 'Jodani',
        'JP' => 'Japu',
        'KE' => 'Kenya',
        'KG' => 'Kigizisita',
        'KH' => 'Kambodza',
        'KI' => 'Kiribati',
        'KM' => 'Komoru',
        'KN' => 'Santu krístofe ne Neves',
        'KP' => 'Kore wa muulu',
        'KR' => 'Kore wa mwinshi',
        'KW' => 'Koweti',
        'KY' => 'Lutanda lua Kayima',
        'KZ' => 'Kazakusita',
        'LA' => 'Lawosi',
        'LB' => 'Liba',
        'LC' => 'Santu lisi',
        'LI' => 'Lishuteni',
        'LK' => 'Sirilanka',
        'LR' => 'Liberiya',
        'LS' => 'Lesoto',
        'LT' => 'Litwani',
        'LU' => 'Likisambulu',
        'LV' => 'Letoni',
        'LY' => 'Libi',
        'MA' => 'Maroke',
        'MC' => 'Monaku',
        'MD' => 'Molidavi',
        'MG' => 'Madagasikari',
        'MH' => 'Lutanda lua Marishale',
        'ML' => 'Mali',
        'MM' => 'Myamare',
        'MN' => 'Mongoli',
        'MP' => 'Lutanda lua Mariane wa muulu',
        'MQ' => 'Martiniki',
        'MR' => 'Moritani',
        'MS' => 'Musera',
        'MT' => 'Malite',
        'MU' => 'Morise',
        'MV' => 'Madive',
        'MW' => 'Malawi',
        'MX' => 'Meksike',
        'MY' => 'Malezi',
        'MZ' => 'Mozambiki',
        'NA' => 'Namibi',
        'NC' => 'Kaledoni wa mumu',
        'NE' => 'Nijere',
        'NF' => 'Lutanda lua Norfok',
        'NG' => 'Nijerya',
        'NI' => 'Nikaragwa',
        'NL' => 'Olandɛ',
        'NO' => 'Noriveje',
        'NP' => 'Nepálɛ',
        'NR' => 'Nauru',
        'NU' => 'Nyue',
        'NZ' => 'Zelanda wa mumu',
        'OM' => 'Omane',
        'PA' => 'Panama',
        'PE' => 'Peru',
        'PF' => 'Polinezi wa Nfalanse',
        'PG' => 'Papwazi wa Nginɛ wa mumu',
        'PH' => 'Nfilipi',
        'PK' => 'Pakisita',
        'PL' => 'Mpoloni',
        'PM' => 'Santu pététo ne Mikelu',
        'PN' => 'Pikairni',
        'PR' => 'Mpotoriku',
        'PS' => 'Palesine',
        'PT' => 'Mputulugeshi',
        'PW' => 'Palau',
        'PY' => 'Palagwei',
        'QA' => 'Katari',
        'RE' => 'Lenyo',
        'RO' => 'Romani',
        'RU' => 'Risi',
        'RW' => 'Rwanda',
        'SA' => 'Alabu Nsawudi',
        'SB' => 'Lutanda lua Solomu',
        'SC' => 'Seshele',
        'SD' => 'Suda',
        'SE' => 'Suwedi',
        'SG' => 'Singapure',
        'SH' => 'Santu eleni',
        'SI' => 'Siloveni',
        'SK' => 'Silovaki',
        'SL' => 'Siera Leone',
        'SM' => 'Santu Marine',
        'SN' => 'Senegale',
        'SO' => 'Somali',
        'SR' => 'Suriname',
        'ST' => 'Sao Tome ne Presipɛ',
        'SV' => 'Savadore',
        'SY' => 'Siri',
        'SZ' => 'Swazilandi',
        'TC' => 'Lutanda lua Tuluki ne Kaiko',
        'TD' => 'Tshadi',
        'TG' => 'Togu',
        'TH' => 'Tayilanda',
        'TJ' => 'Tazikisita',
        'TK' => 'Tokelau',
        'TL' => 'Timoru wa diboku',
        'TM' => 'Tukemenisita',
        'TN' => 'Tinizi',
        'TO' => 'Tonga',
        'TR' => 'Tuluki',
        'TT' => 'Tinidade ne Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'Taiwani',
        'TZ' => 'Tanzani',
        'UA' => 'Ukreni',
        'UG' => 'Uganda',
        'US' => 'Ameriki',
        'UY' => 'Irigwei',
        'UZ' => 'Uzibekisita',
        'VA' => 'Nvatika',
        'VC' => 'Santu vesa ne Ngelenadine',
        'VE' => 'Venezuela',
        'VG' => 'Lutanda lua Vierzi wa Angeletele',
        'VI' => 'Lutanda lua Vierzi wa Ameriki',
        'VN' => 'Viyetiname',
        'VU' => 'Vanuatu',
        'WF' => 'Walise ne Futuna',
        'WS' => 'Samoa',
        'YE' => 'Yemenu',
        'YT' => 'Mayote',
        'ZA' => 'Afrika ya Súdi',
        'ZM' => 'Zambi',
        'ZW' => 'Zimbabwe',
    ],
];
