<?php

return [
    'Names' => [
        'BL' => 'St. Barthélemy',
        'KN' => 'St. Kitts & Nevis',
        'LC' => 'St. Lucia',
        'MF' => 'St. Martin',
        'VC' => 'St. Vincent & Grenadines',
    ],
];
