<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Waktu Greenwich (Abidjan)',
        'Africa/Accra' => 'Waktu Greenwich (Accra)',
        'Africa/Algiers' => 'Waktu Éropa Tengah (Algiers)',
        'Africa/Bamako' => 'Waktu Greenwich (Bamako)',
        'Africa/Banjul' => 'Waktu Greenwich (Banjul)',
        'Africa/Bissau' => 'Waktu Greenwich (Bissau)',
        'Africa/Cairo' => 'Waktu Éropa Timur (Cairo)',
        'Africa/Casablanca' => 'Waktu Éropa Barat (Casablanca)',
        'Africa/Ceuta' => 'Waktu Éropa Tengah (Ceuta)',
        'Africa/Conakry' => 'Waktu Greenwich (Conakry)',
        'Africa/Dakar' => 'Waktu Greenwich (Dakar)',
        'Africa/El_Aaiun' => 'Waktu Éropa Barat (El Aaiun)',
        'Africa/Freetown' => 'Waktu Greenwich (Freetown)',
        'Africa/Lome' => 'Waktu Greenwich (Lome)',
        'Africa/Monrovia' => 'Waktu Greenwich (Monrovia)',
        'Africa/Nouakchott' => 'Waktu Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Waktu Greenwich (Ouagadougou)',
        'Africa/Sao_Tome' => 'Waktu Greenwich (Sao Tome)',
        'Africa/Tripoli' => 'Waktu Éropa Timur (Tripoli)',
        'Africa/Tunis' => 'Waktu Éropa Tengah (Tunis)',
        'America/Adak' => 'Amérika Sarikat (Adak)',
        'America/Anchorage' => 'Amérika Sarikat (Anchorage)',
        'America/Anguilla' => 'Waktu Atlantik (Anguilla)',
        'America/Antigua' => 'Waktu Atlantik (Antigua)',
        'America/Araguaina' => 'Brasil (Araguaina)',
        'America/Aruba' => 'Waktu Atlantik (Aruba)',
        'America/Bahia' => 'Brasil (Bahia)',
        'America/Bahia_Banderas' => 'Waktu Tengah (Bahia Banderas)',
        'America/Barbados' => 'Waktu Atlantik (Barbados)',
        'America/Belem' => 'Brasil (Belem)',
        'America/Belize' => 'Waktu Tengah (Belize)',
        'America/Blanc-Sablon' => 'Waktu Atlantik (Blanc-Sablon)',
        'America/Boa_Vista' => 'Brasil (Boa Vista)',
        'America/Bogota' => 'Waktu Kolombia (Bogota)',
        'America/Boise' => 'Waktu Pagunungan (Boise)',
        'America/Cambridge_Bay' => 'Waktu Pagunungan (Cambridge Bay)',
        'America/Campo_Grande' => 'Brasil (Campo Grande)',
        'America/Cancun' => 'Waktu Wétan (Cancun)',
        'America/Cayman' => 'Waktu Wétan (Cayman)',
        'America/Chicago' => 'Waktu Tengah (Chicago)',
        'America/Coral_Harbour' => 'Waktu Wétan (Atikokan)',
        'America/Costa_Rica' => 'Waktu Tengah (Costa Rica)',
        'America/Creston' => 'Waktu Pagunungan (Creston)',
        'America/Cuiaba' => 'Brasil (Cuiaba)',
        'America/Curacao' => 'Waktu Atlantik (Curacao)',
        'America/Danmarkshavn' => 'Waktu Greenwich (Danmarkshavn)',
        'America/Dawson_Creek' => 'Waktu Pagunungan (Dawson Creek)',
        'America/Denver' => 'Waktu Pagunungan (Denver)',
        'America/Detroit' => 'Waktu Wétan (Detroit)',
        'America/Dominica' => 'Waktu Atlantik (Dominica)',
        'America/Edmonton' => 'Waktu Pagunungan (Edmonton)',
        'America/Eirunepe' => 'Brasil (Eirunepe)',
        'America/El_Salvador' => 'Waktu Tengah (El Salvador)',
        'America/Fort_Nelson' => 'Waktu Pagunungan (Fort Nelson)',
        'America/Fortaleza' => 'Brasil (Fortaleza)',
        'America/Glace_Bay' => 'Waktu Atlantik (Glace Bay)',
        'America/Goose_Bay' => 'Waktu Atlantik (Goose Bay)',
        'America/Grand_Turk' => 'Waktu Wétan (Grand Turk)',
        'America/Grenada' => 'Waktu Atlantik (Grenada)',
        'America/Guadeloupe' => 'Waktu Atlantik (Guadeloupe)',
        'America/Guatemala' => 'Waktu Tengah (Guatemala)',
        'America/Halifax' => 'Waktu Atlantik (Halifax)',
        'America/Indiana/Knox' => 'Waktu Tengah (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Waktu Wétan (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Waktu Wétan (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Waktu Tengah (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Waktu Wétan (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Waktu Wétan (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Waktu Wétan (Winamac, Indiana)',
        'America/Indianapolis' => 'Waktu Wétan (Indianapolis)',
        'America/Inuvik' => 'Waktu Pagunungan (Inuvik)',
        'America/Iqaluit' => 'Waktu Wétan (Iqaluit)',
        'America/Jamaica' => 'Waktu Wétan (Jamaica)',
        'America/Juneau' => 'Amérika Sarikat (Juneau)',
        'America/Kentucky/Monticello' => 'Waktu Wétan (Monticello, Kentucky)',
        'America/Kralendijk' => 'Waktu Atlantik (Kralendijk)',
        'America/Los_Angeles' => 'Waktu Pasifik (Los Angeles)',
        'America/Louisville' => 'Waktu Wétan (Louisville)',
        'America/Lower_Princes' => 'Waktu Atlantik (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasil (Maceio)',
        'America/Managua' => 'Waktu Tengah (Managua)',
        'America/Manaus' => 'Brasil (Manaus)',
        'America/Marigot' => 'Waktu Atlantik (Marigot)',
        'America/Martinique' => 'Waktu Atlantik (Martinique)',
        'America/Matamoros' => 'Waktu Tengah (Matamoros)',
        'America/Menominee' => 'Waktu Tengah (Menominee)',
        'America/Merida' => 'Waktu Tengah (Merida)',
        'America/Metlakatla' => 'Amérika Sarikat (Metlakatla)',
        'America/Mexico_City' => 'Waktu Tengah (Mexico City)',
        'America/Moncton' => 'Waktu Atlantik (Moncton)',
        'America/Monterrey' => 'Waktu Tengah (Monterrey)',
        'America/Montserrat' => 'Waktu Atlantik (Montserrat)',
        'America/Nassau' => 'Waktu Wétan (Nassau)',
        'America/New_York' => 'Waktu Wétan (New York)',
        'America/Nipigon' => 'Waktu Wétan (Nipigon)',
        'America/Nome' => 'Amérika Sarikat (Nome)',
        'America/Noronha' => 'Brasil (Noronha)',
        'America/North_Dakota/Beulah' => 'Waktu Tengah (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Waktu Tengah (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Waktu Tengah (New Salem, North Dakota)',
        'America/Ojinaga' => 'Waktu Pagunungan (Ojinaga)',
        'America/Panama' => 'Waktu Wétan (Panama)',
        'America/Pangnirtung' => 'Waktu Wétan (Pangnirtung)',
        'America/Phoenix' => 'Waktu Pagunungan (Phoenix)',
        'America/Port-au-Prince' => 'Waktu Wétan (Port-au-Prince)',
        'America/Port_of_Spain' => 'Waktu Atlantik (Port of Spain)',
        'America/Porto_Velho' => 'Brasil (Porto Velho)',
        'America/Puerto_Rico' => 'Waktu Atlantik (Puerto Rico)',
        'America/Rainy_River' => 'Waktu Tengah (Rainy River)',
        'America/Rankin_Inlet' => 'Waktu Tengah (Rankin Inlet)',
        'America/Recife' => 'Brasil (Recife)',
        'America/Regina' => 'Waktu Tengah (Regina)',
        'America/Resolute' => 'Waktu Tengah (Resolute)',
        'America/Rio_Branco' => 'Brasil (Rio Branco)',
        'America/Santarem' => 'Brasil (Santarem)',
        'America/Santo_Domingo' => 'Waktu Atlantik (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasil (Sao Paulo)',
        'America/Sitka' => 'Amérika Sarikat (Sitka)',
        'America/St_Barthelemy' => 'Waktu Atlantik (St. Barthelemy)',
        'America/St_Kitts' => 'Waktu Atlantik (St. Kitts)',
        'America/St_Lucia' => 'Waktu Atlantik (St. Lucia)',
        'America/St_Thomas' => 'Waktu Atlantik (St. Thomas)',
        'America/St_Vincent' => 'Waktu Atlantik (St. Vincent)',
        'America/Swift_Current' => 'Waktu Tengah (Swift Current)',
        'America/Tegucigalpa' => 'Waktu Tengah (Tegucigalpa)',
        'America/Thule' => 'Waktu Atlantik (Thule)',
        'America/Thunder_Bay' => 'Waktu Wétan (Thunder Bay)',
        'America/Tijuana' => 'Waktu Pasifik (Tijuana)',
        'America/Toronto' => 'Waktu Wétan (Toronto)',
        'America/Tortola' => 'Waktu Atlantik (Tortola)',
        'America/Vancouver' => 'Waktu Pasifik (Vancouver)',
        'America/Winnipeg' => 'Waktu Tengah (Winnipeg)',
        'America/Yakutat' => 'Amérika Sarikat (Yakutat)',
        'America/Yellowknife' => 'Waktu Pagunungan (Yellowknife)',
        'Antarctica/Troll' => 'Waktu Greenwich (Troll)',
        'Arctic/Longyearbyen' => 'Waktu Éropa Tengah (Longyearbyen)',
        'Asia/Amman' => 'Waktu Éropa Timur (Amman)',
        'Asia/Anadyr' => 'Rusia (Anadyr)',
        'Asia/Barnaul' => 'Rusia (Barnaul)',
        'Asia/Beirut' => 'Waktu Éropa Timur (Beirut)',
        'Asia/Calcutta' => 'India (Kolkata)',
        'Asia/Chita' => 'Rusia (Chita)',
        'Asia/Damascus' => 'Waktu Éropa Timur (Damascus)',
        'Asia/Famagusta' => 'Waktu Éropa Timur (Famagusta)',
        'Asia/Gaza' => 'Waktu Éropa Timur (Gaza)',
        'Asia/Hebron' => 'Waktu Éropa Timur (Hebron)',
        'Asia/Irkutsk' => 'Rusia (Irkutsk)',
        'Asia/Jakarta' => 'Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Indonesia (Jayapura)',
        'Asia/Kamchatka' => 'Rusia (Kamchatka)',
        'Asia/Khandyga' => 'Rusia (Khandyga)',
        'Asia/Krasnoyarsk' => 'Rusia (Krasnoyarsk)',
        'Asia/Magadan' => 'Rusia (Magadan)',
        'Asia/Makassar' => 'Indonesia (Makassar)',
        'Asia/Nicosia' => 'Waktu Éropa Timur (Nicosia)',
        'Asia/Novokuznetsk' => 'Rusia (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Rusia (Novosibirsk)',
        'Asia/Omsk' => 'Rusia (Omsk)',
        'Asia/Pontianak' => 'Indonesia (Pontianak)',
        'Asia/Sakhalin' => 'Rusia (Sakhalin)',
        'Asia/Shanghai' => 'Tiongkok (Shanghai)',
        'Asia/Srednekolymsk' => 'Rusia (Srednekolymsk)',
        'Asia/Tokyo' => 'Jepang (Tokyo)',
        'Asia/Tomsk' => 'Rusia (Tomsk)',
        'Asia/Urumqi' => 'Tiongkok (Urumqi)',
        'Asia/Ust-Nera' => 'Rusia (Ust-Nera)',
        'Asia/Vladivostok' => 'Rusia (Vladivostok)',
        'Asia/Yakutsk' => 'Rusia (Yakutsk)',
        'Asia/Yekaterinburg' => 'Rusia (Yekaterinburg)',
        'Atlantic/Bermuda' => 'Waktu Atlantik (Bermuda)',
        'Atlantic/Canary' => 'Waktu Éropa Barat (Canary)',
        'Atlantic/Faeroe' => 'Waktu Éropa Barat (Faroe)',
        'Atlantic/Madeira' => 'Waktu Éropa Barat (Madeira)',
        'Atlantic/Reykjavik' => 'Waktu Greenwich (Reykjavik)',
        'Atlantic/St_Helena' => 'Waktu Greenwich (St. Helena)',
        'CST6CDT' => 'Waktu Tengah',
        'EST5EDT' => 'Waktu Wétan',
        'Etc/GMT' => 'Waktu Greenwich',
        'Etc/UTC' => 'Waktu Universal Terkoordinasi',
        'Europe/Amsterdam' => 'Waktu Éropa Tengah (Amsterdam)',
        'Europe/Andorra' => 'Waktu Éropa Tengah (Andorra)',
        'Europe/Astrakhan' => 'Rusia (Astrakhan)',
        'Europe/Athens' => 'Waktu Éropa Timur (Athens)',
        'Europe/Belgrade' => 'Waktu Éropa Tengah (Belgrade)',
        'Europe/Berlin' => 'Waktu Éropa Tengah (Berlin)',
        'Europe/Bratislava' => 'Waktu Éropa Tengah (Bratislava)',
        'Europe/Brussels' => 'Waktu Éropa Tengah (Brussels)',
        'Europe/Bucharest' => 'Waktu Éropa Timur (Bucharest)',
        'Europe/Budapest' => 'Waktu Éropa Tengah (Budapest)',
        'Europe/Busingen' => 'Waktu Éropa Tengah (Busingen)',
        'Europe/Chisinau' => 'Waktu Éropa Timur (Chisinau)',
        'Europe/Copenhagen' => 'Waktu Éropa Tengah (Copenhagen)',
        'Europe/Dublin' => 'Waktu Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Waktu Éropa Tengah (Gibraltar)',
        'Europe/Guernsey' => 'Waktu Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Waktu Éropa Timur (Helsinki)',
        'Europe/Isle_of_Man' => 'Waktu Greenwich (Isle of Man)',
        'Europe/Jersey' => 'Waktu Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Waktu Éropa Timur (Kaliningrad)',
        'Europe/Kiev' => 'Waktu Éropa Timur (Kyiv)',
        'Europe/Kirov' => 'Rusia (Kirov)',
        'Europe/Lisbon' => 'Waktu Éropa Barat (Lisbon)',
        'Europe/Ljubljana' => 'Waktu Éropa Tengah (Ljubljana)',
        'Europe/London' => 'Waktu Greenwich (London)',
        'Europe/Luxembourg' => 'Waktu Éropa Tengah (Luxembourg)',
        'Europe/Madrid' => 'Waktu Éropa Tengah (Madrid)',
        'Europe/Malta' => 'Waktu Éropa Tengah (Malta)',
        'Europe/Mariehamn' => 'Waktu Éropa Timur (Mariehamn)',
        'Europe/Monaco' => 'Waktu Éropa Tengah (Monaco)',
        'Europe/Moscow' => 'Rusia (Moscow)',
        'Europe/Oslo' => 'Waktu Éropa Tengah (Oslo)',
        'Europe/Paris' => 'Waktu Éropa Tengah (Paris)',
        'Europe/Podgorica' => 'Waktu Éropa Tengah (Podgorica)',
        'Europe/Prague' => 'Waktu Éropa Tengah (Prague)',
        'Europe/Riga' => 'Waktu Éropa Timur (Riga)',
        'Europe/Rome' => 'Waktu Éropa Tengah (Rome)',
        'Europe/Samara' => 'Rusia (Samara)',
        'Europe/San_Marino' => 'Waktu Éropa Tengah (San Marino)',
        'Europe/Sarajevo' => 'Waktu Éropa Tengah (Sarajevo)',
        'Europe/Saratov' => 'Rusia (Saratov)',
        'Europe/Skopje' => 'Waktu Éropa Tengah (Skopje)',
        'Europe/Sofia' => 'Waktu Éropa Timur (Sofia)',
        'Europe/Stockholm' => 'Waktu Éropa Tengah (Stockholm)',
        'Europe/Tallinn' => 'Waktu Éropa Timur (Tallinn)',
        'Europe/Tirane' => 'Waktu Éropa Tengah (Tirane)',
        'Europe/Ulyanovsk' => 'Rusia (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Waktu Éropa Timur (Uzhgorod)',
        'Europe/Vaduz' => 'Waktu Éropa Tengah (Vaduz)',
        'Europe/Vatican' => 'Waktu Éropa Tengah (Vatican)',
        'Europe/Vienna' => 'Waktu Éropa Tengah (Vienna)',
        'Europe/Vilnius' => 'Waktu Éropa Timur (Vilnius)',
        'Europe/Volgograd' => 'Rusia (Volgograd)',
        'Europe/Warsaw' => 'Waktu Éropa Tengah (Warsaw)',
        'Europe/Zagreb' => 'Waktu Éropa Tengah (Zagreb)',
        'Europe/Zaporozhye' => 'Waktu Éropa Timur (Zaporozhye)',
        'Europe/Zurich' => 'Waktu Éropa Tengah (Zurich)',
        'MST7MDT' => 'Waktu Pagunungan',
        'PST8PDT' => 'Waktu Pasifik',
        'Pacific/Galapagos' => 'Waktu Galapagos',
        'Pacific/Honolulu' => 'Amérika Sarikat (Honolulu)',
    ],
    'Meta' => [
    ],
];
