<?php

return [
    'Names' => [
        'ady' => 'adigeo',
        'alt' => 'altái del sur',
        'arp' => 'arapajó',
        'ars' => 'árabe de Néyed',
        'bla' => 'siksiká',
        'eu' => 'vasco',
        'goh' => 'alemán de la alta edad antigua',
        'grc' => 'griego clásico',
        'gu' => 'gujarati',
        'ht' => 'haitiano',
        'kbd' => 'cabardiano',
        'krc' => 'karachái-bálkaro',
        'ks' => 'cachemiro',
        'lo' => 'laosiano',
        'ml' => 'malabar',
        'mni' => 'manipuri',
        'nr' => 'ndebele del sur',
        'nso' => 'sesotho del norte',
        'pa' => 'panyabí',
        'prg' => 'prusiano antiguo',
        'rm' => 'retorrománico',
        'sd' => 'sindhi',
        'shu' => 'árabe (Chad)',
        'sma' => 'sami del sur',
        'st' => 'sesotho del sur',
        'sw' => 'swahili',
        'syr' => 'siríaco',
        'tet' => 'tetun',
        'tyv' => 'tuvano',
        'wal' => 'walamo',
        'wuu' => 'wu',
        'xal' => 'calmuco',
        'zun' => 'zuni',
    ],
    'LocalizedNames' => [
        'sw_CD' => 'swahili (Congo)',
    ],
];
