<?php

return [
    'Names' => [
        'af' => 'isiBhulu',
        'ar' => 'Isi-Arabhu',
        'bn' => 'IsiBangla',
        'de' => 'IsiJamani',
        'en' => 'IsiNgesi',
        'es' => 'Isi-Spanish',
        'fr' => 'IsiFrentshi',
        'hi' => 'IsiHindi',
        'id' => 'Isi-Indonesia',
        'it' => 'IsiTaliyane',
        'ja' => 'IsiJapan',
        'ko' => 'Isi-Korean',
        'nl' => 'IsiDatshi',
        'pl' => 'Isi-Polish',
        'pt' => 'IsiPhuthukezi',
        'ru' => 'Isi-Russian',
        'th' => 'Isi-Thai',
        'tr' => 'Isi-Turkish',
        'xh' => 'IsiXhosa',
        'zh' => 'IsiMandarin',
        'zu' => 'isiZulu',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Isi-Arabhu (Sale mihla)',
        'de_AT' => 'IsiJamani Sase-Austria',
        'de_CH' => 'IsiJamani Esiyi-High Swiss',
        'en_AU' => 'IsiNgesi Sase-Australia',
        'en_CA' => 'IsiNgesi SaseKhanada',
        'en_GB' => 'IsiNgesi SaseBritane',
        'en_US' => 'Isingesi SaseMelika',
        'es_419' => 'IsiSpanish SaseLatin America',
        'es_ES' => 'IsiSpanish SaseYurophu',
        'es_MX' => 'IsiSpanish SaseMexico',
        'fr_CA' => 'IsiFrentshi SaseKhanada',
        'fr_CH' => 'IsiFrentshi SaseSwitzerland',
        'hi_Latn' => 'IsiHindi (Latin)',
        'nl_BE' => 'IsiFlemish',
        'pt_BR' => 'IsiPhuthukezi SaseBrazil',
        'pt_PT' => 'IsiPhuthukezi SasePortugal',
        'zh_Hans' => 'IsiTshayina Esenziwe Lula',
        'zh_Hant' => 'IsiTshayina Esiqhelekileyo',
    ],
];
