<?php

return [
    'Names' => [
        'BAM' => [
            0 => 'КМ',
            1 => 'Босанскохерцеговачка конвертибилна марка',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Бјелоруска рубља',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Сјевернокорејски вон',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Никарагванска златна кордоба',
        ],
    ],
];
