<?php

return [
    'Names' => [
        'aa' => 'افار',
        'ab' => 'ابقازیان',
        'ace' => 'اچائینیز',
        'ach' => 'اکولی',
        'ada' => 'ادانگمے',
        'ady' => 'ادیگھے',
        'af' => 'افریقی',
        'agq' => 'اغم',
        'ain' => 'اینو',
        'ak' => 'اکان',
        'ale' => 'الیوت',
        'alt' => 'جنوبی الٹائی',
        'am' => 'امہاری',
        'an' => 'اراگونیز',
        'ann' => 'اوبولو',
        'anp' => 'انگیکا',
        'ar' => 'عربی',
        'arn' => 'ماپوچے',
        'arp' => 'اراپاہو',
        'ars' => 'نجدی عربی',
        'as' => 'آسامی',
        'asa' => 'آسو',
        'ast' => 'اسٹوریائی',
        'atj' => 'اٹیکامیکو',
        'av' => 'اواری',
        'awa' => 'اوادھی',
        'ay' => 'ایمارا',
        'az' => 'آذربائیجانی',
        'ba' => 'باشکیر',
        'ban' => 'بالینیز',
        'bas' => 'باسا',
        'be' => 'بیلاروسی',
        'bem' => 'بیمبا',
        'bez' => 'بینا',
        'bg' => 'بلغاری',
        'bgn' => 'مغربی بلوچی',
        'bho' => 'بھوجپوری',
        'bi' => 'بسلاما',
        'bin' => 'بینی',
        'bla' => 'سکسیکا',
        'bm' => 'بمبارا',
        'bn' => 'بنگلہ',
        'bo' => 'تبتی',
        'br' => 'بریٹن',
        'brx' => 'بوڈو',
        'bs' => 'بوسنیائی',
        'bug' => 'بگینیز',
        'byn' => 'بلین',
        'ca' => 'کیٹالان',
        'cay' => 'کایوگا',
        'ccp' => 'چکمہ',
        'ce' => 'چیچن',
        'ceb' => 'سیبوآنو',
        'cgg' => 'چیگا',
        'ch' => 'چیمارو',
        'chk' => 'چوکیز',
        'chm' => 'ماری',
        'cho' => 'چاکٹاؤ',
        'chp' => 'چپوائن',
        'chr' => 'چیروکی',
        'chy' => 'چینّے',
        'ckb' => 'سینٹرل کردش',
        'clc' => 'چلکوٹن',
        'co' => 'کوراسیکن',
        'crg' => 'میچیف',
        'crj' => 'جنوب مشرقی کری',
        'crk' => 'پلینز کری',
        'crl' => 'شمال مشرقی کری',
        'crm' => 'موس کری',
        'crr' => 'کیرولینا الگونکوئن',
        'crs' => 'سیسلوا کریولے فرانسیسی',
        'cs' => 'چیک',
        'csw' => 'سوامپی کری',
        'cu' => 'چرچ سلاوک',
        'cv' => 'چوواش',
        'cy' => 'ویلش',
        'da' => 'ڈینش',
        'dak' => 'ڈاکوٹا',
        'dar' => 'درگوا',
        'dav' => 'تائتا',
        'de' => 'جرمن',
        'dgr' => 'دوگریب',
        'dje' => 'زرما',
        'doi' => 'ڈوگری',
        'dsb' => 'ذیلی سربیائی',
        'dua' => 'دوالا',
        'dv' => 'ڈیویہی',
        'dyo' => 'جولا فونيا',
        'dz' => 'ژونگکھا',
        'dzg' => 'دزاگا',
        'ebu' => 'امبو',
        'ee' => 'ایو',
        'efi' => 'ایفِک',
        'eka' => 'ایکاجوی',
        'el' => 'یونانی',
        'en' => 'انگریزی',
        'eo' => 'ایسپرانٹو',
        'es' => 'ہسپانوی',
        'et' => 'اسٹونین',
        'eu' => 'باسکی',
        'ewo' => 'ایوانڈو',
        'fa' => 'فارسی',
        'ff' => 'فولہ',
        'fi' => 'فینیش',
        'fil' => 'فلیپینو',
        'fj' => 'فجی',
        'fo' => 'فیروئیز',
        'fon' => 'فون',
        'fr' => 'فرانسیسی',
        'frc' => 'کاجن فرانسیسی',
        'frr' => 'شمالی فریزئین',
        'fur' => 'فریولیائی',
        'fy' => 'مغربی فریسیئن',
        'ga' => 'آئرش',
        'gaa' => 'گا',
        'gag' => 'غاغاوز',
        'gan' => 'gan',
        'gd' => 'سکاٹش گیلک',
        'gez' => 'گیز',
        'gil' => 'گلبرتیز',
        'gl' => 'گالیشیائی',
        'gn' => 'گُارانی',
        'gor' => 'گورانٹالو',
        'gsw' => 'سوئس جرمن',
        'gu' => 'گجراتی',
        'guz' => 'گسی',
        'gv' => 'مینکس',
        'gwi' => 'گوئچ ان',
        'ha' => 'ہؤسا',
        'hai' => 'ہائیڈا',
        'haw' => 'ہوائی',
        'hax' => 'جنوبی ہائیڈا',
        'he' => 'عبرانی',
        'hi' => 'ہندی',
        'hil' => 'ہالیگینون',
        'hmn' => 'ہمانگ',
        'hr' => 'کراتی',
        'hsb' => 'اپر سربیائی',
        'ht' => 'ہیتی',
        'hu' => 'ہنگیرین',
        'hup' => 'ہیوپا',
        'hur' => 'ہالکومیلم',
        'hy' => 'آرمینیائی',
        'hz' => 'ہریرو',
        'ia' => 'بین لسانیات',
        'iba' => 'ایبان',
        'ibb' => 'ابی بیو',
        'id' => 'انڈونیثیائی',
        'ig' => 'اِگبو',
        'ii' => 'سچوان ای',
        'ikt' => 'مغربی کینیڈین اینُکٹیٹٹ',
        'ilo' => 'ایلوکو',
        'inh' => 'انگوش',
        'io' => 'ایڈو',
        'is' => 'آئس لینڈک',
        'it' => 'اطالوی',
        'iu' => 'اینُکٹیٹٹ',
        'ja' => 'جاپانی',
        'jbo' => 'لوجبان',
        'jgo' => 'نگومبا',
        'jmc' => 'ماشیم',
        'jv' => 'جاوی',
        'ka' => 'جارجیائی',
        'kab' => 'قبائلی',
        'kac' => 'کاچن',
        'kaj' => 'جے جو',
        'kam' => 'کامبا',
        'kbd' => 'کبارڈین',
        'kcg' => 'تیاپ',
        'kde' => 'ماکونده',
        'kea' => 'کابويرديانو',
        'kfo' => 'کورو',
        'kg' => 'کانگو',
        'kgp' => 'کینگینگ',
        'kha' => 'کھاسی',
        'khq' => 'کويرا شيني',
        'ki' => 'کیکویو',
        'kj' => 'کونیاما',
        'kk' => 'قزاخ',
        'kkj' => 'کاکو',
        'kl' => 'کالاليست',
        'kln' => 'کالينجين',
        'km' => 'خمیر',
        'kmb' => 'کیمبونڈو',
        'kn' => 'کنّاڈا',
        'ko' => 'کوریائی',
        'koi' => 'کومی پرمیاک',
        'kok' => 'کونکنی',
        'kpe' => 'کیپیلّے',
        'kr' => 'کنوری',
        'krc' => 'کراچے بالکر',
        'krl' => 'کیرلین',
        'kru' => 'کوروکھ',
        'ks' => 'کشمیری',
        'ksb' => 'شامبالا',
        'ksf' => 'بافيا',
        'ksh' => 'کولوگنیائی',
        'ku' => 'کردش',
        'kum' => 'کومیک',
        'kv' => 'کومی',
        'kw' => 'کورنش',
        'kwk' => 'کیواکوالا',
        'ky' => 'کرغیزی',
        'la' => 'لاطینی',
        'lad' => 'لیڈینو',
        'lag' => 'لانگی',
        'lb' => 'لکسمبرگیش',
        'lez' => 'لیزگیان',
        'lg' => 'گینڈا',
        'li' => 'لیمبرگش',
        'lil' => 'للوئیٹ',
        'lkt' => 'لاکوٹا',
        'ln' => 'لِنگَلا',
        'lo' => 'لاؤ',
        'lou' => 'لوزیانا کریول',
        'loz' => 'لوزی',
        'lrc' => 'شمالی لری',
        'lsm' => 'سامیہ',
        'lt' => 'لیتھوینین',
        'lu' => 'لبا-کاتانجا',
        'lua' => 'لیوبا لولوآ',
        'lun' => 'لونڈا',
        'luo' => 'لو',
        'lus' => 'میزو',
        'luy' => 'لویا',
        'lv' => 'لیٹوین',
        'mad' => 'مدورسی',
        'mag' => 'مگاہی',
        'mai' => 'میتھیلی',
        'mak' => 'مکاسر',
        'mas' => 'مسائی',
        'mdf' => 'موکشا',
        'men' => 'میندے',
        'mer' => 'میرو',
        'mfe' => 'موریسیین',
        'mg' => 'ملاگاسی',
        'mgh' => 'ماخاوا-ميتو',
        'mgo' => 'میٹا',
        'mh' => 'مارشلیز',
        'mi' => 'ماؤری',
        'mic' => 'مکمیک',
        'min' => 'منانگکباؤ',
        'mk' => 'مقدونیائی',
        'ml' => 'مالایالم',
        'mn' => 'منگولین',
        'mni' => 'منی پوری',
        'moe' => 'انو ایمن',
        'moh' => 'موہاک',
        'mos' => 'موسی',
        'mr' => 'مراٹهی',
        'ms' => 'مالے',
        'mt' => 'مالٹی',
        'mua' => 'منڈانگ',
        'mus' => 'کریک',
        'mwl' => 'میرانڈیز',
        'my' => 'برمی',
        'myv' => 'ارزیا',
        'mzn' => 'مزندرانی',
        'na' => 'ناؤرو',
        'nap' => 'نیاپولیٹن',
        'naq' => 'ناما',
        'nb' => 'نارویجین بوکمل',
        'nd' => 'شمالی دبیل',
        'nds' => 'ادنی جرمن',
        'ne' => 'نیپالی',
        'new' => 'نیواری',
        'ng' => 'نڈونگا',
        'nia' => 'نیاس',
        'niu' => 'نیویائی',
        'nl' => 'ڈچ',
        'nmg' => 'کوايسو',
        'nn' => 'نارویجین نینورسک',
        'nnh' => 'نگیمبون',
        'no' => 'نارویجین',
        'nog' => 'نوگائی',
        'nqo' => 'اینکو',
        'nr' => 'جنوبی نڈیبیلی',
        'nso' => 'شمالی سوتھو',
        'nus' => 'نویر',
        'nv' => 'نواجو',
        'ny' => 'نیانجا',
        'nyn' => 'نینکول',
        'oc' => 'آکسیٹان',
        'ojb' => 'شمال مغربی اوجبوا',
        'ojc' => 'سینٹرل اوجبوا',
        'ojs' => 'اوجی کری',
        'ojw' => 'مغربی اوجبوا',
        'oka' => 'اوکناگن',
        'om' => 'اورومو',
        'or' => 'اڑیہ',
        'os' => 'اوسیٹک',
        'pa' => 'پنجابی',
        'pag' => 'پنگاسنان',
        'pam' => 'پامپنگا',
        'pap' => 'پاپیامینٹو',
        'pau' => 'پالاون',
        'pcm' => 'نائجیریائی پڈگن',
        'pis' => 'پجن',
        'pl' => 'پولش',
        'pqm' => 'مالیسیٹ پاساماکوڈی',
        'prg' => 'پارسی',
        'ps' => 'پشتو',
        'pt' => 'پُرتگالی',
        'qu' => 'کویچوآ',
        'quc' => 'کيشی',
        'rap' => 'رپانوی',
        'rar' => 'راروتونگان',
        'rhg' => 'روہنگیا',
        'rm' => 'رومانش',
        'rn' => 'رونڈی',
        'ro' => 'رومینین',
        'rof' => 'رومبو',
        'ru' => 'روسی',
        'rup' => 'ارومانی',
        'rw' => 'کینیاروانڈا',
        'rwk' => 'روا',
        'sa' => 'سنسکرت',
        'sad' => 'سنڈاوے',
        'sah' => 'ساکھا',
        'saq' => 'سامبورو',
        'sat' => 'سنتالی',
        'sba' => 'نگامبے',
        'sbp' => 'سانگو',
        'sc' => 'سردینین',
        'scn' => 'سیسیلین',
        'sco' => 'سکاٹ',
        'sd' => 'سندھی',
        'sdh' => 'جنوبی کرد',
        'se' => 'شمالی سامی',
        'seh' => 'سینا',
        'ses' => 'کويرابورو سينی',
        'sg' => 'ساںغو',
        'sh' => 'سربو-کروئیشین',
        'shi' => 'تشلحيت',
        'shn' => 'شان',
        'si' => 'سنہالا',
        'sk' => 'سلوواک',
        'sl' => 'سلووینیائی',
        'slh' => 'جنوبی لوشوٹسیڈ',
        'sm' => 'ساموآن',
        'sma' => 'جنوبی سامی',
        'smj' => 'لول سامی',
        'smn' => 'اناری سامی',
        'sms' => 'سکولٹ سامی',
        'sn' => 'شونا',
        'snk' => 'سوننکے',
        'so' => 'صومالی',
        'sq' => 'البانی',
        'sr' => 'سربین',
        'srn' => 'سرانن ٹونگو',
        'ss' => 'سواتی',
        'ssy' => 'ساہو',
        'st' => 'جنوبی سوتھو',
        'str' => 'سٹریٹس سالِش',
        'su' => 'سنڈانیز',
        'suk' => 'سکوما',
        'sv' => 'سویڈش',
        'sw' => 'سواحلی',
        'swb' => 'کوموریائی',
        'syr' => 'سریانی',
        'ta' => 'تمل',
        'tce' => 'جنوبی ٹچون',
        'te' => 'تیلگو',
        'tem' => 'ٹمنے',
        'teo' => 'تیسو',
        'tet' => 'ٹیٹم',
        'tg' => 'تاجک',
        'tgx' => 'ٹاگش',
        'th' => 'تھائی',
        'tht' => 'ٹاہلٹن',
        'ti' => 'ٹگرینیا',
        'tig' => 'ٹگرے',
        'tk' => 'ترکمان',
        'tl' => 'ٹیگا لوگ',
        'tlh' => 'کلنگن',
        'tli' => 'ٹلنگٹ',
        'tn' => 'سوانا',
        'to' => 'ٹونگن',
        'tok' => 'ٹوکی پونا',
        'tpi' => 'ٹوک پِسِن',
        'tr' => 'ترکی',
        'trv' => 'ٹوروکو',
        'ts' => 'زونگا',
        'tt' => 'تاتار',
        'ttm' => 'شمالی ٹچون',
        'tum' => 'ٹمبوکا',
        'tvl' => 'تووالو',
        'tw' => 'توی',
        'twq' => 'تاساواق',
        'ty' => 'تاہیتی',
        'tyv' => 'تووینین',
        'tzm' => 'سینٹرل ایٹلس ٹمازائٹ',
        'udm' => 'ادمورت',
        'ug' => 'یوئگہر',
        'uk' => 'یوکرینیائی',
        'umb' => 'اومبوندو',
        'ur' => 'اردو',
        'uz' => 'ازبیک',
        'vai' => 'وائی',
        've' => 'وینڈا',
        'vi' => 'ویتنامی',
        'vo' => 'وولاپوک',
        'vun' => 'ونجو',
        'wa' => 'والون',
        'wae' => 'والسر',
        'wal' => 'وولایتا',
        'war' => 'وارے',
        'wbp' => 'وارلپیری',
        'wo' => 'وولوف',
        'wuu' => 'وو چائینیز',
        'xal' => 'کالمیک',
        'xh' => 'ژوسا',
        'xog' => 'سوگا',
        'yav' => 'یانگبین',
        'ybb' => 'یمبا',
        'yi' => 'یدش',
        'yo' => 'یوروبا',
        'yrl' => 'نینگاٹو',
        'yue' => 'کینٹونیز',
        'zgh' => 'اسٹینڈرڈ مراقشی تمازیقی',
        'zh' => 'چینی',
        'zu' => 'زولو',
        'zun' => 'زونی',
        'zza' => 'زازا',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ماڈرن اسٹینڈرڈ عربی',
        'az_Arab' => 'آزربائیجانی (عربی)',
        'de_AT' => 'آسٹریائی جرمن',
        'de_CH' => 'سوئس ہائی جرمن',
        'en_AU' => 'آسٹریلیائی انگریزی',
        'en_CA' => 'کینیڈین انگریزی',
        'en_GB' => 'برطانوی انگریزی',
        'en_US' => 'امریکی انگریزی',
        'es_419' => 'لاطینی امریکی ہسپانوی',
        'es_ES' => 'یورپی ہسپانوی',
        'es_MX' => 'میکسیکن ہسپانوی',
        'fa_AF' => 'دری',
        'fr_CA' => 'کینیڈین فرانسیسی',
        'fr_CH' => 'سوئس فرینچ',
        'nds_NL' => 'ادنی سیکسن',
        'nl_BE' => 'فلیمِش',
        'pt_BR' => 'برازیلی پرتگالی',
        'pt_PT' => 'یورپی پرتگالی',
        'ro_MD' => 'مالدووا',
        'sw_CD' => 'کانگو سواحلی',
        'zh_Hans' => 'چینی (آسان کردہ)',
        'zh_Hant' => 'روایتی چینی',
    ],
];
