<?php

return [
    'Names' => [
        'af' => 'ئافرىكانچە',
        'af_NA' => 'ئافرىكانچە (نامىبىيە)',
        'af_ZA' => 'ئافرىكانچە (جەنۇبىي ئافرىقا)',
        'ak' => 'ئاكانچە',
        'ak_GH' => 'ئاكانچە (گانا)',
        'am' => 'ئامھارچە',
        'am_ET' => 'ئامھارچە (ئېفىيوپىيە)',
        'ar' => 'ئەرەبچە',
        'ar_001' => 'ئەرەبچە (دۇنيا)',
        'ar_AE' => 'ئەرەبچە (ئەرەب بىرلەشمە خەلىپىلىكى)',
        'ar_BH' => 'ئەرەبچە (بەھرەين)',
        'ar_DJ' => 'ئەرەبچە (جىبۇتى)',
        'ar_DZ' => 'ئەرەبچە (ئالجىرىيە)',
        'ar_EG' => 'ئەرەبچە (مىسىر)',
        'ar_EH' => 'ئەرەبچە (غەربىي ساخارا)',
        'ar_ER' => 'ئەرەبچە (ئېرىترىيە)',
        'ar_IL' => 'ئەرەبچە (ئىسرائىلىيە)',
        'ar_IQ' => 'ئەرەبچە (ئىراق)',
        'ar_JO' => 'ئەرەبچە (ئىيوردانىيە)',
        'ar_KM' => 'ئەرەبچە (كومورو)',
        'ar_KW' => 'ئەرەبچە (كۇۋەيت)',
        'ar_LB' => 'ئەرەبچە (لىۋان)',
        'ar_LY' => 'ئەرەبچە (لىۋىيە)',
        'ar_MA' => 'ئەرەبچە (ماراكەش)',
        'ar_MR' => 'ئەرەبچە (ماۋرىتانىيە)',
        'ar_OM' => 'ئەرەبچە (ئومان)',
        'ar_PS' => 'ئەرەبچە (پەلەستىن زېمىنى)',
        'ar_QA' => 'ئەرەبچە (قاتار)',
        'ar_SA' => 'ئەرەبچە (سەئۇدىي ئەرەبىستان)',
        'ar_SD' => 'ئەرەبچە (سۇدان)',
        'ar_SO' => 'ئەرەبچە (سومالى)',
        'ar_SS' => 'ئەرەبچە (جەنۇبىي سۇدان)',
        'ar_SY' => 'ئەرەبچە (سۇرىيە)',
        'ar_TD' => 'ئەرەبچە (چاد)',
        'ar_TN' => 'ئەرەبچە (تۇنىس)',
        'ar_YE' => 'ئەرەبچە (يەمەن)',
        'as' => 'ئاسامچە',
        'as_IN' => 'ئاسامچە (ھىندىستان)',
        'az' => 'ئەزەربەيجانچە',
        'az_AZ' => 'ئەزەربەيجانچە (ئەزەربەيجان)',
        'az_Cyrl' => 'ئەزەربەيجانچە (كىرىل)',
        'az_Cyrl_AZ' => 'ئەزەربەيجانچە (كىرىل، ئەزەربەيجان)',
        'az_Latn' => 'ئەزەربەيجانچە (لاتىنچە)',
        'az_Latn_AZ' => 'ئەزەربەيجانچە (لاتىنچە، ئەزەربەيجان)',
        'be' => 'بېلارۇسچە',
        'be_BY' => 'بېلارۇسچە (بېلارۇسىيە)',
        'bg' => 'بۇلغارچە',
        'bg_BG' => 'بۇلغارچە (بۇلغارىيە)',
        'bm' => 'بامباراچە',
        'bm_ML' => 'بامباراچە (مالى)',
        'bn' => 'بېنگالچە',
        'bn_BD' => 'بېنگالچە (بېنگال)',
        'bn_IN' => 'بېنگالچە (ھىندىستان)',
        'bo' => 'تىبەتچە',
        'bo_CN' => 'تىبەتچە (جۇڭگو)',
        'bo_IN' => 'تىبەتچە (ھىندىستان)',
        'br' => 'بىرېتونچە',
        'br_FR' => 'بىرېتونچە (فىرانسىيە)',
        'bs' => 'بوسىنچە',
        'bs_BA' => 'بوسىنچە (بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'bs_Cyrl' => 'بوسىنچە (كىرىل)',
        'bs_Cyrl_BA' => 'بوسىنچە (كىرىل، بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'bs_Latn' => 'بوسىنچە (لاتىنچە)',
        'bs_Latn_BA' => 'بوسىنچە (لاتىنچە، بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'ca' => 'كاتالانچە',
        'ca_AD' => 'كاتالانچە (ئاندوررا)',
        'ca_ES' => 'كاتالانچە (ئىسپانىيە)',
        'ca_FR' => 'كاتالانچە (فىرانسىيە)',
        'ca_IT' => 'كاتالانچە (ئىتالىيە)',
        'ce' => 'چېچىنچە',
        'ce_RU' => 'چېچىنچە (رۇسىيە)',
        'cs' => 'چېخچە',
        'cs_CZ' => 'چېخچە (چېخ جۇمھۇرىيىتى)',
        'cv' => 'چۇۋاشچە',
        'cv_RU' => 'چۇۋاشچە (رۇسىيە)',
        'cy' => 'ۋېلشچە',
        'cy_GB' => 'ۋېلشچە (بىرلەشمە پادىشاھلىق)',
        'da' => 'دانىشچە',
        'da_DK' => 'دانىشچە (دانىيە)',
        'da_GL' => 'دانىشچە (گىرېنلاندىيە)',
        'de' => 'گېرمانچە',
        'de_AT' => 'گېرمانچە (ئاۋىستىرىيە)',
        'de_BE' => 'گېرمانچە (بېلگىيە)',
        'de_CH' => 'گېرمانچە (شىۋېتسارىيە)',
        'de_DE' => 'گېرمانچە (گېرمانىيە)',
        'de_IT' => 'گېرمانچە (ئىتالىيە)',
        'de_LI' => 'گېرمانچە (لىكتېنستېين)',
        'de_LU' => 'گېرمانچە (لىيۇكسېمبۇرگ)',
        'dz' => 'زوڭخاچە',
        'dz_BT' => 'زوڭخاچە (بۇتان)',
        'ee' => 'ئېۋېچە',
        'ee_GH' => 'ئېۋېچە (گانا)',
        'ee_TG' => 'ئېۋېچە (توگو)',
        'el' => 'گىرېكچە',
        'el_CY' => 'گىرېكچە (سىپرۇس)',
        'el_GR' => 'گىرېكچە (گىرېتسىيە)',
        'en' => 'ئىنگلىزچە',
        'en_001' => 'ئىنگلىزچە (دۇنيا)',
        'en_150' => 'ئىنگلىزچە (ياۋروپا)',
        'en_AE' => 'ئىنگلىزچە (ئەرەب بىرلەشمە خەلىپىلىكى)',
        'en_AG' => 'ئىنگلىزچە (ئانتىگۇئا ۋە باربۇدا)',
        'en_AI' => 'ئىنگلىزچە (ئانگۋىللا)',
        'en_AS' => 'ئىنگلىزچە (ئامېرىكا ساموئا)',
        'en_AT' => 'ئىنگلىزچە (ئاۋىستىرىيە)',
        'en_AU' => 'ئىنگلىزچە (ئاۋسترالىيە)',
        'en_BB' => 'ئىنگلىزچە (باربادوس)',
        'en_BE' => 'ئىنگلىزچە (بېلگىيە)',
        'en_BI' => 'ئىنگلىزچە (بۇرۇندى)',
        'en_BM' => 'ئىنگلىزچە (بېرمۇدا)',
        'en_BS' => 'ئىنگلىزچە (باھاما)',
        'en_BW' => 'ئىنگلىزچە (بوتسۋانا)',
        'en_BZ' => 'ئىنگلىزچە (بېلىز)',
        'en_CA' => 'ئىنگلىزچە (كانادا)',
        'en_CC' => 'ئىنگلىزچە (كوكوس [كىلىڭ] ئاراللىرى)',
        'en_CH' => 'ئىنگلىزچە (شىۋېتسارىيە)',
        'en_CK' => 'ئىنگلىزچە (كۇك ئاراللىرى)',
        'en_CM' => 'ئىنگلىزچە (كامېرون)',
        'en_CX' => 'ئىنگلىزچە (مىلاد ئارىلى)',
        'en_CY' => 'ئىنگلىزچە (سىپرۇس)',
        'en_DE' => 'ئىنگلىزچە (گېرمانىيە)',
        'en_DK' => 'ئىنگلىزچە (دانىيە)',
        'en_DM' => 'ئىنگلىزچە (دومىنىكا)',
        'en_ER' => 'ئىنگلىزچە (ئېرىترىيە)',
        'en_FI' => 'ئىنگلىزچە (فىنلاندىيە)',
        'en_FJ' => 'ئىنگلىزچە (فىجى)',
        'en_FK' => 'ئىنگلىزچە (فالكلاند ئاراللىرى)',
        'en_FM' => 'ئىنگلىزچە (مىكرونېزىيە)',
        'en_GB' => 'ئىنگلىزچە (بىرلەشمە پادىشاھلىق)',
        'en_GD' => 'ئىنگلىزچە (گىرېنادا)',
        'en_GG' => 'ئىنگلىزچە (گۇرنسېي)',
        'en_GH' => 'ئىنگلىزچە (گانا)',
        'en_GI' => 'ئىنگلىزچە (جەبىلتارىق)',
        'en_GM' => 'ئىنگلىزچە (گامبىيە)',
        'en_GU' => 'ئىنگلىزچە (گۇئام)',
        'en_GY' => 'ئىنگلىزچە (گىۋىيانا)',
        'en_HK' => 'ئىنگلىزچە (شياڭگاڭ ئالاھىدە مەمۇرىي رايونى [جۇڭگو])',
        'en_IE' => 'ئىنگلىزچە (ئىرېلاندىيە)',
        'en_IL' => 'ئىنگلىزچە (ئىسرائىلىيە)',
        'en_IM' => 'ئىنگلىزچە (مان ئارىلى)',
        'en_IN' => 'ئىنگلىزچە (ھىندىستان)',
        'en_IO' => 'ئىنگلىزچە (ئەنگلىيەگە قاراشلىق ھىندى ئوكيان تېررىتورىيەسى)',
        'en_JE' => 'ئىنگلىزچە (جېرسېي)',
        'en_JM' => 'ئىنگلىزچە (يامايكا)',
        'en_KE' => 'ئىنگلىزچە (كېنىيە)',
        'en_KI' => 'ئىنگلىزچە (كىرىباتى)',
        'en_KN' => 'ئىنگلىزچە (ساينت كىتىس ۋە نېۋىس)',
        'en_KY' => 'ئىنگلىزچە (كايمان ئاراللىرى)',
        'en_LC' => 'ئىنگلىزچە (ساينت لۇسىيە)',
        'en_LR' => 'ئىنگلىزچە (لىبېرىيە)',
        'en_LS' => 'ئىنگلىزچە (لېسوتو)',
        'en_MG' => 'ئىنگلىزچە (ماداغاسقار)',
        'en_MH' => 'ئىنگلىزچە (مارشال ئاراللىرى)',
        'en_MO' => 'ئىنگلىزچە (ئاۋمېن ئالاھىدە مەمۇرىي رايونى)',
        'en_MP' => 'ئىنگلىزچە (شىمالىي مارىيانا ئاراللىرى)',
        'en_MS' => 'ئىنگلىزچە (مونتسېررات)',
        'en_MT' => 'ئىنگلىزچە (مالتا)',
        'en_MU' => 'ئىنگلىزچە (ماۋرىتىيۇس)',
        'en_MV' => 'ئىنگلىزچە (مالدىۋې)',
        'en_MW' => 'ئىنگلىزچە (مالاۋى)',
        'en_MY' => 'ئىنگلىزچە (مالايسىيا)',
        'en_NA' => 'ئىنگلىزچە (نامىبىيە)',
        'en_NF' => 'ئىنگلىزچە (نورفولك ئارىلى)',
        'en_NG' => 'ئىنگلىزچە (نىگېرىيە)',
        'en_NL' => 'ئىنگلىزچە (گوللاندىيە)',
        'en_NR' => 'ئىنگلىزچە (ناۋرۇ)',
        'en_NU' => 'ئىنگلىزچە (نيۇئې)',
        'en_NZ' => 'ئىنگلىزچە (يېڭى زېلاندىيە)',
        'en_PG' => 'ئىنگلىزچە (پاپۇئا يېڭى گىۋىنىيەسى)',
        'en_PH' => 'ئىنگلىزچە (فىلىپپىن)',
        'en_PK' => 'ئىنگلىزچە (پاكىستان)',
        'en_PN' => 'ئىنگلىزچە (پىتكايرن ئاراللىرى)',
        'en_PR' => 'ئىنگلىزچە (پۇئېرتو رىكو)',
        'en_PW' => 'ئىنگلىزچە (پالائۇ)',
        'en_RW' => 'ئىنگلىزچە (رىۋاندا)',
        'en_SB' => 'ئىنگلىزچە (سولومون ئاراللىرى)',
        'en_SC' => 'ئىنگلىزچە (سېيشېل)',
        'en_SD' => 'ئىنگلىزچە (سۇدان)',
        'en_SE' => 'ئىنگلىزچە (شىۋېتسىيە)',
        'en_SG' => 'ئىنگلىزچە (سىنگاپور)',
        'en_SH' => 'ئىنگلىزچە (ساينىت ھېلېنا)',
        'en_SI' => 'ئىنگلىزچە (سىلوۋېنىيە)',
        'en_SL' => 'ئىنگلىزچە (سېررالېئون)',
        'en_SS' => 'ئىنگلىزچە (جەنۇبىي سۇدان)',
        'en_SX' => 'ئىنگلىزچە (سىنت مارتېن)',
        'en_SZ' => 'ئىنگلىزچە (سىۋېزىلاند)',
        'en_TC' => 'ئىنگلىزچە (تۇركس ۋە كايكوس ئاراللىرى)',
        'en_TK' => 'ئىنگلىزچە (توكېلاۋ)',
        'en_TO' => 'ئىنگلىزچە (تونگا)',
        'en_TT' => 'ئىنگلىزچە (تىرىنىداد ۋە توباگو)',
        'en_TV' => 'ئىنگلىزچە (تۇۋالۇ)',
        'en_TZ' => 'ئىنگلىزچە (تانزانىيە)',
        'en_UG' => 'ئىنگلىزچە (ئۇگاندا)',
        'en_UM' => 'ئىنگلىزچە (ئا ق ش تاشقى ئاراللىرى)',
        'en_US' => 'ئىنگلىزچە (ئامېرىكا قوشما ئىشتاتلىرى)',
        'en_VC' => 'ئىنگلىزچە (ساينت ۋىنسېنت ۋە گىرېنادىنېس)',
        'en_VG' => 'ئىنگلىزچە (ئەنگلىيە ۋىرگىن ئاراللىرى)',
        'en_VI' => 'ئىنگلىزچە (ئا ق ش ۋىرگىن ئاراللىرى)',
        'en_VU' => 'ئىنگلىزچە (ۋانۇئاتۇ)',
        'en_WS' => 'ئىنگلىزچە (ساموئا)',
        'en_ZA' => 'ئىنگلىزچە (جەنۇبىي ئافرىقا)',
        'en_ZM' => 'ئىنگلىزچە (زامبىيە)',
        'en_ZW' => 'ئىنگلىزچە (زىمبابۋې)',
        'eo' => 'ئېسپرانتوچە',
        'eo_001' => 'ئېسپرانتوچە (دۇنيا)',
        'es' => 'ئىسپانچە',
        'es_419' => 'ئىسپانچە (لاتىن ئامېرىكا)',
        'es_AR' => 'ئىسپانچە (ئارگېنتىنا)',
        'es_BO' => 'ئىسپانچە (بولىۋىيە)',
        'es_BR' => 'ئىسپانچە (بىرازىلىيە)',
        'es_BZ' => 'ئىسپانچە (بېلىز)',
        'es_CL' => 'ئىسپانچە (چىلى)',
        'es_CO' => 'ئىسپانچە (كولومبىيە)',
        'es_CR' => 'ئىسپانچە (كوستارىكا)',
        'es_CU' => 'ئىسپانچە (كۇبا)',
        'es_DO' => 'ئىسپانچە (دومىنىكا جۇمھۇرىيىتى)',
        'es_EC' => 'ئىسپانچە (ئېكۋاتور)',
        'es_ES' => 'ئىسپانچە (ئىسپانىيە)',
        'es_GQ' => 'ئىسپانچە (ئېكۋاتور گىۋىنىيەسى)',
        'es_GT' => 'ئىسپانچە (گىۋاتېمالا)',
        'es_HN' => 'ئىسپانچە (ھوندۇراس)',
        'es_MX' => 'ئىسپانچە (مېكسىكا)',
        'es_NI' => 'ئىسپانچە (نىكاراگۇئا)',
        'es_PA' => 'ئىسپانچە (پاناما)',
        'es_PE' => 'ئىسپانچە (پېرۇ)',
        'es_PH' => 'ئىسپانچە (فىلىپپىن)',
        'es_PR' => 'ئىسپانچە (پۇئېرتو رىكو)',
        'es_PY' => 'ئىسپانچە (پاراگۋاي)',
        'es_SV' => 'ئىسپانچە (سالۋادور)',
        'es_US' => 'ئىسپانچە (ئامېرىكا قوشما ئىشتاتلىرى)',
        'es_UY' => 'ئىسپانچە (ئۇرۇگۋاي)',
        'es_VE' => 'ئىسپانچە (ۋېنېسۇئېلا)',
        'et' => 'ئېستونچە',
        'et_EE' => 'ئېستونچە (ئېستونىيە)',
        'eu' => 'باسكىچە',
        'eu_ES' => 'باسكىچە (ئىسپانىيە)',
        'fa' => 'پارسچە',
        'fa_AF' => 'پارسچە (ئافغانىستان)',
        'fa_IR' => 'پارسچە (ئىران)',
        'ff' => 'فۇلاھچە',
        'ff_CM' => 'فۇلاھچە (كامېرون)',
        'ff_GN' => 'فۇلاھچە (گىۋىنىيە)',
        'ff_Latn' => 'فۇلاھچە (لاتىنچە)',
        'ff_Latn_BF' => 'فۇلاھچە (لاتىنچە، بۇركىنا فاسو)',
        'ff_Latn_CM' => 'فۇلاھچە (لاتىنچە، كامېرون)',
        'ff_Latn_GH' => 'فۇلاھچە (لاتىنچە، گانا)',
        'ff_Latn_GM' => 'فۇلاھچە (لاتىنچە، گامبىيە)',
        'ff_Latn_GN' => 'فۇلاھچە (لاتىنچە، گىۋىنىيە)',
        'ff_Latn_GW' => 'فۇلاھچە (لاتىنچە، گىۋىنىيە بىسسائۇ)',
        'ff_Latn_LR' => 'فۇلاھچە (لاتىنچە، لىبېرىيە)',
        'ff_Latn_MR' => 'فۇلاھچە (لاتىنچە، ماۋرىتانىيە)',
        'ff_Latn_NE' => 'فۇلاھچە (لاتىنچە، نىگېر)',
        'ff_Latn_NG' => 'فۇلاھچە (لاتىنچە، نىگېرىيە)',
        'ff_Latn_SL' => 'فۇلاھچە (لاتىنچە، سېررالېئون)',
        'ff_Latn_SN' => 'فۇلاھچە (لاتىنچە، سېنېگال)',
        'ff_MR' => 'فۇلاھچە (ماۋرىتانىيە)',
        'ff_SN' => 'فۇلاھچە (سېنېگال)',
        'fi' => 'فىنچە',
        'fi_FI' => 'فىنچە (فىنلاندىيە)',
        'fo' => 'فائېروچە',
        'fo_DK' => 'فائېروچە (دانىيە)',
        'fo_FO' => 'فائېروچە (فارو ئاراللىرى)',
        'fr' => 'فىرانسۇزچە',
        'fr_BE' => 'فىرانسۇزچە (بېلگىيە)',
        'fr_BF' => 'فىرانسۇزچە (بۇركىنا فاسو)',
        'fr_BI' => 'فىرانسۇزچە (بۇرۇندى)',
        'fr_BJ' => 'فىرانسۇزچە (بېنىن)',
        'fr_BL' => 'فىرانسۇزچە (ساينت بارتېلېمى)',
        'fr_CA' => 'فىرانسۇزچە (كانادا)',
        'fr_CD' => 'فىرانسۇزچە (كونگو - كىنشاسا)',
        'fr_CF' => 'فىرانسۇزچە (ئوتتۇرا ئافرىقا جۇمھۇرىيىتى)',
        'fr_CG' => 'فىرانسۇزچە (كونگو - بىراززاۋىل)',
        'fr_CH' => 'فىرانسۇزچە (شىۋېتسارىيە)',
        'fr_CI' => 'فىرانسۇزچە (كوتې دې ئىۋوئىر)',
        'fr_CM' => 'فىرانسۇزچە (كامېرون)',
        'fr_DJ' => 'فىرانسۇزچە (جىبۇتى)',
        'fr_DZ' => 'فىرانسۇزچە (ئالجىرىيە)',
        'fr_FR' => 'فىرانسۇزچە (فىرانسىيە)',
        'fr_GA' => 'فىرانسۇزچە (گابون)',
        'fr_GF' => 'فىرانسۇزچە (فىرانسىيەگە قاراشلىق گىۋىيانا)',
        'fr_GN' => 'فىرانسۇزچە (گىۋىنىيە)',
        'fr_GP' => 'فىرانسۇزچە (گىۋادېلۇپ)',
        'fr_GQ' => 'فىرانسۇزچە (ئېكۋاتور گىۋىنىيەسى)',
        'fr_HT' => 'فىرانسۇزچە (ھايتى)',
        'fr_KM' => 'فىرانسۇزچە (كومورو)',
        'fr_LU' => 'فىرانسۇزچە (لىيۇكسېمبۇرگ)',
        'fr_MA' => 'فىرانسۇزچە (ماراكەش)',
        'fr_MC' => 'فىرانسۇزچە (موناكو)',
        'fr_MF' => 'فىرانسۇزچە (ساينت مارتىن)',
        'fr_MG' => 'فىرانسۇزچە (ماداغاسقار)',
        'fr_ML' => 'فىرانسۇزچە (مالى)',
        'fr_MQ' => 'فىرانسۇزچە (مارتىنىكا)',
        'fr_MR' => 'فىرانسۇزچە (ماۋرىتانىيە)',
        'fr_MU' => 'فىرانسۇزچە (ماۋرىتىيۇس)',
        'fr_NC' => 'فىرانسۇزچە (يېڭى كالېدونىيە)',
        'fr_NE' => 'فىرانسۇزچە (نىگېر)',
        'fr_PF' => 'فىرانسۇزچە (فىرانسىيەگە قاراشلىق پولىنېزىيە)',
        'fr_PM' => 'فىرانسۇزچە (ساينت پىيېر ۋە مىكېلون ئاراللىرى)',
        'fr_RE' => 'فىرانسۇزچە (رېيۇنىيون)',
        'fr_RW' => 'فىرانسۇزچە (رىۋاندا)',
        'fr_SC' => 'فىرانسۇزچە (سېيشېل)',
        'fr_SN' => 'فىرانسۇزچە (سېنېگال)',
        'fr_SY' => 'فىرانسۇزچە (سۇرىيە)',
        'fr_TD' => 'فىرانسۇزچە (چاد)',
        'fr_TG' => 'فىرانسۇزچە (توگو)',
        'fr_TN' => 'فىرانسۇزچە (تۇنىس)',
        'fr_VU' => 'فىرانسۇزچە (ۋانۇئاتۇ)',
        'fr_WF' => 'فىرانسۇزچە (ۋاللىس ۋە فۇتۇنا)',
        'fr_YT' => 'فىرانسۇزچە (مايوتى)',
        'fy' => 'غەربىي فىرسچە',
        'fy_NL' => 'غەربىي فىرسچە (گوللاندىيە)',
        'ga' => 'ئىرېلاندچە',
        'ga_GB' => 'ئىرېلاندچە (بىرلەشمە پادىشاھلىق)',
        'ga_IE' => 'ئىرېلاندچە (ئىرېلاندىيە)',
        'gd' => 'شوتلاندىيە گايلچىسى',
        'gd_GB' => 'شوتلاندىيە گايلچىسى (بىرلەشمە پادىشاھلىق)',
        'gl' => 'گالىچە',
        'gl_ES' => 'گالىچە (ئىسپانىيە)',
        'gu' => 'گۇجاراتچە',
        'gu_IN' => 'گۇجاراتچە (ھىندىستان)',
        'gv' => 'مانچە',
        'gv_IM' => 'مانچە (مان ئارىلى)',
        'ha' => 'خائۇساچە',
        'ha_GH' => 'خائۇساچە (گانا)',
        'ha_NE' => 'خائۇساچە (نىگېر)',
        'ha_NG' => 'خائۇساچە (نىگېرىيە)',
        'he' => 'ئىبرانىيچە',
        'he_IL' => 'ئىبرانىيچە (ئىسرائىلىيە)',
        'hi' => 'ھىندىچە',
        'hi_IN' => 'ھىندىچە (ھىندىستان)',
        'hi_Latn' => 'ھىندىچە (لاتىنچە)',
        'hi_Latn_IN' => 'ھىندىچە (لاتىنچە، ھىندىستان)',
        'hr' => 'كىرودىچە',
        'hr_BA' => 'كىرودىچە (بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'hr_HR' => 'كىرودىچە (كىرودىيە)',
        'hu' => 'ۋېنگىرچە',
        'hu_HU' => 'ۋېنگىرچە (ۋېنگىرىيە)',
        'hy' => 'ئەرمېنچە',
        'hy_AM' => 'ئەرمېنچە (ئەرمېنىيە)',
        'ia' => 'ئارىلىق تىل',
        'ia_001' => 'ئارىلىق تىل (دۇنيا)',
        'id' => 'ھىندونېزچە',
        'id_ID' => 'ھىندونېزچە (ھىندونېزىيە)',
        'ig' => 'ئىگبوچە',
        'ig_NG' => 'ئىگبوچە (نىگېرىيە)',
        'ii' => 'يىچە [سىچۈەن]',
        'ii_CN' => 'يىچە [سىچۈەن] (جۇڭگو)',
        'is' => 'ئىسلاندچە',
        'is_IS' => 'ئىسلاندچە (ئىسلاندىيە)',
        'it' => 'ئىتالىيانچە',
        'it_CH' => 'ئىتالىيانچە (شىۋېتسارىيە)',
        'it_IT' => 'ئىتالىيانچە (ئىتالىيە)',
        'it_SM' => 'ئىتالىيانچە (سان مارىنو)',
        'it_VA' => 'ئىتالىيانچە (ۋاتىكان)',
        'ja' => 'ياپونچە',
        'ja_JP' => 'ياپونچە (ياپونىيە)',
        'jv' => 'ياۋاچە',
        'jv_ID' => 'ياۋاچە (ھىندونېزىيە)',
        'ka' => 'گىرۇزچە',
        'ka_GE' => 'گىرۇزچە (گىرۇزىيە)',
        'ki' => 'كىكۇيۇچە',
        'ki_KE' => 'كىكۇيۇچە (كېنىيە)',
        'kk' => 'قازاقچە',
        'kk_KZ' => 'قازاقچە (قازاقىستان)',
        'kl' => 'گىرېنلاندچە',
        'kl_GL' => 'گىرېنلاندچە (گىرېنلاندىيە)',
        'km' => 'كىمېرچە',
        'km_KH' => 'كىمېرچە (كامبودژا)',
        'kn' => 'كانناداچە',
        'kn_IN' => 'كانناداچە (ھىندىستان)',
        'ko' => 'كورېيەچە',
        'ko_KP' => 'كورېيەچە (چاۋشيەن)',
        'ko_KR' => 'كورېيەچە (كورېيە)',
        'ks' => 'كەشمىرچە',
        'ks_Arab' => 'كەشمىرچە (ئەرەب)',
        'ks_Arab_IN' => 'كەشمىرچە (ئەرەب، ھىندىستان)',
        'ks_Deva' => 'كەشمىرچە (دېۋاناگارى)',
        'ks_Deva_IN' => 'كەشمىرچە (دېۋاناگارى، ھىندىستان)',
        'ks_IN' => 'كەشمىرچە (ھىندىستان)',
        'ku' => 'كۇردچە',
        'ku_TR' => 'كۇردچە (تۈركىيە)',
        'kw' => 'كورنىشچە',
        'kw_GB' => 'كورنىشچە (بىرلەشمە پادىشاھلىق)',
        'ky' => 'قىرغىزچە',
        'ky_KG' => 'قىرغىزچە (قىرغىزىستان)',
        'lb' => 'لىيۇكسېمبۇرگچە',
        'lb_LU' => 'لىيۇكسېمبۇرگچە (لىيۇكسېمبۇرگ)',
        'lg' => 'گانداچە',
        'lg_UG' => 'گانداچە (ئۇگاندا)',
        'ln' => 'لىنگالاچە',
        'ln_AO' => 'لىنگالاچە (ئانگولا)',
        'ln_CD' => 'لىنگالاچە (كونگو - كىنشاسا)',
        'ln_CF' => 'لىنگالاچە (ئوتتۇرا ئافرىقا جۇمھۇرىيىتى)',
        'ln_CG' => 'لىنگالاچە (كونگو - بىراززاۋىل)',
        'lo' => 'لائوسچە',
        'lo_LA' => 'لائوسچە (لائوس)',
        'lt' => 'لىتۋانىچە',
        'lt_LT' => 'لىتۋانىچە (لىتۋانىيە)',
        'lu' => 'لۇبا-كاتانگاچە',
        'lu_CD' => 'لۇبا-كاتانگاچە (كونگو - كىنشاسا)',
        'lv' => 'لاتچە',
        'lv_LV' => 'لاتچە (لاتۋىيە)',
        'mg' => 'مالاگاسچە',
        'mg_MG' => 'مالاگاسچە (ماداغاسقار)',
        'mi' => 'ماۋرىچە',
        'mi_NZ' => 'ماۋرىچە (يېڭى زېلاندىيە)',
        'mk' => 'ماكېدونچە',
        'mk_MK' => 'ماكېدونچە (شىمالىي ماكېدونىيە)',
        'ml' => 'مالايالامچە',
        'ml_IN' => 'مالايالامچە (ھىندىستان)',
        'mn' => 'موڭغۇلچە',
        'mn_MN' => 'موڭغۇلچە (موڭغۇلىيە)',
        'mr' => 'ماراتىچە',
        'mr_IN' => 'ماراتىچە (ھىندىستان)',
        'ms' => 'مالايچە',
        'ms_BN' => 'مالايچە (بىرۇنېي)',
        'ms_ID' => 'مالايچە (ھىندونېزىيە)',
        'ms_MY' => 'مالايچە (مالايسىيا)',
        'ms_SG' => 'مالايچە (سىنگاپور)',
        'mt' => 'مالتاچە',
        'mt_MT' => 'مالتاچە (مالتا)',
        'my' => 'بىرماچە',
        'my_MM' => 'بىرماچە (بىرما)',
        'nb' => 'نورۋىگىيە بوكمالچە',
        'nb_NO' => 'نورۋىگىيە بوكمالچە (نورۋېگىيە)',
        'nb_SJ' => 'نورۋىگىيە بوكمالچە (سىۋالبارد ۋە يان مايېن)',
        'nd' => 'شىمالى ندەبەلەچە',
        'nd_ZW' => 'شىمالى ندەبەلەچە (زىمبابۋې)',
        'ne' => 'نېپالچە',
        'ne_IN' => 'نېپالچە (ھىندىستان)',
        'ne_NP' => 'نېپالچە (نېپال)',
        'nl' => 'گوللاندچە',
        'nl_AW' => 'گوللاندچە (ئارۇبا)',
        'nl_BE' => 'گوللاندچە (بېلگىيە)',
        'nl_BQ' => 'گوللاندچە (كارىب دېڭىزى گوللاندىيە)',
        'nl_CW' => 'گوللاندچە (كۇراچاۋ)',
        'nl_NL' => 'گوللاندچە (گوللاندىيە)',
        'nl_SR' => 'گوللاندچە (سۇرىنام)',
        'nl_SX' => 'گوللاندچە (سىنت مارتېن)',
        'nn' => 'يېڭى نورۋېگچە',
        'nn_NO' => 'يېڭى نورۋېگچە (نورۋېگىيە)',
        'no' => 'نورۋېگچە',
        'no_NO' => 'نورۋېگچە (نورۋېگىيە)',
        'om' => 'ئوروموچە',
        'om_ET' => 'ئوروموچە (ئېفىيوپىيە)',
        'om_KE' => 'ئوروموچە (كېنىيە)',
        'or' => 'ئودىياچە',
        'or_IN' => 'ئودىياچە (ھىندىستان)',
        'os' => 'ئوسسېتچەچە',
        'os_GE' => 'ئوسسېتچەچە (گىرۇزىيە)',
        'os_RU' => 'ئوسسېتچەچە (رۇسىيە)',
        'pa' => 'پەنجابچە',
        'pa_Arab' => 'پەنجابچە (ئەرەب)',
        'pa_Arab_PK' => 'پەنجابچە (ئەرەب، پاكىستان)',
        'pa_Guru' => 'پەنجابچە (گۇرمۇكىچە)',
        'pa_Guru_IN' => 'پەنجابچە (گۇرمۇكىچە، ھىندىستان)',
        'pa_IN' => 'پەنجابچە (ھىندىستان)',
        'pa_PK' => 'پەنجابچە (پاكىستان)',
        'pl' => 'پولەكچە',
        'pl_PL' => 'پولەكچە (پولشا)',
        'ps' => 'پۇشتۇچە',
        'ps_AF' => 'پۇشتۇچە (ئافغانىستان)',
        'ps_PK' => 'پۇشتۇچە (پاكىستان)',
        'pt' => 'پورتۇگالچە',
        'pt_AO' => 'پورتۇگالچە (ئانگولا)',
        'pt_BR' => 'پورتۇگالچە (بىرازىلىيە)',
        'pt_CH' => 'پورتۇگالچە (شىۋېتسارىيە)',
        'pt_CV' => 'پورتۇگالچە (يېشىل تۇمشۇق)',
        'pt_GQ' => 'پورتۇگالچە (ئېكۋاتور گىۋىنىيەسى)',
        'pt_GW' => 'پورتۇگالچە (گىۋىنىيە بىسسائۇ)',
        'pt_LU' => 'پورتۇگالچە (لىيۇكسېمبۇرگ)',
        'pt_MO' => 'پورتۇگالچە (ئاۋمېن ئالاھىدە مەمۇرىي رايونى)',
        'pt_MZ' => 'پورتۇگالچە (موزامبىك)',
        'pt_PT' => 'پورتۇگالچە (پورتۇگالىيە)',
        'pt_ST' => 'پورتۇگالچە (سان تومې ۋە پرىنسىپې)',
        'pt_TL' => 'پورتۇگالچە (شەرقىي تىمور)',
        'qu' => 'كېچىۋاچە',
        'qu_BO' => 'كېچىۋاچە (بولىۋىيە)',
        'qu_EC' => 'كېچىۋاچە (ئېكۋاتور)',
        'qu_PE' => 'كېچىۋاچە (پېرۇ)',
        'rm' => 'رومانسچە',
        'rm_CH' => 'رومانسچە (شىۋېتسارىيە)',
        'rn' => 'رۇندىچە',
        'rn_BI' => 'رۇندىچە (بۇرۇندى)',
        'ro' => 'رومىنچە',
        'ro_MD' => 'رومىنچە (مولدوۋا)',
        'ro_RO' => 'رومىنچە (رومىنىيە)',
        'ru' => 'رۇسچە',
        'ru_BY' => 'رۇسچە (بېلارۇسىيە)',
        'ru_KG' => 'رۇسچە (قىرغىزىستان)',
        'ru_KZ' => 'رۇسچە (قازاقىستان)',
        'ru_MD' => 'رۇسچە (مولدوۋا)',
        'ru_RU' => 'رۇسچە (رۇسىيە)',
        'ru_UA' => 'رۇسچە (ئۇكرائىنا)',
        'rw' => 'كېنىيەرىۋانداچە',
        'rw_RW' => 'كېنىيەرىۋانداچە (رىۋاندا)',
        'sa' => 'سانسكرىتچە',
        'sa_IN' => 'سانسكرىتچە (ھىندىستان)',
        'sc' => 'ساردىنىيەچە',
        'sc_IT' => 'ساردىنىيەچە (ئىتالىيە)',
        'sd' => 'سىندىچە',
        'sd_Arab' => 'سىندىچە (ئەرەب)',
        'sd_Arab_PK' => 'سىندىچە (ئەرەب، پاكىستان)',
        'sd_Deva' => 'سىندىچە (دېۋاناگارى)',
        'sd_Deva_IN' => 'سىندىچە (دېۋاناگارى، ھىندىستان)',
        'sd_IN' => 'سىندىچە (ھىندىستان)',
        'sd_PK' => 'سىندىچە (پاكىستان)',
        'se' => 'شىمالىي سامىچە',
        'se_FI' => 'شىمالىي سامىچە (فىنلاندىيە)',
        'se_NO' => 'شىمالىي سامىچە (نورۋېگىيە)',
        'se_SE' => 'شىمالىي سامىچە (شىۋېتسىيە)',
        'sg' => 'سانگوچە',
        'sg_CF' => 'سانگوچە (ئوتتۇرا ئافرىقا جۇمھۇرىيىتى)',
        'sh' => 'سېرب-كرودىيەچە',
        'sh_BA' => 'سېرب-كرودىيەچە (بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'si' => 'سىنگالچە',
        'si_LK' => 'سىنگالچە (سىرىلانكا)',
        'sk' => 'سىلوۋاكچە',
        'sk_SK' => 'سىلوۋاكچە (سىلوۋاكىيە)',
        'sl' => 'سىلوۋېنچە',
        'sl_SI' => 'سىلوۋېنچە (سىلوۋېنىيە)',
        'sn' => 'شوناچە',
        'sn_ZW' => 'شوناچە (زىمبابۋې)',
        'so' => 'سومالىچە',
        'so_DJ' => 'سومالىچە (جىبۇتى)',
        'so_ET' => 'سومالىچە (ئېفىيوپىيە)',
        'so_KE' => 'سومالىچە (كېنىيە)',
        'so_SO' => 'سومالىچە (سومالى)',
        'sq' => 'ئالبانچە',
        'sq_AL' => 'ئالبانچە (ئالبانىيە)',
        'sq_MK' => 'ئالبانچە (شىمالىي ماكېدونىيە)',
        'sr' => 'سېربچە',
        'sr_BA' => 'سېربچە (بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'sr_Cyrl' => 'سېربچە (كىرىل)',
        'sr_Cyrl_BA' => 'سېربچە (كىرىل، بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'sr_Cyrl_ME' => 'سېربچە (كىرىل، قارا تاغ)',
        'sr_Cyrl_RS' => 'سېربچە (كىرىل، سېربىيە)',
        'sr_Latn' => 'سېربچە (لاتىنچە)',
        'sr_Latn_BA' => 'سېربچە (لاتىنچە، بوسىنىيە ۋە گېرتسېگوۋىنا)',
        'sr_Latn_ME' => 'سېربچە (لاتىنچە، قارا تاغ)',
        'sr_Latn_RS' => 'سېربچە (لاتىنچە، سېربىيە)',
        'sr_ME' => 'سېربچە (قارا تاغ)',
        'sr_RS' => 'سېربچە (سېربىيە)',
        'su' => 'سۇنداچە',
        'su_ID' => 'سۇنداچە (ھىندونېزىيە)',
        'su_Latn' => 'سۇنداچە (لاتىنچە)',
        'su_Latn_ID' => 'سۇنداچە (لاتىنچە، ھىندونېزىيە)',
        'sv' => 'شىۋېدچە',
        'sv_AX' => 'شىۋېدچە (ئالاند ئاراللىرى)',
        'sv_FI' => 'شىۋېدچە (فىنلاندىيە)',
        'sv_SE' => 'شىۋېدچە (شىۋېتسىيە)',
        'sw' => 'سىۋاھىلچە',
        'sw_CD' => 'سىۋاھىلچە (كونگو - كىنشاسا)',
        'sw_KE' => 'سىۋاھىلچە (كېنىيە)',
        'sw_TZ' => 'سىۋاھىلچە (تانزانىيە)',
        'sw_UG' => 'سىۋاھىلچە (ئۇگاندا)',
        'ta' => 'تامىلچە',
        'ta_IN' => 'تامىلچە (ھىندىستان)',
        'ta_LK' => 'تامىلچە (سىرىلانكا)',
        'ta_MY' => 'تامىلچە (مالايسىيا)',
        'ta_SG' => 'تامىلچە (سىنگاپور)',
        'te' => 'تېلۇگۇچە',
        'te_IN' => 'تېلۇگۇچە (ھىندىستان)',
        'tg' => 'تاجىكچە',
        'tg_TJ' => 'تاجىكچە (تاجىكىستان)',
        'th' => 'تايلاندچە',
        'th_TH' => 'تايلاندچە (تايلاند)',
        'ti' => 'تىگرىنياچە',
        'ti_ER' => 'تىگرىنياچە (ئېرىترىيە)',
        'ti_ET' => 'تىگرىنياچە (ئېفىيوپىيە)',
        'tk' => 'تۈركمەنچە',
        'tk_TM' => 'تۈركمەنچە (تۈركمەنىستان)',
        'tl' => 'تاگالوگچە',
        'tl_PH' => 'تاگالوگچە (فىلىپپىن)',
        'to' => 'تونگانچە',
        'to_TO' => 'تونگانچە (تونگا)',
        'tr' => 'تۈركچە',
        'tr_CY' => 'تۈركچە (سىپرۇس)',
        'tr_TR' => 'تۈركچە (تۈركىيە)',
        'tt' => 'تاتارچە',
        'tt_RU' => 'تاتارچە (رۇسىيە)',
        'ug' => 'ئۇيغۇرچە',
        'ug_CN' => 'ئۇيغۇرچە (جۇڭگو)',
        'uk' => 'ئۇكرائىنچە',
        'uk_UA' => 'ئۇكرائىنچە (ئۇكرائىنا)',
        'ur' => 'ئوردۇچە',
        'ur_IN' => 'ئوردۇچە (ھىندىستان)',
        'ur_PK' => 'ئوردۇچە (پاكىستان)',
        'uz' => 'ئۆزبېكچە',
        'uz_AF' => 'ئۆزبېكچە (ئافغانىستان)',
        'uz_Arab' => 'ئۆزبېكچە (ئەرەب)',
        'uz_Arab_AF' => 'ئۆزبېكچە (ئەرەب، ئافغانىستان)',
        'uz_Cyrl' => 'ئۆزبېكچە (كىرىل)',
        'uz_Cyrl_UZ' => 'ئۆزبېكچە (كىرىل، ئۆزبېكىستان)',
        'uz_Latn' => 'ئۆزبېكچە (لاتىنچە)',
        'uz_Latn_UZ' => 'ئۆزبېكچە (لاتىنچە، ئۆزبېكىستان)',
        'uz_UZ' => 'ئۆزبېكچە (ئۆزبېكىستان)',
        'vi' => 'ۋىيېتنامچە',
        'vi_VN' => 'ۋىيېتنامچە (ۋىيېتنام)',
        'wo' => 'ۋولوفچە',
        'wo_SN' => 'ۋولوفچە (سېنېگال)',
        'xh' => 'خوساچە',
        'xh_ZA' => 'خوساچە (جەنۇبىي ئافرىقا)',
        'yi' => 'يىددىشچە',
        'yi_001' => 'يىددىشچە (دۇنيا)',
        'yo' => 'يورۇباچە',
        'yo_BJ' => 'يورۇباچە (بېنىن)',
        'yo_NG' => 'يورۇباچە (نىگېرىيە)',
        'zh' => 'خەنزۇچە',
        'zh_CN' => 'خەنزۇچە (جۇڭگو)',
        'zh_HK' => 'خەنزۇچە (شياڭگاڭ ئالاھىدە مەمۇرىي رايونى [جۇڭگو])',
        'zh_Hans' => 'خەنزۇچە (ئاددىي خەنچە)',
        'zh_Hans_CN' => 'خەنزۇچە (ئاددىي خەنچە، جۇڭگو)',
        'zh_Hans_HK' => 'خەنزۇچە (ئاددىي خەنچە، شياڭگاڭ ئالاھىدە مەمۇرىي رايونى [جۇڭگو])',
        'zh_Hans_MO' => 'خەنزۇچە (ئاددىي خەنچە، ئاۋمېن ئالاھىدە مەمۇرىي رايونى)',
        'zh_Hans_SG' => 'خەنزۇچە (ئاددىي خەنچە، سىنگاپور)',
        'zh_Hant' => 'خەنزۇچە (مۇرەككەپ خەنچە)',
        'zh_Hant_HK' => 'خەنزۇچە (مۇرەككەپ خەنچە، شياڭگاڭ ئالاھىدە مەمۇرىي رايونى [جۇڭگو])',
        'zh_Hant_MO' => 'خەنزۇچە (مۇرەككەپ خەنچە، ئاۋمېن ئالاھىدە مەمۇرىي رايونى)',
        'zh_Hant_TW' => 'خەنزۇچە (مۇرەككەپ خەنچە، تەيۋەن)',
        'zh_MO' => 'خەنزۇچە (ئاۋمېن ئالاھىدە مەمۇرىي رايونى)',
        'zh_SG' => 'خەنزۇچە (سىنگاپور)',
        'zh_TW' => 'خەنزۇچە (تەيۋەن)',
        'zu' => 'زۇلۇچە',
        'zu_ZA' => 'زۇلۇچە (جەنۇبىي ئافرىقا)',
    ],
];
