<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'peseta andorrane',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham des Émirats arabes unis',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afghani afghan',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'lek albanais (1947–1961)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albanais',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'dram arménien',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'florin antillais',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolais',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'kwanza angolais (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'nouveau kwanza angolais (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'kwanza angolais réajusté (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'austral argentin',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'peso argentin (1983–1985)',
        ],
        'ARS' => [
            0 => '$AR',
            1 => 'peso argentin',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'schilling autrichien',
        ],
        'AUD' => [
            0 => '$AU',
            1 => 'dollar australien',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'florin arubais',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'manat azéri (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat azéri',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'dinar bosniaque',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'mark convertible bosniaque',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dollar barbadien',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'taka bangladeshi',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'franc belge (convertible)',
        ],
        'BEF' => [
            0 => 'FB',
            1 => 'franc belge',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'franc belge (financier)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'lev bulgare (1962–1999)',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lev bulgare',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinar bahreïni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'franc burundais',
        ],
        'BMD' => [
            0 => '$BM',
            1 => 'dollar bermudien',
        ],
        'BND' => [
            0 => '$BN',
            1 => 'dollar brunéien',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviano bolivien',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'peso bolivien',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'mvdol bolivien',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'nouveau cruzeiro brésilien (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'cruzado brésilien (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'cruzeiro brésilien (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'réal brésilien',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'nouveau cruzado',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'cruzeiro',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dollar bahaméen',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ngultrum bouthanais',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'kyat birman',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula botswanais',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'nouveau rouble biélorusse (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rouble biélorusse',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'rouble biélorusse (2000–2016)',
        ],
        'BZD' => [
            0 => '$BZ',
            1 => 'dollar bélizéen',
        ],
        'CAD' => [
            0 => '$CA',
            1 => 'dollar canadien',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'franc congolais',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'euro WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'franc suisse',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'franc WIR',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'unité d’investissement chilienne',
        ],
        'CLP' => [
            0 => '$CL',
            1 => 'peso chilien',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'yuan chinois (zone extracôtière)',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'yuan renminbi chinois',
        ],
        'COP' => [
            0 => '$CO',
            1 => 'peso colombien',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'unité de valeur réelle colombienne',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colón costaricain',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'dinar serbo-monténégrin',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'couronne forte tchécoslovaque',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso cubain convertible',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso cubain',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo capverdien',
        ],
        'CYP' => [
            0 => '£CY',
            1 => 'livre chypriote',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'couronne tchèque',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'mark est-allemand',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'mark allemand',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'franc djiboutien',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'couronne danoise',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominicain',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinar algérien',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'sucre équatorien',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'unité de valeur constante équatoriale (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'couronne estonienne',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'livre égyptienne',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nafka érythréen',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'peseta espagnole (compte A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'peseta espagnole (compte convertible)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'peseta espagnole',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr éthiopien',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'mark finlandais',
        ],
        'FJD' => [
            0 => '$FJ',
            1 => 'dollar fidjien',
        ],
        'FKP' => [
            0 => '£FK',
            1 => 'livre des îles Malouines',
        ],
        'FRF' => [
            0 => 'F',
            1 => 'franc français',
        ],
        'GBP' => [
            0 => '£GB',
            1 => 'livre sterling',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'coupon de lari géorgien',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'lari géorgien',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'cédi',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cédi ghanéen',
        ],
        'GIP' => [
            0 => '£GI',
            1 => 'livre de Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambien',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'franc guinéen',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'syli guinéen',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekwélé équatoguinéen',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'drachme grecque',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal guatémaltèque',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'escudo de Guinée portugaise',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'peso bissau-guinéen',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dollar du Guyana',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'dollar de Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira hondurien',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'dinar croate',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna croate',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haïtienne',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'forint hongrois',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'roupie indonésienne',
        ],
        'IEP' => [
            0 => '£IE',
            1 => 'livre irlandaise',
        ],
        'ILP' => [
            0 => '£IL',
            1 => 'livre israélienne',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'nouveau shekel israélien',
        ],
        'INR' => [
            0 => '₹',
            1 => 'roupie indienne',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'dinar irakien',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'riyal iranien',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'couronne islandaise',
        ],
        'ITL' => [
            0 => '₤IT',
            1 => 'lire italienne',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dollar jamaïcain',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'dinar jordanien',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'yen japonais',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'shilling kényan',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'som kirghize',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'riel cambodgien',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'franc comorien',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'won nord-coréen',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'won sud-coréen',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'dinar koweïtien',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dollar des îles Caïmans',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'tenge kazakh',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip loatien',
        ],
        'LBP' => [
            0 => '£LB',
            1 => 'livre libanaise',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'roupie srilankaise',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dollar libérien',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti lesothan',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litas lituanien',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'talonas lituanien',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'franc convertible luxembourgeois',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'franc luxembourgeois',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'franc financier luxembourgeois',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'lats letton',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'rouble letton',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinar libyen',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marocain',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'franc marocain',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'leu moldave',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary malgache',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'franc malgache',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'denar macédonien',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'franc malien',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'kyat myanmarais',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'tugrik mongol',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'pataca macanaise',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ouguiya mauritanien (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ouguiya mauritanien',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'lire maltaise',
        ],
        'MTP' => [
            0 => '£MT',
            1 => 'livre maltaise',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'roupie mauricienne',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'rufiyaa maldivien',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha malawite',
        ],
        'MXN' => [
            0 => '$MX',
            1 => 'peso mexicain',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'peso d’argent mexicain (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'unité de conversion mexicaine (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'ringgit malais',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'escudo mozambicain',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'métical',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical mozambicain',
        ],
        'NAD' => [
            0 => '$NA',
            1 => 'dollar namibien',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nigérian',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'cordoba',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'córdoba oro nicaraguayen',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'florin néerlandais',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'couronne norvégienne',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'roupie népalaise',
        ],
        'NZD' => [
            0 => '$NZ',
            1 => 'dollar néo-zélandais',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'riyal omanais',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa panaméen',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'inti péruvien',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol péruvien',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'sol péruvien (1863–1985)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina papouan-néo-guinéen',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'peso philippin',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'roupie pakistanaise',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'zloty polonais',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'escudo portugais',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guaraní paraguayen',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'riyal qatari',
        ],
        'RHD' => [
            0 => '$RH',
            1 => 'dollar rhodésien',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'ancien leu roumain',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'leu roumain',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinar serbe',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rouble russe',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'rouble russe (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'franc rwandais',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'riyal saoudien',
        ],
        'SBD' => [
            0 => '$SB',
            1 => 'dollar des îles Salomon',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'roupie des Seychelles',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'dinar soudanais',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'livre soudanaise',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'livre soudanaise (1956–2007)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'couronne suédoise',
        ],
        'SGD' => [
            0 => '$SG',
            1 => 'dollar de Singapour',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'livre de Sainte-Hélène',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'tolar slovène',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'couronne slovaque',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone sierra-léonais',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'shilling somalien',
        ],
        'SRD' => [
            0 => '$SR',
            1 => 'dollar surinamais',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'florin surinamais',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'livre sud-soudanaise',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra santoméen (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra santoméen',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'rouble soviétique',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'colón salvadorien',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'livre syrienne',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni swazi',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'baht thaïlandais',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'rouble tadjik',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'somoni tadjik',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'manat turkmène',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'nouveau manat turkmène',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinar tunisien',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'pa’anga tongan',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'escudo timorais',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'livre turque (1844–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'livre turque',
        ],
        'TTD' => [
            0 => '$TT',
            1 => 'dollar de Trinité-et-Tobago',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'nouveau dollar taïwanais',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'shilling tanzanien',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'hryvnia ukrainienne',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'shilling ougandais (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'shilling ougandais',
        ],
        'USD' => [
            0 => '$US',
            1 => 'dollar des États-Unis',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'dollar des Etats-Unis (jour suivant)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'dollar des Etats-Unis (jour même)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'peso uruguayen (unités indexées)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'peso uruguayen (1975–1993)',
        ],
        'UYU' => [
            0 => '$UY',
            1 => 'peso uruguayen',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'sum ouzbek',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'bolivar vénézuélien (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'bolivar vénézuélien (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'bolivar vénézuélien',
        ],
        'VND' => [
            0 => '₫',
            1 => 'dông vietnamien',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu vanuatuan',
        ],
        'WST' => [
            0 => '$WS',
            1 => 'tala samoan',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'franc CFA (BEAC)',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'dollar des Caraïbes orientales',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'unité de compte européenne (ECU)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'franc or',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'franc UIC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'franc CFA (BCEAO)',
        ],
        'XPF' => [
            0 => 'FCFP',
            1 => 'franc CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'type de fonds RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'dinar du Yémen',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'riyal yéménite',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'nouveau dinar yougoslave',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'dinar yougoslave Noviy',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'dinar yougoslave convertible',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'rand sud-africain (financier)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand sud-africain',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'kwacha zambien (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha zambien',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'nouveau zaïre zaïrien',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zaïre zaïrois',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'dollar zimbabwéen',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'dollar zimbabwéen (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'dollar zimbabwéen (2008)',
        ],
    ],
];
