<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Oge Mpaghara Greemwich Mean (Abidjan)',
        'Africa/Accra' => 'Oge Mpaghara Greemwich Mean (Accra)',
        'Africa/Addis_Ababa' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Addis Ababa)',
        'Africa/Algiers' => 'Oge Mpaghara Etiti Europe (Algiers)',
        'Africa/Asmera' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Asmara)',
        'Africa/Bamako' => 'Oge Mpaghara Greemwich Mean (Bamako)',
        'Africa/Bangui' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Bangui)',
        'Africa/Banjul' => 'Oge Mpaghara Greemwich Mean (Banjul)',
        'Africa/Bissau' => 'Oge Mpaghara Greemwich Mean (Bissau)',
        'Africa/Blantyre' => 'Oge Etiti Afrịka (Blantyre)',
        'Africa/Brazzaville' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Brazzaville)',
        'Africa/Bujumbura' => 'Oge Etiti Afrịka (Bujumbura)',
        'Africa/Cairo' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Cairo)',
        'Africa/Casablanca' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (Casablanca)',
        'Africa/Ceuta' => 'Oge Mpaghara Etiti Europe (Ceuta)',
        'Africa/Conakry' => 'Oge Mpaghara Greemwich Mean (Conakry)',
        'Africa/Dakar' => 'Oge Mpaghara Greemwich Mean (Dakar)',
        'Africa/Dar_es_Salaam' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Dar es Salaam)',
        'Africa/Djibouti' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Djibouti)',
        'Africa/Douala' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Douala)',
        'Africa/El_Aaiun' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (El Aaiun)',
        'Africa/Freetown' => 'Oge Mpaghara Greemwich Mean (Freetown)',
        'Africa/Gaborone' => 'Oge Etiti Afrịka (Gaborone)',
        'Africa/Harare' => 'Oge Etiti Afrịka (Harare)',
        'Africa/Johannesburg' => 'Oge Izugbe Mpaghara Mgbada Ugwu Afrịka (Johannesburg)',
        'Africa/Juba' => 'Oge Etiti Afrịka (Juba)',
        'Africa/Kampala' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Kampala)',
        'Africa/Khartoum' => 'Oge Etiti Afrịka (Khartoum)',
        'Africa/Kigali' => 'Oge Etiti Afrịka (Kigali)',
        'Africa/Kinshasa' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Kinshasa)',
        'Africa/Lagos' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Lagos)',
        'Africa/Libreville' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Libreville)',
        'Africa/Lome' => 'Oge Mpaghara Greemwich Mean (Lome)',
        'Africa/Luanda' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Luanda)',
        'Africa/Lubumbashi' => 'Oge Etiti Afrịka (Lubumbashi)',
        'Africa/Lusaka' => 'Oge Etiti Afrịka (Lusaka)',
        'Africa/Malabo' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Malabo)',
        'Africa/Maputo' => 'Oge Etiti Afrịka (Maputo)',
        'Africa/Maseru' => 'Oge Izugbe Mpaghara Mgbada Ugwu Afrịka (Maseru)',
        'Africa/Mbabane' => 'Oge Izugbe Mpaghara Mgbada Ugwu Afrịka (Mbabane)',
        'Africa/Mogadishu' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Mogadishu)',
        'Africa/Monrovia' => 'Oge Mpaghara Greemwich Mean (Monrovia)',
        'Africa/Nairobi' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Nairobi)',
        'Africa/Ndjamena' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Ndjamena)',
        'Africa/Niamey' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Niamey)',
        'Africa/Nouakchott' => 'Oge Mpaghara Greemwich Mean (Nouakchott)',
        'Africa/Ouagadougou' => 'Oge Mpaghara Greemwich Mean (Ouagadougou)',
        'Africa/Porto-Novo' => 'Oge Mpaghara Ọdịda Anyanwụ Afrịka (Porto-Novo)',
        'Africa/Sao_Tome' => 'Oge Mpaghara Greemwich Mean (Sao Tome)',
        'Africa/Tripoli' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Tripoli)',
        'Africa/Tunis' => 'Oge Mpaghara Etiti Europe (Tunis)',
        'Africa/Windhoek' => 'Oge Etiti Afrịka (Windhoek)',
        'America/Adak' => 'Oge Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Oge Alaska (Anchorage)',
        'America/Anguilla' => 'Oge Mpaghara Atlantic (Anguilla)',
        'America/Antigua' => 'Oge Mpaghara Atlantic (Antigua)',
        'America/Araguaina' => 'Oge Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'Oge Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Oge Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Oge Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Oge Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Oge Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Oge Argentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'Oge Argentina (Ushuaia)',
        'America/Aruba' => 'Oge Mpaghara Atlantic (Aruba)',
        'America/Asuncion' => 'Oge Paraguay (Asuncion)',
        'America/Bahia' => 'Oge Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Oge Mpaghara Etiti (Bahia Banderas)',
        'America/Barbados' => 'Oge Mpaghara Atlantic (Barbados)',
        'America/Belem' => 'Oge Brasilia (Belem)',
        'America/Belize' => 'Oge Mpaghara Etiti (Belize)',
        'America/Blanc-Sablon' => 'Oge Mpaghara Atlantic (Blanc-Sablon)',
        'America/Boa_Vista' => 'Oge Amazon (Boa Vista)',
        'America/Bogota' => 'Oge Columbia (Bogota)',
        'America/Boise' => 'Oge Mpaghara Ugwu (Boise)',
        'America/Buenos_Aires' => 'Oge Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Oge Mpaghara Ugwu (Cambridge Bay)',
        'America/Campo_Grande' => 'Oge Amazon (Campo Grande)',
        'America/Cancun' => 'Oge Mpaghara Ọwụwa Anyanwụ (Cancun)',
        'America/Caracas' => 'Oge Venezuela (Caracas)',
        'America/Catamarca' => 'Oge Argentina (Catamarca)',
        'America/Cayenne' => 'Oge French Guiana (Cayenne)',
        'America/Cayman' => 'Oge Mpaghara Ọwụwa Anyanwụ (Cayman)',
        'America/Chicago' => 'Oge Mpaghara Etiti (Chicago)',
        'America/Chihuahua' => 'Oge Mexican Pacific (Chihuahua)',
        'America/Coral_Harbour' => 'Oge Mpaghara Ọwụwa Anyanwụ (Atikokan)',
        'America/Cordoba' => 'Oge Argentina (Cordoba)',
        'America/Costa_Rica' => 'Oge Mpaghara Etiti (Costa Rica)',
        'America/Creston' => 'Oge Mpaghara Ugwu (Creston)',
        'America/Cuiaba' => 'Oge Amazon (Cuiaba)',
        'America/Curacao' => 'Oge Mpaghara Atlantic (Curacao)',
        'America/Danmarkshavn' => 'Oge Mpaghara Greemwich Mean (Danmarkshavn)',
        'America/Dawson' => 'Oge Yukon (Dawson)',
        'America/Dawson_Creek' => 'Oge Mpaghara Ugwu (Dawson Creek)',
        'America/Denver' => 'Oge Mpaghara Ugwu (Denver)',
        'America/Detroit' => 'Oge Mpaghara Ọwụwa Anyanwụ (Detroit)',
        'America/Dominica' => 'Oge Mpaghara Atlantic (Dominica)',
        'America/Edmonton' => 'Oge Mpaghara Ugwu (Edmonton)',
        'America/Eirunepe' => 'Oge Brazil (Eirunepe)',
        'America/El_Salvador' => 'Oge Mpaghara Etiti (El Salvador)',
        'America/Fort_Nelson' => 'Oge Mpaghara Ugwu (Fort Nelson)',
        'America/Fortaleza' => 'Oge Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Oge Mpaghara Atlantic (Glace Bay)',
        'America/Godthab' => 'Oge Mpaghara Ọdịda Anyanwụ Greenland (Nuuk)',
        'America/Goose_Bay' => 'Oge Mpaghara Atlantic (Goose Bay)',
        'America/Grand_Turk' => 'Oge Mpaghara Ọwụwa Anyanwụ (Grand Turk)',
        'America/Grenada' => 'Oge Mpaghara Atlantic (Grenada)',
        'America/Guadeloupe' => 'Oge Mpaghara Atlantic (Guadeloupe)',
        'America/Guatemala' => 'Oge Mpaghara Etiti (Guatemala)',
        'America/Guayaquil' => 'Oge Ecuador (Guayaquil)',
        'America/Guyana' => 'Oge Guyana',
        'America/Halifax' => 'Oge Mpaghara Atlantic (Halifax)',
        'America/Havana' => 'Oge Cuba (Havana)',
        'America/Hermosillo' => 'Oge Mexican Pacific (Hermosillo)',
        'America/Indiana/Knox' => 'Oge Mpaghara Etiti (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Oge Mpaghara Ọwụwa Anyanwụ (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Oge Mpaghara Ọwụwa Anyanwụ (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Oge Mpaghara Etiti (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Oge Mpaghara Ọwụwa Anyanwụ (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Oge Mpaghara Ọwụwa Anyanwụ (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Oge Mpaghara Ọwụwa Anyanwụ (Winamac, Indiana)',
        'America/Indianapolis' => 'Oge Mpaghara Ọwụwa Anyanwụ (Indianapolis)',
        'America/Inuvik' => 'Oge Mpaghara Ugwu (Inuvik)',
        'America/Iqaluit' => 'Oge Mpaghara Ọwụwa Anyanwụ (Iqaluit)',
        'America/Jamaica' => 'Oge Mpaghara Ọwụwa Anyanwụ (Jamaica)',
        'America/Jujuy' => 'Oge Argentina (Jujuy)',
        'America/Juneau' => 'Oge Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Oge Mpaghara Ọwụwa Anyanwụ (Monticello, Kentucky)',
        'America/Kralendijk' => 'Oge Mpaghara Atlantic (Kralendijk)',
        'America/La_Paz' => 'Oge Bolivia (La Paz)',
        'America/Lima' => 'Oge Peru (Lima)',
        'America/Los_Angeles' => 'Oge Mpaghara Pacific (Los Angeles)',
        'America/Louisville' => 'Oge Mpaghara Ọwụwa Anyanwụ (Louisville)',
        'America/Lower_Princes' => 'Oge Mpaghara Atlantic (Lower Prince’s Quarter)',
        'America/Maceio' => 'Oge Brasilia (Maceio)',
        'America/Managua' => 'Oge Mpaghara Etiti (Managua)',
        'America/Manaus' => 'Oge Amazon (Manaus)',
        'America/Marigot' => 'Oge Mpaghara Atlantic (Marigot)',
        'America/Martinique' => 'Oge Mpaghara Atlantic (Martinique)',
        'America/Matamoros' => 'Oge Mpaghara Etiti (Matamoros)',
        'America/Mazatlan' => 'Oge Mexican Pacific (Mazatlan)',
        'America/Mendoza' => 'Oge Argentina (Mendoza)',
        'America/Menominee' => 'Oge Mpaghara Etiti (Menominee)',
        'America/Merida' => 'Oge Mpaghara Etiti (Merida)',
        'America/Metlakatla' => 'Oge Alaska (Metlakatla)',
        'America/Mexico_City' => 'Oge Mpaghara Etiti (Mexico City)',
        'America/Miquelon' => 'Oge St. Pierre & Miquelon',
        'America/Moncton' => 'Oge Mpaghara Atlantic (Moncton)',
        'America/Monterrey' => 'Oge Mpaghara Etiti (Monterrey)',
        'America/Montevideo' => 'Oge Uruguay (Montevideo)',
        'America/Montreal' => 'Oge Kanada (Montreal)',
        'America/Montserrat' => 'Oge Mpaghara Atlantic (Montserrat)',
        'America/Nassau' => 'Oge Mpaghara Ọwụwa Anyanwụ (Nassau)',
        'America/New_York' => 'Oge Mpaghara Ọwụwa Anyanwụ (New York)',
        'America/Nipigon' => 'Oge Mpaghara Ọwụwa Anyanwụ (Nipigon)',
        'America/Nome' => 'Oge Alaska (Nome)',
        'America/Noronha' => 'Oge Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Oge Mpaghara Etiti (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Oge Mpaghara Etiti (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Oge Mpaghara Etiti (New Salem, North Dakota)',
        'America/Ojinaga' => 'Oge Mpaghara Ugwu (Ojinaga)',
        'America/Panama' => 'Oge Mpaghara Ọwụwa Anyanwụ (Panama)',
        'America/Pangnirtung' => 'Oge Mpaghara Ọwụwa Anyanwụ (Pangnirtung)',
        'America/Paramaribo' => 'Oge Suriname (Paramaribo)',
        'America/Phoenix' => 'Oge Mpaghara Ugwu (Phoenix)',
        'America/Port-au-Prince' => 'Oge Mpaghara Ọwụwa Anyanwụ (Port-au-Prince)',
        'America/Port_of_Spain' => 'Oge Mpaghara Atlantic (Port of Spain)',
        'America/Porto_Velho' => 'Oge Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'Oge Mpaghara Atlantic (Puerto Rico)',
        'America/Punta_Arenas' => 'Oge Chile (Punta Arenas)',
        'America/Rainy_River' => 'Oge Mpaghara Etiti (Rainy River)',
        'America/Rankin_Inlet' => 'Oge Mpaghara Etiti (Rankin Inlet)',
        'America/Recife' => 'Oge Brasilia (Recife)',
        'America/Regina' => 'Oge Mpaghara Etiti (Regina)',
        'America/Resolute' => 'Oge Mpaghara Etiti (Resolute)',
        'America/Rio_Branco' => 'Oge Brazil (Rio Branco)',
        'America/Santa_Isabel' => 'Oge Northwest Mexico (Santa Isabel)',
        'America/Santarem' => 'Oge Brasilia (Santarem)',
        'America/Santiago' => 'Oge Chile (Santiago)',
        'America/Santo_Domingo' => 'Oge Mpaghara Atlantic (Santo Domingo)',
        'America/Sao_Paulo' => 'Oge Brasilia (Sao Paulo)',
        'America/Scoresbysund' => 'Oge Mpaghara Ọwụwa Anyanwụ Greenland (Ittoqqortoormiit)',
        'America/Sitka' => 'Oge Alaska (Sitka)',
        'America/St_Barthelemy' => 'Oge Mpaghara Atlantic (St. Barthelemy)',
        'America/St_Johns' => 'Oge Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Oge Mpaghara Atlantic (St. Kitts)',
        'America/St_Lucia' => 'Oge Mpaghara Atlantic (St. Lucia)',
        'America/St_Thomas' => 'Oge Mpaghara Atlantic (St. Thomas)',
        'America/St_Vincent' => 'Oge Mpaghara Atlantic (St. Vincent)',
        'America/Swift_Current' => 'Oge Mpaghara Etiti (Swift Current)',
        'America/Tegucigalpa' => 'Oge Mpaghara Etiti (Tegucigalpa)',
        'America/Thule' => 'Oge Mpaghara Atlantic (Thule)',
        'America/Thunder_Bay' => 'Oge Mpaghara Ọwụwa Anyanwụ (Thunder Bay)',
        'America/Tijuana' => 'Oge Mpaghara Pacific (Tijuana)',
        'America/Toronto' => 'Oge Mpaghara Ọwụwa Anyanwụ (Toronto)',
        'America/Tortola' => 'Oge Mpaghara Atlantic (Tortola)',
        'America/Vancouver' => 'Oge Mpaghara Pacific (Vancouver)',
        'America/Whitehorse' => 'Oge Yukon (Whitehorse)',
        'America/Winnipeg' => 'Oge Mpaghara Etiti (Winnipeg)',
        'America/Yakutat' => 'Oge Alaska (Yakutat)',
        'America/Yellowknife' => 'Oge Mpaghara Ugwu (Yellowknife)',
        'Antarctica/Casey' => 'Oge Antarctica (Casey)',
        'Antarctica/Davis' => 'Oge Davis',
        'Antarctica/DumontDUrville' => 'Oge Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Macquarie)',
        'Antarctica/Mawson' => 'Oge Mawson',
        'Antarctica/McMurdo' => 'Oge New Zealand (McMurdo)',
        'Antarctica/Palmer' => 'Oge Chile (Palmer)',
        'Antarctica/Rothera' => 'Oge Rothera',
        'Antarctica/Syowa' => 'Oge Syowa',
        'Antarctica/Troll' => 'Oge Mpaghara Greemwich Mean (Troll)',
        'Antarctica/Vostok' => 'Oge Vostok',
        'Arctic/Longyearbyen' => 'Oge Mpaghara Etiti Europe (Longyearbyen)',
        'Asia/Aden' => 'Oge Arab (Aden)',
        'Asia/Almaty' => 'Oge Mpaghara Ọwụwa Anyanwụ Kazakhstan (Almaty)',
        'Asia/Amman' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Amman)',
        'Asia/Anadyr' => 'Oge Rụssịa (Anadyr)',
        'Asia/Aqtau' => 'Oge Mpaghara Ọdịda Anyanwụ Kazakhstan (Aqtau)',
        'Asia/Aqtobe' => 'Oge Mpaghara Ọdịda Anyanwụ Kazakhstan (Aqtobe)',
        'Asia/Ashgabat' => 'Oge Turkmenist (Ashgabat)',
        'Asia/Atyrau' => 'Oge Mpaghara Ọdịda Anyanwụ Kazakhstan (Atyrau)',
        'Asia/Baghdad' => 'Oge Arab (Baghdad)',
        'Asia/Bahrain' => 'Oge Arab (Bahrain)',
        'Asia/Baku' => 'Oge Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Oge Indochina (Bangkok)',
        'Asia/Barnaul' => 'Oge Rụssịa (Barnaul)',
        'Asia/Beirut' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Beirut)',
        'Asia/Bishkek' => 'Oge Kyrgyzstan (Bishkek)',
        'Asia/Brunei' => 'Oge Brunei Darussalam',
        'Asia/Calcutta' => 'Oge Izugbe India (Kolkata)',
        'Asia/Chita' => 'Oge Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Oge Ulaanbaatar (Choibalsan)',
        'Asia/Colombo' => 'Oge Izugbe India (Colombo)',
        'Asia/Damascus' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Damascus)',
        'Asia/Dhaka' => 'Oge Bangladesh (Dhaka)',
        'Asia/Dili' => 'Oge Mpaghara Ọwụwa Anyanwụ Timor (Dili)',
        'Asia/Dubai' => 'Oge Izugbe Gulf (Dubai)',
        'Asia/Dushanbe' => 'Oge Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Famagusta)',
        'Asia/Gaza' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Gaza)',
        'Asia/Hebron' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Hebron)',
        'Asia/Hong_Kong' => 'Oge Hong Kong',
        'Asia/Hovd' => 'Oge Hovd',
        'Asia/Irkutsk' => 'Oge Irkutsk',
        'Asia/Jakarta' => 'Oge Mpaghara Ọdịda Anyanwụ Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Oge Mpaghara Ọwụwa Anyanwụ Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'Oge Israel (Jerusalem)',
        'Asia/Kabul' => 'Oge Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Oge Rụssịa (Kamchatka)',
        'Asia/Karachi' => 'Oge Pakistan (Karachi)',
        'Asia/Katmandu' => 'Oge Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Oge Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Oge Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Oge Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Oge Malaysia (Kuching)',
        'Asia/Kuwait' => 'Oge Arab (Kuwait)',
        'Asia/Macau' => 'Oge China (Macao)',
        'Asia/Magadan' => 'Oge Magadan',
        'Asia/Makassar' => 'Oge Etiti Indonesia (Makassar)',
        'Asia/Manila' => 'Oge Philippine (Manila)',
        'Asia/Muscat' => 'Oge Izugbe Gulf (Muscat)',
        'Asia/Nicosia' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Nicosia)',
        'Asia/Novokuznetsk' => 'Oge Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Oge Novosibirsk',
        'Asia/Omsk' => 'Oge Omsk',
        'Asia/Oral' => 'Oge Mpaghara Ọdịda Anyanwụ Kazakhstan (Oral)',
        'Asia/Phnom_Penh' => 'Oge Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Oge Mpaghara Ọdịda Anyanwụ Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'Oge Korea (Pyongyang)',
        'Asia/Qatar' => 'Oge Arab (Qatar)',
        'Asia/Qostanay' => 'Oge Mpaghara Ọwụwa Anyanwụ Kazakhstan (Qostanay)',
        'Asia/Qyzylorda' => 'Oge Mpaghara Ọdịda Anyanwụ Kazakhstan (Qyzylorda)',
        'Asia/Rangoon' => 'Oge Myanmar (Yangon)',
        'Asia/Riyadh' => 'Oge Arab (Riyadh)',
        'Asia/Saigon' => 'Oge Indochina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Oge Sakhalin',
        'Asia/Samarkand' => 'Oge Uzbekist (Samarkand)',
        'Asia/Seoul' => 'Oge Korea (Seoul)',
        'Asia/Shanghai' => 'Oge China (Shanghai)',
        'Asia/Singapore' => 'Oge Izugbe Singapore',
        'Asia/Srednekolymsk' => 'Oge Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Oge Taipei',
        'Asia/Tashkent' => 'Oge Uzbekist (Tashkent)',
        'Asia/Tbilisi' => 'Oge Georgia (Tbilisi)',
        'Asia/Tehran' => 'Oge Iran (Tehran)',
        'Asia/Thimphu' => 'Oge Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Oge Japan (Tokyo)',
        'Asia/Tomsk' => 'Oge Rụssịa (Tomsk)',
        'Asia/Ulaanbaatar' => 'Oge Ulaanbaatar',
        'Asia/Urumqi' => 'Oge China (Urumqi)',
        'Asia/Ust-Nera' => 'Oge Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Oge Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Oge Vladivostok',
        'Asia/Yakutsk' => 'Oge Yakutsk',
        'Asia/Yekaterinburg' => 'Oge Yekaterinburg',
        'Asia/Yerevan' => 'Oge Armenia (Yerevan)',
        'Atlantic/Azores' => 'Oge Azores',
        'Atlantic/Bermuda' => 'Oge Mpaghara Atlantic (Bermuda)',
        'Atlantic/Canary' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (Canary)',
        'Atlantic/Cape_Verde' => 'Oge Cape Verde',
        'Atlantic/Faeroe' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (Faroe)',
        'Atlantic/Madeira' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (Madeira)',
        'Atlantic/Reykjavik' => 'Oge Mpaghara Greemwich Mean (Reykjavik)',
        'Atlantic/South_Georgia' => 'Oge South Georgia',
        'Atlantic/St_Helena' => 'Oge Mpaghara Greemwich Mean (St. Helena)',
        'Atlantic/Stanley' => 'Oge Falkland Islands (Stanley)',
        'Australia/Adelaide' => 'Oge Etiti Australia (Adelaide)',
        'Australia/Brisbane' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Brisbane)',
        'Australia/Broken_Hill' => 'Oge Etiti Australia (Broken Hill)',
        'Australia/Currie' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Currie)',
        'Australia/Darwin' => 'Oge Etiti Australia (Darwin)',
        'Australia/Eucla' => 'Oge Mpaghara Ọdịda Anyanwụ Etiti Australia (Eucla)',
        'Australia/Hobart' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Hobart)',
        'Australia/Lindeman' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Lindeman)',
        'Australia/Lord_Howe' => 'Oge Lord Howe',
        'Australia/Melbourne' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Melbourne)',
        'Australia/Perth' => 'Oge Mpaghara Ọdịda Anyanwụ Australia (Perth)',
        'Australia/Sydney' => 'Oge Mpaghara Ọwụwa Anyanwụ Australia (Sydney)',
        'CST6CDT' => 'Oge Mpaghara Etiti',
        'EST5EDT' => 'Oge Mpaghara Ọwụwa Anyanwụ',
        'Etc/GMT' => 'Oge Mpaghara Greemwich Mean',
        'Etc/UTC' => 'Nhazi Oge Ụwa Niile',
        'Europe/Amsterdam' => 'Oge Mpaghara Etiti Europe (Amsterdam)',
        'Europe/Andorra' => 'Oge Mpaghara Etiti Europe (Andorra)',
        'Europe/Astrakhan' => 'Oge Moscow (Astrakhan)',
        'Europe/Athens' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Athens)',
        'Europe/Belgrade' => 'Oge Mpaghara Etiti Europe (Belgrade)',
        'Europe/Berlin' => 'Oge Mpaghara Etiti Europe (Berlin)',
        'Europe/Bratislava' => 'Oge Mpaghara Etiti Europe (Bratislava)',
        'Europe/Brussels' => 'Oge Mpaghara Etiti Europe (Brussels)',
        'Europe/Bucharest' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Bucharest)',
        'Europe/Budapest' => 'Oge Mpaghara Etiti Europe (Budapest)',
        'Europe/Busingen' => 'Oge Mpaghara Etiti Europe (Busingen)',
        'Europe/Chisinau' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Chisinau)',
        'Europe/Copenhagen' => 'Oge Mpaghara Etiti Europe (Copenhagen)',
        'Europe/Dublin' => 'Oge Mpaghara Greemwich Mean (Dublin)',
        'Europe/Gibraltar' => 'Oge Mpaghara Etiti Europe (Gibraltar)',
        'Europe/Guernsey' => 'Oge Mpaghara Greemwich Mean (Guernsey)',
        'Europe/Helsinki' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Helsinki)',
        'Europe/Isle_of_Man' => 'Oge Mpaghara Greemwich Mean (Isle of Man)',
        'Europe/Istanbul' => 'Oge Turkey (Istanbul)',
        'Europe/Jersey' => 'Oge Mpaghara Greemwich Mean (Jersey)',
        'Europe/Kaliningrad' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Kaliningrad)',
        'Europe/Kiev' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Kyiv)',
        'Europe/Kirov' => 'Oge Rụssịa (Kirov)',
        'Europe/Lisbon' => 'Oge Mpaghara Ọdịda Anyanwụ Europe (Lisbon)',
        'Europe/Ljubljana' => 'Oge Mpaghara Etiti Europe (Ljubljana)',
        'Europe/London' => 'Oge Mpaghara Greemwich Mean (London)',
        'Europe/Luxembourg' => 'Oge Mpaghara Etiti Europe (Luxembourg)',
        'Europe/Madrid' => 'Oge Mpaghara Etiti Europe (Madrid)',
        'Europe/Malta' => 'Oge Mpaghara Etiti Europe (Malta)',
        'Europe/Mariehamn' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Mariehamn)',
        'Europe/Minsk' => 'Oge Moscow (Minsk)',
        'Europe/Monaco' => 'Oge Mpaghara Etiti Europe (Monaco)',
        'Europe/Moscow' => 'Oge Moscow',
        'Europe/Oslo' => 'Oge Mpaghara Etiti Europe (Oslo)',
        'Europe/Paris' => 'Oge Mpaghara Etiti Europe (Paris)',
        'Europe/Podgorica' => 'Oge Mpaghara Etiti Europe (Podgorica)',
        'Europe/Prague' => 'Oge Mpaghara Etiti Europe (Prague)',
        'Europe/Riga' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Riga)',
        'Europe/Rome' => 'Oge Mpaghara Etiti Europe (Rome)',
        'Europe/Samara' => 'Oge Rụssịa (Samara)',
        'Europe/San_Marino' => 'Oge Mpaghara Etiti Europe (San Marino)',
        'Europe/Sarajevo' => 'Oge Mpaghara Etiti Europe (Sarajevo)',
        'Europe/Saratov' => 'Oge Moscow (Saratov)',
        'Europe/Simferopol' => 'Oge Moscow (Simferopol)',
        'Europe/Skopje' => 'Oge Mpaghara Etiti Europe (Skopje)',
        'Europe/Sofia' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Sofia)',
        'Europe/Stockholm' => 'Oge Mpaghara Etiti Europe (Stockholm)',
        'Europe/Tallinn' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Tallinn)',
        'Europe/Tirane' => 'Oge Mpaghara Etiti Europe (Tirane)',
        'Europe/Ulyanovsk' => 'Oge Moscow (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Uzhgorod)',
        'Europe/Vaduz' => 'Oge Mpaghara Etiti Europe (Vaduz)',
        'Europe/Vatican' => 'Oge Mpaghara Etiti Europe (Vatican)',
        'Europe/Vienna' => 'Oge Mpaghara Etiti Europe (Vienna)',
        'Europe/Vilnius' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Vilnius)',
        'Europe/Volgograd' => 'Oge Volgograd',
        'Europe/Warsaw' => 'Oge Mpaghara Etiti Europe (Warsaw)',
        'Europe/Zagreb' => 'Oge Mpaghara Etiti Europe (Zagreb)',
        'Europe/Zaporozhye' => 'Oge Mpaghara Ọwụwa Anyanwụ Europe (Zaporozhye)',
        'Europe/Zurich' => 'Oge Mpaghara Etiti Europe (Zurich)',
        'Indian/Antananarivo' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Antananarivo)',
        'Indian/Chagos' => 'Oge Osimiri India (Chagos)',
        'Indian/Christmas' => 'Oge Ekeresimesi Island (Christmas)',
        'Indian/Cocos' => 'Oge Cocos Islands',
        'Indian/Comoro' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Comoro)',
        'Indian/Kerguelen' => 'Oge French Southern & Antarctic (Kerguelen)',
        'Indian/Mahe' => 'Oge Seychelles (Mahe)',
        'Indian/Maldives' => 'Oge Maldives',
        'Indian/Mauritius' => 'Oge Mauritius',
        'Indian/Mayotte' => 'Oge Mpaghara Ọwụwa Anyanwụ Afrịka (Mayotte)',
        'Indian/Reunion' => 'Oge Réunion (Reunion)',
        'MST7MDT' => 'Oge Mpaghara Ugwu',
        'PST8PDT' => 'Oge Mpaghara Pacific',
        'Pacific/Apia' => 'Oge Apia',
        'Pacific/Auckland' => 'Oge New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Oge Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Oge Chatham',
        'Pacific/Easter' => 'Oge Mpaghara Ọwụwa Anyanwụ Island (Easter)',
        'Pacific/Efate' => 'Oge Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Oge Phoenix Islands (Enderbury)',
        'Pacific/Fakaofo' => 'Oge Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Oge Fiji',
        'Pacific/Funafuti' => 'Oge Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Oge Galapagos',
        'Pacific/Gambier' => 'Oge Gambier',
        'Pacific/Guadalcanal' => 'Oge Solomon Islands (Guadalcanal)',
        'Pacific/Guam' => 'Oge Izugbe Chamorro (Guam)',
        'Pacific/Honolulu' => 'Oge Hawaii-Aleutian (Honolulu)',
        'Pacific/Johnston' => 'Oge Hawaii-Aleutian (Johnston)',
        'Pacific/Kiritimati' => 'Oge Line Islands (Kiritimati)',
        'Pacific/Kosrae' => 'Oge Kosrae',
        'Pacific/Kwajalein' => 'Oge Marshall Islands (Kwajalein)',
        'Pacific/Majuro' => 'Oge Marshall Islands (Majuro)',
        'Pacific/Marquesas' => 'Oge Marquesas',
        'Pacific/Midway' => 'Oge Samoa (Midway)',
        'Pacific/Nauru' => 'Oge Nauru',
        'Pacific/Niue' => 'Oge Niue',
        'Pacific/Norfolk' => 'Oge Norfolk Island',
        'Pacific/Noumea' => 'Oge New Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'Oge Samoa (Pago Pago)',
        'Pacific/Palau' => 'Oge Palau',
        'Pacific/Pitcairn' => 'Oge Pitcairn',
        'Pacific/Ponape' => 'Oge Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Oge Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Oge Cook Islands (Rarotonga)',
        'Pacific/Saipan' => 'Oge Izugbe Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Oge Tahiti',
        'Pacific/Tarawa' => 'Oge Gilbert Islands (Tarawa)',
        'Pacific/Tongatapu' => 'Oge Tonga (Tongatapu)',
        'Pacific/Truk' => 'Oge Chuuk',
        'Pacific/Wake' => 'Oge Wake Island',
        'Pacific/Wallis' => 'Oge Wallis & Futuna',
    ],
    'Meta' => [
    ],
];
