<?php

return [
    'Names' => [
        'aa' => 'አፋርኛ',
        'ab' => 'አብሐዚኛ',
        'ace' => 'አቻይንኛ',
        'ach' => 'አኮሊኛ',
        'ada' => 'አዳንግሜ',
        'ady' => 'አድይግሄ',
        'ae' => 'አቬስታን',
        'af' => 'አፍሪካንኛ',
        'afh' => 'አፍሪሂሊ',
        'agq' => 'አገም',
        'ain' => 'አይኑ',
        'ak' => 'አካንኛ',
        'akk' => 'አካዲያን',
        'akz' => 'አላባማ',
        'ale' => 'አልዩት',
        'alt' => 'ደቡባዊ አልታይ',
        'am' => 'አማርኛ',
        'an' => 'አራጎንስ',
        'ann' => 'ኦቦሎ',
        'anp' => 'አንጊካ',
        'ar' => 'ዓረብኛ',
        'arc' => 'አራማይክ',
        'arn' => 'ማፑቼ',
        'aro' => 'አራኦና',
        'arp' => 'አራፓሆ',
        'arq' => 'የአልጄሪያ ዓረብኛ',
        'ars' => 'ናጅዲ-አረቢክ',
        'arw' => 'አራዋክ',
        'as' => 'አሳሜዛዊ',
        'asa' => 'አሱ',
        'ase' => 'የአሜሪካ የምልክት ቋንቋ',
        'ast' => 'አስቱሪያን',
        'atj' => 'አቲካምከው',
        'av' => 'አቫሪክ',
        'awa' => 'አዋድሂ',
        'ay' => 'አያማርኛ',
        'az' => 'አዘርባጃንኛ',
        'ba' => 'ባስኪርኛ',
        'bal' => 'ባሉቺ',
        'ban' => 'ባሊኔስ',
        'bar' => 'ባቫሪያን',
        'bas' => 'ባሳ',
        'bax' => 'ባሙን',
        'bbc' => 'ባታካ ቶባ',
        'be' => 'ቤላራሻኛ',
        'bej' => 'ቤጃ',
        'bem' => 'ቤምባ',
        'bew' => 'ቤታዊ',
        'bez' => 'ቤና',
        'bfd' => 'ባፉት',
        'bfq' => 'ባዳጋ',
        'bg' => 'ቡልጋሪኛ',
        'bgn' => 'የምዕራብ ባሎቺ',
        'bho' => 'ቦጁሪ',
        'bi' => 'ቢስላምኛ',
        'bik' => 'ቢኮል',
        'bin' => 'ቢኒ',
        'bjn' => 'ባንጃር',
        'bla' => 'ሲክሲካ',
        'bm' => 'ባምባርኛ',
        'bn' => 'ቤንጋሊኛ',
        'bo' => 'ቲቤታንኛ',
        'bpy' => 'ቢሹንፑሪያ',
        'bqi' => 'ባክህቲያሪ',
        'br' => 'ብሬቶንኛ',
        'bra' => 'ብራጅ',
        'brh' => 'ብራሁዪ',
        'brx' => 'ቦዶ',
        'bs' => 'ቦስኒያንኛ',
        'bss' => 'አኮስ',
        'bua' => 'ቡሪያት',
        'bug' => 'ቡጊኔዝ',
        'bum' => 'ቡሉ',
        'byn' => 'ብሊን',
        'ca' => 'ካታላንኛ',
        'cad' => 'ካዶ',
        'car' => 'ካሪብ',
        'cay' => 'ካዩጋ',
        'cch' => 'አትሳም',
        'ccp' => 'ቻክማ',
        'ce' => 'ችችን',
        'ceb' => 'ካቡዋኖ',
        'cgg' => 'ቺጋኛ',
        'ch' => 'ቻሞሮ',
        'chb' => 'ቺብቻ',
        'chg' => 'ቻጋታይ',
        'chk' => 'ቹክስ',
        'chm' => 'ማሪ',
        'chn' => 'ቺኑክ ጃርጎን',
        'cho' => 'ቾክታዋ',
        'chp' => 'ቺፔውያን',
        'chr' => 'ቼሮኬኛ',
        'chy' => 'ችዬኔ',
        'ckb' => 'የሶራኒ ኩርድኛ',
        'clc' => 'ቺልኮቲን',
        'co' => 'ኮርሲካኛ',
        'cop' => 'ኮፕቲክ',
        'cps' => 'ካፒዝኖን',
        'cr' => 'ክሪ',
        'crg' => 'ሚቺፍ',
        'crh' => 'ክሪሚያን ተርኪሽ',
        'crj' => 'ደቡባዊ ምዕራብ ክሪ',
        'crk' => 'ክሪ ሜዳዎች',
        'crl' => 'ሰሜናዊ ምዕራብ ክሪ',
        'crm' => 'ሙስ-ክሪ',
        'crr' => 'ካሮሊና አልጎንክዊያን',
        'crs' => 'ሰሰላዊ ክሬኦሊ ፈረንሳይኛ',
        'cs' => 'ቼክኛ',
        'csw' => 'ረግረጋማ ክሪ',
        'cu' => 'ቸርች ስላቪክ',
        'cv' => 'ቹቫሽ',
        'cy' => 'ወልሽ',
        'da' => 'ዴኒሽ',
        'dak' => 'ዳኮታ',
        'dar' => 'ዳርግዋ',
        'dav' => 'ታይታኛ',
        'de' => 'ጀርመን',
        'del' => 'ዳላዌር',
        'dgr' => 'ዶግሪብ',
        'din' => 'ዲንካ',
        'dje' => 'ዛርማኛ',
        'doi' => 'ዶግሪ',
        'dsb' => 'የታችኛው ሰርቢያንኛ',
        'dtp' => 'ሴንተራል ዱሰን',
        'dua' => 'ዱዋላኛ',
        'dv' => 'ዲቬሂ',
        'dyo' => 'ጆላ ፎንያኛ',
        'dyu' => 'ድዩላ',
        'dz' => 'ድዞንግኻኛ',
        'dzg' => 'ዳዛጋ',
        'ebu' => 'ኢቦኛ',
        'ee' => 'ኢዊ',
        'efi' => 'ኤፊክ',
        'egy' => 'የጥንታዊ ግብጽኛ',
        'eka' => 'ኤካጁክ',
        'el' => 'ግሪክኛ',
        'en' => 'እንግሊዝኛ',
        'eo' => 'ኤስፐራንቶ',
        'es' => 'ስፓንሽኛ',
        'esu' => 'ሴንተራል ዩፒክ',
        'et' => 'ኢስቶኒያንኛ',
        'eu' => 'ባስክኛ',
        'ewo' => 'ኤዎንዶ',
        'fa' => 'ፐርሺያኛ',
        'ff' => 'ፉላህ',
        'fi' => 'ፊኒሽ',
        'fil' => 'ፊሊፒንኛ',
        'fj' => 'ፊጂኛ',
        'fo' => 'ፋሮኛ',
        'fon' => 'ፎን',
        'fr' => 'ፈረንሳይኛ',
        'frc' => 'ካጁን ፍሬንች',
        'frp' => 'አርፒታን',
        'frr' => 'ሰሜናዊ ፍሪሳን',
        'fur' => 'ፍሩሊያን',
        'fy' => 'ምዕራባዊ ፍሪሲኛ',
        'ga' => 'አይሪሽ',
        'gaa' => 'ጋ',
        'gag' => 'ጋጉዝኛ',
        'gan' => 'ጋን ቻይንኛ',
        'gd' => 'የስኮቲሽ ጌልክኛ',
        'gez' => 'ግዕዝኛ',
        'gil' => 'ጅልበርትስ',
        'gl' => 'ጋሊሺያ',
        'gn' => 'ጓራኒኛ',
        'gor' => 'ጎሮንታሎ',
        'grc' => 'የጥንታዊ ግሪክ',
        'gsw' => 'የስዊዝ ጀርመን',
        'gu' => 'ጉጃርቲኛ',
        'guz' => 'ጉስሊኛ',
        'gv' => 'ማንክስኛ',
        'gwi' => 'ግዊቺን',
        'ha' => 'ሃውሳኛ',
        'hai' => 'ሃይዳ',
        'hak' => 'ሃካ ቻይንኛ',
        'haw' => 'ሃዊያኛ',
        'hax' => 'ደቡባዊ ሃይዳ',
        'he' => 'ዕብራይስጥ﻿',
        'hi' => 'ሒንዱኛ',
        'hil' => 'ሂሊጋይኖን',
        'hmn' => 'ህሞንግ',
        'hr' => 'ክሮሽያንኛ',
        'hsb' => 'የላይኛው ሶርቢያንኛ',
        'hsn' => 'ዢያንግ ቻይንኛ',
        'ht' => 'ሃይትኛ',
        'hu' => 'ሀንጋሪኛ',
        'hup' => 'ሁፓ',
        'hur' => 'ሃልኮመልም',
        'hy' => 'አርመናዊ',
        'hz' => 'ሄሬሮ',
        'ia' => 'ኢንቴርሊንጓ',
        'iba' => 'ኢባን',
        'ibb' => 'ኢቢቦ',
        'id' => 'ኢንዶኔዥኛ',
        'ie' => 'እንተርሊንግወ',
        'ig' => 'ኢግቦኛ',
        'ii' => 'ሲቹንዪኛ',
        'ik' => 'እኑፒያቅኛ',
        'ikt' => 'የምዕራባዊ ካናዳ ኢኑክቲቱት',
        'ilo' => 'ኢሎኮ',
        'inh' => 'ኢንጉሽ',
        'io' => 'ኢዶ',
        'is' => 'አይስላንድኛ',
        'it' => 'ጣሊያንኛ',
        'iu' => 'እኑክቲቱትኛ',
        'ja' => 'ጃፓንኛ',
        'jbo' => 'ሎጅባን',
        'jgo' => 'ንጎባኛ',
        'jmc' => 'ማቻሜኛ',
        'jv' => 'ጃቫንኛ',
        'ka' => 'ጆርጂያን',
        'kab' => 'ካብይል',
        'kac' => 'ካቺን',
        'kaj' => 'ካጅ',
        'kam' => 'ካምባ',
        'kbd' => 'ካባርዲያን',
        'kcg' => 'ታያፕ',
        'kde' => 'ማኮንዴ',
        'kea' => 'ካቡቨርዲያኑ',
        'kfo' => 'ኮሮ',
        'kg' => 'ኮንጎኛ',
        'kgp' => 'ካይንጋንግ',
        'kha' => 'ክሃሲ',
        'khq' => 'ኮይራ ቺኒ',
        'ki' => 'ኪኩዩ',
        'kj' => 'ኩንያማ',
        'kk' => 'ካዛክኛ',
        'kkj' => 'ካኮ',
        'kl' => 'ካላሊሱትኛ',
        'kln' => 'ካለንጂን',
        'km' => 'ክህመርኛ',
        'kmb' => 'ኪምቡንዱ',
        'kn' => 'ካናዳኛ',
        'ko' => 'ኮሪያኛ',
        'koi' => 'ኮሚ ፔርምያክ',
        'kok' => 'ኮንካኒ',
        'kpe' => 'ክፔሌ',
        'kr' => 'ካኑሪ',
        'krc' => 'ካራቻይ-ባልካር',
        'krl' => 'ካረሊኛ',
        'kru' => 'ኩሩክ',
        'ks' => 'ካሽሚርኛ',
        'ksb' => 'ሻምባላ',
        'ksf' => 'ባፊያ',
        'ksh' => 'ኮሎኝኛ',
        'ku' => 'ኩርድሽኛ',
        'kum' => 'ኩማይክ',
        'kv' => 'ኮሚ',
        'kw' => 'ኮርኒሽ',
        'kwk' => 'ክዋክዋላ',
        'ky' => 'ኪርጊዝኛ',
        'la' => 'ላቲንኛ',
        'lad' => 'ላዲኖ',
        'lag' => 'ላንጊ',
        'lb' => 'ሉክዘምበርኛ',
        'lez' => 'ሌዝጊያን',
        'lg' => 'ጋንዳኛ',
        'li' => 'ሊምቡርጊሽ',
        'lil' => 'ሊሎኤት',
        'lkt' => 'ላኮታ',
        'ln' => 'ሊንጋላኛ',
        'lo' => 'ላኦኛ',
        'lou' => 'ሉዊዚያና ክሬኦል',
        'loz' => 'ሎዚኛ',
        'lrc' => 'ሰሜናዊ ሉሪ',
        'lsm' => 'ሳሚያ',
        'lt' => 'ሉቴንያንኛ',
        'lu' => 'ሉባ ካታንጋ',
        'lua' => 'ሉባ-ሉሏ',
        'lun' => 'ሉንዳ',
        'luo' => 'ሉኦ',
        'lus' => 'ሚዞ',
        'luy' => 'ሉዪያ',
        'lv' => 'ላትቪያን',
        'mad' => 'ማዱረስ',
        'mag' => 'ማጋሂ',
        'mai' => 'ማይተሊ',
        'mak' => 'ማካሳር',
        'mas' => 'ማሳይ',
        'mdf' => 'ሞክሻ',
        'men' => 'ሜንዴ',
        'mer' => 'ሜሩ',
        'mfe' => 'ሞሪሲየኛ',
        'mg' => 'ማላጋስኛ',
        'mgh' => 'ማኩዋ ሜቶ',
        'mgo' => 'ሜታ',
        'mh' => 'ማርሻሌዝኛ',
        'mi' => 'ማኦሪኛ',
        'mic' => 'ሚክማክ',
        'min' => 'ሚናንግካባኡ',
        'mk' => 'ማሴዶንኛ',
        'ml' => 'ማላያላምኛ',
        'mn' => 'ሞንጎሊያኛ',
        'mni' => 'ማኒፑሪ',
        'moe' => 'ኢኑ-አይመን',
        'moh' => 'ሞሃውክ',
        'mos' => 'ሞሲ',
        'mr' => 'ማራቲኛ',
        'ms' => 'ማላይኛ',
        'mt' => 'ማልቲስኛ',
        'mua' => 'ሙንዳንግ',
        'mus' => 'ክሪክ',
        'mwl' => 'ሚራንዴዝኛ',
        'my' => 'ቡርማኛ',
        'myv' => 'ኤርዝያ',
        'mzn' => 'ማዛንደራኒ',
        'na' => 'ናኡሩ',
        'nan' => 'ሚን ኛን ቻይንኛ',
        'nap' => 'ኒአፖሊታን',
        'naq' => 'ናማ',
        'nb' => 'የኖርዌይ ቦክማል',
        'nd' => 'ሰሜን ንዴብሌ',
        'nds' => 'የታችኛው ጀርመን',
        'ne' => 'ኔፓሊኛ',
        'new' => 'ኒዋሪ(ኔፓል)',
        'ng' => 'ንዶንጋ',
        'nia' => 'ኒአስ',
        'niu' => 'ኒዩአንኛ',
        'njo' => 'ኦ ናጋ',
        'nl' => 'ደች',
        'nmg' => 'ክዋሲዮ',
        'nn' => 'የኖርዌይ ናይኖርስክ',
        'nnh' => 'ኒጊምቡን',
        'no' => 'ኖርዌጂያን',
        'nog' => 'ኖጋይ',
        'nqo' => 'ንኮ',
        'nr' => 'ደቡብ ንደቤሌ',
        'nso' => 'ሰሜናዊ ሶቶ',
        'nus' => 'ኑዌር',
        'nv' => 'ናቫጆ',
        'nwc' => 'ክላሲክ ኔዋሪ',
        'ny' => 'ንያንጃ',
        'nyn' => 'ኒያንኮልኛ',
        'oc' => 'ኦኪታንኛ',
        'ojb' => 'ሰሜናዊ ምዕራብ ኦጂብዋ',
        'ojc' => 'ማዕከላዊ ኦጂብዋ',
        'ojs' => 'ኦጂ-ክሪ',
        'ojw' => 'ምዕራባዊ ኦጂቡዋ',
        'oka' => 'ኦካናጋን',
        'om' => 'ኦሮሞኛ',
        'or' => 'ኦዲያኛ',
        'os' => 'ኦሴቲክ',
        'pa' => 'ፑንጃብኛ',
        'pag' => 'ፓንጋሲናንኛ',
        'pam' => 'ፓምፓንጋ',
        'pap' => 'ፓፒአሜንቶ',
        'pau' => 'ፓላኡአን',
        'pcm' => 'የናይጄሪያ ፒጂን',
        'pis' => 'ፒጂን',
        'pl' => 'ፖሊሽኛ',
        'pqm' => 'ማሊሰት-ፓሳማቆድይ',
        'prg' => 'ፐሩሳንኛ',
        'ps' => 'ፓሽቶኛ',
        'pt' => 'ፖርቹጋልኛ',
        'qu' => 'ኵቿኛ',
        'quc' => 'ኪቼ',
        'qug' => 'ቺምቦራዞ ሃይላንድ ኩቹዋ',
        'rap' => 'ራፓኑኢ',
        'rar' => 'ራሮቶንጋ',
        'rhg' => 'ሮሂንግኛ',
        'rm' => 'ሮማንሽ',
        'rn' => 'ሩንዲኛ',
        'ro' => 'ሮማኒያን',
        'rof' => 'ሮምቦ',
        'ru' => 'ራሽያኛ',
        'rup' => 'አሮማንያን',
        'rw' => 'ኪንያርዋንድኛ',
        'rwk' => 'ርዋ',
        'sa' => 'ሳንስክሪትኛ',
        'sad' => 'ሳንዳዌ',
        'sah' => 'ሳክሃ',
        'saq' => 'ሳምቡሩ',
        'sat' => 'ሳንታሊ',
        'sba' => 'ንጋምባይ',
        'sbp' => 'ሳንጉ',
        'sc' => 'ሳርዲንያንኛ',
        'scn' => 'ሲሲሊያንኛ',
        'sco' => 'ስኮትስ',
        'sd' => 'ሲንድሂኛ',
        'sdh' => 'ደቡባዊ ኩርዲሽ',
        'se' => 'ሰሜናዊ ሳሚ',
        'seh' => 'ሴና',
        'ses' => 'ኮይራቦሮ ሴኒ',
        'sg' => 'ሳንጎኛ',
        'sh' => 'ሰርቦ-ክሮኤሽያኛ',
        'shi' => 'ታቼልሂት',
        'shn' => 'ሻን',
        'shu' => 'ቻዲያን ዓረብኛ',
        'si' => 'ሲንሃልኛ',
        'sid' => 'ሲዳምኛ',
        'sk' => 'ስሎቫክኛ',
        'sl' => 'ስሎቪኛ',
        'slh' => 'ደቡባዊ ሉሹትሲድ',
        'sm' => 'ሳሞአኛ',
        'sma' => 'ደቡባዊ ሳሚ',
        'smj' => 'ሉሌ ሳሚ',
        'smn' => 'ኢናሪ ሳሚ',
        'sms' => 'ስኮልት ሳሚ',
        'sn' => 'ሾናኛ',
        'snk' => 'ሶኒንኬ',
        'so' => 'ሱማልኛ',
        'sq' => 'አልባንያንኛ',
        'sr' => 'ሰርብያኛ',
        'srn' => 'ስራናን ቶንጎ',
        'ss' => 'ስዋቲኛ',
        'ssy' => 'ሳሆኛ',
        'st' => 'ደቡባዊ ሶቶ',
        'str' => 'ጠረሮች ሳሊሽ',
        'su' => 'ሱዳንኛ',
        'suk' => 'ሱኩማ',
        'sv' => 'ስዊድንኛ',
        'sw' => 'ስዋሂሊኛ',
        'swb' => 'ኮሞሪያን',
        'syc' => 'ክላሲክ ኔይራ',
        'syr' => 'ሲሪያክ',
        'ta' => 'ታሚልኛ',
        'tce' => 'ደቡባዊ ቱትቾን',
        'te' => 'ተሉጉኛ',
        'tem' => 'ቲምኔ',
        'teo' => 'ቴሶ',
        'tet' => 'ቴተም',
        'tg' => 'ታጂኪኛ',
        'tgx' => 'ታጊሽ',
        'th' => 'ታይኛ',
        'tht' => 'ታህልታን',
        'ti' => 'ትግርኛ',
        'tig' => 'ትግረ',
        'tk' => 'ቱርክሜንኛ',
        'tl' => 'ታጋሎገኛ',
        'tlh' => 'ክሊንጎንኛ',
        'tli' => 'ትሊንጊት',
        'tn' => 'ጽዋናዊኛ',
        'to' => 'ቶንጋኛ',
        'tok' => 'ቶኪ ፖና',
        'tpi' => 'ቶክ ፒሲን',
        'tr' => 'ቱርክኛ',
        'trv' => 'ታሮኮ',
        'ts' => 'ጾንጋኛ',
        'tt' => 'ታታርኛ',
        'ttm' => 'ሰሜናዊ ቱትቾን',
        'tum' => 'ቱምቡካ',
        'tvl' => 'ቱቫሉ',
        'tw' => 'ትዊኛ',
        'twq' => 'ታሳዋቅ',
        'ty' => 'ታሂታንኛ',
        'tyv' => 'ቱቪንያንኛ',
        'tzm' => 'መካከለኛው አትላስ ታማዚኛ',
        'udm' => 'ኡድሙርት',
        'ug' => 'ኡዊግሁርኛ',
        'uk' => 'ዩክሬንኛ',
        'umb' => 'ኡምቡንዱ',
        'ur' => 'ኡርዱኛ',
        'uz' => 'ኡዝቤክኛ',
        'vai' => 'ቫይ',
        've' => 'ቬንዳ',
        'vi' => 'ቪየትናምኛ',
        'vo' => 'ቮላፑክኛ',
        'vun' => 'ቩንጆ',
        'wa' => 'ዋሎን',
        'wae' => 'ዋልሰር',
        'wal' => 'ወላይትኛ',
        'war' => 'ዋራይ',
        'wbp' => 'ዋርልፒሪ',
        'wo' => 'ዎሎፍኛ',
        'wuu' => 'ዉ ቻይንኛ',
        'xal' => 'ካልማይክ',
        'xh' => 'ዞሳኛ',
        'xog' => 'ሶጋ',
        'yav' => 'ያንግቤንኛ',
        'ybb' => 'የምባ',
        'yi' => 'ይዲሽኛ',
        'yo' => 'ዮሩባዊኛ',
        'yrl' => 'ኒኛቱ',
        'yue' => 'ካንቶኒዝ',
        'za' => 'ዡዋንግኛ',
        'zbl' => 'ብሊስይምቦልስ',
        'zgh' => 'መደበኛ የሞሮኮ ታማዚግት',
        'zh' => 'ቻይንኛ',
        'zu' => 'ዙሉኛ',
        'zun' => 'ዙኒ',
        'zza' => 'ዛዛ',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ዘመናዊ መደበኛ ዓረብኛ',
        'de_AT' => 'የኦስትሪያ ጀርመን',
        'de_CH' => 'የስዊዝ ከፍተኛ ጀርመንኛ',
        'en_AU' => 'የአውስትራሊያ እንግሊዝኛ',
        'en_CA' => 'የካናዳ እንግሊዝኛ',
        'en_GB' => 'የብሪቲሽ እንግሊዝኛ',
        'en_US' => 'የአሜሪካ እንግሊዝኛ',
        'es_419' => 'የላቲን አሜሪካ ስፓኒሽ',
        'es_ES' => 'የአውሮፓ ስፓንሽኛ',
        'es_MX' => 'የሜክሲኮ ስፓንሽኛ',
        'fa_AF' => 'ዳሪኛ',
        'fr_CA' => 'የካናዳ ፈረንሳይኛ',
        'fr_CH' => 'የስዊዝ ፈረንሳይኛ',
        'nds_NL' => 'የታችኛው ሳክሰን',
        'nl_BE' => 'ፍሌሚሽ',
        'pt_BR' => 'የብራዚል ፖርቹጋልኛ',
        'pt_PT' => 'የአውሮፓ ፖርቹጋልኛ',
        'ro_MD' => 'ሞልዳቪያንኛ',
        'sw_CD' => 'ኮንጎ ስዋሂሊ',
        'zh_Hans' => 'ቀለል ያለ ቻይንኛ',
        'zh_Hant' => 'ባህላዊ ቻይንኛ',
    ],
];
