<?php

return [
    'Names' => [
        'Adlm' => 'adlama',
        'Arab' => 'arābu',
        'Aran' => 'nastaliku',
        'Armi' => 'aramiešu',
        'Armn' => 'armēņu',
        'Bali' => 'baliešu',
        'Beng' => 'bengāļu',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'Braila raksts',
        'Cakm' => 'čakmu',
        'Cans' => 'vienotā Kanādas aborigēnu zilbju rakstība',
        'Cher' => 'irokēzu',
        'Copt' => 'koptu',
        'Cyrl' => 'kirilica',
        'Cyrs' => 'senslāvu',
        'Deva' => 'dēvanāgari',
        'Egyd' => 'demotiskais raksts',
        'Egyh' => 'hierātiskais raksts',
        'Egyp' => 'ēģiptiešu hieroglifi',
        'Ethi' => 'etiopiešu',
        'Geor' => 'gruzīnu',
        'Goth' => 'gotu',
        'Grek' => 'grieķu',
        'Gujr' => 'gudžaratu',
        'Guru' => 'pandžabu',
        'Hanb' => 'haņu ar bopomofo',
        'Hang' => 'hangils',
        'Hani' => 'haņu',
        'Hans' => 'vienkāršotā',
        'Hant' => 'tradicionālā',
        'Hebr' => 'ivrits',
        'Hira' => 'hiragana',
        'Hrkt' => 'japāņu zilbju alfabēts',
        'Hung' => 'senungāru',
        'Ital' => 'vecitāļu',
        'Jamo' => 'jamo',
        'Java' => 'javiešu',
        'Jpan' => 'japāņu',
        'Kana' => 'katakana',
        'Khmr' => 'khmeru',
        'Knda' => 'kannadu',
        'Kore' => 'korejiešu',
        'Laoo' => 'laosiešu',
        'Latn' => 'latīņu',
        'Lina' => 'lineārā A',
        'Linb' => 'lineārā B',
        'Lydi' => 'līdiešu',
        'Maya' => 'maiju',
        'Mlym' => 'malajalu',
        'Mong' => 'mongoļu',
        'Moon' => 'Mūna raksts',
        'Mtei' => 'meitei-majeku',
        'Mymr' => 'birmiešu',
        'Nkoo' => 'nko',
        'Ogam' => 'ogamiskais raksts',
        'Olck' => 'olčiki',
        'Orya' => 'oriju',
        'Osma' => 'osmaņu turku',
        'Phnx' => 'feniķiešu',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'rūnu raksts',
        'Samr' => 'samariešu',
        'Sinh' => 'singāļu',
        'Sund' => 'zundu',
        'Syrc' => 'sīriešu',
        'Syrj' => 'rietumsīriešu',
        'Syrn' => 'austrumsīriešu',
        'Taml' => 'tamilu',
        'Telu' => 'telugu',
        'Tfng' => 'tifinagu',
        'Tglg' => 'tagalu',
        'Thaa' => 'tāna',
        'Thai' => 'taju',
        'Tibt' => 'tibetiešu',
        'Vaii' => 'vaju',
        'Xpeo' => 'senperiešu',
        'Xsux' => 'šumeru-akadiešu ķīļraksts',
        'Yiii' => 'ji',
        'Zinh' => 'mantotā',
        'Zmth' => 'matemātiskais pieraksts',
        'Zsye' => 'emocijzīmes',
        'Zsym' => 'simboli',
        'Zxxx' => 'bez rakstības',
        'Zyyy' => 'vispārējā',
    ],
];
