<?php

return [
    'Names' => [
        'ARS' => [
            0 => '$',
            1 => 'peso argentino',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'dólar estadounidense',
        ],
    ],
];
