<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorranesch Peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'VAE-Dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afghanesch Afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghanesch Afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanesche Lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armeneschen Dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Antillen-Gulden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolanesche Kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolanesche Kwanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolaneschen Neie Kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolanesche Kwanza Reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentineschen Austral',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentinesche Peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentinesche Peso',
        ],
        'ATS' => [
            0 => 'öS',
            1 => 'Éisträichesche Schilling',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Australeschen Dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruba-Florin',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Aserbaidschan-Manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Aserbaidschan-Manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosnien an Herzegowina Dinar (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnien an Herzegowina Konvertéierbar Mark',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados-Dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladesch-Taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belsche Frang (konvertibel)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belsche Frang',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belsche Finanz-Frang',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgaresch Lew (1962–1999)',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgaresch Lew',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahrain-Dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi-Frang',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda-Dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunei-Dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivianesche Boliviano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Bolivianesche Peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Bolivianseche Mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Brasilianesche Cruzeiro Novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Brasilianesche Cruzado (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Brasilianesche Cruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Brasilianesche Real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Brasilianesche Cruzado Novo (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brasilianesche Cruzeiro (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Brasilianesche Cruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahama-Dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhutan-Ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Birmanesche Kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswanesch Pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Wäissrussesche Rubel (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Wäissrussesche Rubel',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Wäissrussesche Rubel (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belize-Dollar',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanadeschen Dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongo-Frang',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR-Euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Schwäizer Frang',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR-Frang',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Chileneschen Unidad de Fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chilenesche Peso',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Renminbi Yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbianesche Peso',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Costa-Rica-Colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Serbeschen Dinar (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Tschechoslowakesch Kroun',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kubanesche Peso (konvertibel)',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kubanesche Peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kap-Verde-Escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Zypern-Pond',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Tschechesch Kroun',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'DDR-Mark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Däitsch Mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Dschibuti-Frang',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Dänesch Kroun',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikanesche Peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algereschen Dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ecuadorianesche Sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Verrechnungseenheete fir Ecuador',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estnesch Kroun',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptescht Pond',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritréieschen Nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Spuenesch Peseta (A–Konten)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Spuenesch Peseta (konvertibel)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Spuenesch Peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ethiopescht Birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Finnesch Mark',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fidschi-Dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falkland-Pond',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franséische Frang',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Britescht Pond',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Georgesche Kupon Larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgesche Lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ghanaeschen Cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanaeschen Cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltar-Pond',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambia-Dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinea-Frang',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guinéiesche Syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Equatorialguinea-Ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Griichesch Drachme',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemaltekesche Quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugisesch-Guinea Escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guinea-Bissau Peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyana-Dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hong-Kong-Dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Honduras-Lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Kroateschen Dinar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatesche Kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haitianesch Gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Ungaresche Forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesesch Rupiah',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Irescht Pond',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Israelescht Pond',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Israeleschen Neie Schekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indesch Rupie',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irakeschen Dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iranesch Rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islännesch Kroun',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italienesch Lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaika-Dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordaneschen Dinar',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Japanesche Yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenia-Schilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgisesche Som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodschanesche Riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komore-Frang',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Nordkoreanesche Won',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Südkoreanesche Won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuwait-Dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kaiman-Dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kasacheschen Tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laoteschen Kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libanesescht Pond',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri-Lanka-Rupie',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberianeschen Dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litauesche Litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litaueschen Talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Lëtzebuerger Frang (konvertibel)',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Lëtzebuerger Frang',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Lëtzebuerger Finanz-Frang',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lettesche Lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Lettesche Rubel',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libeschen Dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokkaneschen Dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokkanesche Frang',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldawesche Leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskar-Ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madagaskar-Frang',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Mazedoneschen Denar',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malesche Frang',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmaresche Kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongoleschen Tögrög',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macau-Pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauretaneschen Ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauretaneschen Ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltesesch Lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltesescht Pond',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritius-Rupie',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldiven-Rupie',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawi-Kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Mexikanesche Peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Mexikanesche Sëlwer-Peso (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Mexikaneschen Unidad de Inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malayseschen Ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mosambikaneschen Escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mosambikanesche Metical (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mosambikanesche Metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibia-Dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigerianeschen Naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nicaraguanesche Córdoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nicaraguanesche Córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Hollännesche Gulden',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norwegesch Kroun',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalesesch Rupie',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Neiséiland-Dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omanesche Rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamaesche Balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peruaneschen Inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruaneschen Sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peruaneschen Sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua-Neiguinéiesche Kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Philippinnesche Peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistanesch Rupie',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polneschen Zloty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Polneschen Zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugiseschen Escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguayeschen Guaraní',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katar-Riyal',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rhodeseschen Dollar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rumänesche Leu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumänesche Leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbeschen Dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russesche Rubel',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Russesche Rubel (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruanda-Frang',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudi-Rial',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Salomonen-Dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seychellen-Rupie',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Sudaneseschen Dinar (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudanesescht Pond',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Sudanesescht Pond (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Schwedesch Kroun',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapur-Dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'St. Helena-Pond',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Sloweneschen Tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slowakesch Kroun',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra-leonesche Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalia-Schilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinameschen Dollar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinamesche Gulden',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Südsudanesescht Pond',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'São-toméeschen Dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'São-toméeschen Dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sowjetesche Rubel',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'El-Salvador-Colón',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Syrescht Pond',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swasilännesche Lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Thailännesche Baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadschikistan-Rubel',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadschikistan-Somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmenistan-Manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistan-Manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tuneseschen Dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongaeschen Paʻanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timor-Escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Tierkesch Lira (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Tierkesch Lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad-an-Tobago-Dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Neien Taiwan-Dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tansania-Schilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukraineschen Hrywnja',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrainesche Karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Uganda-Schilling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Uganda-Schilling',
        ],
        'USD' => [
            0 => '$',
            1 => 'US-Dollar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'US Dollar (Nächsten Dag)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'US Dollar (Selwechten Dag)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruguayesche Peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguayesche Peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Usbekistan-Sum',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venezolanesche Bolívar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezolanesche Bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venezolanesche Bolívar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vietnameseschen Dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu-Vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoaneschen Tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA-Frang (BEAC)',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Ostkaribeschen Dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Europäesch Währungseenheet (XEU)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franséische Gold-Frang',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Franséischen UIC-Frang',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'CFA-Frang (BCEAO)',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP-Frang',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET Funds',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemen-Dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemen-Rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Jugoslaweschen Dinar (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Jugoslaweschen Neien Dinar (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Jugoslaweschen Dinar (konvertibel)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Südafrikanesche Rand (Finanz)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Südafrikanesche Rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zaire-Neien Zaïre (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zaire-Zaïre (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Simbabwe-Dollar (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Simbabwe-Dollar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Simbabwe-Dollar (2008)',
        ],
    ],
];
