<?php

return [
    'Names' => [
        'af' => 'Afrikaans Simi',
        'af_NA' => 'Afrikaans Simi (Namibia)',
        'af_ZA' => 'Afrikaans Simi (Sudáfrica)',
        'ak' => 'Akan Simi',
        'ak_GH' => 'Akan Simi (Ghana)',
        'am' => 'Amarico Simi',
        'am_ET' => 'Amarico Simi (Etiopía)',
        'ar' => 'Arabe Simi',
        'ar_001' => 'Arabe Simi (Pacha)',
        'ar_AE' => 'Arabe Simi (Emiratos Árabes Unidos)',
        'ar_BH' => 'Arabe Simi (Baréin)',
        'ar_DJ' => 'Arabe Simi (Yibuti)',
        'ar_DZ' => 'Arabe Simi (Argelia)',
        'ar_EG' => 'Arabe Simi (Egipto)',
        'ar_EH' => 'Arabe Simi (Sahara Occidental)',
        'ar_ER' => 'Arabe Simi (Eritrea)',
        'ar_IL' => 'Arabe Simi (Israel)',
        'ar_IQ' => 'Arabe Simi (Irak)',
        'ar_JO' => 'Arabe Simi (Jordania)',
        'ar_KM' => 'Arabe Simi (Comoras)',
        'ar_KW' => 'Arabe Simi (Kuwait)',
        'ar_LB' => 'Arabe Simi (Líbano)',
        'ar_LY' => 'Arabe Simi (Libia)',
        'ar_MA' => 'Arabe Simi (Marruecos)',
        'ar_MR' => 'Arabe Simi (Mauritania)',
        'ar_OM' => 'Arabe Simi (Omán)',
        'ar_PS' => 'Arabe Simi (Palestina Kamachikuq)',
        'ar_QA' => 'Arabe Simi (Qatar)',
        'ar_SA' => 'Arabe Simi (Arabia Saudí)',
        'ar_SD' => 'Arabe Simi (Sudán)',
        'ar_SO' => 'Arabe Simi (Somalia)',
        'ar_SS' => 'Arabe Simi (Sudán del Sur)',
        'ar_SY' => 'Arabe Simi (Siria)',
        'ar_TD' => 'Arabe Simi (Chad)',
        'ar_TN' => 'Arabe Simi (Túnez)',
        'ar_YE' => 'Arabe Simi (Yemen)',
        'as' => 'Asames Simi',
        'as_IN' => 'Asames Simi (India)',
        'az' => 'Azerbaiyano Simi',
        'az_AZ' => 'Azerbaiyano Simi (Azerbaiyán)',
        'az_Cyrl' => 'Azerbaiyano Simi (Cirilico)',
        'az_Cyrl_AZ' => 'Azerbaiyano Simi (Cirilico, Azerbaiyán)',
        'az_Latn' => 'Azerbaiyano Simi (Latin Simi)',
        'az_Latn_AZ' => 'Azerbaiyano Simi (Latin Simi, Azerbaiyán)',
        'be' => 'Bielorruso Simi',
        'be_BY' => 'Bielorruso Simi (Belarús)',
        'bg' => 'Bulgaro Simi',
        'bg_BG' => 'Bulgaro Simi (Bulgaria)',
        'bm' => 'Bambara Simi',
        'bm_ML' => 'Bambara Simi (Malí)',
        'bn' => 'Bangla Simi',
        'bn_BD' => 'Bangla Simi (Bangladesh)',
        'bn_IN' => 'Bangla Simi (India)',
        'bo' => 'Tibetano Simi',
        'bo_CN' => 'Tibetano Simi (China)',
        'bo_IN' => 'Tibetano Simi (India)',
        'br' => 'Breton Simi',
        'br_FR' => 'Breton Simi (Francia)',
        'bs' => 'Bosnio Simi',
        'bs_BA' => 'Bosnio Simi (Bosnia y Herzegovina)',
        'bs_Cyrl' => 'Bosnio Simi (Cirilico)',
        'bs_Cyrl_BA' => 'Bosnio Simi (Cirilico, Bosnia y Herzegovina)',
        'bs_Latn' => 'Bosnio Simi (Latin Simi)',
        'bs_Latn_BA' => 'Bosnio Simi (Latin Simi, Bosnia y Herzegovina)',
        'ca' => 'Catalan Simi',
        'ca_AD' => 'Catalan Simi (Andorra)',
        'ca_ES' => 'Catalan Simi (España)',
        'ca_FR' => 'Catalan Simi (Francia)',
        'ca_IT' => 'Catalan Simi (Italia)',
        'ce' => 'Checheno Simi',
        'ce_RU' => 'Checheno Simi (Rusia)',
        'cs' => 'Checo Simi',
        'cs_CZ' => 'Checo Simi (Chequia)',
        'cv' => 'Chuvash Simi',
        'cv_RU' => 'Chuvash Simi (Rusia)',
        'cy' => 'Gales Simi',
        'cy_GB' => 'Gales Simi (Reino Unido)',
        'da' => 'Danes Simi',
        'da_DK' => 'Danes Simi (Dinamarca)',
        'da_GL' => 'Danes Simi (Groenlandia)',
        'de' => 'Aleman Simi',
        'de_AT' => 'Aleman Simi (Austria)',
        'de_BE' => 'Aleman Simi (Bélgica)',
        'de_CH' => 'Aleman Simi (Suiza)',
        'de_DE' => 'Aleman Simi (Alemania)',
        'de_IT' => 'Aleman Simi (Italia)',
        'de_LI' => 'Aleman Simi (Liechtenstein)',
        'de_LU' => 'Aleman Simi (Luxemburgo)',
        'dz' => 'Butanés Simi',
        'dz_BT' => 'Butanés Simi (Bután)',
        'ee' => 'Ewé Simi',
        'ee_GH' => 'Ewé Simi (Ghana)',
        'ee_TG' => 'Ewé Simi (Togo)',
        'el' => 'Griego Simi',
        'el_CY' => 'Griego Simi (Chipre)',
        'el_GR' => 'Griego Simi (Grecia)',
        'en' => 'Ingles Simi',
        'en_001' => 'Ingles Simi (Pacha)',
        'en_150' => 'Ingles Simi (Europa)',
        'en_AE' => 'Ingles Simi (Emiratos Árabes Unidos)',
        'en_AG' => 'Ingles Simi (Antigua y Barbuda)',
        'en_AI' => 'Ingles Simi (Anguila)',
        'en_AS' => 'Ingles Simi (Samoa Americana)',
        'en_AT' => 'Ingles Simi (Austria)',
        'en_AU' => 'Ingles Simi (Australia)',
        'en_BB' => 'Ingles Simi (Barbados)',
        'en_BE' => 'Ingles Simi (Bélgica)',
        'en_BI' => 'Ingles Simi (Burundi)',
        'en_BM' => 'Ingles Simi (Bermudas)',
        'en_BS' => 'Ingles Simi (Bahamas)',
        'en_BW' => 'Ingles Simi (Botsuana)',
        'en_BZ' => 'Ingles Simi (Belice)',
        'en_CA' => 'Ingles Simi (Canadá)',
        'en_CC' => 'Ingles Simi (Islas Cocos)',
        'en_CH' => 'Ingles Simi (Suiza)',
        'en_CK' => 'Ingles Simi (Islas Cook)',
        'en_CM' => 'Ingles Simi (Camerún)',
        'en_CX' => 'Ingles Simi (Isla Christmas)',
        'en_CY' => 'Ingles Simi (Chipre)',
        'en_DE' => 'Ingles Simi (Alemania)',
        'en_DK' => 'Ingles Simi (Dinamarca)',
        'en_DM' => 'Ingles Simi (Dominica)',
        'en_ER' => 'Ingles Simi (Eritrea)',
        'en_FI' => 'Ingles Simi (Finlandia)',
        'en_FJ' => 'Ingles Simi (Fiyi)',
        'en_FK' => 'Ingles Simi (Islas Malvinas)',
        'en_FM' => 'Ingles Simi (Micronesia)',
        'en_GB' => 'Ingles Simi (Reino Unido)',
        'en_GD' => 'Ingles Simi (Granada)',
        'en_GG' => 'Ingles Simi (Guernesey)',
        'en_GH' => 'Ingles Simi (Ghana)',
        'en_GI' => 'Ingles Simi (Gibraltar)',
        'en_GM' => 'Ingles Simi (Gambia)',
        'en_GU' => 'Ingles Simi (Guam)',
        'en_GY' => 'Ingles Simi (Guyana)',
        'en_HK' => 'Ingles Simi (Hong Kong RAE China)',
        'en_IE' => 'Ingles Simi (Irlanda)',
        'en_IL' => 'Ingles Simi (Israel)',
        'en_IM' => 'Ingles Simi (Isla de Man)',
        'en_IN' => 'Ingles Simi (India)',
        'en_IO' => 'Ingles Simi (Territorio Británico del Océano Índico)',
        'en_JE' => 'Ingles Simi (Jersey)',
        'en_JM' => 'Ingles Simi (Jamaica)',
        'en_KE' => 'Ingles Simi (Kenia)',
        'en_KI' => 'Ingles Simi (Kiribati)',
        'en_KN' => 'Ingles Simi (San Cristóbal y Nieves)',
        'en_KY' => 'Ingles Simi (Islas Caimán)',
        'en_LC' => 'Ingles Simi (Santa Lucia)',
        'en_LR' => 'Ingles Simi (Liberia)',
        'en_LS' => 'Ingles Simi (Lesoto)',
        'en_MG' => 'Ingles Simi (Madagascar)',
        'en_MH' => 'Ingles Simi (Islas Marshall)',
        'en_MO' => 'Ingles Simi (Macao RAE China)',
        'en_MP' => 'Ingles Simi (Islas Marianas del Norte)',
        'en_MS' => 'Ingles Simi (Montserrat)',
        'en_MT' => 'Ingles Simi (Malta)',
        'en_MU' => 'Ingles Simi (Mauricio)',
        'en_MV' => 'Ingles Simi (Maldivas)',
        'en_MW' => 'Ingles Simi (Malawi)',
        'en_MY' => 'Ingles Simi (Malasia)',
        'en_NA' => 'Ingles Simi (Namibia)',
        'en_NF' => 'Ingles Simi (Isla Norfolk)',
        'en_NG' => 'Ingles Simi (Nigeria)',
        'en_NL' => 'Ingles Simi (Países Bajos)',
        'en_NR' => 'Ingles Simi (Nauru)',
        'en_NU' => 'Ingles Simi (Niue)',
        'en_NZ' => 'Ingles Simi (Nueva Zelanda)',
        'en_PG' => 'Ingles Simi (Papúa Nueva Guinea)',
        'en_PH' => 'Ingles Simi (Filipinas)',
        'en_PK' => 'Ingles Simi (Pakistán)',
        'en_PN' => 'Ingles Simi (Islas Pitcairn)',
        'en_PR' => 'Ingles Simi (Puerto Rico)',
        'en_PW' => 'Ingles Simi (Palaos)',
        'en_RW' => 'Ingles Simi (Ruanda)',
        'en_SB' => 'Ingles Simi (Islas Salomón)',
        'en_SC' => 'Ingles Simi (Seychelles)',
        'en_SD' => 'Ingles Simi (Sudán)',
        'en_SE' => 'Ingles Simi (Suecia)',
        'en_SG' => 'Ingles Simi (Singapur)',
        'en_SH' => 'Ingles Simi (Santa Elena)',
        'en_SI' => 'Ingles Simi (Eslovenia)',
        'en_SL' => 'Ingles Simi (Sierra Leona)',
        'en_SS' => 'Ingles Simi (Sudán del Sur)',
        'en_SX' => 'Ingles Simi (Sint Maarten)',
        'en_SZ' => 'Ingles Simi (Esuatini)',
        'en_TC' => 'Ingles Simi (Islas Turcas y Caicos)',
        'en_TK' => 'Ingles Simi (Tokelau)',
        'en_TO' => 'Ingles Simi (Tonga)',
        'en_TT' => 'Ingles Simi (Trinidad y Tobago)',
        'en_TV' => 'Ingles Simi (Tuvalu)',
        'en_TZ' => 'Ingles Simi (Tanzania)',
        'en_UG' => 'Ingles Simi (Uganda)',
        'en_UM' => 'Ingles Simi (Islas menores alejadas de los EE.UU.)',
        'en_US' => 'Ingles Simi (Estados Unidos)',
        'en_VC' => 'Ingles Simi (San Vicente y las Granadinas)',
        'en_VG' => 'Ingles Simi (Islas Vírgenes Británicas)',
        'en_VI' => 'Ingles Simi (EE.UU. Islas Vírgenes)',
        'en_VU' => 'Ingles Simi (Vanuatu)',
        'en_WS' => 'Ingles Simi (Samoa)',
        'en_ZA' => 'Ingles Simi (Sudáfrica)',
        'en_ZM' => 'Ingles Simi (Zambia)',
        'en_ZW' => 'Ingles Simi (Zimbabue)',
        'eo' => 'Esperanto Simi',
        'eo_001' => 'Esperanto Simi (Pacha)',
        'es' => 'Español Simi',
        'es_419' => 'Español Simi (AmericaLatina)',
        'es_AR' => 'Español Simi (Argentina)',
        'es_BO' => 'Español Simi (Bolivia)',
        'es_BR' => 'Español Simi (Brasil)',
        'es_BZ' => 'Español Simi (Belice)',
        'es_CL' => 'Español Simi (Chile)',
        'es_CO' => 'Español Simi (Colombia)',
        'es_CR' => 'Español Simi (Costa Rica)',
        'es_CU' => 'Español Simi (Cuba)',
        'es_DO' => 'Español Simi (República Dominicana)',
        'es_EC' => 'Español Simi (Ecuador)',
        'es_ES' => 'Español Simi (España)',
        'es_GQ' => 'Español Simi (Guinea Ecuatorial)',
        'es_GT' => 'Español Simi (Guatemala)',
        'es_HN' => 'Español Simi (Honduras)',
        'es_MX' => 'Español Simi (México)',
        'es_NI' => 'Español Simi (Nicaragua)',
        'es_PA' => 'Español Simi (Panamá)',
        'es_PE' => 'Español Simi (Perú)',
        'es_PH' => 'Español Simi (Filipinas)',
        'es_PR' => 'Español Simi (Puerto Rico)',
        'es_PY' => 'Español Simi (Paraguay)',
        'es_SV' => 'Español Simi (El Salvador)',
        'es_US' => 'Español Simi (Estados Unidos)',
        'es_UY' => 'Español Simi (Uruguay)',
        'es_VE' => 'Español Simi (Venezuela)',
        'et' => 'Estonio Simi',
        'et_EE' => 'Estonio Simi (Estonia)',
        'eu' => 'Euskera Simi',
        'eu_ES' => 'Euskera Simi (España)',
        'fa' => 'Persa Simi',
        'fa_AF' => 'Persa Simi (Afganistán)',
        'fa_IR' => 'Persa Simi (Irán)',
        'ff' => 'Fulah Simi',
        'ff_Adlm' => 'Fulah Simi (Adlam Simi)',
        'ff_Adlm_BF' => 'Fulah Simi (Adlam Simi, Burkina Faso)',
        'ff_Adlm_CM' => 'Fulah Simi (Adlam Simi, Camerún)',
        'ff_Adlm_GH' => 'Fulah Simi (Adlam Simi, Ghana)',
        'ff_Adlm_GM' => 'Fulah Simi (Adlam Simi, Gambia)',
        'ff_Adlm_GN' => 'Fulah Simi (Adlam Simi, Guinea)',
        'ff_Adlm_GW' => 'Fulah Simi (Adlam Simi, Guinea-Bisáu)',
        'ff_Adlm_LR' => 'Fulah Simi (Adlam Simi, Liberia)',
        'ff_Adlm_MR' => 'Fulah Simi (Adlam Simi, Mauritania)',
        'ff_Adlm_NE' => 'Fulah Simi (Adlam Simi, Níger)',
        'ff_Adlm_NG' => 'Fulah Simi (Adlam Simi, Nigeria)',
        'ff_Adlm_SL' => 'Fulah Simi (Adlam Simi, Sierra Leona)',
        'ff_Adlm_SN' => 'Fulah Simi (Adlam Simi, Senegal)',
        'ff_CM' => 'Fulah Simi (Camerún)',
        'ff_GN' => 'Fulah Simi (Guinea)',
        'ff_Latn' => 'Fulah Simi (Latin Simi)',
        'ff_Latn_BF' => 'Fulah Simi (Latin Simi, Burkina Faso)',
        'ff_Latn_CM' => 'Fulah Simi (Latin Simi, Camerún)',
        'ff_Latn_GH' => 'Fulah Simi (Latin Simi, Ghana)',
        'ff_Latn_GM' => 'Fulah Simi (Latin Simi, Gambia)',
        'ff_Latn_GN' => 'Fulah Simi (Latin Simi, Guinea)',
        'ff_Latn_GW' => 'Fulah Simi (Latin Simi, Guinea-Bisáu)',
        'ff_Latn_LR' => 'Fulah Simi (Latin Simi, Liberia)',
        'ff_Latn_MR' => 'Fulah Simi (Latin Simi, Mauritania)',
        'ff_Latn_NE' => 'Fulah Simi (Latin Simi, Níger)',
        'ff_Latn_NG' => 'Fulah Simi (Latin Simi, Nigeria)',
        'ff_Latn_SL' => 'Fulah Simi (Latin Simi, Sierra Leona)',
        'ff_Latn_SN' => 'Fulah Simi (Latin Simi, Senegal)',
        'ff_MR' => 'Fulah Simi (Mauritania)',
        'ff_SN' => 'Fulah Simi (Senegal)',
        'fi' => 'Fines Simi',
        'fi_FI' => 'Fines Simi (Finlandia)',
        'fo' => 'Feroes Simi',
        'fo_DK' => 'Feroes Simi (Dinamarca)',
        'fo_FO' => 'Feroes Simi (Islas Feroe)',
        'fr' => 'Frances Simi',
        'fr_BE' => 'Frances Simi (Bélgica)',
        'fr_BF' => 'Frances Simi (Burkina Faso)',
        'fr_BI' => 'Frances Simi (Burundi)',
        'fr_BJ' => 'Frances Simi (Benín)',
        'fr_BL' => 'Frances Simi (San Bartolomé)',
        'fr_CA' => 'Frances Simi (Canadá)',
        'fr_CD' => 'Frances Simi (Congo [RDC])',
        'fr_CF' => 'Frances Simi (República Centroafricana)',
        'fr_CG' => 'Frances Simi (Congo)',
        'fr_CH' => 'Frances Simi (Suiza)',
        'fr_CI' => 'Frances Simi (Côte d’Ivoire)',
        'fr_CM' => 'Frances Simi (Camerún)',
        'fr_DJ' => 'Frances Simi (Yibuti)',
        'fr_DZ' => 'Frances Simi (Argelia)',
        'fr_FR' => 'Frances Simi (Francia)',
        'fr_GA' => 'Frances Simi (Gabón)',
        'fr_GF' => 'Frances Simi (Guayana Francesa)',
        'fr_GN' => 'Frances Simi (Guinea)',
        'fr_GP' => 'Frances Simi (Guadalupe)',
        'fr_GQ' => 'Frances Simi (Guinea Ecuatorial)',
        'fr_HT' => 'Frances Simi (Haití)',
        'fr_KM' => 'Frances Simi (Comoras)',
        'fr_LU' => 'Frances Simi (Luxemburgo)',
        'fr_MA' => 'Frances Simi (Marruecos)',
        'fr_MC' => 'Frances Simi (Mónaco)',
        'fr_MF' => 'Frances Simi (San Martín)',
        'fr_MG' => 'Frances Simi (Madagascar)',
        'fr_ML' => 'Frances Simi (Malí)',
        'fr_MQ' => 'Frances Simi (Martinica)',
        'fr_MR' => 'Frances Simi (Mauritania)',
        'fr_MU' => 'Frances Simi (Mauricio)',
        'fr_NC' => 'Frances Simi (Nueva Caledonia)',
        'fr_NE' => 'Frances Simi (Níger)',
        'fr_PF' => 'Frances Simi (Polinesia Francesa)',
        'fr_PM' => 'Frances Simi (San Pedro y Miquelón)',
        'fr_RE' => 'Frances Simi (Reunión)',
        'fr_RW' => 'Frances Simi (Ruanda)',
        'fr_SC' => 'Frances Simi (Seychelles)',
        'fr_SN' => 'Frances Simi (Senegal)',
        'fr_SY' => 'Frances Simi (Siria)',
        'fr_TD' => 'Frances Simi (Chad)',
        'fr_TG' => 'Frances Simi (Togo)',
        'fr_TN' => 'Frances Simi (Túnez)',
        'fr_VU' => 'Frances Simi (Vanuatu)',
        'fr_WF' => 'Frances Simi (Wallis y Futuna)',
        'fr_YT' => 'Frances Simi (Mayotte)',
        'fy' => 'Frison Simi',
        'fy_NL' => 'Frison Simi (Países Bajos)',
        'ga' => 'Irlandes Simi',
        'ga_GB' => 'Irlandes Simi (Reino Unido)',
        'ga_IE' => 'Irlandes Simi (Irlanda)',
        'gd' => 'Gaelico Escoces Simi',
        'gd_GB' => 'Gaelico Escoces Simi (Reino Unido)',
        'gl' => 'Gallego Simi',
        'gl_ES' => 'Gallego Simi (España)',
        'gu' => 'Gujarati Simi',
        'gu_IN' => 'Gujarati Simi (India)',
        'gv' => 'Manés Simi',
        'gv_IM' => 'Manés Simi (Isla de Man)',
        'ha' => 'Hausa Simi',
        'ha_GH' => 'Hausa Simi (Ghana)',
        'ha_NE' => 'Hausa Simi (Níger)',
        'ha_NG' => 'Hausa Simi (Nigeria)',
        'he' => 'Hebreo Simi',
        'he_IL' => 'Hebreo Simi (Israel)',
        'hi' => 'Hindi Simi',
        'hi_IN' => 'Hindi Simi (India)',
        'hi_Latn' => 'Hindi Simi (Latin Simi)',
        'hi_Latn_IN' => 'Hindi Simi (Latin Simi, India)',
        'hr' => 'Croata Simi',
        'hr_BA' => 'Croata Simi (Bosnia y Herzegovina)',
        'hr_HR' => 'Croata Simi (Croacia)',
        'hu' => 'Hungaro Simi',
        'hu_HU' => 'Hungaro Simi (Hungría)',
        'hy' => 'Armenio Simi',
        'hy_AM' => 'Armenio Simi (Armenia)',
        'ia' => 'Interlingua Simi',
        'ia_001' => 'Interlingua Simi (Pacha)',
        'id' => 'Indonesio Simi',
        'id_ID' => 'Indonesio Simi (Indonesia)',
        'ig' => 'Igbo Simi',
        'ig_NG' => 'Igbo Simi (Nigeria)',
        'ii' => 'Yi Simi',
        'ii_CN' => 'Yi Simi (China)',
        'is' => 'Islandes Simi',
        'is_IS' => 'Islandes Simi (Islandia)',
        'it' => 'Italiano Simi',
        'it_CH' => 'Italiano Simi (Suiza)',
        'it_IT' => 'Italiano Simi (Italia)',
        'it_SM' => 'Italiano Simi (San Marino)',
        'it_VA' => 'Italiano Simi (Santa Sede [Ciudad del Vaticano])',
        'ja' => 'Japones Simi',
        'ja_JP' => 'Japones Simi (Japón)',
        'jv' => 'Javanés Simi',
        'jv_ID' => 'Javanés Simi (Indonesia)',
        'ka' => 'Georgiano Simi',
        'ka_GE' => 'Georgiano Simi (Georgia)',
        'ki' => 'Kikuyu Simi',
        'ki_KE' => 'Kikuyu Simi (Kenia)',
        'kk' => 'Kazajo Simi',
        'kk_KZ' => 'Kazajo Simi (Kazajistán)',
        'kl' => 'Groenlandes Simi',
        'kl_GL' => 'Groenlandes Simi (Groenlandia)',
        'km' => 'Khmer Simi',
        'km_KH' => 'Khmer Simi (Camboya)',
        'kn' => 'Kannada Simi',
        'kn_IN' => 'Kannada Simi (India)',
        'ko' => 'Coreano Simi',
        'ko_KP' => 'Coreano Simi (Corea del Norte)',
        'ko_KR' => 'Coreano Simi (Corea del Sur)',
        'ks' => 'Cachemir Simi',
        'ks_Arab' => 'Cachemir Simi (Arabe Simi)',
        'ks_Arab_IN' => 'Cachemir Simi (Arabe Simi, India)',
        'ks_Deva' => 'Cachemir Simi (Devanagari)',
        'ks_Deva_IN' => 'Cachemir Simi (Devanagari, India)',
        'ks_IN' => 'Cachemir Simi (India)',
        'ku' => 'Kurdo Simi',
        'ku_TR' => 'Kurdo Simi (Turquía)',
        'kw' => 'Córnico Simi',
        'kw_GB' => 'Córnico Simi (Reino Unido)',
        'ky' => 'Kirghiz Simi',
        'ky_KG' => 'Kirghiz Simi (Kirguistán)',
        'lb' => 'Luxemburgues Simi',
        'lb_LU' => 'Luxemburgues Simi (Luxemburgo)',
        'lg' => 'Luganda Simi',
        'lg_UG' => 'Luganda Simi (Uganda)',
        'ln' => 'Lingala Simi',
        'ln_AO' => 'Lingala Simi (Angola)',
        'ln_CD' => 'Lingala Simi (Congo [RDC])',
        'ln_CF' => 'Lingala Simi (República Centroafricana)',
        'ln_CG' => 'Lingala Simi (Congo)',
        'lo' => 'Lao Simi',
        'lo_LA' => 'Lao Simi (Laos)',
        'lt' => 'Lituano Simi',
        'lt_LT' => 'Lituano Simi (Lituania)',
        'lu' => 'Luba-Katanga Simi',
        'lu_CD' => 'Luba-Katanga Simi (Congo [RDC])',
        'lv' => 'Leton Simi',
        'lv_LV' => 'Leton Simi (Letonia)',
        'mg' => 'Malgache Simi',
        'mg_MG' => 'Malgache Simi (Madagascar)',
        'mi' => 'Maori Simi',
        'mi_NZ' => 'Maori Simi (Nueva Zelanda)',
        'mk' => 'Macedonio Simi',
        'mk_MK' => 'Macedonio Simi (Macedonia del Norte)',
        'ml' => 'Malayalam Simi',
        'ml_IN' => 'Malayalam Simi (India)',
        'mn' => 'Mongol Simi',
        'mn_MN' => 'Mongol Simi (Mongolia)',
        'mr' => 'Marathi Simi',
        'mr_IN' => 'Marathi Simi (India)',
        'ms' => 'Malayo Simi',
        'ms_BN' => 'Malayo Simi (Brunéi)',
        'ms_ID' => 'Malayo Simi (Indonesia)',
        'ms_MY' => 'Malayo Simi (Malasia)',
        'ms_SG' => 'Malayo Simi (Singapur)',
        'mt' => 'Maltes Simi',
        'mt_MT' => 'Maltes Simi (Malta)',
        'my' => 'Birmano Simi',
        'my_MM' => 'Birmano Simi (Myanmar)',
        'nb' => 'Noruego Bokmål Simi',
        'nb_NO' => 'Noruego Bokmål Simi (Noruega)',
        'nb_SJ' => 'Noruego Bokmål Simi (Svalbard y Jan Mayen)',
        'nd' => 'Ndebele septentrional Simi',
        'nd_ZW' => 'Ndebele septentrional Simi (Zimbabue)',
        'ne' => 'Nepali Simi',
        'ne_IN' => 'Nepali Simi (India)',
        'ne_NP' => 'Nepali Simi (Nepal)',
        'nl' => 'Neerlandes Simi',
        'nl_AW' => 'Neerlandes Simi (Aruba)',
        'nl_BE' => 'Neerlandes Simi (Bélgica)',
        'nl_BQ' => 'Neerlandes Simi (Bonaire)',
        'nl_CW' => 'Neerlandes Simi (Curazao)',
        'nl_NL' => 'Neerlandes Simi (Países Bajos)',
        'nl_SR' => 'Neerlandes Simi (Surinam)',
        'nl_SX' => 'Neerlandes Simi (Sint Maarten)',
        'nn' => 'Noruego Nynorsk Simi',
        'nn_NO' => 'Noruego Nynorsk Simi (Noruega)',
        'no' => 'Noruego Simi',
        'no_NO' => 'Noruego Simi (Noruega)',
        'om' => 'Oromo Simi',
        'om_ET' => 'Oromo Simi (Etiopía)',
        'om_KE' => 'Oromo Simi (Kenia)',
        'or' => 'Odia Simi',
        'or_IN' => 'Odia Simi (India)',
        'os' => 'Osetio Simi',
        'os_GE' => 'Osetio Simi (Georgia)',
        'os_RU' => 'Osetio Simi (Rusia)',
        'pa' => 'Punyabi Simi',
        'pa_Arab' => 'Punyabi Simi (Arabe Simi)',
        'pa_Arab_PK' => 'Punyabi Simi (Arabe Simi, Pakistán)',
        'pa_Guru' => 'Punyabi Simi (Gurmukhi Simi)',
        'pa_Guru_IN' => 'Punyabi Simi (Gurmukhi Simi, India)',
        'pa_IN' => 'Punyabi Simi (India)',
        'pa_PK' => 'Punyabi Simi (Pakistán)',
        'pl' => 'Polaco Simi',
        'pl_PL' => 'Polaco Simi (Polonia)',
        'ps' => 'Pashto Simi',
        'ps_AF' => 'Pashto Simi (Afganistán)',
        'ps_PK' => 'Pashto Simi (Pakistán)',
        'pt' => 'Portugues Simi',
        'pt_AO' => 'Portugues Simi (Angola)',
        'pt_BR' => 'Portugues Simi (Brasil)',
        'pt_CH' => 'Portugues Simi (Suiza)',
        'pt_CV' => 'Portugues Simi (Cabo Verde)',
        'pt_GQ' => 'Portugues Simi (Guinea Ecuatorial)',
        'pt_GW' => 'Portugues Simi (Guinea-Bisáu)',
        'pt_LU' => 'Portugues Simi (Luxemburgo)',
        'pt_MO' => 'Portugues Simi (Macao RAE China)',
        'pt_MZ' => 'Portugues Simi (Mozambique)',
        'pt_PT' => 'Portugues Simi (Portugal)',
        'pt_ST' => 'Portugues Simi (Santo Tomé y Príncipe)',
        'pt_TL' => 'Portugues Simi (Timor-Leste)',
        'qu' => 'Runasimi',
        'qu_BO' => 'Runasimi (Bolivia)',
        'qu_EC' => 'Runasimi (Ecuador)',
        'qu_PE' => 'Runasimi (Perú)',
        'rm' => 'Romanche Simi',
        'rm_CH' => 'Romanche Simi (Suiza)',
        'rn' => 'Rundi Simi',
        'rn_BI' => 'Rundi Simi (Burundi)',
        'ro' => 'Rumano Simi',
        'ro_MD' => 'Rumano Simi (Moldova)',
        'ro_RO' => 'Rumano Simi (Rumania)',
        'ru' => 'Ruso Simi',
        'ru_BY' => 'Ruso Simi (Belarús)',
        'ru_KG' => 'Ruso Simi (Kirguistán)',
        'ru_KZ' => 'Ruso Simi (Kazajistán)',
        'ru_MD' => 'Ruso Simi (Moldova)',
        'ru_RU' => 'Ruso Simi (Rusia)',
        'ru_UA' => 'Ruso Simi (Ucrania)',
        'rw' => 'Kinyarwanda Simi',
        'rw_RW' => 'Kinyarwanda Simi (Ruanda)',
        'sa' => 'Sanscrito Simi',
        'sa_IN' => 'Sanscrito Simi (India)',
        'sc' => 'Sardinian Simi',
        'sc_IT' => 'Sardinian Simi (Italia)',
        'sd' => 'Sindhi Simi',
        'sd_Arab' => 'Sindhi Simi (Arabe Simi)',
        'sd_Arab_PK' => 'Sindhi Simi (Arabe Simi, Pakistán)',
        'sd_Deva' => 'Sindhi Simi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi Simi (Devanagari, India)',
        'sd_IN' => 'Sindhi Simi (India)',
        'sd_PK' => 'Sindhi Simi (Pakistán)',
        'se' => 'Chincha Sami Simi',
        'se_FI' => 'Chincha Sami Simi (Finlandia)',
        'se_NO' => 'Chincha Sami Simi (Noruega)',
        'se_SE' => 'Chincha Sami Simi (Suecia)',
        'sg' => 'Sango Simi',
        'sg_CF' => 'Sango Simi (República Centroafricana)',
        'si' => 'Cingales Simi',
        'si_LK' => 'Cingales Simi (Sri Lanka)',
        'sk' => 'Eslovaco Simi',
        'sk_SK' => 'Eslovaco Simi (Eslovaquia)',
        'sl' => 'Esloveno Simi',
        'sl_SI' => 'Esloveno Simi (Eslovenia)',
        'sn' => 'Shona Simi',
        'sn_ZW' => 'Shona Simi (Zimbabue)',
        'so' => 'Somali Simi',
        'so_DJ' => 'Somali Simi (Yibuti)',
        'so_ET' => 'Somali Simi (Etiopía)',
        'so_KE' => 'Somali Simi (Kenia)',
        'so_SO' => 'Somali Simi (Somalia)',
        'sq' => 'Albanes Simi',
        'sq_AL' => 'Albanes Simi (Albania)',
        'sq_MK' => 'Albanes Simi (Macedonia del Norte)',
        'sr' => 'Serbio Simi',
        'sr_BA' => 'Serbio Simi (Bosnia y Herzegovina)',
        'sr_Cyrl' => 'Serbio Simi (Cirilico)',
        'sr_Cyrl_BA' => 'Serbio Simi (Cirilico, Bosnia y Herzegovina)',
        'sr_Cyrl_ME' => 'Serbio Simi (Cirilico, Montenegro)',
        'sr_Cyrl_RS' => 'Serbio Simi (Cirilico, Serbia)',
        'sr_Latn' => 'Serbio Simi (Latin Simi)',
        'sr_Latn_BA' => 'Serbio Simi (Latin Simi, Bosnia y Herzegovina)',
        'sr_Latn_ME' => 'Serbio Simi (Latin Simi, Montenegro)',
        'sr_Latn_RS' => 'Serbio Simi (Latin Simi, Serbia)',
        'sr_ME' => 'Serbio Simi (Montenegro)',
        'sr_RS' => 'Serbio Simi (Serbia)',
        'su' => 'Sundanés Simi',
        'su_ID' => 'Sundanés Simi (Indonesia)',
        'su_Latn' => 'Sundanés Simi (Latin Simi)',
        'su_Latn_ID' => 'Sundanés Simi (Latin Simi, Indonesia)',
        'sv' => 'Sueco Simi',
        'sv_AX' => 'Sueco Simi (Islas Åland)',
        'sv_FI' => 'Sueco Simi (Finlandia)',
        'sv_SE' => 'Sueco Simi (Suecia)',
        'sw' => 'Suajili Simi',
        'sw_CD' => 'Suajili Simi (Congo [RDC])',
        'sw_KE' => 'Suajili Simi (Kenia)',
        'sw_TZ' => 'Suajili Simi (Tanzania)',
        'sw_UG' => 'Suajili Simi (Uganda)',
        'ta' => 'Tamil Simi',
        'ta_IN' => 'Tamil Simi (India)',
        'ta_LK' => 'Tamil Simi (Sri Lanka)',
        'ta_MY' => 'Tamil Simi (Malasia)',
        'ta_SG' => 'Tamil Simi (Singapur)',
        'te' => 'Telugu Simi',
        'te_IN' => 'Telugu Simi (India)',
        'tg' => 'Tayiko Simi',
        'tg_TJ' => 'Tayiko Simi (Tayikistán)',
        'th' => 'Tailandes Simi',
        'th_TH' => 'Tailandes Simi (Tailandia)',
        'ti' => 'Tigriña Simi',
        'ti_ER' => 'Tigriña Simi (Eritrea)',
        'ti_ET' => 'Tigriña Simi (Etiopía)',
        'tk' => 'Turcomano Simi',
        'tk_TM' => 'Turcomano Simi (Turkmenistán)',
        'to' => 'Tongano Simi',
        'to_TO' => 'Tongano Simi (Tonga)',
        'tr' => 'Turco Simi',
        'tr_CY' => 'Turco Simi (Chipre)',
        'tr_TR' => 'Turco Simi (Turquía)',
        'tt' => 'Tartaro Simi',
        'tt_RU' => 'Tartaro Simi (Rusia)',
        'ug' => 'Uigur Simi',
        'ug_CN' => 'Uigur Simi (China)',
        'uk' => 'Ucraniano Simi',
        'uk_UA' => 'Ucraniano Simi (Ucrania)',
        'ur' => 'Urdu Simi',
        'ur_IN' => 'Urdu Simi (India)',
        'ur_PK' => 'Urdu Simi (Pakistán)',
        'uz' => 'Uzbeko Simi',
        'uz_AF' => 'Uzbeko Simi (Afganistán)',
        'uz_Arab' => 'Uzbeko Simi (Arabe Simi)',
        'uz_Arab_AF' => 'Uzbeko Simi (Arabe Simi, Afganistán)',
        'uz_Cyrl' => 'Uzbeko Simi (Cirilico)',
        'uz_Cyrl_UZ' => 'Uzbeko Simi (Cirilico, Uzbekistán)',
        'uz_Latn' => 'Uzbeko Simi (Latin Simi)',
        'uz_Latn_UZ' => 'Uzbeko Simi (Latin Simi, Uzbekistán)',
        'uz_UZ' => 'Uzbeko Simi (Uzbekistán)',
        'vi' => 'Vietnamita Simi',
        'vi_VN' => 'Vietnamita Simi (Vietnam)',
        'wo' => 'Wolof Simi',
        'wo_SN' => 'Wolof Simi (Senegal)',
        'xh' => 'Isixhosa Simi',
        'xh_ZA' => 'Isixhosa Simi (Sudáfrica)',
        'yi' => 'Yiddish Simi',
        'yi_001' => 'Yiddish Simi (Pacha)',
        'yo' => 'Yoruba Simi',
        'yo_BJ' => 'Yoruba Simi (Benín)',
        'yo_NG' => 'Yoruba Simi (Nigeria)',
        'zh' => 'Chino Simi',
        'zh_CN' => 'Chino Simi (China)',
        'zh_HK' => 'Chino Simi (Hong Kong RAE China)',
        'zh_Hans' => 'Chino Simi (Simplificado)',
        'zh_Hans_CN' => 'Chino Simi (Simplificado, China)',
        'zh_Hans_HK' => 'Chino Simi (Simplificado, Hong Kong RAE China)',
        'zh_Hans_MO' => 'Chino Simi (Simplificado, Macao RAE China)',
        'zh_Hans_SG' => 'Chino Simi (Simplificado, Singapur)',
        'zh_Hant' => 'Chino Simi (Tradicional)',
        'zh_Hant_HK' => 'Chino Simi (Tradicional, Hong Kong RAE China)',
        'zh_Hant_MO' => 'Chino Simi (Tradicional, Macao RAE China)',
        'zh_Hant_TW' => 'Chino Simi (Tradicional, Taiwán)',
        'zh_MO' => 'Chino Simi (Macao RAE China)',
        'zh_SG' => 'Chino Simi (Singapur)',
        'zh_TW' => 'Chino Simi (Taiwán)',
        'zu' => 'Isizulu Simi',
        'zu_ZA' => 'Isizulu Simi (Sudáfrica)',
    ],
];
