<?php

return [
    'Names' => [
        'Adlm' => 'አድላም',
        'Arab' => 'ዓረብኛ',
        'Aran' => 'ናስታሊክ',
        'Armn' => 'አርሜንያዊ',
        'Beng' => 'ቤንጋሊ',
        'Bopo' => 'ቦፖሞፎ',
        'Brai' => 'ብሬይል',
        'Buhd' => 'ቡሂድ',
        'Cakm' => 'ቻክማ',
        'Cans' => 'የተዋሐዱ የካናዳ ጥንታዊ ምልክቶች',
        'Cher' => 'ቼሮኪ',
        'Copt' => 'ኮፕቲክ',
        'Cprt' => 'ሲፕሪኦት',
        'Cyrl' => 'ሲይሪልክ',
        'Deva' => 'ደቫንጋሪ',
        'Dsrt' => 'ዴዘረት',
        'Ethi' => 'ኢትዮፒክ',
        'Geor' => 'ጆርጂያዊ',
        'Goth' => 'ጐቲክ',
        'Grek' => 'ግሪክ',
        'Gujr' => 'ጉጃራቲ',
        'Guru' => 'ጉርሙኪ',
        'Hanb' => 'ሃንብ',
        'Hang' => 'ሐንጉል',
        'Hani' => 'ሃን',
        'Hano' => 'ሀኑኦ',
        'Hans' => 'ቀለል ያለ',
        'Hant' => 'ባህላዊ',
        'Hebr' => 'እብራይስጥ',
        'Hira' => 'ሂራጋና',
        'Hrkt' => 'ካታካና ወይንም ሂራጋና',
        'Jamo' => 'ጃሞ',
        'Jpan' => 'ጃፓንኛ',
        'Kana' => 'ካታካና',
        'Khmr' => 'ክህመር',
        'Knda' => 'ካንአዳ',
        'Kore' => 'ኮሪያኛ',
        'Laoo' => 'ላኦ',
        'Latn' => 'ላቲን',
        'Limb' => 'ሊምቡ',
        'Lina' => 'ሊኒያር ኤ',
        'Linb' => 'ሊኒያር ቢ',
        'Mlym' => 'ማላያልም',
        'Mong' => 'ሞንጎሊያኛ',
        'Mtei' => 'ሜቴ ማይክ',
        'Mymr' => 'ምያንማር',
        'Nkoo' => 'ንኮ',
        'Ogam' => 'ኦግሀም',
        'Olck' => 'ኦይ ቺኪ',
        'Orya' => 'ኦሪያ',
        'Osma' => 'ኦስማኒያ',
        'Rohg' => 'ሃኒፊ',
        'Runr' => 'ሩኒክ',
        'Shaw' => 'የሻቪያ ፊደል',
        'Sinh' => 'ሲንሃላ',
        'Sund' => 'ሱዳናዊ',
        'Syrc' => 'ሲሪክ',
        'Tagb' => 'ትአግባንዋ',
        'Tale' => 'ታኢ ለ',
        'Talu' => 'አዲስ ታኢ ሉ',
        'Taml' => 'ታሚል',
        'Telu' => 'ተሉጉ',
        'Tfng' => 'ቲፊናግህ',
        'Tglg' => 'ታጋሎግ',
        'Thaa' => 'ታና',
        'Thai' => 'ታይ',
        'Tibt' => 'ቲቤታን',
        'Ugar' => 'ኡጋሪቲክ',
        'Vaii' => 'ቫይ',
        'Yiii' => 'ዪ',
        'Zinh' => 'የተወረሰ',
        'Zmth' => 'የሂሳብ መግለጫ',
        'Zsye' => 'ኢሞጂ',
        'Zsym' => 'ምልክቶች',
        'Zxxx' => 'ያልተጻፈ',
        'Zyyy' => 'የጋራ',
    ],
];
