<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвичы рӕстӕмбис рӕстӕг (Abidjan)',
        'Africa/Accra' => 'Гринвичы рӕстӕмбис рӕстӕг (Accra)',
        'Africa/Algiers' => 'Астӕуккаг Европӕйаг рӕстӕг (Algiers)',
        'Africa/Bamako' => 'Гринвичы рӕстӕмбис рӕстӕг (Bamako)',
        'Africa/Banjul' => 'Гринвичы рӕстӕмбис рӕстӕг (Banjul)',
        'Africa/Bissau' => 'Гринвичы рӕстӕмбис рӕстӕг (Bissau)',
        'Africa/Cairo' => 'Скӕсӕн Европӕйаг рӕстӕг (Cairo)',
        'Africa/Casablanca' => 'Ныгъуылӕн Европӕйаг рӕстӕг (Casablanca)',
        'Africa/Ceuta' => 'Астӕуккаг Европӕйаг рӕстӕг (Ceuta)',
        'Africa/Conakry' => 'Гринвичы рӕстӕмбис рӕстӕг (Conakry)',
        'Africa/Dakar' => 'Гринвичы рӕстӕмбис рӕстӕг (Dakar)',
        'Africa/El_Aaiun' => 'Ныгъуылӕн Европӕйаг рӕстӕг (El Aaiun)',
        'Africa/Freetown' => 'Гринвичы рӕстӕмбис рӕстӕг (Freetown)',
        'Africa/Lome' => 'Гринвичы рӕстӕмбис рӕстӕг (Lome)',
        'Africa/Monrovia' => 'Гринвичы рӕстӕмбис рӕстӕг (Monrovia)',
        'Africa/Nouakchott' => 'Гринвичы рӕстӕмбис рӕстӕг (Nouakchott)',
        'Africa/Ouagadougou' => 'Гринвичы рӕстӕмбис рӕстӕг (Ouagadougou)',
        'Africa/Sao_Tome' => 'Гринвичы рӕстӕмбис рӕстӕг (Sao Tome)',
        'Africa/Tripoli' => 'Скӕсӕн Европӕйаг рӕстӕг (Tripoli)',
        'Africa/Tunis' => 'Астӕуккаг Европӕйаг рӕстӕг (Tunis)',
        'America/Adak' => 'АИШ рӕстӕг (Adak)',
        'America/Anchorage' => 'АИШ рӕстӕг (Anchorage)',
        'America/Araguaina' => 'Бразили рӕстӕг (Araguaina)',
        'America/Bahia' => 'Бразили рӕстӕг (Bahia)',
        'America/Belem' => 'Бразили рӕстӕг (Belem)',
        'America/Boa_Vista' => 'Бразили рӕстӕг (Boa Vista)',
        'America/Boise' => 'АИШ рӕстӕг (Boise)',
        'America/Campo_Grande' => 'Бразили рӕстӕг (Campo Grande)',
        'America/Chicago' => 'АИШ рӕстӕг (Chicago)',
        'America/Cuiaba' => 'Бразили рӕстӕг (Cuiaba)',
        'America/Danmarkshavn' => 'Гринвичы рӕстӕмбис рӕстӕг (Danmarkshavn)',
        'America/Denver' => 'АИШ рӕстӕг (Denver)',
        'America/Detroit' => 'АИШ рӕстӕг (Detroit)',
        'America/Eirunepe' => 'Бразили рӕстӕг (Eirunepe)',
        'America/Fortaleza' => 'Бразили рӕстӕг (Fortaleza)',
        'America/Indiana/Knox' => 'АИШ рӕстӕг (Knox, Indiana)',
        'America/Indiana/Marengo' => 'АИШ рӕстӕг (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'АИШ рӕстӕг (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'АИШ рӕстӕг (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'АИШ рӕстӕг (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'АИШ рӕстӕг (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'АИШ рӕстӕг (Winamac, Indiana)',
        'America/Indianapolis' => 'АИШ рӕстӕг (Indianapolis)',
        'America/Juneau' => 'АИШ рӕстӕг (Juneau)',
        'America/Kentucky/Monticello' => 'АИШ рӕстӕг (Monticello, Kentucky)',
        'America/Los_Angeles' => 'АИШ рӕстӕг (Los Angeles)',
        'America/Louisville' => 'АИШ рӕстӕг (Louisville)',
        'America/Maceio' => 'Бразили рӕстӕг (Maceio)',
        'America/Manaus' => 'Бразили рӕстӕг (Manaus)',
        'America/Menominee' => 'АИШ рӕстӕг (Menominee)',
        'America/Metlakatla' => 'АИШ рӕстӕг (Metlakatla)',
        'America/New_York' => 'АИШ рӕстӕг (New York)',
        'America/Nome' => 'АИШ рӕстӕг (Nome)',
        'America/Noronha' => 'Бразили рӕстӕг (Noronha)',
        'America/North_Dakota/Beulah' => 'АИШ рӕстӕг (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'АИШ рӕстӕг (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'АИШ рӕстӕг (New Salem, North Dakota)',
        'America/Phoenix' => 'АИШ рӕстӕг (Phoenix)',
        'America/Porto_Velho' => 'Бразили рӕстӕг (Porto Velho)',
        'America/Recife' => 'Бразили рӕстӕг (Recife)',
        'America/Rio_Branco' => 'Бразили рӕстӕг (Rio Branco)',
        'America/Santarem' => 'Бразили рӕстӕг (Santarem)',
        'America/Sao_Paulo' => 'Бразили рӕстӕг (Sao Paulo)',
        'America/Sitka' => 'АИШ рӕстӕг (Sitka)',
        'America/Yakutat' => 'АИШ рӕстӕг (Yakutat)',
        'Antarctica/Troll' => 'Гринвичы рӕстӕмбис рӕстӕг (Troll)',
        'Arctic/Longyearbyen' => 'Астӕуккаг Европӕйаг рӕстӕг (Longyearbyen)',
        'Asia/Amman' => 'Скӕсӕн Европӕйаг рӕстӕг (Amman)',
        'Asia/Anadyr' => 'Уӕрӕсе рӕстӕг (Anadyr)',
        'Asia/Barnaul' => 'Уӕрӕсе рӕстӕг (Barnaul)',
        'Asia/Beirut' => 'Скӕсӕн Европӕйаг рӕстӕг (Beirut)',
        'Asia/Calcutta' => 'Инди рӕстӕг (Kolkata)',
        'Asia/Chita' => 'Уӕрӕсе рӕстӕг (Chita)',
        'Asia/Damascus' => 'Скӕсӕн Европӕйаг рӕстӕг (Damascus)',
        'Asia/Famagusta' => 'Скӕсӕн Европӕйаг рӕстӕг (Famagusta)',
        'Asia/Gaza' => 'Скӕсӕн Европӕйаг рӕстӕг (Gaza)',
        'Asia/Hebron' => 'Скӕсӕн Европӕйаг рӕстӕг (Hebron)',
        'Asia/Irkutsk' => 'Уӕрӕсе рӕстӕг (Irkutsk)',
        'Asia/Kamchatka' => 'Уӕрӕсе рӕстӕг (Kamchatka)',
        'Asia/Khandyga' => 'Уӕрӕсе рӕстӕг (Khandyga)',
        'Asia/Krasnoyarsk' => 'Уӕрӕсе рӕстӕг (Krasnoyarsk)',
        'Asia/Magadan' => 'Уӕрӕсе рӕстӕг (Magadan)',
        'Asia/Nicosia' => 'Скӕсӕн Европӕйаг рӕстӕг (Nicosia)',
        'Asia/Novokuznetsk' => 'Уӕрӕсе рӕстӕг (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Уӕрӕсе рӕстӕг (Novosibirsk)',
        'Asia/Omsk' => 'Уӕрӕсе рӕстӕг (Omsk)',
        'Asia/Sakhalin' => 'Уӕрӕсе рӕстӕг (Sakhalin)',
        'Asia/Shanghai' => 'Китай рӕстӕг (Shanghai)',
        'Asia/Srednekolymsk' => 'Уӕрӕсе рӕстӕг (Srednekolymsk)',
        'Asia/Tbilisi' => 'Гуырдзыстоны рӕстӕг (Тбилис)',
        'Asia/Tokyo' => 'Япон рӕстӕг (Tokyo)',
        'Asia/Tomsk' => 'Уӕрӕсе рӕстӕг (Tomsk)',
        'Asia/Urumqi' => 'Китай рӕстӕг (Urumqi)',
        'Asia/Ust-Nera' => 'Уӕрӕсе рӕстӕг (Ust-Nera)',
        'Asia/Vladivostok' => 'Уӕрӕсе рӕстӕг (Vladivostok)',
        'Asia/Yakutsk' => 'Уӕрӕсе рӕстӕг (Yakutsk)',
        'Asia/Yekaterinburg' => 'Уӕрӕсе рӕстӕг (Yekaterinburg)',
        'Atlantic/Canary' => 'Ныгъуылӕн Европӕйаг рӕстӕг (Canary)',
        'Atlantic/Faeroe' => 'Ныгъуылӕн Европӕйаг рӕстӕг (Faroe)',
        'Atlantic/Madeira' => 'Ныгъуылӕн Европӕйаг рӕстӕг (Madeira)',
        'Atlantic/Reykjavik' => 'Гринвичы рӕстӕмбис рӕстӕг (Reykjavik)',
        'Atlantic/St_Helena' => 'Гринвичы рӕстӕмбис рӕстӕг (St. Helena)',
        'Etc/GMT' => 'Гринвичы рӕстӕмбис рӕстӕг',
        'Europe/Amsterdam' => 'Астӕуккаг Европӕйаг рӕстӕг (Amsterdam)',
        'Europe/Andorra' => 'Астӕуккаг Европӕйаг рӕстӕг (Andorra)',
        'Europe/Astrakhan' => 'Мӕскуыйы рӕстӕг (Astrakhan)',
        'Europe/Athens' => 'Скӕсӕн Европӕйаг рӕстӕг (Athens)',
        'Europe/Belgrade' => 'Астӕуккаг Европӕйаг рӕстӕг (Belgrade)',
        'Europe/Berlin' => 'Астӕуккаг Европӕйаг рӕстӕг (Berlin)',
        'Europe/Bratislava' => 'Астӕуккаг Европӕйаг рӕстӕг (Bratislava)',
        'Europe/Brussels' => 'Астӕуккаг Европӕйаг рӕстӕг (Brussels)',
        'Europe/Bucharest' => 'Скӕсӕн Европӕйаг рӕстӕг (Bucharest)',
        'Europe/Budapest' => 'Астӕуккаг Европӕйаг рӕстӕг (Budapest)',
        'Europe/Busingen' => 'Астӕуккаг Европӕйаг рӕстӕг (Busingen)',
        'Europe/Chisinau' => 'Скӕсӕн Европӕйаг рӕстӕг (Chisinau)',
        'Europe/Copenhagen' => 'Астӕуккаг Европӕйаг рӕстӕг (Copenhagen)',
        'Europe/Dublin' => 'Гринвичы рӕстӕмбис рӕстӕг (Dublin)',
        'Europe/Gibraltar' => 'Астӕуккаг Европӕйаг рӕстӕг (Gibraltar)',
        'Europe/Guernsey' => 'Гринвичы рӕстӕмбис рӕстӕг (Guernsey)',
        'Europe/Helsinki' => 'Скӕсӕн Европӕйаг рӕстӕг (Helsinki)',
        'Europe/Isle_of_Man' => 'Гринвичы рӕстӕмбис рӕстӕг (Isle of Man)',
        'Europe/Jersey' => 'Гринвичы рӕстӕмбис рӕстӕг (Jersey)',
        'Europe/Kaliningrad' => 'Скӕсӕн Европӕйаг рӕстӕг (Kaliningrad)',
        'Europe/Kiev' => 'Скӕсӕн Европӕйаг рӕстӕг (Kyiv)',
        'Europe/Kirov' => 'Уӕрӕсе рӕстӕг (Kirov)',
        'Europe/Lisbon' => 'Ныгъуылӕн Европӕйаг рӕстӕг (Lisbon)',
        'Europe/Ljubljana' => 'Астӕуккаг Европӕйаг рӕстӕг (Ljubljana)',
        'Europe/London' => 'Гринвичы рӕстӕмбис рӕстӕг (London)',
        'Europe/Luxembourg' => 'Астӕуккаг Европӕйаг рӕстӕг (Luxembourg)',
        'Europe/Madrid' => 'Астӕуккаг Европӕйаг рӕстӕг (Madrid)',
        'Europe/Malta' => 'Астӕуккаг Европӕйаг рӕстӕг (Malta)',
        'Europe/Mariehamn' => 'Скӕсӕн Европӕйаг рӕстӕг (Mariehamn)',
        'Europe/Minsk' => 'Мӕскуыйы рӕстӕг (Минск)',
        'Europe/Monaco' => 'Астӕуккаг Европӕйаг рӕстӕг (Monaco)',
        'Europe/Moscow' => 'Мӕскуыйы рӕстӕг',
        'Europe/Oslo' => 'Астӕуккаг Европӕйаг рӕстӕг (Oslo)',
        'Europe/Paris' => 'Астӕуккаг Европӕйаг рӕстӕг (Paris)',
        'Europe/Podgorica' => 'Астӕуккаг Европӕйаг рӕстӕг (Podgorica)',
        'Europe/Prague' => 'Астӕуккаг Европӕйаг рӕстӕг (Prague)',
        'Europe/Riga' => 'Скӕсӕн Европӕйаг рӕстӕг (Riga)',
        'Europe/Rome' => 'Астӕуккаг Европӕйаг рӕстӕг (Rome)',
        'Europe/Samara' => 'Уӕрӕсе рӕстӕг (Samara)',
        'Europe/San_Marino' => 'Астӕуккаг Европӕйаг рӕстӕг (San Marino)',
        'Europe/Sarajevo' => 'Астӕуккаг Европӕйаг рӕстӕг (Sarajevo)',
        'Europe/Saratov' => 'Мӕскуыйы рӕстӕг (Saratov)',
        'Europe/Simferopol' => 'Мӕскуыйы рӕстӕг (Simferopol)',
        'Europe/Skopje' => 'Астӕуккаг Европӕйаг рӕстӕг (Skopje)',
        'Europe/Sofia' => 'Скӕсӕн Европӕйаг рӕстӕг (Sofia)',
        'Europe/Stockholm' => 'Астӕуккаг Европӕйаг рӕстӕг (Stockholm)',
        'Europe/Tallinn' => 'Скӕсӕн Европӕйаг рӕстӕг (Tallinn)',
        'Europe/Tirane' => 'Астӕуккаг Европӕйаг рӕстӕг (Tirane)',
        'Europe/Ulyanovsk' => 'Мӕскуыйы рӕстӕг (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Скӕсӕн Европӕйаг рӕстӕг (Uzhgorod)',
        'Europe/Vaduz' => 'Астӕуккаг Европӕйаг рӕстӕг (Vaduz)',
        'Europe/Vatican' => 'Астӕуккаг Европӕйаг рӕстӕг (Vatican)',
        'Europe/Vienna' => 'Астӕуккаг Европӕйаг рӕстӕг (Vienna)',
        'Europe/Vilnius' => 'Скӕсӕн Европӕйаг рӕстӕг (Vilnius)',
        'Europe/Volgograd' => 'Уӕрӕсе рӕстӕг (Volgograd)',
        'Europe/Warsaw' => 'Астӕуккаг Европӕйаг рӕстӕг (Warsaw)',
        'Europe/Zagreb' => 'Астӕуккаг Европӕйаг рӕстӕг (Zagreb)',
        'Europe/Zaporozhye' => 'Скӕсӕн Европӕйаг рӕстӕг (Zaporozhye)',
        'Europe/Zurich' => 'Астӕуккаг Европӕйаг рӕстӕг (Zurich)',
        'Pacific/Honolulu' => 'АИШ рӕстӕг (Honolulu)',
    ],
    'Meta' => [
    ],
];
