<?php

return [
    'Names' => [
        'ab' => 'abkhaziagbe',
        'af' => 'afrikaangbe',
        'agq' => 'aghemgbe',
        'ak' => 'blugbe',
        'am' => 'amhariagbe',
        'ar' => 'Arabiagbe',
        'as' => 'assamegbe',
        'asa' => 'asagbe',
        'ay' => 'aymargbe',
        'az' => 'azerbaijangbe',
        'be' => 'belarusiagbe',
        'bem' => 'bembagbe',
        'bez' => 'benagbe',
        'bg' => 'bulgariagbe',
        'bm' => 'bambaragbe',
        'bn' => 'Bengaligbe',
        'bo' => 'tibetagbe',
        'br' => 'bretongbe',
        'brx' => 'bodogbe',
        'bs' => 'bosniagbe',
        'ca' => 'katalagbe',
        'cs' => 'tsɛkgbe',
        'cy' => 'walesgbe',
        'da' => 'denmarkgbe',
        'de' => 'Germaniagbe',
        'dv' => 'divehgbe',
        'dz' => 'dzongkhagbe',
        'ebu' => 'embugbe',
        'ee' => 'Eʋegbe',
        'efi' => 'efigbe',
        'el' => 'grisigbe',
        'en' => 'Yevugbe',
        'eo' => 'esperantogbe',
        'es' => 'Spanishgbe',
        'et' => 'estoniagbe',
        'eu' => 'basqugbe',
        'fa' => 'persiagbe',
        'fi' => 'finlanɖgbe',
        'fil' => 'filipingbe',
        'fj' => 'fidzigbe',
        'fr' => 'Fransegbe',
        'ga' => 'irelanɖgbe',
        'gl' => 'galatagbe',
        'gn' => 'guarangbe',
        'gsw' => 'swizerlanɖtɔwo ƒe germaniagbe',
        'gu' => 'gujarati',
        'ha' => 'hausagbe',
        'haw' => 'hawaigbe',
        'he' => 'hebrigbe',
        'hi' => 'Hindigbe',
        'hr' => 'kroatiagbe',
        'ht' => 'haitigbe',
        'hu' => 'hungarigbe',
        'hy' => 'armeniagbe',
        'id' => 'Indonesiagbe',
        'ig' => 'igbogbe',
        'is' => 'icelanɖgbe',
        'it' => 'Italiagbe',
        'ja' => 'Japangbe',
        'jv' => 'dzavangbe',
        'ka' => 'gɔgiagbe',
        'kea' => 'cape verdegbe',
        'kk' => 'kazakhstangbe',
        'km' => 'khmergbe',
        'kn' => 'kannadagbe',
        'ko' => 'Koreagbe',
        'ks' => 'kashmirgbe',
        'ku' => 'kurdiagbe',
        'ky' => 'kirghistangbe',
        'la' => 'latin',
        'lah' => 'lahndagbe',
        'lb' => 'laksembɔggbe',
        'ln' => 'lingala',
        'lo' => 'laogbe',
        'lt' => 'lithuaniagbe',
        'luy' => 'luyiagbe',
        'lv' => 'latviagbe',
        'mg' => 'malagasegbe',
        'mi' => 'maorgbe',
        'mk' => 'makedoniagbe',
        'ml' => 'malayagbe',
        'mn' => 'mongoliagbe',
        'mr' => 'marathiagbe',
        'ms' => 'malaygbe',
        'mt' => 'maltagbe',
        'my' => 'burmagbe',
        'nb' => 'nɔweigbe bokmål',
        'nd' => 'dziehe ndebelegbe',
        'ne' => 'nepalgbe',
        'nl' => 'Hollandgbe',
        'nn' => 'nɔweigbe ninɔsk',
        'no' => 'nɔweigbe',
        'nso' => 'dziehe sothogbe',
        'ny' => 'nyanjagbe',
        'or' => 'oriyagbe',
        'os' => 'ossetiagbe',
        'pa' => 'pundzabgbe',
        'pl' => 'Polishgbe',
        'ps' => 'pashtogbe',
        'pt' => 'Portuguesegbe',
        'qu' => 'kwetsuagbe',
        'rm' => 'romanshgbe',
        'rn' => 'rundigbe',
        'ro' => 'romaniagbe',
        'rof' => 'rombogbe',
        'ru' => 'Russiagbe',
        'rw' => 'ruwandagbe',
        'rwk' => 'rwagbe',
        'sa' => 'sanskrigbe',
        'sah' => 'sakagbe',
        'sd' => 'sindhgbe',
        'se' => 'dziehe samigbe',
        'sg' => 'sangogbe',
        'sh' => 'serbo-croatiagbe',
        'si' => 'sinhalgbe',
        'sk' => 'slovakiagbe',
        'sl' => 'sloveniagbe',
        'sm' => 'samoagbe',
        'sn' => 'shonagbe',
        'so' => 'somaliagbe',
        'sq' => 'albaniagbe',
        'sr' => 'serbiagbe',
        'ss' => 'swatgbe',
        'st' => 'anyiehe sothogbe',
        'sv' => 'swedengbe',
        'sw' => 'swahili',
        'swb' => 'komorogbe',
        'ta' => 'tamilgbe',
        'te' => 'telegugbe',
        'tet' => 'tetumgbe',
        'tg' => 'tadzikistangbe',
        'th' => 'Thailandgbe',
        'ti' => 'tigrinyagbe',
        'tk' => 'tɛkmengbe',
        'tl' => 'tagalogbe',
        'tn' => 'tswanagbe',
        'to' => 'tongagbe',
        'tpi' => 'tok pisigbe',
        'tr' => 'Turkishgbe',
        'ts' => 'tsongagbe',
        'ty' => 'tahitigbe',
        'ug' => 'uighurgbe',
        'uk' => 'ukraingbe',
        'ur' => 'urdugbe',
        'uz' => 'uzbekistangbe',
        've' => 'vendagbe',
        'vi' => 'vietnamgbe',
        'wae' => 'walsegbe',
        'wo' => 'wolofgbe',
        'xh' => 'xhosagbe',
        'yo' => 'yorubagbe',
        'yue' => 'cantongbe',
        'zh' => 'Chinagbe',
        'zu' => 'zulugbe',
    ],
    'LocalizedNames' => [
        'de_AT' => 'Germaniagbe (Austria)',
        'de_CH' => 'Germaniagbe (Switzerland)',
        'en_AU' => 'Yevugbe (Australia)',
        'en_CA' => 'Yevugbe (Canada)',
        'en_GB' => 'Yevugbe (Britain)',
        'en_US' => 'Yevugbe (America)',
        'es_419' => 'Spanishgbe (Latin America)',
        'es_ES' => 'Spanishgbe (Europe)',
        'es_MX' => 'Spanishgbe (Mexico)',
        'fr_CA' => 'Fransegbe (Canada)',
        'fr_CH' => 'Fransegbe (Switzerland)',
        'nl_BE' => 'Flemishgbe',
        'pt_BR' => 'Portuguesegbe (Brazil)',
        'pt_PT' => 'Portuguesegbe (Europe)',
        'zh_Hans' => 'tsainagbe',
        'zh_Hant' => 'blema tsainagbe',
    ],
];
