<?php

return [
    'Names' => [
        'af' => 'ອາຟຣິການ',
        'af_NA' => 'ອາຟຣິການ (ນາມີເບຍ)',
        'af_ZA' => 'ອາຟຣິການ (ອາຟຣິກາໃຕ້)',
        'ak' => 'ອາການ',
        'ak_GH' => 'ອາການ (ການາ)',
        'am' => 'ອຳຮາຣິກ',
        'am_ET' => 'ອຳຮາຣິກ (ອີທິໂອເປຍ)',
        'ar' => 'ອາຣັບ',
        'ar_001' => 'ອາຣັບ (ໂລກ)',
        'ar_AE' => 'ອາຣັບ (ສະຫະລັດອາຣັບເອມິເຣດ)',
        'ar_BH' => 'ອາຣັບ (ບາເຣນ)',
        'ar_DJ' => 'ອາຣັບ (ຈິບູຕິ)',
        'ar_DZ' => 'ອາຣັບ (ອັລຈິເຣຍ)',
        'ar_EG' => 'ອາຣັບ (ອີຢິບ)',
        'ar_EH' => 'ອາຣັບ (ຊາຮາຣາຕາເວັນຕົກ)',
        'ar_ER' => 'ອາຣັບ (ເອຣິເທຣຍ)',
        'ar_IL' => 'ອາຣັບ (ອິສຣາເອວ)',
        'ar_IQ' => 'ອາຣັບ (ອີຣັກ)',
        'ar_JO' => 'ອາຣັບ (ຈໍແດນ)',
        'ar_KM' => 'ອາຣັບ (ໂຄໂມໂຣສ)',
        'ar_KW' => 'ອາຣັບ (ກູເວດ)',
        'ar_LB' => 'ອາຣັບ (ເລບານອນ)',
        'ar_LY' => 'ອາຣັບ (ລິເບຍ)',
        'ar_MA' => 'ອາຣັບ (ໂມຣັອກໂຄ)',
        'ar_MR' => 'ອາຣັບ (ມົວຣິເທເນຍ)',
        'ar_OM' => 'ອາຣັບ (ໂອມານ)',
        'ar_PS' => 'ອາຣັບ (ດິນແດນປາເລດສະຕິນ)',
        'ar_QA' => 'ອາຣັບ (ກາຕາ)',
        'ar_SA' => 'ອາຣັບ (ຊາອຸດິ ອາຣາເບຍ)',
        'ar_SD' => 'ອາຣັບ (ຊູດານ)',
        'ar_SO' => 'ອາຣັບ (ໂຊມາເລຍ)',
        'ar_SS' => 'ອາຣັບ (ຊູດານໃຕ້)',
        'ar_SY' => 'ອາຣັບ (ຊີເຣຍ)',
        'ar_TD' => 'ອາຣັບ (ຊາດ)',
        'ar_TN' => 'ອາຣັບ (ຕູນິເຊຍ)',
        'ar_YE' => 'ອາຣັບ (ເຢເມນ)',
        'as' => 'ອັສຊາມີສ',
        'as_IN' => 'ອັສຊາມີສ (ອິນເດຍ)',
        'az' => 'ອາເຊີໄບຈານິ',
        'az_AZ' => 'ອາເຊີໄບຈານິ (ອາເຊີໄບຈານ)',
        'az_Cyrl' => 'ອາເຊີໄບຈານິ (ຊີຣິວລິກ)',
        'az_Cyrl_AZ' => 'ອາເຊີໄບຈານິ (ຊີຣິວລິກ, ອາເຊີໄບຈານ)',
        'az_Latn' => 'ອາເຊີໄບຈານິ (ລາຕິນ)',
        'az_Latn_AZ' => 'ອາເຊີໄບຈານິ (ລາຕິນ, ອາເຊີໄບຈານ)',
        'be' => 'ເບລາຣັສຊຽນ',
        'be_BY' => 'ເບລາຣັສຊຽນ (ເບລາຣຸສ)',
        'bg' => 'ບັງກາຣຽນ',
        'bg_BG' => 'ບັງກາຣຽນ (ບັງກາເຣຍ)',
        'bm' => 'ບາມບາຣາ',
        'bm_ML' => 'ບາມບາຣາ (ມາລີ)',
        'bn' => 'ເບັງກາລີ',
        'bn_BD' => 'ເບັງກາລີ (ບັງກະລາເທດ)',
        'bn_IN' => 'ເບັງກາລີ (ອິນເດຍ)',
        'bo' => 'ທິເບທັນ',
        'bo_CN' => 'ທິເບທັນ (ຈີນ)',
        'bo_IN' => 'ທິເບທັນ (ອິນເດຍ)',
        'br' => 'ເບຣຕັນ',
        'br_FR' => 'ເບຣຕັນ (ຝຣັ່ງ)',
        'bs' => 'ບອສນຽນ',
        'bs_BA' => 'ບອສນຽນ (ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'bs_Cyrl' => 'ບອສນຽນ (ຊີຣິວລິກ)',
        'bs_Cyrl_BA' => 'ບອສນຽນ (ຊີຣິວລິກ, ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'bs_Latn' => 'ບອສນຽນ (ລາຕິນ)',
        'bs_Latn_BA' => 'ບອສນຽນ (ລາຕິນ, ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'ca' => 'ຄາຕາລານ',
        'ca_AD' => 'ຄາຕາລານ (ອັນດໍຣາ)',
        'ca_ES' => 'ຄາຕາລານ (ສະເປນ)',
        'ca_FR' => 'ຄາຕາລານ (ຝຣັ່ງ)',
        'ca_IT' => 'ຄາຕາລານ (ອິຕາລີ)',
        'ce' => 'ຊີເຄນ',
        'ce_RU' => 'ຊີເຄນ (ຣັດເຊຍ)',
        'cs' => 'ເຊກ',
        'cs_CZ' => 'ເຊກ (ເຊັກເຊຍ)',
        'cv' => 'ຊູວາຊ',
        'cv_RU' => 'ຊູວາຊ (ຣັດເຊຍ)',
        'cy' => 'ເວວ',
        'cy_GB' => 'ເວວ (ສະຫະລາດຊະອະນາຈັກ)',
        'da' => 'ແດນິຊ',
        'da_DK' => 'ແດນິຊ (ເດນມາກ)',
        'da_GL' => 'ແດນິຊ (ກຣີນແລນ)',
        'de' => 'ເຢຍລະມັນ',
        'de_AT' => 'ເຢຍລະມັນ (ອອສເທຣຍ)',
        'de_BE' => 'ເຢຍລະມັນ (ເບວຢຽມ)',
        'de_CH' => 'ເຢຍລະມັນ (ສະວິດເຊີແລນ)',
        'de_DE' => 'ເຢຍລະມັນ (ເຢຍລະມັນ)',
        'de_IT' => 'ເຢຍລະມັນ (ອິຕາລີ)',
        'de_LI' => 'ເຢຍລະມັນ (ລິດເທນສະຕາຍ)',
        'de_LU' => 'ເຢຍລະມັນ (ລຸກແຊມເບີກ)',
        'dz' => 'ດີຊອງຄາ',
        'dz_BT' => 'ດີຊອງຄາ (ພູຖານ)',
        'ee' => 'ອິວາ',
        'ee_GH' => 'ອິວາ (ການາ)',
        'ee_TG' => 'ອິວາ (ໂຕໂກ)',
        'el' => 'ກຣີກ',
        'el_CY' => 'ກຣີກ (ໄຊປຣັສ)',
        'el_GR' => 'ກຣີກ (ກຣີຊ)',
        'en' => 'ອັງກິດ',
        'en_001' => 'ອັງກິດ (ໂລກ)',
        'en_150' => 'ອັງກິດ (ຢູໂຣບ)',
        'en_AE' => 'ອັງກິດ (ສະຫະລັດອາຣັບເອມິເຣດ)',
        'en_AG' => 'ອັງກິດ (ແອນທິກົວ ແລະ ບາບູດາ)',
        'en_AI' => 'ອັງກິດ (ແອນກຸຍລາ)',
        'en_AS' => 'ອັງກິດ (ອາເມຣິກາ ຊາມົວ)',
        'en_AT' => 'ອັງກິດ (ອອສເທຣຍ)',
        'en_AU' => 'ອັງກິດ (ອອສເຕຣເລຍ)',
        'en_BB' => 'ອັງກິດ (ບາບາໂດສ)',
        'en_BE' => 'ອັງກິດ (ເບວຢຽມ)',
        'en_BI' => 'ອັງກິດ (ບູຣຸນດິ)',
        'en_BM' => 'ອັງກິດ (ເບີມິວດາ)',
        'en_BS' => 'ອັງກິດ (ບາຮາມາສ)',
        'en_BW' => 'ອັງກິດ (ບອດສະວານາ)',
        'en_BZ' => 'ອັງກິດ (ເບລີຊ)',
        'en_CA' => 'ອັງກິດ (ແຄນາດາ)',
        'en_CC' => 'ອັງກິດ (ຫມູ່ເກາະໂກໂກສ)',
        'en_CH' => 'ອັງກິດ (ສະວິດເຊີແລນ)',
        'en_CK' => 'ອັງກິດ (ໝູ່ເກາະຄຸກ)',
        'en_CM' => 'ອັງກິດ (ຄາເມຣູນ)',
        'en_CX' => 'ອັງກິດ (ເກາະຄຣິສມາດ)',
        'en_CY' => 'ອັງກິດ (ໄຊປຣັສ)',
        'en_DE' => 'ອັງກິດ (ເຢຍລະມັນ)',
        'en_DK' => 'ອັງກິດ (ເດນມາກ)',
        'en_DM' => 'ອັງກິດ (ໂດມີນິຄາ)',
        'en_ER' => 'ອັງກິດ (ເອຣິເທຣຍ)',
        'en_FI' => 'ອັງກິດ (ຟິນແລນ)',
        'en_FJ' => 'ອັງກິດ (ຟິຈິ)',
        'en_FK' => 'ອັງກິດ (ຫມູ່ເກາະຟອກແລນ)',
        'en_FM' => 'ອັງກິດ (ໄມໂຄຣນີເຊຍ)',
        'en_GB' => 'ອັງກິດ (ສະຫະລາດຊະອະນາຈັກ)',
        'en_GD' => 'ອັງກິດ (ເກຣເນດາ)',
        'en_GG' => 'ອັງກິດ (ເກີນຊີ)',
        'en_GH' => 'ອັງກິດ (ການາ)',
        'en_GI' => 'ອັງກິດ (ຈິບບຣອນທາ)',
        'en_GM' => 'ອັງກິດ (ສາທາລະນະລັດແກມເບຍ)',
        'en_GU' => 'ອັງກິດ (ກວາມ)',
        'en_GY' => 'ອັງກິດ (ກາຍຢານາ)',
        'en_HK' => 'ອັງກິດ (ຮົງກົງ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'en_IE' => 'ອັງກິດ (ໄອແລນ)',
        'en_IL' => 'ອັງກິດ (ອິສຣາເອວ)',
        'en_IM' => 'ອັງກິດ (ເອວ ອອບ ແມນ)',
        'en_IN' => 'ອັງກິດ (ອິນເດຍ)',
        'en_IO' => 'ອັງກິດ (ເຂດແດນອັງກິດໃນມະຫາສະມຸດອິນເດຍ)',
        'en_JE' => 'ອັງກິດ (ເຈີຊີ)',
        'en_JM' => 'ອັງກິດ (ຈາໄມຄາ)',
        'en_KE' => 'ອັງກິດ (ເຄນຢາ)',
        'en_KI' => 'ອັງກິດ (ຄິຣິບາທິ)',
        'en_KN' => 'ອັງກິດ (ເຊນ ຄິດ ແລະ ເນວິສ)',
        'en_KY' => 'ອັງກິດ (ໝູ່ເກາະ ເຄແມນ)',
        'en_LC' => 'ອັງກິດ (ເຊນ ລູເຊຍ)',
        'en_LR' => 'ອັງກິດ (ລິເບີເຣຍ)',
        'en_LS' => 'ອັງກິດ (ເລໂຊໂທ)',
        'en_MG' => 'ອັງກິດ (ມາດາກາສະກາ)',
        'en_MH' => 'ອັງກິດ (ຫມູ່ເກາະມາແຊວ)',
        'en_MO' => 'ອັງກິດ (ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'en_MP' => 'ອັງກິດ (ໝູ່ເກາະມາເຣຍນາຕອນເໜືອ)',
        'en_MS' => 'ອັງກິດ (ມອນເຊີຣາດ)',
        'en_MT' => 'ອັງກິດ (ມອນທາ)',
        'en_MU' => 'ອັງກິດ (ມົວຣິຊຽສ)',
        'en_MV' => 'ອັງກິດ (ມັນດິຟ)',
        'en_MW' => 'ອັງກິດ (ມາລາວີ)',
        'en_MY' => 'ອັງກິດ (ມາເລເຊຍ)',
        'en_NA' => 'ອັງກິດ (ນາມີເບຍ)',
        'en_NF' => 'ອັງກິດ (ເກາະນໍໂຟກ)',
        'en_NG' => 'ອັງກິດ (ໄນຈີເຣຍ)',
        'en_NL' => 'ອັງກິດ (ເນເທີແລນ)',
        'en_NR' => 'ອັງກິດ (ນາອູຣູ)',
        'en_NU' => 'ອັງກິດ (ນີອູເອ)',
        'en_NZ' => 'ອັງກິດ (ນິວຊີແລນ)',
        'en_PG' => 'ອັງກິດ (ປາປົວນິວກີນີ)',
        'en_PH' => 'ອັງກິດ (ຟິລິບປິນ)',
        'en_PK' => 'ອັງກິດ (ປາກິດສະຖານ)',
        'en_PN' => 'ອັງກິດ (ໝູ່ເກາະພິດແຄນ)',
        'en_PR' => 'ອັງກິດ (ເພືອໂຕ ຣິໂກ)',
        'en_PW' => 'ອັງກິດ (ປາລາວ)',
        'en_RW' => 'ອັງກິດ (ຣວັນດາ)',
        'en_SB' => 'ອັງກິດ (ຫມູ່ເກາະໂຊໂລມອນ)',
        'en_SC' => 'ອັງກິດ (ເຊເຊວເລສ)',
        'en_SD' => 'ອັງກິດ (ຊູດານ)',
        'en_SE' => 'ອັງກິດ (ສະວີເດັນ)',
        'en_SG' => 'ອັງກິດ (ສິງກະໂປ)',
        'en_SH' => 'ອັງກິດ (ເຊນ ເຮເລນາ)',
        'en_SI' => 'ອັງກິດ (ສະໂລເວເນຍ)',
        'en_SL' => 'ອັງກິດ (ເຊຍຣາ ລີໂອນ)',
        'en_SS' => 'ອັງກິດ (ຊູດານໃຕ້)',
        'en_SX' => 'ອັງກິດ (ຊິນ ມາເທັນ)',
        'en_SZ' => 'ອັງກິດ (​ເອ​ສະ​ວາ​ຕິ​ນີ)',
        'en_TC' => 'ອັງກິດ (ໝູ່ເກາະ ເທີກ ແລະ ໄຄໂຄສ)',
        'en_TK' => 'ອັງກິດ (ໂຕເກເລົາ)',
        'en_TO' => 'ອັງກິດ (ທອງກາ)',
        'en_TT' => 'ອັງກິດ (ທຣິນິແດດ ແລະ ໂທແບໂກ)',
        'en_TV' => 'ອັງກິດ (ຕູວາລູ)',
        'en_TZ' => 'ອັງກິດ (ທານຊາເນຍ)',
        'en_UG' => 'ອັງກິດ (ອູການດາ)',
        'en_UM' => 'ອັງກິດ (ໝູ່ເກາະຮອບນອກຂອງສະຫະລັດຯ)',
        'en_US' => 'ອັງກິດ (ສະຫະລັດ)',
        'en_VC' => 'ອັງກິດ (ເຊນ ວິນເຊນ ແລະ ເກຣເນດິນ)',
        'en_VG' => 'ອັງກິດ (ໝູ່ເກາະ ເວີຈິນຂອງອັງກິດ)',
        'en_VI' => 'ອັງກິດ (ໝູ່ເກາະ ເວີຈິນ ຂອງສະຫະລັດ)',
        'en_VU' => 'ອັງກິດ (ວານົວຕູ)',
        'en_WS' => 'ອັງກິດ (ຊາມົວ)',
        'en_ZA' => 'ອັງກິດ (ອາຟຣິກາໃຕ້)',
        'en_ZM' => 'ອັງກິດ (ແຊມເບຍ)',
        'en_ZW' => 'ອັງກິດ (ຊິມບັບເວ)',
        'eo' => 'ເອສປາຍ',
        'eo_001' => 'ເອສປາຍ (ໂລກ)',
        'es' => 'ສະແປນນິຊ',
        'es_419' => 'ສະແປນນິຊ (ລາຕິນ ອາເມລິກາ)',
        'es_AR' => 'ສະແປນນິຊ (ອາເຈນທິນາ)',
        'es_BO' => 'ສະແປນນິຊ (ໂບລິເວຍ)',
        'es_BR' => 'ສະແປນນິຊ (ບຣາຊິວ)',
        'es_BZ' => 'ສະແປນນິຊ (ເບລີຊ)',
        'es_CL' => 'ສະແປນນິຊ (ຊິລີ)',
        'es_CO' => 'ສະແປນນິຊ (ໂຄລົມເບຍ)',
        'es_CR' => 'ສະແປນນິຊ (ໂຄສຕາ ຣິກາ)',
        'es_CU' => 'ສະແປນນິຊ (ຄິວບາ)',
        'es_DO' => 'ສະແປນນິຊ (ສາທາລະນະລັດ ໂດມິນິກັນ)',
        'es_EC' => 'ສະແປນນິຊ (ເອກວາດໍ)',
        'es_ES' => 'ສະແປນນິຊ (ສະເປນ)',
        'es_GQ' => 'ສະແປນນິຊ (ເອຄົວໂທຣຽວ ກີນີ)',
        'es_GT' => 'ສະແປນນິຊ (ກົວເທມາລາ)',
        'es_HN' => 'ສະແປນນິຊ (ຮອນດູຣັສ)',
        'es_MX' => 'ສະແປນນິຊ (ເມັກຊິໂກ)',
        'es_NI' => 'ສະແປນນິຊ (ນິກຄາຣາກົວ)',
        'es_PA' => 'ສະແປນນິຊ (ພານາມາ)',
        'es_PE' => 'ສະແປນນິຊ (ເປຣູ)',
        'es_PH' => 'ສະແປນນິຊ (ຟິລິບປິນ)',
        'es_PR' => 'ສະແປນນິຊ (ເພືອໂຕ ຣິໂກ)',
        'es_PY' => 'ສະແປນນິຊ (ພາຣາກວຍ)',
        'es_SV' => 'ສະແປນນິຊ (ເອວ ຊໍວາດໍ)',
        'es_US' => 'ສະແປນນິຊ (ສະຫະລັດ)',
        'es_UY' => 'ສະແປນນິຊ (ອູຣຸກວຍ)',
        'es_VE' => 'ສະແປນນິຊ (ເວເນຊູເອລາ)',
        'et' => 'ເອສໂຕນຽນ',
        'et_EE' => 'ເອສໂຕນຽນ (ເອສໂຕເນຍ)',
        'eu' => 'ບັສກີ',
        'eu_ES' => 'ບັສກີ (ສະເປນ)',
        'fa' => 'ເປີຊຽນ',
        'fa_AF' => 'ເປີຊຽນ (ອາຟການິດສະຖານ)',
        'fa_IR' => 'ເປີຊຽນ (ອີຣານ)',
        'ff' => 'ຟູລາ',
        'ff_Adlm' => 'ຟູລາ (ແອດລາມ)',
        'ff_Adlm_BF' => 'ຟູລາ (ແອດລາມ, ເບີກິນາ ຟາໂຊ)',
        'ff_Adlm_CM' => 'ຟູລາ (ແອດລາມ, ຄາເມຣູນ)',
        'ff_Adlm_GH' => 'ຟູລາ (ແອດລາມ, ການາ)',
        'ff_Adlm_GM' => 'ຟູລາ (ແອດລາມ, ສາທາລະນະລັດແກມເບຍ)',
        'ff_Adlm_GN' => 'ຟູລາ (ແອດລາມ, ກິນີ)',
        'ff_Adlm_GW' => 'ຟູລາ (ແອດລາມ, ກິນີ-ບິສເຊົາ)',
        'ff_Adlm_LR' => 'ຟູລາ (ແອດລາມ, ລິເບີເຣຍ)',
        'ff_Adlm_MR' => 'ຟູລາ (ແອດລາມ, ມົວຣິເທເນຍ)',
        'ff_Adlm_NE' => 'ຟູລາ (ແອດລາມ, ນິເຈີ)',
        'ff_Adlm_NG' => 'ຟູລາ (ແອດລາມ, ໄນຈີເຣຍ)',
        'ff_Adlm_SL' => 'ຟູລາ (ແອດລາມ, ເຊຍຣາ ລີໂອນ)',
        'ff_Adlm_SN' => 'ຟູລາ (ແອດລາມ, ເຊນີໂກລ)',
        'ff_CM' => 'ຟູລາ (ຄາເມຣູນ)',
        'ff_GN' => 'ຟູລາ (ກິນີ)',
        'ff_Latn' => 'ຟູລາ (ລາຕິນ)',
        'ff_Latn_BF' => 'ຟູລາ (ລາຕິນ, ເບີກິນາ ຟາໂຊ)',
        'ff_Latn_CM' => 'ຟູລາ (ລາຕິນ, ຄາເມຣູນ)',
        'ff_Latn_GH' => 'ຟູລາ (ລາຕິນ, ການາ)',
        'ff_Latn_GM' => 'ຟູລາ (ລາຕິນ, ສາທາລະນະລັດແກມເບຍ)',
        'ff_Latn_GN' => 'ຟູລາ (ລາຕິນ, ກິນີ)',
        'ff_Latn_GW' => 'ຟູລາ (ລາຕິນ, ກິນີ-ບິສເຊົາ)',
        'ff_Latn_LR' => 'ຟູລາ (ລາຕິນ, ລິເບີເຣຍ)',
        'ff_Latn_MR' => 'ຟູລາ (ລາຕິນ, ມົວຣິເທເນຍ)',
        'ff_Latn_NE' => 'ຟູລາ (ລາຕິນ, ນິເຈີ)',
        'ff_Latn_NG' => 'ຟູລາ (ລາຕິນ, ໄນຈີເຣຍ)',
        'ff_Latn_SL' => 'ຟູລາ (ລາຕິນ, ເຊຍຣາ ລີໂອນ)',
        'ff_Latn_SN' => 'ຟູລາ (ລາຕິນ, ເຊນີໂກລ)',
        'ff_MR' => 'ຟູລາ (ມົວຣິເທເນຍ)',
        'ff_SN' => 'ຟູລາ (ເຊນີໂກລ)',
        'fi' => 'ຟິນນິຊ',
        'fi_FI' => 'ຟິນນິຊ (ຟິນແລນ)',
        'fo' => 'ຟາໂຣສ',
        'fo_DK' => 'ຟາໂຣສ (ເດນມາກ)',
        'fo_FO' => 'ຟາໂຣສ (ຫມູ່ເກາະແຟໂຣ)',
        'fr' => 'ຝຣັ່ງ',
        'fr_BE' => 'ຝຣັ່ງ (ເບວຢຽມ)',
        'fr_BF' => 'ຝຣັ່ງ (ເບີກິນາ ຟາໂຊ)',
        'fr_BI' => 'ຝຣັ່ງ (ບູຣຸນດິ)',
        'fr_BJ' => 'ຝຣັ່ງ (ເບນິນ)',
        'fr_BL' => 'ຝຣັ່ງ (ເຊນ ບາເທເລມີ)',
        'fr_CA' => 'ຝຣັ່ງ (ແຄນາດາ)',
        'fr_CD' => 'ຝຣັ່ງ (ຄອງໂກ - ຄິນຊາຊາ)',
        'fr_CF' => 'ຝຣັ່ງ (ສາທາລະນະລັດອາຟຣິກາກາງ)',
        'fr_CG' => 'ຝຣັ່ງ (ຄອງໂກ - ບຣາຊາວິວ)',
        'fr_CH' => 'ຝຣັ່ງ (ສະວິດເຊີແລນ)',
        'fr_CI' => 'ຝຣັ່ງ (ໂຄຕີ ວົວ)',
        'fr_CM' => 'ຝຣັ່ງ (ຄາເມຣູນ)',
        'fr_DJ' => 'ຝຣັ່ງ (ຈິບູຕິ)',
        'fr_DZ' => 'ຝຣັ່ງ (ອັລຈິເຣຍ)',
        'fr_FR' => 'ຝຣັ່ງ (ຝຣັ່ງ)',
        'fr_GA' => 'ຝຣັ່ງ (ກາບອນ)',
        'fr_GF' => 'ຝຣັ່ງ (ເຟຣນຊ໌ ກຸຍອານາ)',
        'fr_GN' => 'ຝຣັ່ງ (ກິນີ)',
        'fr_GP' => 'ຝຣັ່ງ (ກົວດາລູບ)',
        'fr_GQ' => 'ຝຣັ່ງ (ເອຄົວໂທຣຽວ ກີນີ)',
        'fr_HT' => 'ຝຣັ່ງ (ໄຮຕິ)',
        'fr_KM' => 'ຝຣັ່ງ (ໂຄໂມໂຣສ)',
        'fr_LU' => 'ຝຣັ່ງ (ລຸກແຊມເບີກ)',
        'fr_MA' => 'ຝຣັ່ງ (ໂມຣັອກໂຄ)',
        'fr_MC' => 'ຝຣັ່ງ (ໂມນາໂຄ)',
        'fr_MF' => 'ຝຣັ່ງ (ເຊນ ມາທິນ)',
        'fr_MG' => 'ຝຣັ່ງ (ມາດາກາສະກາ)',
        'fr_ML' => 'ຝຣັ່ງ (ມາລີ)',
        'fr_MQ' => 'ຝຣັ່ງ (ມາຕິນີກ)',
        'fr_MR' => 'ຝຣັ່ງ (ມົວຣິເທເນຍ)',
        'fr_MU' => 'ຝຣັ່ງ (ມົວຣິຊຽສ)',
        'fr_NC' => 'ຝຣັ່ງ (ນິວ ຄາເລໂດເນຍ)',
        'fr_NE' => 'ຝຣັ່ງ (ນິເຈີ)',
        'fr_PF' => 'ຝຣັ່ງ (ເຟຣນຊ໌ ໂພລິນີເຊຍ)',
        'fr_PM' => 'ຝຣັ່ງ (ເຊນ ປີແອ ມິເກວລອນ)',
        'fr_RE' => 'ຝຣັ່ງ (ເຣອູນິຍົງ)',
        'fr_RW' => 'ຝຣັ່ງ (ຣວັນດາ)',
        'fr_SC' => 'ຝຣັ່ງ (ເຊເຊວເລສ)',
        'fr_SN' => 'ຝຣັ່ງ (ເຊນີໂກລ)',
        'fr_SY' => 'ຝຣັ່ງ (ຊີເຣຍ)',
        'fr_TD' => 'ຝຣັ່ງ (ຊາດ)',
        'fr_TG' => 'ຝຣັ່ງ (ໂຕໂກ)',
        'fr_TN' => 'ຝຣັ່ງ (ຕູນິເຊຍ)',
        'fr_VU' => 'ຝຣັ່ງ (ວານົວຕູ)',
        'fr_WF' => 'ຝຣັ່ງ (ວາລລິສ ແລະ ຟູຕູນາ)',
        'fr_YT' => 'ຝຣັ່ງ (ມາຢັອດ)',
        'fy' => 'ຟຣິຊຽນ ຕາເວັນຕົກ',
        'fy_NL' => 'ຟຣິຊຽນ ຕາເວັນຕົກ (ເນເທີແລນ)',
        'ga' => 'ໄອຣິສ',
        'ga_GB' => 'ໄອຣິສ (ສະຫະລາດຊະອະນາຈັກ)',
        'ga_IE' => 'ໄອຣິສ (ໄອແລນ)',
        'gd' => 'ສະກັອດເກລິກ',
        'gd_GB' => 'ສະກັອດເກລິກ (ສະຫະລາດຊະອະນາຈັກ)',
        'gl' => 'ກາລິຊຽນ',
        'gl_ES' => 'ກາລິຊຽນ (ສະເປນ)',
        'gu' => 'ກູຈາຣາຕິ',
        'gu_IN' => 'ກູຈາຣາຕິ (ອິນເດຍ)',
        'gv' => 'ແມງຊ໌',
        'gv_IM' => 'ແມງຊ໌ (ເອວ ອອບ ແມນ)',
        'ha' => 'ເຮົາຊາ',
        'ha_GH' => 'ເຮົາຊາ (ການາ)',
        'ha_NE' => 'ເຮົາຊາ (ນິເຈີ)',
        'ha_NG' => 'ເຮົາຊາ (ໄນຈີເຣຍ)',
        'he' => 'ຮີບຣິວ',
        'he_IL' => 'ຮີບຣິວ (ອິສຣາເອວ)',
        'hi' => 'ຮິນດິ',
        'hi_IN' => 'ຮິນດິ (ອິນເດຍ)',
        'hi_Latn' => 'ຮິນດິ (ລາຕິນ)',
        'hi_Latn_IN' => 'ຮິນດິ (ລາຕິນ, ອິນເດຍ)',
        'hr' => 'ໂຄຣເອທຽນ',
        'hr_BA' => 'ໂຄຣເອທຽນ (ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'hr_HR' => 'ໂຄຣເອທຽນ (ໂຄຣເອເທຍ)',
        'hu' => 'ຮັງກາຣຽນ',
        'hu_HU' => 'ຮັງກາຣຽນ (ຮັງກາຣີ)',
        'hy' => 'ອາເມນຽນ',
        'hy_AM' => 'ອາເມນຽນ (ອາເມເນຍ)',
        'ia' => 'ອິນເຕີລິງລົວ',
        'ia_001' => 'ອິນເຕີລິງລົວ (ໂລກ)',
        'id' => 'ອິນໂດເນຊຽນ',
        'id_ID' => 'ອິນໂດເນຊຽນ (ອິນໂດເນເຊຍ)',
        'ig' => 'ອິກໂບ',
        'ig_NG' => 'ອິກໂບ (ໄນຈີເຣຍ)',
        'ii' => 'ເສສວນ ອີ',
        'ii_CN' => 'ເສສວນ ອີ (ຈີນ)',
        'is' => 'ໄອສແລນດິກ',
        'is_IS' => 'ໄອສແລນດິກ (ໄອສແລນ)',
        'it' => 'ອິຕາລຽນ',
        'it_CH' => 'ອິຕາລຽນ (ສະວິດເຊີແລນ)',
        'it_IT' => 'ອິຕາລຽນ (ອິຕາລີ)',
        'it_SM' => 'ອິຕາລຽນ (ແຊນ ມາຣິໂນ)',
        'it_VA' => 'ອິຕາລຽນ (ນະຄອນ ວາຕິກັນ)',
        'ja' => 'ຍີ່ປຸ່ນ',
        'ja_JP' => 'ຍີ່ປຸ່ນ (ຍີ່ປຸ່ນ)',
        'jv' => 'ຈາແວນີສ',
        'jv_ID' => 'ຈາແວນີສ (ອິນໂດເນເຊຍ)',
        'ka' => 'ຈໍຈຽນ',
        'ka_GE' => 'ຈໍຈຽນ (ຈໍເຈຍ)',
        'ki' => 'ຄິຄູຢຸ',
        'ki_KE' => 'ຄິຄູຢຸ (ເຄນຢາ)',
        'kk' => 'ຄາຊັກ',
        'kk_KZ' => 'ຄາຊັກ (ຄາຊັກສະຖານ)',
        'kl' => 'ກຣີນແລນລິດ',
        'kl_GL' => 'ກຣີນແລນລິດ (ກຣີນແລນ)',
        'km' => 'ຂະເໝນ',
        'km_KH' => 'ຂະເໝນ (ກຳປູເຈຍ)',
        'kn' => 'ຄັນນາດາ',
        'kn_IN' => 'ຄັນນາດາ (ອິນເດຍ)',
        'ko' => 'ເກົາຫລີ',
        'ko_KP' => 'ເກົາຫລີ (ເກົາຫລີເໜືອ)',
        'ko_KR' => 'ເກົາຫລີ (ເກົາຫລີໃຕ້)',
        'ks' => 'ຄາສເມຍຣິ',
        'ks_Arab' => 'ຄາສເມຍຣິ (ອາຣາບິກ)',
        'ks_Arab_IN' => 'ຄາສເມຍຣິ (ອາຣາບິກ, ອິນເດຍ)',
        'ks_Deva' => 'ຄາສເມຍຣິ (ດີວານາກາຣີ)',
        'ks_Deva_IN' => 'ຄາສເມຍຣິ (ດີວານາກາຣີ, ອິນເດຍ)',
        'ks_IN' => 'ຄາສເມຍຣິ (ອິນເດຍ)',
        'ku' => 'ເຄີດິສ',
        'ku_TR' => 'ເຄີດິສ (ເທີຄີ)',
        'kw' => 'ຄໍນິຊ',
        'kw_GB' => 'ຄໍນິຊ (ສະຫະລາດຊະອະນາຈັກ)',
        'ky' => 'ເກຍກີສ',
        'ky_KG' => 'ເກຍກີສ (ຄຽກກິດສະຖານ)',
        'lb' => 'ລັກເຊມບວກກິຊ',
        'lb_LU' => 'ລັກເຊມບວກກິຊ (ລຸກແຊມເບີກ)',
        'lg' => 'ແກນດາ',
        'lg_UG' => 'ແກນດາ (ອູການດາ)',
        'ln' => 'ລິງກາລາ',
        'ln_AO' => 'ລິງກາລາ (ແອງໂກລາ)',
        'ln_CD' => 'ລິງກາລາ (ຄອງໂກ - ຄິນຊາຊາ)',
        'ln_CF' => 'ລິງກາລາ (ສາທາລະນະລັດອາຟຣິກາກາງ)',
        'ln_CG' => 'ລິງກາລາ (ຄອງໂກ - ບຣາຊາວິວ)',
        'lo' => 'ລາວ',
        'lo_LA' => 'ລາວ (ລາວ)',
        'lt' => 'ລິທົວນຽນ',
        'lt_LT' => 'ລິທົວນຽນ (ລິທົວເນຍ)',
        'lu' => 'ລູບາ-ຄາຕັງກາ',
        'lu_CD' => 'ລູບາ-ຄາຕັງກາ (ຄອງໂກ - ຄິນຊາຊາ)',
        'lv' => 'ລັດວຽນ',
        'lv_LV' => 'ລັດວຽນ (ລັດເວຍ)',
        'mg' => 'ມາລາກາສຊີ',
        'mg_MG' => 'ມາລາກາສຊີ (ມາດາກາສະກາ)',
        'mi' => 'ມາວຣິ',
        'mi_NZ' => 'ມາວຣິ (ນິວຊີແລນ)',
        'mk' => 'ແມຊິໂດນຽນ',
        'mk_MK' => 'ແມຊິໂດນຽນ (ແມຊິໂດເນຍເໜືອ)',
        'ml' => 'ມາເລອາລຳ',
        'ml_IN' => 'ມາເລອາລຳ (ອິນເດຍ)',
        'mn' => 'ມອງໂກເລຍ',
        'mn_MN' => 'ມອງໂກເລຍ (ມອງໂກເລຍ)',
        'mr' => 'ມາຣາທີ',
        'mr_IN' => 'ມາຣາທີ (ອິນເດຍ)',
        'ms' => 'ມາເລ',
        'ms_BN' => 'ມາເລ (ບຣູໄນ)',
        'ms_ID' => 'ມາເລ (ອິນໂດເນເຊຍ)',
        'ms_MY' => 'ມາເລ (ມາເລເຊຍ)',
        'ms_SG' => 'ມາເລ (ສິງກະໂປ)',
        'mt' => 'ມອລທີສ',
        'mt_MT' => 'ມອລທີສ (ມອນທາ)',
        'my' => 'ມຽນມາ',
        'my_MM' => 'ມຽນມາ (ມຽນມາ [ເບີມາ])',
        'nb' => 'ນໍເວຈຽນ ບັອກມອລ',
        'nb_NO' => 'ນໍເວຈຽນ ບັອກມອລ (ນໍເວ)',
        'nb_SJ' => 'ນໍເວຈຽນ ບັອກມອລ (ສະວາບາ ແລະ ແຢນ ມາເຢນ)',
        'nd' => 'ເອັນເດເບເລເໜືອ',
        'nd_ZW' => 'ເອັນເດເບເລເໜືອ (ຊິມບັບເວ)',
        'ne' => 'ເນປາລີ',
        'ne_IN' => 'ເນປາລີ (ອິນເດຍ)',
        'ne_NP' => 'ເນປາລີ (ເນປານ)',
        'nl' => 'ດັຊ',
        'nl_AW' => 'ດັຊ (ອາຣູບາ)',
        'nl_BE' => 'ດັຊ (ເບວຢຽມ)',
        'nl_BQ' => 'ດັຊ (ຄາຣິບບຽນ ເນເທີແລນ)',
        'nl_CW' => 'ດັຊ (ຄູຣາຊາວ)',
        'nl_NL' => 'ດັຊ (ເນເທີແລນ)',
        'nl_SR' => 'ດັຊ (ຊູຣິນາມ)',
        'nl_SX' => 'ດັຊ (ຊິນ ມາເທັນ)',
        'nn' => 'ນໍເວຈຽນ ນີນອກ',
        'nn_NO' => 'ນໍເວຈຽນ ນີນອກ (ນໍເວ)',
        'no' => 'ນໍເວຍ',
        'no_NO' => 'ນໍເວຍ (ນໍເວ)',
        'om' => 'ໂອໂຣໂມ',
        'om_ET' => 'ໂອໂຣໂມ (ອີທິໂອເປຍ)',
        'om_KE' => 'ໂອໂຣໂມ (ເຄນຢາ)',
        'or' => 'ໂອຣິຢາ',
        'or_IN' => 'ໂອຣິຢາ (ອິນເດຍ)',
        'os' => 'ອອດເຊຕິກ',
        'os_GE' => 'ອອດເຊຕິກ (ຈໍເຈຍ)',
        'os_RU' => 'ອອດເຊຕິກ (ຣັດເຊຍ)',
        'pa' => 'ປັນຈາບີ',
        'pa_Arab' => 'ປັນຈາບີ (ອາຣາບິກ)',
        'pa_Arab_PK' => 'ປັນຈາບີ (ອາຣາບິກ, ປາກິດສະຖານ)',
        'pa_Guru' => 'ປັນຈາບີ (ກົວມູຄີ)',
        'pa_Guru_IN' => 'ປັນຈາບີ (ກົວມູຄີ, ອິນເດຍ)',
        'pa_IN' => 'ປັນຈາບີ (ອິນເດຍ)',
        'pa_PK' => 'ປັນຈາບີ (ປາກິດສະຖານ)',
        'pl' => 'ໂປລິຊ',
        'pl_PL' => 'ໂປລິຊ (ໂປແລນ)',
        'ps' => 'ປາສໂຕ',
        'ps_AF' => 'ປາສໂຕ (ອາຟການິດສະຖານ)',
        'ps_PK' => 'ປາສໂຕ (ປາກິດສະຖານ)',
        'pt' => 'ປອກຕຸຍກິສ',
        'pt_AO' => 'ປອກຕຸຍກິສ (ແອງໂກລາ)',
        'pt_BR' => 'ປອກຕຸຍກິສ (ບຣາຊິວ)',
        'pt_CH' => 'ປອກຕຸຍກິສ (ສະວິດເຊີແລນ)',
        'pt_CV' => 'ປອກຕຸຍກິສ (ເຄບ ເວີດ)',
        'pt_GQ' => 'ປອກຕຸຍກິສ (ເອຄົວໂທຣຽວ ກີນີ)',
        'pt_GW' => 'ປອກຕຸຍກິສ (ກິນີ-ບິສເຊົາ)',
        'pt_LU' => 'ປອກຕຸຍກິສ (ລຸກແຊມເບີກ)',
        'pt_MO' => 'ປອກຕຸຍກິສ (ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'pt_MZ' => 'ປອກຕຸຍກິສ (ໂມແຊມບິກ)',
        'pt_PT' => 'ປອກຕຸຍກິສ (ພອລທູໂກ)',
        'pt_ST' => 'ປອກຕຸຍກິສ (ເຊົາທູເມ ແລະ ພຣິນຊິບ)',
        'pt_TL' => 'ປອກຕຸຍກິສ (ທິມໍ-ເລສເຕ)',
        'qu' => 'ຄີຊົວ',
        'qu_BO' => 'ຄີຊົວ (ໂບລິເວຍ)',
        'qu_EC' => 'ຄີຊົວ (ເອກວາດໍ)',
        'qu_PE' => 'ຄີຊົວ (ເປຣູ)',
        'rm' => 'ໂຣແມນຊ໌',
        'rm_CH' => 'ໂຣແມນຊ໌ (ສະວິດເຊີແລນ)',
        'rn' => 'ຣຸນດິ',
        'rn_BI' => 'ຣຸນດິ (ບູຣຸນດິ)',
        'ro' => 'ໂຣແມນຽນ',
        'ro_MD' => 'ໂຣແມນຽນ (ໂມນໂດວາ)',
        'ro_RO' => 'ໂຣແມນຽນ (ໂຣແມເນຍ)',
        'ru' => 'ລັດເຊຍ',
        'ru_BY' => 'ລັດເຊຍ (ເບລາຣຸສ)',
        'ru_KG' => 'ລັດເຊຍ (ຄຽກກິດສະຖານ)',
        'ru_KZ' => 'ລັດເຊຍ (ຄາຊັກສະຖານ)',
        'ru_MD' => 'ລັດເຊຍ (ໂມນໂດວາ)',
        'ru_RU' => 'ລັດເຊຍ (ຣັດເຊຍ)',
        'ru_UA' => 'ລັດເຊຍ (ຢູເຄຣນ)',
        'rw' => 'ຄິນຢາວານດາ',
        'rw_RW' => 'ຄິນຢາວານດາ (ຣວັນດາ)',
        'sa' => 'ສັນສະກຣິດ',
        'sa_IN' => 'ສັນສະກຣິດ (ອິນເດຍ)',
        'sc' => 'ສາດີນຽນ',
        'sc_IT' => 'ສາດີນຽນ (ອິຕາລີ)',
        'sd' => 'ສິນທິ',
        'sd_Arab' => 'ສິນທິ (ອາຣາບິກ)',
        'sd_Arab_PK' => 'ສິນທິ (ອາຣາບິກ, ປາກິດສະຖານ)',
        'sd_Deva' => 'ສິນທິ (ດີວານາກາຣີ)',
        'sd_Deva_IN' => 'ສິນທິ (ດີວານາກາຣີ, ອິນເດຍ)',
        'sd_IN' => 'ສິນທິ (ອິນເດຍ)',
        'sd_PK' => 'ສິນທິ (ປາກິດສະຖານ)',
        'se' => 'ຊາມິເໜືອ',
        'se_FI' => 'ຊາມິເໜືອ (ຟິນແລນ)',
        'se_NO' => 'ຊາມິເໜືອ (ນໍເວ)',
        'se_SE' => 'ຊາມິເໜືອ (ສະວີເດັນ)',
        'sg' => 'ແຊງໂກ',
        'sg_CF' => 'ແຊງໂກ (ສາທາລະນະລັດອາຟຣິກາກາງ)',
        'sh' => 'ເຊີໂບ-ໂກເຊຍ',
        'sh_BA' => 'ເຊີໂບ-ໂກເຊຍ (ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'si' => 'ສິນຫາລາ',
        'si_LK' => 'ສິນຫາລາ (ສີລັງກາ)',
        'sk' => 'ສະໂລແວັກ',
        'sk_SK' => 'ສະໂລແວັກ (ສະໂລວາເກຍ)',
        'sl' => 'ສະໂລເວນຽນ',
        'sl_SI' => 'ສະໂລເວນຽນ (ສະໂລເວເນຍ)',
        'sn' => 'ໂຊນາ',
        'sn_ZW' => 'ໂຊນາ (ຊິມບັບເວ)',
        'so' => 'ໂຊມາລີ',
        'so_DJ' => 'ໂຊມາລີ (ຈິບູຕິ)',
        'so_ET' => 'ໂຊມາລີ (ອີທິໂອເປຍ)',
        'so_KE' => 'ໂຊມາລີ (ເຄນຢາ)',
        'so_SO' => 'ໂຊມາລີ (ໂຊມາເລຍ)',
        'sq' => 'ອານບານຽນ',
        'sq_AL' => 'ອານບານຽນ (ແອວເບເນຍ)',
        'sq_MK' => 'ອານບານຽນ (ແມຊິໂດເນຍເໜືອ)',
        'sr' => 'ເຊີບຽນ',
        'sr_BA' => 'ເຊີບຽນ (ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'sr_Cyrl' => 'ເຊີບຽນ (ຊີຣິວລິກ)',
        'sr_Cyrl_BA' => 'ເຊີບຽນ (ຊີຣິວລິກ, ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'sr_Cyrl_ME' => 'ເຊີບຽນ (ຊີຣິວລິກ, ມອນເຕເນໂກຣ)',
        'sr_Cyrl_RS' => 'ເຊີບຽນ (ຊີຣິວລິກ, ເຊີເບຍ)',
        'sr_Latn' => 'ເຊີບຽນ (ລາຕິນ)',
        'sr_Latn_BA' => 'ເຊີບຽນ (ລາຕິນ, ບອດສະເນຍ ແລະ ແຮສໂກວີນາ)',
        'sr_Latn_ME' => 'ເຊີບຽນ (ລາຕິນ, ມອນເຕເນໂກຣ)',
        'sr_Latn_RS' => 'ເຊີບຽນ (ລາຕິນ, ເຊີເບຍ)',
        'sr_ME' => 'ເຊີບຽນ (ມອນເຕເນໂກຣ)',
        'sr_RS' => 'ເຊີບຽນ (ເຊີເບຍ)',
        'su' => 'ຊຸນແດນນີສ',
        'su_ID' => 'ຊຸນແດນນີສ (ອິນໂດເນເຊຍ)',
        'su_Latn' => 'ຊຸນແດນນີສ (ລາຕິນ)',
        'su_Latn_ID' => 'ຊຸນແດນນີສ (ລາຕິນ, ອິນໂດເນເຊຍ)',
        'sv' => 'ສະວີດິຊ',
        'sv_AX' => 'ສະວີດິຊ (ຫມູ່ເກາະໂອລັນ)',
        'sv_FI' => 'ສະວີດິຊ (ຟິນແລນ)',
        'sv_SE' => 'ສະວີດິຊ (ສະວີເດັນ)',
        'sw' => 'ຊວາຮີລິ',
        'sw_CD' => 'ຊວາຮີລິ (ຄອງໂກ - ຄິນຊາຊາ)',
        'sw_KE' => 'ຊວາຮີລິ (ເຄນຢາ)',
        'sw_TZ' => 'ຊວາຮີລິ (ທານຊາເນຍ)',
        'sw_UG' => 'ຊວາຮີລິ (ອູການດາ)',
        'ta' => 'ທາມິລ',
        'ta_IN' => 'ທາມິລ (ອິນເດຍ)',
        'ta_LK' => 'ທາມິລ (ສີລັງກາ)',
        'ta_MY' => 'ທາມິລ (ມາເລເຊຍ)',
        'ta_SG' => 'ທາມິລ (ສິງກະໂປ)',
        'te' => 'ເຕລູກູ',
        'te_IN' => 'ເຕລູກູ (ອິນເດຍ)',
        'tg' => 'ທາຈິກ',
        'tg_TJ' => 'ທາຈິກ (ທາຈິກິດສະຖານ)',
        'th' => 'ໄທ',
        'th_TH' => 'ໄທ (ໄທ)',
        'ti' => 'ຕິກຣິນຢາ',
        'ti_ER' => 'ຕິກຣິນຢາ (ເອຣິເທຣຍ)',
        'ti_ET' => 'ຕິກຣິນຢາ (ອີທິໂອເປຍ)',
        'tk' => 'ເທີກເມັນ',
        'tk_TM' => 'ເທີກເມັນ (ເທີກເມນິສະຖານ)',
        'tl' => 'ຕາກາລອກ',
        'tl_PH' => 'ຕາກາລອກ (ຟິລິບປິນ)',
        'to' => 'ທອງການ',
        'to_TO' => 'ທອງການ (ທອງກາ)',
        'tr' => 'ເທີຄິຊ',
        'tr_CY' => 'ເທີຄິຊ (ໄຊປຣັສ)',
        'tr_TR' => 'ເທີຄິຊ (ເທີຄີ)',
        'tt' => 'ທາທາ',
        'tt_RU' => 'ທາທາ (ຣັດເຊຍ)',
        'ug' => 'ອຸຍເຄີ',
        'ug_CN' => 'ອຸຍເຄີ (ຈີນ)',
        'uk' => 'ຢູເຄຣນຽນ',
        'uk_UA' => 'ຢູເຄຣນຽນ (ຢູເຄຣນ)',
        'ur' => 'ອູຣດູ',
        'ur_IN' => 'ອູຣດູ (ອິນເດຍ)',
        'ur_PK' => 'ອູຣດູ (ປາກິດສະຖານ)',
        'uz' => 'ອຸສເບກ',
        'uz_AF' => 'ອຸສເບກ (ອາຟການິດສະຖານ)',
        'uz_Arab' => 'ອຸສເບກ (ອາຣາບິກ)',
        'uz_Arab_AF' => 'ອຸສເບກ (ອາຣາບິກ, ອາຟການິດສະຖານ)',
        'uz_Cyrl' => 'ອຸສເບກ (ຊີຣິວລິກ)',
        'uz_Cyrl_UZ' => 'ອຸສເບກ (ຊີຣິວລິກ, ອຸສເບກິສະຖານ)',
        'uz_Latn' => 'ອຸສເບກ (ລາຕິນ)',
        'uz_Latn_UZ' => 'ອຸສເບກ (ລາຕິນ, ອຸສເບກິສະຖານ)',
        'uz_UZ' => 'ອຸສເບກ (ອຸສເບກິສະຖານ)',
        'vi' => 'ຫວຽດນາມ',
        'vi_VN' => 'ຫວຽດນາມ (ຫວຽດນາມ)',
        'wo' => 'ວໍລອບ',
        'wo_SN' => 'ວໍລອບ (ເຊນີໂກລ)',
        'xh' => 'ໂຮຊາ',
        'xh_ZA' => 'ໂຮຊາ (ອາຟຣິກາໃຕ້)',
        'yi' => 'ຢິວ',
        'yi_001' => 'ຢິວ (ໂລກ)',
        'yo' => 'ໂຢຣູບາ',
        'yo_BJ' => 'ໂຢຣູບາ (ເບນິນ)',
        'yo_NG' => 'ໂຢຣູບາ (ໄນຈີເຣຍ)',
        'zh' => 'ຈີນ',
        'zh_CN' => 'ຈີນ (ຈີນ)',
        'zh_HK' => 'ຈີນ (ຮົງກົງ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'zh_Hans' => 'ຈີນ (ແບບຮຽບງ່າຍ)',
        'zh_Hans_CN' => 'ຈີນ (ແບບຮຽບງ່າຍ, ຈີນ)',
        'zh_Hans_HK' => 'ຈີນ (ແບບຮຽບງ່າຍ, ຮົງກົງ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'zh_Hans_MO' => 'ຈີນ (ແບບຮຽບງ່າຍ, ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'zh_Hans_SG' => 'ຈີນ (ແບບຮຽບງ່າຍ, ສິງກະໂປ)',
        'zh_Hant' => 'ຈີນ (ແບບດັ້ງເດີມ)',
        'zh_Hant_HK' => 'ຈີນ (ແບບດັ້ງເດີມ, ຮົງກົງ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'zh_Hant_MO' => 'ຈີນ (ແບບດັ້ງເດີມ, ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'zh_Hant_TW' => 'ຈີນ (ແບບດັ້ງເດີມ, ໄຕ້ຫວັນ)',
        'zh_MO' => 'ຈີນ (ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ)',
        'zh_SG' => 'ຈີນ (ສິງກະໂປ)',
        'zh_TW' => 'ຈີນ (ໄຕ້ຫວັນ)',
        'zu' => 'ຊູລູ',
        'zu_ZA' => 'ຊູລູ (ອາຟຣິກາໃຕ້)',
    ],
];
