<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвич боюнча орточо убакыт (Абиджан)',
        'Africa/Accra' => 'Гринвич боюнча орточо убакыт (Аккра)',
        'Africa/Addis_Ababa' => 'Чыгыш Африка убактысы (Аддис-Абеба)',
        'Africa/Algiers' => 'Борбордук Европа убактысы (Алжир)',
        'Africa/Asmera' => 'Чыгыш Африка убактысы (Асмара)',
        'Africa/Bamako' => 'Гринвич боюнча орточо убакыт (Бамако)',
        'Africa/Bangui' => 'Батыш Африка убактысы (Баги)',
        'Africa/Banjul' => 'Гринвич боюнча орточо убакыт (Банжул)',
        'Africa/Bissau' => 'Гринвич боюнча орточо убакыт (Бисау)',
        'Africa/Blantyre' => 'Борбордук Африка убактысы (Блантайр)',
        'Africa/Brazzaville' => 'Батыш Африка убактысы (Браззавилл)',
        'Africa/Bujumbura' => 'Борбордук Африка убактысы (Бужумбура)',
        'Africa/Cairo' => 'Чыгыш Европа убактысы (Каир)',
        'Africa/Casablanca' => 'Батыш Европа убактысы (Касабланка)',
        'Africa/Ceuta' => 'Борбордук Европа убактысы (Сеута)',
        'Africa/Conakry' => 'Гринвич боюнча орточо убакыт (Конакри)',
        'Africa/Dakar' => 'Гринвич боюнча орточо убакыт (Дакар)',
        'Africa/Dar_es_Salaam' => 'Чыгыш Африка убактысы (Дар эс Салаам)',
        'Africa/Djibouti' => 'Чыгыш Африка убактысы (Жибути)',
        'Africa/Douala' => 'Батыш Африка убактысы (Дуала)',
        'Africa/El_Aaiun' => 'Батыш Европа убактысы (Эл Айун)',
        'Africa/Freetown' => 'Гринвич боюнча орточо убакыт (Фритаун)',
        'Africa/Gaborone' => 'Борбордук Африка убактысы (Габороне)',
        'Africa/Harare' => 'Борбордук Африка убактысы (Хараре)',
        'Africa/Johannesburg' => 'Түштүк Африка убактысы (Йоханнесбург)',
        'Africa/Juba' => 'Борбордук Африка убактысы (Жуба)',
        'Africa/Kampala' => 'Чыгыш Африка убактысы (Кампала)',
        'Africa/Khartoum' => 'Борбордук Африка убактысы (Картум)',
        'Africa/Kigali' => 'Борбордук Африка убактысы (Кигали)',
        'Africa/Kinshasa' => 'Батыш Африка убактысы (Киншаса)',
        'Africa/Lagos' => 'Батыш Африка убактысы (Лагос)',
        'Africa/Libreville' => 'Батыш Африка убактысы (Либревилл)',
        'Africa/Lome' => 'Гринвич боюнча орточо убакыт (Ломе)',
        'Africa/Luanda' => 'Батыш Африка убактысы (Луанда)',
        'Africa/Lubumbashi' => 'Борбордук Африка убактысы (Лубумбаши)',
        'Africa/Lusaka' => 'Борбордук Африка убактысы (Лусака)',
        'Africa/Malabo' => 'Батыш Африка убактысы (Малабо)',
        'Africa/Maputo' => 'Борбордук Африка убактысы (Мапуто)',
        'Africa/Maseru' => 'Түштүк Африка убактысы (Масеру)',
        'Africa/Mbabane' => 'Түштүк Африка убактысы (Мбабане)',
        'Africa/Mogadishu' => 'Чыгыш Африка убактысы (Могадишу)',
        'Africa/Monrovia' => 'Гринвич боюнча орточо убакыт (Монровиа)',
        'Africa/Nairobi' => 'Чыгыш Африка убактысы (Найроби)',
        'Africa/Ndjamena' => 'Батыш Африка убактысы (Нжамена)',
        'Africa/Niamey' => 'Батыш Африка убактысы (Нйаме)',
        'Africa/Nouakchott' => 'Гринвич боюнча орточо убакыт (Нуакшот)',
        'Africa/Ouagadougou' => 'Гринвич боюнча орточо убакыт (Уагадугу)',
        'Africa/Porto-Novo' => 'Батыш Африка убактысы (Порто-Ново)',
        'Africa/Sao_Tome' => 'Гринвич боюнча орточо убакыт (Сао Томе)',
        'Africa/Tripoli' => 'Чыгыш Европа убактысы (Триполи)',
        'Africa/Tunis' => 'Борбордук Европа убактысы (Тунис)',
        'Africa/Windhoek' => 'Борбордук Африка убактысы (Уиндхук)',
        'America/Adak' => 'Гавайи-Алеут убактысы (Адак)',
        'America/Anchorage' => 'Аляска убактысы (Анкориж)',
        'America/Anguilla' => 'Атлантика убактысы (Ангуила)',
        'America/Antigua' => 'Атлантика убактысы (Антигуа)',
        'America/Araguaina' => 'Бразилия убактысы (Арагуаина)',
        'America/Argentina/La_Rioja' => 'Аргентина убактысы (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина убактысы (Рио Галлегос)',
        'America/Argentina/Salta' => 'Аргентина убактысы (Салта)',
        'America/Argentina/San_Juan' => 'Аргентина убактысы (Сан Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина убактысы (Сан Луи)',
        'America/Argentina/Tucuman' => 'Аргентина убактысы (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина убактысы (Ушуайа)',
        'America/Aruba' => 'Атлантика убактысы (Аруба)',
        'America/Asuncion' => 'Парагвай убактысы (Асунсион)',
        'America/Bahia' => 'Бразилия убактысы (Байиа)',
        'America/Bahia_Banderas' => 'Түндүк Америка, борбордук убакыт (Баийа Бандерас)',
        'America/Barbados' => 'Атлантика убактысы (Барбадос)',
        'America/Belem' => 'Бразилия убактысы (Белем)',
        'America/Belize' => 'Түндүк Америка, борбордук убакыт (Белиз)',
        'America/Blanc-Sablon' => 'Атлантика убактысы (Бланк-Саблон)',
        'America/Boa_Vista' => 'Амазон убактысы (Боа Виста)',
        'America/Bogota' => 'Колумбия убактысы (Богота)',
        'America/Boise' => 'Түндүк Америка, тоо убактысы (Бойсе)',
        'America/Buenos_Aires' => 'Аргентина убактысы (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Түндүк Америка, тоо убактысы (Кэмбриж Бей)',
        'America/Campo_Grande' => 'Амазон убактысы (Кампо Гранде)',
        'America/Cancun' => 'Түндүк Америка, чыгыш убактысы (Канкун)',
        'America/Caracas' => 'Венесуэла убактысы (Каракас)',
        'America/Catamarca' => 'Аргентина убактысы (Катамарка)',
        'America/Cayenne' => 'Француз Гвиана убактысы (Кайен)',
        'America/Cayman' => 'Түндүк Америка, чыгыш убактысы (Кайман)',
        'America/Chicago' => 'Түндүк Америка, борбордук убакыт (Чикаго)',
        'America/Chihuahua' => 'Мексика, Тынч океан убактысы (Чихуахуа)',
        'America/Coral_Harbour' => 'Түндүк Америка, чыгыш убактысы (Атикокан)',
        'America/Cordoba' => 'Аргентина убактысы (Кордова)',
        'America/Costa_Rica' => 'Түндүк Америка, борбордук убакыт (Коста-Рика)',
        'America/Creston' => 'Түндүк Америка, тоо убактысы (Крестон)',
        'America/Cuiaba' => 'Амазон убактысы (Куйаба)',
        'America/Curacao' => 'Атлантика убактысы (Кюрасао)',
        'America/Danmarkshavn' => 'Гринвич боюнча орточо убакыт (Данмарксхавн)',
        'America/Dawson' => 'Юкон убактысы (Доусон)',
        'America/Dawson_Creek' => 'Түндүк Америка, тоо убактысы (Доусон Грек)',
        'America/Denver' => 'Түндүк Америка, тоо убактысы (Денвер)',
        'America/Detroit' => 'Түндүк Америка, чыгыш убактысы (Детройт)',
        'America/Dominica' => 'Атлантика убактысы (Доминика)',
        'America/Edmonton' => 'Түндүк Америка, тоо убактысы (Эдмонтон)',
        'America/Eirunepe' => 'Бразилия убактысы (Эйрунепе)',
        'America/El_Salvador' => 'Түндүк Америка, борбордук убакыт (Эл Салвадор)',
        'America/Fort_Nelson' => 'Түндүк Америка, тоо убактысы (Форт Нельсон)',
        'America/Fortaleza' => 'Бразилия убактысы (Форталеза)',
        'America/Glace_Bay' => 'Атлантика убактысы (Глейс Бей)',
        'America/Godthab' => 'Батыш Гренландия убактысы (Нуук)',
        'America/Goose_Bay' => 'Атлантика убактысы (Гус Бей)',
        'America/Grand_Turk' => 'Түндүк Америка, чыгыш убактысы (Гранд Түрк)',
        'America/Grenada' => 'Атлантика убактысы (Гренада)',
        'America/Guadeloupe' => 'Атлантика убактысы (Гваделупе)',
        'America/Guatemala' => 'Түндүк Америка, борбордук убакыт (Гватемала)',
        'America/Guayaquil' => 'Экуадор убактысы (Гуайакил)',
        'America/Guyana' => 'Гвиана убактысы (Гуйана)',
        'America/Halifax' => 'Атлантика убактысы (Галифакс)',
        'America/Havana' => 'Куба убактысы (Гавана)',
        'America/Hermosillo' => 'Мексика, Тынч океан убактысы (Эрмосилло)',
        'America/Indiana/Knox' => 'Түндүк Америка, борбордук убакыт (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Түндүк Америка, чыгыш убактысы (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Түндүк Америка, чыгыш убактысы (Питерсбург, Индиана)',
        'America/Indiana/Tell_City' => 'Түндүк Америка, борбордук убакыт (Телл Сити, Индиана)',
        'America/Indiana/Vevay' => 'Түндүк Америка, чыгыш убактысы (Вивей, Индиана)',
        'America/Indiana/Vincennes' => 'Түндүк Америка, чыгыш убактысы (Винсен, Индиана)',
        'America/Indiana/Winamac' => 'Түндүк Америка, чыгыш убактысы (Уинамак, Индиана)',
        'America/Indianapolis' => 'Түндүк Америка, чыгыш убактысы (Индианаполис)',
        'America/Inuvik' => 'Түндүк Америка, тоо убактысы (Инувик)',
        'America/Iqaluit' => 'Түндүк Америка, чыгыш убактысы (Икалуит)',
        'America/Jamaica' => 'Түндүк Америка, чыгыш убактысы (Ямайка)',
        'America/Jujuy' => 'Аргентина убактысы (Жужуй)',
        'America/Juneau' => 'Аляска убактысы (Жуно)',
        'America/Kentucky/Monticello' => 'Түндүк Америка, чыгыш убактысы (Монтичелло, Кентукки)',
        'America/Kralendijk' => 'Атлантика убактысы (Кралендейк)',
        'America/La_Paz' => 'Боливия убактысы (Ла Пас)',
        'America/Lima' => 'Перу убактысы (Лима)',
        'America/Los_Angeles' => 'Түндүк Америка, Тынч океан убактысы (Лос-Анжелес)',
        'America/Louisville' => 'Түндүк Америка, чыгыш убактысы (Луизвилл)',
        'America/Lower_Princes' => 'Атлантика убактысы (Лоуэр Принсес Куате)',
        'America/Maceio' => 'Бразилия убактысы (Масейо)',
        'America/Managua' => 'Түндүк Америка, борбордук убакыт (Манагуа)',
        'America/Manaus' => 'Амазон убактысы (Манаус)',
        'America/Marigot' => 'Атлантика убактысы (Мариго)',
        'America/Martinique' => 'Атлантика убактысы (Мартиник)',
        'America/Matamoros' => 'Түндүк Америка, борбордук убакыт (Матаморос)',
        'America/Mazatlan' => 'Мексика, Тынч океан убактысы (Мазатлан)',
        'America/Mendoza' => 'Аргентина убактысы (Мендоза)',
        'America/Menominee' => 'Түндүк Америка, борбордук убакыт (Меномини)',
        'America/Merida' => 'Түндүк Америка, борбордук убакыт (Мерида)',
        'America/Metlakatla' => 'Аляска убактысы (Метлакатла)',
        'America/Mexico_City' => 'Түндүк Америка, борбордук убакыт (Мехико шаары)',
        'America/Miquelon' => 'Сен Пьер жана Микелон убактысы',
        'America/Moncton' => 'Атлантика убактысы (Монктон)',
        'America/Monterrey' => 'Түндүк Америка, борбордук убакыт (Монтерей)',
        'America/Montevideo' => 'Уругвай убактысы (Монтевидео)',
        'America/Montreal' => 'Канада убактысы (Montreal)',
        'America/Montserrat' => 'Атлантика убактысы (Монсерат)',
        'America/Nassau' => 'Түндүк Америка, чыгыш убактысы (Нассау)',
        'America/New_York' => 'Түндүк Америка, чыгыш убактысы (Нью-Йорк)',
        'America/Nipigon' => 'Түндүк Америка, чыгыш убактысы (Нипигон)',
        'America/Nome' => 'Аляска убактысы (Ном)',
        'America/Noronha' => 'Фернандо де Норонья убактысы (Норониа)',
        'America/North_Dakota/Beulah' => 'Түндүк Америка, борбордук убакыт (Беула, Түндүк Дакота)',
        'America/North_Dakota/Center' => 'Түндүк Америка, борбордук убакыт (Түндүк Дакотанын борбору)',
        'America/North_Dakota/New_Salem' => 'Түндүк Америка, борбордук убакыт (Нью-Салем, Түндүк Дакота)',
        'America/Ojinaga' => 'Түндүк Америка, тоо убактысы (Охинага)',
        'America/Panama' => 'Түндүк Америка, чыгыш убактысы (Панама)',
        'America/Pangnirtung' => 'Түндүк Америка, чыгыш убактысы (Пангиртуң)',
        'America/Paramaribo' => 'Суринаме убактысы (Парамарибо)',
        'America/Phoenix' => 'Түндүк Америка, тоо убактысы (Феникс)',
        'America/Port-au-Prince' => 'Түндүк Америка, чыгыш убактысы (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атлантика убактысы (Порт оф Спейн)',
        'America/Porto_Velho' => 'Амазон убактысы (Порто Велио)',
        'America/Puerto_Rico' => 'Атлантика убактысы (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чили убактысы (Пунта-Аренас)',
        'America/Rainy_River' => 'Түндүк Америка, борбордук убакыт (Рейни Ривер)',
        'America/Rankin_Inlet' => 'Түндүк Америка, борбордук убакыт (Рэнкин Инлет)',
        'America/Recife' => 'Бразилия убактысы (Ресифи)',
        'America/Regina' => 'Түндүк Америка, борбордук убакыт (Регина)',
        'America/Resolute' => 'Түндүк Америка, борбордук убакыт (Резолут)',
        'America/Rio_Branco' => 'Бразилия убактысы (Рио Бранко)',
        'America/Santa_Isabel' => 'Түндүк-чыгыш Мексика убактысы (Санта Изабел)',
        'America/Santarem' => 'Бразилия убактысы (Сантарем)',
        'America/Santiago' => 'Чили убактысы (Сантиаго)',
        'America/Santo_Domingo' => 'Атлантика убактысы (Санто Доминго)',
        'America/Sao_Paulo' => 'Бразилия убактысы (Сао Пауло)',
        'America/Scoresbysund' => 'Чыгыш Гренландия убактысы (Иттоккортоормиит)',
        'America/Sitka' => 'Аляска убактысы (Ситка)',
        'America/St_Barthelemy' => 'Атлантика убактысы (Сент-Бартелеми)',
        'America/St_Johns' => 'Нюфаундлэнд убактысы (Сент Жонс)',
        'America/St_Kitts' => 'Атлантика убактысы (Сент-Китс)',
        'America/St_Lucia' => 'Атлантика убактысы (Санта Лючия)',
        'America/St_Thomas' => 'Атлантика убактысы (Сент-Томас)',
        'America/St_Vincent' => 'Атлантика убактысы (Сент-Винсент)',
        'America/Swift_Current' => 'Түндүк Америка, борбордук убакыт (Свифт Каррент)',
        'America/Tegucigalpa' => 'Түндүк Америка, борбордук убакыт (Тегусигальпа)',
        'America/Thule' => 'Атлантика убактысы (Туле)',
        'America/Thunder_Bay' => 'Түндүк Америка, чыгыш убактысы (Сандер Бей)',
        'America/Tijuana' => 'Түндүк Америка, Тынч океан убактысы (Тихуана)',
        'America/Toronto' => 'Түндүк Америка, чыгыш убактысы (Торонто)',
        'America/Tortola' => 'Атлантика убактысы (Тортола)',
        'America/Vancouver' => 'Түндүк Америка, Тынч океан убактысы (Ванкувер)',
        'America/Whitehorse' => 'Юкон убактысы (Уайтхорс)',
        'America/Winnipeg' => 'Түндүк Америка, борбордук убакыт (Уиннипег)',
        'America/Yakutat' => 'Аляска убактысы (Якутат)',
        'America/Yellowknife' => 'Түндүк Америка, тоо убактысы (Йеллоунайф)',
        'Antarctica/Casey' => 'Антарктида убактысы (Кейси)',
        'Antarctica/Davis' => 'Дэвис убактысы',
        'Antarctica/DumontDUrville' => 'Дюмон-д-Урвил убактысы',
        'Antarctica/Macquarie' => 'Австралия чыгыш убактысы (Маккуори)',
        'Antarctica/Mawson' => 'Моусон убактысы',
        'Antarctica/McMurdo' => 'Жаңы Зеландия убактысы (МакМёрдо)',
        'Antarctica/Palmer' => 'Чили убактысы (Палмер)',
        'Antarctica/Rothera' => 'Ротера убактысы',
        'Antarctica/Syowa' => 'Саоа убактысы',
        'Antarctica/Troll' => 'Гринвич боюнча орточо убакыт (Тролл)',
        'Antarctica/Vostok' => 'Восток убактысы',
        'Arctic/Longyearbyen' => 'Борбордук Европа убактысы (Лонгйербиен)',
        'Asia/Aden' => 'Арабия убактысы (Аден)',
        'Asia/Almaty' => 'Чыгыш Казакстан убактысы (Алматы)',
        'Asia/Amman' => 'Чыгыш Европа убактысы (Амман)',
        'Asia/Anadyr' => 'Россия убактысы (Анадыр)',
        'Asia/Aqtau' => 'Батыш Казакстан убактысы (Актау)',
        'Asia/Aqtobe' => 'Батыш Казакстан убактысы (Актобе)',
        'Asia/Ashgabat' => 'Түркмөнстан убактысы (Ашхабад)',
        'Asia/Atyrau' => 'Батыш Казакстан убактысы (Атырау)',
        'Asia/Baghdad' => 'Арабия убактысы (Багдад)',
        'Asia/Bahrain' => 'Арабия убактысы (Бахрейн)',
        'Asia/Baku' => 'Азербайжан убактысы (Баку)',
        'Asia/Bangkok' => 'Индокытай убактысы (Бангкок)',
        'Asia/Barnaul' => 'Россия убактысы (Барнаул)',
        'Asia/Beirut' => 'Чыгыш Европа убактысы (Бейрут)',
        'Asia/Bishkek' => 'Кыргызстан убактысы (Бишкек)',
        'Asia/Brunei' => 'Бруней Даруссалам убактысы',
        'Asia/Calcutta' => 'Индия убактысы (Калькутта)',
        'Asia/Chita' => 'Якутск убактысы (Чита)',
        'Asia/Choibalsan' => 'Улан Батор убактысы (Чойбалсан)',
        'Asia/Colombo' => 'Индия убактысы (Коломбо)',
        'Asia/Damascus' => 'Чыгыш Европа убактысы (Дамаск)',
        'Asia/Dhaka' => 'Бангладеш убактысы (Дакка)',
        'Asia/Dili' => 'Чыгыш Тимор убактысы (Дили)',
        'Asia/Dubai' => 'Булуңдун стандарттык убакыты (Дубай)',
        'Asia/Dushanbe' => 'Тажикстан убактысы (Душанбе)',
        'Asia/Famagusta' => 'Чыгыш Европа убактысы (Фамагуста)',
        'Asia/Gaza' => 'Чыгыш Европа убактысы (Газа)',
        'Asia/Hebron' => 'Чыгыш Европа убактысы (Хеброн)',
        'Asia/Hong_Kong' => 'Гонконг убактысы',
        'Asia/Hovd' => 'Ховд убактысы',
        'Asia/Irkutsk' => 'Иркутск убактысы',
        'Asia/Jakarta' => 'Батыш Индонезия убактысы (Жакарта)',
        'Asia/Jayapura' => 'Чыгыш Индонезия убактысы (Жайапура)',
        'Asia/Jerusalem' => 'Израиль убакыты (Иерусалим)',
        'Asia/Kabul' => 'Афганистан убактысы (Кабул)',
        'Asia/Kamchatka' => 'Россия убактысы (Камчатка)',
        'Asia/Karachi' => 'Пакистан убактысы (Карачи)',
        'Asia/Katmandu' => 'Непал убактысы (Катманду)',
        'Asia/Khandyga' => 'Якутск убактысы (Кандыга)',
        'Asia/Krasnoyarsk' => 'Красноярск убактысы',
        'Asia/Kuala_Lumpur' => 'Малайзия убактысы (Куала Лумпур)',
        'Asia/Kuching' => 'Малайзия убактысы (Кучиң)',
        'Asia/Kuwait' => 'Арабия убактысы (Кувейт)',
        'Asia/Macau' => 'Кытай убактысы (Макау)',
        'Asia/Magadan' => 'Магадан убактысы',
        'Asia/Makassar' => 'Борбордук Индонезия убактысы (Макассар)',
        'Asia/Manila' => 'Филиппин аралдарынын убактысы (Манила)',
        'Asia/Muscat' => 'Булуңдун стандарттык убакыты (Мускат)',
        'Asia/Nicosia' => 'Чыгыш Европа убактысы (Никосия)',
        'Asia/Novokuznetsk' => 'Красноярск убактысы (Новокузнецк)',
        'Asia/Novosibirsk' => 'Новосибирск убактысы',
        'Asia/Omsk' => 'Омск убактысы',
        'Asia/Oral' => 'Батыш Казакстан убактысы (Орал)',
        'Asia/Phnom_Penh' => 'Индокытай убактысы (Пномпень)',
        'Asia/Pontianak' => 'Батыш Индонезия убактысы (Понтианак)',
        'Asia/Pyongyang' => 'Корея убактысы (Пхеньян)',
        'Asia/Qatar' => 'Арабия убактысы (Катар)',
        'Asia/Qostanay' => 'Чыгыш Казакстан убактысы (Костанай)',
        'Asia/Qyzylorda' => 'Батыш Казакстан убактысы (Кызылорда)',
        'Asia/Rangoon' => 'Мйанмар убактысы (Рангун)',
        'Asia/Riyadh' => 'Арабия убактысы (Рийад)',
        'Asia/Saigon' => 'Индокытай убактысы (Хо Ши Мин)',
        'Asia/Sakhalin' => 'Сахалин убактысы',
        'Asia/Samarkand' => 'Өзбекстан убактысы (Самарканд)',
        'Asia/Seoul' => 'Корея убактысы (Сеул)',
        'Asia/Shanghai' => 'Кытай убактысы (Шанхай)',
        'Asia/Singapore' => 'Сингапур убактысы',
        'Asia/Srednekolymsk' => 'Магадан убактысы (Среднеколымск)',
        'Asia/Taipei' => 'Тайпей убактысы',
        'Asia/Tashkent' => 'Өзбекстан убактысы (Ташкент)',
        'Asia/Tbilisi' => 'Грузия убактысы (Тбилиси)',
        'Asia/Tehran' => 'Иран убактысы (Тегеран)',
        'Asia/Thimphu' => 'Бутан убактысы (Тимпу)',
        'Asia/Tokyo' => 'Жапон убактысы (Токио)',
        'Asia/Tomsk' => 'Россия убактысы (Томск)',
        'Asia/Ulaanbaatar' => 'Улан Батор убактысы',
        'Asia/Urumqi' => 'Кытай убактысы (Үрүмчү)',
        'Asia/Ust-Nera' => 'Владивосток убактысы (Усть-Нера)',
        'Asia/Vientiane' => 'Индокытай убактысы (Виентиан)',
        'Asia/Vladivostok' => 'Владивосток убактысы',
        'Asia/Yakutsk' => 'Якутск убактысы',
        'Asia/Yekaterinburg' => 'Екатеринбург убактысы',
        'Asia/Yerevan' => 'Армения убактысы (Ереван)',
        'Atlantic/Azores' => 'Азор убактысы',
        'Atlantic/Bermuda' => 'Атлантика убактысы (Бермуда)',
        'Atlantic/Canary' => 'Батыш Европа убактысы (Канари)',
        'Atlantic/Cape_Verde' => 'Капе Верде убактысы',
        'Atlantic/Faeroe' => 'Батыш Европа убактысы (Фарер)',
        'Atlantic/Madeira' => 'Батыш Европа убактысы (Мадейра)',
        'Atlantic/Reykjavik' => 'Гринвич боюнча орточо убакыт (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Түштүк Жоржия убактысы',
        'Atlantic/St_Helena' => 'Гринвич боюнча орточо убакыт (Сент Елена)',
        'Atlantic/Stanley' => 'Фолкленд аралдарынын убактысы (Стэнли)',
        'Australia/Adelaide' => 'Австралия борбордук убактысы (Аделаида)',
        'Australia/Brisbane' => 'Австралия чыгыш убактысы (Брисбен)',
        'Australia/Broken_Hill' => 'Австралия борбордук убактысы (Броукен Хил)',
        'Australia/Currie' => 'Австралия чыгыш убактысы (Керри)',
        'Australia/Darwin' => 'Австралия борбордук убактысы (Дарвин)',
        'Australia/Eucla' => 'Австралия борбордук батыш убактысы (Юкла)',
        'Australia/Hobart' => 'Австралия чыгыш убактысы (Хобарт)',
        'Australia/Lindeman' => 'Австралия чыгыш убактысы (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд Хау убактысы',
        'Australia/Melbourne' => 'Австралия чыгыш убактысы (Мельбурн)',
        'Australia/Perth' => 'Австралия батыш убактысы (Перт)',
        'Australia/Sydney' => 'Австралия чыгыш убактысы (Сидней)',
        'CST6CDT' => 'Түндүк Америка, борбордук убакыт',
        'EST5EDT' => 'Түндүк Америка, чыгыш убактысы',
        'Etc/GMT' => 'Гринвич боюнча орточо убакыт',
        'Etc/UTC' => 'Бирдиктүү дүйнөлүк убакыт',
        'Europe/Amsterdam' => 'Борбордук Европа убактысы (Амстердам)',
        'Europe/Andorra' => 'Борбордук Европа убактысы (Андорра)',
        'Europe/Astrakhan' => 'Москва убактысы (Астрахань)',
        'Europe/Athens' => 'Чыгыш Европа убактысы (Афины)',
        'Europe/Belgrade' => 'Борбордук Европа убактысы (Белград)',
        'Europe/Berlin' => 'Борбордук Европа убактысы (Берлин)',
        'Europe/Bratislava' => 'Борбордук Европа убактысы (Братислава)',
        'Europe/Brussels' => 'Борбордук Европа убактысы (Брюссель)',
        'Europe/Bucharest' => 'Чыгыш Европа убактысы (Бухарест)',
        'Europe/Budapest' => 'Борбордук Европа убактысы (Будапешт)',
        'Europe/Busingen' => 'Борбордук Европа убактысы (Бузинген)',
        'Europe/Chisinau' => 'Чыгыш Европа убактысы (Кишинев)',
        'Europe/Copenhagen' => 'Борбордук Европа убактысы (Копенгаген)',
        'Europe/Dublin' => 'Гринвич боюнча орточо убакыт (Дублин)',
        'Europe/Gibraltar' => 'Борбордук Европа убактысы (Гибралтар)',
        'Europe/Guernsey' => 'Гринвич боюнча орточо убакыт (Гернси)',
        'Europe/Helsinki' => 'Чыгыш Европа убактысы (Хельсинки)',
        'Europe/Isle_of_Man' => 'Гринвич боюнча орточо убакыт (Мэн аралы)',
        'Europe/Istanbul' => 'Түркия убактысы (Стамбул)',
        'Europe/Jersey' => 'Гринвич боюнча орточо убакыт (Жерси)',
        'Europe/Kaliningrad' => 'Чыгыш Европа убактысы (Калининград)',
        'Europe/Kiev' => 'Чыгыш Европа убактысы (Киев)',
        'Europe/Kirov' => 'Россия убактысы (Киров)',
        'Europe/Lisbon' => 'Батыш Европа убактысы (Лиссабон)',
        'Europe/Ljubljana' => 'Борбордук Европа убактысы (Любляна)',
        'Europe/London' => 'Гринвич боюнча орточо убакыт (Лондон)',
        'Europe/Luxembourg' => 'Борбордук Европа убактысы (Люксембург)',
        'Europe/Madrid' => 'Борбордук Европа убактысы (Мадрид)',
        'Europe/Malta' => 'Борбордук Европа убактысы (Мальта)',
        'Europe/Mariehamn' => 'Чыгыш Европа убактысы (Мариехамн)',
        'Europe/Minsk' => 'Москва убактысы (Минск)',
        'Europe/Monaco' => 'Борбордук Европа убактысы (Монако)',
        'Europe/Moscow' => 'Москва убактысы',
        'Europe/Oslo' => 'Борбордук Европа убактысы (Осло)',
        'Europe/Paris' => 'Борбордук Европа убактысы (Париж)',
        'Europe/Podgorica' => 'Борбордук Европа убактысы (Подгорица)',
        'Europe/Prague' => 'Борбордук Европа убактысы (Прага)',
        'Europe/Riga' => 'Чыгыш Европа убактысы (Рига)',
        'Europe/Rome' => 'Борбордук Европа убактысы (Рим)',
        'Europe/Samara' => 'Россия убактысы (Самара)',
        'Europe/San_Marino' => 'Борбордук Европа убактысы (Сан Марино)',
        'Europe/Sarajevo' => 'Борбордук Европа убактысы (Сараево)',
        'Europe/Saratov' => 'Москва убактысы (Саратов)',
        'Europe/Simferopol' => 'Москва убактысы (Симферополь)',
        'Europe/Skopje' => 'Борбордук Европа убактысы (Скопйе)',
        'Europe/Sofia' => 'Чыгыш Европа убактысы (София)',
        'Europe/Stockholm' => 'Борбордук Европа убактысы (Стокгольм)',
        'Europe/Tallinn' => 'Чыгыш Европа убактысы (Таллин)',
        'Europe/Tirane' => 'Борбордук Европа убактысы (Тирана)',
        'Europe/Ulyanovsk' => 'Москва убактысы (Ульяновск)',
        'Europe/Uzhgorod' => 'Чыгыш Европа убактысы (Ужгород)',
        'Europe/Vaduz' => 'Борбордук Европа убактысы (Фадуц)',
        'Europe/Vatican' => 'Борбордук Европа убактысы (Ватикан)',
        'Europe/Vienna' => 'Борбордук Европа убактысы (Вена)',
        'Europe/Vilnius' => 'Чыгыш Европа убактысы (Вильнюс)',
        'Europe/Volgograd' => 'Волгоград убактысы',
        'Europe/Warsaw' => 'Борбордук Европа убактысы (Варшава)',
        'Europe/Zagreb' => 'Борбордук Европа убактысы (Загреб)',
        'Europe/Zaporozhye' => 'Чыгыш Европа убактысы (Запорожье)',
        'Europe/Zurich' => 'Борбордук Европа убактысы (Цюрих)',
        'Indian/Antananarivo' => 'Чыгыш Африка убактысы (Антананариво)',
        'Indian/Chagos' => 'Инди океан убактысы (Чагос)',
        'Indian/Christmas' => 'Крисмас аралынын убактысы',
        'Indian/Cocos' => 'Кокос аралдарынын убактысы',
        'Indian/Comoro' => 'Чыгыш Африка убактысы (Коморо)',
        'Indian/Kerguelen' => 'Француз Түштүгү жана Антарктика убактысы (Кергелен)',
        'Indian/Mahe' => 'Сейшел убактысы (Маэ)',
        'Indian/Maldives' => 'Мальдив убактысы (Мальдив аралдары)',
        'Indian/Mauritius' => 'Маврикий убактысы',
        'Indian/Mayotte' => 'Чыгыш Африка убактысы (Майотт)',
        'Indian/Reunion' => 'Реюнион убактысы',
        'MST7MDT' => 'Түндүк Америка, тоо убактысы',
        'PST8PDT' => 'Түндүк Америка, Тынч океан убактысы',
        'Pacific/Apia' => 'Апиа убактысы',
        'Pacific/Auckland' => 'Жаңы Зеландия убактысы (Оклэнд)',
        'Pacific/Bougainville' => 'Папуа-Жаңы Гвинея убакыты (Бугенвиль)',
        'Pacific/Chatham' => 'Чатам убактысы (Чатем)',
        'Pacific/Easter' => 'Истер аралынын убактысы',
        'Pacific/Efate' => 'Вануату убактысы (Эфат)',
        'Pacific/Enderbury' => 'Феникс аралдарынын убактысы (Эндербери)',
        'Pacific/Fakaofo' => 'Токелау убактысы (Факаофо)',
        'Pacific/Fiji' => 'Фижи убактысы',
        'Pacific/Funafuti' => 'Тувалу убактысы (Фунафути)',
        'Pacific/Galapagos' => 'Галапагос убактысы',
        'Pacific/Gambier' => 'Гамбие убактысы',
        'Pacific/Guadalcanal' => 'Соломон аралдарынын убактысы (Гуадалканал)',
        'Pacific/Guam' => 'Чаморро убактысы (Гуам)',
        'Pacific/Honolulu' => 'Гавайи-Алеут убактысы (Гонолулу)',
        'Pacific/Johnston' => 'Гавайи-Алеут убактысы (Жонстон)',
        'Pacific/Kiritimati' => 'Лайн аралдарынын убактысы (Киритимати)',
        'Pacific/Kosrae' => 'Косрае убактысы (Козрае)',
        'Pacific/Kwajalein' => 'Маршалл аралдарынын убактысы (Куажалейн)',
        'Pacific/Majuro' => 'Маршалл аралдарынын убактысы (Мажуро)',
        'Pacific/Marquesas' => 'Маркезас убактысы',
        'Pacific/Midway' => 'Самоа убактысы (Мидуэй)',
        'Pacific/Nauru' => 'Науру убактысы',
        'Pacific/Niue' => 'Ниуэ убактысы',
        'Pacific/Norfolk' => 'Норфолк убактысы',
        'Pacific/Noumea' => 'Жаңы Каледония убактысы (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа убактысы (Паго Паго)',
        'Pacific/Palau' => 'Палау убактысы',
        'Pacific/Pitcairn' => 'Питкэрнг убактысы',
        'Pacific/Ponape' => 'Понапе убактысы (Понпей)',
        'Pacific/Port_Moresby' => 'Папуа-Жаңы Гвинея убакыты (Порт Моэрсби)',
        'Pacific/Rarotonga' => 'Кук аралдарынын убактысы (Раготонга)',
        'Pacific/Saipan' => 'Чаморро убактысы (Сайпан)',
        'Pacific/Tahiti' => 'Таити убактысы',
        'Pacific/Tarawa' => 'Гилберт убактысы (Тарава)',
        'Pacific/Tongatapu' => 'Тонга убактысы (Тонгатапу)',
        'Pacific/Truk' => 'Чуук убактысы',
        'Pacific/Wake' => 'Уейк аралдарынын убактысы',
        'Pacific/Wallis' => 'Уолис жана Футуна убактысы',
    ],
    'Meta' => [
    ],
];
