<?php

return [
    'Names' => [
        'af' => '𞤀𞤬𞤪𞤭𞤳𞤢𞤲𞤪𞤫',
        'af_NA' => '𞤀𞤬𞤪𞤭𞤳𞤢𞤲𞤪𞤫 (𞤐𞤢𞤥𞤭𞥅𞤦𞤭𞤴𞤢𞥄)',
        'af_ZA' => '𞤀𞤬𞤪𞤭𞤳𞤢𞤲𞤪𞤫 (𞤀𞤬𞤪𞤭𞤳𞤢 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
        'ak' => '𞤀𞤳𞤢𞤲𞤪𞤫',
        'ak_GH' => '𞤀𞤳𞤢𞤲𞤪𞤫 (𞤘𞤢𞤲𞤢)',
        'am' => '𞤀𞤥𞤸𞤢𞤪𞤭𞥅𞤪𞤫',
        'am_ET' => '𞤀𞤥𞤸𞤢𞤪𞤭𞥅𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
        'ar' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫',
        'ar_001' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
        'ar_AE' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤋𞤥𞤪𞤢𞥄𞤼𞤭 𞤀𞥄𞤪𞤢𞤦𞤵)',
        'ar_BH' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤄𞤢𞤸𞤢𞤪𞤢𞤴𞤲)',
        'ar_DJ' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤔𞤭𞤦𞤵𞥅𞤼𞤭)',
        'ar_DZ' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤀𞤤𞤶𞤢𞤪𞤭𞥅)',
        'ar_EG' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤃𞤭𞤧𞤭𞤪𞤢)',
        'ar_EH' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤅𞤢𞥄𞤸𞤢𞤪𞤢 𞤖𞤭𞥅𞤲𞤢𞥄𞤪𞤭)',
        'ar_ER' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤉𞤪𞤭𞥅𞤼𞤫𞤪𞤫)',
        'ar_IL' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤋𞤧𞤪𞤢𞥄𞤴𞤭𞥅𞤤)',
        'ar_IQ' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤋𞤪𞤢𞥄𞤳)',
        'ar_JO' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤔𞤮𞤪𞤣𞤢𞥄𞤲)',
        'ar_KM' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤑𞤮𞤥𞤮𞥅𞤪𞤮)',
        'ar_KW' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤑𞤵𞤱𞤢𞤴𞤼𞤵)',
        'ar_LB' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤂𞤭𞤦𞤢𞤲𞤮𞥅𞤲)',
        'ar_LY' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤂𞤭𞤦𞤭𞤴𞤢𞥄)',
        'ar_MA' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤃𞤢𞤪𞤮𞥅𞤳)',
        'ar_MR' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤃𞤮𞤪𞤼𞤢𞤲𞤭𞥅)',
        'ar_OM' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤌𞥅𞤥𞤢𞥄𞤲)',
        'ar_PS' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤂𞤫𞤧𞤣𞤭𞥅𞤶𞤭 𞤊𞤢𞤤𞤫𞤧𞤼𞤭𞥅𞤲)',
        'ar_QA' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤊𞤢𞤤𞤫𞤧𞤼𞤭𞥅𞤲)',
        'ar_SA' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤅𞤢𞤵𞥅𞤣 𞤀𞥄𞤪𞤢𞤦𞤭𞤴𞤢𞥄)',
        'ar_SD' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤅𞤵𞤣𞤢𞥄𞤲)',
        'ar_SO' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤅𞤵𞥅𞤥𞤢𞥄𞤤𞤭)',
        'ar_SS' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤅𞤵𞤣𞤢𞥄𞤲 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
        'ar_SY' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤅𞤵𞥅𞤪𞤭𞤴𞤢𞥄)',
        'ar_TD' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤕𞤢𞥄𞤣)',
        'ar_TN' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤚𞤵𞤲𞤭𞥅𞤧𞤢)',
        'ar_YE' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 (𞤒𞤢𞤥𞤢𞤲)',
        'as' => '𞤀𞤧𞤢𞤥𞤫𞥅𞤪𞤫',
        'as_IN' => '𞤀𞤧𞤢𞤥𞤫𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'az' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫',
        'az_AZ' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫 (𞤀𞥁𞤫𞤪𞤦𞤢𞤭𞤶𞤢𞥄𞤲)',
        'az_Cyrl' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳)',
        'az_Cyrl_AZ' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤀𞥁𞤫𞤪𞤦𞤢𞤭𞤶𞤢𞥄𞤲)',
        'az_Latn' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
        'az_Latn_AZ' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤀𞥁𞤫𞤪𞤦𞤢𞤭𞤶𞤢𞥄𞤲)',
        'be' => '𞤄𞤫𞤤𞤢𞤪𞤭𞥅𞤧𞤭𞥅𞤪𞤫',
        'be_BY' => '𞤄𞤫𞤤𞤢𞤪𞤭𞥅𞤧𞤭𞥅𞤪𞤫 (𞤄𞤫𞤤𞤢𞤪𞤵𞥅𞤧)',
        'bg' => '𞤄𞤭𞤤𞤺𞤢𞥄𞤪𞤫',
        'bg_BG' => '𞤄𞤭𞤤𞤺𞤢𞥄𞤪𞤫 (𞤄𞤵𞥅𞤤𞤺𞤢𞤪𞤭𞤴𞤢𞥄)',
        'bm' => '𞤄𞤢𞤥𞤦𞤢𞤪𞤢𞥄𞤪𞤫',
        'bm_ML' => '𞤄𞤢𞤥𞤦𞤢𞤪𞤢𞥄𞤪𞤫 (𞤃𞤢𞥄𞤤𞤭)',
        'bn' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫',
        'bn_BD' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫 (𞤄𞤢𞤲𞤺𞤭𞤤𞤢𞤣𞤫𞥅𞤧)',
        'bn_IN' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'bo' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫',
        'bo_CN' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫 (𞤕𞤢𞤴𞤲𞤢)',
        'bo_IN' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'br' => '𞤄𞤫𞤪𞤫𞤼𞤮𞤲𞤪𞤫',
        'br_FR' => '𞤄𞤫𞤪𞤫𞤼𞤮𞤲𞤪𞤫 (𞤊𞤢𞤪𞤢𞤲𞤧𞤭)',
        'bs' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫',
        'bs_BA' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫 (𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'bs_Cyrl' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳)',
        'bs_Cyrl_BA' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'bs_Latn' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
        'bs_Latn_BA' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'ca' => '𞤑𞤢𞤼𞤢𞤤𞤢𞤲𞤪𞤫',
        'ca_AD' => '𞤑𞤢𞤼𞤢𞤤𞤢𞤲𞤪𞤫 (𞤀𞤲𞤣𞤮𞤪𞤢𞥄)',
        'ca_ES' => '𞤑𞤢𞤼𞤢𞤤𞤢𞤲𞤪𞤫 (𞤉𞤧𞤨𞤢𞤻𞤢𞥄)',
        'ca_FR' => '𞤑𞤢𞤼𞤢𞤤𞤢𞤲𞤪𞤫 (𞤊𞤢𞤪𞤢𞤲𞤧𞤭)',
        'ca_IT' => '𞤑𞤢𞤼𞤢𞤤𞤢𞤲𞤪𞤫 (𞤋𞤼𞤢𞤤𞤭𞥅)',
        'ce' => '𞤕𞤫𞤷𞤫𞤲𞤪𞤫',
        'ce_RU' => '𞤕𞤫𞤷𞤫𞤲𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
        'cs' => '𞤕𞤫𞤳𞤧𞤭𞤲𞤢𞥄𞤪𞤫',
        'cs_CZ' => '𞤕𞤫𞤳𞤧𞤭𞤲𞤢𞥄𞤪𞤫 (𞤕𞤫𞥅𞤳𞤭𞤴𞤢𞥄)',
        'cv' => '𞤕𞤵𞥅𞤾𞤢𞤧𞤪𞤫',
        'cv_RU' => '𞤕𞤵𞥅𞤾𞤢𞤧𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
        'cy' => '𞤘𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'cy_GB' => '𞤘𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
        'da' => '𞤁𞤢𞥄𞤲𞤭𞤧𞤳𞤮𞥅𞤪𞤫',
        'da_DK' => '𞤁𞤢𞥄𞤲𞤭𞤧𞤳𞤮𞥅𞤪𞤫 (𞤁𞤢𞤲𞤵𞤥𞤢𞤪𞤳)',
        'da_GL' => '𞤁𞤢𞥄𞤲𞤭𞤧𞤳𞤮𞥅𞤪𞤫 (𞤘𞤭𞤪𞤤𞤢𞤲𞤣𞤭)',
        'de' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'de_AT' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤌𞤼𞤭𞤪𞤧𞤢)',
        'de_BE' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤫𞤤𞤶𞤭𞤳𞤢𞥄)',
        'de_CH' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
        'de_DE' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞥅)',
        'de_IT' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤼𞤢𞤤𞤭𞥅)',
        'de_LI' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤂𞤭𞤧𞤼𞤫𞤲𞤧𞤭𞤼𞤫𞥅𞤲)',
        'de_LU' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
        'dz' => '𞤄𞤵𞥅𞤼𞤢𞤲𞤪𞤫',
        'dz_BT' => '𞤄𞤵𞥅𞤼𞤢𞤲𞤪𞤫 (𞤄𞤵𞥅𞤼𞤢𞥄𞤲)',
        'ee' => '𞤉𞤱𞤫𞥅𞤪𞤫',
        'ee_GH' => '𞤉𞤱𞤫𞥅𞤪𞤫 (𞤘𞤢𞤲𞤢)',
        'ee_TG' => '𞤉𞤱𞤫𞥅𞤪𞤫 (𞤚𞤮𞤺𞤮)',
        'el' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫',
        'el_CY' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫 (𞤑𞤵𞤦𞤪𞤵𞥅𞤧)',
        'el_GR' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫 (𞤀𞤤𞤴𞤵𞤲𞤢𞥄𞤲)',
        'en' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫',
        'en_001' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
        'en_150' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤓𞤪𞤨𞤢)',
        'en_AE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤋𞤥𞤪𞤢𞥄𞤼𞤭 𞤀𞥄𞤪𞤢𞤦𞤵)',
        'en_AG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤀𞤲𞤼𞤭𞤺𞤵𞤱𞤢 & 𞤄𞤢𞤪𞤦𞤵𞥅𞤣𞤢)',
        'en_AI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤀𞤲𞤺𞤭𞤤𞤢𞥄)',
        'en_AS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤢𞤥𞤵𞤱𞤢 𞤀𞤥𞤫𞤪𞤭𞤳𞤭𞤴𞤢𞤲𞤳𞤮)',
        'en_AT' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤌𞤼𞤭𞤪𞤧𞤢)',
        'en_AU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤌𞤧𞤼𞤢𞤪𞤤𞤭𞤴𞤢𞥄)',
        'en_BB' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤄𞤢𞤪𞤦𞤫𞥅𞤣𞤮𞥅𞤧)',
        'en_BE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤄𞤫𞤤𞤶𞤭𞤳𞤢𞥄)',
        'en_BI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤄𞤵𞤪𞤵𞤲𞤣𞤭)',
        'en_BM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤄𞤭𞤪𞤥𞤵𞤣𞤢)',
        'en_BS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤄𞤢𞤸𞤢𞤥𞤢𞥄𞤧)',
        'en_BW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (‮𞤄𞤮𞤼𞤧𞤵𞤱𞤢𞥄𞤲𞤢)',
        'en_BZ' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤄𞤫𞤤𞤭𞥅𞥁)',
        'en_CA' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤑𞤢𞤲𞤢𞤣𞤢𞥄)',
        'en_CC' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤑𞤮𞤳𞤮𞥅𞤧 [𞤑𞤭𞥅𞤤𞤭𞤲𞤺])',
        'en_CH' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
        'en_CK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤑𞤵𞥅𞤳)',
        'en_CM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤑𞤢𞤥𞤢𞤪𞤵𞥅𞤲)',
        'en_CX' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤑𞤭𞤪𞤧𞤭𞤥𞤢𞥄𞤧)',
        'en_CY' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤑𞤵𞤦𞤪𞤵𞥅𞤧)',
        'en_DE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞥅)',
        'en_DK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤁𞤢𞤲𞤵𞤥𞤢𞤪𞤳)',
        'en_DM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤁𞤮𞤥𞤭𞤲𞤭𞤳𞤢𞥄)',
        'en_ER' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤉𞤪𞤭𞥅𞤼𞤫𞤪𞤫)',
        'en_FI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
        'en_FJ' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤊𞤭𞤶𞤭𞥅)',
        'en_FK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤊𞤢𞤤𞤳𞤵𞤤𞤢𞤲𞤣)',
        'en_FM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤭𞤳𞤪𞤮𞤲𞤫𞥅𞤧𞤭𞤴𞤢)',
        'en_GB' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
        'en_GD' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤪𞤲𞤢𞤣𞤢𞥄)',
        'en_GG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤪𞤲𞤫𞤧𞤭𞥅)',
        'en_GH' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤲𞤢)',
        'en_GI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤔𞤭𞤦𞤪𞤢𞤤𞤼𞤢𞥄)',
        'en_GM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤥𞤦𞤭𞤴𞤢)',
        'en_GU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤵𞤱𞤢𞥄𞤥)',
        'en_GY' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤘𞤢𞤴𞤢𞤲𞤢𞥄)',
        'en_HK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
        'en_IE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤋𞤪𞤤𞤢𞤲𞤣)',
        'en_IL' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤋𞤧𞤪𞤢𞥄𞤴𞤭𞥅𞤤)',
        'en_IM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤃𞤫𞥅𞤲)',
        'en_IN' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'en_IO' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤚𞤵𞤥𞤦𞤫𞤪𞤫 𞤄𞤪𞤭𞤼𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 𞤀𞤬𞤪𞤭𞤳𞤭)',
        'en_JE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤔𞤫𞤪𞤧𞤭𞥅)',
        'en_JM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤔𞤢𞤥𞤢𞤴𞤳𞤢𞥄)',
        'en_KE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
        'en_KI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤑𞤭𞤪𞤦𞤢𞤼𞤭𞥅)',
        'en_KN' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤼. 𞤑𞤪𞤭𞤧𞤼𞤮𞤦𞤢𞤤 & 𞤐𞤫𞥅𞤾𞤭𞤧)',
        'en_KY' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤑𞤢𞤴𞤥𞤢𞥄𞤲)',
        'en_LC' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤼. 𞤂𞤵𞥅𞤧𞤭𞤴𞤢)',
        'en_LR' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤂𞤢𞤦𞤭𞤪𞤭𞤴𞤢𞥄)',
        'en_LS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤂𞤫𞤧𞤮𞤼𞤮𞥅)',
        'en_MG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤣𞤢𞤺𞤢𞤧𞤳𞤢𞥄𞤪)',
        'en_MH' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤃𞤢𞤪𞥃𞤢𞤤)',
        'en_MO' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
        'en_MP' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤃𞤢𞤪𞤭𞤴𞤢𞥄𞤲𞤢 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤭)',
        'en_MS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤮𞤲𞤧𞤭𞤪𞤢𞥄𞤼)',
        'en_MT' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤼𞤢)',
        'en_MU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤮𞤪𞤭𞥅𞤧𞤭)',
        'en_MV' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤣𞤭𞥅𞤬)',
        'en_MW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤢𞤱𞤭𞥅)',
        'en_MY' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤫𞥅𞤧𞤭𞤴𞤢)',
        'en_NA' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤐𞤢𞤥𞤭𞥅𞤦𞤭𞤴𞤢𞥄)',
        'en_NF' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤐𞤮𞤪𞤬𞤮𞤤𞤳𞤵)',
        'en_NG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
        'en_NL' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤖𞤮𞤤𞤢𞤲𞤣𞤭𞤴𞤢𞥄)',
        'en_NR' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤐𞤢𞤱𞤪𞤵)',
        'en_NU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤐𞤵𞥅𞤱𞤭)',
        'en_NZ' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤐𞤫𞤱 𞤟𞤫𞤤𞤢𞤲𞤣)',
        'en_PG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤆𞤢𞤨𞤵𞤱𞤢 𞤘𞤭𞤲𞤫 𞤖𞤫𞤧𞤮)',
        'en_PH' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤊𞤭𞤤𞤭𞤨𞤭𞥅𞤲)',
        'en_PK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'en_PN' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤆𞤭𞤼𞤳𞤭𞥅𞤪𞤲𞤵)',
        'en_PR' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤆𞤮𞤪𞤼𞤮 𞤈𞤭𞤳𞤮𞥅)',
        'en_PW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤆𞤢𞤤𞤢𞤱)',
        'en_RW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤈𞤵𞤱𞤢𞤲𞤣𞤢𞥄)',
        'en_SB' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤅𞤵𞤤𞤢𞤴𞤥𞤢𞥄𞤲)',
        'en_SC' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤫𞤴𞤭𞤧𞤫𞤤)',
        'en_SD' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤣𞤢𞥄𞤲)',
        'en_SE' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤱𞤫𞤣𞤭𞤴𞤢𞥄)',
        'en_SG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
        'en_SH' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤫𞤲-𞤖𞤫𞤤𞤫𞤲𞤢𞥄)',
        'en_SI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞥄)',
        'en_SL' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤢𞤪𞤢𞤤𞤮𞤲)',
        'en_SS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤵𞤣𞤢𞥄𞤲 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
        'en_SX' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤫𞤲𞤼𞤵 𞤃𞤢𞥄𞤪𞤼𞤫𞤲)',
        'en_SZ' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤉𞤧𞤱𞤢𞤼𞤭𞤲𞤭)',
        'en_TC' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤚𞤵𞤪𞤳𞤵𞤧 & 𞤑𞤢𞤴𞤳𞤮𞥅𞤧)',
        'en_TK' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤚𞤮𞥅𞤳𞤮𞤤𞤢𞥄𞤱𞤵)',
        'en_TO' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤚𞤮𞤲𞤺𞤢)',
        'en_TT' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤚𞤭𞤪𞤲𞤭𞤣𞤢𞥄𞤣 & 𞤚𞤮𞤦𞤢𞤺𞤮𞥅)',
        'en_TV' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤚𞤵𞥅𞤾𞤢𞤤𞤵)',
        'en_TZ' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤚𞤢𞤲𞤧𞤢𞤲𞤭𞥅)',
        'en_UG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤓𞤺𞤢𞤲𞤣𞤢𞥄)',
        'en_UM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤁𞤢𞥄𞤴𞤭𞥅𞤯𞤫 𞤁𞤂𞤀)',
        'en_US' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤂𞤢𞤪𞤫)',
        'en_VC' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤼. 𞤜𞤭𞤲𞤧𞤢𞤲 & 𞤘𞤭𞤪𞤲𞤢𞤣𞤭𞥅𞤲)',
        'en_VG' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤜𞤭𞤪𞤺𞤭𞥅𞤲 𞤄𞤪𞤭𞤼𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤶𞤫)',
        'en_VI' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤜𞤭𞤪𞤺𞤭𞥅𞤲 𞤁𞤂𞤀)',
        'en_VU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤜𞤢𞤲𞤵𞤱𞤢𞥄𞤼𞤵)',
        'en_WS' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤅𞤢𞤥𞤵𞤱𞤢)',
        'en_ZA' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤀𞤬𞤪𞤭𞤳𞤢 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
        'en_ZM' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤟𞤢𞤥𞤦𞤭𞤴𞤢)',
        'en_ZW' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 (𞤟𞤭𞤥𞤦𞤢𞥄𞤥𞤵𞤴𞤢)',
        'eo' => '𞤉𞤧𞤨𞤫𞤪𞤢𞤲𞤼𞤮𞥅𞤪𞤫',
        'eo_001' => '𞤉𞤧𞤨𞤫𞤪𞤢𞤲𞤼𞤮𞥅𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
        'es' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'es_419' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤥𞤫𞤪𞤭𞤳𞤢𞥄 𞤂𞤢𞤼𞤭𞤲𞤳𞤮)',
        'es_AR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤪𞤶𞤢𞤲𞤼𞤭𞤲𞤢𞥄)',
        'es_BO' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤮𞤤𞤭𞥅𞤾𞤭𞤴𞤢𞥄)',
        'es_BR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤪𞤢𞤧𞤭𞤤)',
        'es_BZ' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤄𞤫𞤤𞤭𞥅𞥁)',
        'es_CL' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤕𞤭𞤤𞤫𞥊𞥅)',
        'es_CO' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤑𞤮𞤤𞤮𞤥𞤦𞤭𞤴𞤢𞥄)',
        'es_CR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤑𞤮𞤧𞤼𞤢 𞤈𞤭𞤳𞤢𞥄)',
        'es_CU' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤑𞤵𞥅𞤦𞤢𞥄)',
        'es_DO' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤐𞤣𞤫𞤲𞤣𞤭 𞤁𞤮𞤥𞤭𞤲𞤭𞤳𞤢𞥄)',
        'es_EC' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤉𞤳𞤵𞤱𞤢𞤣𞤮𞥅𞤪)',
        'es_ES' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤉𞤧𞤨𞤢𞤻𞤢𞥄)',
        'es_GQ' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫 𞤕𞤢𞤳𞤢𞤲𞤼𞤫𞥅𞤪𞤭)',
        'es_GT' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤘𞤵𞤱𞤢𞤼𞤫𞤥𞤢𞤤𞤢𞥄)',
        'es_HN' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤲𞤣𞤭𞤪𞤢𞥄𞤧)',
        'es_MX' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤫𞤳𞤧𞤭𞤳𞤮𞥅)',
        'es_NI' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤐𞤭𞤳𞤢𞤪𞤢𞤺𞤵𞤱𞤢𞥄)',
        'es_PA' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤆𞤢𞤲𞤢𞤥𞤢)',
        'es_PE' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤆𞤫𞤪𞤵𞥅)',
        'es_PH' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤊𞤭𞤤𞤭𞤨𞤭𞥅𞤲)',
        'es_PR' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤆𞤮𞤪𞤼𞤮 𞤈𞤭𞤳𞤮𞥅)',
        'es_PY' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤆𞤢𞥄𞤪𞤢𞤺𞤵𞤱𞤢𞥄𞤴)',
        'es_SV' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤉𞤤 𞤅𞤢𞤤𞤾𞤢𞤣𞤮𞥅𞤪)',
        'es_US' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤂𞤢𞤪𞤫)',
        'es_UY' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤒𞤵𞤪𞤺𞤮𞤴)',
        'es_VE' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤜𞤫𞥊𞤲𞤭𞥅𞥁𞤵𞤱𞤫𞤤𞤢𞥄)',
        'et' => '𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'et_EE' => '𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞥄)',
        'eu' => '𞤄𞤢𞤧𞤳𞤢𞤪𞤢𞥄𞤪𞤫',
        'eu_ES' => '𞤄𞤢𞤧𞤳𞤢𞤪𞤢𞥄𞤪𞤫 (𞤉𞤧𞤨𞤢𞤻𞤢𞥄)',
        'fa' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'fa_AF' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
        'fa_IR' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤪𞤢𞥄𞤲)',
        'ff' => '𞤆𞤵𞤤𞤢𞤪',
        'ff_Adlm' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃)',
        'ff_Adlm_BF' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤄𞤵𞤪𞤳𞤭𞤲𞤢 𞤊𞤢𞤧𞤮𞥅)',
        'ff_Adlm_CM' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤑𞤢𞤥𞤢𞤪𞤵𞥅𞤲)',
        'ff_Adlm_GH' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤘𞤢𞤲𞤢)',
        'ff_Adlm_GM' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤘𞤢𞤥𞤦𞤭𞤴𞤢)',
        'ff_Adlm_GN' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤘𞤭𞤲𞤫)',
        'ff_Adlm_GW' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤘𞤭𞤲𞤫-𞤄𞤭𞤧𞤢𞤱𞤮𞥅)',
        'ff_Adlm_LR' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤂𞤢𞤦𞤭𞤪𞤭𞤴𞤢𞥄)',
        'ff_Adlm_MR' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤃𞤮𞤪𞤼𞤢𞤲𞤭𞥅)',
        'ff_Adlm_NE' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤐𞤭𞥅𞤶𞤫𞤪)',
        'ff_Adlm_NG' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
        'ff_Adlm_SL' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤅𞤢𞤪𞤢𞤤𞤮𞤲)',
        'ff_Adlm_SN' => '𞤆𞤵𞤤𞤢𞤪 (𞤀𞤁𞤂𞤢𞤃⹁ 𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
        'ff_CM' => '𞤆𞤵𞤤𞤢𞤪 (𞤑𞤢𞤥𞤢𞤪𞤵𞥅𞤲)',
        'ff_GN' => '𞤆𞤵𞤤𞤢𞤪 (𞤘𞤭𞤲𞤫)',
        'ff_Latn' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲)',
        'ff_Latn_BF' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤄𞤵𞤪𞤳𞤭𞤲𞤢 𞤊𞤢𞤧𞤮𞥅)',
        'ff_Latn_CM' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤑𞤢𞤥𞤢𞤪𞤵𞥅𞤲)',
        'ff_Latn_GH' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤘𞤢𞤲𞤢)',
        'ff_Latn_GM' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤘𞤢𞤥𞤦𞤭𞤴𞤢)',
        'ff_Latn_GN' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤘𞤭𞤲𞤫)',
        'ff_Latn_GW' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤘𞤭𞤲𞤫-𞤄𞤭𞤧𞤢𞤱𞤮𞥅)',
        'ff_Latn_LR' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤂𞤢𞤦𞤭𞤪𞤭𞤴𞤢𞥄)',
        'ff_Latn_MR' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤃𞤮𞤪𞤼𞤢𞤲𞤭𞥅)',
        'ff_Latn_NE' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤐𞤭𞥅𞤶𞤫𞤪)',
        'ff_Latn_NG' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
        'ff_Latn_SL' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤅𞤢𞤪𞤢𞤤𞤮𞤲)',
        'ff_Latn_SN' => '𞤆𞤵𞤤𞤢𞤪 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
        'ff_MR' => '𞤆𞤵𞤤𞤢𞤪 (𞤃𞤮𞤪𞤼𞤢𞤲𞤭𞥅)',
        'ff_SN' => '𞤆𞤵𞤤𞤢𞤪 (𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
        'fi' => '𞤊𞤫𞤲𞤭𞤧𞤪𞤫',
        'fi_FI' => '𞤊𞤫𞤲𞤭𞤧𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
        'fo' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫',
        'fo_DK' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫 (𞤁𞤢𞤲𞤵𞤥𞤢𞤪𞤳)',
        'fo_FO' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤊𞤢𞤪𞤵𞥅𞤧)',
        'fr' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫',
        'fr_BE' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤄𞤫𞤤𞤶𞤭𞤳𞤢𞥄)',
        'fr_BF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤄𞤵𞤪𞤳𞤭𞤲𞤢 𞤊𞤢𞤧𞤮𞥅)',
        'fr_BI' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤄𞤵𞤪𞤵𞤲𞤣𞤭)',
        'fr_BJ' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤄𞤫𞤲𞤫𞤲)',
        'fr_BL' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤼. 𞤄𞤢𞤪𞤼𞤫𞤤𞤭𞤥𞤭)',
        'fr_CA' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤢𞤲𞤢𞤣𞤢𞥄)',
        'fr_CD' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
        'fr_CF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤐𞤣𞤫𞤲𞤣𞤭 𞤚𞤵𞤥𞤦𞤮𞥅𞤪𞤭 𞤀𞤬𞤪𞤭𞤳𞤢𞥄)',
        'fr_CG' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤄𞤪𞤢𞥁𞤢𞤾𞤭𞤤)',
        'fr_CH' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
        'fr_CI' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤮𞤼𞤣𞤭𞤾𞤢𞥄𞤪)',
        'fr_CM' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤢𞤥𞤢𞤪𞤵𞥅𞤲)',
        'fr_DJ' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤔𞤭𞤦𞤵𞥅𞤼𞤭)',
        'fr_DZ' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤀𞤤𞤶𞤢𞤪𞤭𞥅)',
        'fr_FR' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤊𞤢𞤪𞤢𞤲𞤧𞤭)',
        'fr_GA' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤘𞤢𞤦𞤮𞤲)',
        'fr_GF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤘𞤵𞤴𞤢𞥄𞤲 𞤊𞤪𞤢𞤲𞤧𞤭𞤲𞤳𞤮)',
        'fr_GN' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫)',
        'fr_GP' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤘𞤵𞤱𞤢𞤣𞤢𞤤𞤵𞤨𞤫𞥅)',
        'fr_GQ' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫 𞤕𞤢𞤳𞤢𞤲𞤼𞤫𞥅𞤪𞤭)',
        'fr_HT' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤖𞤢𞤴𞤼𞤭𞥅)',
        'fr_KM' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤮𞤥𞤮𞥅𞤪𞤮)',
        'fr_LU' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
        'fr_MA' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞤪𞤮𞥅𞤳)',
        'fr_MC' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤮𞤲𞤢𞤳𞤮𞥅)',
        'fr_MF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤼. 𞤃𞤢𞤪𞤼𞤫𞤲)',
        'fr_MG' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞤣𞤢𞤺𞤢𞤧𞤳𞤢𞥄𞤪)',
        'fr_ML' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞥄𞤤𞤭)',
        'fr_MQ' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞤪𞤼𞤭𞤲𞤭𞤳𞤢𞥄)',
        'fr_MR' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤮𞤪𞤼𞤢𞤲𞤭𞥅)',
        'fr_MU' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤮𞤪𞤭𞥅𞤧𞤭)',
        'fr_NC' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤑𞤢𞤤𞤭𞤣𞤮𞤲𞤭𞤴𞤢𞥄 𞤖𞤫𞤧𞤮)',
        'fr_NE' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤐𞤭𞥅𞤶𞤫𞤪)',
        'fr_PF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤆𞤮𞤤𞤭𞤲𞤫𞥅𞤧𞤭𞤴𞤢 𞤊𞤪𞤢𞤲𞤧𞤭𞤲𞤳𞤮)',
        'fr_PM' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤼. 𞤆𞤭𞤴𞤫𞥅𞤪 & 𞤃𞤭𞤳𞤫𞤤𞤮𞤲)',
        'fr_RE' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤈𞤫𞥅𞤲𞤭𞤴𞤮𞤲)',
        'fr_RW' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤈𞤵𞤱𞤢𞤲𞤣𞤢𞥄)',
        'fr_SC' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤫𞤴𞤭𞤧𞤫𞤤)',
        'fr_SN' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
        'fr_SY' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤅𞤵𞥅𞤪𞤭𞤴𞤢𞥄)',
        'fr_TD' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤕𞤢𞥄𞤣)',
        'fr_TG' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤚𞤮𞤺𞤮)',
        'fr_TN' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤚𞤵𞤲𞤭𞥅𞤧𞤢)',
        'fr_VU' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤜𞤢𞤲𞤵𞤱𞤢𞥄𞤼𞤵)',
        'fr_WF' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤏𞤢𞤤𞥆𞤭𞥅𞤧 & 𞤊𞤵𞤼𞤵𞤲𞤢)',
        'fr_YT' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞤴𞤮𞥅𞤼𞤵)',
        'fy' => '𞤊𞤭𞤪𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤖𞤭𞤪𞤲𞤢',
        'fy_NL' => '𞤊𞤭𞤪𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤖𞤭𞤪𞤲𞤢 (𞤖𞤮𞤤𞤢𞤲𞤣𞤭𞤴𞤢𞥄)',
        'ga' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'ga_GB' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
        'ga_IE' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤋𞤪𞤤𞤢𞤲𞤣)',
        'gd' => '𞤅𞤭𞤳𞤮𞤼𞤭𞤧𞤪𞤫 𞤘𞤢𞤫𞤭𞤳',
        'gd_GB' => '𞤅𞤭𞤳𞤮𞤼𞤭𞤧𞤪𞤫 𞤘𞤢𞤫𞤭𞤳 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
        'gl' => '𞤘𞤢𞤤𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'gl_ES' => '𞤘𞤢𞤤𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤉𞤧𞤨𞤢𞤻𞤢𞥄)',
        'gu' => '𞤘𞤵𞤶𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫',
        'gu_IN' => '𞤘𞤵𞤶𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'gv' => '𞤃𞤢𞤲𞤳𞤭𞤧𞤪𞤫',
        'gv_IM' => '𞤃𞤢𞤲𞤳𞤭𞤧𞤪𞤫 (𞤅𞤵𞤪𞤭𞥅𞤪𞤫 𞤃𞤫𞥅𞤲)',
        'ha' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫',
        'ha_GH' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫 (𞤘𞤢𞤲𞤢)',
        'ha_NE' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫 (𞤐𞤭𞥅𞤶𞤫𞤪)',
        'ha_NG' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
        'he' => '𞤖𞤭𞤦𞤵𞤪𞤵𞥅𞤪𞤫',
        'he_IL' => '𞤖𞤭𞤦𞤵𞤪𞤵𞥅𞤪𞤫 (𞤋𞤧𞤪𞤢𞥄𞤴𞤭𞥅𞤤)',
        'hi' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫',
        'hi_IN' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'hi_Latn' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
        'hi_Latn_IN' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
        'hr' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫',
        'hr_BA' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫 (𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'hr_HR' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫 (𞤑𞤵𞤪𞤱𞤢𞥄𞤧𞤭𞤴𞤢)',
        'hu' => '𞤖𞤵𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞤲𞤪𞤫',
        'hu_HU' => '𞤖𞤵𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞤲𞤪𞤫 (𞤖𞤢𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞥄)',
        'hy' => '𞤀𞤪𞤥𞤫𞤲𞤭𞥅𞤪𞤫',
        'hy_AM' => '𞤀𞤪𞤥𞤫𞤲𞤭𞥅𞤪𞤫 (𞤀𞤪𞤥𞤫𞤲𞤭𞤴𞤢𞥄)',
        'ia' => '𞤉𞤲𞤼𞤫𞤪𞤤𞤭𞤺𞤢𞥄𞤪𞤫',
        'ia_001' => '𞤉𞤲𞤼𞤫𞤪𞤤𞤭𞤺𞤢𞥄𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
        'id' => '𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'id_ID' => '𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
        'ig' => '𞤋𞤦𞤮𞥅𞤪𞤫',
        'ig_NG' => '𞤋𞤦𞤮𞥅𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
        'ii' => '𞤅𞤭𞤧𞤵𞤢𞤲𞤪𞤫 𞤒𞤭𞥅',
        'ii_CN' => '𞤅𞤭𞤧𞤵𞤢𞤲𞤪𞤫 𞤒𞤭𞥅 (𞤕𞤢𞤴𞤲𞤢)',
        'is' => '𞤀𞤴𞤧𞤭𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'is_IS' => '𞤀𞤴𞤧𞤭𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤀𞤴𞤧𞤵𞤤𞤢𞤲𞤣)',
        'it' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'it_CH' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
        'it_IT' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤼𞤢𞤤𞤭𞥅)',
        'it_SM' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤢𞤲 𞤃𞤢𞤪𞤭𞤲𞤮𞥅)',
        'it_VA' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤜𞤢𞤼𞤭𞤳𞤢𞥄𞤲)',
        'ja' => '𞤐𞤭𞤨𞤮𞤲𞤪𞤫',
        'ja_JP' => '𞤐𞤭𞤨𞤮𞤲𞤪𞤫 (𞤐𞤭𞤨𞥆𞤮𞤲)',
        'jv' => '𞤔𞤢𞥄𞤱𞤢𞤫𞥅𞤪𞤫',
        'jv_ID' => '𞤔𞤢𞥄𞤱𞤢𞤫𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
        'ka' => '𞤔𞤮𞥅𞤪𞥁𞤭𞤴𞤢𞤲𞤪𞤫',
        'ka_GE' => '𞤔𞤮𞥅𞤪𞥁𞤭𞤴𞤢𞤲𞤪𞤫 (𞤔𞤮𞤪𞤶𞤭𞤴𞤢𞥄)',
        'ki' => '𞤑𞤭𞤳𞤵𞤴𞤵𞥅𞤪𞤫',
        'ki_KE' => '𞤑𞤭𞤳𞤵𞤴𞤵𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
        'kk' => '𞤑𞤢𞥁𞤢𞤳𞤪𞤫',
        'kk_KZ' => '𞤑𞤢𞥁𞤢𞤳𞤪𞤫 (𞤑𞤢𞥁𞤢𞤧𞤼𞤢𞥄𞤲)',
        'kl' => '𞤑𞤢𞤤𞤢𞥄𞤤𞤧𞤵𞤼𞤪𞤫',
        'kl_GL' => '𞤑𞤢𞤤𞤢𞥄𞤤𞤧𞤵𞤼𞤪𞤫 (𞤘𞤭𞤪𞤤𞤢𞤲𞤣𞤭)',
        'km' => '𞤑𞤵𞤥𞤢𞤴𞤪𞤫',
        'km_KH' => '𞤑𞤵𞤥𞤢𞤴𞤪𞤫 (𞤑𞤢𞤥𞤦𞤮𞥅𞤣𞤭𞤴𞤢)',
        'kn' => '𞤑𞤢𞤲𞥆𞤢𞤣𞤢𞥄𞤪𞤫',
        'kn_IN' => '𞤑𞤢𞤲𞥆𞤢𞤣𞤢𞥄𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ko' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫',
        'ko_KP' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫 (𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞥄 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫)',
        'ko_KR' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫 (𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞥄 𞤙𞤢𞤥𞤲𞤢𞥄𞤲𞤺𞤫)',
        'ks' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫',
        'ks_Arab' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
        'ks_Arab_IN' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ks_Deva' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭)',
        'ks_Deva_IN' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ks_IN' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ku' => '𞤑𞤵𞤪𞤣𞤭𞤧𞤭𞥅𞤪𞤫',
        'ku_TR' => '𞤑𞤵𞤪𞤣𞤭𞤧𞤭𞥅𞤪𞤫 (𞤚𞤵𞤪𞤳𞤭𞤴𞤢𞥄)',
        'kw' => '𞤑𞤮𞤪𞤲𞤭𞥅𞤪𞤫',
        'kw_GB' => '𞤑𞤮𞤪𞤲𞤭𞥅𞤪𞤫 (𞤁𞤫𞤲𞤼𞤢𞤤 𞤐𞤺𞤫𞤯𞤵𞥅𞤪𞤭)',
        'ky' => '𞤑𞤭𞤪𞤺𞤵𞥅𞤪𞤫',
        'ky_KG' => '𞤑𞤭𞤪𞤺𞤵𞥅𞤪𞤫 (𞤑𞤭𞤪𞤶𞤭𞤧𞤼𞤢𞥄𞤲)',
        'lb' => '𞤂𞤵𞥁𞤫𞤲𞤦𞤵𞥅𞤪𞤺𞤭𞤧𞤪𞤫',
        'lb_LU' => '𞤂𞤵𞥁𞤫𞤲𞤦𞤵𞥅𞤪𞤺𞤭𞤧𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
        'lg' => '𞤘𞤢𞤲𞤣𞤢𞥄𞤪𞤫',
        'lg_UG' => '𞤘𞤢𞤲𞤣𞤢𞥄𞤪𞤫 (𞤓𞤺𞤢𞤲𞤣𞤢𞥄)',
        'ln' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫',
        'ln_AO' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤀𞤲𞤺𞤮𞤤𞤢𞥄)',
        'ln_CD' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
        'ln_CF' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤐𞤣𞤫𞤲𞤣𞤭 𞤚𞤵𞤥𞤦𞤮𞥅𞤪𞤭 𞤀𞤬𞤪𞤭𞤳𞤢𞥄)',
        'ln_CG' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤄𞤪𞤢𞥁𞤢𞤾𞤭𞤤)',
        'lo' => '𞤂𞤢𞤮𞥅𞤪𞤫',
        'lo_LA' => '𞤂𞤢𞤮𞥅𞤪𞤫 (𞤂𞤢𞤱𞤮𞥅𞤧)',
        'lt' => '𞤂𞤭𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'lt_LT' => '𞤂𞤭𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤭𞤼𞤵𞤾𞤢)',
        'lu' => '𞤂𞤵𞤦𞤢-𞤑𞤢𞤼𞤢𞤲𞤺𞤢𞥄𞤪𞤫',
        'lu_CD' => '𞤂𞤵𞤦𞤢-𞤑𞤢𞤼𞤢𞤲𞤺𞤢𞥄𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
        'lv' => '𞤂𞤢𞤼𞤾𞤭𞤴𞤢𞤲𞤪𞤫',
        'lv_LV' => '𞤂𞤢𞤼𞤾𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤾𞤭𞤴𞤢)',
        'mg' => '𞤃𞤢𞤤𞤢𞤺𞤢𞤧𞤭𞥅𞤪𞤫',
        'mg_MG' => '𞤃𞤢𞤤𞤢𞤺𞤢𞤧𞤭𞥅𞤪𞤫 (𞤃𞤢𞤣𞤢𞤺𞤢𞤧𞤳𞤢𞥄𞤪)',
        'mi' => '𞤃𞤢𞥄𞤮𞤪𞤭𞥅𞤪𞤫',
        'mi_NZ' => '𞤃𞤢𞥄𞤮𞤪𞤭𞥅𞤪𞤫 (𞤐𞤫𞤱 𞤟𞤫𞤤𞤢𞤲𞤣)',
        'mk' => '𞤃𞤢𞤧𞤫𞤣𞤮𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'mk_MK' => '𞤃𞤢𞤧𞤫𞤣𞤮𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤢𞤳𞤫𞤣𞤮𞤲𞤭𞤴𞤢𞥄 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫)',
        'ml' => '𞤃𞤢𞤤𞤢𞤴𞤢𞤤𞤢𞤥𞤪𞤫',
        'ml_IN' => '𞤃𞤢𞤤𞤢𞤴𞤢𞤤𞤢𞤥𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'mn' => '𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'mn_MN' => '𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤴𞤢)',
        'mr' => '𞤃𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫',
        'mr_IN' => '𞤃𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ms' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫',
        'ms_BN' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫 (𞤄𞤵𞤪𞤲𞤢𞥄𞤴)',
        'ms_ID' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
        'ms_MY' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫 (𞤃𞤢𞤤𞤫𞥅𞤧𞤭𞤴𞤢)',
        'ms_SG' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫 (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
        'mt' => '𞤃𞤢𞤤𞤼𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'mt_MT' => '𞤃𞤢𞤤𞤼𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤃𞤢𞤤𞤼𞤢)',
        'my' => '𞤄𞤵𞤪𞤥𞤢𞥄𞤪𞤫',
        'my_MM' => '𞤄𞤵𞤪𞤥𞤢𞥄𞤪𞤫 (𞤃𞤭𞤴𞤢𞤥𞤢𞥄𞤪 [𞤄𞤵𞥅𞤪𞤥𞤢])',
        'nb' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤',
        'nb_NO' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
        'nb_SJ' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤 (𞤅𞤢𞤾𞤢𞤤𞤦𞤢𞤪𞤣 & 𞤔𞤢𞤲 𞤃𞤢𞤴𞤫𞤲)',
        'nd' => '𞤐𞤣𞤫𞤦𞤫𞤤𞤫𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤺𞤫',
        'nd_ZW' => '𞤐𞤣𞤫𞤦𞤫𞤤𞤫𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤺𞤫 (𞤟𞤭𞤥𞤦𞤢𞥄𞤥𞤵𞤴𞤢)',
        'ne' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'ne_IN' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ne_NP' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤐𞤭𞤨𞤢𞥄𞤤)',
        'nl' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫',
        'nl_AW' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤀𞤪𞤵𞤦𞤢𞥄)',
        'nl_BE' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤄𞤫𞤤𞤶𞤭𞤳𞤢𞥄)',
        'nl_BQ' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤑𞤢𞤪𞤦𞤭𞤴𞤢𞥄 𞤖𞤮𞤤𞤢𞤲𞤣𞤭𞤴𞤢𞥄)',
        'nl_CW' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤑𞤵𞥅𞤪𞤢𞤧𞤢𞤱𞤮)',
        'nl_NL' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤖𞤮𞤤𞤢𞤲𞤣𞤭𞤴𞤢𞥄)',
        'nl_SR' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤅𞤵𞤪𞤭𞤲𞤢𞥄𞤥)',
        'nl_SX' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫 (𞤅𞤫𞤲𞤼𞤵 𞤃𞤢𞥄𞤪𞤼𞤫𞤲)',
        'nn' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤙𞤮𞤪𞤧𞤳',
        'nn_NO' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤙𞤮𞤪𞤧𞤳 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
        'no' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫',
        'no_NO' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
        'om' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫',
        'om_ET' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
        'om_KE' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
        'or' => '𞤌𞤣𞤭𞤢𞥄𞤪𞤫',
        'or_IN' => '𞤌𞤣𞤭𞤢𞥄𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'os' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫',
        'os_GE' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫 (𞤔𞤮𞤪𞤶𞤭𞤴𞤢𞥄)',
        'os_RU' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
        'pa' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫',
        'pa_Arab' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
        'pa_Arab_PK' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'pa_Guru' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤘𞤵𞤪𞤥𞤵𞤿𞤭)',
        'pa_Guru_IN' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤘𞤵𞤪𞤥𞤵𞤿𞤭⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
        'pa_IN' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'pa_PK' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'pl' => '𞤆𞤮𞤤𞤢𞤲𞤣𞤭𞥅𞤪𞤫',
        'pl_PL' => '𞤆𞤮𞤤𞤢𞤲𞤣𞤭𞥅𞤪𞤫 (𞤆𞤮𞤤𞤢𞤲𞤣)',
        'ps' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫',
        'ps_AF' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫 (𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
        'ps_PK' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'pt' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫',
        'pt_AO' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤀𞤲𞤺𞤮𞤤𞤢𞥄)',
        'pt_BR' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤄𞤪𞤢𞤧𞤭𞤤)',
        'pt_CH' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
        'pt_CV' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤑𞤢𞥄𞤦𞤮 𞤜𞤫𞤪𞤣𞤫)',
        'pt_GQ' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫 𞤕𞤢𞤳𞤢𞤲𞤼𞤫𞥅𞤪𞤭)',
        'pt_GW' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤘𞤭𞤲𞤫-𞤄𞤭𞤧𞤢𞤱𞤮𞥅)',
        'pt_LU' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤂𞤵𞤳𞤧𞤢𞤲𞤦𞤵𞥅𞤺)',
        'pt_MO' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
        'pt_MZ' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤃𞤮𞤧𞤢𞤥𞤦𞤭𞥅𞤳)',
        'pt_PT' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤆𞤮𞥅𞤪𞤼𞤵𞤺𞤢𞥄𞤤)',
        'pt_ST' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤅𞤢𞤱𞤵 𞤚𞤵𞤥𞤫𞥅 & 𞤆𞤫𞤪𞤫𞤲𞤧𞤭𞤨𞤫)',
        'pt_TL' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 (𞤚𞤭𞤥𞤮𞥅𞤪 𞤂𞤫𞤧𞤼𞤫)',
        'qu' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫',
        'qu_BO' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫 (𞤄𞤮𞤤𞤭𞥅𞤾𞤭𞤴𞤢𞥄)',
        'qu_EC' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫 (𞤉𞤳𞤵𞤱𞤢𞤣𞤮𞥅𞤪)',
        'qu_PE' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫 (𞤆𞤫𞤪𞤵𞥅)',
        'rm' => '𞤈𞤮𞤥𞤢𞤲𞤧𞤪𞤫',
        'rm_CH' => '𞤈𞤮𞤥𞤢𞤲𞤧𞤪𞤫 (𞤅𞤵𞤱𞤭𞤪𞤧𞤢𞥄)',
        'rn' => '𞤈𞤵𞤲𞤣𞤭𞥅𞤪𞤫',
        'rn_BI' => '𞤈𞤵𞤲𞤣𞤭𞥅𞤪𞤫 (𞤄𞤵𞤪𞤵𞤲𞤣𞤭)',
        'ro' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'ro_MD' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤃𞤮𞤤𞤣𞤮𞤾𞤢𞥄)',
        'ro_RO' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤈𞤵𞤥𞤢𞥄𞤲𞤭𞤴𞤢)',
        'ru' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'ru_BY' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤄𞤫𞤤𞤢𞤪𞤵𞥅𞤧)',
        'ru_KG' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤑𞤭𞤪𞤶𞤭𞤧𞤼𞤢𞥄𞤲)',
        'ru_KZ' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤑𞤢𞥁𞤢𞤧𞤼𞤢𞥄𞤲)',
        'ru_MD' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤃𞤮𞤤𞤣𞤮𞤾𞤢𞥄)',
        'ru_RU' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
        'ru_UA' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫 (𞤓𞤳𞤪𞤫𞥅𞤲𞤭𞤴𞤢)',
        'rw' => '𞤑𞤭𞤻𞤭𞤪𞤵𞤱𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'rw_RW' => '𞤑𞤭𞤻𞤭𞤪𞤵𞤱𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤈𞤵𞤱𞤢𞤲𞤣𞤢𞥄)',
        'sa' => '𞤅𞤢𞤲𞤧𞤳𞤪𞤭𞤼𞤪𞤫',
        'sa_IN' => '𞤅𞤢𞤲𞤧𞤳𞤪𞤭𞤼𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'sc' => '𞤅𞤢𞤪𞤣𞤭𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'sc_IT' => '𞤅𞤢𞤪𞤣𞤭𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤋𞤼𞤢𞤤𞤭𞥅)',
        'sd' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫',
        'sd_Arab' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
        'sd_Arab_PK' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'sd_Deva' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭)',
        'sd_Deva_IN' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤁𞤫𞤾𞤢𞤲𞤢𞤺𞤢𞤪𞤭⹁ 𞤋𞤲𞤣𞤭𞤴𞤢)',
        'sd_IN' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'sd_PK' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'se' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'se_FI' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
        'se_NO' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫 (𞤐𞤮𞤪𞤺𞤫𞤴𞤢𞥄)',
        'se_SE' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫 (𞤅𞤵𞤱𞤫𞤣𞤭𞤴𞤢𞥄)',
        'sg' => '𞤅𞤢𞤲𞤺𞤮𞥅𞤪𞤫',
        'sg_CF' => '𞤅𞤢𞤲𞤺𞤮𞥅𞤪𞤫 (𞤐𞤣𞤫𞤲𞤣𞤭 𞤚𞤵𞤥𞤦𞤮𞥅𞤪𞤭 𞤀𞤬𞤪𞤭𞤳𞤢𞥄)',
        'si' => '𞤅𞤭𞤲𞤸𞤢𞤤𞤢𞥄𞤪𞤫',
        'si_LK' => '𞤅𞤭𞤲𞤸𞤢𞤤𞤢𞥄𞤪𞤫 (𞤅𞤭𞤪 𞤂𞤢𞤲𞤳𞤢𞥄)',
        'sk' => '𞤅𞤤𞤮𞤾𞤢𞥄𞤳𞤪𞤫',
        'sk_SK' => '𞤅𞤤𞤮𞤾𞤢𞥄𞤳𞤪𞤫 (𞤅𞤵𞤤𞤮𞤾𞤢𞥄𞤳𞤭𞤴𞤢)',
        'sl' => '𞤅𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'sl_SI' => '𞤅𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤵𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞥄)',
        'sn' => '𞤅𞤮𞤲𞤢𞥄𞤪𞤫',
        'sn_ZW' => '𞤅𞤮𞤲𞤢𞥄𞤪𞤫 (𞤟𞤭𞤥𞤦𞤢𞥄𞤥𞤵𞤴𞤢)',
        'so' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫',
        'so_DJ' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤔𞤭𞤦𞤵𞥅𞤼𞤭)',
        'so_ET' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
        'so_KE' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
        'so_SO' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫 (𞤅𞤵𞥅𞤥𞤢𞥄𞤤𞤭)',
        'sq' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫',
        'sq_AL' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫 (𞤀𞤤𞤦𞤢𞤲𞤭𞤴𞤢𞥄)',
        'sq_MK' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫 (𞤃𞤢𞤳𞤫𞤣𞤮𞤲𞤭𞤴𞤢𞥄 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫)',
        'sr' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫',
        'sr_BA' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'sr_Cyrl' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳)',
        'sr_Cyrl_BA' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'sr_Cyrl_ME' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤃𞤮𞤲𞤼𞤫𞤲𞤫𞥅𞤺𞤮𞤪𞤮)',
        'sr_Cyrl_RS' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞥄)',
        'sr_Latn' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
        'sr_Latn_BA' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤄𞤮𞤧𞤲𞤭𞤴𞤢 & 𞤖𞤫𞤪𞤧𞤫𞤳𞤮𞤾𞤭𞤲𞤢𞥄)',
        'sr_Latn_ME' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤃𞤮𞤲𞤼𞤫𞤲𞤫𞥅𞤺𞤮𞤪𞤮)',
        'sr_Latn_RS' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞥄)',
        'sr_ME' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤃𞤮𞤲𞤼𞤫𞤲𞤫𞥅𞤺𞤮𞤪𞤮)',
        'sr_RS' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 (𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞥄)',
        'su' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫',
        'su_ID' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫 (𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
        'su_Latn' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
        'su_Latn_ID' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤴𞤢)',
        'sv' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'sv_AX' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤕𞤵𞤪𞤭𞥅𞤶𞤫 𞤀𞤤𞤢𞤲𞤣)',
        'sv_FI' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤊𞤭𞤲𞤤𞤢𞤲𞤣)',
        'sv_SE' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤵𞤱𞤫𞤣𞤭𞤴𞤢𞥄)',
        'sw' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫',
        'sw_CD' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤑𞤮𞤲𞤺𞤮 - 𞤑𞤭𞤲𞤧𞤢𞤧𞤢)',
        'sw_KE' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤑𞤫𞤲𞤭𞤴𞤢𞥄)',
        'sw_TZ' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤚𞤢𞤲𞤧𞤢𞤲𞤭𞥅)',
        'sw_UG' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 (𞤓𞤺𞤢𞤲𞤣𞤢𞥄)',
        'ta' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫',
        'ta_IN' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ta_LK' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤅𞤭𞤪 𞤂𞤢𞤲𞤳𞤢𞥄)',
        'ta_MY' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤃𞤢𞤤𞤫𞥅𞤧𞤭𞤴𞤢)',
        'ta_SG' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫 (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
        'te' => '𞤚𞤫𞤤𞤫𞤺𞤵𞥅𞤪𞤫',
        'te_IN' => '𞤚𞤫𞤤𞤫𞤺𞤵𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'tg' => '𞤚𞤢𞤶𞤭𞤳𞤪𞤫',
        'tg_TJ' => '𞤚𞤢𞤶𞤭𞤳𞤪𞤫 (𞤚𞤢𞤶𞤭𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'th' => '𞤚𞤢𞤴𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'th_TH' => '𞤚𞤢𞤴𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫 (𞤚𞤢𞥄𞤴𞤤𞤢𞤲𞤣)',
        'ti' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫',
        'ti_ER' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫 (𞤉𞤪𞤭𞥅𞤼𞤫𞤪𞤫)',
        'ti_ET' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫 (𞤀𞤦𞤢𞤧𞤭𞤲𞤭𞥅)',
        'tk' => '𞤼𞤵𞤪𞤳𞤥𞤢𞤲𞤪𞤫',
        'tk_TM' => '𞤼𞤵𞤪𞤳𞤥𞤢𞤲𞤪𞤫 (𞤚𞤵𞤪𞤳𞤵𞤥𞤫𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
        'to' => '𞤚𞤮𞤲𞤺𞤢𞤲𞤪𞤫',
        'to_TO' => '𞤚𞤮𞤲𞤺𞤢𞤲𞤪𞤫 (𞤚𞤮𞤲𞤺𞤢)',
        'tr' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'tr_CY' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤑𞤵𞤦𞤪𞤵𞥅𞤧)',
        'tr_TR' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤵𞤪𞤳𞤭𞤴𞤢𞥄)',
        'tt' => '𞤚𞤢𞤼𞤢𞤪𞥇𞤪𞤫',
        'tt_RU' => '𞤚𞤢𞤼𞤢𞤪𞥇𞤪𞤫 (𞤈𞤮𞥅𞤧𞤭𞤴𞤢)',
        'ug' => '𞤓𞥅𞤴𞤺𞤵𞥅𞤪𞤫',
        'ug_CN' => '𞤓𞥅𞤴𞤺𞤵𞥅𞤪𞤫 (𞤕𞤢𞤴𞤲𞤢)',
        'uk' => '𞤒𞤵𞤳𞤪𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'uk_UA' => '𞤒𞤵𞤳𞤪𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫 (𞤓𞤳𞤪𞤫𞥅𞤲𞤭𞤴𞤢)',
        'ur' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫',
        'ur_IN' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫 (𞤋𞤲𞤣𞤭𞤴𞤢)',
        'ur_PK' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫 (𞤆𞤢𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'uz' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫',
        'uz_AF' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
        'uz_Arab' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵)',
        'uz_Arab_AF' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤀𞥄𞤪𞤢𞤦𞤵⹁ 𞤀𞤬𞤺𞤢𞤲𞤭𞤧𞤼𞤢𞥄𞤲)',
        'uz_Cyrl' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳)',
        'uz_Cyrl_UZ' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤅𞤭𞤪𞤤𞤭𞤳⹁ 𞤓𞥁𞤦𞤫𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'uz_Latn' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲)',
        'uz_Latn_UZ' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤂𞤢𞤼𞤫𞤲⹁ 𞤓𞥁𞤦𞤫𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'uz_UZ' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫 (𞤓𞥁𞤦𞤫𞤳𞤭𞤧𞤼𞤢𞥄𞤲)',
        'vi' => '𞤏𞤭𞤴𞤫𞤼𞤲𞤢𞤥𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'vi_VN' => '𞤏𞤭𞤴𞤫𞤼𞤲𞤢𞤥𞤭𞤲𞤳𞤮𞥅𞤪𞤫 (𞤜𞤭𞤴𞤫𞤼𞤲𞤢𞥄𞤥)',
        'wo' => '𞤏𞤮𞤤𞤮𞤬𞤪𞤫',
        'wo_SN' => '𞤏𞤮𞤤𞤮𞤬𞤪𞤫 (𞤅𞤫𞤲𞤫𞤺𞤢𞥄𞤤)',
        'xh' => '𞤑𞤮𞥅𞤧𞤢𞥄𞤪𞤫',
        'xh_ZA' => '𞤑𞤮𞥅𞤧𞤢𞥄𞤪𞤫 (𞤀𞤬𞤪𞤭𞤳𞤢 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
        'yi' => '𞤒𞤭𞤣𞤭𞤧𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'yi_001' => '𞤒𞤭𞤣𞤭𞤧𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤀𞤣𞤵𞤲𞤢)',
        'yo' => '𞤒𞤮𞥅𞤪𞤵𞤦𞤢𞥄𞤪𞤫',
        'yo_BJ' => '𞤒𞤮𞥅𞤪𞤵𞤦𞤢𞥄𞤪𞤫 (𞤄𞤫𞤲𞤫𞤲)',
        'yo_NG' => '𞤒𞤮𞥅𞤪𞤵𞤦𞤢𞥄𞤪𞤫 (𞤐𞤢𞤶𞤫𞤪𞤭𞤴𞤢𞥄)',
        'zh' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'zh_CN' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤕𞤢𞤴𞤲𞤢)',
        'zh_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
        'zh_Hans' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫)',
        'zh_Hans_CN' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤕𞤢𞤴𞤲𞤢)',
        'zh_Hans_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
        'zh_Hans_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
        'zh_Hans_SG' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤮𞤴𞤲𞤢𞥄𞤲𞤣𞤫⹁ 𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
        'zh_Hant' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫)',
        'zh_Hant_HK' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤖𞤮𞤲𞤺 𞤑𞤮𞤲𞤺)',
        'zh_Hant_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
        'zh_Hant_TW' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤱𞤢𞥄𞤲𞤣𞤫⹁ 𞤚𞤢𞤴𞤱𞤢𞥄𞤲)',
        'zh_MO' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤖𞤂𞤀 𞤕𞤢𞤴𞤲𞤢 𞤫 𞤃𞤢𞤳𞤢𞤱𞤮𞥅)',
        'zh_SG' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤅𞤭𞤲𞤺𞤢𞤨𞤵𞥅𞤪)',
        'zh_TW' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 (𞤚𞤢𞤴𞤱𞤢𞥄𞤲)',
        'zu' => '𞥁𞤵𞤤𞤵𞥅𞤪𞤫',
        'zu_ZA' => '𞥁𞤵𞤤𞤵𞥅𞤪𞤫 (𞤀𞤬𞤪𞤭𞤳𞤢 𞤂𞤫𞤧𞤤𞤫𞤴𞤪𞤭)',
    ],
];
