<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namíbia)',
        'af_ZA' => 'afrikaans (Dél-afrikai Köztársaság)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghána)',
        'am' => 'amhara',
        'am_ET' => 'amhara (Etiópia)',
        'ar' => 'arab',
        'ar_001' => 'arab (Világ)',
        'ar_AE' => 'arab (Egyesült Arab Emírségek)',
        'ar_BH' => 'arab (Bahrein)',
        'ar_DJ' => 'arab (Dzsibuti)',
        'ar_DZ' => 'arab (Algéria)',
        'ar_EG' => 'arab (Egyiptom)',
        'ar_EH' => 'arab (Nyugat-Szahara)',
        'ar_ER' => 'arab (Eritrea)',
        'ar_IL' => 'arab (Izrael)',
        'ar_IQ' => 'arab (Irak)',
        'ar_JO' => 'arab (Jordánia)',
        'ar_KM' => 'arab (Comore-szigetek)',
        'ar_KW' => 'arab (Kuvait)',
        'ar_LB' => 'arab (Libanon)',
        'ar_LY' => 'arab (Líbia)',
        'ar_MA' => 'arab (Marokkó)',
        'ar_MR' => 'arab (Mauritánia)',
        'ar_OM' => 'arab (Omán)',
        'ar_PS' => 'arab (Palesztin Autonómia)',
        'ar_QA' => 'arab (Katar)',
        'ar_SA' => 'arab (Szaúd-Arábia)',
        'ar_SD' => 'arab (Szudán)',
        'ar_SO' => 'arab (Szomália)',
        'ar_SS' => 'arab (Dél-Szudán)',
        'ar_SY' => 'arab (Szíria)',
        'ar_TD' => 'arab (Csád)',
        'ar_TN' => 'arab (Tunézia)',
        'ar_YE' => 'arab (Jemen)',
        'as' => 'asszámi',
        'as_IN' => 'asszámi (India)',
        'az' => 'azerbajdzsáni',
        'az_AZ' => 'azerbajdzsáni (Azerbajdzsán)',
        'az_Cyrl' => 'azerbajdzsáni (Cirill)',
        'az_Cyrl_AZ' => 'azerbajdzsáni (Cirill, Azerbajdzsán)',
        'az_Latn' => 'azerbajdzsáni (Latin)',
        'az_Latn_AZ' => 'azerbajdzsáni (Latin, Azerbajdzsán)',
        'be' => 'belarusz',
        'be_BY' => 'belarusz (Belarusz)',
        'bg' => 'bolgár',
        'bg_BG' => 'bolgár (Bulgária)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bangla',
        'bn_BD' => 'bangla (Banglades)',
        'bn_IN' => 'bangla (India)',
        'bo' => 'tibeti',
        'bo_CN' => 'tibeti (Kína)',
        'bo_IN' => 'tibeti (India)',
        'br' => 'breton',
        'br_FR' => 'breton (Franciaország)',
        'bs' => 'bosnyák',
        'bs_BA' => 'bosnyák (Bosznia-Hercegovina)',
        'bs_Cyrl' => 'bosnyák (Cirill)',
        'bs_Cyrl_BA' => 'bosnyák (Cirill, Bosznia-Hercegovina)',
        'bs_Latn' => 'bosnyák (Latin)',
        'bs_Latn_BA' => 'bosnyák (Latin, Bosznia-Hercegovina)',
        'ca' => 'katalán',
        'ca_AD' => 'katalán (Andorra)',
        'ca_ES' => 'katalán (Spanyolország)',
        'ca_FR' => 'katalán (Franciaország)',
        'ca_IT' => 'katalán (Olaszország)',
        'ce' => 'csecsen',
        'ce_RU' => 'csecsen (Oroszország)',
        'cs' => 'cseh',
        'cs_CZ' => 'cseh (Csehország)',
        'cv' => 'csuvas',
        'cv_RU' => 'csuvas (Oroszország)',
        'cy' => 'walesi',
        'cy_GB' => 'walesi (Egyesült Királyság)',
        'da' => 'dán',
        'da_DK' => 'dán (Dánia)',
        'da_GL' => 'dán (Grönland)',
        'de' => 'német',
        'de_AT' => 'német (Ausztria)',
        'de_BE' => 'német (Belgium)',
        'de_CH' => 'német (Svájc)',
        'de_DE' => 'német (Németország)',
        'de_IT' => 'német (Olaszország)',
        'de_LI' => 'német (Liechtenstein)',
        'de_LU' => 'német (Luxemburg)',
        'dz' => 'dzsonga',
        'dz_BT' => 'dzsonga (Bhután)',
        'ee' => 'eve',
        'ee_GH' => 'eve (Ghána)',
        'ee_TG' => 'eve (Togo)',
        'el' => 'görög',
        'el_CY' => 'görög (Ciprus)',
        'el_GR' => 'görög (Görögország)',
        'en' => 'angol',
        'en_001' => 'angol (Világ)',
        'en_150' => 'angol (Európa)',
        'en_AE' => 'angol (Egyesült Arab Emírségek)',
        'en_AG' => 'angol (Antigua és Barbuda)',
        'en_AI' => 'angol (Anguilla)',
        'en_AS' => 'angol (Amerikai Szamoa)',
        'en_AT' => 'angol (Ausztria)',
        'en_AU' => 'angol (Ausztrália)',
        'en_BB' => 'angol (Barbados)',
        'en_BE' => 'angol (Belgium)',
        'en_BI' => 'angol (Burundi)',
        'en_BM' => 'angol (Bermuda)',
        'en_BS' => 'angol (Bahama-szigetek)',
        'en_BW' => 'angol (Botswana)',
        'en_BZ' => 'angol (Belize)',
        'en_CA' => 'angol (Kanada)',
        'en_CC' => 'angol (Kókusz [Keeling]-szigetek)',
        'en_CH' => 'angol (Svájc)',
        'en_CK' => 'angol (Cook-szigetek)',
        'en_CM' => 'angol (Kamerun)',
        'en_CX' => 'angol (Karácsony-sziget)',
        'en_CY' => 'angol (Ciprus)',
        'en_DE' => 'angol (Németország)',
        'en_DK' => 'angol (Dánia)',
        'en_DM' => 'angol (Dominika)',
        'en_ER' => 'angol (Eritrea)',
        'en_FI' => 'angol (Finnország)',
        'en_FJ' => 'angol (Fidzsi)',
        'en_FK' => 'angol (Falkland-szigetek)',
        'en_FM' => 'angol (Mikronézia)',
        'en_GB' => 'angol (Egyesült Királyság)',
        'en_GD' => 'angol (Grenada)',
        'en_GG' => 'angol (Guernsey)',
        'en_GH' => 'angol (Ghána)',
        'en_GI' => 'angol (Gibraltár)',
        'en_GM' => 'angol (Gambia)',
        'en_GU' => 'angol (Guam)',
        'en_GY' => 'angol (Guyana)',
        'en_HK' => 'angol (Hongkong KKT)',
        'en_IE' => 'angol (Írország)',
        'en_IL' => 'angol (Izrael)',
        'en_IM' => 'angol (Man-sziget)',
        'en_IN' => 'angol (India)',
        'en_IO' => 'angol (Brit Indiai-óceáni Terület)',
        'en_JE' => 'angol (Jersey)',
        'en_JM' => 'angol (Jamaica)',
        'en_KE' => 'angol (Kenya)',
        'en_KI' => 'angol (Kiribati)',
        'en_KN' => 'angol (Saint Kitts és Nevis)',
        'en_KY' => 'angol (Kajmán-szigetek)',
        'en_LC' => 'angol (Saint Lucia)',
        'en_LR' => 'angol (Libéria)',
        'en_LS' => 'angol (Lesotho)',
        'en_MG' => 'angol (Madagaszkár)',
        'en_MH' => 'angol (Marshall-szigetek)',
        'en_MO' => 'angol (Makaó KKT)',
        'en_MP' => 'angol (Északi Mariana-szigetek)',
        'en_MS' => 'angol (Montserrat)',
        'en_MT' => 'angol (Málta)',
        'en_MU' => 'angol (Mauritius)',
        'en_MV' => 'angol (Maldív-szigetek)',
        'en_MW' => 'angol (Malawi)',
        'en_MY' => 'angol (Malajzia)',
        'en_NA' => 'angol (Namíbia)',
        'en_NF' => 'angol (Norfolk-sziget)',
        'en_NG' => 'angol (Nigéria)',
        'en_NL' => 'angol (Hollandia)',
        'en_NR' => 'angol (Nauru)',
        'en_NU' => 'angol (Niue)',
        'en_NZ' => 'angol (Új-Zéland)',
        'en_PG' => 'angol (Pápua Új-Guinea)',
        'en_PH' => 'angol (Fülöp-szigetek)',
        'en_PK' => 'angol (Pakisztán)',
        'en_PN' => 'angol (Pitcairn-szigetek)',
        'en_PR' => 'angol (Puerto Rico)',
        'en_PW' => 'angol (Palau)',
        'en_RW' => 'angol (Ruanda)',
        'en_SB' => 'angol (Salamon-szigetek)',
        'en_SC' => 'angol (Seychelle-szigetek)',
        'en_SD' => 'angol (Szudán)',
        'en_SE' => 'angol (Svédország)',
        'en_SG' => 'angol (Szingapúr)',
        'en_SH' => 'angol (Szent Ilona)',
        'en_SI' => 'angol (Szlovénia)',
        'en_SL' => 'angol (Sierra Leone)',
        'en_SS' => 'angol (Dél-Szudán)',
        'en_SX' => 'angol (Sint Maarten)',
        'en_SZ' => 'angol (Szváziföld)',
        'en_TC' => 'angol (Turks- és Caicos-szigetek)',
        'en_TK' => 'angol (Tokelau)',
        'en_TO' => 'angol (Tonga)',
        'en_TT' => 'angol (Trinidad és Tobago)',
        'en_TV' => 'angol (Tuvalu)',
        'en_TZ' => 'angol (Tanzánia)',
        'en_UG' => 'angol (Uganda)',
        'en_UM' => 'angol (Az USA lakatlan külbirtokai)',
        'en_US' => 'angol (Egyesült Államok)',
        'en_VC' => 'angol (Saint Vincent és a Grenadine-szigetek)',
        'en_VG' => 'angol (Brit Virgin-szigetek)',
        'en_VI' => 'angol (Amerikai Virgin-szigetek)',
        'en_VU' => 'angol (Vanuatu)',
        'en_WS' => 'angol (Szamoa)',
        'en_ZA' => 'angol (Dél-afrikai Köztársaság)',
        'en_ZM' => 'angol (Zambia)',
        'en_ZW' => 'angol (Zimbabwe)',
        'eo' => 'eszperantó',
        'eo_001' => 'eszperantó (Világ)',
        'es' => 'spanyol',
        'es_419' => 'spanyol (Latin-Amerika)',
        'es_AR' => 'spanyol (Argentína)',
        'es_BO' => 'spanyol (Bolívia)',
        'es_BR' => 'spanyol (Brazília)',
        'es_BZ' => 'spanyol (Belize)',
        'es_CL' => 'spanyol (Chile)',
        'es_CO' => 'spanyol (Kolumbia)',
        'es_CR' => 'spanyol (Costa Rica)',
        'es_CU' => 'spanyol (Kuba)',
        'es_DO' => 'spanyol (Dominikai Köztársaság)',
        'es_EC' => 'spanyol (Ecuador)',
        'es_ES' => 'spanyol (Spanyolország)',
        'es_GQ' => 'spanyol (Egyenlítői-Guinea)',
        'es_GT' => 'spanyol (Guatemala)',
        'es_HN' => 'spanyol (Honduras)',
        'es_MX' => 'spanyol (Mexikó)',
        'es_NI' => 'spanyol (Nicaragua)',
        'es_PA' => 'spanyol (Panama)',
        'es_PE' => 'spanyol (Peru)',
        'es_PH' => 'spanyol (Fülöp-szigetek)',
        'es_PR' => 'spanyol (Puerto Rico)',
        'es_PY' => 'spanyol (Paraguay)',
        'es_SV' => 'spanyol (Salvador)',
        'es_US' => 'spanyol (Egyesült Államok)',
        'es_UY' => 'spanyol (Uruguay)',
        'es_VE' => 'spanyol (Venezuela)',
        'et' => 'észt',
        'et_EE' => 'észt (Észtország)',
        'eu' => 'baszk',
        'eu_ES' => 'baszk (Spanyolország)',
        'fa' => 'perzsa',
        'fa_AF' => 'perzsa (Afganisztán)',
        'fa_IR' => 'perzsa (Irán)',
        'ff' => 'fulani',
        'ff_Adlm' => 'fulani (Adlam)',
        'ff_Adlm_BF' => 'fulani (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulani (Adlam, Kamerun)',
        'ff_Adlm_GH' => 'fulani (Adlam, Ghána)',
        'ff_Adlm_GM' => 'fulani (Adlam, Gambia)',
        'ff_Adlm_GN' => 'fulani (Adlam, Guinea)',
        'ff_Adlm_GW' => 'fulani (Adlam, Bissau-Guinea)',
        'ff_Adlm_LR' => 'fulani (Adlam, Libéria)',
        'ff_Adlm_MR' => 'fulani (Adlam, Mauritánia)',
        'ff_Adlm_NE' => 'fulani (Adlam, Niger)',
        'ff_Adlm_NG' => 'fulani (Adlam, Nigéria)',
        'ff_Adlm_SL' => 'fulani (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulani (Adlam, Szenegál)',
        'ff_CM' => 'fulani (Kamerun)',
        'ff_GN' => 'fulani (Guinea)',
        'ff_Latn' => 'fulani (Latin)',
        'ff_Latn_BF' => 'fulani (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'fulani (Latin, Kamerun)',
        'ff_Latn_GH' => 'fulani (Latin, Ghána)',
        'ff_Latn_GM' => 'fulani (Latin, Gambia)',
        'ff_Latn_GN' => 'fulani (Latin, Guinea)',
        'ff_Latn_GW' => 'fulani (Latin, Bissau-Guinea)',
        'ff_Latn_LR' => 'fulani (Latin, Libéria)',
        'ff_Latn_MR' => 'fulani (Latin, Mauritánia)',
        'ff_Latn_NE' => 'fulani (Latin, Niger)',
        'ff_Latn_NG' => 'fulani (Latin, Nigéria)',
        'ff_Latn_SL' => 'fulani (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'fulani (Latin, Szenegál)',
        'ff_MR' => 'fulani (Mauritánia)',
        'ff_SN' => 'fulani (Szenegál)',
        'fi' => 'finn',
        'fi_FI' => 'finn (Finnország)',
        'fo' => 'feröeri',
        'fo_DK' => 'feröeri (Dánia)',
        'fo_FO' => 'feröeri (Feröer szigetek)',
        'fr' => 'francia',
        'fr_BE' => 'francia (Belgium)',
        'fr_BF' => 'francia (Burkina Faso)',
        'fr_BI' => 'francia (Burundi)',
        'fr_BJ' => 'francia (Benin)',
        'fr_BL' => 'francia (Saint-Barthélemy)',
        'fr_CA' => 'francia (Kanada)',
        'fr_CD' => 'francia (Kongó – Kinshasa)',
        'fr_CF' => 'francia (Közép-afrikai Köztársaság)',
        'fr_CG' => 'francia (Kongó – Brazzaville)',
        'fr_CH' => 'francia (Svájc)',
        'fr_CI' => 'francia (Elefántcsontpart)',
        'fr_CM' => 'francia (Kamerun)',
        'fr_DJ' => 'francia (Dzsibuti)',
        'fr_DZ' => 'francia (Algéria)',
        'fr_FR' => 'francia (Franciaország)',
        'fr_GA' => 'francia (Gabon)',
        'fr_GF' => 'francia (Francia Guyana)',
        'fr_GN' => 'francia (Guinea)',
        'fr_GP' => 'francia (Guadeloupe)',
        'fr_GQ' => 'francia (Egyenlítői-Guinea)',
        'fr_HT' => 'francia (Haiti)',
        'fr_KM' => 'francia (Comore-szigetek)',
        'fr_LU' => 'francia (Luxemburg)',
        'fr_MA' => 'francia (Marokkó)',
        'fr_MC' => 'francia (Monaco)',
        'fr_MF' => 'francia (Saint Martin)',
        'fr_MG' => 'francia (Madagaszkár)',
        'fr_ML' => 'francia (Mali)',
        'fr_MQ' => 'francia (Martinique)',
        'fr_MR' => 'francia (Mauritánia)',
        'fr_MU' => 'francia (Mauritius)',
        'fr_NC' => 'francia (Új-Kaledónia)',
        'fr_NE' => 'francia (Niger)',
        'fr_PF' => 'francia (Francia Polinézia)',
        'fr_PM' => 'francia (Saint-Pierre és Miquelon)',
        'fr_RE' => 'francia (Réunion)',
        'fr_RW' => 'francia (Ruanda)',
        'fr_SC' => 'francia (Seychelle-szigetek)',
        'fr_SN' => 'francia (Szenegál)',
        'fr_SY' => 'francia (Szíria)',
        'fr_TD' => 'francia (Csád)',
        'fr_TG' => 'francia (Togo)',
        'fr_TN' => 'francia (Tunézia)',
        'fr_VU' => 'francia (Vanuatu)',
        'fr_WF' => 'francia (Wallis és Futuna)',
        'fr_YT' => 'francia (Mayotte)',
        'fy' => 'nyugati fríz',
        'fy_NL' => 'nyugati fríz (Hollandia)',
        'ga' => 'ír',
        'ga_GB' => 'ír (Egyesült Királyság)',
        'ga_IE' => 'ír (Írország)',
        'gd' => 'skóciai kelta',
        'gd_GB' => 'skóciai kelta (Egyesült Királyság)',
        'gl' => 'gallego',
        'gl_ES' => 'gallego (Spanyolország)',
        'gu' => 'gudzsaráti',
        'gu_IN' => 'gudzsaráti (India)',
        'gv' => 'man-szigeti',
        'gv_IM' => 'man-szigeti (Man-sziget)',
        'ha' => 'hausza',
        'ha_GH' => 'hausza (Ghána)',
        'ha_NE' => 'hausza (Niger)',
        'ha_NG' => 'hausza (Nigéria)',
        'he' => 'héber',
        'he_IL' => 'héber (Izrael)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (Latin)',
        'hi_Latn_IN' => 'hindi (Latin, India)',
        'hr' => 'horvát',
        'hr_BA' => 'horvát (Bosznia-Hercegovina)',
        'hr_HR' => 'horvát (Horvátország)',
        'hu' => 'magyar',
        'hu_HU' => 'magyar (Magyarország)',
        'hy' => 'örmény',
        'hy_AM' => 'örmény (Örményország)',
        'ia' => 'interlingva',
        'ia_001' => 'interlingva (Világ)',
        'id' => 'indonéz',
        'id_ID' => 'indonéz (Indonézia)',
        'ig' => 'igbó',
        'ig_NG' => 'igbó (Nigéria)',
        'ii' => 'szecsuán ji',
        'ii_CN' => 'szecsuán ji (Kína)',
        'is' => 'izlandi',
        'is_IS' => 'izlandi (Izland)',
        'it' => 'olasz',
        'it_CH' => 'olasz (Svájc)',
        'it_IT' => 'olasz (Olaszország)',
        'it_SM' => 'olasz (San Marino)',
        'it_VA' => 'olasz (Vatikán)',
        'ja' => 'japán',
        'ja_JP' => 'japán (Japán)',
        'jv' => 'jávai',
        'jv_ID' => 'jávai (Indonézia)',
        'ka' => 'grúz',
        'ka_GE' => 'grúz (Grúzia)',
        'ki' => 'kikuju',
        'ki_KE' => 'kikuju (Kenya)',
        'kk' => 'kazah',
        'kk_KZ' => 'kazah (Kazahsztán)',
        'kl' => 'grönlandi',
        'kl_GL' => 'grönlandi (Grönland)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Kambodzsa)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'koreai',
        'ko_KP' => 'koreai (Észak-Korea)',
        'ko_KR' => 'koreai (Dél-Korea)',
        'ks' => 'kasmíri',
        'ks_Arab' => 'kasmíri (Arab)',
        'ks_Arab_IN' => 'kasmíri (Arab, India)',
        'ks_Deva' => 'kasmíri (Devanagári)',
        'ks_Deva_IN' => 'kasmíri (Devanagári, India)',
        'ks_IN' => 'kasmíri (India)',
        'ku' => 'kurd',
        'ku_TR' => 'kurd (Törökország)',
        'kw' => 'korni',
        'kw_GB' => 'korni (Egyesült Királyság)',
        'ky' => 'kirgiz',
        'ky_KG' => 'kirgiz (Kirgizisztán)',
        'lb' => 'luxemburgi',
        'lb_LU' => 'luxemburgi (Luxemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongó – Kinshasa)',
        'ln_CF' => 'lingala (Közép-afrikai Köztársaság)',
        'ln_CG' => 'lingala (Kongó – Brazzaville)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laosz)',
        'lt' => 'litván',
        'lt_LT' => 'litván (Litvánia)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Kongó – Kinshasa)',
        'lv' => 'lett',
        'lv_LV' => 'lett (Lettország)',
        'mg' => 'malgas',
        'mg_MG' => 'malgas (Madagaszkár)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Új-Zéland)',
        'mk' => 'macedón',
        'mk_MK' => 'macedón (Észak-Macedónia)',
        'ml' => 'malajálam',
        'ml_IN' => 'malajálam (India)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongólia)',
        'mr' => 'maráthi',
        'mr_IN' => 'maráthi (India)',
        'ms' => 'maláj',
        'ms_BN' => 'maláj (Brunei)',
        'ms_ID' => 'maláj (Indonézia)',
        'ms_MY' => 'maláj (Malajzia)',
        'ms_SG' => 'maláj (Szingapúr)',
        'mt' => 'máltai',
        'mt_MT' => 'máltai (Málta)',
        'my' => 'burmai',
        'my_MM' => 'burmai (Mianmar)',
        'nb' => 'norvég [bokmål]',
        'nb_NO' => 'norvég [bokmål] (Norvégia)',
        'nb_SJ' => 'norvég [bokmål] (Svalbard és Jan Mayen)',
        'nd' => 'északi ndebele',
        'nd_ZW' => 'északi ndebele (Zimbabwe)',
        'ne' => 'nepáli',
        'ne_IN' => 'nepáli (India)',
        'ne_NP' => 'nepáli (Nepál)',
        'nl' => 'holland',
        'nl_AW' => 'holland (Aruba)',
        'nl_BE' => 'holland (Belgium)',
        'nl_BQ' => 'holland (Holland Karib-térség)',
        'nl_CW' => 'holland (Curaçao)',
        'nl_NL' => 'holland (Hollandia)',
        'nl_SR' => 'holland (Suriname)',
        'nl_SX' => 'holland (Sint Maarten)',
        'nn' => 'norvég [nynorsk]',
        'nn_NO' => 'norvég [nynorsk] (Norvégia)',
        'no' => 'norvég',
        'no_NO' => 'norvég (Norvégia)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiópia)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'odia',
        'or_IN' => 'odia (India)',
        'os' => 'oszét',
        'os_GE' => 'oszét (Grúzia)',
        'os_RU' => 'oszét (Oroszország)',
        'pa' => 'pandzsábi',
        'pa_Arab' => 'pandzsábi (Arab)',
        'pa_Arab_PK' => 'pandzsábi (Arab, Pakisztán)',
        'pa_Guru' => 'pandzsábi (Gurmuki)',
        'pa_Guru_IN' => 'pandzsábi (Gurmuki, India)',
        'pa_IN' => 'pandzsábi (India)',
        'pa_PK' => 'pandzsábi (Pakisztán)',
        'pl' => 'lengyel',
        'pl_PL' => 'lengyel (Lengyelország)',
        'ps' => 'pastu',
        'ps_AF' => 'pastu (Afganisztán)',
        'ps_PK' => 'pastu (Pakisztán)',
        'pt' => 'portugál',
        'pt_AO' => 'portugál (Angola)',
        'pt_BR' => 'portugál (Brazília)',
        'pt_CH' => 'portugál (Svájc)',
        'pt_CV' => 'portugál (Zöld-foki Köztársaság)',
        'pt_GQ' => 'portugál (Egyenlítői-Guinea)',
        'pt_GW' => 'portugál (Bissau-Guinea)',
        'pt_LU' => 'portugál (Luxemburg)',
        'pt_MO' => 'portugál (Makaó KKT)',
        'pt_MZ' => 'portugál (Mozambik)',
        'pt_PT' => 'portugál (Portugália)',
        'pt_ST' => 'portugál (São Tomé és Príncipe)',
        'pt_TL' => 'portugál (Kelet-Timor)',
        'qu' => 'kecsua',
        'qu_BO' => 'kecsua (Bolívia)',
        'qu_EC' => 'kecsua (Ecuador)',
        'qu_PE' => 'kecsua (Peru)',
        'rm' => 'rétoromán',
        'rm_CH' => 'rétoromán (Svájc)',
        'rn' => 'kirundi',
        'rn_BI' => 'kirundi (Burundi)',
        'ro' => 'román',
        'ro_MD' => 'román (Moldova)',
        'ro_RO' => 'román (Románia)',
        'ru' => 'orosz',
        'ru_BY' => 'orosz (Belarusz)',
        'ru_KG' => 'orosz (Kirgizisztán)',
        'ru_KZ' => 'orosz (Kazahsztán)',
        'ru_MD' => 'orosz (Moldova)',
        'ru_RU' => 'orosz (Oroszország)',
        'ru_UA' => 'orosz (Ukrajna)',
        'rw' => 'kinyarvanda',
        'rw_RW' => 'kinyarvanda (Ruanda)',
        'sa' => 'szanszkrit',
        'sa_IN' => 'szanszkrit (India)',
        'sc' => 'szardíniai',
        'sc_IT' => 'szardíniai (Olaszország)',
        'sd' => 'szindhi',
        'sd_Arab' => 'szindhi (Arab)',
        'sd_Arab_PK' => 'szindhi (Arab, Pakisztán)',
        'sd_Deva' => 'szindhi (Devanagári)',
        'sd_Deva_IN' => 'szindhi (Devanagári, India)',
        'sd_IN' => 'szindhi (India)',
        'sd_PK' => 'szindhi (Pakisztán)',
        'se' => 'északi számi',
        'se_FI' => 'északi számi (Finnország)',
        'se_NO' => 'északi számi (Norvégia)',
        'se_SE' => 'északi számi (Svédország)',
        'sg' => 'szangó',
        'sg_CF' => 'szangó (Közép-afrikai Köztársaság)',
        'sh' => 'szerbhorvát',
        'sh_BA' => 'szerbhorvát (Bosznia-Hercegovina)',
        'si' => 'szingaléz',
        'si_LK' => 'szingaléz (Srí Lanka)',
        'sk' => 'szlovák',
        'sk_SK' => 'szlovák (Szlovákia)',
        'sl' => 'szlovén',
        'sl_SI' => 'szlovén (Szlovénia)',
        'sn' => 'sona',
        'sn_ZW' => 'sona (Zimbabwe)',
        'so' => 'szomáli',
        'so_DJ' => 'szomáli (Dzsibuti)',
        'so_ET' => 'szomáli (Etiópia)',
        'so_KE' => 'szomáli (Kenya)',
        'so_SO' => 'szomáli (Szomália)',
        'sq' => 'albán',
        'sq_AL' => 'albán (Albánia)',
        'sq_MK' => 'albán (Észak-Macedónia)',
        'sr' => 'szerb',
        'sr_BA' => 'szerb (Bosznia-Hercegovina)',
        'sr_Cyrl' => 'szerb (Cirill)',
        'sr_Cyrl_BA' => 'szerb (Cirill, Bosznia-Hercegovina)',
        'sr_Cyrl_ME' => 'szerb (Cirill, Montenegró)',
        'sr_Cyrl_RS' => 'szerb (Cirill, Szerbia)',
        'sr_Latn' => 'szerb (Latin)',
        'sr_Latn_BA' => 'szerb (Latin, Bosznia-Hercegovina)',
        'sr_Latn_ME' => 'szerb (Latin, Montenegró)',
        'sr_Latn_RS' => 'szerb (Latin, Szerbia)',
        'sr_ME' => 'szerb (Montenegró)',
        'sr_RS' => 'szerb (Szerbia)',
        'su' => 'szundanéz',
        'su_ID' => 'szundanéz (Indonézia)',
        'su_Latn' => 'szundanéz (Latin)',
        'su_Latn_ID' => 'szundanéz (Latin, Indonézia)',
        'sv' => 'svéd',
        'sv_AX' => 'svéd (Åland-szigetek)',
        'sv_FI' => 'svéd (Finnország)',
        'sv_SE' => 'svéd (Svédország)',
        'sw' => 'szuahéli',
        'sw_CD' => 'szuahéli (Kongó – Kinshasa)',
        'sw_KE' => 'szuahéli (Kenya)',
        'sw_TZ' => 'szuahéli (Tanzánia)',
        'sw_UG' => 'szuahéli (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (India)',
        'ta_LK' => 'tamil (Srí Lanka)',
        'ta_MY' => 'tamil (Malajzia)',
        'ta_SG' => 'tamil (Szingapúr)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tadzsik',
        'tg_TJ' => 'tadzsik (Tádzsikisztán)',
        'th' => 'thai',
        'th_TH' => 'thai (Thaiföld)',
        'ti' => 'tigrinya',
        'ti_ER' => 'tigrinya (Eritrea)',
        'ti_ET' => 'tigrinya (Etiópia)',
        'tk' => 'türkmén',
        'tk_TM' => 'türkmén (Türkmenisztán)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Fülöp-szigetek)',
        'to' => 'tongai',
        'to_TO' => 'tongai (Tonga)',
        'tr' => 'török',
        'tr_CY' => 'török (Ciprus)',
        'tr_TR' => 'török (Törökország)',
        'tt' => 'tatár',
        'tt_RU' => 'tatár (Oroszország)',
        'ug' => 'ujgur',
        'ug_CN' => 'ujgur (Kína)',
        'uk' => 'ukrán',
        'uk_UA' => 'ukrán (Ukrajna)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakisztán)',
        'uz' => 'üzbég',
        'uz_AF' => 'üzbég (Afganisztán)',
        'uz_Arab' => 'üzbég (Arab)',
        'uz_Arab_AF' => 'üzbég (Arab, Afganisztán)',
        'uz_Cyrl' => 'üzbég (Cirill)',
        'uz_Cyrl_UZ' => 'üzbég (Cirill, Üzbegisztán)',
        'uz_Latn' => 'üzbég (Latin)',
        'uz_Latn_UZ' => 'üzbég (Latin, Üzbegisztán)',
        'uz_UZ' => 'üzbég (Üzbegisztán)',
        'vi' => 'vietnámi',
        'vi_VN' => 'vietnámi (Vietnám)',
        'wo' => 'volof',
        'wo_SN' => 'volof (Szenegál)',
        'xh' => 'xhosza',
        'xh_ZA' => 'xhosza (Dél-afrikai Köztársaság)',
        'yi' => 'jiddis',
        'yi_001' => 'jiddis (Világ)',
        'yo' => 'joruba',
        'yo_BJ' => 'joruba (Benin)',
        'yo_NG' => 'joruba (Nigéria)',
        'zh' => 'kínai',
        'zh_CN' => 'kínai (Kína)',
        'zh_HK' => 'kínai (Hongkong KKT)',
        'zh_Hans' => 'kínai (Egyszerűsített)',
        'zh_Hans_CN' => 'kínai (Egyszerűsített, Kína)',
        'zh_Hans_HK' => 'kínai (Egyszerűsített, Hongkong KKT)',
        'zh_Hans_MO' => 'kínai (Egyszerűsített, Makaó KKT)',
        'zh_Hans_SG' => 'kínai (Egyszerűsített, Szingapúr)',
        'zh_Hant' => 'kínai (Hagyományos)',
        'zh_Hant_HK' => 'kínai (Hagyományos, Hongkong KKT)',
        'zh_Hant_MO' => 'kínai (Hagyományos, Makaó KKT)',
        'zh_Hant_TW' => 'kínai (Hagyományos, Tajvan)',
        'zh_MO' => 'kínai (Makaó KKT)',
        'zh_SG' => 'kínai (Szingapúr)',
        'zh_TW' => 'kínai (Tajvan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Dél-afrikai Köztársaság)',
    ],
];
