<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Birlashgan Arab Amirliklari dirhami',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afg‘oniston afg‘oniysi',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albaniya leki',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armaniston drami',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Niderlandiya antil guldeni',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angola kvanzasi',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentina pesosi',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Avstraliya dollari',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruba florini',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Ozarbayjon manati',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosniya va Gertsegovina ayirboshlash markasi',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados dollari',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladesh takasi',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bolgariya levi',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahrayn dinori',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi franki',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda dollari',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Bruney dollari',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviya bolivianosi',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Braziliya reali',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bagama dollari',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butan ngultrumi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botsvana pulasi',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarus rubli',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Belarus rubli (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Beliz dollari',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanada dollari',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongo franki',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Shveytsariya franki',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chili pesosi',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Xitoy yuani (ofshor)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Xitoy yuani',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbiya pesosi',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kosta-Rika koloni',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kuba ayirboshlash pesosi',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kuba pesosi',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kabo-Verde eskudosi',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Chexiya kronasi',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Jibuti franki',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Daniya kronasi',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikana pesosi',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Jazoir dinori',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Misr funti',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritreya nakfasi',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Efiopiya biri',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yevro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fiji dollari',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Folklend orollari funti',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Angliya funt sterlingi',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gruziya larisi',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Gana sedisi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltar funti',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambiya dalasisi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gvineya franki',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Gvatemala ketsali',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Gayana dollari',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Gonkong dollari',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Gonduras lempirasi',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Xorvatiya kunasi',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gaiti gurdi',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Vengriya forinti',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indoneziya rupiyasi',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Isroil yangi shekeli',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Hindiston rupiyasi',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Iroq dinori',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Eron riyoli',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islandiya kronasi',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Yamayka dollari',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Iordaniya dinori',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yaponiya iyenasi',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Keniya shillingi',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Qirg‘iziston somi',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodja rieli',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komor orollari franki',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Shimoliy Koreya voni',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Janubiy Koreya voni',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuvayt dinori',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kayman orollari dollari',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Qozog‘iston tengesi',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laos kipi',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Livan funti',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Shri-Lanka rupiyasi',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberiya dollari',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesoto lotisi',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litva liti',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Latviya lati',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Liviya dinori',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokash dirhami',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldova leyi',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagasi ariarisi',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedoniya dinori',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanma kyati',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongoliya tugriki',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao patakasi',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mavritaniya uqiyasi (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mavritaniya uqiyasi',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mavritaniya rupiyasi',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldiv rupiyasi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malavi kvachasi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksika pesosi',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malayziya ringgiti',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambik metikali',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibiya dollari',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeriya nayrasi',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragua kordobasi',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norvegiya kronasi',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepal rupiyasi',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Yangi Zelandiya dollari',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Ummon riyoli',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panama balboasi',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru soli',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua – Yangi Gvineya kinasi',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filippin pesosi',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pokiston rupiyasi',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polsha zlotiyi',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paragvay guaranisi',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Qatar riyoli',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Ruminiya leyi',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbiya dinori',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rossiya rubli',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruanda franki',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudiya Arabistoni riyoli',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomon orollari dollari',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seyshel rupiyasi',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudan funti',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Shvetsiya kronasi',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapur dollari',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Muqaddas Yelena oroli funti',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Syerra-Leone leonesi',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somali shillingi',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinam dollari',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Janubiy Sudan funti',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'San-Tome va Prinsipi dobrasi (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'San-Tome va Prinsipi dobrasi',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Suriya funti',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svazilend lilangenisi',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Tailand bati',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tojikiston somoniysi',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmaniston manati',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunis dinori',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tonga paangasi',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turk lirasi',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad va Tobago dollari',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Yangi Tayvan dollari',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniya shillingi',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukraina grivnasi',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Uganda shillingi',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'AQSH dollari',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Urugvay pesosi',
        ],
        'UZS' => [
            0 => 'soʻm',
            1 => 'O‘zbekiston so‘mi',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venesuela bolivari (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venesuela bolivari',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vyetnam dongi',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu vatusi',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa talasi',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Markaziy Afrika CFA franki',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Sharqiy Karib dollari',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'G‘arbiy Afrika CFA franki',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Fransuz Polineziyasi franki',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Yaman riyoli',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Janubiy Afrika rendi',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambiya kvachasi',
        ],
    ],
];
