<?php

return [
    'Names' => [
        'be' => 'бјелоруски',
        'bm' => 'бамананкан',
        'bn' => 'бангла',
        'crl' => 'сјевероисточни кри',
        'de' => 'њемачки',
        'frr' => 'сјевернофризијски',
        'gsw' => 'њемачки (Швајцарска)',
        'ht' => 'хаићански креолски',
        'lrc' => 'сјеверни лури',
        'nd' => 'сјеверни ндебеле',
        'nds' => 'нискоњемачки',
        'nso' => 'сјеверни сото',
        'ojb' => 'сјеверозападни оџибва',
        'se' => 'сјеверни сами',
        'ttm' => 'сјеверни тучон',
    ],
    'LocalizedNames' => [
        'de_CH' => 'швајцарски високи њемачки',
    ],
];
