<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'i-Dirham yase-United Arab Emirates',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'i-Afghan Afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'i-Albanian Lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'i-Armenian Dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'i-Netherlands Antillean Guilder',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'i-Angolan Kwanza',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'i-Argentina Peso',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'i-Austrilian Dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'i-Aruban Florin',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'i-Azerbaijani Manat',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'i-Bosnia-Herzegovina Convertible Mark',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'i-Barbadian Dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'i-Bangladeshi Taka',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'i-Bulgarian Lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'i-Bahraini Dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'i-Burundian Franc',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'i-Bermudan Dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'i-Brunei Dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'i-Bolivian Boliviano',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'i-Brazilian Real',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'i-Bahamian Dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'i-Bhutanese Ngultrum',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'i-Botswana Pula',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'i-Belarusian Ruble',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'i-Belarusian Ruble (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'i-Belize Dollar',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'i-Candian Dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'i-Congolese Franc',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'i-Swiss Franc',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'i-Chilean Peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'i-CNH',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'i-Chinese Yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'i-Colombian Peso',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'i-Costa Rican Colón',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'i-Cuban Convertable Peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'i-Cuban Peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'i-Cape Verdean Escudo',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'i-Czech Republic Koruna',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'i-Djiboutian Franc',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'i-Danish Krone',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'i-Dominican Peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'i-Algerian Dinar',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'i-Egyptian Pound',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'i-Eritrean Nakfa',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'i-Ethopian Birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'i-Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'i-Fijian Dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'i-Falkland Islands Pound',
        ],
        'GBP' => [
            0 => '£',
            1 => 'i-British Pound',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'i-Georgian Lari',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'i-Ghanaian Cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'i-Gibraltar Pound',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'i-Gambian Dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'i-Gunean Franc',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'i-Guatemalan Quetzal',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'i-Guyanaese Dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'i-Hong Kong Dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'i-Honduran Lempira',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'i-Croatian Kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'i-Haitian Gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'i-Hungarian Forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'i-Indonesian Rupiah',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'i-Israeli New Sheqel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'i-Indian Rupee',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'i-Iraqi Dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'i-Iranian Rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'i-Icelandic Króna',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'i-Jamaican Dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'i-Jordanian Dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'i-Japanese Yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'i-Kenyan Shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'i-Kyrgystani Som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'i-Cambodian Riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'i-Comorian Franc',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'i-North Korean Won',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'i-South Korean Won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'i-Kuwaiti Dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'i-Cayman Islands Dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'i-Kazakhstani Tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'i-Laotian Kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'i-Lebanese Pound',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'i-Sri Lankan Rupee',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'i-Liberian Dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'i-Lesotho Loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'i-Lithuanian Litas',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'i-Latvian Lats',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'i-Libyan Dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'i-Moroccan Dirham',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'i-Moldovan Leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'i-Malagasy Ariary',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'i-Macedonian Denar',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'i-Myanma Kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'i-Mongolian Tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'i-Macanese Pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'i-Mauritanian Ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'i-Mauritanian Ouguiya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'i-Mauritian Rupee',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'i-Maldivian Rufiyana',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'i-Malawian Kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'i-Mexican Peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'i-Malaysian Ringgit',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'i-Mozambican Metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'i-Namibian Dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'i-Nigerian Naira',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'i-Nicaraguan Córdoba',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'i-Norwegian Krone',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'i-Nepalese Rupee',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'i-New Zealand Dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'i-Omani Rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'i-Panamanian Balboa',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'i-Peruvian Nuevo Sol',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'i-Papua New Guinean Kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'i-Philippine Peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'i-Pakistani Rupee',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'i-Polish Zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'i-Paraguayan Guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'i-Qatari Rial',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'i-Romanian Leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'i-Serbian Dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'i-Russian Ruble',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'i-Rwandan Franc',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'i-Saudi Riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'i-Solomon Islands Dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'i-Seychellois Rupee',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'i-Sudanese Pound',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'i-Swedish Krona',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'i-Singapore Dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'i-Saint Helena Pound',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'i-Sierra Leonean Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'i-Somali Shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'i-Surinamese Dollar',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'i-South Sudanese Pound',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'i-São Tomé kanye ne-Príncipe Dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'i-São Tomé kanye ne-Príncipe Dobra',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'i-Syrian Pound',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'i-Swazi Lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'i-Thai Baht',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'i-Tajikistani Somoni',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'i-Turkmenistani Manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'i-Tunisian Dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'i-Tongan Paʻanga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'i-Turkish Lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'i-Trinidad and Tobago Dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'i-New Taiwan Dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'i-Tanzanian Shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'i-Ukrainian Hryvnia',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'i-Ugandan Shilling',
        ],
        'USD' => [
            0 => '$',
            1 => 'i-US Dollar',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'i-Uruguayan Peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'i-Uzbekistan Som',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'i-Venezuelan Bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'i-Venezuelan Bolívar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'i-Vietnamese Dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'i-Vanuatu Vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'i-Samoan Tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'i-Central African CFA Franc',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'i-East Caribbean Dollar',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'i-West African CFA Franc',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'i-CFP Franc',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'i-Yemeni Rial',
        ],
        'ZAR' => [
            0 => 'R',
            1 => 'i-South African Rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'i-Zambian Kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'i-Zambian Kwacha',
        ],
    ],
];
