<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'dirâm tî âEmirâti tî Arâbo Ôko',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwânza tî Angoläa',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'dolära tî Ostralïi',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dolùara tî Bahrâina',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'farânga tî Burundïi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pûla tî Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'dolära tî kanadäa',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'farânga tî Kongöo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'farânga tî Sûîsi',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'yuan renminbi tî Shîni',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'eskûêdo tî Kâpo-Vêre',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'farânga tî Dibutïi',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinäri tî Alzerïi',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'pôndo tî Kâmitâ',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nakafa tî Eritrëe',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'bir tî Etiopïi',
        ],
        'EUR' => [
            0 => '€',
            1 => 'zoröo',
        ],
        'GBP' => [
            0 => '£',
            1 => 'pôndo tî Anglëe',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'sêdi tî Ganäa',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi tî gambïi',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'sili tî Ginëe',
        ],
        'INR' => [
            0 => '₹',
            1 => 'rupïi tî Ênnde',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'yêni tî Zapön',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'shilîngi tî Kenyäa',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'farânga tî Kömôro',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dolära tî Liberïa',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti tî Lesôtho',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinäar tî Libïi',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirâm tî Marôko',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariâri tî Madagasikära',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ugîya tî Moritanïi (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ugîya tî Moritanïi',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupïi tî Mörîsi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwâtia tî Malawïi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'metikala tî Mozambîka',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dolära tî Namibïi',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nâîra tî Nizerïa',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'farânga tî Ruandäa',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'riâli tî Saûdi Arabïi',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupïi tî Sëyshêle',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'pôndo tî Sudäan',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'pôndo tî Zûâ Sênt-Helêna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leône tî Sierâ-Leône',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'shilîngi tî Somalïi',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dôbra tî Sâô Tomë na Prinsîpe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dôbra tî Sâô Tomë na Prinsîpe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangùeni tî Swazïlânde',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinära tî Tunizïi',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'shilîngi tî Tanzanïi',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'shilîngi tî Ugandäa',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'dol$ara ttî äLetäa-Ôko tî Amerîka',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'farânga CFA (BEAC)',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'farânga CFA (BCEAO)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rânde tî Mbongo-Afrîka',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'kwâtia tî Zambïi (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwâtia tî Zambïi',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'dolära tî Zimbäbwe',
        ],
    ],
];
