<?php

return [
    'Names' => [
        'af' => 'አፍሪካንኛ',
        'af_NA' => 'አፍሪካንኛ (ናሚቢያ)',
        'af_ZA' => 'አፍሪካንኛ (ደቡብ አፍሪካ)',
        'ak' => 'አካንኛ',
        'ak_GH' => 'አካንኛ (ጋና)',
        'am' => 'አማርኛ',
        'am_ET' => 'አማርኛ (ኢትዮጵያ)',
        'ar' => 'ዓረብኛ',
        'ar_001' => 'ዓረብኛ (ዓለም)',
        'ar_AE' => 'ዓረብኛ (የተባበሩት ዓረብ ኤምሬትስ)',
        'ar_BH' => 'ዓረብኛ (ባህሬን)',
        'ar_DJ' => 'ዓረብኛ (ጂቡቲ)',
        'ar_DZ' => 'ዓረብኛ (አልጄሪያ)',
        'ar_EG' => 'ዓረብኛ (ግብጽ)',
        'ar_EH' => 'ዓረብኛ (ምዕራባዊ ሳህራ)',
        'ar_ER' => 'ዓረብኛ (ኤርትራ)',
        'ar_IL' => 'ዓረብኛ (እስራኤል)',
        'ar_IQ' => 'ዓረብኛ (ኢራቅ)',
        'ar_JO' => 'ዓረብኛ (ጆርዳን)',
        'ar_KM' => 'ዓረብኛ (ኮሞሮስ)',
        'ar_KW' => 'ዓረብኛ (ክዌት)',
        'ar_LB' => 'ዓረብኛ (ሊባኖስ)',
        'ar_LY' => 'ዓረብኛ (ሊቢያ)',
        'ar_MA' => 'ዓረብኛ (ሞሮኮ)',
        'ar_MR' => 'ዓረብኛ (ሞሪቴኒያ)',
        'ar_OM' => 'ዓረብኛ (ኦማን)',
        'ar_PS' => 'ዓረብኛ (የፍልስጤም ግዛት)',
        'ar_QA' => 'ዓረብኛ (ኳታር)',
        'ar_SA' => 'ዓረብኛ (ሳውድአረቢያ)',
        'ar_SD' => 'ዓረብኛ (ሱዳን)',
        'ar_SO' => 'ዓረብኛ (ሱማሌ)',
        'ar_SS' => 'ዓረብኛ (ደቡብ ሱዳን)',
        'ar_SY' => 'ዓረብኛ (ሲሪያ)',
        'ar_TD' => 'ዓረብኛ (ቻድ)',
        'ar_TN' => 'ዓረብኛ (ቱኒዚያ)',
        'ar_YE' => 'ዓረብኛ (የመን)',
        'as' => 'አሳሜዛዊ',
        'as_IN' => 'አሳሜዛዊ (ህንድ)',
        'az' => 'አዘርባጃንኛ',
        'az_AZ' => 'አዘርባጃንኛ (አዘርባጃን)',
        'az_Cyrl' => 'አዘርባጃንኛ (ሲይሪልክ)',
        'az_Cyrl_AZ' => 'አዘርባጃንኛ (ሲይሪልክ፣አዘርባጃን)',
        'az_Latn' => 'አዘርባጃንኛ (ላቲን)',
        'az_Latn_AZ' => 'አዘርባጃንኛ (ላቲን፣አዘርባጃን)',
        'be' => 'ቤላራሻኛ',
        'be_BY' => 'ቤላራሻኛ (ቤላሩስ)',
        'bg' => 'ቡልጋሪኛ',
        'bg_BG' => 'ቡልጋሪኛ (ቡልጌሪያ)',
        'bm' => 'ባምባርኛ',
        'bm_ML' => 'ባምባርኛ (ማሊ)',
        'bn' => 'ቤንጋሊኛ',
        'bn_BD' => 'ቤንጋሊኛ (ባንግላዲሽ)',
        'bn_IN' => 'ቤንጋሊኛ (ህንድ)',
        'bo' => 'ቲቤታንኛ',
        'bo_CN' => 'ቲቤታንኛ (ቻይና)',
        'bo_IN' => 'ቲቤታንኛ (ህንድ)',
        'br' => 'ብሬቶንኛ',
        'br_FR' => 'ብሬቶንኛ (ፈረንሳይ)',
        'bs' => 'ቦስኒያንኛ',
        'bs_BA' => 'ቦስኒያንኛ (ቦስኒያ እና ሄርዞጎቪኒያ)',
        'bs_Cyrl' => 'ቦስኒያንኛ (ሲይሪልክ)',
        'bs_Cyrl_BA' => 'ቦስኒያንኛ (ሲይሪልክ፣ቦስኒያ እና ሄርዞጎቪኒያ)',
        'bs_Latn' => 'ቦስኒያንኛ (ላቲን)',
        'bs_Latn_BA' => 'ቦስኒያንኛ (ላቲን፣ቦስኒያ እና ሄርዞጎቪኒያ)',
        'ca' => 'ካታላንኛ',
        'ca_AD' => 'ካታላንኛ (አንዶራ)',
        'ca_ES' => 'ካታላንኛ (ስፔን)',
        'ca_FR' => 'ካታላንኛ (ፈረንሳይ)',
        'ca_IT' => 'ካታላንኛ (ጣሊያን)',
        'ce' => 'ችችን',
        'ce_RU' => 'ችችን (ሩስያ)',
        'cs' => 'ቼክኛ',
        'cs_CZ' => 'ቼክኛ (ቼቺያ)',
        'cv' => 'ቹቫሽ',
        'cv_RU' => 'ቹቫሽ (ሩስያ)',
        'cy' => 'ወልሽ',
        'cy_GB' => 'ወልሽ (ዩናይትድ ኪንግደም)',
        'da' => 'ዴኒሽ',
        'da_DK' => 'ዴኒሽ (ዴንማርክ)',
        'da_GL' => 'ዴኒሽ (ግሪንላንድ)',
        'de' => 'ጀርመን',
        'de_AT' => 'ጀርመን (ኦስትሪያ)',
        'de_BE' => 'ጀርመን (ቤልጄም)',
        'de_CH' => 'ጀርመን (ስዊዘርላንድ)',
        'de_DE' => 'ጀርመን (ጀርመን)',
        'de_IT' => 'ጀርመን (ጣሊያን)',
        'de_LI' => 'ጀርመን (ሊችተንስታይን)',
        'de_LU' => 'ጀርመን (ሉክሰምበርግ)',
        'dz' => 'ድዞንግኻኛ',
        'dz_BT' => 'ድዞንግኻኛ (ቡህታን)',
        'ee' => 'ኢዊ',
        'ee_GH' => 'ኢዊ (ጋና)',
        'ee_TG' => 'ኢዊ (ቶጐ)',
        'el' => 'ግሪክኛ',
        'el_CY' => 'ግሪክኛ (ሳይፕረስ)',
        'el_GR' => 'ግሪክኛ (ግሪክ)',
        'en' => 'እንግሊዝኛ',
        'en_001' => 'እንግሊዝኛ (ዓለም)',
        'en_150' => 'እንግሊዝኛ (አውሮፓ)',
        'en_AE' => 'እንግሊዝኛ (የተባበሩት ዓረብ ኤምሬትስ)',
        'en_AG' => 'እንግሊዝኛ (አንቲጓ እና ባሩዳ)',
        'en_AI' => 'እንግሊዝኛ (አንጉይላ)',
        'en_AS' => 'እንግሊዝኛ (የአሜሪካ ሳሞአ)',
        'en_AT' => 'እንግሊዝኛ (ኦስትሪያ)',
        'en_AU' => 'እንግሊዝኛ (አውስትራልያ)',
        'en_BB' => 'እንግሊዝኛ (ባርቤዶስ)',
        'en_BE' => 'እንግሊዝኛ (ቤልጄም)',
        'en_BI' => 'እንግሊዝኛ (ብሩንዲ)',
        'en_BM' => 'እንግሊዝኛ (ቤርሙዳ)',
        'en_BS' => 'እንግሊዝኛ (ባሃማስ)',
        'en_BW' => 'እንግሊዝኛ (ቦትስዋና)',
        'en_BZ' => 'እንግሊዝኛ (በሊዝ)',
        'en_CA' => 'እንግሊዝኛ (ካናዳ)',
        'en_CC' => 'እንግሊዝኛ (ኮኮስ[ኬሊንግ] ደሴቶች)',
        'en_CH' => 'እንግሊዝኛ (ስዊዘርላንድ)',
        'en_CK' => 'እንግሊዝኛ (ኩክ ደሴቶች)',
        'en_CM' => 'እንግሊዝኛ (ካሜሩን)',
        'en_CX' => 'እንግሊዝኛ (ክሪስማስ ደሴት)',
        'en_CY' => 'እንግሊዝኛ (ሳይፕረስ)',
        'en_DE' => 'እንግሊዝኛ (ጀርመን)',
        'en_DK' => 'እንግሊዝኛ (ዴንማርክ)',
        'en_DM' => 'እንግሊዝኛ (ዶሚኒካ)',
        'en_ER' => 'እንግሊዝኛ (ኤርትራ)',
        'en_FI' => 'እንግሊዝኛ (ፊንላንድ)',
        'en_FJ' => 'እንግሊዝኛ (ፊጂ)',
        'en_FK' => 'እንግሊዝኛ (የፎክላንድ ደሴቶች)',
        'en_FM' => 'እንግሊዝኛ (ሚክሮኔዢያ)',
        'en_GB' => 'እንግሊዝኛ (ዩናይትድ ኪንግደም)',
        'en_GD' => 'እንግሊዝኛ (ግሬናዳ)',
        'en_GG' => 'እንግሊዝኛ (ጉርነሲ)',
        'en_GH' => 'እንግሊዝኛ (ጋና)',
        'en_GI' => 'እንግሊዝኛ (ጂብራልተር)',
        'en_GM' => 'እንግሊዝኛ (ጋምቢያ)',
        'en_GU' => 'እንግሊዝኛ (ጉዋም)',
        'en_GY' => 'እንግሊዝኛ (ጉያና)',
        'en_HK' => 'እንግሊዝኛ (ሆንግ ኮንግ ልዩ የአስተዳደር ክልል ቻይና)',
        'en_IE' => 'እንግሊዝኛ (አየርላንድ)',
        'en_IL' => 'እንግሊዝኛ (እስራኤል)',
        'en_IM' => 'እንግሊዝኛ (አይል ኦፍ ማን)',
        'en_IN' => 'እንግሊዝኛ (ህንድ)',
        'en_IO' => 'እንግሊዝኛ (የብሪታኒያ ህንድ ውቂያኖስ ግዛት)',
        'en_JE' => 'እንግሊዝኛ (ጀርሲ)',
        'en_JM' => 'እንግሊዝኛ (ጃማይካ)',
        'en_KE' => 'እንግሊዝኛ (ኬንያ)',
        'en_KI' => 'እንግሊዝኛ (ኪሪባቲ)',
        'en_KN' => 'እንግሊዝኛ (ቅዱስ ኪትስ እና ኔቪስ)',
        'en_KY' => 'እንግሊዝኛ (ካይማን ደሴቶች)',
        'en_LC' => 'እንግሊዝኛ (ሴንት ሉቺያ)',
        'en_LR' => 'እንግሊዝኛ (ላይቤሪያ)',
        'en_LS' => 'እንግሊዝኛ (ሌሶቶ)',
        'en_MG' => 'እንግሊዝኛ (ማዳጋስካር)',
        'en_MH' => 'እንግሊዝኛ (ማርሻል አይላንድ)',
        'en_MO' => 'እንግሊዝኛ (ማካኦ ልዩ የአስተዳደር ክልል ቻይና)',
        'en_MP' => 'እንግሊዝኛ (የሰሜናዊ ማሪያና ደሴቶች)',
        'en_MS' => 'እንግሊዝኛ (ሞንትሴራት)',
        'en_MT' => 'እንግሊዝኛ (ማልታ)',
        'en_MU' => 'እንግሊዝኛ (ሞሪሸስ)',
        'en_MV' => 'እንግሊዝኛ (ማልዲቭስ)',
        'en_MW' => 'እንግሊዝኛ (ማላዊ)',
        'en_MY' => 'እንግሊዝኛ (ማሌዢያ)',
        'en_NA' => 'እንግሊዝኛ (ናሚቢያ)',
        'en_NF' => 'እንግሊዝኛ (ኖርፎልክ ደሴት)',
        'en_NG' => 'እንግሊዝኛ (ናይጄሪያ)',
        'en_NL' => 'እንግሊዝኛ (ኔዘርላንድ)',
        'en_NR' => 'እንግሊዝኛ (ናኡሩ)',
        'en_NU' => 'እንግሊዝኛ (ኒኡይ)',
        'en_NZ' => 'እንግሊዝኛ (ኒው ዚላንድ)',
        'en_PG' => 'እንግሊዝኛ (ፓፑዋ ኒው ጊኒ)',
        'en_PH' => 'እንግሊዝኛ (ፊሊፒንስ)',
        'en_PK' => 'እንግሊዝኛ (ፓኪስታን)',
        'en_PN' => 'እንግሊዝኛ (ፒትካኢርን ደሴቶች)',
        'en_PR' => 'እንግሊዝኛ (ፖርታ ሪኮ)',
        'en_PW' => 'እንግሊዝኛ (ፓላው)',
        'en_RW' => 'እንግሊዝኛ (ሩዋንዳ)',
        'en_SB' => 'እንግሊዝኛ (ሰሎሞን ደሴት)',
        'en_SC' => 'እንግሊዝኛ (ሲሼልስ)',
        'en_SD' => 'እንግሊዝኛ (ሱዳን)',
        'en_SE' => 'እንግሊዝኛ (ስዊድን)',
        'en_SG' => 'እንግሊዝኛ (ሲንጋፖር)',
        'en_SH' => 'እንግሊዝኛ (ሴንት ሄለና)',
        'en_SI' => 'እንግሊዝኛ (ስሎቬኒያ)',
        'en_SL' => 'እንግሊዝኛ (ሴራሊዮን)',
        'en_SS' => 'እንግሊዝኛ (ደቡብ ሱዳን)',
        'en_SX' => 'እንግሊዝኛ (ሲንት ማርተን)',
        'en_SZ' => 'እንግሊዝኛ (ሱዋዚላንድ)',
        'en_TC' => 'እንግሊዝኛ (የቱርኮችና የካኢኮስ ደሴቶች)',
        'en_TK' => 'እንግሊዝኛ (ቶክላው)',
        'en_TO' => 'እንግሊዝኛ (ቶንጋ)',
        'en_TT' => 'እንግሊዝኛ (ትሪናዳድ እና ቶቤጎ)',
        'en_TV' => 'እንግሊዝኛ (ቱቫሉ)',
        'en_TZ' => 'እንግሊዝኛ (ታንዛኒያ)',
        'en_UG' => 'እንግሊዝኛ (ዩጋንዳ)',
        'en_UM' => 'እንግሊዝኛ (የዩ ኤስ ጠረፍ ላይ ያሉ ደሴቶች)',
        'en_US' => 'እንግሊዝኛ (ዩናይትድ ስቴትስ)',
        'en_VC' => 'እንግሊዝኛ (ቅዱስ ቪንሴንት እና ግሬናዲንስ)',
        'en_VG' => 'እንግሊዝኛ (የእንግሊዝ ቨርጂን ደሴቶች)',
        'en_VI' => 'እንግሊዝኛ (የአሜሪካ ቨርጂን ደሴቶች)',
        'en_VU' => 'እንግሊዝኛ (ቫኑአቱ)',
        'en_WS' => 'እንግሊዝኛ (ሳሞአ)',
        'en_ZA' => 'እንግሊዝኛ (ደቡብ አፍሪካ)',
        'en_ZM' => 'እንግሊዝኛ (ዛምቢያ)',
        'en_ZW' => 'እንግሊዝኛ (ዚምቧቤ)',
        'eo' => 'ኤስፐራንቶ',
        'eo_001' => 'ኤስፐራንቶ (ዓለም)',
        'es' => 'ስፓንሽኛ',
        'es_419' => 'ስፓንሽኛ (ላቲን አሜሪካ)',
        'es_AR' => 'ስፓንሽኛ (አርጀንቲና)',
        'es_BO' => 'ስፓንሽኛ (ቦሊቪያ)',
        'es_BR' => 'ስፓንሽኛ (ብራዚል)',
        'es_BZ' => 'ስፓንሽኛ (በሊዝ)',
        'es_CL' => 'ስፓንሽኛ (ቺሊ)',
        'es_CO' => 'ስፓንሽኛ (ኮሎምቢያ)',
        'es_CR' => 'ስፓንሽኛ (ኮስታሪካ)',
        'es_CU' => 'ስፓንሽኛ (ኩባ)',
        'es_DO' => 'ስፓንሽኛ (ዶመኒካን ሪፑብሊክ)',
        'es_EC' => 'ስፓንሽኛ (ኢኳዶር)',
        'es_ES' => 'ስፓንሽኛ (ስፔን)',
        'es_GQ' => 'ስፓንሽኛ (ኢኳቶሪያል ጊኒ)',
        'es_GT' => 'ስፓንሽኛ (ጉዋቲማላ)',
        'es_HN' => 'ስፓንሽኛ (ሆንዱራስ)',
        'es_MX' => 'ስፓንሽኛ (ሜክሲኮ)',
        'es_NI' => 'ስፓንሽኛ (ኒካራጓ)',
        'es_PA' => 'ስፓንሽኛ (ፓናማ)',
        'es_PE' => 'ስፓንሽኛ (ፔሩ)',
        'es_PH' => 'ስፓንሽኛ (ፊሊፒንስ)',
        'es_PR' => 'ስፓንሽኛ (ፖርታ ሪኮ)',
        'es_PY' => 'ስፓንሽኛ (ፓራጓይ)',
        'es_SV' => 'ስፓንሽኛ (ኤል ሳልቫዶር)',
        'es_US' => 'ስፓንሽኛ (ዩናይትድ ስቴትስ)',
        'es_UY' => 'ስፓንሽኛ (ኡራጓይ)',
        'es_VE' => 'ስፓንሽኛ (ቬንዙዌላ)',
        'et' => 'ኢስቶኒያንኛ',
        'et_EE' => 'ኢስቶኒያንኛ (ኤስቶኒያ)',
        'eu' => 'ባስክኛ',
        'eu_ES' => 'ባስክኛ (ስፔን)',
        'fa' => 'ፐርሺያኛ',
        'fa_AF' => 'ፐርሺያኛ (አፍጋኒስታን)',
        'fa_IR' => 'ፐርሺያኛ (ኢራን)',
        'ff' => 'ፉላህ',
        'ff_Adlm' => 'ፉላህ (አድላም)',
        'ff_Adlm_BF' => 'ፉላህ (አድላም፣ቡርኪና ፋሶ)',
        'ff_Adlm_CM' => 'ፉላህ (አድላም፣ካሜሩን)',
        'ff_Adlm_GH' => 'ፉላህ (አድላም፣ጋና)',
        'ff_Adlm_GM' => 'ፉላህ (አድላም፣ጋምቢያ)',
        'ff_Adlm_GN' => 'ፉላህ (አድላም፣ጊኒ)',
        'ff_Adlm_GW' => 'ፉላህ (አድላም፣ጊኒ ቢሳኦ)',
        'ff_Adlm_LR' => 'ፉላህ (አድላም፣ላይቤሪያ)',
        'ff_Adlm_MR' => 'ፉላህ (አድላም፣ሞሪቴኒያ)',
        'ff_Adlm_NE' => 'ፉላህ (አድላም፣ኒጀር)',
        'ff_Adlm_NG' => 'ፉላህ (አድላም፣ናይጄሪያ)',
        'ff_Adlm_SL' => 'ፉላህ (አድላም፣ሴራሊዮን)',
        'ff_Adlm_SN' => 'ፉላህ (አድላም፣ሴኔጋል)',
        'ff_CM' => 'ፉላህ (ካሜሩን)',
        'ff_GN' => 'ፉላህ (ጊኒ)',
        'ff_Latn' => 'ፉላህ (ላቲን)',
        'ff_Latn_BF' => 'ፉላህ (ላቲን፣ቡርኪና ፋሶ)',
        'ff_Latn_CM' => 'ፉላህ (ላቲን፣ካሜሩን)',
        'ff_Latn_GH' => 'ፉላህ (ላቲን፣ጋና)',
        'ff_Latn_GM' => 'ፉላህ (ላቲን፣ጋምቢያ)',
        'ff_Latn_GN' => 'ፉላህ (ላቲን፣ጊኒ)',
        'ff_Latn_GW' => 'ፉላህ (ላቲን፣ጊኒ ቢሳኦ)',
        'ff_Latn_LR' => 'ፉላህ (ላቲን፣ላይቤሪያ)',
        'ff_Latn_MR' => 'ፉላህ (ላቲን፣ሞሪቴኒያ)',
        'ff_Latn_NE' => 'ፉላህ (ላቲን፣ኒጀር)',
        'ff_Latn_NG' => 'ፉላህ (ላቲን፣ናይጄሪያ)',
        'ff_Latn_SL' => 'ፉላህ (ላቲን፣ሴራሊዮን)',
        'ff_Latn_SN' => 'ፉላህ (ላቲን፣ሴኔጋል)',
        'ff_MR' => 'ፉላህ (ሞሪቴኒያ)',
        'ff_SN' => 'ፉላህ (ሴኔጋል)',
        'fi' => 'ፊኒሽ',
        'fi_FI' => 'ፊኒሽ (ፊንላንድ)',
        'fo' => 'ፋሮኛ',
        'fo_DK' => 'ፋሮኛ (ዴንማርክ)',
        'fo_FO' => 'ፋሮኛ (የፋሮ ደሴቶች)',
        'fr' => 'ፈረንሳይኛ',
        'fr_BE' => 'ፈረንሳይኛ (ቤልጄም)',
        'fr_BF' => 'ፈረንሳይኛ (ቡርኪና ፋሶ)',
        'fr_BI' => 'ፈረንሳይኛ (ብሩንዲ)',
        'fr_BJ' => 'ፈረንሳይኛ (ቤኒን)',
        'fr_BL' => 'ፈረንሳይኛ (ቅዱስ በርቴሎሜ)',
        'fr_CA' => 'ፈረንሳይኛ (ካናዳ)',
        'fr_CD' => 'ፈረንሳይኛ (ኮንጎ-ኪንሻሳ)',
        'fr_CF' => 'ፈረንሳይኛ (ማዕከላዊ አፍሪካ ሪፑብሊክ)',
        'fr_CG' => 'ፈረንሳይኛ (ኮንጎ ብራዛቪል)',
        'fr_CH' => 'ፈረንሳይኛ (ስዊዘርላንድ)',
        'fr_CI' => 'ፈረንሳይኛ (ኮት ዲቯር)',
        'fr_CM' => 'ፈረንሳይኛ (ካሜሩን)',
        'fr_DJ' => 'ፈረንሳይኛ (ጂቡቲ)',
        'fr_DZ' => 'ፈረንሳይኛ (አልጄሪያ)',
        'fr_FR' => 'ፈረንሳይኛ (ፈረንሳይ)',
        'fr_GA' => 'ፈረንሳይኛ (ጋቦን)',
        'fr_GF' => 'ፈረንሳይኛ (የፈረንሳይ ጉዊአና)',
        'fr_GN' => 'ፈረንሳይኛ (ጊኒ)',
        'fr_GP' => 'ፈረንሳይኛ (ጉዋደሉፕ)',
        'fr_GQ' => 'ፈረንሳይኛ (ኢኳቶሪያል ጊኒ)',
        'fr_HT' => 'ፈረንሳይኛ (ሀይቲ)',
        'fr_KM' => 'ፈረንሳይኛ (ኮሞሮስ)',
        'fr_LU' => 'ፈረንሳይኛ (ሉክሰምበርግ)',
        'fr_MA' => 'ፈረንሳይኛ (ሞሮኮ)',
        'fr_MC' => 'ፈረንሳይኛ (ሞናኮ)',
        'fr_MF' => 'ፈረንሳይኛ (ሴንት ማርቲን)',
        'fr_MG' => 'ፈረንሳይኛ (ማዳጋስካር)',
        'fr_ML' => 'ፈረንሳይኛ (ማሊ)',
        'fr_MQ' => 'ፈረንሳይኛ (ማርቲኒክ)',
        'fr_MR' => 'ፈረንሳይኛ (ሞሪቴኒያ)',
        'fr_MU' => 'ፈረንሳይኛ (ሞሪሸስ)',
        'fr_NC' => 'ፈረንሳይኛ (ኒው ካሌዶኒያ)',
        'fr_NE' => 'ፈረንሳይኛ (ኒጀር)',
        'fr_PF' => 'ፈረንሳይኛ (የፈረንሳይ ፖሊኔዢያ)',
        'fr_PM' => 'ፈረንሳይኛ (ቅዱስ ፒዬር እና ሚኩኤሎን)',
        'fr_RE' => 'ፈረንሳይኛ (ሪዩኒየን)',
        'fr_RW' => 'ፈረንሳይኛ (ሩዋንዳ)',
        'fr_SC' => 'ፈረንሳይኛ (ሲሼልስ)',
        'fr_SN' => 'ፈረንሳይኛ (ሴኔጋል)',
        'fr_SY' => 'ፈረንሳይኛ (ሲሪያ)',
        'fr_TD' => 'ፈረንሳይኛ (ቻድ)',
        'fr_TG' => 'ፈረንሳይኛ (ቶጐ)',
        'fr_TN' => 'ፈረንሳይኛ (ቱኒዚያ)',
        'fr_VU' => 'ፈረንሳይኛ (ቫኑአቱ)',
        'fr_WF' => 'ፈረንሳይኛ (ዋሊስ እና ፉቱና ደሴቶች)',
        'fr_YT' => 'ፈረንሳይኛ (ሜይኦቴ)',
        'fy' => 'ምዕራባዊ ፍሪሲኛ',
        'fy_NL' => 'ምዕራባዊ ፍሪሲኛ (ኔዘርላንድ)',
        'ga' => 'አይሪሽ',
        'ga_GB' => 'አይሪሽ (ዩናይትድ ኪንግደም)',
        'ga_IE' => 'አይሪሽ (አየርላንድ)',
        'gd' => 'የስኮቲሽ ጌልክኛ',
        'gd_GB' => 'የስኮቲሽ ጌልክኛ (ዩናይትድ ኪንግደም)',
        'gl' => 'ጋሊሺያ',
        'gl_ES' => 'ጋሊሺያ (ስፔን)',
        'gu' => 'ጉጃርቲኛ',
        'gu_IN' => 'ጉጃርቲኛ (ህንድ)',
        'gv' => 'ማንክስኛ',
        'gv_IM' => 'ማንክስኛ (አይል ኦፍ ማን)',
        'ha' => 'ሃውሳኛ',
        'ha_GH' => 'ሃውሳኛ (ጋና)',
        'ha_NE' => 'ሃውሳኛ (ኒጀር)',
        'ha_NG' => 'ሃውሳኛ (ናይጄሪያ)',
        'he' => 'ዕብራይስጥ﻿',
        'he_IL' => 'ዕብራይስጥ﻿ (እስራኤል)',
        'hi' => 'ሒንዱኛ',
        'hi_IN' => 'ሒንዱኛ (ህንድ)',
        'hi_Latn' => 'ሒንዱኛ (ላቲን)',
        'hi_Latn_IN' => 'ሒንዱኛ (ላቲን፣ህንድ)',
        'hr' => 'ክሮሽያንኛ',
        'hr_BA' => 'ክሮሽያንኛ (ቦስኒያ እና ሄርዞጎቪኒያ)',
        'hr_HR' => 'ክሮሽያንኛ (ክሮኤሽያ)',
        'hu' => 'ሀንጋሪኛ',
        'hu_HU' => 'ሀንጋሪኛ (ሀንጋሪ)',
        'hy' => 'አርመናዊ',
        'hy_AM' => 'አርመናዊ (አርሜኒያ)',
        'ia' => 'ኢንቴርሊንጓ',
        'ia_001' => 'ኢንቴርሊንጓ (ዓለም)',
        'id' => 'ኢንዶኔዥኛ',
        'id_ID' => 'ኢንዶኔዥኛ (ኢንዶኔዢያ)',
        'ig' => 'ኢግቦኛ',
        'ig_NG' => 'ኢግቦኛ (ናይጄሪያ)',
        'ii' => 'ሲቹንዪኛ',
        'ii_CN' => 'ሲቹንዪኛ (ቻይና)',
        'is' => 'አይስላንድኛ',
        'is_IS' => 'አይስላንድኛ (አይስላንድ)',
        'it' => 'ጣሊያንኛ',
        'it_CH' => 'ጣሊያንኛ (ስዊዘርላንድ)',
        'it_IT' => 'ጣሊያንኛ (ጣሊያን)',
        'it_SM' => 'ጣሊያንኛ (ሳን ማሪኖ)',
        'it_VA' => 'ጣሊያንኛ (ቫቲካን ከተማ)',
        'ja' => 'ጃፓንኛ',
        'ja_JP' => 'ጃፓንኛ (ጃፓን)',
        'jv' => 'ጃቫንኛ',
        'jv_ID' => 'ጃቫንኛ (ኢንዶኔዢያ)',
        'ka' => 'ጆርጂያን',
        'ka_GE' => 'ጆርጂያን (ጆርጂያ)',
        'ki' => 'ኪኩዩ',
        'ki_KE' => 'ኪኩዩ (ኬንያ)',
        'kk' => 'ካዛክኛ',
        'kk_KZ' => 'ካዛክኛ (ካዛኪስታን)',
        'kl' => 'ካላሊሱትኛ',
        'kl_GL' => 'ካላሊሱትኛ (ግሪንላንድ)',
        'km' => 'ክህመርኛ',
        'km_KH' => 'ክህመርኛ (ካምቦዲያ)',
        'kn' => 'ካናዳኛ',
        'kn_IN' => 'ካናዳኛ (ህንድ)',
        'ko' => 'ኮሪያኛ',
        'ko_KP' => 'ኮሪያኛ (ሰሜን ኮሪያ)',
        'ko_KR' => 'ኮሪያኛ (ደቡብ ኮሪያ)',
        'ks' => 'ካሽሚርኛ',
        'ks_Arab' => 'ካሽሚርኛ (ዓረብኛ)',
        'ks_Arab_IN' => 'ካሽሚርኛ (ዓረብኛ፣ህንድ)',
        'ks_Deva' => 'ካሽሚርኛ (ደቫንጋሪ)',
        'ks_Deva_IN' => 'ካሽሚርኛ (ደቫንጋሪ፣ህንድ)',
        'ks_IN' => 'ካሽሚርኛ (ህንድ)',
        'ku' => 'ኩርድሽኛ',
        'ku_TR' => 'ኩርድሽኛ (ቱርክ)',
        'kw' => 'ኮርኒሽ',
        'kw_GB' => 'ኮርኒሽ (ዩናይትድ ኪንግደም)',
        'ky' => 'ኪርጊዝኛ',
        'ky_KG' => 'ኪርጊዝኛ (ኪርጊስታን)',
        'lb' => 'ሉክዘምበርኛ',
        'lb_LU' => 'ሉክዘምበርኛ (ሉክሰምበርግ)',
        'lg' => 'ጋንዳኛ',
        'lg_UG' => 'ጋንዳኛ (ዩጋንዳ)',
        'ln' => 'ሊንጋላኛ',
        'ln_AO' => 'ሊንጋላኛ (አንጐላ)',
        'ln_CD' => 'ሊንጋላኛ (ኮንጎ-ኪንሻሳ)',
        'ln_CF' => 'ሊንጋላኛ (ማዕከላዊ አፍሪካ ሪፑብሊክ)',
        'ln_CG' => 'ሊንጋላኛ (ኮንጎ ብራዛቪል)',
        'lo' => 'ላኦኛ',
        'lo_LA' => 'ላኦኛ (ላኦስ)',
        'lt' => 'ሉቴንያንኛ',
        'lt_LT' => 'ሉቴንያንኛ (ሊቱዌኒያ)',
        'lu' => 'ሉባ ካታንጋ',
        'lu_CD' => 'ሉባ ካታንጋ (ኮንጎ-ኪንሻሳ)',
        'lv' => 'ላትቪያን',
        'lv_LV' => 'ላትቪያን (ላትቪያ)',
        'mg' => 'ማላጋስኛ',
        'mg_MG' => 'ማላጋስኛ (ማዳጋስካር)',
        'mi' => 'ማኦሪኛ',
        'mi_NZ' => 'ማኦሪኛ (ኒው ዚላንድ)',
        'mk' => 'ማሴዶንኛ',
        'mk_MK' => 'ማሴዶንኛ (ሰሜን መቄዶንያ)',
        'ml' => 'ማላያላምኛ',
        'ml_IN' => 'ማላያላምኛ (ህንድ)',
        'mn' => 'ሞንጎሊያኛ',
        'mn_MN' => 'ሞንጎሊያኛ (ሞንጎሊያ)',
        'mr' => 'ማራቲኛ',
        'mr_IN' => 'ማራቲኛ (ህንድ)',
        'ms' => 'ማላይኛ',
        'ms_BN' => 'ማላይኛ (ብሩኒ)',
        'ms_ID' => 'ማላይኛ (ኢንዶኔዢያ)',
        'ms_MY' => 'ማላይኛ (ማሌዢያ)',
        'ms_SG' => 'ማላይኛ (ሲንጋፖር)',
        'mt' => 'ማልቲስኛ',
        'mt_MT' => 'ማልቲስኛ (ማልታ)',
        'my' => 'ቡርማኛ',
        'my_MM' => 'ቡርማኛ (ማይናማር[በርማ])',
        'nb' => 'የኖርዌይ ቦክማል',
        'nb_NO' => 'የኖርዌይ ቦክማል (ኖርዌይ)',
        'nb_SJ' => 'የኖርዌይ ቦክማል (ስቫልባርድ እና ጃን ማየን)',
        'nd' => 'ሰሜን ንዴብሌ',
        'nd_ZW' => 'ሰሜን ንዴብሌ (ዚምቧቤ)',
        'ne' => 'ኔፓሊኛ',
        'ne_IN' => 'ኔፓሊኛ (ህንድ)',
        'ne_NP' => 'ኔፓሊኛ (ኔፓል)',
        'nl' => 'ደች',
        'nl_AW' => 'ደች (አሩባ)',
        'nl_BE' => 'ደች (ቤልጄም)',
        'nl_BQ' => 'ደች (የካሪቢያን ኔዘርላንድስ)',
        'nl_CW' => 'ደች (ኩራሳዎ)',
        'nl_NL' => 'ደች (ኔዘርላንድ)',
        'nl_SR' => 'ደች (ሱሪናም)',
        'nl_SX' => 'ደች (ሲንት ማርተን)',
        'nn' => 'የኖርዌይ ናይኖርስክ',
        'nn_NO' => 'የኖርዌይ ናይኖርስክ (ኖርዌይ)',
        'no' => 'ኖርዌጂያን',
        'no_NO' => 'ኖርዌጂያን (ኖርዌይ)',
        'om' => 'ኦሮሞኛ',
        'om_ET' => 'ኦሮሞኛ (ኢትዮጵያ)',
        'om_KE' => 'ኦሮሞኛ (ኬንያ)',
        'or' => 'ኦዲያኛ',
        'or_IN' => 'ኦዲያኛ (ህንድ)',
        'os' => 'ኦሴቲክ',
        'os_GE' => 'ኦሴቲክ (ጆርጂያ)',
        'os_RU' => 'ኦሴቲክ (ሩስያ)',
        'pa' => 'ፑንጃብኛ',
        'pa_Arab' => 'ፑንጃብኛ (ዓረብኛ)',
        'pa_Arab_PK' => 'ፑንጃብኛ (ዓረብኛ፣ፓኪስታን)',
        'pa_Guru' => 'ፑንጃብኛ (ጉርሙኪ)',
        'pa_Guru_IN' => 'ፑንጃብኛ (ጉርሙኪ፣ህንድ)',
        'pa_IN' => 'ፑንጃብኛ (ህንድ)',
        'pa_PK' => 'ፑንጃብኛ (ፓኪስታን)',
        'pl' => 'ፖሊሽኛ',
        'pl_PL' => 'ፖሊሽኛ (ፖላንድ)',
        'ps' => 'ፓሽቶኛ',
        'ps_AF' => 'ፓሽቶኛ (አፍጋኒስታን)',
        'ps_PK' => 'ፓሽቶኛ (ፓኪስታን)',
        'pt' => 'ፖርቹጋልኛ',
        'pt_AO' => 'ፖርቹጋልኛ (አንጐላ)',
        'pt_BR' => 'ፖርቹጋልኛ (ብራዚል)',
        'pt_CH' => 'ፖርቹጋልኛ (ስዊዘርላንድ)',
        'pt_CV' => 'ፖርቹጋልኛ (ኬፕ ቬርዴ)',
        'pt_GQ' => 'ፖርቹጋልኛ (ኢኳቶሪያል ጊኒ)',
        'pt_GW' => 'ፖርቹጋልኛ (ጊኒ ቢሳኦ)',
        'pt_LU' => 'ፖርቹጋልኛ (ሉክሰምበርግ)',
        'pt_MO' => 'ፖርቹጋልኛ (ማካኦ ልዩ የአስተዳደር ክልል ቻይና)',
        'pt_MZ' => 'ፖርቹጋልኛ (ሞዛምቢክ)',
        'pt_PT' => 'ፖርቹጋልኛ (ፖርቱጋል)',
        'pt_ST' => 'ፖርቹጋልኛ (ሳኦ ቶሜ እና ፕሪንሲፔ)',
        'pt_TL' => 'ፖርቹጋልኛ (ቲሞር ሌስቴ)',
        'qu' => 'ኵቿኛ',
        'qu_BO' => 'ኵቿኛ (ቦሊቪያ)',
        'qu_EC' => 'ኵቿኛ (ኢኳዶር)',
        'qu_PE' => 'ኵቿኛ (ፔሩ)',
        'rm' => 'ሮማንሽ',
        'rm_CH' => 'ሮማንሽ (ስዊዘርላንድ)',
        'rn' => 'ሩንዲኛ',
        'rn_BI' => 'ሩንዲኛ (ብሩንዲ)',
        'ro' => 'ሮማኒያን',
        'ro_MD' => 'ሮማኒያን (ሞልዶቫ)',
        'ro_RO' => 'ሮማኒያን (ሮሜኒያ)',
        'ru' => 'ራሽያኛ',
        'ru_BY' => 'ራሽያኛ (ቤላሩስ)',
        'ru_KG' => 'ራሽያኛ (ኪርጊስታን)',
        'ru_KZ' => 'ራሽያኛ (ካዛኪስታን)',
        'ru_MD' => 'ራሽያኛ (ሞልዶቫ)',
        'ru_RU' => 'ራሽያኛ (ሩስያ)',
        'ru_UA' => 'ራሽያኛ (ዩክሬን)',
        'rw' => 'ኪንያርዋንድኛ',
        'rw_RW' => 'ኪንያርዋንድኛ (ሩዋንዳ)',
        'sa' => 'ሳንስክሪትኛ',
        'sa_IN' => 'ሳንስክሪትኛ (ህንድ)',
        'sc' => 'ሳርዲንያንኛ',
        'sc_IT' => 'ሳርዲንያንኛ (ጣሊያን)',
        'sd' => 'ሲንድሂኛ',
        'sd_Arab' => 'ሲንድሂኛ (ዓረብኛ)',
        'sd_Arab_PK' => 'ሲንድሂኛ (ዓረብኛ፣ፓኪስታን)',
        'sd_Deva' => 'ሲንድሂኛ (ደቫንጋሪ)',
        'sd_Deva_IN' => 'ሲንድሂኛ (ደቫንጋሪ፣ህንድ)',
        'sd_IN' => 'ሲንድሂኛ (ህንድ)',
        'sd_PK' => 'ሲንድሂኛ (ፓኪስታን)',
        'se' => 'ሰሜናዊ ሳሚ',
        'se_FI' => 'ሰሜናዊ ሳሚ (ፊንላንድ)',
        'se_NO' => 'ሰሜናዊ ሳሚ (ኖርዌይ)',
        'se_SE' => 'ሰሜናዊ ሳሚ (ስዊድን)',
        'sg' => 'ሳንጎኛ',
        'sg_CF' => 'ሳንጎኛ (ማዕከላዊ አፍሪካ ሪፑብሊክ)',
        'sh' => 'ሰርቦ-ክሮኤሽያኛ',
        'sh_BA' => 'ሰርቦ-ክሮኤሽያኛ (ቦስኒያ እና ሄርዞጎቪኒያ)',
        'si' => 'ሲንሃልኛ',
        'si_LK' => 'ሲንሃልኛ (ሲሪላንካ)',
        'sk' => 'ስሎቫክኛ',
        'sk_SK' => 'ስሎቫክኛ (ስሎቫኪያ)',
        'sl' => 'ስሎቪኛ',
        'sl_SI' => 'ስሎቪኛ (ስሎቬኒያ)',
        'sn' => 'ሾናኛ',
        'sn_ZW' => 'ሾናኛ (ዚምቧቤ)',
        'so' => 'ሱማልኛ',
        'so_DJ' => 'ሱማልኛ (ጂቡቲ)',
        'so_ET' => 'ሱማልኛ (ኢትዮጵያ)',
        'so_KE' => 'ሱማልኛ (ኬንያ)',
        'so_SO' => 'ሱማልኛ (ሱማሌ)',
        'sq' => 'አልባንያንኛ',
        'sq_AL' => 'አልባንያንኛ (አልባኒያ)',
        'sq_MK' => 'አልባንያንኛ (ሰሜን መቄዶንያ)',
        'sr' => 'ሰርብያኛ',
        'sr_BA' => 'ሰርብያኛ (ቦስኒያ እና ሄርዞጎቪኒያ)',
        'sr_Cyrl' => 'ሰርብያኛ (ሲይሪልክ)',
        'sr_Cyrl_BA' => 'ሰርብያኛ (ሲይሪልክ፣ቦስኒያ እና ሄርዞጎቪኒያ)',
        'sr_Cyrl_ME' => 'ሰርብያኛ (ሲይሪልክ፣ሞንተኔግሮ)',
        'sr_Cyrl_RS' => 'ሰርብያኛ (ሲይሪልክ፣ሰርብያ)',
        'sr_Latn' => 'ሰርብያኛ (ላቲን)',
        'sr_Latn_BA' => 'ሰርብያኛ (ላቲን፣ቦስኒያ እና ሄርዞጎቪኒያ)',
        'sr_Latn_ME' => 'ሰርብያኛ (ላቲን፣ሞንተኔግሮ)',
        'sr_Latn_RS' => 'ሰርብያኛ (ላቲን፣ሰርብያ)',
        'sr_ME' => 'ሰርብያኛ (ሞንተኔግሮ)',
        'sr_RS' => 'ሰርብያኛ (ሰርብያ)',
        'su' => 'ሱዳንኛ',
        'su_ID' => 'ሱዳንኛ (ኢንዶኔዢያ)',
        'su_Latn' => 'ሱዳንኛ (ላቲን)',
        'su_Latn_ID' => 'ሱዳንኛ (ላቲን፣ኢንዶኔዢያ)',
        'sv' => 'ስዊድንኛ',
        'sv_AX' => 'ስዊድንኛ (የአላንድ ደሴቶች)',
        'sv_FI' => 'ስዊድንኛ (ፊንላንድ)',
        'sv_SE' => 'ስዊድንኛ (ስዊድን)',
        'sw' => 'ስዋሂሊኛ',
        'sw_CD' => 'ስዋሂሊኛ (ኮንጎ-ኪንሻሳ)',
        'sw_KE' => 'ስዋሂሊኛ (ኬንያ)',
        'sw_TZ' => 'ስዋሂሊኛ (ታንዛኒያ)',
        'sw_UG' => 'ስዋሂሊኛ (ዩጋንዳ)',
        'ta' => 'ታሚልኛ',
        'ta_IN' => 'ታሚልኛ (ህንድ)',
        'ta_LK' => 'ታሚልኛ (ሲሪላንካ)',
        'ta_MY' => 'ታሚልኛ (ማሌዢያ)',
        'ta_SG' => 'ታሚልኛ (ሲንጋፖር)',
        'te' => 'ተሉጉኛ',
        'te_IN' => 'ተሉጉኛ (ህንድ)',
        'tg' => 'ታጂኪኛ',
        'tg_TJ' => 'ታጂኪኛ (ታጃኪስታን)',
        'th' => 'ታይኛ',
        'th_TH' => 'ታይኛ (ታይላንድ)',
        'ti' => 'ትግርኛ',
        'ti_ER' => 'ትግርኛ (ኤርትራ)',
        'ti_ET' => 'ትግርኛ (ኢትዮጵያ)',
        'tk' => 'ቱርክሜንኛ',
        'tk_TM' => 'ቱርክሜንኛ (ቱርክሜኒስታን)',
        'tl' => 'ታጋሎገኛ',
        'tl_PH' => 'ታጋሎገኛ (ፊሊፒንስ)',
        'to' => 'ቶንጋኛ',
        'to_TO' => 'ቶንጋኛ (ቶንጋ)',
        'tr' => 'ቱርክኛ',
        'tr_CY' => 'ቱርክኛ (ሳይፕረስ)',
        'tr_TR' => 'ቱርክኛ (ቱርክ)',
        'tt' => 'ታታርኛ',
        'tt_RU' => 'ታታርኛ (ሩስያ)',
        'ug' => 'ኡዊግሁርኛ',
        'ug_CN' => 'ኡዊግሁርኛ (ቻይና)',
        'uk' => 'ዩክሬንኛ',
        'uk_UA' => 'ዩክሬንኛ (ዩክሬን)',
        'ur' => 'ኡርዱኛ',
        'ur_IN' => 'ኡርዱኛ (ህንድ)',
        'ur_PK' => 'ኡርዱኛ (ፓኪስታን)',
        'uz' => 'ኡዝቤክኛ',
        'uz_AF' => 'ኡዝቤክኛ (አፍጋኒስታን)',
        'uz_Arab' => 'ኡዝቤክኛ (ዓረብኛ)',
        'uz_Arab_AF' => 'ኡዝቤክኛ (ዓረብኛ፣አፍጋኒስታን)',
        'uz_Cyrl' => 'ኡዝቤክኛ (ሲይሪልክ)',
        'uz_Cyrl_UZ' => 'ኡዝቤክኛ (ሲይሪልክ፣ኡዝቤኪስታን)',
        'uz_Latn' => 'ኡዝቤክኛ (ላቲን)',
        'uz_Latn_UZ' => 'ኡዝቤክኛ (ላቲን፣ኡዝቤኪስታን)',
        'uz_UZ' => 'ኡዝቤክኛ (ኡዝቤኪስታን)',
        'vi' => 'ቪየትናምኛ',
        'vi_VN' => 'ቪየትናምኛ (ቬትናም)',
        'wo' => 'ዎሎፍኛ',
        'wo_SN' => 'ዎሎፍኛ (ሴኔጋል)',
        'xh' => 'ዞሳኛ',
        'xh_ZA' => 'ዞሳኛ (ደቡብ አፍሪካ)',
        'yi' => 'ይዲሽኛ',
        'yi_001' => 'ይዲሽኛ (ዓለም)',
        'yo' => 'ዮሩባዊኛ',
        'yo_BJ' => 'ዮሩባዊኛ (ቤኒን)',
        'yo_NG' => 'ዮሩባዊኛ (ናይጄሪያ)',
        'zh' => 'ቻይንኛ',
        'zh_CN' => 'ቻይንኛ (ቻይና)',
        'zh_HK' => 'ቻይንኛ (ሆንግ ኮንግ ልዩ የአስተዳደር ክልል ቻይና)',
        'zh_Hans' => 'ቻይንኛ (ቀለል ያለ)',
        'zh_Hans_CN' => 'ቻይንኛ (ቀለል ያለ፣ቻይና)',
        'zh_Hans_HK' => 'ቻይንኛ (ቀለል ያለ፣ሆንግ ኮንግ ልዩ የአስተዳደር ክልል ቻይና)',
        'zh_Hans_MO' => 'ቻይንኛ (ቀለል ያለ፣ማካኦ ልዩ የአስተዳደር ክልል ቻይና)',
        'zh_Hans_SG' => 'ቻይንኛ (ቀለል ያለ፣ሲንጋፖር)',
        'zh_Hant' => 'ቻይንኛ (ባህላዊ)',
        'zh_Hant_HK' => 'ቻይንኛ (ባህላዊ፣ሆንግ ኮንግ ልዩ የአስተዳደር ክልል ቻይና)',
        'zh_Hant_MO' => 'ቻይንኛ (ባህላዊ፣ማካኦ ልዩ የአስተዳደር ክልል ቻይና)',
        'zh_Hant_TW' => 'ቻይንኛ (ባህላዊ፣ታይዋን)',
        'zh_MO' => 'ቻይንኛ (ማካኦ ልዩ የአስተዳደር ክልል ቻይና)',
        'zh_SG' => 'ቻይንኛ (ሲንጋፖር)',
        'zh_TW' => 'ቻይንኛ (ታይዋን)',
        'zu' => 'ዙሉኛ',
        'zu_ZA' => 'ዙሉኛ (ደቡብ አፍሪካ)',
    ],
];
