<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Ego Dirham obodo United Arab Emirates',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Ego Afghani Obodo Afghanistan',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Ego Lek Obodo Albania',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Ego Dram obodo Armenia',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Ego Antillean Guilder obodo Netherlands',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Ego Kwanza obodo Angola',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Ego Peso obodo Argentina',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Ego Dollar obodo Australia',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Ego Florin obodo Aruba',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Ego Manat obodo Azerbaijan',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Akara mgbanwe ego obodo Bosnia-Herzegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Ego Dollar obodo Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Ego Taka obodo Bangladesh',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Ego Lev mba Bulgaria',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Ego Dinar Obodo Bahrain',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Ego Franc obodo Burundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dollar Bermuda',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Ego Dollar obodo Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Ego Boliviano obodo Bolivia',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Real Brazil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Ego Dollar Obodo Bahamas',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ego Ngultrum obodo Bhutan',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ego Pula obodo Bostwana',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Ego Ruble mba Belarus',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dollar Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dollar Canada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Ego Franc obodo Congo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Ego Franc mba Switzerland',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Ego Peso obodo Chile',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Ego Yuan Obodo China (ndị bi na mmiri)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan China',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Ego Peso obodo Columbia',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Ego Colón obodo Costa Rica',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Ego Peso e nwere ike ịgbanwe nke obodo Cuba',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Ego Peso obodo Cuba',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo Caboverdiano',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Ego Koruna obodo Czech',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Ego Franc obodo Djibouti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Ego Krone Obodo Denmark',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Ego Peso Obodo Dominica',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Ego Dinar Obodo Algeria',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Ego Pound obodo Egypt',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Ego Nakfa obodo Eritrea',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ego Birr obodo Ethiopia',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Ego Dollar obodo Fiji',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Ego Pound obodo Falkland Islands',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Pound British',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Ego Lari Obodo Georgia',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ego Cedi obodo Ghana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Ego Pound obodo Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Ego Dalasi obodo Gambia',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Ego Franc obodo Guinea',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Ego Quetzal obodo Guatemala',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Ego Dollar obodo Guyana',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Ego Dollar Obodo Honk Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Ego Lempira obodo Honduras',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Ego Kuna obodo Croatia',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Ego Gourde obodo Haiti',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Ego Forint obodo Hungary',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Ego Rupiah Obodo Indonesia',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Ego Shekel ọhụrụ obodo Israel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupee India',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Ego Dinar obodo Iraq',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Ego Rial obodo Iran',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Ego Króna obodo Iceland',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ego Dollar obodo Jamaica',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Ego Dinar Obodo Jordan',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Yen Japan',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Ego Shilling obodo Kenya',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Ego Som Obodo Kyrgyzstan',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Ego Riel obodo Cambodia',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Ego Franc obodo Comoros',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Ego Won Obodo North Korea',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Ego Won Obodo South Korea',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Ego Dinar Obodo Kuwait',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Ego Dollar obodo Cayman Islands',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Ego Tenge obodo Kazakhstani',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Ego Kip Obodo Laos',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Ego Pound obodo Lebanon',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Ego Rupee obodo Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Ego Dollar obodo Liberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Ego loti obodo Lesotho',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Ego Dinar obodo Libya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Ego Dirham obodo Morocco',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Ego Leu obodo Moldova',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ego Ariary obodo Madagascar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Ego Denar Obodo Macedonia',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Ego Kyat obodo Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Ego Turgik Obodo Mongolia',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Ego Pataca ndị Obodo Macanese',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ego Ouguiya Obodo Mauritania',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Ego Rupee obodo Mauritania',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Ego Rufiyaa obodo Moldova',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Ego Kwacha obodo Malawi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Ego Peso obodo Mexico',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ego Ringgit obodo Malaysia',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Ego Metical obodo Mozambique',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Ego Dollar obodo Namibia',
        ],
        'NGN' => [
            0 => '₦',
            1 => 'Naịra',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Ego Córodoba obodo Nicaragua',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Ego Krone Obodo Norway',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Ego Rupee obodo Nepal',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Ego Dollar obodo New Zealand',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Ego Rial obodo Oman',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Ego Balboa obodo Panama',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Ego Sol obodo Peru',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Ego Kina obodo Papua New Guinea',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'Ego piso obodo Philippine',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Ego Rupee obodo Pakistan',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Ego Zloty mba Poland',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Ego Guarani obodo Paraguay',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Ego Rial obodo Qatar',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Ego Leu obodo Romania',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Ego Dinar obodo Serbia',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Ruble Russia',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ego Franc obodo Rwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Ego Riyal obodo Saudi',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Ego Dollar obodo Solomon Islands',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Ego Rupee obodo Seychelles',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Ego Pound obodo Sudan',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Ego Krona Obodo Sweden',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Ego Dollar obodo Singapore',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Ego Pound obodo St Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Ego Leone obodo Sierra Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Ego shilling obodo Somali',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dollar Surinamese',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Ego Pound obodo South Sudan',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Ego Dobra nke obodo Sāo Tomé na Principe',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Ego Pound obodo Syria',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Ego Lilangeni obodo Swaziland',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Ego Baht obodo Thai',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Who Somoni obodo Tajikistan',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Ego Manat Obodo Turkmenistan',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Ego Dinar Obodo Tunisia',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Ego paʻanga obodo Tonga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Ego Lira obodo Turkey',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dollar Trinidad & Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dollar obodo New Taiwan',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Ego Shilling Obodo Tanzania',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ego Hryvnia obodo Ukraine',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ego Shilling obodo Uganda',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dollar US',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Ego Peso obodo Uruguay',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Ego Som obodo Uzbekistan',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Ego Bolivar obodo Venezuela',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Ego Dong obodo Vietnam',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Ego Vatu obodo Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Ego Tala obodo Samoa',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Ego Franc mba etiti Africa',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Ego Dollar obodo East Carribbean',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Ego CFA Franc obodo West Africa',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Ego Franc obodo CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Ego Rial obodo Yemeni',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Ego Rand obodo South Africa',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Ego Kwacha Obodo Zambia',
        ],
    ],
];
