<?php

return [
    'Names' => [
        'alt' => 'Kialtai cha Kusini',
        'arq' => 'Kiarabu cha Aljeria',
        'atj' => 'Kiatikameku',
        'az' => 'Kiazabaijani',
        'ban' => 'Kibalini',
        'bho' => 'Kibojpuri',
        'bn' => 'Kibangla',
        'ce' => 'Kichechen',
        'ceb' => 'Kisebuano',
        'ch' => 'Kichamoro',
        'chk' => 'Kichuuki',
        'chr' => 'Kicheroki',
        'ckb' => 'Kikurdi cha Kati',
        'clc' => 'Kichilkotini',
        'crg' => 'Kimichif',
        'crk' => 'Kikrii cha Chini',
        'crm' => 'Kimoosekrii',
        'crr' => 'Kialgiki cha Carolina',
        'csw' => 'Kikrii cha Kinamasi',
        'cu' => 'Kislovakia cha Kanisa la Jadi',
        'cy' => 'Kiwels',
        'dje' => 'Kizama',
        'ff' => 'Kifula',
        'fo' => 'Kifaro',
        'frr' => 'Kifrisi cha Kaskazini',
        'fur' => 'Kifriuli',
        'fy' => 'Kifrisi cha Magharibi',
        'gaa' => 'Kiga',
        'gez' => 'Kigiiz',
        'gil' => 'Kigilbert',
        'grc' => 'Kigiriki cha Kale',
        'gv' => 'Kimaniksi',
        'gwi' => 'Kigwichʼin',
        'haw' => 'Kihawaii',
        'hr' => 'Kikroeshia',
        'hsb' => 'Kisorbia cha Juu',
        'ht' => 'Kikrioli cha Haiti',
        'hup' => 'Kihupa',
        'hur' => 'Kihalkomelem',
        'ia' => 'Lugha ya kimataifa',
        'ig' => 'Kiibo',
        'ii' => 'Kiiyi cha Sichuan',
        'ikt' => 'Kiinuktitut cha Kanada Magharibi',
        'ilo' => 'Kiiloko',
        'inh' => 'Kiingushi',
        'is' => 'Kiaisilandi',
        'jbo' => 'Kilojbani',
        'kac' => 'Kikachini',
        'kbd' => 'Kikabadi',
        'kea' => 'Kikabuvedi',
        'khq' => 'Kikoyrachiini',
        'kj' => 'Kikuanyama',
        'kk' => 'Kikazaki',
        'kkj' => 'Kikako',
        'km' => 'Kikhema',
        'koi' => 'Kikomipermyak',
        'kpe' => 'Kikpele',
        'krc' => 'Kikarachaybalka',
        'krl' => 'Kakareli',
        'kru' => 'Kikuruki',
        'ksb' => 'Kisambala',
        'ksh' => 'Kikolon',
        'kum' => 'Kikumyk',
        'kw' => 'Kikoni',
        'ky' => 'Kikirigizi',
        'lag' => 'Kilangi',
        'lam' => 'Kilamba',
        'lez' => 'Kilezighi',
        'li' => 'Kilimbugi',
        'luy' => 'Kiluyia',
        'mak' => 'Kimakasaa',
        'mas' => 'Kimasai',
        'mdf' => 'Kimoksha',
        'mfe' => 'Kimorisi',
        'mh' => 'Kimashali',
        'mic' => 'Kimi\'kmak',
        'mk' => 'Kimasedonia',
        'ml' => 'Kimalayalam',
        'moh' => 'Kimohok',
        'mos' => 'Kimosi',
        'mus' => 'Kimuskogii',
        'mwl' => 'Kimiranda',
        'my' => 'Kibama',
        'nds' => 'Kijerumani cha Chini',
        'nnh' => 'Kiingiemboon',
        'nqo' => 'Kiin’ko',
        'nr' => 'Kindebele cha Kusini',
        'oc' => 'Kiositia',
        'ojc' => 'Kiojibwa cha Kati',
        'or' => 'Kiodia',
        'pag' => 'Kipangasini',
        'pcm' => 'Kipijini cha Naijeria',
        'rm' => 'Kirumi',
        'rwk' => 'Kirwa',
        'sba' => 'Kingambei',
        'sc' => 'Kisadini',
        'scn' => 'Kisisilia',
        'ses' => 'Kikoyraborosenni',
        'shn' => 'Kishani',
        'shu' => 'Kiarabu cha Chadi',
        'slh' => 'Kilushootseed cha Kusini',
        'srn' => 'Kisranantongo',
        'st' => 'Kisotho cha Kusini',
        'str' => 'Kisali cha Straits',
        'su' => 'Kisundani',
        'swb' => 'Kikomoro',
        'syr' => 'Kisiria',
        'tce' => 'Kituchone cha Kusini',
        'tem' => 'Kitimne',
        'tgx' => 'Kitagi',
        'tht' => 'Kitahlti',
        'tn' => 'Kiswana',
        'tok' => 'Kitokipona',
        'ts' => 'Kisonga',
        'ttm' => 'Kituchone cha Kaskazini',
        'tw' => 'Kitwi',
        'tzm' => 'Kitamazight cha Atlas ya Kati',
        'udm' => 'Kiudumurti',
        'ug' => 'Kiuiguri',
        'uk' => 'Kiukreni',
        'umb' => 'Kiumbundu',
        'wa' => 'Kiwaluni',
        'wae' => 'Kiwalsa',
        'wal' => 'Kiwolaitta',
        'war' => 'Kiwarai',
        'wo' => 'Kiwolof',
        'xh' => 'Kikhosa',
        'yav' => 'Kiyangbeni',
        'yi' => 'Kiyidi',
        'zgh' => 'Kitamazight cha Kawaida cha Moroko',
    ],
    'LocalizedNames' => [
        'de_AT' => 'Kijerumani cha Austria',
        'de_CH' => 'Kijerumani cha Kawaida cha Uswisi',
        'en_AU' => 'Kiingereza cha Australia',
        'en_CA' => 'Kiingereza cha Kanada',
        'en_GB' => 'Kiingereza cha Uingereza',
        'en_US' => 'Kiingereza cha Marekani',
        'es_419' => 'Kihispania cha Amerika Kusini',
        'es_ES' => 'Kihispania cha Ulaya',
        'es_MX' => 'Kihispania cha Meksiko',
        'fa_AF' => 'Kidari',
        'fr_CA' => 'Kifaransa cha Kanada',
        'fr_CH' => 'Kifaransa cha Uswisi',
        'pt_BR' => 'Kireno cha Brazili',
        'pt_PT' => 'Kireno cha Ulaya',
        'sw_CD' => 'Kiswahili cha Kongo',
        'zh_Hans' => 'Kichina Kilichorahisishwa',
        'zh_Hant' => 'Kichina cha Kawaida',
    ],
];
