<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'توقيت غرينتش (أبيدجان)',
        'Africa/Accra' => 'توقيت غرينتش (أكرا)',
        'Africa/Addis_Ababa' => 'توقيت شرق أفريقيا (أديس أبابا)',
        'Africa/Algiers' => 'توقيت وسط أوروبا (الجزائر)',
        'Africa/Asmera' => 'توقيت شرق أفريقيا (أسمرة)',
        'Africa/Bamako' => 'توقيت غرينتش (باماكو)',
        'Africa/Bangui' => 'توقيت غرب أفريقيا (بانغوي)',
        'Africa/Banjul' => 'توقيت غرينتش (بانجول)',
        'Africa/Bissau' => 'توقيت غرينتش (بيساو)',
        'Africa/Blantyre' => 'توقيت وسط أفريقيا (بلانتاير)',
        'Africa/Brazzaville' => 'توقيت غرب أفريقيا (برازافيل)',
        'Africa/Bujumbura' => 'توقيت وسط أفريقيا (بوجومبورا)',
        'Africa/Cairo' => 'توقيت شرق أوروبا (القاهرة)',
        'Africa/Casablanca' => 'توقيت غرب أوروبا (الدار البيضاء)',
        'Africa/Ceuta' => 'توقيت وسط أوروبا (سيتا)',
        'Africa/Conakry' => 'توقيت غرينتش (كوناكري)',
        'Africa/Dakar' => 'توقيت غرينتش (داكار)',
        'Africa/Dar_es_Salaam' => 'توقيت شرق أفريقيا (دار السلام)',
        'Africa/Djibouti' => 'توقيت شرق أفريقيا (جيبوتي)',
        'Africa/Douala' => 'توقيت غرب أفريقيا (دوالا)',
        'Africa/El_Aaiun' => 'توقيت غرب أوروبا (العيون)',
        'Africa/Freetown' => 'توقيت غرينتش (فري تاون)',
        'Africa/Gaborone' => 'توقيت وسط أفريقيا (غابورون)',
        'Africa/Harare' => 'توقيت وسط أفريقيا (هراري)',
        'Africa/Johannesburg' => 'توقيت جنوب أفريقيا (جوهانسبرغ)',
        'Africa/Juba' => 'توقيت وسط أفريقيا (جوبا)',
        'Africa/Kampala' => 'توقيت شرق أفريقيا (كامبالا)',
        'Africa/Khartoum' => 'توقيت وسط أفريقيا (الخرطوم)',
        'Africa/Kigali' => 'توقيت وسط أفريقيا (كيغالي)',
        'Africa/Kinshasa' => 'توقيت غرب أفريقيا (كينشاسا)',
        'Africa/Lagos' => 'توقيت غرب أفريقيا (لاغوس)',
        'Africa/Libreville' => 'توقيت غرب أفريقيا (ليبرفيل)',
        'Africa/Lome' => 'توقيت غرينتش (لومي)',
        'Africa/Luanda' => 'توقيت غرب أفريقيا (لواندا)',
        'Africa/Lubumbashi' => 'توقيت وسط أفريقيا (لومبباشا)',
        'Africa/Lusaka' => 'توقيت وسط أفريقيا (لوساكا)',
        'Africa/Malabo' => 'توقيت غرب أفريقيا (مالابو)',
        'Africa/Maputo' => 'توقيت وسط أفريقيا (مابوتو)',
        'Africa/Maseru' => 'توقيت جنوب أفريقيا (ماسيرو)',
        'Africa/Mbabane' => 'توقيت جنوب أفريقيا (مباباني)',
        'Africa/Mogadishu' => 'توقيت شرق أفريقيا (مقديشيو)',
        'Africa/Monrovia' => 'توقيت غرينتش (مونروفيا)',
        'Africa/Nairobi' => 'توقيت شرق أفريقيا (نيروبي)',
        'Africa/Ndjamena' => 'توقيت غرب أفريقيا (نجامينا)',
        'Africa/Niamey' => 'توقيت غرب أفريقيا (نيامي)',
        'Africa/Nouakchott' => 'توقيت غرينتش (نواكشوط)',
        'Africa/Ouagadougou' => 'توقيت غرينتش (واغادوغو)',
        'Africa/Porto-Novo' => 'توقيت غرب أفريقيا (بورتو نوفو)',
        'Africa/Sao_Tome' => 'توقيت غرينتش (ساو تومي)',
        'Africa/Tripoli' => 'توقيت شرق أوروبا (طرابلس)',
        'Africa/Tunis' => 'توقيت وسط أوروبا (تونس)',
        'Africa/Windhoek' => 'توقيت وسط أفريقيا (ويندهوك)',
        'America/Adak' => 'توقيت هاواي ألوتيان (أداك)',
        'America/Anchorage' => 'توقيت ألاسكا (أنشوراج)',
        'America/Anguilla' => 'توقيت الأطلسي (أنغويلا)',
        'America/Antigua' => 'توقيت الأطلسي (أنتيغوا)',
        'America/Araguaina' => 'توقيت برازيليا (أروجوانيا)',
        'America/Argentina/La_Rioja' => 'توقيت الأرجنتين (لا ريوجا)',
        'America/Argentina/Rio_Gallegos' => 'توقيت الأرجنتين (ريو جالييوس)',
        'America/Argentina/Salta' => 'توقيت الأرجنتين (سالطا)',
        'America/Argentina/San_Juan' => 'توقيت الأرجنتين (سان خوان)',
        'America/Argentina/San_Luis' => 'توقيت الأرجنتين (سان لويس)',
        'America/Argentina/Tucuman' => 'توقيت الأرجنتين (تاكمان)',
        'America/Argentina/Ushuaia' => 'توقيت الأرجنتين (أشوا)',
        'America/Aruba' => 'توقيت الأطلسي (أروبا)',
        'America/Asuncion' => 'توقيت باراغواي (أسونسيون)',
        'America/Bahia' => 'توقيت برازيليا (باهيا)',
        'America/Bahia_Banderas' => 'التوقيت المركزي لأمريكا الشمالية (باهيا بانديراس)',
        'America/Barbados' => 'توقيت الأطلسي (بربادوس)',
        'America/Belem' => 'توقيت برازيليا (بلم)',
        'America/Belize' => 'التوقيت المركزي لأمريكا الشمالية (بليز)',
        'America/Blanc-Sablon' => 'توقيت الأطلسي (بلانك-سابلون)',
        'America/Boa_Vista' => 'توقيت الأمازون (باو فيستا)',
        'America/Bogota' => 'توقيت كولومبيا (بوغوتا)',
        'America/Boise' => 'التوقيت الجبلي لأمريكا الشمالية (بويس)',
        'America/Buenos_Aires' => 'توقيت الأرجنتين (بوينوس أيرس)',
        'America/Cambridge_Bay' => 'التوقيت الجبلي لأمريكا الشمالية (كامبرديج باي)',
        'America/Campo_Grande' => 'توقيت الأمازون (كومبو جراند)',
        'America/Cancun' => 'التوقيت الشرقي لأمريكا الشمالية (كانكون)',
        'America/Caracas' => 'توقيت فنزويلا (كاراكاس)',
        'America/Catamarca' => 'توقيت الأرجنتين (كاتاماركا)',
        'America/Cayenne' => 'توقيت غويانا الفرنسية (كايين)',
        'America/Cayman' => 'التوقيت الشرقي لأمريكا الشمالية (كايمان)',
        'America/Chicago' => 'التوقيت المركزي لأمريكا الشمالية (شيكاغو)',
        'America/Chihuahua' => 'توقيت المحيط الهادي للمكسيك (تشيواوا)',
        'America/Coral_Harbour' => 'التوقيت الشرقي لأمريكا الشمالية (كورال هاربر)',
        'America/Cordoba' => 'توقيت الأرجنتين (كوردوبا)',
        'America/Costa_Rica' => 'التوقيت المركزي لأمريكا الشمالية (كوستاريكا)',
        'America/Creston' => 'التوقيت الجبلي لأمريكا الشمالية (كريستون)',
        'America/Cuiaba' => 'توقيت الأمازون (كيابا)',
        'America/Curacao' => 'توقيت الأطلسي (كوراساو)',
        'America/Danmarkshavn' => 'توقيت غرينتش (دانمرك شافن)',
        'America/Dawson' => 'توقيت يوكون (داوسان)',
        'America/Dawson_Creek' => 'التوقيت الجبلي لأمريكا الشمالية (داوسن كريك)',
        'America/Denver' => 'التوقيت الجبلي لأمريكا الشمالية (دنفر)',
        'America/Detroit' => 'التوقيت الشرقي لأمريكا الشمالية (ديترويت)',
        'America/Dominica' => 'توقيت الأطلسي (دومينيكا)',
        'America/Edmonton' => 'التوقيت الجبلي لأمريكا الشمالية (ايدمونتون)',
        'America/Eirunepe' => 'توقيت البرازيل (ايرونبي)',
        'America/El_Salvador' => 'التوقيت المركزي لأمريكا الشمالية (السلفادور)',
        'America/Fort_Nelson' => 'التوقيت الجبلي لأمريكا الشمالية (فورت نيلسون)',
        'America/Fortaleza' => 'توقيت برازيليا (فورتاليزا)',
        'America/Glace_Bay' => 'توقيت الأطلسي (جلاس باي)',
        'America/Godthab' => 'توقيت غرب غرينلاند (غودثاب)',
        'America/Goose_Bay' => 'توقيت الأطلسي (جوس باي)',
        'America/Grand_Turk' => 'التوقيت الشرقي لأمريكا الشمالية (غراند ترك)',
        'America/Grenada' => 'توقيت الأطلسي (غرينادا)',
        'America/Guadeloupe' => 'توقيت الأطلسي (غوادلوب)',
        'America/Guatemala' => 'التوقيت المركزي لأمريكا الشمالية (غواتيمالا)',
        'America/Guayaquil' => 'توقيت الإكوادور (غواياكويل)',
        'America/Guyana' => 'توقيت غيانا',
        'America/Halifax' => 'توقيت الأطلسي (هاليفاكس)',
        'America/Havana' => 'توقيت كوبا (هافانا)',
        'America/Hermosillo' => 'توقيت المحيط الهادي للمكسيك (هيرموسيلو)',
        'America/Indiana/Knox' => 'التوقيت المركزي لأمريكا الشمالية (كونكس)',
        'America/Indiana/Marengo' => 'التوقيت الشرقي لأمريكا الشمالية (مارنجو)',
        'America/Indiana/Petersburg' => 'التوقيت الشرقي لأمريكا الشمالية (بيترسبرغ)',
        'America/Indiana/Tell_City' => 'التوقيت المركزي لأمريكا الشمالية (مدينة تل، إنديانا)',
        'America/Indiana/Vevay' => 'التوقيت الشرقي لأمريكا الشمالية (فيفاي)',
        'America/Indiana/Vincennes' => 'التوقيت الشرقي لأمريكا الشمالية (فينسينس)',
        'America/Indiana/Winamac' => 'التوقيت الشرقي لأمريكا الشمالية (ويناماك)',
        'America/Indianapolis' => 'التوقيت الشرقي لأمريكا الشمالية (إنديانابوليس)',
        'America/Inuvik' => 'التوقيت الجبلي لأمريكا الشمالية (اينوفيك)',
        'America/Iqaluit' => 'التوقيت الشرقي لأمريكا الشمالية (اكويلت)',
        'America/Jamaica' => 'التوقيت الشرقي لأمريكا الشمالية (جامايكا)',
        'America/Jujuy' => 'توقيت الأرجنتين (جوجو)',
        'America/Juneau' => 'توقيت ألاسكا (جوني)',
        'America/Kentucky/Monticello' => 'التوقيت الشرقي لأمريكا الشمالية (مونتيسيلو)',
        'America/Kralendijk' => 'توقيت الأطلسي (كرالنديك)',
        'America/La_Paz' => 'توقيت بوليفيا (لا باز)',
        'America/Lima' => 'توقيت بيرو (ليما)',
        'America/Los_Angeles' => 'توقيت المحيط الهادي (لوس انجلوس)',
        'America/Louisville' => 'التوقيت الشرقي لأمريكا الشمالية (لويس فيل)',
        'America/Lower_Princes' => 'توقيت الأطلسي (حي الأمير السفلي)',
        'America/Maceio' => 'توقيت برازيليا (ماشيو)',
        'America/Managua' => 'التوقيت المركزي لأمريكا الشمالية (ماناغوا)',
        'America/Manaus' => 'توقيت الأمازون (ماناوس)',
        'America/Marigot' => 'توقيت الأطلسي (ماريغوت)',
        'America/Martinique' => 'توقيت الأطلسي (المارتينيك)',
        'America/Matamoros' => 'التوقيت المركزي لأمريكا الشمالية (ماتاموروس)',
        'America/Mazatlan' => 'توقيت المحيط الهادي للمكسيك (مازاتلان)',
        'America/Mendoza' => 'توقيت الأرجنتين (ميندوزا)',
        'America/Menominee' => 'التوقيت المركزي لأمريكا الشمالية (مينوميني)',
        'America/Merida' => 'التوقيت المركزي لأمريكا الشمالية (ميريدا)',
        'America/Metlakatla' => 'توقيت ألاسكا (ميتلاكاتلا)',
        'America/Mexico_City' => 'التوقيت المركزي لأمريكا الشمالية (مكسيكو سيتي)',
        'America/Miquelon' => 'توقيت سانت بيير وميكولون (مكويلون)',
        'America/Moncton' => 'توقيت الأطلسي (وينكتون)',
        'America/Monterrey' => 'التوقيت المركزي لأمريكا الشمالية (مونتيري)',
        'America/Montevideo' => 'توقيت أوروغواي (مونتفيديو)',
        'America/Montreal' => 'توقيت كندا (Montreal)',
        'America/Montserrat' => 'توقيت الأطلسي (مونتسيرات)',
        'America/Nassau' => 'التوقيت الشرقي لأمريكا الشمالية (ناسو)',
        'America/New_York' => 'التوقيت الشرقي لأمريكا الشمالية (نيويورك)',
        'America/Nipigon' => 'التوقيت الشرقي لأمريكا الشمالية (نيبيجون)',
        'America/Nome' => 'توقيت ألاسكا (نوم)',
        'America/Noronha' => 'توقيت فيرناندو دي نورونها (نوروناه)',
        'America/North_Dakota/Beulah' => 'التوقيت المركزي لأمريكا الشمالية (بيولا، داكوتا الشمالية)',
        'America/North_Dakota/Center' => 'التوقيت المركزي لأمريكا الشمالية (سنتر)',
        'America/North_Dakota/New_Salem' => 'التوقيت المركزي لأمريكا الشمالية (نيو ساليم)',
        'America/Ojinaga' => 'التوقيت الجبلي لأمريكا الشمالية (أوجيناجا)',
        'America/Panama' => 'التوقيت الشرقي لأمريكا الشمالية (بنما)',
        'America/Pangnirtung' => 'التوقيت الشرقي لأمريكا الشمالية (بانجينتينج)',
        'America/Paramaribo' => 'توقيت سورينام (باراماريبو)',
        'America/Phoenix' => 'التوقيت الجبلي لأمريكا الشمالية (فينكس)',
        'America/Port-au-Prince' => 'التوقيت الشرقي لأمريكا الشمالية (بورت أو برنس)',
        'America/Port_of_Spain' => 'توقيت الأطلسي (بورت أوف سبين)',
        'America/Porto_Velho' => 'توقيت الأمازون (بورتو فيلو)',
        'America/Puerto_Rico' => 'توقيت الأطلسي (بورتوريكو)',
        'America/Punta_Arenas' => 'توقيت تشيلي (بونتا أريناز)',
        'America/Rainy_River' => 'التوقيت المركزي لأمريكا الشمالية (راني ريفر)',
        'America/Rankin_Inlet' => 'التوقيت المركزي لأمريكا الشمالية (رانكن انلت)',
        'America/Recife' => 'توقيت برازيليا (ريسيف)',
        'America/Regina' => 'التوقيت المركزي لأمريكا الشمالية (ريجينا)',
        'America/Resolute' => 'التوقيت المركزي لأمريكا الشمالية (ريزولوت)',
        'America/Rio_Branco' => 'توقيت البرازيل (ريوبرانكو)',
        'America/Santa_Isabel' => 'توقيت شمال غرب المكسيك (سانتا إيزابيل)',
        'America/Santarem' => 'توقيت برازيليا (سانتاريم)',
        'America/Santiago' => 'توقيت تشيلي (سانتياغو)',
        'America/Santo_Domingo' => 'توقيت الأطلسي (سانتو دومينغو)',
        'America/Sao_Paulo' => 'توقيت برازيليا (ساو باولو)',
        'America/Scoresbysund' => 'توقيت شرق غرينلاند (سكورسبيسند)',
        'America/Sitka' => 'توقيت ألاسكا (سيتكا)',
        'America/St_Barthelemy' => 'توقيت الأطلسي (سانت بارتيليمي)',
        'America/St_Johns' => 'توقيت نيوفاوندلاند (سانت جونس)',
        'America/St_Kitts' => 'توقيت الأطلسي (سانت كيتس)',
        'America/St_Lucia' => 'توقيت الأطلسي (سانت لوشيا)',
        'America/St_Thomas' => 'توقيت الأطلسي (سانت توماس)',
        'America/St_Vincent' => 'توقيت الأطلسي (سانت فنسنت)',
        'America/Swift_Current' => 'التوقيت المركزي لأمريكا الشمالية (سوفت كارنت)',
        'America/Tegucigalpa' => 'التوقيت المركزي لأمريكا الشمالية (تيغوسيغالبا)',
        'America/Thule' => 'توقيت الأطلسي (ثيل)',
        'America/Thunder_Bay' => 'التوقيت الشرقي لأمريكا الشمالية (ثندر باي)',
        'America/Tijuana' => 'توقيت المحيط الهادي (تيخوانا)',
        'America/Toronto' => 'التوقيت الشرقي لأمريكا الشمالية (تورونتو)',
        'America/Tortola' => 'توقيت الأطلسي (تورتولا)',
        'America/Vancouver' => 'توقيت المحيط الهادي (فانكوفر)',
        'America/Whitehorse' => 'توقيت يوكون (وايت هورس)',
        'America/Winnipeg' => 'التوقيت المركزي لأمريكا الشمالية (وينيبيج)',
        'America/Yakutat' => 'توقيت ألاسكا (ياكوتات)',
        'America/Yellowknife' => 'التوقيت الجبلي لأمريكا الشمالية (يلونيف)',
        'Antarctica/Casey' => 'توقيت أنتاركتيكا (كاساي)',
        'Antarctica/Davis' => 'توقيت دافيز',
        'Antarctica/DumontDUrville' => 'توقيت دي مونت دو روفيل',
        'Antarctica/Macquarie' => 'توقيت شرق أستراليا (ماكواري)',
        'Antarctica/Mawson' => 'توقيت ماوسون',
        'Antarctica/McMurdo' => 'توقيت نيوزيلندا (ماك موردو)',
        'Antarctica/Palmer' => 'توقيت تشيلي (بالمير)',
        'Antarctica/Rothera' => 'توقيت روثيرا',
        'Antarctica/Syowa' => 'توقيت سايووا',
        'Antarctica/Troll' => 'توقيت غرينتش (ترول)',
        'Antarctica/Vostok' => 'توقيت فوستوك',
        'Arctic/Longyearbyen' => 'توقيت وسط أوروبا (لونجيربين)',
        'Asia/Aden' => 'التوقيت العربي (عدن)',
        'Asia/Almaty' => 'توقيت شرق كازاخستان (ألماتي)',
        'Asia/Amman' => 'توقيت شرق أوروبا (عمّان)',
        'Asia/Anadyr' => 'توقيت أنادير (أندير)',
        'Asia/Aqtau' => 'توقيت غرب كازاخستان (أكتاو)',
        'Asia/Aqtobe' => 'توقيت غرب كازاخستان (أكتوب)',
        'Asia/Ashgabat' => 'توقيت تركمانستان (عشق آباد)',
        'Asia/Atyrau' => 'توقيت غرب كازاخستان (أتيراو)',
        'Asia/Baghdad' => 'التوقيت العربي (بغداد)',
        'Asia/Bahrain' => 'التوقيت العربي (البحرين)',
        'Asia/Baku' => 'توقيت أذربيجان (باكو)',
        'Asia/Bangkok' => 'توقيت الهند الصينية (بانكوك)',
        'Asia/Barnaul' => 'توقيت روسيا (بارناول)',
        'Asia/Beirut' => 'توقيت شرق أوروبا (بيروت)',
        'Asia/Bishkek' => 'توقيت قيرغيزستان (بشكيك)',
        'Asia/Brunei' => 'توقيت بروناي',
        'Asia/Calcutta' => 'توقيت الهند (كالكتا)',
        'Asia/Chita' => 'توقيت ياكوتسك (تشيتا)',
        'Asia/Choibalsan' => 'توقيت أولان باتور (تشوبالسان)',
        'Asia/Colombo' => 'توقيت الهند (كولومبو)',
        'Asia/Damascus' => 'توقيت شرق أوروبا (دمشق)',
        'Asia/Dhaka' => 'توقيت بنغلاديش (دكا)',
        'Asia/Dili' => 'توقيت تيمور الشرقية (ديلي)',
        'Asia/Dubai' => 'توقيت الخليج (دبي)',
        'Asia/Dushanbe' => 'توقيت طاجكستان (دوشانبي)',
        'Asia/Famagusta' => 'توقيت شرق أوروبا (فاماغوستا)',
        'Asia/Gaza' => 'توقيت شرق أوروبا (غزة)',
        'Asia/Hebron' => 'توقيت شرق أوروبا (هيبرون (مدينة الخليل))',
        'Asia/Hong_Kong' => 'توقيت هونغ كونغ',
        'Asia/Hovd' => 'توقيت هوفد',
        'Asia/Irkutsk' => 'توقيت إركوتسك (ايركيتسك)',
        'Asia/Jakarta' => 'توقيت غرب إندونيسيا (جاكرتا)',
        'Asia/Jayapura' => 'توقيت شرق إندونيسيا (جايابيورا)',
        'Asia/Jerusalem' => 'توقيت إسرائيل (القدس)',
        'Asia/Kabul' => 'توقيت أفغانستان (كابول)',
        'Asia/Kamchatka' => 'توقيت كامشاتكا (كامتشاتكا)',
        'Asia/Karachi' => 'توقيت باكستان (كراتشي)',
        'Asia/Katmandu' => 'توقيت نيبال (كاتماندو)',
        'Asia/Khandyga' => 'توقيت ياكوتسك (خانديجا)',
        'Asia/Krasnoyarsk' => 'توقيت كراسنويارسك',
        'Asia/Kuala_Lumpur' => 'توقيت ماليزيا (كوالا لامبور)',
        'Asia/Kuching' => 'توقيت ماليزيا (كيشينج)',
        'Asia/Kuwait' => 'التوقيت العربي (الكويت)',
        'Asia/Macau' => 'توقيت الصين (ماكاو)',
        'Asia/Magadan' => 'توقيت ماغادان (مجادن)',
        'Asia/Makassar' => 'توقيت وسط إندونيسيا (ماكسار)',
        'Asia/Manila' => 'توقيت الفيلبين (مانيلا)',
        'Asia/Muscat' => 'توقيت الخليج (مسقط)',
        'Asia/Nicosia' => 'توقيت شرق أوروبا (نيقوسيا)',
        'Asia/Novokuznetsk' => 'توقيت كراسنويارسك (نوفوكوزنتسك)',
        'Asia/Novosibirsk' => 'توقيت نوفوسيبيرسك (نوفوسبيرسك)',
        'Asia/Omsk' => 'توقيت أومسك',
        'Asia/Oral' => 'توقيت غرب كازاخستان (أورال)',
        'Asia/Phnom_Penh' => 'توقيت الهند الصينية (بنوم بنه)',
        'Asia/Pontianak' => 'توقيت غرب إندونيسيا (بونتيانك)',
        'Asia/Pyongyang' => 'توقيت كوريا (بيونغ يانغ)',
        'Asia/Qatar' => 'التوقيت العربي (قطر)',
        'Asia/Qostanay' => 'توقيت شرق كازاخستان (قوستاناي)',
        'Asia/Qyzylorda' => 'توقيت غرب كازاخستان (كيزيلوردا)',
        'Asia/Rangoon' => 'توقيت ميانمار (رانغون)',
        'Asia/Riyadh' => 'التوقيت العربي (الرياض)',
        'Asia/Saigon' => 'توقيت الهند الصينية (مدينة هو تشي منة)',
        'Asia/Sakhalin' => 'توقيت ساخالين (سكالين)',
        'Asia/Samarkand' => 'توقيت أوزبكستان (سمرقند)',
        'Asia/Seoul' => 'توقيت كوريا (سول)',
        'Asia/Shanghai' => 'توقيت الصين (شنغهاي)',
        'Asia/Singapore' => 'توقيت سنغافورة',
        'Asia/Srednekolymsk' => 'توقيت ماغادان (سريدنكوليمسك)',
        'Asia/Taipei' => 'توقيت تايبيه',
        'Asia/Tashkent' => 'توقيت أوزبكستان (طشقند)',
        'Asia/Tbilisi' => 'توقيت جورجيا (تبليسي)',
        'Asia/Tehran' => 'توقيت إيران (طهران)',
        'Asia/Thimphu' => 'توقيت بوتان (تيمفو)',
        'Asia/Tokyo' => 'توقيت اليابان (طوكيو)',
        'Asia/Tomsk' => 'توقيت روسيا (تومسك)',
        'Asia/Ulaanbaatar' => 'توقيت أولان باتور (آلانباتار)',
        'Asia/Urumqi' => 'توقيت الصين (أرومكي)',
        'Asia/Ust-Nera' => 'توقيت فلاديفوستوك (أوست نيرا)',
        'Asia/Vientiane' => 'توقيت الهند الصينية (فيانتيان)',
        'Asia/Vladivostok' => 'توقيت فلاديفوستوك (فلاديفوستك)',
        'Asia/Yakutsk' => 'توقيت ياكوتسك (ياكتسك)',
        'Asia/Yekaterinburg' => 'توقيت يكاترينبورغ (يكاترنبيرج)',
        'Asia/Yerevan' => 'توقيت أرمينيا (يريفان)',
        'Atlantic/Azores' => 'توقيت أزورس',
        'Atlantic/Bermuda' => 'توقيت الأطلسي (برمودا)',
        'Atlantic/Canary' => 'توقيت غرب أوروبا (كناري)',
        'Atlantic/Cape_Verde' => 'توقيت الرأس الأخضر',
        'Atlantic/Faeroe' => 'توقيت غرب أوروبا (فارو)',
        'Atlantic/Madeira' => 'توقيت غرب أوروبا (ماديرا)',
        'Atlantic/Reykjavik' => 'توقيت غرينتش (ريكيافيك)',
        'Atlantic/South_Georgia' => 'توقيت جنوب جورجيا (جورجيا الجنوبية)',
        'Atlantic/St_Helena' => 'توقيت غرينتش (سانت هيلينا)',
        'Atlantic/Stanley' => 'توقيت جزر فوكلاند (استانلي)',
        'Australia/Adelaide' => 'توقيت وسط أستراليا (أديليد)',
        'Australia/Brisbane' => 'توقيت شرق أستراليا (برسيبان)',
        'Australia/Broken_Hill' => 'توقيت وسط أستراليا (بروكن هيل)',
        'Australia/Currie' => 'توقيت شرق أستراليا (كوري)',
        'Australia/Darwin' => 'توقيت وسط أستراليا (دارون)',
        'Australia/Eucla' => 'توقيت غرب وسط أستراليا (أوكلا)',
        'Australia/Hobart' => 'توقيت شرق أستراليا (هوبارت)',
        'Australia/Lindeman' => 'توقيت شرق أستراليا (ليندمان)',
        'Australia/Lord_Howe' => 'توقيت لورد هاو',
        'Australia/Melbourne' => 'توقيت شرق أستراليا (ميلبورن)',
        'Australia/Perth' => 'توقيت غرب أستراليا (برثا)',
        'Australia/Sydney' => 'توقيت شرق أستراليا (سيدني)',
        'CST6CDT' => 'التوقيت المركزي لأمريكا الشمالية',
        'EST5EDT' => 'التوقيت الشرقي لأمريكا الشمالية',
        'Etc/GMT' => 'توقيت غرينتش',
        'Etc/UTC' => 'التوقيت العالمي المنسق',
        'Europe/Amsterdam' => 'توقيت وسط أوروبا (أمستردام)',
        'Europe/Andorra' => 'توقيت وسط أوروبا (أندورا)',
        'Europe/Astrakhan' => 'توقيت موسكو (أستراخان)',
        'Europe/Athens' => 'توقيت شرق أوروبا (أثينا)',
        'Europe/Belgrade' => 'توقيت وسط أوروبا (بلغراد)',
        'Europe/Berlin' => 'توقيت وسط أوروبا (برلين)',
        'Europe/Bratislava' => 'توقيت وسط أوروبا (براتيسلافا)',
        'Europe/Brussels' => 'توقيت وسط أوروبا (بروكسل)',
        'Europe/Bucharest' => 'توقيت شرق أوروبا (بوخارست)',
        'Europe/Budapest' => 'توقيت وسط أوروبا (بودابست)',
        'Europe/Busingen' => 'توقيت وسط أوروبا (بوسنغن)',
        'Europe/Chisinau' => 'توقيت شرق أوروبا (تشيسيناو)',
        'Europe/Copenhagen' => 'توقيت وسط أوروبا (كوبنهاغن)',
        'Europe/Dublin' => 'توقيت غرينتش (دبلن)',
        'Europe/Gibraltar' => 'توقيت وسط أوروبا (جبل طارق)',
        'Europe/Guernsey' => 'توقيت غرينتش (غيرنزي)',
        'Europe/Helsinki' => 'توقيت شرق أوروبا (هلسنكي)',
        'Europe/Isle_of_Man' => 'توقيت غرينتش (جزيرة مان)',
        'Europe/Istanbul' => 'توقيت تركيا (إسطنبول)',
        'Europe/Jersey' => 'توقيت غرينتش (جيرسي)',
        'Europe/Kaliningrad' => 'توقيت شرق أوروبا (كالينجراد)',
        'Europe/Kiev' => 'توقيت شرق أوروبا (كييف)',
        'Europe/Kirov' => 'توقيت روسيا (كيروف)',
        'Europe/Lisbon' => 'توقيت غرب أوروبا (لشبونة)',
        'Europe/Ljubljana' => 'توقيت وسط أوروبا (ليوبليانا)',
        'Europe/London' => 'توقيت غرينتش (لندن)',
        'Europe/Luxembourg' => 'توقيت وسط أوروبا (لوكسمبورغ)',
        'Europe/Madrid' => 'توقيت وسط أوروبا (مدريد)',
        'Europe/Malta' => 'توقيت وسط أوروبا (مالطة)',
        'Europe/Mariehamn' => 'توقيت شرق أوروبا (ماريهامن)',
        'Europe/Minsk' => 'توقيت موسكو (مينسك)',
        'Europe/Monaco' => 'توقيت وسط أوروبا (موناكو)',
        'Europe/Moscow' => 'توقيت موسكو',
        'Europe/Oslo' => 'توقيت وسط أوروبا (أوسلو)',
        'Europe/Paris' => 'توقيت وسط أوروبا (باريس)',
        'Europe/Podgorica' => 'توقيت وسط أوروبا (بودغوريكا)',
        'Europe/Prague' => 'توقيت وسط أوروبا (براغ)',
        'Europe/Riga' => 'توقيت شرق أوروبا (ريغا)',
        'Europe/Rome' => 'توقيت وسط أوروبا (روما)',
        'Europe/Samara' => 'توقيت سامارا (سمراء)',
        'Europe/San_Marino' => 'توقيت وسط أوروبا (سان مارينو)',
        'Europe/Sarajevo' => 'توقيت وسط أوروبا (سراييفو)',
        'Europe/Saratov' => 'توقيت موسكو (ساراتوف)',
        'Europe/Simferopol' => 'توقيت موسكو (سيمفروبول)',
        'Europe/Skopje' => 'توقيت وسط أوروبا (سكوبي)',
        'Europe/Sofia' => 'توقيت شرق أوروبا (صوفيا)',
        'Europe/Stockholm' => 'توقيت وسط أوروبا (ستوكهولم)',
        'Europe/Tallinn' => 'توقيت شرق أوروبا (تالين)',
        'Europe/Tirane' => 'توقيت وسط أوروبا (تيرانا)',
        'Europe/Ulyanovsk' => 'توقيت موسكو (أوليانوفسك)',
        'Europe/Uzhgorod' => 'توقيت شرق أوروبا (أوزجرود)',
        'Europe/Vaduz' => 'توقيت وسط أوروبا (فادوز)',
        'Europe/Vatican' => 'توقيت وسط أوروبا (الفاتيكان)',
        'Europe/Vienna' => 'توقيت وسط أوروبا (فيينا)',
        'Europe/Vilnius' => 'توقيت شرق أوروبا (فيلنيوس)',
        'Europe/Volgograd' => 'توقيت فولغوغراد (فولوجراد)',
        'Europe/Warsaw' => 'توقيت وسط أوروبا (وارسو)',
        'Europe/Zagreb' => 'توقيت وسط أوروبا (زغرب)',
        'Europe/Zaporozhye' => 'توقيت شرق أوروبا (زابوروزي)',
        'Europe/Zurich' => 'توقيت وسط أوروبا (زيورخ)',
        'Indian/Antananarivo' => 'توقيت شرق أفريقيا (أنتاناناريفو)',
        'Indian/Chagos' => 'توقيت المحيط الهندي (تشاغوس)',
        'Indian/Christmas' => 'توقيت جزر الكريسماس',
        'Indian/Cocos' => 'توقيت جزر كوكوس',
        'Indian/Comoro' => 'توقيت شرق أفريقيا (جزر القمر)',
        'Indian/Kerguelen' => 'توقيت المقاطعات الفرنسية الجنوبية والأنتارتيكية (كيرغويلين)',
        'Indian/Mahe' => 'توقيت سيشل (ماهي)',
        'Indian/Maldives' => 'توقيت جزر المالديف',
        'Indian/Mauritius' => 'توقيت موريشيوس',
        'Indian/Mayotte' => 'توقيت شرق أفريقيا (مايوت)',
        'Indian/Reunion' => 'توقيت روينيون (ريونيون)',
        'MST7MDT' => 'التوقيت الجبلي لأمريكا الشمالية',
        'PST8PDT' => 'توقيت المحيط الهادي',
        'Pacific/Apia' => 'توقيت آبيا (أبيا)',
        'Pacific/Auckland' => 'توقيت نيوزيلندا (أوكلاند)',
        'Pacific/Bougainville' => 'توقيت بابوا غينيا الجديدة (بوغانفيل)',
        'Pacific/Chatham' => 'توقيت تشاتام (تشاثام)',
        'Pacific/Easter' => 'توقيت جزيرة استر',
        'Pacific/Efate' => 'توقيت فانواتو (إيفات)',
        'Pacific/Enderbury' => 'توقيت جزر فينكس (اندربيرج)',
        'Pacific/Fakaofo' => 'توقيت توكيلاو (فاكاوفو)',
        'Pacific/Fiji' => 'توقيت فيجي',
        'Pacific/Funafuti' => 'توقيت توفالو (فونافوتي)',
        'Pacific/Galapagos' => 'توقيت غلاباغوس (جلاباجوس)',
        'Pacific/Gambier' => 'توقيت جامبير',
        'Pacific/Guadalcanal' => 'توقيت جزر سليمان (غوادالكانال)',
        'Pacific/Guam' => 'توقيت تشامورو (غوام)',
        'Pacific/Honolulu' => 'توقيت هاواي ألوتيان (هونولولو)',
        'Pacific/Johnston' => 'توقيت هاواي ألوتيان (جونستون)',
        'Pacific/Kiritimati' => 'توقيت جزر لاين (كيريتي ماتي)',
        'Pacific/Kosrae' => 'توقيت كوسرا',
        'Pacific/Kwajalein' => 'توقيت جزر مارشال (كواجالين)',
        'Pacific/Majuro' => 'توقيت جزر مارشال (ماجورو)',
        'Pacific/Marquesas' => 'توقيت ماركيساس',
        'Pacific/Midway' => 'توقيت ساموا (ميدواي)',
        'Pacific/Nauru' => 'توقيت ناورو',
        'Pacific/Niue' => 'توقيت نيوي',
        'Pacific/Norfolk' => 'توقيت جزيرة نورفولك',
        'Pacific/Noumea' => 'توقيت كاليدونيا الجديدة (نوميا)',
        'Pacific/Pago_Pago' => 'توقيت ساموا (باغو باغو)',
        'Pacific/Palau' => 'توقيت بالاو',
        'Pacific/Pitcairn' => 'توقيت بيتكيرن',
        'Pacific/Ponape' => 'توقيت بونابي (باناب)',
        'Pacific/Port_Moresby' => 'توقيت بابوا غينيا الجديدة (بور مورسبي)',
        'Pacific/Rarotonga' => 'توقيت جزر كووك (راروتونغا)',
        'Pacific/Saipan' => 'توقيت تشامورو (سايبان)',
        'Pacific/Tahiti' => 'توقيت تاهيتي',
        'Pacific/Tarawa' => 'توقيت جزر جيلبرت (تاراوا)',
        'Pacific/Tongatapu' => 'توقيت تونغا (تونغاتابو)',
        'Pacific/Truk' => 'توقيت شوك (ترك)',
        'Pacific/Wake' => 'توقيت جزيرة ويك (واك)',
        'Pacific/Wallis' => 'توقيت واليس و فوتونا',
    ],
    'Meta' => [
        'GmtFormat' => 'غرينتش%s',
    ],
];
