<?php

return [
    'Names' => [
        'ak' => 'isi-Akhani',
        'am' => 'isi-Amaharikhi',
        'ar' => 'isi-Alabhu',
        'be' => 'isi-Bhelarashiyani',
        'bg' => 'isi-Bulgaria',
        'bn' => 'isi-Bhengali',
        'cs' => 'isi-Czech',
        'de' => 'isi-Jalimani',
        'el' => 'isi-Giliki',
        'en' => 'isi-Ngisi',
        'es' => 'isi-Sipeyini',
        'fa' => 'isi-Pheshiyani',
        'fr' => 'isi-Fulentshi',
        'ha' => 'isi-Hausa',
        'hi' => 'isi-Hindi',
        'hu' => 'isi-Hangari',
        'id' => 'isi-Indonesia',
        'ig' => 'isi-Igbo',
        'it' => 'isi-Italiano',
        'ja' => 'isi-Japhani',
        'jv' => 'isi-Java',
        'km' => 'isi-Khambodiya',
        'ko' => 'isi-Koriya',
        'ms' => 'isi-Malayi',
        'my' => 'isi-Burma',
        'nd' => 'isiNdebele',
        'ne' => 'isi-Nepali',
        'nl' => 'isi-Dutch',
        'pa' => 'isi-Phunjabi',
        'pl' => 'isi-Pholoshi',
        'pt' => 'isi-Potukezi',
        'ro' => 'isi-Romani',
        'ru' => 'isi-Rashiya',
        'rw' => 'isi-Ruwanda',
        'so' => 'isi-Somali',
        'sv' => 'isi-Swidishi',
        'ta' => 'isi-Thamil',
        'th' => 'isi-Thayi',
        'tr' => 'isi-Thekishi',
        'uk' => 'isi-Ukrain',
        'ur' => 'isi-Udu',
        'vi' => 'isi-Vietnamese',
        'yo' => 'isi-Yorubha',
        'zh' => 'isi-China',
        'zu' => 'isi-Zulu',
    ],
    'LocalizedNames' => [
    ],
];
