<?php

return [
    'Names' => [
        'Adlm' => '아들람 문자',
        'Afak' => '아파카 문자',
        'Aghb' => '코카시안 알바니아 문자',
        'Arab' => '아랍 문자',
        'Aran' => '나스탈리크체',
        'Armi' => '아랍제국 문자',
        'Armn' => '아르메니아 문자',
        'Avst' => '아베스타 문자',
        'Bali' => '발리 문자',
        'Bamu' => '바뭄 문자',
        'Bass' => '바사바흐 문자',
        'Batk' => '바타크 문자',
        'Beng' => '벵골 문자',
        'Blis' => '블리스기호 문자',
        'Bopo' => '주음부호',
        'Brah' => '브라미',
        'Brai' => '브라유 점자',
        'Bugi' => '부기 문자',
        'Buhd' => '부히드 문자',
        'Cakm' => '차크마 문자',
        'Cans' => '통합 캐나다 원주민 음절문자',
        'Cari' => '카리 문자',
        'Cham' => '칸 고어',
        'Cher' => '체로키 문자',
        'Cirt' => '키르쓰',
        'Copt' => '콥트 문자',
        'Cprt' => '키프로스 문자',
        'Cyrl' => '키릴 문자',
        'Cyrs' => '고대교회슬라브어 키릴문자',
        'Deva' => '데바나가리 문자',
        'Dsrt' => '디저렛 문자',
        'Dupl' => '듀플로이안 문자',
        'Egyd' => '고대 이집트 민중문자',
        'Egyh' => '고대 이집트 신관문자',
        'Egyp' => '고대 이집트 신성문자',
        'Elba' => '엘바산 문자',
        'Ethi' => '에티오피아 문자',
        'Geok' => '그루지야 쿠츠리 문자',
        'Geor' => '조지아 문자',
        'Glag' => '글라골 문자',
        'Goth' => '고트 문자',
        'Gran' => '그란타 문자',
        'Grek' => '그리스 문자',
        'Gujr' => '구자라트 문자',
        'Guru' => '구르무키 문자',
        'Hanb' => '주음 자모',
        'Hang' => '한글',
        'Hani' => '한자',
        'Hano' => '하누누 문자',
        'Hans' => '간체',
        'Hant' => '번체',
        'Hebr' => '히브리 문자',
        'Hira' => '히라가나',
        'Hluw' => '아나톨리아 상형문자',
        'Hmng' => '파하우 몽 문자',
        'Hrkt' => '가나',
        'Hung' => '고대 헝가리 문자',
        'Inds' => '인더스 문자',
        'Ital' => '고대 이탈리아 문자',
        'Jamo' => '자모',
        'Java' => '자바 문자',
        'Jpan' => '일본 문자',
        'Jurc' => '줄첸 문자',
        'Kali' => '카야 리 문자',
        'Kana' => '가타카나',
        'Khar' => '카로슈티 문자',
        'Khmr' => '크메르 문자',
        'Khoj' => '코즈키 문자',
        'Knda' => '칸나다 문자',
        'Kore' => '한국 문자',
        'Kpel' => '크펠레 문자',
        'Kthi' => '카이시 문자',
        'Lana' => '란나 문자',
        'Laoo' => '라오 문자',
        'Latf' => '독일식 로마자',
        'Latg' => '아일랜드식 로마자',
        'Latn' => '로마자',
        'Lepc' => '렙차 문자',
        'Limb' => '림부 문자',
        'Lina' => '선형 문자(A)',
        'Linb' => '선형 문자(B)',
        'Lisu' => '프레이저 문자',
        'Loma' => '로마 문자',
        'Lyci' => '리키아 문자',
        'Lydi' => '리디아 문자',
        'Mahj' => '마하자니 문자',
        'Mand' => '만다이아 문자',
        'Mani' => '마니교 문자',
        'Maya' => '마야 상형 문자',
        'Mend' => '멘데 문자',
        'Merc' => '메로에 필기체',
        'Mero' => '메로에 문자',
        'Mlym' => '말라얄람 문자',
        'Mong' => '몽골 문자',
        'Moon' => '문 문자',
        'Mroo' => '므로 문자',
        'Mtei' => '메이테이 마옉 문자',
        'Mymr' => '미얀마 문자',
        'Narb' => '옛 북부 아라비아 문자',
        'Nbat' => '나바테아 문자',
        'Nkgb' => '나시 게바 문자',
        'Nkoo' => '응코 문자',
        'Nshu' => '누슈 문자',
        'Ogam' => '오검 문자',
        'Olck' => '올 치키 문자',
        'Orkh' => '오르혼어',
        'Orya' => '오리야 문자',
        'Osma' => '오스마니아 문자',
        'Palm' => '팔미라 문자',
        'Perm' => '고대 페름 문자',
        'Phag' => '파스파 문자',
        'Phli' => '명문 팔라비 문자',
        'Phlp' => '솔터 팔라비 문자',
        'Phlv' => '북 팔라비 문자',
        'Phnx' => '페니키아 문자',
        'Plrd' => '폴라드 표음 문자',
        'Prti' => '명문 파라티아 문자',
        'Qaag' => '저지 문자',
        'Rjng' => '레장 문자',
        'Rohg' => '하니피 문자',
        'Roro' => '롱고롱고',
        'Runr' => '룬 문자',
        'Samr' => '사마리아 문자',
        'Sara' => '사라티',
        'Sarb' => '옛 남부 아라비아 문자',
        'Saur' => '사우라슈트라 문자',
        'Sgnw' => '수화 문자',
        'Shaw' => '샤비안 문자',
        'Shrd' => '사라다 문자',
        'Sidd' => '실담자',
        'Sind' => '쿠다와디 문자',
        'Sinh' => '신할라 문자',
        'Sora' => '소라 솜펭 문자',
        'Sund' => '순다 문자',
        'Sylo' => '실헤티 나가리',
        'Syrc' => '시리아 문자',
        'Syre' => '에스트랑겔로식 시리아 문자',
        'Syrj' => '서부 시리아 문자',
        'Syrn' => '동부 시리아 문자',
        'Tagb' => '타그반와 문자',
        'Takr' => '타크리 문자',
        'Tale' => '타이 레 문자',
        'Talu' => '신 타이 루에',
        'Taml' => '타밀 문자',
        'Tang' => '탕구트 문자',
        'Tavt' => '태국 베트남 문자',
        'Telu' => '텔루구 문자',
        'Teng' => '텡과르 문자',
        'Tfng' => '티피나그 문자',
        'Tglg' => '타갈로그 문자',
        'Thaa' => '타나 문자',
        'Thai' => '타이 문자',
        'Tibt' => '티베트 문자',
        'Tirh' => '티르후타 문자',
        'Ugar' => '우가리트 문자',
        'Vaii' => '바이 문자',
        'Visp' => '시화법',
        'Wara' => '바랑 크시티 문자',
        'Wole' => '울레아이',
        'Xpeo' => '고대 페르시아 문자',
        'Xsux' => '수메르-아카드어 설형문자',
        'Yiii' => '이 문자',
        'Zinh' => '구전 문자',
        'Zmth' => '수학 기호',
        'Zsye' => '이모티콘',
        'Zsym' => '기호',
        'Zxxx' => '구전',
        'Zyyy' => '일반 문자',
    ],
];
