<?php

return [
    'Names' => [
        'Armn' => 'Àmɛ́níà',
        'Cyrl' => 'èdè ilɛ̀ Rɔ́shíà',
        'Deva' => 'Dɛfanagárì',
        'Ethi' => 'Ɛtiópíìkì',
        'Geor' => 'Jɔ́jíànù',
        'Grek' => 'Jɔ́jíà',
        'Hanb' => 'Han pɛ̀lú Bopomófò',
        'Hans' => 'tí wɔ́n mú rɔrùn.',
        'Hant' => 'Hans àtɔwɔ́dɔ́wɔ́',
        'Hrkt' => 'ìlànà àfɔwɔ́kɔ ará Jàpánù',
        'Khmr' => 'Kɛmɛ̀',
        'Zmth' => 'Àmì Ìshèsìrò',
        'Zsym' => 'Àwɔn àmì',
        'Zxxx' => 'Aikɔsilɛ',
        'Zyyy' => 'Wɔ́pɔ̀',
    ],
];
