<?php

return [
    'Names' => [
        'ak' => 'Lu-akaani',
        'am' => 'Lu-amhariki',
        'ar' => 'Luwarabu',
        'be' => 'Lubelarusi',
        'bg' => 'Lubulugariya',
        'bn' => 'Lubengali',
        'cs' => 'Luceeke',
        'de' => 'Ludaaki',
        'el' => 'Lugereeki/Luyonaani',
        'en' => 'Lungereza',
        'es' => 'Lusipanya',
        'fa' => 'Luperusi',
        'fr' => 'Lufalansa',
        'ha' => 'Luhawuza',
        'hi' => 'Luhindu',
        'hu' => 'Luhangare',
        'id' => 'Luyindonezya',
        'ig' => 'Luyibo',
        'it' => 'Luyitale',
        'ja' => 'Lujapani',
        'jv' => 'Lunnajjava',
        'km' => 'Lukme',
        'ko' => 'Lukoreya',
        'lg' => 'Luganda',
        'ms' => 'Lumalayi',
        'my' => 'Lubbama',
        'ne' => 'Lunepali',
        'nl' => 'Luholandi',
        'pa' => 'Lupunjabi',
        'pl' => 'Lupolandi',
        'pt' => 'Lupotugiizi',
        'ro' => 'Lulomaniya',
        'ru' => 'Lulasa',
        'rw' => 'Lunarwanda',
        'so' => 'Lusomaliya',
        'sv' => 'Luswideni',
        'ta' => 'Lutamiiru',
        'th' => 'Luttaayi',
        'tr' => 'Lutake',
        'uk' => 'Luyukurayine',
        'ur' => 'Lu-urudu',
        'vi' => 'Luvyetinaamu',
        'yo' => 'Luyoruba',
        'zh' => 'Lucayina',
        'zu' => 'Luzzulu',
    ],
    'LocalizedNames' => [
    ],
];
