<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Wektu Rerata Greenwich (Abidjan)',
        'Africa/Accra' => 'Wektu Rerata Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Wektu Afrika Wetan (Addis Ababa)',
        'Africa/Algiers' => 'Wektu Eropa Tengah (Algiers)',
        'Africa/Asmera' => 'Wektu Afrika Wetan (Asmara)',
        'Africa/Bamako' => 'Wektu Rerata Greenwich (Bamako)',
        'Africa/Bangui' => 'Wektu Afrika Kulon (Bangui)',
        'Africa/Banjul' => 'Wektu Rerata Greenwich (Banjul)',
        'Africa/Bissau' => 'Wektu Rerata Greenwich (Bissau)',
        'Africa/Blantyre' => 'Wektu Afrika Tengah (Blantyre)',
        'Africa/Brazzaville' => 'Wektu Afrika Kulon (Brazzaville)',
        'Africa/Bujumbura' => 'Wektu Afrika Tengah (Bujumbura)',
        'Africa/Cairo' => 'Wektu Eropa sisih Wetan (Kairo)',
        'Africa/Casablanca' => 'Wektu Eropa sisih Kulon (Kasablanka)',
        'Africa/Ceuta' => 'Wektu Eropa Tengah (Ceuta)',
        'Africa/Conakry' => 'Wektu Rerata Greenwich (Konakri)',
        'Africa/Dakar' => 'Wektu Rerata Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Wektu Afrika Wetan (Dar es Salaam)',
        'Africa/Djibouti' => 'Wektu Afrika Wetan (Djibouti)',
        'Africa/Douala' => 'Wektu Afrika Kulon (Douala)',
        'Africa/El_Aaiun' => 'Wektu Eropa sisih Kulon (El Aaiun)',
        'Africa/Freetown' => 'Wektu Rerata Greenwich (Freetown)',
        'Africa/Gaborone' => 'Wektu Afrika Tengah (Gaborone)',
        'Africa/Harare' => 'Wektu Afrika Tengah (Harare)',
        'Africa/Johannesburg' => 'Wektu Standar Afrika Kidul (Johannesburg)',
        'Africa/Juba' => 'Wektu Afrika Tengah (Juba)',
        'Africa/Kampala' => 'Wektu Afrika Wetan (Kampala)',
        'Africa/Khartoum' => 'Wektu Afrika Tengah (Khartoum)',
        'Africa/Kigali' => 'Wektu Afrika Tengah (Kigali)',
        'Africa/Kinshasa' => 'Wektu Afrika Kulon (Kinshasa)',
        'Africa/Lagos' => 'Wektu Afrika Kulon (Lagos)',
        'Africa/Libreville' => 'Wektu Afrika Kulon (Libreville)',
        'Africa/Lome' => 'Wektu Rerata Greenwich (Lome)',
        'Africa/Luanda' => 'Wektu Afrika Kulon (Luanda)',
        'Africa/Lubumbashi' => 'Wektu Afrika Tengah (Lubumbashi)',
        'Africa/Lusaka' => 'Wektu Afrika Tengah (Lusaka)',
        'Africa/Malabo' => 'Wektu Afrika Kulon (Malabo)',
        'Africa/Maputo' => 'Wektu Afrika Tengah (Maputo)',
        'Africa/Maseru' => 'Wektu Standar Afrika Kidul (Maseru)',
        'Africa/Mbabane' => 'Wektu Standar Afrika Kidul (Mbabane)',
        'Africa/Mogadishu' => 'Wektu Afrika Wetan (Mogadishu)',
        'Africa/Monrovia' => 'Wektu Rerata Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Wektu Afrika Wetan (Nairobi)',
        'Africa/Ndjamena' => 'Wektu Afrika Kulon (Ndjamena)',
        'Africa/Niamey' => 'Wektu Afrika Kulon (Niamey)',
        'Africa/Nouakchott' => 'Wektu Rerata Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Wektu Rerata Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Wektu Afrika Kulon (Porto-Novo)',
        'Africa/Sao_Tome' => 'Wektu Rerata Greenwich (Sao Tome)',
        'Africa/Tripoli' => 'Wektu Eropa sisih Wetan (Tripoli)',
        'Africa/Tunis' => 'Wektu Eropa Tengah (Tunis)',
        'Africa/Windhoek' => 'Wektu Afrika Tengah (Windhoek)',
        'America/Adak' => 'Wektu Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Wektu Alaska (Anchorage)',
        'America/Anguilla' => 'Wektu Atlantik (Anguilla)',
        'America/Antigua' => 'Wektu Atlantik (Antigua)',
        'America/Araguaina' => 'Wektu Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'Wektu Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Wektu Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Wektu Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Wektu Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Wektu Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Wektu Argentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'Wektu Argentina (Ushuaia)',
        'America/Aruba' => 'Wektu Atlantik (Aruba)',
        'America/Asuncion' => 'Wektu Paraguay (Asuncion)',
        'America/Bahia' => 'Wektu Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Wektu Tengah (Bahia Banderas)',
        'America/Barbados' => 'Wektu Atlantik (Barbados)',
        'America/Belem' => 'Wektu Brasilia (Belem)',
        'America/Belize' => 'Wektu Tengah (Belise)',
        'America/Blanc-Sablon' => 'Wektu Atlantik (Blanc-Sablon)',
        'America/Boa_Vista' => 'Wektu Amazon (Boa Vista)',
        'America/Bogota' => 'Wektu Kolombia (Bogota)',
        'America/Boise' => 'Wektu Giri (Boise)',
        'America/Buenos_Aires' => 'Wektu Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Wektu Giri (Teluk Cambridge)',
        'America/Campo_Grande' => 'Wektu Amazon (Kampo Grande)',
        'America/Cancun' => 'Wektu sisih Wetan (Cancun)',
        'America/Caracas' => 'Wektu Venezuela (Karakas)',
        'America/Catamarca' => 'Wektu Argentina (Katamarka)',
        'America/Cayenne' => 'Wektu Guiana Prancis (Kayenne)',
        'America/Cayman' => 'Wektu sisih Wetan (Caiman)',
        'America/Chicago' => 'Wektu Tengah (Chicago)',
        'America/Chihuahua' => 'Wektu Pasifik Meksiko (Chihuahua)',
        'America/Coral_Harbour' => 'Wektu sisih Wetan (Atikokan)',
        'America/Cordoba' => 'Wektu Argentina (Kordoba)',
        'America/Costa_Rica' => 'Wektu Tengah (Kosta Rika)',
        'America/Creston' => 'Wektu Giri (Creston)',
        'America/Cuiaba' => 'Wektu Amazon (Kuiaba)',
        'America/Curacao' => 'Wektu Atlantik (Curacao)',
        'America/Danmarkshavn' => 'Wektu Rerata Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Wektu Yukon (Dawson)',
        'America/Dawson_Creek' => 'Wektu Giri (Dawson Creek)',
        'America/Denver' => 'Wektu Giri (Denver)',
        'America/Detroit' => 'Wektu sisih Wetan (Detroit)',
        'America/Dominica' => 'Wektu Atlantik (Dominika)',
        'America/Edmonton' => 'Wektu Giri (Edmonton)',
        'America/Eirunepe' => 'Wektu Brasil (Eirunepe)',
        'America/El_Salvador' => 'Wektu Tengah (El Salvador)',
        'America/Fort_Nelson' => 'Wektu Giri (Benteng Nelson)',
        'America/Fortaleza' => 'Wektu Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Wektu Atlantik (Teluk Glace)',
        'America/Godthab' => 'Wektu Grinland Kulon (Nuuk)',
        'America/Goose_Bay' => 'Wektu Atlantik (Teluk Goose)',
        'America/Grand_Turk' => 'Wektu sisih Wetan (Grand Turk)',
        'America/Grenada' => 'Wektu Atlantik (Grenada)',
        'America/Guadeloupe' => 'Wektu Atlantik (Guadeloupe)',
        'America/Guatemala' => 'Wektu Tengah (Guatemala)',
        'America/Guayaquil' => 'Wektu Ekuador (Guayaquil)',
        'America/Guyana' => 'Wektu Guyana',
        'America/Halifax' => 'Wektu Atlantik (Halifak)',
        'America/Havana' => 'Wektu Kuba (Havana)',
        'America/Hermosillo' => 'Wektu Pasifik Meksiko (Hermosillo)',
        'America/Indiana/Knox' => 'Wektu Tengah (Knox [Indiana])',
        'America/Indiana/Marengo' => 'Wektu sisih Wetan (Marengo [Indiana])',
        'America/Indiana/Petersburg' => 'Wektu sisih Wetan (Petersburg [Indiana])',
        'America/Indiana/Tell_City' => 'Wektu Tengah (Tell City [Indiana])',
        'America/Indiana/Vevay' => 'Wektu sisih Wetan (Vevay [Indiana])',
        'America/Indiana/Vincennes' => 'Wektu sisih Wetan (Vincennes [Indiana])',
        'America/Indiana/Winamac' => 'Wektu sisih Wetan (Winamac [Indiana])',
        'America/Indianapolis' => 'Wektu sisih Wetan (Indianapolis)',
        'America/Inuvik' => 'Wektu Giri (Inuvik)',
        'America/Iqaluit' => 'Wektu sisih Wetan (Iqaluit)',
        'America/Jamaica' => 'Wektu sisih Wetan (Jamaica)',
        'America/Jujuy' => 'Wektu Argentina (Jujuy)',
        'America/Juneau' => 'Wektu Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Wektu sisih Wetan (Monticello [Kentucky])',
        'America/Kralendijk' => 'Wektu Atlantik (Kralendijk)',
        'America/La_Paz' => 'Wektu Bolivia (La Paz)',
        'America/Lima' => 'Wektu Peru (Lima)',
        'America/Los_Angeles' => 'Wektu Pasifik (Los Angeles)',
        'America/Louisville' => 'Wektu sisih Wetan (Louisville)',
        'America/Lower_Princes' => 'Wektu Atlantik (Lower Prince’s Quarter)',
        'America/Maceio' => 'Wektu Brasilia (Maceio)',
        'America/Managua' => 'Wektu Tengah (Managua)',
        'America/Manaus' => 'Wektu Amazon (Manaus)',
        'America/Marigot' => 'Wektu Atlantik (Marigot)',
        'America/Martinique' => 'Wektu Atlantik (Martinik)',
        'America/Matamoros' => 'Wektu Tengah (Matamoros)',
        'America/Mazatlan' => 'Wektu Pasifik Meksiko (Mazatlan)',
        'America/Mendoza' => 'Wektu Argentina (Mendosa)',
        'America/Menominee' => 'Wektu Tengah (Menominee)',
        'America/Merida' => 'Wektu Tengah (Merida)',
        'America/Metlakatla' => 'Wektu Alaska (Metlakatla)',
        'America/Mexico_City' => 'Wektu Tengah (Kutho Meksiko)',
        'America/Miquelon' => 'Wektu Santa Pierre lan Miquelon',
        'America/Moncton' => 'Wektu Atlantik (Moncton)',
        'America/Monterrey' => 'Wektu Tengah (Monterrey)',
        'America/Montevideo' => 'Wektu Uruguay (Montevideo)',
        'America/Montreal' => 'Wektu Kanada (Montreal)',
        'America/Montserrat' => 'Wektu Atlantik (Montserrat)',
        'America/Nassau' => 'Wektu sisih Wetan (Nassau)',
        'America/New_York' => 'Wektu sisih Wetan (New York)',
        'America/Nipigon' => 'Wektu sisih Wetan (Nipigon)',
        'America/Nome' => 'Wektu Alaska (Nome)',
        'America/Noronha' => 'Wektu Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Wektu Tengah (Beulah [Dakota Lor])',
        'America/North_Dakota/Center' => 'Wektu Tengah (Tengah [Dakota Lor])',
        'America/North_Dakota/New_Salem' => 'Wektu Tengah (Salem Anyar [Dakota Lor])',
        'America/Ojinaga' => 'Wektu Giri (Ojinaga)',
        'America/Panama' => 'Wektu sisih Wetan (Panama)',
        'America/Pangnirtung' => 'Wektu sisih Wetan (Pangnirtung)',
        'America/Paramaribo' => 'Wektu Suriname (Paramaribo)',
        'America/Phoenix' => 'Wektu Giri (Phoenix)',
        'America/Port-au-Prince' => 'Wektu sisih Wetan (Port-au-Prince)',
        'America/Port_of_Spain' => 'Wektu Atlantik (Palabuhan Spanyol)',
        'America/Porto_Velho' => 'Wektu Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'Wektu Atlantik (Puerto Riko)',
        'America/Punta_Arenas' => 'Wektu Chili (Punta Arenas)',
        'America/Rainy_River' => 'Wektu Tengah (Kali Rainy)',
        'America/Rankin_Inlet' => 'Wektu Tengah (Rankin Inlet)',
        'America/Recife' => 'Wektu Brasilia (Recife)',
        'America/Regina' => 'Wektu Tengah (Regina)',
        'America/Resolute' => 'Wektu Tengah (Resolute)',
        'America/Rio_Branco' => 'Wektu Brasil (Rio Branco)',
        'America/Santa_Isabel' => 'Wektu Meksiko Lor-Kulon (Santa Isabel)',
        'America/Santarem' => 'Wektu Brasilia (Santarem)',
        'America/Santiago' => 'Wektu Chili (Santiago)',
        'America/Santo_Domingo' => 'Wektu Atlantik (Santo Domingo)',
        'America/Sao_Paulo' => 'Wektu Brasilia (Sao Paulo)',
        'America/Scoresbysund' => 'Wektu Grinland Wetan (Ittoqqortoormiit)',
        'America/Sitka' => 'Wektu Alaska (Sitka)',
        'America/St_Barthelemy' => 'Wektu Atlantik (Santa Barthelemy)',
        'America/St_Johns' => 'Wektu Newfoundland (Santa John)',
        'America/St_Kitts' => 'Wektu Atlantik (Santa Kitts)',
        'America/St_Lucia' => 'Wektu Atlantik (Santa Lucia)',
        'America/St_Thomas' => 'Wektu Atlantik (Santa Thomas)',
        'America/St_Vincent' => 'Wektu Atlantik (Santa Vincent)',
        'America/Swift_Current' => 'Wektu Tengah (Arus Banter)',
        'America/Tegucigalpa' => 'Wektu Tengah (Tegucigalpa)',
        'America/Thule' => 'Wektu Atlantik (Thule)',
        'America/Thunder_Bay' => 'Wektu sisih Wetan (Teluk Gludhug)',
        'America/Tijuana' => 'Wektu Pasifik (Tijuana)',
        'America/Toronto' => 'Wektu sisih Wetan (Toronto)',
        'America/Tortola' => 'Wektu Atlantik (Tortola)',
        'America/Vancouver' => 'Wektu Pasifik (Vancouver)',
        'America/Whitehorse' => 'Wektu Yukon (Whitehorse)',
        'America/Winnipeg' => 'Wektu Tengah (Winnipeg)',
        'America/Yakutat' => 'Wektu Alaska (Yakutat)',
        'America/Yellowknife' => 'Wektu Giri (Yellowknife)',
        'Antarctica/Casey' => 'Wektu Antartika (Casey)',
        'Antarctica/Davis' => 'Wektu Davis',
        'Antarctica/DumontDUrville' => 'Wektu Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Wektu Australia sisih Wetan (Macquarie)',
        'Antarctica/Mawson' => 'Wektu Mawson',
        'Antarctica/McMurdo' => 'Wektu Selandia Anyar (McMurdo)',
        'Antarctica/Palmer' => 'Wektu Chili (Palmer)',
        'Antarctica/Rothera' => 'Wektu Rothera',
        'Antarctica/Syowa' => 'Wektu Syowa',
        'Antarctica/Troll' => 'Wektu Rerata Greenwich (Troll)',
        'Antarctica/Vostok' => 'Wektu Vostok',
        'Arctic/Longyearbyen' => 'Wektu Eropa Tengah (Longyearbyen)',
        'Asia/Aden' => 'Wektu Arab (Aden)',
        'Asia/Almaty' => 'Wektu Kazakhstan Wetan (Almaty)',
        'Asia/Amman' => 'Wektu Eropa sisih Wetan (Amman)',
        'Asia/Anadyr' => 'Wektu Rusia (Anadyr)',
        'Asia/Aqtau' => 'Wektu Kazakhstan Kulon (Aqtau)',
        'Asia/Aqtobe' => 'Wektu Kazakhstan Kulon (Aqtobe)',
        'Asia/Ashgabat' => 'Wektu Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Wektu Kazakhstan Kulon (Atyrau)',
        'Asia/Baghdad' => 'Wektu Arab (Baghdad)',
        'Asia/Bahrain' => 'Wektu Arab (Bahrain)',
        'Asia/Baku' => 'Wektu Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Wektu Indocina (Bangkok)',
        'Asia/Barnaul' => 'Wektu Rusia (Barnaul)',
        'Asia/Beirut' => 'Wektu Eropa sisih Wetan (Beirut)',
        'Asia/Bishkek' => 'Wektu Kirgizstan (Bishkek)',
        'Asia/Brunei' => 'Wektu Brunai Darussalam (Brunei)',
        'Asia/Calcutta' => 'Wektu Standar India (Kalkuta)',
        'Asia/Chita' => 'Wektu Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Wektu Ulaanbaatar (Choibalsan)',
        'Asia/Colombo' => 'Wektu Standar India (Kolombo)',
        'Asia/Damascus' => 'Wektu Eropa sisih Wetan (Damaskus)',
        'Asia/Dhaka' => 'Wektu Bangladesh (Dhaka)',
        'Asia/Dili' => 'Wektu Timor Leste (Dili)',
        'Asia/Dubai' => 'Wektu Standar Teluk (Dubai)',
        'Asia/Dushanbe' => 'Wektu Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Wektu Eropa sisih Wetan (Famagusta)',
        'Asia/Gaza' => 'Wektu Eropa sisih Wetan (Gaza)',
        'Asia/Hebron' => 'Wektu Eropa sisih Wetan (Hebron)',
        'Asia/Hong_Kong' => 'Wektu Hong Kong',
        'Asia/Hovd' => 'Wektu Hovd',
        'Asia/Irkutsk' => 'Wektu Irkutsk',
        'Asia/Jakarta' => 'Wektu Indonesia sisih Kulon (Jakarta)',
        'Asia/Jayapura' => 'Wektu Indonesia sisih Wetan (Jayapura)',
        'Asia/Jerusalem' => 'Wektu Israel (Yerusalem)',
        'Asia/Kabul' => 'Wektu Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Wektu Rusia (Kamchatka)',
        'Asia/Karachi' => 'Wektu Pakistan (Karachi)',
        'Asia/Katmandu' => 'Wektu Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Wektu Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Wektu Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Wektu Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Wektu Malaysia (Kuching)',
        'Asia/Kuwait' => 'Wektu Arab (Kuwait)',
        'Asia/Macau' => 'Wektu Cina (Macau)',
        'Asia/Magadan' => 'Wektu Magadan',
        'Asia/Makassar' => 'Wektu Indonesia Tengah (Makasar)',
        'Asia/Manila' => 'Wektu Filipina (Manila)',
        'Asia/Muscat' => 'Wektu Standar Teluk (Muscat)',
        'Asia/Nicosia' => 'Wektu Eropa sisih Wetan (Nicosia)',
        'Asia/Novokuznetsk' => 'Wektu Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Wektu Novosibirsk',
        'Asia/Omsk' => 'Wektu Omsk',
        'Asia/Oral' => 'Wektu Kazakhstan Kulon (Oral)',
        'Asia/Phnom_Penh' => 'Wektu Indocina (Phnom Penh)',
        'Asia/Pontianak' => 'Wektu Indonesia sisih Kulon (Pontianak)',
        'Asia/Pyongyang' => 'Wektu Korea (Pyongyang)',
        'Asia/Qatar' => 'Wektu Arab (Qatar)',
        'Asia/Qostanay' => 'Wektu Kazakhstan Wetan (Kostanai)',
        'Asia/Qyzylorda' => 'Wektu Kazakhstan Kulon (Qyzylorda)',
        'Asia/Rangoon' => 'Wektu Myanmar (Yangon)',
        'Asia/Riyadh' => 'Wektu Arab (Riyadh)',
        'Asia/Saigon' => 'Wektu Indocina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Wektu Sakhalin',
        'Asia/Samarkand' => 'Wektu Usbekistan (Samarkand)',
        'Asia/Seoul' => 'Wektu Korea (Seoul)',
        'Asia/Shanghai' => 'Wektu Cina (Shanghai)',
        'Asia/Singapore' => 'Wektu Singapura',
        'Asia/Srednekolymsk' => 'Wektu Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Wektu Taipei',
        'Asia/Tashkent' => 'Wektu Usbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Wektu Georgia (Tbilisi)',
        'Asia/Tehran' => 'Wektu Iran (Teheran)',
        'Asia/Thimphu' => 'Wektu Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Wektu Jepang (Tokyo)',
        'Asia/Tomsk' => 'Wektu Rusia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Wektu Ulaanbaatar',
        'Asia/Urumqi' => 'Wektu Tyongkok (Urumqi)',
        'Asia/Ust-Nera' => 'Wektu Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Wektu Indocina (Vientiane)',
        'Asia/Vladivostok' => 'Wektu Vladivostok',
        'Asia/Yakutsk' => 'Wektu Yakutsk',
        'Asia/Yekaterinburg' => 'Wektu Yekaterinburg',
        'Asia/Yerevan' => 'Wektu Armenia (Yerevan)',
        'Atlantic/Azores' => 'Wektu Azores',
        'Atlantic/Bermuda' => 'Wektu Atlantik (Bermuda)',
        'Atlantic/Canary' => 'Wektu Eropa sisih Kulon (Kanari)',
        'Atlantic/Cape_Verde' => 'Wektu Tanjung Verde (Kape Verde)',
        'Atlantic/Faeroe' => 'Wektu Eropa sisih Kulon (Faroe)',
        'Atlantic/Madeira' => 'Wektu Eropa sisih Kulon (Madeira)',
        'Atlantic/Reykjavik' => 'Wektu Rerata Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Wektu Georgia Kidul',
        'Atlantic/St_Helena' => 'Wektu Rerata Greenwich (Santa Helena)',
        'Atlantic/Stanley' => 'Wektu Kepuloan Falkland (Stanley)',
        'Australia/Adelaide' => 'Wektu Australia Tengah (Adelaide)',
        'Australia/Brisbane' => 'Wektu Australia sisih Wetan (Brisbane)',
        'Australia/Broken_Hill' => 'Wektu Australia Tengah (Broken Hill)',
        'Australia/Currie' => 'Wektu Australia sisih Wetan (Currie)',
        'Australia/Darwin' => 'Wektu Australia Tengah (Darwin)',
        'Australia/Eucla' => 'Wektu Australia Tengah sisih Kulon (Eucla)',
        'Australia/Hobart' => 'Wektu Australia sisih Wetan (Hobart)',
        'Australia/Lindeman' => 'Wektu Australia sisih Wetan (Lindeman)',
        'Australia/Lord_Howe' => 'Wektu Lord Howe',
        'Australia/Melbourne' => 'Wektu Australia sisih Wetan (Melbourne)',
        'Australia/Perth' => 'Wektu Australia sisih Kulon (Perth)',
        'Australia/Sydney' => 'Wektu Australia sisih Wetan (Sydney)',
        'CST6CDT' => 'Wektu Tengah',
        'EST5EDT' => 'Wektu sisih Wetan',
        'Etc/GMT' => 'Wektu Rerata Greenwich',
        'Etc/UTC' => 'Wektu Universal Kakoordhinasi',
        'Europe/Amsterdam' => 'Wektu Eropa Tengah (Amsterdam)',
        'Europe/Andorra' => 'Wektu Eropa Tengah (Andorra)',
        'Europe/Astrakhan' => 'Wektu Moscow (Astrakhan)',
        'Europe/Athens' => 'Wektu Eropa sisih Wetan (Athena)',
        'Europe/Belgrade' => 'Wektu Eropa Tengah (Belgrade)',
        'Europe/Berlin' => 'Wektu Eropa Tengah (Berlin)',
        'Europe/Bratislava' => 'Wektu Eropa Tengah (Bratislava)',
        'Europe/Brussels' => 'Wektu Eropa Tengah (Brussels)',
        'Europe/Bucharest' => 'Wektu Eropa sisih Wetan (Bucharest)',
        'Europe/Budapest' => 'Wektu Eropa Tengah (Budapest)',
        'Europe/Busingen' => 'Wektu Eropa Tengah (Busingen)',
        'Europe/Chisinau' => 'Wektu Eropa sisih Wetan (Chisinau)',
        'Europe/Copenhagen' => 'Wektu Eropa Tengah (Kopenhagen)',
        'Europe/Dublin' => 'Wektu Rerata Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Wektu Eropa Tengah (Gibraltar)',
        'Europe/Guernsey' => 'Wektu Rerata Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Wektu Eropa sisih Wetan (Helsinki)',
        'Europe/Isle_of_Man' => 'Wektu Rerata Greenwich (Pulo Man)',
        'Europe/Istanbul' => 'Wektu Turki (Istanbul)',
        'Europe/Jersey' => 'Wektu Rerata Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Wektu Eropa sisih Wetan (Kaliningrad)',
        'Europe/Kiev' => 'Wektu Eropa sisih Wetan (Kiev)',
        'Europe/Kirov' => 'Wektu Rusia (Kirov)',
        'Europe/Lisbon' => 'Wektu Eropa sisih Kulon (Lisbon)',
        'Europe/Ljubljana' => 'Wektu Eropa Tengah (Ljubljana)',
        'Europe/London' => 'Wektu Rerata Greenwich (London)',
        'Europe/Luxembourg' => 'Wektu Eropa Tengah (Luksemburk)',
        'Europe/Madrid' => 'Wektu Eropa Tengah (Madrid)',
        'Europe/Malta' => 'Wektu Eropa Tengah (Malta)',
        'Europe/Mariehamn' => 'Wektu Eropa sisih Wetan (Mariehamn)',
        'Europe/Minsk' => 'Wektu Moscow (Minsk)',
        'Europe/Monaco' => 'Wektu Eropa Tengah (Monako)',
        'Europe/Moscow' => 'Wektu Moscow',
        'Europe/Oslo' => 'Wektu Eropa Tengah (Oslo)',
        'Europe/Paris' => 'Wektu Eropa Tengah (Paris)',
        'Europe/Podgorica' => 'Wektu Eropa Tengah (Podgorica)',
        'Europe/Prague' => 'Wektu Eropa Tengah (Prague)',
        'Europe/Riga' => 'Wektu Eropa sisih Wetan (Riga)',
        'Europe/Rome' => 'Wektu Eropa Tengah (Roma)',
        'Europe/Samara' => 'Wektu Rusia (Samara)',
        'Europe/San_Marino' => 'Wektu Eropa Tengah (San Marino)',
        'Europe/Sarajevo' => 'Wektu Eropa Tengah (Sarajevo)',
        'Europe/Saratov' => 'Wektu Moscow (Saratov)',
        'Europe/Simferopol' => 'Wektu Moscow (Simferopol)',
        'Europe/Skopje' => 'Wektu Eropa Tengah (Skopje)',
        'Europe/Sofia' => 'Wektu Eropa sisih Wetan (Sofia)',
        'Europe/Stockholm' => 'Wektu Eropa Tengah (Stockholm)',
        'Europe/Tallinn' => 'Wektu Eropa sisih Wetan (Tallinn)',
        'Europe/Tirane' => 'Wektu Eropa Tengah (Tirane)',
        'Europe/Ulyanovsk' => 'Wektu Moscow (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Wektu Eropa sisih Wetan (Uzhgorod)',
        'Europe/Vaduz' => 'Wektu Eropa Tengah (Vaduz)',
        'Europe/Vatican' => 'Wektu Eropa Tengah (Vatikan)',
        'Europe/Vienna' => 'Wektu Eropa Tengah (Vienna)',
        'Europe/Vilnius' => 'Wektu Eropa sisih Wetan (Vilnius)',
        'Europe/Volgograd' => 'Wektu Volgograd',
        'Europe/Warsaw' => 'Wektu Eropa Tengah (Warsaw)',
        'Europe/Zagreb' => 'Wektu Eropa Tengah (Zagreb)',
        'Europe/Zaporozhye' => 'Wektu Eropa sisih Wetan (Zaporozhye)',
        'Europe/Zurich' => 'Wektu Eropa Tengah (Zurich)',
        'Indian/Antananarivo' => 'Wektu Afrika Wetan (Antananarivo)',
        'Indian/Chagos' => 'Wektu Segoro Hindia (Khagos)',
        'Indian/Christmas' => 'Wektu Pulo Natal',
        'Indian/Cocos' => 'Wektu Kepuloan Cocos',
        'Indian/Comoro' => 'Wektu Afrika Wetan (Komoro)',
        'Indian/Kerguelen' => 'Wektu Antartika lan Prancis sisih Kidul (Kerguelen)',
        'Indian/Mahe' => 'Wektu Seichelles (Mahe)',
        'Indian/Maldives' => 'Wektu Maladewa',
        'Indian/Mauritius' => 'Wektu Mauritius',
        'Indian/Mayotte' => 'Wektu Afrika Wetan (Mayotte)',
        'Indian/Reunion' => 'Wektu Reunion',
        'MST7MDT' => 'Wektu Giri',
        'PST8PDT' => 'Wektu Pasifik',
        'Pacific/Apia' => 'Wektu Apia',
        'Pacific/Auckland' => 'Wektu Selandia Anyar (Auckland)',
        'Pacific/Bougainville' => 'Wektu Papua Nugini (Bougainville)',
        'Pacific/Chatham' => 'Wektu Chatham',
        'Pacific/Easter' => 'Wektu Pulo Paskah',
        'Pacific/Efate' => 'Wektu Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Wektu Kepuloan Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Wektu Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Wektu Fiji',
        'Pacific/Funafuti' => 'Wektu Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Wektu Galapagos',
        'Pacific/Gambier' => 'Wektu Gambier',
        'Pacific/Guadalcanal' => 'Wektu Kepuloan Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Wektu Chamorro (Guam)',
        'Pacific/Honolulu' => 'Wektu Hawaii-Aleutian (Honolulu)',
        'Pacific/Johnston' => 'Wektu Hawaii-Aleutian (Johnston)',
        'Pacific/Kiritimati' => 'Wektu Kepuloan Line (Kiritimati)',
        'Pacific/Kosrae' => 'Wektu Kosrae',
        'Pacific/Kwajalein' => 'Wektu Kepuloan Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Wektu Kepuloan Marshall (Majuro)',
        'Pacific/Marquesas' => 'Wektu Marquesas',
        'Pacific/Midway' => 'Wektu Samoa (Midway)',
        'Pacific/Nauru' => 'Wektu Nauru',
        'Pacific/Niue' => 'Wektu Niue',
        'Pacific/Norfolk' => 'Wektu Pulo Norfolk',
        'Pacific/Noumea' => 'Wektu Kaledonia Anyar (Noumea)',
        'Pacific/Pago_Pago' => 'Wektu Samoa (Pago Pago)',
        'Pacific/Palau' => 'Wektu Palau',
        'Pacific/Pitcairn' => 'Wektu Pitcairn',
        'Pacific/Ponape' => 'Wektu Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Wektu Papua Nugini (Pelabuhan Moresby)',
        'Pacific/Rarotonga' => 'Wektu Kepuloan Cook (Rarotonga)',
        'Pacific/Saipan' => 'Wektu Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Wektu Tahiti',
        'Pacific/Tarawa' => 'Wektu Kepuloan Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Wektu Tonga (Tongatapu)',
        'Pacific/Truk' => 'Wektu Chuuk',
        'Pacific/Wake' => 'Wektu Pulo Wake',
        'Pacific/Wallis' => 'Wektu Wallis lan Futuna',
    ],
    'Meta' => [
    ],
];
