<?php

return [
    'Names' => [
        'aa' => 'アファル語',
        'ab' => 'アブハズ語',
        'ace' => 'アチェ語',
        'ach' => 'アチョリ語',
        'ada' => 'アダングメ語',
        'ady' => 'アディゲ語',
        'ae' => 'アヴェスタ語',
        'aeb' => 'チュニジア・アラビア語',
        'af' => 'アフリカーンス語',
        'afh' => 'アフリヒリ語',
        'agq' => 'アゲム語',
        'ain' => 'アイヌ語',
        'ak' => 'アカン語',
        'akk' => 'アッカド語',
        'akz' => 'アラバマ語',
        'ale' => 'アレウト語',
        'aln' => 'ゲグ・アルバニア語',
        'alt' => '南アルタイ語',
        'am' => 'アムハラ語',
        'an' => 'アラゴン語',
        'ang' => '古英語',
        'ann' => 'オボロ語',
        'anp' => 'アンギカ語',
        'ar' => 'アラビア語',
        'arc' => 'アラム語',
        'arn' => 'マプチェ語',
        'aro' => 'アラオナ語',
        'arp' => 'アラパホー語',
        'arq' => 'アルジェリア・アラビア語',
        'ars' => 'ナジュド地方・アラビア語',
        'arw' => 'アラワク語',
        'ary' => 'モロッコ・アラビア語',
        'arz' => 'エジプト・アラビア語',
        'as' => 'アッサム語',
        'asa' => 'アス語',
        'ase' => 'アメリカ手話',
        'ast' => 'アストゥリアス語',
        'atj' => 'アティカメク語',
        'av' => 'アヴァル語',
        'avk' => 'コタヴァ',
        'awa' => 'アワディー語',
        'ay' => 'アイマラ語',
        'az' => 'アゼルバイジャン語',
        'ba' => 'バシキール語',
        'bal' => 'バルーチー語',
        'ban' => 'バリ語',
        'bar' => 'バイエルン・オーストリア語',
        'bas' => 'バサ語',
        'bax' => 'バムン語',
        'bbc' => 'トバ・バタク語',
        'bbj' => 'ゴーマラ語',
        'be' => 'ベラルーシ語',
        'bej' => 'ベジャ語',
        'bem' => 'ベンバ語',
        'bew' => 'ベタウィ語',
        'bez' => 'ベナ語',
        'bfd' => 'バフット語',
        'bfq' => 'バダガ語',
        'bg' => 'ブルガリア語',
        'bgn' => '西バローチー語',
        'bho' => 'ボージュプリー語',
        'bi' => 'ビスラマ語',
        'bik' => 'ビコル語',
        'bin' => 'ビニ語',
        'bjn' => 'バンジャル語',
        'bkm' => 'コム語',
        'bla' => 'シクシカ語',
        'bm' => 'バンバラ語',
        'bn' => 'ベンガル語',
        'bo' => 'チベット語',
        'bpy' => 'ビシュヌプリヤ・マニプリ語',
        'bqi' => 'バフティヤーリー語',
        'br' => 'ブルトン語',
        'bra' => 'ブラジ語',
        'brh' => 'ブラフイ語',
        'brx' => 'ボド語',
        'bs' => 'ボスニア語',
        'bss' => 'アコース語',
        'bua' => 'ブリヤート語',
        'bug' => 'ブギ語',
        'bum' => 'ブル語',
        'byn' => 'ビリン語',
        'byv' => 'メドゥンバ語',
        'ca' => 'カタロニア語',
        'cad' => 'カドー語',
        'car' => 'カリブ語',
        'cay' => 'カユーガ語',
        'cch' => 'チャワイ語',
        'ccp' => 'チャクマ語',
        'ce' => 'チェチェン語',
        'ceb' => 'セブアノ語',
        'cgg' => 'チガ語',
        'ch' => 'チャモロ語',
        'chb' => 'チブチャ語',
        'chg' => 'チャガタイ語',
        'chk' => 'チューク語',
        'chm' => 'マリ語',
        'chn' => 'チヌーク混成語',
        'cho' => 'チョクトー語',
        'chp' => 'チペワイアン語',
        'chr' => 'チェロキー語',
        'chy' => 'シャイアン語',
        'ckb' => '中央クルド語',
        'clc' => 'チルコーティン語',
        'co' => 'コルシカ語',
        'cop' => 'コプト語',
        'cps' => 'カピス語',
        'cr' => 'クリー語',
        'crg' => 'ミチフ語',
        'crh' => 'クリミア・タタール語',
        'crj' => '東部クリー語(南部)',
        'crk' => '平原クリー語',
        'crl' => '東部クリー語(北部)',
        'crm' => 'ムースクリー語',
        'crr' => 'カロライナ・アルゴンキン語',
        'crs' => 'セーシェル・クレオール語',
        'cs' => 'チェコ語',
        'csb' => 'カシューブ語',
        'csw' => '湿原クリー語',
        'cu' => '教会スラブ語',
        'cv' => 'チュヴァシ語',
        'cy' => 'ウェールズ語',
        'da' => 'デンマーク語',
        'dak' => 'ダコタ語',
        'dar' => 'ダルグワ語',
        'dav' => 'タイタ語',
        'de' => 'ドイツ語',
        'del' => 'デラウェア語',
        'den' => 'スレイビー語',
        'dgr' => 'ドグリブ語',
        'din' => 'ディンカ語',
        'dje' => 'ザルマ語',
        'doi' => 'ドーグリー語',
        'dsb' => '低地ソルブ語',
        'dtp' => '中央ドゥスン語',
        'dua' => 'ドゥアラ語',
        'dum' => '中世オランダ語',
        'dv' => 'ディベヒ語',
        'dyo' => 'ジョラ＝フォニィ語',
        'dyu' => 'ジュラ語',
        'dz' => 'ゾンカ語',
        'dzg' => 'ダザガ語',
        'ebu' => 'エンブ語',
        'ee' => 'エウェ語',
        'efi' => 'エフィク語',
        'egl' => 'エミリア語',
        'egy' => '古代エジプト語',
        'eka' => 'エカジュク語',
        'el' => 'ギリシャ語',
        'elx' => 'エラム語',
        'en' => '英語',
        'enm' => '中英語',
        'eo' => 'エスペラント語',
        'es' => 'スペイン語',
        'esu' => '中央アラスカ・ユピック語',
        'et' => 'エストニア語',
        'eu' => 'バスク語',
        'ewo' => 'エウォンド語',
        'ext' => 'エストレマドゥーラ語',
        'fa' => 'ペルシア語',
        'fan' => 'ファング語',
        'fat' => 'ファンティー語',
        'ff' => 'フラ語',
        'fi' => 'フィンランド語',
        'fil' => 'フィリピノ語',
        'fit' => 'トルネダール・フィンランド語',
        'fj' => 'フィジー語',
        'fo' => 'フェロー語',
        'fon' => 'フォン語',
        'fr' => 'フランス語',
        'frc' => 'ケイジャン・フランス語',
        'frm' => '中期フランス語',
        'fro' => '古フランス語',
        'frp' => 'アルピタン語',
        'frr' => '北フリジア語',
        'frs' => '東フリジア語',
        'fur' => 'フリウリ語',
        'fy' => '西フリジア語',
        'ga' => 'アイルランド語',
        'gaa' => 'ガ語',
        'gag' => 'ガガウズ語',
        'gan' => '贛語',
        'gay' => 'ガヨ語',
        'gba' => 'バヤ語',
        'gbz' => 'ダリー語(ゾロアスター教)',
        'gd' => 'スコットランド・ゲール語',
        'gez' => 'ゲエズ語',
        'gil' => 'キリバス語',
        'gl' => 'ガリシア語',
        'glk' => 'ギラキ語',
        'gmh' => '中高ドイツ語',
        'gn' => 'グアラニー語',
        'goh' => '古高ドイツ語',
        'gom' => 'ゴア・コンカニ語',
        'gon' => 'ゴーンディー語',
        'gor' => 'ゴロンタロ語',
        'got' => 'ゴート語',
        'grb' => 'グレボ語',
        'grc' => '古代ギリシャ語',
        'gsw' => 'スイスドイツ語',
        'gu' => 'グジャラート語',
        'guc' => 'ワユ語',
        'gur' => 'フラフラ語',
        'guz' => 'グシイ語',
        'gv' => 'マン島語',
        'gwi' => 'グウィッチン語',
        'ha' => 'ハウサ語',
        'hai' => 'ハイダ語',
        'hak' => '客家語',
        'haw' => 'ハワイ語',
        'hax' => '南部ハイダ語',
        'he' => 'ヘブライ語',
        'hi' => 'ヒンディー語',
        'hif' => 'フィジー・ヒンディー語',
        'hil' => 'ヒリガイノン語',
        'hit' => 'ヒッタイト語',
        'hmn' => 'フモン語',
        'ho' => 'ヒリモツ語',
        'hr' => 'クロアチア語',
        'hsb' => '高地ソルブ語',
        'hsn' => '湘語',
        'ht' => 'ハイチ・クレオール語',
        'hu' => 'ハンガリー語',
        'hup' => 'フパ語',
        'hur' => 'ハルコメレム語',
        'hy' => 'アルメニア語',
        'hz' => 'ヘレロ語',
        'ia' => 'インターリングア',
        'iba' => 'イバン語',
        'ibb' => 'イビビオ語',
        'id' => 'インドネシア語',
        'ie' => 'インターリング',
        'ig' => 'イボ語',
        'ii' => '四川イ語',
        'ik' => 'イヌピアック語',
        'ikt' => 'イヌイナクトゥン語',
        'ilo' => 'イロカノ語',
        'inh' => 'イングーシ語',
        'io' => 'イド語',
        'is' => 'アイスランド語',
        'it' => 'イタリア語',
        'iu' => 'イヌクティトット語',
        'izh' => 'イングリア語',
        'ja' => '日本語',
        'jam' => 'ジャマイカ・クレオール語',
        'jbo' => 'ロジバン語',
        'jgo' => 'ンゴンバ語',
        'jmc' => 'マチャメ語',
        'jpr' => 'ユダヤ・ペルシア語',
        'jrb' => 'ユダヤ・アラビア語',
        'jut' => 'ユトランド語',
        'jv' => 'ジャワ語',
        'ka' => 'ジョージア語',
        'kaa' => 'カラカルパク語',
        'kab' => 'カビル語',
        'kac' => 'カチン語',
        'kaj' => 'カジェ語',
        'kam' => 'カンバ語',
        'kaw' => 'カウィ語',
        'kbd' => 'カバルド語',
        'kbl' => 'カネンブ語',
        'kcg' => 'カタブ語',
        'kde' => 'マコンデ語',
        'kea' => 'カーボベルデ・クレオール語',
        'ken' => 'ニャン語',
        'kfo' => 'コロ語',
        'kg' => 'コンゴ語',
        'kgp' => 'カインガング語',
        'kha' => 'カシ語',
        'kho' => 'コータン語',
        'khq' => 'コイラ・チーニ語',
        'khw' => 'コワール語',
        'ki' => 'キクユ語',
        'kiu' => 'キルマンジュキ語',
        'kj' => 'クワニャマ語',
        'kk' => 'カザフ語',
        'kkj' => 'カコ語',
        'kl' => 'グリーンランド語',
        'kln' => 'カレンジン語',
        'km' => 'クメール語',
        'kmb' => 'キンブンド語',
        'kn' => 'カンナダ語',
        'ko' => '韓国語',
        'koi' => 'コミ・ペルミャク語',
        'kok' => 'コンカニ語',
        'kos' => 'コスラエ語',
        'kpe' => 'クペレ語',
        'kr' => 'カヌリ語',
        'krc' => 'カラチャイ・バルカル語',
        'kri' => 'クリオ語',
        'krj' => 'キナライア語',
        'krl' => 'カレリア語',
        'kru' => 'クルク語',
        'ks' => 'カシミール語',
        'ksb' => 'サンバー語',
        'ksf' => 'バフィア語',
        'ksh' => 'ケルン語',
        'ku' => 'クルド語',
        'kum' => 'クムク語',
        'kut' => 'クテナイ語',
        'kv' => 'コミ語',
        'kw' => 'コーンウォール語',
        'kwk' => 'クヮキゥワラ語',
        'ky' => 'キルギス語',
        'la' => 'ラテン語',
        'lad' => 'ラディノ語',
        'lag' => 'ランギ語',
        'lah' => 'ラフンダー語',
        'lam' => 'ランバ語',
        'lb' => 'ルクセンブルク語',
        'lez' => 'レズギ語',
        'lfn' => 'リングア・フランカ・ノバ',
        'lg' => 'ガンダ語',
        'li' => 'リンブルフ語',
        'lij' => 'リグリア語',
        'lil' => 'リルエット語',
        'liv' => 'リヴォニア語',
        'lkt' => 'ラコタ語',
        'lmo' => 'ロンバルド語',
        'ln' => 'リンガラ語',
        'lo' => 'ラオ語',
        'lol' => 'モンゴ語',
        'lou' => 'ルイジアナ・クレオール語',
        'loz' => 'ロジ語',
        'lrc' => '北ロル語',
        'lsm' => 'サーミア語',
        'lt' => 'リトアニア語',
        'ltg' => 'ラトガリア語',
        'lu' => 'ルバ・カタンガ語',
        'lua' => 'ルバ・ルルア語',
        'lui' => 'ルイセーニョ語',
        'lun' => 'ルンダ語',
        'luo' => 'ルオ語',
        'lus' => 'ミゾ語',
        'luy' => 'ルヒヤ語',
        'lv' => 'ラトビア語',
        'lzh' => '漢文',
        'lzz' => 'ラズ語',
        'mad' => 'マドゥラ語',
        'maf' => 'マファ語',
        'mag' => 'マガヒー語',
        'mai' => 'マイティリー語',
        'mak' => 'マカッサル語',
        'man' => 'マンディンゴ語',
        'mas' => 'マサイ語',
        'mde' => 'マバ語',
        'mdf' => 'モクシャ語',
        'mdr' => 'マンダル語',
        'men' => 'メンデ語',
        'mer' => 'メル語',
        'mfe' => 'モーリシャス・クレオール語',
        'mg' => 'マダガスカル語',
        'mga' => '中期アイルランド語',
        'mgh' => 'マクア・ミート語',
        'mgo' => 'メタ語',
        'mh' => 'マーシャル語',
        'mi' => 'マオリ語',
        'mic' => 'ミクマク語',
        'min' => 'ミナンカバウ語',
        'mk' => 'マケドニア語',
        'ml' => 'マラヤーラム語',
        'mn' => 'モンゴル語',
        'mnc' => '満州語',
        'mni' => 'マニプリ語',
        'moe' => 'イヌー＝アイムン語',
        'moh' => 'モーホーク語',
        'mos' => 'モシ語',
        'mr' => 'マラーティー語',
        'mrj' => '山地マリ語',
        'ms' => 'マレー語',
        'mt' => 'マルタ語',
        'mua' => 'ムンダン語',
        'mus' => 'クリーク語',
        'mwl' => 'ミランダ語',
        'mwr' => 'マールワーリー語',
        'mwv' => 'メンタワイ語',
        'my' => 'ミャンマー語',
        'mye' => 'ミエネ語',
        'myv' => 'エルジャ語',
        'mzn' => 'マーザンダラーン語',
        'na' => 'ナウル語',
        'nan' => '閩南語',
        'nap' => 'ナポリ語',
        'naq' => 'ナマ語',
        'nb' => 'ノルウェー語(ブークモール)',
        'nd' => '北ンデベレ語',
        'nds' => '低地ドイツ語',
        'ne' => 'ネパール語',
        'new' => 'ネワール語',
        'ng' => 'ンドンガ語',
        'nia' => 'ニアス語',
        'niu' => 'ニウーエイ語',
        'njo' => 'アオ・ナガ語',
        'nl' => 'オランダ語',
        'nmg' => 'クワシオ語',
        'nn' => 'ノルウェー語(ニーノシュク)',
        'nnh' => 'ンジエムブーン語',
        'no' => 'ノルウェー語',
        'nog' => 'ノガイ語',
        'non' => '古ノルド語',
        'nov' => 'ノヴィアル',
        'nqo' => 'ンコ語',
        'nr' => '南ンデベレ語',
        'nso' => '北部ソト語',
        'nus' => 'ヌエル語',
        'nv' => 'ナバホ語',
        'nwc' => '古典ネワール語',
        'ny' => 'ニャンジャ語',
        'nym' => 'ニャムウェジ語',
        'nyn' => 'ニャンコレ語',
        'nyo' => 'ニョロ語',
        'nzi' => 'ンゼマ語',
        'oc' => 'オック語',
        'oj' => 'オジブウェー語',
        'ojb' => '北西部オジブワ語',
        'ojc' => '中部オジブワ語',
        'ojs' => 'セヴァーン・オジブワ語',
        'ojw' => '西部オジブワ語',
        'oka' => 'オカナガン語',
        'om' => 'オロモ語',
        'or' => 'オディア語',
        'os' => 'オセット語',
        'osa' => 'オセージ語',
        'ota' => 'オスマントルコ語',
        'pa' => 'パンジャブ語',
        'pag' => 'パンガシナン語',
        'pal' => 'パフラヴィー語',
        'pam' => 'パンパンガ語',
        'pap' => 'パピアメント語',
        'pau' => 'パラオ語',
        'pcd' => 'ピカルディ語',
        'pcm' => 'ナイジェリア・ピジン語',
        'pdc' => 'ペンシルベニア・ドイツ語',
        'pdt' => 'メノナイト低地ドイツ語',
        'peo' => '古代ペルシア語',
        'pfl' => 'プファルツ語',
        'phn' => 'フェニキア語',
        'pi' => 'パーリ語',
        'pis' => 'ピジン語',
        'pl' => 'ポーランド語',
        'pms' => 'ピエモンテ語',
        'pnt' => 'ポントス・ギリシャ語',
        'pon' => 'ポンペイ語',
        'pqm' => 'マリシート＝パサマコディ語',
        'prg' => 'プロシア語',
        'pro' => '古期プロバンス語',
        'ps' => 'パシュトゥー語',
        'pt' => 'ポルトガル語',
        'qu' => 'ケチュア語',
        'quc' => 'キチェ語',
        'qug' => 'チンボラソ高地ケチュア語',
        'raj' => 'ラージャスターン語',
        'rap' => 'ラパヌイ語',
        'rar' => 'ラロトンガ語',
        'rgn' => 'ロマーニャ語',
        'rhg' => 'ロヒンギャ語',
        'rif' => 'リーフ語',
        'rm' => 'ロマンシュ語',
        'rn' => 'ルンディ語',
        'ro' => 'ルーマニア語',
        'rof' => 'ロンボ語',
        'rom' => 'ロマーニー語',
        'rtm' => 'ロツマ語',
        'ru' => 'ロシア語',
        'rue' => 'ルシン語',
        'rug' => 'ロヴィアナ語',
        'rup' => 'アルーマニア語',
        'rw' => 'キニアルワンダ語',
        'rwk' => 'ルワ語',
        'sa' => 'サンスクリット語',
        'sad' => 'サンダウェ語',
        'sah' => 'サハ語',
        'sam' => 'サマリア・アラム語',
        'saq' => 'サンブル語',
        'sas' => 'ササク語',
        'sat' => 'サンターリー語',
        'saz' => 'サウラーシュトラ語',
        'sba' => 'ンガムバイ語',
        'sbp' => 'サング語',
        'sc' => 'サルデーニャ語',
        'scn' => 'シチリア語',
        'sco' => 'スコットランド語',
        'sd' => 'シンド語',
        'sdc' => 'サッサリ・サルデーニャ語',
        'sdh' => '南部クルド語',
        'se' => '北サーミ語',
        'see' => 'セネカ語',
        'seh' => 'セナ語',
        'sei' => 'セリ語',
        'sel' => 'セリクプ語',
        'ses' => 'コイラボロ・センニ語',
        'sg' => 'サンゴ語',
        'sga' => '古アイルランド語',
        'sgs' => 'サモギティア語',
        'sh' => 'セルボ・クロアチア語',
        'shi' => 'タシルハイト語',
        'shn' => 'シャン語',
        'shu' => 'チャド・アラビア語',
        'si' => 'シンハラ語',
        'sid' => 'シダモ語',
        'sk' => 'スロバキア語',
        'sl' => 'スロベニア語',
        'slh' => '南部ルシュツィード語',
        'sli' => '低シレジア語',
        'sly' => 'スラヤール語',
        'sm' => 'サモア語',
        'sma' => '南サーミ語',
        'smj' => 'ルレ・サーミ語',
        'smn' => 'イナリ・サーミ語',
        'sms' => 'スコルト・サーミ語',
        'sn' => 'ショナ語',
        'snk' => 'ソニンケ語',
        'so' => 'ソマリ語',
        'sog' => 'ソグド語',
        'sq' => 'アルバニア語',
        'sr' => 'セルビア語',
        'srn' => 'スリナム語',
        'srr' => 'セレル語',
        'ss' => 'スワジ語',
        'ssy' => 'サホ語',
        'st' => '南部ソト語',
        'stq' => 'ザーターフリジア語',
        'str' => 'ストレイツセイリッシュ語',
        'su' => 'スンダ語',
        'suk' => 'スクマ語',
        'sus' => 'スス語',
        'sux' => 'シュメール語',
        'sv' => 'スウェーデン語',
        'sw' => 'スワヒリ語',
        'swb' => 'コモロ語',
        'syc' => '古典シリア語',
        'syr' => 'シリア語',
        'szl' => 'シレジア語',
        'ta' => 'タミル語',
        'tce' => '南部トゥショーニ語',
        'tcy' => 'トゥル語',
        'te' => 'テルグ語',
        'tem' => 'テムネ語',
        'teo' => 'テソ語',
        'ter' => 'テレーノ語',
        'tet' => 'テトゥン語',
        'tg' => 'タジク語',
        'tgx' => 'タギシュ語',
        'th' => 'タイ語',
        'tht' => 'タールタン語',
        'ti' => 'ティグリニア語',
        'tig' => 'ティグレ語',
        'tiv' => 'ティブ語',
        'tk' => 'トルクメン語',
        'tkl' => 'トケラウ語',
        'tkr' => 'ツァフル語',
        'tl' => 'タガログ語',
        'tlh' => 'クリンゴン語',
        'tli' => 'トリンギット語',
        'tly' => 'タリシュ語',
        'tmh' => 'タマシェク語',
        'tn' => 'ツワナ語',
        'to' => 'トンガ語',
        'tog' => 'トンガ語(ニアサ)',
        'tok' => 'トキポナ語',
        'tpi' => 'トク・ピシン語',
        'tr' => 'トルコ語',
        'tru' => 'トゥロヨ語',
        'trv' => 'タロコ語',
        'ts' => 'ツォンガ語',
        'tsd' => 'ツァコン語',
        'tsi' => 'チムシュ語',
        'tt' => 'タタール語',
        'ttm' => '北部トゥショーニ語',
        'ttt' => 'ムスリム・タタール語',
        'tum' => 'トゥンブカ語',
        'tvl' => 'ツバル語',
        'tw' => 'トウィ語',
        'twq' => 'タサワク語',
        'ty' => 'タヒチ語',
        'tyv' => 'トゥヴァ語',
        'tzm' => '中央アトラス・タマジクト語',
        'udm' => 'ウドムルト語',
        'ug' => 'ウイグル語',
        'uga' => 'ウガリト語',
        'uk' => 'ウクライナ語',
        'umb' => 'ムブンドゥ語',
        'ur' => 'ウルドゥー語',
        'uz' => 'ウズベク語',
        'vai' => 'ヴァイ語',
        've' => 'ベンダ語',
        'vec' => 'ヴェネト語',
        'vep' => 'ヴェプス語',
        'vi' => 'ベトナム語',
        'vls' => '西フラマン語',
        'vmf' => 'マインフランク語',
        'vo' => 'ヴォラピュク語',
        'vot' => 'ヴォート語',
        'vro' => 'ヴォロ語',
        'vun' => 'ヴンジョ語',
        'wa' => 'ワロン語',
        'wae' => 'ヴァリス語',
        'wal' => 'ウォライタ語',
        'war' => 'ワライ語',
        'was' => 'ワショ語',
        'wbp' => 'ワルピリ語',
        'wo' => 'ウォロフ語',
        'wuu' => '呉語',
        'xal' => 'カルムイク語',
        'xh' => 'コサ語',
        'xmf' => 'メグレル語',
        'xog' => 'ソガ語',
        'yao' => 'ヤオ語',
        'yap' => 'ヤップ語',
        'yav' => 'ヤンベン語',
        'ybb' => 'イエンバ語',
        'yi' => 'イディッシュ語',
        'yo' => 'ヨルバ語',
        'yrl' => 'ニェエンガトゥ語',
        'yue' => '広東語',
        'za' => 'チワン語',
        'zap' => 'サポテカ語',
        'zbl' => 'ブリスシンボル',
        'zea' => 'ゼーラント語',
        'zen' => 'ゼナガ語',
        'zgh' => '標準モロッコ タマジクト語',
        'zh' => '中国語',
        'zu' => 'ズールー語',
        'zun' => 'ズニ語',
        'zza' => 'ザザ語',
    ],
    'LocalizedNames' => [
        'ar_001' => '現代標準アラビア語',
        'de_CH' => '標準ドイツ語 (スイス)',
        'en_AU' => 'オーストラリア英語',
        'en_CA' => 'カナダ英語',
        'en_GB' => 'イギリス英語',
        'en_US' => 'アメリカ英語',
        'es_ES' => 'スペイン語 (イベリア半島)',
        'fa_AF' => 'ダリー語',
        'nl_BE' => 'フラマン語',
        'pt_PT' => 'ポルトガル語 (イベリア半島)',
        'ro_MD' => 'モルダビア語',
        'sw_CD' => 'コンゴ・スワヒリ語',
        'zh_Hans' => '簡体中国語',
        'zh_Hant' => '繁体中国語',
    ],
];
