<?php

return [
    'Names' => [
        'Arab' => 'arabisk',
        'Armn' => 'armenskt',
        'Beng' => 'bangla',
        'Bopo' => 'bopomofo',
        'Brai' => 'blindaskrift',
        'Cyrl' => 'kyrilliskt',
        'Deva' => 'devanagari',
        'Ethi' => 'etiopiskt',
        'Geor' => 'georgianskt',
        'Grek' => 'grikskt',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hans' => 'einkult',
        'Hant' => 'vanligt',
        'Hebr' => 'hebraiskt',
        'Hira' => 'hiragana',
        'Hrkt' => 'japanskir stavir',
        'Jamo' => 'jamo',
        'Jpan' => 'japanskt',
        'Kana' => 'katakana',
        'Khmr' => 'khmer',
        'Knda' => 'kannada',
        'Kore' => 'koreanskt',
        'Laoo' => 'lao',
        'Latn' => 'latínskt',
        'Mlym' => 'malayalam',
        'Mong' => 'mongolsk',
        'Mymr' => 'myanmarskt',
        'Orya' => 'odia',
        'Sinh' => 'sinhala',
        'Taml' => 'tamilskt',
        'Telu' => 'telugu',
        'Thaa' => 'thaana',
        'Thai' => 'tailendskt',
        'Tibt' => 'tibetskt',
        'Zmth' => 'støddfrøðilig teknskipan',
        'Zsye' => 'emoji',
        'Zsym' => 'tekin',
        'Zxxx' => 'óskriva',
        'Zyyy' => 'vanlig',
    ],
];
