<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Abidjan (Greenwich gaskka áigi)',
        'Africa/Accra' => 'Accra (Greenwich gaskka áigi)',
        'Africa/Addis_Ababa' => 'Addis Ababa (Etiopia áigi)',
        'Africa/Algiers' => 'Algiers (gaska-Eurohpá áigi)',
        'Africa/Asmera' => 'Asmara (Eritrea áigi)',
        'Africa/Bamako' => 'Bamako (Greenwich gaskka áigi)',
        'Africa/Bangui' => 'Bangui (Gaska-Afrihká dásseváldi áigi)',
        'Africa/Banjul' => 'Banjul (Greenwich gaskka áigi)',
        'Africa/Bissau' => 'Bissau (Greenwich gaskka áigi)',
        'Africa/Blantyre' => 'Blantyre (Malawi áigi)',
        'Africa/Brazzaville' => 'Brazzaville (Kongo-Brazzaville áigi)',
        'Africa/Bujumbura' => 'Bujumbura (Burundi áigi)',
        'Africa/Cairo' => 'Cairo (nuorti-Eurohpá áigi)',
        'Africa/Casablanca' => 'Casablanca (oarje-Eurohpá áigi)',
        'Africa/Ceuta' => 'Ceuta (gaska-Eurohpá áigi)',
        'Africa/Conakry' => 'Conakry (Greenwich gaskka áigi)',
        'Africa/Dakar' => 'Dakar (Greenwich gaskka áigi)',
        'Africa/Dar_es_Salaam' => 'Dar es Salaam (Tanzánia áigi)',
        'Africa/Djibouti' => 'Djibouti (Djibouti áigi)',
        'Africa/Douala' => 'Douala (Kamerun áigi)',
        'Africa/El_Aaiun' => 'El Aaiun (oarje-Eurohpá áigi)',
        'Africa/Freetown' => 'Freetown (Greenwich gaskka áigi)',
        'Africa/Gaborone' => 'Gaborone (Botswana áigi)',
        'Africa/Harare' => 'Harare (Zimbabwe áigi)',
        'Africa/Johannesburg' => 'Johannesburg (Mátta-Afrihká áigi)',
        'Africa/Juba' => 'Juba (Máttasudan áigi)',
        'Africa/Kampala' => 'Kampala (Uganda áigi)',
        'Africa/Khartoum' => 'Khartoum (Davvisudan áigi)',
        'Africa/Kigali' => 'Kigali (Rwanda áigi)',
        'Africa/Kinshasa' => 'Kinshasa (Kongo-Kinshasa áigi)',
        'Africa/Lagos' => 'Lagos (Nigeria áigi)',
        'Africa/Libreville' => 'Libreville (Gabon áigi)',
        'Africa/Lome' => 'Lome (Greenwich gaskka áigi)',
        'Africa/Luanda' => 'Luanda (Angola áigi)',
        'Africa/Lubumbashi' => 'Lubumbashi (Kongo-Kinshasa áigi)',
        'Africa/Lusaka' => 'Lusaka (Zambia áigi)',
        'Africa/Malabo' => 'Malabo (Ekvatoriála Guinea áigi)',
        'Africa/Maputo' => 'Maputo (Mosambik áigi)',
        'Africa/Maseru' => 'Maseru (Lesotho áigi)',
        'Africa/Mbabane' => 'Mbabane (Svazieana áigi)',
        'Africa/Mogadishu' => 'Mogadishu (Somália áigi)',
        'Africa/Monrovia' => 'Monrovia (Greenwich gaskka áigi)',
        'Africa/Nairobi' => 'Nairobi (Kenia áigi)',
        'Africa/Ndjamena' => 'Ndjamena (Tčad áigi)',
        'Africa/Niamey' => 'Niamey (Niger áigi)',
        'Africa/Nouakchott' => 'Nouakchott (Greenwich gaskka áigi)',
        'Africa/Ouagadougou' => 'Ouagadougou (Greenwich gaskka áigi)',
        'Africa/Porto-Novo' => 'Porto-Novo (Benin áigi)',
        'Africa/Sao_Tome' => 'Sao Tome (Greenwich gaskka áigi)',
        'Africa/Tripoli' => 'Tripoli (nuorti-Eurohpá áigi)',
        'Africa/Tunis' => 'Tunis (gaska-Eurohpá áigi)',
        'Africa/Windhoek' => 'Windhoek (Namibia áigi)',
        'America/Adak' => 'Adak (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Anchorage' => 'Anchorage (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Anguilla' => 'Anguilla (Anguilla áigi)',
        'America/Antigua' => 'Antigua (Antigua ja Barbuda áigi)',
        'America/Araguaina' => 'Araguaina (Brasil áigi)',
        'America/Argentina/La_Rioja' => 'La Rioja (Argentina áigi)',
        'America/Argentina/Rio_Gallegos' => 'Rio Gallegos (Argentina áigi)',
        'America/Argentina/Salta' => 'Salta (Argentina áigi)',
        'America/Argentina/San_Juan' => 'San Juan (Argentina áigi)',
        'America/Argentina/San_Luis' => 'San Luis (Argentina áigi)',
        'America/Argentina/Tucuman' => 'Tucuman (Argentina áigi)',
        'America/Argentina/Ushuaia' => 'Ushuaia (Argentina áigi)',
        'America/Aruba' => 'Aruba (Aruba áigi)',
        'America/Asuncion' => 'Asuncion (Paraguay áigi)',
        'America/Bahia' => 'Bahia (Brasil áigi)',
        'America/Bahia_Banderas' => 'Bahia Banderas (Meksiko áigi)',
        'America/Barbados' => 'Barbados (Barbados áigi)',
        'America/Belem' => 'Belem (Brasil áigi)',
        'America/Belize' => 'Belize (Belize áigi)',
        'America/Blanc-Sablon' => 'Blanc-Sablon (Kanáda áigi)',
        'America/Boa_Vista' => 'Boa Vista (Brasil áigi)',
        'America/Bogota' => 'Bogota (Kolombia áigi)',
        'America/Boise' => 'Boise (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Buenos_Aires' => 'Buenos Aires (Argentina áigi)',
        'America/Cambridge_Bay' => 'Cambridge Bay (Kanáda áigi)',
        'America/Campo_Grande' => 'Campo Grande (Brasil áigi)',
        'America/Cancun' => 'Cancun (Meksiko áigi)',
        'America/Caracas' => 'Caracas (Venezuela áigi)',
        'America/Catamarca' => 'Catamarca (Argentina áigi)',
        'America/Cayenne' => 'Cayenne (Frankriikka Guayana áigi)',
        'America/Cayman' => 'Cayman (Cayman-sullot áigi)',
        'America/Chicago' => 'Chicago (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Chihuahua' => 'Chihuahua (Meksiko áigi)',
        'America/Coral_Harbour' => 'Atikokan (Kanáda áigi)',
        'America/Cordoba' => 'Cordoba (Argentina áigi)',
        'America/Costa_Rica' => 'Costa Rica (Costa Rica áigi)',
        'America/Creston' => 'Creston (Kanáda áigi)',
        'America/Cuiaba' => 'Cuiaba (Brasil áigi)',
        'America/Curacao' => 'Curaçao (Curaçao áigi)',
        'America/Danmarkshavn' => 'Danmarkshavn (Greenwich gaskka áigi)',
        'America/Dawson' => 'Dawson (Kanáda áigi)',
        'America/Dawson_Creek' => 'Dawson Creek (Kanáda áigi)',
        'America/Denver' => 'Denver (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Detroit' => 'Detroit (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Dominica' => 'Dominica (Dominica áigi)',
        'America/Edmonton' => 'Edmonton (Kanáda áigi)',
        'America/Eirunepe' => 'Eirunepe (Brasil áigi)',
        'America/El_Salvador' => 'El Salvador (El Salvador áigi)',
        'America/Fort_Nelson' => 'Fort Nelson (Kanáda áigi)',
        'America/Fortaleza' => 'Fortaleza (Brasil áigi)',
        'America/Glace_Bay' => 'Glace Bay (Kanáda áigi)',
        'America/Godthab' => 'Nuuk (Kalaallit Nunaat áigi)',
        'America/Goose_Bay' => 'Goose Bay (Kanáda áigi)',
        'America/Grand_Turk' => 'Grand Turk (Turks ja Caicos-sullot áigi)',
        'America/Grenada' => 'Grenada (Grenada áigi)',
        'America/Guadeloupe' => 'Guadeloupe (Guadeloupe áigi)',
        'America/Guatemala' => 'Guatemala (Guatemala áigi)',
        'America/Guayaquil' => 'Guayaquil (Ecuador áigi)',
        'America/Guyana' => 'Guyana (Guyana áigi)',
        'America/Halifax' => 'Halifax (Kanáda áigi)',
        'America/Havana' => 'Havana (Kuba áigi)',
        'America/Hermosillo' => 'Hermosillo (Meksiko áigi)',
        'America/Indiana/Knox' => 'Knox, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indiana/Marengo' => 'Marengo, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indiana/Petersburg' => 'Petersburg, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indiana/Tell_City' => 'Tell City, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indiana/Vevay' => 'Vevay, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indiana/Vincennes' => 'Vincennes, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indiana/Winamac' => 'Winamac, Indiana (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Indianapolis' => 'Indianapolis (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Inuvik' => 'Inuvik (Kanáda áigi)',
        'America/Iqaluit' => 'Iqaluit (Kanáda áigi)',
        'America/Jamaica' => 'Jamaica (Jamaica áigi)',
        'America/Jujuy' => 'Jujuy (Argentina áigi)',
        'America/Juneau' => 'Juneau (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Kentucky/Monticello' => 'Monticello, Kentucky (Amerihká ovttastuvvan stáhtat áigi)',
        'America/La_Paz' => 'La Paz (Bolivia áigi)',
        'America/Lima' => 'Lima (Peru áigi)',
        'America/Los_Angeles' => 'Los Angeles (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Louisville' => 'Louisville (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Lower_Princes' => 'Lower Prince’s Quarter (Vuolleeatnamat Saint Martin áigi)',
        'America/Maceio' => 'Maceio (Brasil áigi)',
        'America/Managua' => 'Managua (Nicaragua áigi)',
        'America/Manaus' => 'Manaus (Brasil áigi)',
        'America/Marigot' => 'Marigot (Frankriikka Saint Martin áigi)',
        'America/Martinique' => 'Martinique (Martinique áigi)',
        'America/Matamoros' => 'Matamoros (Meksiko áigi)',
        'America/Mazatlan' => 'Mazatlan (Meksiko áigi)',
        'America/Mendoza' => 'Mendoza (Argentina áigi)',
        'America/Menominee' => 'Menominee (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Merida' => 'Mérida (Meksiko áigi)',
        'America/Metlakatla' => 'Metlakatla (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Mexico_City' => 'Mexico City (Meksiko áigi)',
        'America/Miquelon' => 'Miquelon (Saint Pierre ja Miquelon áigi)',
        'America/Moncton' => 'Moncton (Kanáda áigi)',
        'America/Monterrey' => 'Monterrey (Meksiko áigi)',
        'America/Montevideo' => 'Montevideo (Uruguay áigi)',
        'America/Montreal' => 'Montreal (Kanáda áigi)',
        'America/Montserrat' => 'Montserrat (Montserrat áigi)',
        'America/Nassau' => 'Nassau (Bahamas áigi)',
        'America/New_York' => 'New York (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Nipigon' => 'Nipigon (Kanáda áigi)',
        'America/Nome' => 'Nome (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Noronha' => 'Noronha (Brasil áigi)',
        'America/North_Dakota/Beulah' => 'Beulah, North Dakota (Amerihká ovttastuvvan stáhtat áigi)',
        'America/North_Dakota/Center' => 'Center, North Dakota (Amerihká ovttastuvvan stáhtat áigi)',
        'America/North_Dakota/New_Salem' => 'New Salem, North Dakota (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Ojinaga' => 'Ojinaga (Meksiko áigi)',
        'America/Panama' => 'Panama (Panama áigi)',
        'America/Pangnirtung' => 'Pangnirtung (Kanáda áigi)',
        'America/Paramaribo' => 'Paramaribo (Surinam áigi)',
        'America/Phoenix' => 'Phoenix (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Port-au-Prince' => 'Port-au-Prince (Haiti áigi)',
        'America/Port_of_Spain' => 'Port of Spain (Trinidad ja Tobago áigi)',
        'America/Porto_Velho' => 'Porto Velho (Brasil áigi)',
        'America/Puerto_Rico' => 'Puerto Rico (Puerto Rico áigi)',
        'America/Punta_Arenas' => 'Punta Arenas (Čiile áigi)',
        'America/Rainy_River' => 'Rainy River (Kanáda áigi)',
        'America/Rankin_Inlet' => 'Rankin Inlet (Kanáda áigi)',
        'America/Recife' => 'Recife (Brasil áigi)',
        'America/Regina' => 'Regina (Kanáda áigi)',
        'America/Resolute' => 'Resolute (Kanáda áigi)',
        'America/Rio_Branco' => 'Rio Branco (Brasil áigi)',
        'America/Santa_Isabel' => 'Santa Isabel (Meksiko áigi)',
        'America/Santarem' => 'Santarem (Brasil áigi)',
        'America/Santiago' => 'Santiago (Čiile áigi)',
        'America/Santo_Domingo' => 'Santo Domingo (Dominikána dásseváldi áigi)',
        'America/Sao_Paulo' => 'São Paulo (Brasil áigi)',
        'America/Scoresbysund' => 'Ittoqqortoormiit (Kalaallit Nunaat áigi)',
        'America/Sitka' => 'Sitka (Amerihká ovttastuvvan stáhtat áigi)',
        'America/St_Barthelemy' => 'Saint Barthélemy (Saint Barthélemy áigi)',
        'America/St_Johns' => 'St. John’s (Kanáda áigi)',
        'America/St_Kitts' => 'St. Kitts (Saint Kitts ja Nevis áigi)',
        'America/St_Lucia' => 'St. Lucia (Saint Lucia áigi)',
        'America/St_Thomas' => 'St. Thomas (AOS Virgin-sullot áigi)',
        'America/St_Vincent' => 'St. Vincent (Saint Vincent ja Grenadine áigi)',
        'America/Swift_Current' => 'Swift Current (Kanáda áigi)',
        'America/Tegucigalpa' => 'Tegucigalpa (Honduras áigi)',
        'America/Thule' => 'Thule (Kalaallit Nunaat áigi)',
        'America/Thunder_Bay' => 'Thunder Bay (Kanáda áigi)',
        'America/Tijuana' => 'Tijuana (Meksiko áigi)',
        'America/Toronto' => 'Toronto (Kanáda áigi)',
        'America/Tortola' => 'Tortola (Brittania Virgin-sullot áigi)',
        'America/Vancouver' => 'Vancouver (Kanáda áigi)',
        'America/Whitehorse' => 'Whitehorse (Kanáda áigi)',
        'America/Winnipeg' => 'Winnipeg (Kanáda áigi)',
        'America/Yakutat' => 'Yakutat (Amerihká ovttastuvvan stáhtat áigi)',
        'America/Yellowknife' => 'Yellowknife (Kanáda áigi)',
        'Antarctica/Casey' => 'Casey (Antárktis áigi)',
        'Antarctica/Davis' => 'Davis (Antárktis áigi)',
        'Antarctica/DumontDUrville' => 'Dumont d’Urville (Antárktis áigi)',
        'Antarctica/Macquarie' => 'Macquarie (Austrália áigi)',
        'Antarctica/Mawson' => 'Mawson (Antárktis áigi)',
        'Antarctica/McMurdo' => 'McMurdo (Antárktis áigi)',
        'Antarctica/Palmer' => 'Palmer (Antárktis áigi)',
        'Antarctica/Rothera' => 'Rothera (Antárktis áigi)',
        'Antarctica/Syowa' => 'Syowa (Antárktis áigi)',
        'Antarctica/Troll' => 'Troll (Greenwich gaskka áigi)',
        'Antarctica/Vostok' => 'Vostok (Antárktis áigi)',
        'Arctic/Longyearbyen' => 'Longyearbyen (gaska-Eurohpá áigi)',
        'Asia/Aden' => 'Aden (Jemen áigi)',
        'Asia/Almaty' => 'Almaty (Kasakstan áigi)',
        'Asia/Amman' => 'Amman (nuorti-Eurohpá áigi)',
        'Asia/Anadyr' => 'Anadyr (Ruošša áigi)',
        'Asia/Aqtau' => 'Aqtau (Kasakstan áigi)',
        'Asia/Aqtobe' => 'Aqtobe (Kasakstan áigi)',
        'Asia/Ashgabat' => 'Ashgabat (Turkmenistan áigi)',
        'Asia/Atyrau' => 'Atyrau (Kasakstan áigi)',
        'Asia/Baghdad' => 'Baghdad (Irak áigi)',
        'Asia/Bahrain' => 'Bahrain (Bahrain áigi)',
        'Asia/Baku' => 'Baku (Aserbaižan áigi)',
        'Asia/Bangkok' => 'Bangkok (Thaieana áigi)',
        'Asia/Barnaul' => 'Barnaul (Ruošša áigi)',
        'Asia/Beirut' => 'Beirut (nuorti-Eurohpá áigi)',
        'Asia/Bishkek' => 'Bishkek (Kirgisistan áigi)',
        'Asia/Brunei' => 'Brunei (Brunei áigi)',
        'Asia/Calcutta' => 'Kolkata (India áigi)',
        'Asia/Chita' => 'Chita (Ruošša áigi)',
        'Asia/Choibalsan' => 'Choibalsan (Mongolia áigi)',
        'Asia/Colombo' => 'Colombo (Sri Lanka áigi)',
        'Asia/Damascus' => 'Damascus (nuorti-Eurohpá áigi)',
        'Asia/Dhaka' => 'Dhaka (Bangladesh áigi)',
        'Asia/Dili' => 'Dili (Nuorta-Timor áigi)',
        'Asia/Dubai' => 'Dubai (Ovttastuvvan Arábaemiráhtat áigi)',
        'Asia/Dushanbe' => 'Dushanbe (Tažikistan áigi)',
        'Asia/Famagusta' => 'Famagusta (nuorti-Eurohpá áigi)',
        'Asia/Gaza' => 'Gaza (nuorti-Eurohpá áigi)',
        'Asia/Hebron' => 'Hebron (nuorti-Eurohpá áigi)',
        'Asia/Hong_Kong' => 'Hong Kong (Hongkong áigi)',
        'Asia/Hovd' => 'Hovd (Mongolia áigi)',
        'Asia/Irkutsk' => 'Irkutsk (Ruošša áigi)',
        'Asia/Jakarta' => 'Jakarta (Indonesia áigi)',
        'Asia/Jayapura' => 'Jayapura (Indonesia áigi)',
        'Asia/Jerusalem' => 'Jerusalem (Israel áigi)',
        'Asia/Kabul' => 'Kabul (Afghanistan áigi)',
        'Asia/Kamchatka' => 'Kamchatka (Ruošša áigi)',
        'Asia/Karachi' => 'Karachi (Pakistan áigi)',
        'Asia/Katmandu' => 'Kathmandu (Nepal áigi)',
        'Asia/Khandyga' => 'Khandyga (Ruošša áigi)',
        'Asia/Krasnoyarsk' => 'Krasnoyarsk (Ruošša áigi)',
        'Asia/Kuala_Lumpur' => 'Kuala Lumpur (Malesia áigi)',
        'Asia/Kuching' => 'Kuching (Malesia áigi)',
        'Asia/Kuwait' => 'Kuwait (Kuwait áigi)',
        'Asia/Macau' => 'Macao (Makáo áigi)',
        'Asia/Magadan' => 'Magadan (Ruošša áigi)',
        'Asia/Makassar' => 'Makassar (Indonesia áigi)',
        'Asia/Manila' => 'Manila (Filippiinnat áigi)',
        'Asia/Muscat' => 'Muscat (Oman áigi)',
        'Asia/Nicosia' => 'Nicosia (nuorti-Eurohpá áigi)',
        'Asia/Novokuznetsk' => 'Novokuznetsk (Ruošša áigi)',
        'Asia/Novosibirsk' => 'Novosibirsk (Ruošša áigi)',
        'Asia/Omsk' => 'Omsk (Ruošša áigi)',
        'Asia/Oral' => 'Oral (Kasakstan áigi)',
        'Asia/Phnom_Penh' => 'Phnom Penh (Kambodža áigi)',
        'Asia/Pontianak' => 'Pontianak (Indonesia áigi)',
        'Asia/Pyongyang' => 'Pyongyang (Davvi-Korea áigi)',
        'Asia/Qatar' => 'Qatar (Qatar áigi)',
        'Asia/Qostanay' => 'Qostanay (Kasakstan áigi)',
        'Asia/Qyzylorda' => 'Qyzylorda (Kasakstan áigi)',
        'Asia/Rangoon' => 'Yangon (Burma áigi)',
        'Asia/Riyadh' => 'Riyadh (Saudi-Arábia áigi)',
        'Asia/Saigon' => 'Ho Chi Minh (Vietnam áigi)',
        'Asia/Sakhalin' => 'Sakhalin (Ruošša áigi)',
        'Asia/Samarkand' => 'Samarkand (Usbekistan áigi)',
        'Asia/Seoul' => 'Seoul (Mátta-Korea áigi)',
        'Asia/Shanghai' => 'Shanghai (Kiinná áigi)',
        'Asia/Singapore' => 'Singapore (Singapore áigi)',
        'Asia/Srednekolymsk' => 'Srednekolymsk (Ruošša áigi)',
        'Asia/Taipei' => 'Taipei (Taiwan áigi)',
        'Asia/Tashkent' => 'Tashkent (Usbekistan áigi)',
        'Asia/Tbilisi' => 'Tbilisi (Georgia áigi)',
        'Asia/Tehran' => 'Tehran (Iran áigi)',
        'Asia/Thimphu' => 'Thimphu (Bhutan áigi)',
        'Asia/Tokyo' => 'Tokyo (Japána áigi)',
        'Asia/Tomsk' => 'Tomsk (Ruošša áigi)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatar (Mongolia áigi)',
        'Asia/Urumqi' => 'Urumqi (Kiinná áigi)',
        'Asia/Ust-Nera' => 'Ust-Nera (Ruošša áigi)',
        'Asia/Vientiane' => 'Vientiane (Laos áigi)',
        'Asia/Vladivostok' => 'Vladivostok (Ruošša áigi)',
        'Asia/Yakutsk' => 'Yakutsk (Ruošša áigi)',
        'Asia/Yekaterinburg' => 'Yekaterinburg (Ruošša áigi)',
        'Asia/Yerevan' => 'Yerevan (Armenia áigi)',
        'Atlantic/Azores' => 'Azores (Portugála áigi)',
        'Atlantic/Bermuda' => 'Bermuda (Bermuda áigi)',
        'Atlantic/Canary' => 'Canary (oarje-Eurohpá áigi)',
        'Atlantic/Cape_Verde' => 'Cape Verde (Kap Verde áigi)',
        'Atlantic/Faeroe' => 'Faroe (oarje-Eurohpá áigi)',
        'Atlantic/Madeira' => 'Madeira (oarje-Eurohpá áigi)',
        'Atlantic/Reykjavik' => 'Reykjavik (Greenwich gaskka áigi)',
        'Atlantic/South_Georgia' => 'South Georgia (Lulli Georgia ja Lulli Sandwich-sullot áigi)',
        'Atlantic/St_Helena' => 'St. Helena (Greenwich gaskka áigi)',
        'Atlantic/Stanley' => 'Stanley (Falklandsullot áigi)',
        'Australia/Adelaide' => 'Adelaide (Austrália áigi)',
        'Australia/Brisbane' => 'Brisbane (Austrália áigi)',
        'Australia/Broken_Hill' => 'Broken Hill (Austrália áigi)',
        'Australia/Currie' => 'Currie (Austrália áigi)',
        'Australia/Darwin' => 'Darwin (Austrália áigi)',
        'Australia/Eucla' => 'Eucla (Austrália áigi)',
        'Australia/Hobart' => 'Hobart (Austrália áigi)',
        'Australia/Lindeman' => 'Lindeman (Austrália áigi)',
        'Australia/Lord_Howe' => 'Lord Howe (Austrália áigi)',
        'Australia/Melbourne' => 'Melbourne (Austrália áigi)',
        'Australia/Perth' => 'Perth (Austrália áigi)',
        'Australia/Sydney' => 'Sydney (Austrália áigi)',
        'Etc/GMT' => 'Greenwich gaskka áigi',
        'Europe/Amsterdam' => 'Amsterdam (gaska-Eurohpá áigi)',
        'Europe/Andorra' => 'Andorra (gaska-Eurohpá áigi)',
        'Europe/Astrakhan' => 'Astrakhan (Moskva-áigi)',
        'Europe/Athens' => 'Athens (nuorti-Eurohpá áigi)',
        'Europe/Belgrade' => 'Belgrade (gaska-Eurohpá áigi)',
        'Europe/Berlin' => 'Berlin (gaska-Eurohpá áigi)',
        'Europe/Bratislava' => 'Bratislava (gaska-Eurohpá áigi)',
        'Europe/Brussels' => 'Brussels (gaska-Eurohpá áigi)',
        'Europe/Bucharest' => 'Bucharest (nuorti-Eurohpá áigi)',
        'Europe/Budapest' => 'Budapest (gaska-Eurohpá áigi)',
        'Europe/Busingen' => 'Busingen (gaska-Eurohpá áigi)',
        'Europe/Chisinau' => 'Chisinau (nuorti-Eurohpá áigi)',
        'Europe/Copenhagen' => 'Copenhagen (gaska-Eurohpá áigi)',
        'Europe/Dublin' => 'Dublin (Greenwich gaskka áigi)',
        'Europe/Gibraltar' => 'Gibraltar (gaska-Eurohpá áigi)',
        'Europe/Guernsey' => 'Guernsey (Greenwich gaskka áigi)',
        'Europe/Helsinki' => 'Helsinki (nuorti-Eurohpá áigi)',
        'Europe/Isle_of_Man' => 'Isle of Man (Greenwich gaskka áigi)',
        'Europe/Istanbul' => 'Istanbul (Durka áigi)',
        'Europe/Jersey' => 'Jersey (Greenwich gaskka áigi)',
        'Europe/Kaliningrad' => 'Kaliningrad (nuorti-Eurohpá áigi)',
        'Europe/Kiev' => 'Kyiv (nuorti-Eurohpá áigi)',
        'Europe/Kirov' => 'Kirov (Ruošša áigi)',
        'Europe/Lisbon' => 'Lisbon (oarje-Eurohpá áigi)',
        'Europe/Ljubljana' => 'Ljubljana (gaska-Eurohpá áigi)',
        'Europe/London' => 'London (Greenwich gaskka áigi)',
        'Europe/Luxembourg' => 'Luxembourg (gaska-Eurohpá áigi)',
        'Europe/Madrid' => 'Madrid (gaska-Eurohpá áigi)',
        'Europe/Malta' => 'Malta (gaska-Eurohpá áigi)',
        'Europe/Mariehamn' => 'Mariehamn (nuorti-Eurohpá áigi)',
        'Europe/Minsk' => 'Minsk (Moskva-áigi)',
        'Europe/Monaco' => 'Monaco (gaska-Eurohpá áigi)',
        'Europe/Moscow' => 'Moscow (Moskva-áigi)',
        'Europe/Oslo' => 'Oslo (gaska-Eurohpá áigi)',
        'Europe/Paris' => 'Paris (gaska-Eurohpá áigi)',
        'Europe/Podgorica' => 'Podgorica (gaska-Eurohpá áigi)',
        'Europe/Prague' => 'Prague (gaska-Eurohpá áigi)',
        'Europe/Riga' => 'Riga (nuorti-Eurohpá áigi)',
        'Europe/Rome' => 'Rome (gaska-Eurohpá áigi)',
        'Europe/Samara' => 'Samara (Ruošša áigi)',
        'Europe/San_Marino' => 'San Marino (gaska-Eurohpá áigi)',
        'Europe/Sarajevo' => 'Sarajevo (gaska-Eurohpá áigi)',
        'Europe/Saratov' => 'Saratov (Moskva-áigi)',
        'Europe/Simferopol' => 'Simferopol (Moskva-áigi)',
        'Europe/Skopje' => 'Skopje (gaska-Eurohpá áigi)',
        'Europe/Sofia' => 'Sofia (nuorti-Eurohpá áigi)',
        'Europe/Stockholm' => 'Stockholm (gaska-Eurohpá áigi)',
        'Europe/Tallinn' => 'Tallinn (nuorti-Eurohpá áigi)',
        'Europe/Tirane' => 'Tirane (gaska-Eurohpá áigi)',
        'Europe/Ulyanovsk' => 'Ulyanovsk (Moskva-áigi)',
        'Europe/Uzhgorod' => 'Uzhgorod (nuorti-Eurohpá áigi)',
        'Europe/Vaduz' => 'Vaduz (gaska-Eurohpá áigi)',
        'Europe/Vatican' => 'Vatican (gaska-Eurohpá áigi)',
        'Europe/Vienna' => 'Vienna (gaska-Eurohpá áigi)',
        'Europe/Vilnius' => 'Vilnius (nuorti-Eurohpá áigi)',
        'Europe/Volgograd' => 'Volgograd (Ruošša áigi)',
        'Europe/Warsaw' => 'Warsaw (gaska-Eurohpá áigi)',
        'Europe/Zagreb' => 'Zagreb (gaska-Eurohpá áigi)',
        'Europe/Zaporozhye' => 'Zaporozhye (nuorti-Eurohpá áigi)',
        'Europe/Zurich' => 'Zurich (gaska-Eurohpá áigi)',
        'Indian/Antananarivo' => 'Antananarivo (Madagaskar áigi)',
        'Indian/Christmas' => 'Christmas (Juovllat-sullot áigi)',
        'Indian/Cocos' => 'Cocos (Cocos-sullot áigi)',
        'Indian/Comoro' => 'Comoro (Komoros áigi)',
        'Indian/Mahe' => 'Mahe (Seychellsullot áigi)',
        'Indian/Maldives' => 'Maldives (Malediivvat áigi)',
        'Indian/Mauritius' => 'Mauritius (Mauritius áigi)',
        'Indian/Mayotte' => 'Mayotte (Mayotte áigi)',
        'Indian/Reunion' => 'Reunion (Réunion áigi)',
        'Pacific/Apia' => 'Apia (Samoa áigi)',
        'Pacific/Auckland' => 'Auckland (Ođđa-Selánda áigi)',
        'Pacific/Bougainville' => 'Bougainville (Papua-Ođđa-Guinea áigi)',
        'Pacific/Chatham' => 'Chatham (Ođđa-Selánda áigi)',
        'Pacific/Easter' => 'Easter (Čiile áigi)',
        'Pacific/Efate' => 'Efate (Vanuatu áigi)',
        'Pacific/Enderbury' => 'Enderbury (Kiribati áigi)',
        'Pacific/Fakaofo' => 'Fakaofo (Tokelau áigi)',
        'Pacific/Fiji' => 'Fiji (Fijisullot áigi)',
        'Pacific/Funafuti' => 'Funafuti (Tuvalu áigi)',
        'Pacific/Galapagos' => 'Galapagos (Ecuador áigi)',
        'Pacific/Gambier' => 'Gambier (Frankriikka Polynesia áigi)',
        'Pacific/Guadalcanal' => 'Guadalcanal (Salomon-sullot áigi)',
        'Pacific/Guam' => 'Guam (Guam áigi)',
        'Pacific/Honolulu' => 'Honolulu (Amerihká ovttastuvvan stáhtat áigi)',
        'Pacific/Kiritimati' => 'Kiritimati (Kiribati áigi)',
        'Pacific/Kosrae' => 'Kosrae (Mikronesia áigi)',
        'Pacific/Kwajalein' => 'Kwajalein (Marshallsullot áigi)',
        'Pacific/Majuro' => 'Majuro (Marshallsullot áigi)',
        'Pacific/Marquesas' => 'Marquesas (Frankriikka Polynesia áigi)',
        'Pacific/Nauru' => 'Nauru (Nauru áigi)',
        'Pacific/Niue' => 'Niue (Niue áigi)',
        'Pacific/Norfolk' => 'Norfolk (Norfolksullot áigi)',
        'Pacific/Noumea' => 'Noumea (Ođđa-Kaledonia áigi)',
        'Pacific/Pago_Pago' => 'Pago Pago (Amerihká Samoa áigi)',
        'Pacific/Palau' => 'Palau (Palau áigi)',
        'Pacific/Pitcairn' => 'Pitcairn (Pitcairn áigi)',
        'Pacific/Ponape' => 'Pohnpei (Mikronesia áigi)',
        'Pacific/Port_Moresby' => 'Port Moresby (Papua-Ođđa-Guinea áigi)',
        'Pacific/Rarotonga' => 'Rarotonga (Cook-sullot áigi)',
        'Pacific/Saipan' => 'Saipan (Davvi-Mariánat áigi)',
        'Pacific/Tahiti' => 'Tahiti (Frankriikka Polynesia áigi)',
        'Pacific/Tarawa' => 'Tarawa (Kiribati áigi)',
        'Pacific/Tongatapu' => 'Tongatapu (Tonga áigi)',
        'Pacific/Truk' => 'Chuuk (Mikronesia áigi)',
        'Pacific/Wallis' => 'Wallis (Wallis ja Futuna áigi)',
    ],
    'Meta' => [
        'GmtFormat' => 'UTC%s',
        'HourFormatNeg' => '−%02d:%02d',
    ],
];
