<?php

return [
    'Names' => [
        'Arab' => 'Arabiagbeŋɔŋlɔ',
        'Armn' => 'armeniagbeŋɔŋlɔ',
        'Beng' => 'bengaligbeŋɔŋlɔ',
        'Bopo' => 'bopomfogbeŋɔŋlɔ',
        'Brai' => 'braillegbeŋɔŋlɔ',
        'Cyrl' => 'Cyrillicgbeŋɔŋlɔ',
        'Deva' => 'devanagarigbeŋɔŋlɔ',
        'Ethi' => 'ethiopiagbeŋɔŋlɔ',
        'Geor' => 'gɔgiagbeŋɔŋlɔ',
        'Grek' => 'grisigbeŋɔŋlɔ',
        'Gujr' => 'gudzaratigbeŋɔŋlɔ',
        'Guru' => 'gurmukhigbeŋɔŋlɔ',
        'Hang' => 'hangulgbeŋɔŋlɔ',
        'Hani' => 'hangbeŋɔŋlɔ',
        'Hans' => 'Chinesegbeŋɔŋlɔ',
        'Hant' => 'Blema Chinesegbeŋɔŋlɔ',
        'Hebr' => 'hebrigbeŋɔŋlɔ',
        'Hira' => 'hiraganagbeŋɔŋlɔ',
        'Jpan' => 'Japanesegbeŋɔŋlɔ',
        'Kana' => 'katakanagbeŋɔŋlɔ',
        'Khmr' => 'khmergbeŋɔŋlɔ',
        'Knda' => 'kannadagbeŋɔŋlɔ',
        'Kore' => 'Koreagbeŋɔŋlɔ',
        'Laoo' => 'laogbeŋɔŋlɔ',
        'Latn' => 'Latingbeŋɔŋlɔ',
        'Mlym' => 'malayagbeŋɔŋlɔ',
        'Mong' => 'mongoliagbeŋɔŋlɔ',
        'Mymr' => 'myanmargbeŋɔŋlɔ',
        'Orya' => 'oriyagbeŋɔŋlɔ',
        'Sinh' => 'sinhalagbeŋɔŋlɔ',
        'Taml' => 'tamilgbeŋɔŋlɔ',
        'Telu' => 'telegugbeŋɔŋlɔ',
        'Thaa' => 'thaanagbeŋɔŋlɔ',
        'Thai' => 'taigbeŋɔŋlɔ',
        'Tibt' => 'tibetgbeŋɔŋlɔ',
        'Zsym' => 'ŋɔŋlɔdzesiwo',
        'Zxxx' => 'gbemaŋlɔ',
        'Zyyy' => 'gbeŋɔŋlɔ bɔbɔ',
    ],
];
