<?php

return [
    'Names' => [
        'Arab' => 'אַראַביש',
        'Cyrl' => 'ציריליש',
        'Deva' => 'דעוואַנאַגאַרי',
        'Grek' => 'גריכיש',
        'Hebr' => 'העברעיש',
        'Latn' => 'גַלחיש',
    ],
];
