<?php

return [
    'Names' => [
        'aa' => 'ອະຟາ',
        'ab' => 'ແອບຄາຊຽນ',
        'ace' => 'ແອັກຊີເນັສ',
        'ach' => 'ອາໂຄລີ',
        'ada' => 'ອາແດງມີ',
        'ady' => 'ເອດີຮິ',
        'ae' => 'ອາເວັສແຕນ',
        'af' => 'ອາຟຣິການ',
        'afh' => 'ແອຟີຮີລີ',
        'agq' => 'ອາເຮັມ',
        'ain' => 'ໄອນູ',
        'ak' => 'ອາການ',
        'akk' => 'ອັກກາດຽມ',
        'ale' => 'ອາເລີດ',
        'alt' => 'ອານໄຕໃຕ້',
        'am' => 'ອຳຮາຣິກ',
        'an' => 'ອາຣາໂກເນັດ',
        'ang' => 'ອັງກິດໂບຮານ',
        'ann' => 'ໂອໂບໂລ',
        'anp' => 'ແອນຈີກາ',
        'ar' => 'ອາຣັບ',
        'arc' => 'ອາລາມິກ',
        'arn' => 'ມາພຸດຊີ',
        'arp' => 'ອາຣາປາໂຮ',
        'ars' => 'ນາຈດີ ອາຣາບິກ',
        'arw' => 'ອາຣາແວກ',
        'as' => 'ອັສຊາມີສ',
        'asa' => 'ອາຊູ',
        'ast' => 'ອັສຕູຮຽນ',
        'atj' => 'ອາຕິກາແມກ',
        'av' => 'ອາວາຣິກ',
        'awa' => 'ອາວາຮິ',
        'ay' => 'ອາຍມາລາ',
        'az' => 'ອາເຊີໄບຈານິ',
        'ba' => 'ບາຣກີ',
        'bal' => 'ບາລູຊີ',
        'ban' => 'ບາລີເນັດ',
        'bas' => 'ບາຊາ',
        'bax' => 'ບາມຸນ',
        'bbj' => 'ໂຄມາລາ',
        'be' => 'ເບລາຣັສຊຽນ',
        'bej' => 'ບີເຈ',
        'bem' => 'ເບັມບາ',
        'bez' => 'ບີນາ',
        'bfd' => 'ບາຟັດ',
        'bg' => 'ບັງກາຣຽນ',
        'bgn' => 'ບາໂລຈີ ພາກຕາເວັນຕົກ',
        'bho' => 'ໂບພູຣິ',
        'bi' => 'ບິສລະມາ',
        'bik' => 'ບີຄອນ',
        'bin' => 'ບີນີ',
        'bkm' => 'ກົມ',
        'bla' => 'ຊິກຊິກາ',
        'bm' => 'ບາມບາຣາ',
        'bn' => 'ເບັງກາລີ',
        'bo' => 'ທິເບທັນ',
        'br' => 'ເບຣຕັນ',
        'bra' => 'ບຣາ',
        'brx' => 'ໂບດູ',
        'bs' => 'ບອສນຽນ',
        'bss' => 'ອາຄຸດ',
        'bua' => 'ບູຣຽດ',
        'bug' => 'ບູຈີເນັດ',
        'bum' => 'ບູລູ',
        'byn' => 'ບລິນ',
        'byv' => 'ເມດູມບາ',
        'ca' => 'ຄາຕາລານ',
        'cad' => 'ແຄດໂດ',
        'car' => 'ຄາຣິບ',
        'cay' => 'ຄາຢູກາ',
        'cch' => 'ອາດແຊມ',
        'ccp' => 'Chakma',
        'ce' => 'ຊີເຄນ',
        'ceb' => 'ຊີບູໂນ',
        'cgg' => 'ຊີກາ',
        'ch' => 'ຊາມໍໂຣ',
        'chb' => 'ຊິບຊາ',
        'chg' => 'ຊາກາໄຕ',
        'chk' => 'ຊູເກດ',
        'chm' => 'ມາຣິ',
        'chn' => 'ຊີນຸກຈາກອນ',
        'cho' => 'ຊອກຕິວ',
        'chp' => 'ຊີພິວຢານ',
        'chr' => 'ຊີໂຣກີ',
        'chy' => 'ຊີເຢນນີ',
        'ckb' => 'ໂຊຣານິ ເຄີດິຊ',
        'clc' => 'ຊິວໂຄຕິນ',
        'co' => 'ຄໍຊິກາ',
        'cop' => 'ຄອບຕິກ',
        'cr' => 'ຄີ',
        'crg' => 'ມິຊິຟ',
        'crh' => 'ຄຣີເມນເຕີຄິຊ',
        'crj' => 'ຄຣີຕາເວັນອອກສ່ຽງໃຕ້',
        'crk' => 'ເພລນຄຣີ',
        'crl' => 'ຄຣີຕາເວັນອອກສ່ຽງເໜືອ',
        'crm' => 'ມູສຄຣີ',
        'crr' => 'ຄາໂຣລິນາ ອາກອນຄວຽນ',
        'crs' => 'ເຊເຊວາ ໂຄຣດ ຝຣັ່ງ',
        'cs' => 'ເຊກ',
        'csb' => 'ກາຊູບຽນ',
        'csw' => 'ຊວາມປີຄຣີ',
        'cu' => 'ໂບດສລາວິກ',
        'cv' => 'ຊູວາຊ',
        'cy' => 'ເວວ',
        'da' => 'ແດນິຊ',
        'dak' => 'ດາໂກຕາ',
        'dar' => 'ດາກວາ',
        'dav' => 'ໄຕຕາ',
        'de' => 'ເຢຍລະມັນ',
        'del' => 'ເດລາວາ',
        'den' => 'ຊີເລັບ',
        'dgr' => 'ໂດກຣິບ',
        'din' => 'ດິນກາ',
        'dje' => 'ຊາມາ',
        'doi' => 'ດອກຣີ',
        'dsb' => 'ຊໍບຽນຕໍ່ກວ່າ',
        'dua' => 'ດົວລາ',
        'dum' => 'ດັກກາງ',
        'dv' => 'ດີວີຮີ',
        'dyo' => 'ໂຈລາ-ຟອນຢີ',
        'dyu' => 'ດູລາ',
        'dz' => 'ດີຊອງຄາ',
        'dzg' => 'ດາຊາກາ',
        'ebu' => 'ເອັມບູ',
        'ee' => 'ອິວາ',
        'efi' => 'ອີຟິກ',
        'egy' => 'ອີຢິບບູຮານ',
        'eka' => 'ອີກາຈັກ',
        'el' => 'ກຣີກ',
        'elx' => 'ອີລາໄມ',
        'en' => 'ອັງກິດ',
        'enm' => 'ອັງກິດກາງ',
        'eo' => 'ເອສປາຍ',
        'es' => 'ສະແປນນິຊ',
        'et' => 'ເອສໂຕນຽນ',
        'eu' => 'ບັສກີ',
        'ewo' => 'ອີວອນດູ',
        'fa' => 'ເປີຊຽນ',
        'fan' => 'ແຟງ',
        'fat' => 'ແຟນຕີ',
        'ff' => 'ຟູລາ',
        'fi' => 'ຟິນນິຊ',
        'fil' => 'ຟີລິປີໂນ',
        'fj' => 'ຟິຈຽນ',
        'fo' => 'ຟາໂຣສ',
        'fon' => 'ຟອນ',
        'fr' => 'ຝຣັ່ງ',
        'frc' => 'ຝຣັ່ງເຄຈຸນ',
        'frm' => 'ຟຮັ່ງເສດກາງ',
        'fro' => 'ຟຮັ່ງເສດໂບຮານ',
        'frr' => 'ຟຣີຊຽນເໜືອ',
        'frs' => 'ຟຣີຊຽນຕາເວັນອອກ',
        'fur' => 'ຟຣີລຽນ',
        'fy' => 'ຟຣິຊຽນ ຕາເວັນຕົກ',
        'ga' => 'ໄອຣິສ',
        'gaa' => 'ກາ',
        'gag' => 'ກາກາອຸຊ',
        'gay' => 'ກາໂຢ',
        'gba' => 'ບາຍາ',
        'gd' => 'ສະກັອດເກລິກ',
        'gez' => 'ກີ',
        'gil' => 'ກິນເບີເທັດ',
        'gl' => 'ກາລິຊຽນ',
        'gmh' => 'ເຢຍລະມັນສູງກາງ',
        'gn' => 'ກົວຣານີ',
        'goh' => 'ເຢຍລະມັນສູງໂບຮານ',
        'gon' => 'ກອນດີ',
        'gor' => 'ໂກຣອນຕາໂຣ',
        'got' => 'ກອດຮິກ',
        'grb' => 'ກຣີໂບ',
        'grc' => 'ແອນຊຽນກຣີກ',
        'gsw' => 'ສະວິສ ເຈີແມນ',
        'gu' => 'ກູຈາຣາຕິ',
        'guz' => 'ກູຊິ',
        'gv' => 'ແມງຊ໌',
        'gwi' => 'ວິດອິນ',
        'ha' => 'ເຮົາຊາ',
        'hai' => 'ໄຮດາ',
        'haw' => 'ຮາໄວອຽນ',
        'hax' => 'ໄຮດາໃຕ້',
        'he' => 'ຮີບຣິວ',
        'hi' => 'ຮິນດິ',
        'hil' => 'ຮິຣິໄກນອນ',
        'hit' => 'ຮິດໄຕ',
        'hmn' => 'ມອງ',
        'ho' => 'ຮິຣິໂມຕູ',
        'hr' => 'ໂຄຣເອທຽນ',
        'hsb' => 'ຊໍບຽນ ທາງຕອນເໜືອ',
        'ht' => 'ໄຮຕຽນ',
        'hu' => 'ຮັງກາຣຽນ',
        'hup' => 'ຮູປາ',
        'hur' => 'ຮາລໂກເມລຽມ',
        'hy' => 'ອາເມນຽນ',
        'hz' => 'ເຮິຮິໂຣ',
        'ia' => 'ອິນເຕີລິງລົວ',
        'iba' => 'ໄອບານ',
        'ibb' => 'ໄອໄບໄບໂອ',
        'id' => 'ອິນໂດເນຊຽນ',
        'ie' => 'ອິນເຕີລິງກຣີ',
        'ig' => 'ອິກໂບ',
        'ii' => 'ເສສວນ ອີ',
        'ik' => 'ອິນນູປຽກ',
        'ikt' => 'ອິນັກທິທັດຄານາດາຕາເວັນຕົກ',
        'ilo' => 'ໄອໂລໂກ',
        'inh' => 'ອິນກັຊ',
        'io' => 'ອີໂດ',
        'is' => 'ໄອສແລນດິກ',
        'it' => 'ອິຕາລຽນ',
        'iu' => 'ອິນນຸກຕິຕັດ',
        'ja' => 'ຍີ່ປຸ່ນ',
        'jbo' => 'ໂລບບັນ',
        'jgo' => 'ງອມບາ',
        'jmc' => 'ມາແຊມ',
        'jpr' => 'ຈູແດວ-ເພີຊຽນ',
        'jrb' => 'ຈູແດວ-ອາລາບິກ',
        'jv' => 'ຈາແວນີສ',
        'ka' => 'ຈໍຈຽນ',
        'kaa' => 'ກາຣາ-ການປາກ',
        'kab' => 'ກາໄບລ໌',
        'kac' => 'ກາຊິນ',
        'kaj' => 'ຈຣູ',
        'kam' => 'ກາມບາ',
        'kaw' => 'ກະວີ',
        'kbd' => 'ກາບາດຽນ',
        'kbl' => 'ຄາແນມບູ',
        'kcg' => 'ຕີບ',
        'kde' => 'ມາຄອນເດ',
        'kea' => 'ຄາເວີເດຍນູ',
        'kfo' => 'ໂຄໂລ',
        'kg' => 'ຄອງໂກ',
        'kgp' => 'ເຄນກັງ',
        'kha' => 'ຄາສິ',
        'kho' => 'ໂຄຕັນ',
        'khq' => 'ຄອຍຣາ ຊິນີ',
        'ki' => 'ຄິຄູຢຸ',
        'kj' => 'ກວນຍາມາ',
        'kk' => 'ຄາຊັກ',
        'kkj' => 'ຄາໂກ',
        'kl' => 'ກຣີນແລນລິດ',
        'kln' => 'ຄາເລັນຈິນ',
        'km' => 'ຂະເໝນ',
        'kmb' => 'ຄິມບັນດູ',
        'kn' => 'ຄັນນາດາ',
        'ko' => 'ເກົາຫລີ',
        'koi' => 'ໂຄມີ-ເພີມຢັກ',
        'kok' => 'ກອນການີ',
        'kos' => 'ຄູສໄລ',
        'kpe' => 'ກາແປຣ',
        'kr' => 'ຄານຸລິ',
        'krc' => 'ກາຣາໄຊ-ບານກາ',
        'krl' => 'ກາເຣລຽນ',
        'kru' => 'ກູຣູກ',
        'ks' => 'ຄາສເມຍຣິ',
        'ksb' => 'ຊຳບາລ້າ',
        'ksf' => 'ບາເຟຍ',
        'ksh' => 'ໂຄລອກນຽນ',
        'ku' => 'ເຄີດິສ',
        'kum' => 'ຄູມີກ',
        'kut' => 'ຄູເທໄນ',
        'kv' => 'ໂຄມິ',
        'kw' => 'ຄໍນິຊ',
        'kwk' => 'ຄວາກຄວາກລາ',
        'ky' => 'ເກຍກີສ',
        'la' => 'ລາຕິນ',
        'lad' => 'ລາດີໂນ',
        'lag' => 'ແລນກິ',
        'lah' => 'ລານດາ',
        'lam' => 'ແລມບາ',
        'lb' => 'ລັກເຊມບວກກິຊ',
        'lez' => 'ລີຊຽນ',
        'lg' => 'ແກນດາ',
        'li' => 'ລິມເບີກີຊ',
        'lil' => 'ລິນລູເອັດ',
        'lkt' => 'ລາໂກຕາ',
        'ln' => 'ລິງກາລາ',
        'lo' => 'ລາວ',
        'lol' => 'ແມັງໂກ້',
        'lou' => 'ລຸຍຊີອານນາ ຄຣີໂອນ',
        'loz' => 'ໂລຊິ',
        'lrc' => 'ລູຣິ ທາງຕອນເໜືອ',
        'lsm' => 'ຊາອາເມຍ',
        'lt' => 'ລິທົວນຽນ',
        'lu' => 'ລູບາ-ຄາຕັງກາ',
        'lua' => 'ລູບາ-ລູລົວ',
        'lui' => 'ລູເຊໂນ',
        'lun' => 'ລຸນດາ',
        'luo' => 'ລົວ',
        'lus' => 'ລູໄຊ',
        'luy' => 'ລູໄຍ',
        'lv' => 'ລັດວຽນ',
        'mad' => 'ມາດູລາ',
        'maf' => 'ມາຟາ',
        'mag' => 'ມາກາຮິ',
        'mai' => 'ໄມທີລິ',
        'mak' => 'ມາກາຊາຣ',
        'man' => 'ມັນດິງກາ',
        'mas' => 'ມາໄຊ',
        'mde' => 'ມາບາ',
        'mdf' => 'ມອກຊາ',
        'mdr' => 'ມານດາຣ',
        'men' => 'ເມນເດ',
        'mer' => 'ເມຣູ',
        'mfe' => 'ມໍຣິສເຢນ',
        'mg' => 'ມາລາກາສຊີ',
        'mga' => 'ໄອລິດກາງ',
        'mgh' => 'ມາຄູວາ-ມີດໂຕ',
        'mgo' => 'ເມທາ',
        'mh' => 'ມາຊານເລັດ',
        'mi' => 'ມາວຣິ',
        'mic' => 'ມິກແມກ',
        'min' => 'ທີແນງກາບູ',
        'mk' => 'ແມຊິໂດນຽນ',
        'ml' => 'ມາເລອາລຳ',
        'mn' => 'ມອງໂກເລຍ',
        'mnc' => 'ແມນຈູ',
        'mni' => 'ມານີພູຣິ',
        'moe' => 'ອິນນຸໄອມັນ',
        'moh' => 'ໂມຫາ',
        'mos' => 'ມອສຊີ',
        'mr' => 'ມາຣາທີ',
        'ms' => 'ມາເລ',
        'mt' => 'ມອລທີສ',
        'mua' => 'ມັນດັງ',
        'mus' => 'ຄຣິກ',
        'mwl' => 'ມີລັນດາ',
        'mwr' => 'ມາວາຣິ',
        'my' => 'ມຽນມາ',
        'mye' => 'ມໍຢິນ',
        'myv' => 'ເອີຍາ',
        'mzn' => 'ມາແຊນເດີລັງ',
        'na' => 'ນາຢູລູ',
        'nap' => 'ນາໂປລີ',
        'naq' => 'ນາມາ',
        'nb' => 'ນໍເວຈຽນ ບັອກມອລ',
        'nd' => 'ເອັນເດເບເລເໜືອ',
        'nds' => 'ເຢຍລະມັນ ຕອນໄຕ້',
        'ne' => 'ເນປາລີ',
        'new' => 'ນີວາຣິ',
        'ng' => 'ເອັນດອງກາ',
        'nia' => 'ນີ່ອັດ',
        'niu' => 'ນີ່ອູ',
        'nl' => 'ດັຊ',
        'nmg' => 'ກວາຊີໂອ',
        'nn' => 'ນໍເວຈຽນ ນີນອກ',
        'nnh' => 'ຈີ່ມບູນ',
        'no' => 'ນໍເວຍ',
        'nog' => 'ນໍໄກ',
        'non' => 'ນໍໂບຮານ',
        'nqo' => 'ເອັນໂກ',
        'nr' => 'ນີບີລີໃຕ້',
        'nso' => 'ໂຊໂທເໜືອ',
        'nus' => 'ເນີ',
        'nv' => 'ນາວາໂຈ',
        'nwc' => 'ເນວາດັ້ງເດີມ',
        'ny' => 'ນານຈາ',
        'nym' => 'ນາມວີຊິ',
        'nyn' => 'ນານຄອນ',
        'nyo' => 'ໂນໂຣ',
        'nzi' => 'ນິມາ',
        'oc' => 'ອັອກຊີຕານ',
        'oj' => 'ໂອຈິບວາ',
        'ojb' => 'ໂອຈິບວາຕາເວັນຕົກສ່ຽງເໜືອ',
        'ojc' => 'ໂອຈິບວາກາງ',
        'ojs' => 'ໂອຈິຄຣີ',
        'ojw' => 'ໂອຈິບວາຕາເວັນຕົກ',
        'oka' => 'ໂອກະນາກັນ',
        'om' => 'ໂອໂຣໂມ',
        'or' => 'ໂອຣິຢາ',
        'os' => 'ອອດເຊຕິກ',
        'osa' => 'ໂອແຊກ',
        'ota' => 'ຕູກີອອດໂຕມັນ',
        'pa' => 'ປັນຈາບີ',
        'pag' => 'ປານກາຊີມານ',
        'pal' => 'ພາລາວີ',
        'pam' => 'ປາມປານກາ',
        'pap' => 'ປາມເປຍເມັນໂທ',
        'pau' => 'ປາລົວອານ',
        'pcm' => 'ໄນຈີຣຽນພິດກິນ',
        'peo' => 'ເປີເຊຍໂບຮານ',
        'phn' => 'ຟີນີເຊຍ',
        'pi' => 'ປາລີ',
        'pis' => 'ປິຈິນ',
        'pl' => 'ໂປລິຊ',
        'pon' => 'ພອນເພ',
        'pqm' => 'ມາລິຊີດ ພາສຊາມາໂຄດດີ',
        'prg' => 'ປຣັສຊຽນ',
        'pro' => 'ໂປວອງຊານໂບຮານ',
        'ps' => 'ປາສໂຕ',
        'pt' => 'ປອກຕຸຍກິສ',
        'qu' => 'ຄີຊົວ',
        'quc' => 'Kʼicheʼ',
        'raj' => 'ຣາຈັສທານິ',
        'rap' => 'ຣາປານຸຍ',
        'rar' => 'ຣາໂຣທອນການ',
        'rhg' => 'ໂຣຮິນຢາ',
        'rm' => 'ໂຣແມນຊ໌',
        'rn' => 'ຣຸນດິ',
        'ro' => 'ໂຣແມນຽນ',
        'rof' => 'ຣົມໂບ',
        'rom' => 'ໂຣເມນີ',
        'ru' => 'ລັດເຊຍ',
        'rup' => 'ອາໂຣມານຽນ',
        'rw' => 'ຄິນຢາວານດາ',
        'rwk' => 'ອາຣວາ',
        'sa' => 'ສັນສະກຣິດ',
        'sad' => 'ຊັນດາວ',
        'sah' => 'ຊາກາ',
        'sam' => 'ສາມາຣິແຕນ-',
        'saq' => 'ຊຳບູຣູ',
        'sas' => 'ຊາຊັກ',
        'sat' => 'ຊານທາລິ',
        'sba' => 'ກຳເບ',
        'sbp' => 'ຊານກູ',
        'sc' => 'ສາດີນຽນ',
        'scn' => 'ຊີຊິລີນ',
        'sco' => 'ສກອດ',
        'sd' => 'ສິນທິ',
        'sdh' => 'ພາກໄຕ້ ຂອງ ກູດິດ',
        'se' => 'ຊາມິເໜືອ',
        'see' => 'ຊີນີກາ',
        'seh' => 'ຊີນາ',
        'sel' => 'ເຊນຄັບ',
        'ses' => 'ໂຄຍຣາໂບໂຣ ເຊນນິ',
        'sg' => 'ແຊງໂກ',
        'sga' => 'ອີຣິຊເກົ່າ',
        'sh' => 'ເຊີໂບ-ໂກເຊຍ',
        'shi' => 'ທາເຊວຫິດ',
        'shn' => 'ຊານ',
        'shu' => 'ອາລັບ-ຊາດ',
        'si' => 'ສິນຫາລາ',
        'sid' => 'ຊິດາໂມ',
        'sk' => 'ສະໂລແວັກ',
        'sl' => 'ສະໂລເວນຽນ',
        'slh' => 'ລູຊຸດຊີດໃຕ້',
        'sm' => 'ຊາມົວ',
        'sma' => 'ຊາມິໃຕ້',
        'smj' => 'ລຸນຊາມິ',
        'smn' => 'ອີນາຣິຊາມິ',
        'sms' => 'ສກອດຊາມິ',
        'sn' => 'ໂຊນາ',
        'snk' => 'ໂຊນິນກີ',
        'so' => 'ໂຊມາລີ',
        'sog' => 'ຊອກດິນ',
        'sq' => 'ອານບານຽນ',
        'sr' => 'ເຊີບຽນ',
        'srn' => 'ສຣານນານຕອນໂກ',
        'srr' => 'ເຊເລີ',
        'ss' => 'ຊຣາຕິ',
        'ssy' => 'ຊາໂຮ',
        'st' => 'ໂຊໂທໃຕ້',
        'str' => 'ຊ່ອງແຄບເຊລີຊ',
        'su' => 'ຊຸນແດນນີສ',
        'suk' => 'ຊູຄູມ້າ',
        'sus' => 'ຊູຊູ',
        'sux' => 'ຊູເມີເລຍ',
        'sv' => 'ສະວີດິຊ',
        'sw' => 'ຊວາຮີລິ',
        'swb' => 'ໂຄໂນຣຽນ',
        'syc' => 'ຊີເລຍແບບດັ້ງເດີມ',
        'syr' => 'ຊີເລຍ',
        'ta' => 'ທາມິລ',
        'tce' => 'ທຸດຊອນໃຕ້',
        'te' => 'ເຕລູກູ',
        'tem' => 'ທີມເນ',
        'teo' => 'ເຕໂຊ',
        'ter' => 'ເຕເລໂນ',
        'tet' => 'ເຕຕູມ',
        'tg' => 'ທາຈິກ',
        'tgx' => 'ທາກີຊ',
        'th' => 'ໄທ',
        'tht' => 'ທາວທັນ',
        'ti' => 'ຕິກຣິນຢາ',
        'tig' => 'ໄທກຣີ',
        'tiv' => 'ຕີວ',
        'tk' => 'ເທີກເມັນ',
        'tkl' => 'ໂຕເກເລົາ',
        'tl' => 'ຕາກາລອກ',
        'tlh' => 'ຄຣິງກອນ',
        'tli' => 'ທລີງກິດ',
        'tmh' => 'ທາມາກເຊກ',
        'tn' => 'ເຕສະວານາ',
        'to' => 'ທອງການ',
        'tog' => 'ນາຍອາຊາຕອງກາ',
        'tok' => 'ໂທກີໂພນາ',
        'tpi' => 'ທອກພີຊິນ',
        'tr' => 'ເທີຄິຊ',
        'trv' => 'ຕາໂລໂກ',
        'ts' => 'ເຕຊອງກາ',
        'tsi' => 'ຊີມຊີແອນ',
        'tt' => 'ທາທາ',
        'ttm' => 'ທັດໂຈນເເໜືອ',
        'tum' => 'ຕຳບູກາ',
        'tvl' => 'ຕູວາລູ',
        'tw' => 'ທວີ',
        'twq' => 'ຕາຊາວັກ',
        'ty' => 'ຕາຮີຕຽນ',
        'tyv' => 'ຕູວີນຽນ',
        'tzm' => 'ອັດລາສ ທາມາຊີກ ກາງ',
        'udm' => 'ອຸດມັດ',
        'ug' => 'ອຸຍເຄີ',
        'uga' => 'ຢູກາລິກ',
        'uk' => 'ຢູເຄຣນຽນ',
        'umb' => 'ອຳບັນດູ',
        'ur' => 'ອູຣດູ',
        'uz' => 'ອຸສເບກ',
        'vai' => 'ໄວ',
        've' => 'ເວນດາ',
        'vi' => 'ຫວຽດນາມ',
        'vo' => 'ໂວລາພັກ',
        'vot' => 'ໂວຕິກ',
        'vun' => 'ວັນໂຈ',
        'wa' => 'ວໍລູມ',
        'wae' => 'ວາເຊີ',
        'wal' => 'ວາລາໂມ',
        'war' => 'ວາເລ',
        'was' => 'ວາໂຊ',
        'wbp' => 'ວາຣພິຣິ',
        'wo' => 'ວໍລອບ',
        'wuu' => 'ຈີນອູ',
        'xal' => 'ການມິກ',
        'xh' => 'ໂຮຊາ',
        'xog' => 'ໂຊກາ',
        'yao' => 'ເຢົ້າ',
        'yap' => 'ຢັບ',
        'yav' => 'ແຍງເບນ',
        'ybb' => 'ແຢມບາ',
        'yi' => 'ຢິວ',
        'yo' => 'ໂຢຣູບາ',
        'yrl' => 'ນີນກາຕູ',
        'yue' => 'ກວາງຕຸ້ງ',
        'za' => 'ຊວາງ',
        'zap' => 'ຊາໂປແຕບ',
        'zbl' => 'ສັນຍາລັກບລີຊິມ',
        'zen' => 'ເຊນາກາ',
        'zgh' => 'ໂມຣັອກແຄນ ທາມາຊີກ ມາດຕະຖານ',
        'zh' => 'ຈີນ',
        'zu' => 'ຊູລູ',
        'zun' => 'ຊູນີ',
        'zza' => 'ຊາຊາ',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ອາຣາບິກມາດຕະຖານສະໄໝໃໝ່',
        'de_AT' => 'ເຢຍລະມັນ (ໂອສຕຣິດ)',
        'de_CH' => 'ສະວິສ ໄຮ ເຈີແມນ',
        'en_GB' => 'ອັງກິດ (ບຣິດທິຊ)',
        'en_US' => 'ອັງກິດ (ອາເມລິກັນ)',
        'es_419' => 'ລາຕິນ ອາເມຣິກັນ ສະແປນນິຊ',
        'es_ES' => 'ສະເປັນ ຢຸໂຣບ',
        'es_MX' => 'ເມັກຊິກັນ ສະແປນນິຊ',
        'fa_AF' => 'ດາຣີ',
        'fr_CH' => 'ຝຣັ່ງ (ສວິສ)',
        'nds_NL' => 'ຊາຊອນ ຕອນໄຕ',
        'nl_BE' => 'ຟລີມິຊ',
        'pt_BR' => 'ປອກຕຸຍກິສ ບະເລຊີ່ນ',
        'pt_PT' => 'ປອກຕຸຍກິສ ຢຸໂຣບ',
        'ro_MD' => 'ໂມດາວຽນ',
        'sw_CD' => 'ຄອງໂກ ຊວາຮີລິ',
        'zh_Hans' => 'ຈີນແບບຮຽບງ່າຍ',
        'zh_Hant' => 'ຈີນແບບດັ້ງເດີມ',
    ],
];
