<?php

return [
    'Names' => [
        'aa' => 'آفاری',
        'ab' => 'آبخازی',
        'ace' => 'آچئی',
        'ach' => 'آچولیایی',
        'ada' => 'آدانگمه‌ای',
        'ady' => 'آدیجیایی',
        'ae' => 'اوستایی',
        'aeb' => 'عربی تونسی',
        'af' => 'آفریکانس',
        'afh' => 'آفریهیلی',
        'agq' => 'آگیم',
        'ain' => 'آینویی',
        'ak' => 'آکان',
        'akk' => 'اکدی',
        'akz' => 'آلابامایی',
        'ale' => 'آلئوتی',
        'alt' => 'آلتایی جنوبی',
        'am' => 'امهری',
        'an' => 'آراگونی',
        'ang' => 'انگلیسی باستان',
        'ann' => 'اوبولو',
        'anp' => 'آنگیکا',
        'ar' => 'عربی',
        'arc' => 'آرامی',
        'arn' => 'ماپوچه‌ای',
        'arp' => 'آراپاهویی',
        'arq' => 'عربی الجزایری',
        'ars' => 'عربی نجدی',
        'arw' => 'آراواکی',
        'ary' => 'عربی مراکشی',
        'arz' => 'عربی مصری',
        'as' => 'آسامی',
        'asa' => 'آسو',
        'ast' => 'آستوری',
        'atj' => 'آتیکامکو',
        'av' => 'آواری',
        'awa' => 'اودهی',
        'ay' => 'آیمارایی',
        'az' => 'ترکی آذربایجانی',
        'ba' => 'باشقیری',
        'bal' => 'بلوچی',
        'ban' => 'بالیایی',
        'bar' => 'باواریایی',
        'bas' => 'باسایی',
        'bax' => 'بمونی',
        'be' => 'بلاروسی',
        'bej' => 'بجایی',
        'bem' => 'بمبایی',
        'bez' => 'بنایی',
        'bg' => 'بلغاری',
        'bgn' => 'بلوچی غربی',
        'bho' => 'بوجپوری',
        'bi' => 'بیسلاما',
        'bik' => 'بیکولی',
        'bin' => 'بینی',
        'bla' => 'سیکسیکا',
        'bm' => 'بامبارایی',
        'bn' => 'بنگالی',
        'bo' => 'تبتی',
        'bqi' => 'لری بختیاری',
        'br' => 'برتون',
        'bra' => 'براج',
        'brh' => 'براهویی',
        'brx' => 'بودویی',
        'bs' => 'بوسنیایی',
        'bua' => 'بوریاتی',
        'bug' => 'بوگینس',
        'byn' => 'بلین',
        'ca' => 'کاتالان',
        'cad' => 'کادویی',
        'car' => 'کاریبی',
        'cay' => 'کایوگا',
        'ccp' => 'چاکما',
        'ce' => 'چچنی',
        'ceb' => 'سبویی',
        'cgg' => 'چیگا',
        'ch' => 'چامورویی',
        'chb' => 'چیبچا',
        'chg' => 'جغتایی',
        'chk' => 'چوکی',
        'chm' => 'ماریایی',
        'cho' => 'چوکتویی',
        'chp' => 'چیپه‌ویه‌ای',
        'chr' => 'چروکی',
        'chy' => 'شایانی',
        'ckb' => 'کردی مرکزی',
        'clc' => 'چیلکوتن',
        'co' => 'کورسی',
        'cop' => 'قبطی',
        'cr' => 'کریایی',
        'crg' => 'میچیف',
        'crh' => 'ترکی کریمه',
        'crj' => 'کری جنوب شرقی',
        'crk' => 'کری صحرایی',
        'crl' => 'کری شمال شرقی',
        'crm' => 'موس کری',
        'crr' => 'آلگانکوین کارولینا',
        'crs' => 'سیشل آمیختهٔ فرانسوی',
        'cs' => 'چکی',
        'csb' => 'کاشوبی',
        'csw' => 'کری سوامپی',
        'cu' => 'اسلاوی کلیسایی',
        'cv' => 'چوواشی',
        'cy' => 'ولزی',
        'da' => 'دانمارکی',
        'dak' => 'داکوتایی',
        'dar' => 'دارگوا',
        'dav' => 'تایتا',
        'de' => 'آلمانی',
        'del' => 'دلاواری',
        'dgr' => 'دوگریب',
        'din' => 'دینکایی',
        'dje' => 'زرما',
        'doi' => 'دوگری',
        'dsb' => 'صُربی سفلی',
        'dua' => 'دوآلایی',
        'dum' => 'هلندی میانه',
        'dv' => 'دیوهی',
        'dyo' => 'دیولا فونی',
        'dyu' => 'دایولایی',
        'dz' => 'دزونگخا',
        'dzg' => 'دازاگا',
        'ebu' => 'امبو',
        'ee' => 'اوه‌ای',
        'efi' => 'افیکی',
        'egy' => 'مصری کهن',
        'eka' => 'اکاجوک',
        'el' => 'یونانی',
        'elx' => 'عیلامی',
        'en' => 'انگلیسی',
        'enm' => 'انگلیسی میانه',
        'eo' => 'اسپرانتو',
        'es' => 'اسپانیایی',
        'et' => 'استونیایی',
        'eu' => 'باسکی',
        'ewo' => 'اواندو',
        'fa' => 'فارسی',
        'fan' => 'فانگی',
        'fat' => 'فانتیایی',
        'ff' => 'فولانی',
        'fi' => 'فنلاندی',
        'fil' => 'فیلیپینی',
        'fj' => 'فیجیایی',
        'fo' => 'فارویی',
        'fon' => 'فونی',
        'fr' => 'فرانسوی',
        'frc' => 'فرانسوی کاجون',
        'frm' => 'فرانسوی میانه',
        'fro' => 'فرانسوی باستان',
        'frr' => 'فریزی شمالی',
        'frs' => 'فریزی شرقی',
        'fur' => 'فریولیایی',
        'fy' => 'فریسی غربی',
        'ga' => 'ایرلندی',
        'gaa' => 'گایی',
        'gag' => 'گاگائوزیایی',
        'gay' => 'گایویی',
        'gba' => 'گبایایی',
        'gbz' => 'دری زرتشتی',
        'gd' => 'گیلی اسکاتلندی',
        'gez' => 'گی‌ئزی',
        'gil' => 'گیلبرتی',
        'gl' => 'گالیسیایی',
        'glk' => 'گیلکی',
        'gmh' => 'آلمانی معیار میانه',
        'gn' => 'گوارانی',
        'goh' => 'آلمانی علیای باستان',
        'gon' => 'گوندی',
        'gor' => 'گورونتالو',
        'got' => 'گوتی',
        'grb' => 'گریبویی',
        'grc' => 'یونانی کهن',
        'gsw' => 'آلمانی سوئیسی',
        'gu' => 'گجراتی',
        'guz' => 'گوسی',
        'gv' => 'مانی',
        'gwi' => 'گویچ این',
        'ha' => 'هوسایی',
        'hai' => 'هایدایی',
        'haw' => 'هاوایی',
        'hax' => 'هایدا جنوبی',
        'he' => 'عبری',
        'hi' => 'هندی',
        'hif' => 'هندی فیجیایی',
        'hil' => 'هیلی‌گاینونی',
        'hit' => 'هیتی',
        'hmn' => 'همونگ',
        'ho' => 'موتویی هیری',
        'hr' => 'کروات',
        'hsb' => 'صُربی علیا',
        'ht' => 'هائیتیایی',
        'hu' => 'مجاری',
        'hup' => 'هوپا',
        'hur' => 'هالکوملم',
        'hy' => 'ارمنی',
        'hz' => 'هریرویی',
        'ia' => 'اینترلینگوا',
        'iba' => 'ایبانی',
        'ibb' => 'ایبیبیو',
        'id' => 'اندونزیایی',
        'ie' => 'اکسیدنتال',
        'ig' => 'ایگبویی',
        'ii' => 'یی سیچوان',
        'ik' => 'اینوپیک',
        'ikt' => 'اینوکتیتوت غرب کانادا',
        'ilo' => 'ایلوکویی',
        'inh' => 'اینگوشی',
        'io' => 'ایدو',
        'is' => 'ایسلندی',
        'it' => 'ایتالیایی',
        'iu' => 'اینوکتیتوت',
        'ja' => 'ژاپنی',
        'jbo' => 'لوجبان',
        'jgo' => 'نگومبا',
        'jmc' => 'ماچامه‌ای',
        'jpr' => 'فارسی یهودی',
        'jrb' => 'عربی یهودی',
        'jv' => 'جاوه‌ای',
        'ka' => 'گرجی',
        'kaa' => 'قره‌قالپاقی',
        'kab' => 'قبایلی',
        'kac' => 'کاچینی',
        'kaj' => 'جو',
        'kam' => 'کامبایی',
        'kaw' => 'کاویایی',
        'kbd' => 'کاباردینی',
        'kcg' => 'تیاپی',
        'kde' => 'ماکونده',
        'kea' => 'کابووردیانو',
        'kfo' => 'کورو',
        'kg' => 'کنگویی',
        'kgp' => 'کاین گنگ',
        'kha' => 'خاسیایی',
        'kho' => 'ختنی',
        'khq' => 'کوجراچینی',
        'khw' => 'کهوار',
        'ki' => 'کیکویویی',
        'kiu' => 'کرمانجی',
        'kj' => 'کوانیاما',
        'kk' => 'قزاقی',
        'kkj' => 'کاکایی',
        'kl' => 'گرینلندی',
        'kln' => 'کالنجین',
        'km' => 'خمری',
        'kmb' => 'کیمبوندویی',
        'kn' => 'کانارا',
        'ko' => 'کره‌ای',
        'koi' => 'کومی پرمیاک',
        'kok' => 'کنکانی',
        'kpe' => 'کپله‌ای',
        'kr' => 'کانوریایی',
        'krc' => 'قره‌چایی‐بالکاری',
        'krl' => 'کاریلیانی',
        'kru' => 'کوروخی',
        'ks' => 'کشمیری',
        'ksb' => 'شامبالا',
        'ksf' => 'بافیایی',
        'ksh' => 'کولش',
        'ku' => 'کردی',
        'kum' => 'کومیکی',
        'kut' => 'کوتنی',
        'kv' => 'کومیایی',
        'kw' => 'کورنی',
        'kwk' => 'کواک والا',
        'ky' => 'قرقیزی',
        'la' => 'لاتین',
        'lad' => 'لادینو',
        'lag' => 'لانگی',
        'lah' => 'لاهندا',
        'lam' => 'لامبا',
        'lb' => 'لوگزامبورگی',
        'lez' => 'لزگی',
        'lg' => 'گاندایی',
        'li' => 'لیمبورگی',
        'lil' => 'لیلوئت',
        'lkt' => 'لاکوتا',
        'ln' => 'لینگالا',
        'lo' => 'لائوسی',
        'lol' => 'مونگویی',
        'lou' => 'کرئول لوئیزیانا',
        'loz' => 'لوزیایی',
        'lrc' => 'لری شمالی',
        'lsm' => 'سامیا',
        'lt' => 'لیتوانیایی',
        'lu' => 'لوبایی‐کاتانگا',
        'lua' => 'لوبایی‐لولوا',
        'lui' => 'لویسنو',
        'lun' => 'لوندایی',
        'luo' => 'لوئویی',
        'lus' => 'میزو',
        'luy' => 'لویا',
        'lv' => 'لتونیایی',
        'lzh' => 'چینی ادبی',
        'mad' => 'مادورایی',
        'mag' => 'ماگاهیایی',
        'mai' => 'مایدیلی',
        'mak' => 'ماکاسار',
        'man' => 'ماندینگویی',
        'mas' => 'ماسایی',
        'mdf' => 'مکشایی',
        'mdr' => 'ماندار',
        'men' => 'منده‌ای',
        'mer' => 'مرویی',
        'mfe' => 'موریسین',
        'mg' => 'مالاگاسی',
        'mga' => 'ایرلندی میانه',
        'mgh' => 'ماکوا متو',
        'mgo' => 'متایی',
        'mh' => 'مارشالی',
        'mi' => 'مائوری',
        'mic' => 'میکماکی',
        'min' => 'مینانگ‌کابویی',
        'mk' => 'مقدونی',
        'ml' => 'مالایالامی',
        'mn' => 'مغولی',
        'mnc' => 'مانچویی',
        'mni' => 'مانیپوری',
        'moe' => 'اینوآیموم',
        'moh' => 'موهاکی',
        'mos' => 'ماسیایی',
        'mr' => 'مراتی',
        'ms' => 'مالایی',
        'mt' => 'مالتی',
        'mua' => 'ماندانگی',
        'mus' => 'کریکی',
        'mwl' => 'میراندی',
        'mwr' => 'مارواری',
        'my' => 'برمه‌ای',
        'myv' => 'ارزیایی',
        'mzn' => 'مازندرانی',
        'na' => 'نائورویی',
        'nap' => 'ناپلی',
        'naq' => 'نامایی',
        'nb' => 'نروژی بوک‌مُل',
        'nd' => 'انده‌بله‌ای شمالی',
        'nds' => 'آلمانی سفلی',
        'ne' => 'نپالی',
        'new' => 'نواریایی',
        'ng' => 'اندونگایی',
        'nia' => 'نیاسی',
        'niu' => 'نیویی',
        'nl' => 'هلندی',
        'nmg' => 'کوازیو',
        'nn' => 'نروژی نی‌نُشک',
        'nnh' => 'نیامبون',
        'no' => 'نروژی',
        'nog' => 'نغایی',
        'non' => 'نرس باستان',
        'nqo' => 'نکو',
        'nr' => 'انده‌بله‌ای جنوبی',
        'nso' => 'سوتویی شمالی',
        'nus' => 'نویر',
        'nv' => 'ناواهویی',
        'nwc' => 'نواریایی کلاسیک',
        'ny' => 'نیانجایی',
        'nym' => 'نیام‌وزیایی',
        'nyn' => 'نیانکوله‌ای',
        'nyo' => 'نیورویی',
        'nzi' => 'نزیمایی',
        'oc' => 'اکسیتان',
        'oj' => 'اوجیبوایی',
        'ojb' => 'اوجیبوای شمالی',
        'ojc' => 'اوجیبوای مرکزی',
        'ojs' => 'اوجی-کری',
        'ojw' => 'اوجیبوای غربی',
        'oka' => 'اوکاناگان',
        'om' => 'اورومویی',
        'or' => 'اوریه‌ای',
        'os' => 'آسی',
        'osa' => 'اوسیجی',
        'ota' => 'ترکی عثمانی',
        'pa' => 'پنجابی',
        'pag' => 'پانگاسینانی',
        'pal' => 'پهلوی',
        'pam' => 'پامپانگایی',
        'pap' => 'پاپیامنتو',
        'pau' => 'پالائویی',
        'pcm' => 'نیم‌زبان نیجریه‌ای',
        'pdc' => 'آلمانی پنسیلوانیایی',
        'peo' => 'فارسی باستان',
        'phn' => 'فنیقی',
        'pi' => 'پالی',
        'pis' => 'پی‌جین',
        'pl' => 'لهستانی',
        'pon' => 'پانپیی',
        'pqm' => 'ملیسیت - پاسماکودی',
        'prg' => 'پروسی',
        'pro' => 'پرووانسی باستان',
        'ps' => 'پشتو',
        'pt' => 'پرتغالی',
        'qu' => 'کچوایی',
        'quc' => 'کیچه‌',
        'raj' => 'راجستانی',
        'rap' => 'راپانویی',
        'rar' => 'راروتونگایی',
        'rhg' => 'روهینگیا',
        'rm' => 'رومانش',
        'rn' => 'روندیایی',
        'ro' => 'رومانیایی',
        'rof' => 'رومبویی',
        'rom' => 'رومانویی',
        'ru' => 'روسی',
        'rup' => 'آرومانی',
        'rw' => 'کینیارواندایی',
        'rwk' => 'روایی',
        'sa' => 'سانسکریت',
        'sad' => 'سانداوه‌ای',
        'sah' => 'یاقوتی',
        'sam' => 'آرامی سامری',
        'saq' => 'سامبورو',
        'sas' => 'ساساکی',
        'sat' => 'سانتالی',
        'sba' => 'انگامبایی',
        'sbp' => 'سانگویی',
        'sc' => 'ساردینیایی',
        'scn' => 'سیسیلی',
        'sco' => 'اسکاتلندی',
        'sd' => 'سندی',
        'sdh' => 'کردی جنوبی',
        'se' => 'سامی شمالی',
        'seh' => 'سنا',
        'sel' => 'سلکوپی',
        'ses' => 'کویرابورا سنی',
        'sg' => 'سانگو',
        'sga' => 'ایرلندی باستان',
        'sh' => 'صرب و کرواتی',
        'shi' => 'تاچل‌هیت',
        'shn' => 'شانی',
        'shu' => 'عربی چادی',
        'si' => 'سینهالی',
        'sid' => 'سیدامویی',
        'sk' => 'اسلواکی',
        'sl' => 'اسلوونیایی',
        'slh' => 'لاشوتسید جنوبی',
        'sli' => 'سیلزیایی سفلی',
        'sm' => 'ساموآیی',
        'sma' => 'سامی جنوبی',
        'smj' => 'لوله سامی',
        'smn' => 'ایناری سامی',
        'sms' => 'اسکولت سامی',
        'sn' => 'شونایی',
        'snk' => 'سونینکه‌ای',
        'so' => 'سومالیایی',
        'sog' => 'سغدی',
        'sq' => 'آلبانیایی',
        'sr' => 'صربی',
        'srn' => 'زبان اسرانان',
        'srr' => 'سریری',
        'ss' => 'سوازیایی',
        'ssy' => 'ساهو',
        'st' => 'سوتوی جنوبی',
        'str' => 'سالیش استریتز',
        'su' => 'سوندایی',
        'suk' => 'سوکومایی',
        'sus' => 'سوسویی',
        'sux' => 'سومری',
        'sv' => 'سوئدی',
        'sw' => 'سواحیلی',
        'swb' => 'کوموری',
        'syc' => 'سریانی کلاسیک',
        'syr' => 'سریانی',
        'szl' => 'سیلزیایی',
        'ta' => 'تامیلی',
        'tce' => 'توچون جنوبی',
        'te' => 'تلوگویی',
        'tem' => 'تمنه‌ای',
        'teo' => 'تسویی',
        'ter' => 'ترنو',
        'tet' => 'تتومی',
        'tg' => 'تاجیکی',
        'tgx' => 'تاگیش',
        'th' => 'تایلندی',
        'tht' => 'تالتان',
        'ti' => 'تیگرینیایی',
        'tig' => 'تیگره‌ای',
        'tiv' => 'تیوی',
        'tk' => 'ترکمنی',
        'tl' => 'تاگالوگی',
        'tlh' => 'کلینگون',
        'tli' => 'تلین‌گیتی',
        'tmh' => 'تاماشقی',
        'tn' => 'تسوانایی',
        'to' => 'تونگایی',
        'tog' => 'تونگایی نیاسا',
        'tok' => 'توکی پونا',
        'tpi' => 'توک‌پیسینی',
        'tr' => 'ترکی استانبولی',
        'trv' => 'تاروکویی',
        'ts' => 'تسونگایی',
        'tsi' => 'تسیم‌شیانی',
        'tt' => 'تاتاری',
        'ttm' => 'تاچونی شمالی',
        'tum' => 'تومبوکایی',
        'tvl' => 'تووالویی',
        'tw' => 'توی‌یایی',
        'twq' => 'تسواکی',
        'ty' => 'تاهیتیایی',
        'tyv' => 'تووایی',
        'tzm' => 'آمازیغی اطلس مرکزی',
        'udm' => 'اودمورتی',
        'ug' => 'اویغوری',
        'uga' => 'اوگاریتی',
        'uk' => 'اوکراینی',
        'umb' => 'امبوندویی',
        'ur' => 'اردو',
        'uz' => 'ازبکی',
        'vai' => 'ویایی',
        've' => 'وندایی',
        'vi' => 'ویتنامی',
        'vo' => 'ولاپوک',
        'vot' => 'وتی',
        'vun' => 'ونجو',
        'wa' => 'والونی',
        'wae' => 'والسر',
        'wal' => 'والامو',
        'war' => 'وارایی',
        'was' => 'واشویی',
        'wbp' => 'وارلپیری',
        'wo' => 'ولوفی',
        'wuu' => 'وو چینی',
        'xal' => 'قلموقی',
        'xh' => 'خوسایی',
        'xog' => 'سوگایی',
        'yao' => 'یائویی',
        'yap' => 'یاپی',
        'yav' => 'یانگبنی',
        'ybb' => 'یمبایی',
        'yi' => 'یدی',
        'yo' => 'یوروبایی',
        'yrl' => 'نهین گاتو',
        'yue' => 'کانتونی',
        'za' => 'چوانگی',
        'zap' => 'زاپوتکی',
        'zen' => 'زناگا',
        'zgh' => 'آمازیغی معیار مراکش',
        'zh' => 'چینی',
        'zu' => 'زولویی',
        'zun' => 'زونیایی',
        'zza' => 'زازایی',
    ],
    'LocalizedNames' => [
        'ar_001' => 'عربی رسمی',
        'az_Arab' => 'ترکی آذری جنوبی',
        'de_AT' => 'آلمانی اتریش',
        'de_CH' => 'آلمانی معیار سوئیس',
        'en_AU' => 'انگلیسی استرالیا',
        'en_CA' => 'انگلیسی کانادا',
        'en_GB' => 'انگلیسی بریتانیا',
        'en_US' => 'انگلیسی آمریکا',
        'es_419' => 'اسپانیایی امریکای لاتین',
        'es_ES' => 'اسپانیایی اروپا',
        'es_MX' => 'اسپانیایی مکزیک',
        'fa_AF' => 'دری',
        'fr_CA' => 'فرانسوی کانادا',
        'fr_CH' => 'فرانسوی سوئیس',
        'nds_NL' => 'ساکسونی سفلی',
        'nl_BE' => 'فلمنگی',
        'pt_BR' => 'پرتغالی برزیل',
        'pt_PT' => 'پرتغالی اروپا',
        'ro_MD' => 'مولداویایی',
        'sw_CD' => 'سواحیلی کنگو',
        'zh_Hans' => 'چینی ساده‌شده',
        'zh_Hant' => 'چینی سنتی',
    ],
];
