<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'เวลามาตรฐานกรีนิช (อาบีจาน)',
        'Africa/Accra' => 'เวลามาตรฐานกรีนิช (อักกรา)',
        'Africa/Addis_Ababa' => 'เวลาแอฟริกาตะวันออก (แอดดิสอาบาบา)',
        'Africa/Algiers' => 'เวลายุโรปกลาง (แอลเจียร์)',
        'Africa/Asmera' => 'เวลาแอฟริกาตะวันออก (แอสมารา)',
        'Africa/Bamako' => 'เวลามาตรฐานกรีนิช (บามาโก)',
        'Africa/Bangui' => 'เวลาแอฟริกาตะวันตก (บังกี)',
        'Africa/Banjul' => 'เวลามาตรฐานกรีนิช (บันจูล)',
        'Africa/Bissau' => 'เวลามาตรฐานกรีนิช (บิสเซา)',
        'Africa/Blantyre' => 'เวลาแอฟริกากลาง (แบลนไทร์)',
        'Africa/Brazzaville' => 'เวลาแอฟริกาตะวันตก (บราซซาวิล)',
        'Africa/Bujumbura' => 'เวลาแอฟริกากลาง (บูจุมบูรา)',
        'Africa/Cairo' => 'เวลายุโรปตะวันออก (ไคโร)',
        'Africa/Casablanca' => 'เวลายุโรปตะวันตก (คาสซาบลางก้า)',
        'Africa/Ceuta' => 'เวลายุโรปกลาง (เซวตา)',
        'Africa/Conakry' => 'เวลามาตรฐานกรีนิช (โกนากรี)',
        'Africa/Dakar' => 'เวลามาตรฐานกรีนิช (ดาการ์)',
        'Africa/Dar_es_Salaam' => 'เวลาแอฟริกาตะวันออก (ดาร์เอสซาลาม)',
        'Africa/Djibouti' => 'เวลาแอฟริกาตะวันออก (จิบูตี)',
        'Africa/Douala' => 'เวลาแอฟริกาตะวันตก (ดูอาลา)',
        'Africa/El_Aaiun' => 'เวลายุโรปตะวันตก (เอลไอย์อุง)',
        'Africa/Freetown' => 'เวลามาตรฐานกรีนิช (ฟรีทาวน์)',
        'Africa/Gaborone' => 'เวลาแอฟริกากลาง (กาโบโรเน)',
        'Africa/Harare' => 'เวลาแอฟริกากลาง (ฮาราเร)',
        'Africa/Johannesburg' => 'เวลาแอฟริกาใต้ (โจฮันเนสเบอร์ก)',
        'Africa/Juba' => 'เวลาแอฟริกากลาง (จูบา)',
        'Africa/Kampala' => 'เวลาแอฟริกาตะวันออก (คัมพาลา)',
        'Africa/Khartoum' => 'เวลาแอฟริกากลาง (คาร์ทูม)',
        'Africa/Kigali' => 'เวลาแอฟริกากลาง (คิกาลี)',
        'Africa/Kinshasa' => 'เวลาแอฟริกาตะวันตก (กินชาซา)',
        'Africa/Lagos' => 'เวลาแอฟริกาตะวันตก (ลากอส)',
        'Africa/Libreville' => 'เวลาแอฟริกาตะวันตก (ลีเบรอวิล)',
        'Africa/Lome' => 'เวลามาตรฐานกรีนิช (โลเม)',
        'Africa/Luanda' => 'เวลาแอฟริกาตะวันตก (ลูอันดา)',
        'Africa/Lubumbashi' => 'เวลาแอฟริกากลาง (ลูบัมบาชิ)',
        'Africa/Lusaka' => 'เวลาแอฟริกากลาง (ลูซากา)',
        'Africa/Malabo' => 'เวลาแอฟริกาตะวันตก (มาลาโบ)',
        'Africa/Maputo' => 'เวลาแอฟริกากลาง (มาปูโต)',
        'Africa/Maseru' => 'เวลาแอฟริกาใต้ (มาเซรู)',
        'Africa/Mbabane' => 'เวลาแอฟริกาใต้ (อัมบาบาเน)',
        'Africa/Mogadishu' => 'เวลาแอฟริกาตะวันออก (โมกาดิชู)',
        'Africa/Monrovia' => 'เวลามาตรฐานกรีนิช (มันโรเวีย)',
        'Africa/Nairobi' => 'เวลาแอฟริกาตะวันออก (ไนโรเบีย)',
        'Africa/Ndjamena' => 'เวลาแอฟริกาตะวันตก (เอ็นจาเมนา)',
        'Africa/Niamey' => 'เวลาแอฟริกาตะวันตก (นีอาเมย์)',
        'Africa/Nouakchott' => 'เวลามาตรฐานกรีนิช (นูแอกชอต)',
        'Africa/Ouagadougou' => 'เวลามาตรฐานกรีนิช (วากาดูกู)',
        'Africa/Porto-Novo' => 'เวลาแอฟริกาตะวันตก (ปอร์โต-โนโว)',
        'Africa/Sao_Tome' => 'เวลามาตรฐานกรีนิช (เซาตูเม)',
        'Africa/Tripoli' => 'เวลายุโรปตะวันออก (ตรีโปลี)',
        'Africa/Tunis' => 'เวลายุโรปกลาง (ตูนิส)',
        'Africa/Windhoek' => 'เวลาแอฟริกากลาง (วินด์ฮุก)',
        'America/Adak' => 'เวลาฮาวาย-อะลูเชียน (เอดัก)',
        'America/Anchorage' => 'เวลาอะแลสกา (แองเคอเรจ)',
        'America/Anguilla' => 'เวลาแอตแลนติก (แองกิลลา)',
        'America/Antigua' => 'เวลาแอตแลนติก (แอนติกา)',
        'America/Araguaina' => 'เวลาบราซิเลีย (อารากัวนา)',
        'America/Argentina/La_Rioja' => 'เวลาอาร์เจนตินา (ลาริโอจา)',
        'America/Argentina/Rio_Gallegos' => 'เวลาอาร์เจนตินา (ริโอกาลเลกอส)',
        'America/Argentina/Salta' => 'เวลาอาร์เจนตินา (ซัลตา)',
        'America/Argentina/San_Juan' => 'เวลาอาร์เจนตินา (ซานฮวน)',
        'America/Argentina/San_Luis' => 'เวลาอาร์เจนตินา (ซันลูอิส)',
        'America/Argentina/Tucuman' => 'เวลาอาร์เจนตินา (ทูคูแมน)',
        'America/Argentina/Ushuaia' => 'เวลาอาร์เจนตินา (อูชูเอีย)',
        'America/Aruba' => 'เวลาแอตแลนติก (อารูบา)',
        'America/Asuncion' => 'เวลาปารากวัย (อะซุนซิออง)',
        'America/Bahia' => 'เวลาบราซิเลีย (บาเยีย)',
        'America/Bahia_Banderas' => 'เวลาตอนกลางในอเมริกาเหนือ (บาเอียบันเดรัส)',
        'America/Barbados' => 'เวลาแอตแลนติก (บาร์เบโดส)',
        'America/Belem' => 'เวลาบราซิเลีย (เบเลง)',
        'America/Belize' => 'เวลาตอนกลางในอเมริกาเหนือ (เบลีซ)',
        'America/Blanc-Sablon' => 'เวลาแอตแลนติก (บลังค์-ซาบลอน)',
        'America/Boa_Vista' => 'เวลาแอมะซอน (บัววีชตา)',
        'America/Bogota' => 'เวลาโคลอมเบีย (โบโกตา)',
        'America/Boise' => 'เวลาแถบภูเขาในอเมริกาเหนือ (บอยซี)',
        'America/Buenos_Aires' => 'เวลาอาร์เจนตินา (บัวโนสไอเรส)',
        'America/Cambridge_Bay' => 'เวลาแถบภูเขาในอเมริกาเหนือ (อ่าวแคมบริดจ์)',
        'America/Campo_Grande' => 'เวลาแอมะซอน (กัมปูกรันดี)',
        'America/Cancun' => 'เวลาทางตะวันออกในอเมริกาเหนือ (แคนคุน)',
        'America/Caracas' => 'เวลาเวเนซุเอลา (คาราคัส)',
        'America/Catamarca' => 'เวลาอาร์เจนตินา (กาตามาร์กา)',
        'America/Cayenne' => 'เวลาเฟรนช์เกียนา (กาแยน)',
        'America/Cayman' => 'เวลาทางตะวันออกในอเมริกาเหนือ (เคย์แมน)',
        'America/Chicago' => 'เวลาตอนกลางในอเมริกาเหนือ (ชิคาโก)',
        'America/Chihuahua' => 'เวลาแปซิฟิกเม็กซิโก (ชีวาวา)',
        'America/Coral_Harbour' => 'เวลาทางตะวันออกในอเมริกาเหนือ (คอรัลฮาร์เบอร์)',
        'America/Cordoba' => 'เวลาอาร์เจนตินา (คอร์โดบา)',
        'America/Costa_Rica' => 'เวลาตอนกลางในอเมริกาเหนือ (คอสตาริกา)',
        'America/Creston' => 'เวลาแถบภูเขาในอเมริกาเหนือ (เครสตัน)',
        'America/Cuiaba' => 'เวลาแอมะซอน (กุยาบา)',
        'America/Curacao' => 'เวลาแอตแลนติก (คูราเซา)',
        'America/Danmarkshavn' => 'เวลามาตรฐานกรีนิช (ดานมาร์กสฮาวน์)',
        'America/Dawson' => 'เวลายูคอน (ดอว์สัน)',
        'America/Dawson_Creek' => 'เวลาแถบภูเขาในอเมริกาเหนือ (ดอว์สัน ครีก)',
        'America/Denver' => 'เวลาแถบภูเขาในอเมริกาเหนือ (เดนเวอร์)',
        'America/Detroit' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ดีทรอยต์)',
        'America/Dominica' => 'เวลาแอตแลนติก (โดมินิกา)',
        'America/Edmonton' => 'เวลาแถบภูเขาในอเมริกาเหนือ (เอดมันตัน)',
        'America/Eirunepe' => 'เวลาอาเกร (เอรูเนเป)',
        'America/El_Salvador' => 'เวลาตอนกลางในอเมริกาเหนือ (เอลซัลวาดอร์)',
        'America/Fort_Nelson' => 'เวลาแถบภูเขาในอเมริกาเหนือ (ฟอร์ตเนลสัน)',
        'America/Fortaleza' => 'เวลาบราซิเลีย (ฟอร์ตาเลซา)',
        'America/Glace_Bay' => 'เวลาแอตแลนติก (เกลซเบย์)',
        'America/Godthab' => 'เวลากรีนแลนด์ตะวันตก (กอดแธบ)',
        'America/Goose_Bay' => 'เวลาแอตแลนติก (กูสเบย์)',
        'America/Grand_Turk' => 'เวลาทางตะวันออกในอเมริกาเหนือ (แกรนด์เติร์ก)',
        'America/Grenada' => 'เวลาแอตแลนติก (เกรนาดา)',
        'America/Guadeloupe' => 'เวลาแอตแลนติก (กวาเดอลูป)',
        'America/Guatemala' => 'เวลาตอนกลางในอเมริกาเหนือ (กัวเตมาลา)',
        'America/Guayaquil' => 'เวลาเอกวาดอร์ (กัวยากิล)',
        'America/Guyana' => 'เวลากายอานา',
        'America/Halifax' => 'เวลาแอตแลนติก (แฮลิแฟกซ์)',
        'America/Havana' => 'เวลาคิวบา (ฮาวานา)',
        'America/Hermosillo' => 'เวลาแปซิฟิกเม็กซิโก (เอร์โมซีโย)',
        'America/Indiana/Knox' => 'เวลาตอนกลางในอเมริกาเหนือ (นอกซ์, อินดีแอนา)',
        'America/Indiana/Marengo' => 'เวลาทางตะวันออกในอเมริกาเหนือ (มาเรงโก, อินดีแอนา)',
        'America/Indiana/Petersburg' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ปีเตอร์สเบิร์ก, อินดีแอนา)',
        'America/Indiana/Tell_City' => 'เวลาตอนกลางในอเมริกาเหนือ (เทลล์ซิตี, อินดีแอนา)',
        'America/Indiana/Vevay' => 'เวลาทางตะวันออกในอเมริกาเหนือ (วีเวย์, อินดีแอนา)',
        'America/Indiana/Vincennes' => 'เวลาทางตะวันออกในอเมริกาเหนือ (วินเซนเนส, อินดีแอนา)',
        'America/Indiana/Winamac' => 'เวลาทางตะวันออกในอเมริกาเหนือ (วินาแมค, อินดีแอนา)',
        'America/Indianapolis' => 'เวลาทางตะวันออกในอเมริกาเหนือ (อินเดียแนโพลิส)',
        'America/Inuvik' => 'เวลาแถบภูเขาในอเมริกาเหนือ (อินูวิก)',
        'America/Iqaluit' => 'เวลาทางตะวันออกในอเมริกาเหนือ (อีกวาลิต)',
        'America/Jamaica' => 'เวลาทางตะวันออกในอเมริกาเหนือ (จาเมกา)',
        'America/Jujuy' => 'เวลาอาร์เจนตินา (จูจิว)',
        'America/Juneau' => 'เวลาอะแลสกา (จูโน)',
        'America/Kentucky/Monticello' => 'เวลาทางตะวันออกในอเมริกาเหนือ (มอนติเซลโล, เคนตักกี)',
        'America/Kralendijk' => 'เวลาแอตแลนติก (คราเลนดิจค์)',
        'America/La_Paz' => 'เวลาโบลิเวีย (ลาปาซ)',
        'America/Lima' => 'เวลาเปรู (ลิมา)',
        'America/Los_Angeles' => 'เวลาแปซิฟิกในอเมริกาเหนือ (ลอสแองเจลิส)',
        'America/Louisville' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ลูส์วิลล์)',
        'America/Lower_Princes' => 'เวลาแอตแลนติก (โลเวอร์พรินซ์ ควอเตอร์)',
        'America/Maceio' => 'เวลาบราซิเลีย (มาเซโอ)',
        'America/Managua' => 'เวลาตอนกลางในอเมริกาเหนือ (มานากัว)',
        'America/Manaus' => 'เวลาแอมะซอน (มาเนาส์)',
        'America/Marigot' => 'เวลาแอตแลนติก (มาริโกต์)',
        'America/Martinique' => 'เวลาแอตแลนติก (มาร์ตินีก)',
        'America/Matamoros' => 'เวลาตอนกลางในอเมริกาเหนือ (มาตาโมรอส)',
        'America/Mazatlan' => 'เวลาแปซิฟิกเม็กซิโก (มาซาทลาน)',
        'America/Mendoza' => 'เวลาอาร์เจนตินา (เมนดูซา)',
        'America/Menominee' => 'เวลาตอนกลางในอเมริกาเหนือ (เมโนมินี)',
        'America/Merida' => 'เวลาตอนกลางในอเมริกาเหนือ (เมรีดา)',
        'America/Metlakatla' => 'เวลาอะแลสกา (เมทลากาตละ)',
        'America/Mexico_City' => 'เวลาตอนกลางในอเมริกาเหนือ (เม็กซิโกซิตี)',
        'America/Miquelon' => 'เวลาแซงปีแยร์และมีเกอลง',
        'America/Moncton' => 'เวลาแอตแลนติก (มองตัน)',
        'America/Monterrey' => 'เวลาตอนกลางในอเมริกาเหนือ (มอนเตร์เรย์)',
        'America/Montevideo' => 'เวลาอุรุกวัย (มอนเตวิเดโอ)',
        'America/Montreal' => 'เวลาแคนาดา (Montreal)',
        'America/Montserrat' => 'เวลาแอตแลนติก (มอนเซอร์รัต)',
        'America/Nassau' => 'เวลาทางตะวันออกในอเมริกาเหนือ (แนสซอ)',
        'America/New_York' => 'เวลาทางตะวันออกในอเมริกาเหนือ (นิวยอร์ก)',
        'America/Nipigon' => 'เวลาทางตะวันออกในอเมริกาเหนือ (นิปิกอน)',
        'America/Nome' => 'เวลาอะแลสกา (นอม)',
        'America/Noronha' => 'เวลาหมู่เกาะเฟอร์นันโด (โนรอนฮา)',
        'America/North_Dakota/Beulah' => 'เวลาตอนกลางในอเมริกาเหนือ (โบลาห์, นอร์ทดาโคตา)',
        'America/North_Dakota/Center' => 'เวลาตอนกลางในอเมริกาเหนือ (เซนเตอร์, นอร์ทดาโคตา)',
        'America/North_Dakota/New_Salem' => 'เวลาตอนกลางในอเมริกาเหนือ (นิวเซเลม, นอร์ทดาโคตา)',
        'America/Ojinaga' => 'เวลาแถบภูเขาในอเมริกาเหนือ (โอจินากา)',
        'America/Panama' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ปานามา)',
        'America/Pangnirtung' => 'เวลาทางตะวันออกในอเมริกาเหนือ (พางนีทัง)',
        'America/Paramaribo' => 'เวลาซูรินาเม (ปารามาริโบ)',
        'America/Phoenix' => 'เวลาแถบภูเขาในอเมริกาเหนือ (ฟินิกซ์)',
        'America/Port-au-Prince' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ปอร์โตแปรงซ์)',
        'America/Port_of_Spain' => 'เวลาแอตแลนติก (พอร์ทออฟสเปน)',
        'America/Porto_Velho' => 'เวลาแอมะซอน (ปอร์ตูเวลโย)',
        'America/Puerto_Rico' => 'เวลาแอตแลนติก (เปอโตริโก)',
        'America/Punta_Arenas' => 'เวลาชิลี (ปุนตาอาเรนัส)',
        'America/Rainy_River' => 'เวลาตอนกลางในอเมริกาเหนือ (เรนนี่ริเวอร์)',
        'America/Rankin_Inlet' => 'เวลาตอนกลางในอเมริกาเหนือ (แรงกินอินเล็ต)',
        'America/Recife' => 'เวลาบราซิเลีย (เรซีเฟ)',
        'America/Regina' => 'เวลาตอนกลางในอเมริกาเหนือ (ริไจนา)',
        'America/Resolute' => 'เวลาตอนกลางในอเมริกาเหนือ (เรโซลูท)',
        'America/Rio_Branco' => 'เวลาอาเกร (รีโอบรังโก)',
        'America/Santa_Isabel' => 'เวลาเม็กซิโกตะวันตกเฉียงเหนือ (ซานตาอิซาเบล)',
        'America/Santarem' => 'เวลาบราซิเลีย (ซันตาเรม)',
        'America/Santiago' => 'เวลาชิลี (ซันติอาโก)',
        'America/Santo_Domingo' => 'เวลาแอตแลนติก (ซานโต โดมิงโก)',
        'America/Sao_Paulo' => 'เวลาบราซิเลีย (เซาเปาลู)',
        'America/Scoresbysund' => 'เวลากรีนแลนด์ตะวันออก (สกอเรสไบซันด์)',
        'America/Sitka' => 'เวลาอะแลสกา (ซิตกา)',
        'America/St_Barthelemy' => 'เวลาแอตแลนติก (เซนต์บาร์เธเลมี)',
        'America/St_Johns' => 'เวลานิวฟันด์แลนด์ (เซนต์จอนส์)',
        'America/St_Kitts' => 'เวลาแอตแลนติก (เซนต์คิตส์)',
        'America/St_Lucia' => 'เวลาแอตแลนติก (เซนต์ลูเซีย)',
        'America/St_Thomas' => 'เวลาแอตแลนติก (เซนต์โธมัส)',
        'America/St_Vincent' => 'เวลาแอตแลนติก (เซนต์วินเซนต์)',
        'America/Swift_Current' => 'เวลาตอนกลางในอเมริกาเหนือ (สวิฟต์เคอร์เรนต์)',
        'America/Tegucigalpa' => 'เวลาตอนกลางในอเมริกาเหนือ (เตกูซิกัลปา)',
        'America/Thule' => 'เวลาแอตแลนติก (ทูเล)',
        'America/Thunder_Bay' => 'เวลาทางตะวันออกในอเมริกาเหนือ (ทันเดอร์เบย์)',
        'America/Tijuana' => 'เวลาแปซิฟิกในอเมริกาเหนือ (ทิฮัวนา)',
        'America/Toronto' => 'เวลาทางตะวันออกในอเมริกาเหนือ (โทรอนโต)',
        'America/Tortola' => 'เวลาแอตแลนติก (ตอร์โตลา)',
        'America/Vancouver' => 'เวลาแปซิฟิกในอเมริกาเหนือ (แวนคูเวอร์)',
        'America/Whitehorse' => 'เวลายูคอน (ไวต์ฮอร์ส)',
        'America/Winnipeg' => 'เวลาตอนกลางในอเมริกาเหนือ (วินนิเพก)',
        'America/Yakutat' => 'เวลาอะแลสกา (ยากูทัต)',
        'America/Yellowknife' => 'เวลาแถบภูเขาในอเมริกาเหนือ (เยลโลว์ไนฟ์)',
        'Antarctica/Casey' => 'เวลาเคซีย์',
        'Antarctica/Davis' => 'เวลาเดวิส',
        'Antarctica/DumontDUrville' => 'เวลาดูมองต์ดูร์วิลล์',
        'Antarctica/Macquarie' => 'เวลาออสเตรเลียตะวันออก (แมคควอรี)',
        'Antarctica/Mawson' => 'เวลามอว์สัน',
        'Antarctica/McMurdo' => 'เวลานิวซีแลนด์ (แมคมัวโด)',
        'Antarctica/Palmer' => 'เวลาชิลี (พาล์เมอร์)',
        'Antarctica/Rothera' => 'เวลาโรธีรา',
        'Antarctica/Syowa' => 'เวลาไซโยวา',
        'Antarctica/Troll' => 'เวลามาตรฐานกรีนิช (โทรล)',
        'Antarctica/Vostok' => 'เวลาวอสตอค',
        'Arctic/Longyearbyen' => 'เวลายุโรปกลาง (ลองเยียร์เบียน)',
        'Asia/Aden' => 'เวลาอาหรับ (เอเดน)',
        'Asia/Almaty' => 'เวลาคาซัคสถานตะวันออก (อัลมาตี)',
        'Asia/Amman' => 'เวลายุโรปตะวันออก (อัมมาน)',
        'Asia/Anadyr' => 'เวลาอะนาดีร์ (อานาดีร์)',
        'Asia/Aqtau' => 'เวลาคาซัคสถานตะวันตก (อัคตาอู)',
        'Asia/Aqtobe' => 'เวลาคาซัคสถานตะวันตก (อัคโทบี)',
        'Asia/Ashgabat' => 'เวลาเติร์กเมนิสถาน (อาชกาบัต)',
        'Asia/Atyrau' => 'เวลาคาซัคสถานตะวันตก (อทีราว)',
        'Asia/Baghdad' => 'เวลาอาหรับ (แบกแดด)',
        'Asia/Bahrain' => 'เวลาอาหรับ (บาห์เรน)',
        'Asia/Baku' => 'เวลาอาเซอร์ไบจาน (บากู)',
        'Asia/Bangkok' => 'เวลาอินโดจีน (กรุงเทพ)',
        'Asia/Barnaul' => 'เวลารัสเซีย (บาร์เนาว์)',
        'Asia/Beirut' => 'เวลายุโรปตะวันออก (เบรุต)',
        'Asia/Bishkek' => 'เวลาคีร์กีซสถาน (บิชเคก)',
        'Asia/Brunei' => 'เวลาบรูไนดารุสซาลาม',
        'Asia/Calcutta' => 'เวลาอินเดีย (โกลกาตา)',
        'Asia/Chita' => 'เวลายาคุตสค์ (ชิตา)',
        'Asia/Choibalsan' => 'เวลาอูลานบาตอร์ (ชอยบาลซาน)',
        'Asia/Colombo' => 'เวลาอินเดีย (โคลัมโบ)',
        'Asia/Damascus' => 'เวลายุโรปตะวันออก (ดามัสกัส)',
        'Asia/Dhaka' => 'เวลาบังกลาเทศ (ดากา)',
        'Asia/Dili' => 'เวลาติมอร์ตะวันออก (ดิลี)',
        'Asia/Dubai' => 'เวลากัลฟ์ (ดูไบ)',
        'Asia/Dushanbe' => 'เวลาทาจิกิสถาน (ดูชานเบ)',
        'Asia/Famagusta' => 'เวลายุโรปตะวันออก (แฟมากุสตา)',
        'Asia/Gaza' => 'เวลายุโรปตะวันออก (กาซา)',
        'Asia/Hebron' => 'เวลายุโรปตะวันออก (เฮบรอน)',
        'Asia/Hong_Kong' => 'เวลาฮ่องกง',
        'Asia/Hovd' => 'เวลาฮอฟด์',
        'Asia/Irkutsk' => 'เวลาอีร์คุตสค์',
        'Asia/Jakarta' => 'เวลาอินโดนีเซียฝั่งตะวันตก (จาการ์ตา)',
        'Asia/Jayapura' => 'เวลาอินโดนีเซียฝั่งตะวันออก (จายาปุระ)',
        'Asia/Jerusalem' => 'เวลาอิสราเอล (เยรูซาเลม)',
        'Asia/Kabul' => 'เวลาอัฟกานิสถาน (คาบูล)',
        'Asia/Kamchatka' => 'เวลาคัมชัตคา (คามชัตกา)',
        'Asia/Karachi' => 'เวลาปากีสถาน (การาจี)',
        'Asia/Katmandu' => 'เวลาเนปาล (กาตมันดุ)',
        'Asia/Khandyga' => 'เวลายาคุตสค์ (ฮันดืยกา)',
        'Asia/Krasnoyarsk' => 'เวลาครัสโนยาสค์ (ครัสโนยาร์สก์)',
        'Asia/Kuala_Lumpur' => 'เวลามาเลเซีย (กัวลาลัมเปอร์)',
        'Asia/Kuching' => 'เวลามาเลเซีย (กูชิง)',
        'Asia/Kuwait' => 'เวลาอาหรับ (คูเวต)',
        'Asia/Macau' => 'เวลาจีน (มาเก๊า)',
        'Asia/Magadan' => 'เวลามากาดาน',
        'Asia/Makassar' => 'เวลาอินโดนีเซียตอนกลาง (มากัสซาร์)',
        'Asia/Manila' => 'เวลาฟิลิปปินส์ (มะนิลา)',
        'Asia/Muscat' => 'เวลากัลฟ์ (มัสกัต)',
        'Asia/Nicosia' => 'เวลายุโรปตะวันออก (นิโคเซีย)',
        'Asia/Novokuznetsk' => 'เวลาครัสโนยาสค์ (โนโวคุซเนตสค์)',
        'Asia/Novosibirsk' => 'เวลาโนโวซีบีสค์ (โนโวซิบิร์สก์)',
        'Asia/Omsk' => 'เวลาออมสค์ (โอมสก์)',
        'Asia/Oral' => 'เวลาคาซัคสถานตะวันตก (ออรัล)',
        'Asia/Phnom_Penh' => 'เวลาอินโดจีน (พนมเปญ)',
        'Asia/Pontianak' => 'เวลาอินโดนีเซียฝั่งตะวันตก (พอนเทียนัก)',
        'Asia/Pyongyang' => 'เวลาเกาหลี (เปียงยาง)',
        'Asia/Qatar' => 'เวลาอาหรับ (กาตาร์)',
        'Asia/Qostanay' => 'เวลาคาซัคสถานตะวันออก (คอสตาเนย์)',
        'Asia/Qyzylorda' => 'เวลาคาซัคสถานตะวันตก (ไคซีลอร์ดา)',
        'Asia/Rangoon' => 'เวลาพม่า (ย่างกุ้ง)',
        'Asia/Riyadh' => 'เวลาอาหรับ (ริยาร์ด)',
        'Asia/Saigon' => 'เวลาอินโดจีน (นครโฮจิมินห์)',
        'Asia/Sakhalin' => 'เวลาซาคาลิน',
        'Asia/Samarkand' => 'เวลาอุซเบกิสถาน (ซามาร์กานด์)',
        'Asia/Seoul' => 'เวลาเกาหลี (โซล)',
        'Asia/Shanghai' => 'เวลาจีน (เซี่ยงไฮ้)',
        'Asia/Singapore' => 'เวลาสิงคโปร์',
        'Asia/Srednekolymsk' => 'เวลามากาดาน (ซเรดเนคโคลิมสก์)',
        'Asia/Taipei' => 'เวลาไทเป',
        'Asia/Tashkent' => 'เวลาอุซเบกิสถาน (ทาชเคนต์)',
        'Asia/Tbilisi' => 'เวลาจอร์เจีย (ทบิลิซิ)',
        'Asia/Tehran' => 'เวลาอิหร่าน (เตหะราน)',
        'Asia/Thimphu' => 'เวลาภูฏาน (ทิมพู)',
        'Asia/Tokyo' => 'เวลาญี่ปุ่น (โตเกียว)',
        'Asia/Tomsk' => 'เวลารัสเซีย (ตอมสค์)',
        'Asia/Ulaanbaatar' => 'เวลาอูลานบาตอร์',
        'Asia/Urumqi' => 'เวลาจีน (อุรุมชี)',
        'Asia/Ust-Nera' => 'เวลาวลาดีวอสตอค (อุสต์เนรา)',
        'Asia/Vientiane' => 'เวลาอินโดจีน (เวียงจันทน์)',
        'Asia/Vladivostok' => 'เวลาวลาดีวอสตอค (วลาดิโวสต็อก)',
        'Asia/Yakutsk' => 'เวลายาคุตสค์',
        'Asia/Yekaterinburg' => 'เวลาเยคาเตรินบูร์ก (ยีคาเตอรินเบิร์ก)',
        'Asia/Yerevan' => 'เวลาอาร์เมเนีย (เยเรวาน)',
        'Atlantic/Azores' => 'เวลาอะโซร์ส',
        'Atlantic/Bermuda' => 'เวลาแอตแลนติก (เบอร์มิวดา)',
        'Atlantic/Canary' => 'เวลายุโรปตะวันตก (คะเนรี)',
        'Atlantic/Cape_Verde' => 'เวลาเคปเวิร์ด',
        'Atlantic/Faeroe' => 'เวลายุโรปตะวันตก (แฟโร)',
        'Atlantic/Madeira' => 'เวลายุโรปตะวันตก (มาเดรา)',
        'Atlantic/Reykjavik' => 'เวลามาตรฐานกรีนิช (เรคยาวิก)',
        'Atlantic/South_Georgia' => 'เวลาเซาท์จอร์เจีย (เซาท์ จอร์เจีย)',
        'Atlantic/St_Helena' => 'เวลามาตรฐานกรีนิช (เซนต์เฮเลนา)',
        'Atlantic/Stanley' => 'เวลาหมู่เกาะฟอล์กแลนด์ (สแตนลีย์)',
        'Australia/Adelaide' => 'เวลาออสเตรเลียกลาง (แอดิเลด)',
        'Australia/Brisbane' => 'เวลาออสเตรเลียตะวันออก (บริสเบน)',
        'Australia/Broken_Hill' => 'เวลาออสเตรเลียกลาง (โบรกเคนฮิลล์)',
        'Australia/Currie' => 'เวลาออสเตรเลียตะวันออก (คูร์รี)',
        'Australia/Darwin' => 'เวลาออสเตรเลียกลาง (ดาร์วิน)',
        'Australia/Eucla' => 'เวลาทางตะวันตกตอนกลางของออสเตรเลีย (ยูคลา)',
        'Australia/Hobart' => 'เวลาออสเตรเลียตะวันออก (โฮบาร์ต)',
        'Australia/Lindeman' => 'เวลาออสเตรเลียตะวันออก (ลินดีแมน)',
        'Australia/Lord_Howe' => 'เวลาลอร์ดโฮว์',
        'Australia/Melbourne' => 'เวลาออสเตรเลียตะวันออก (เมลเบิร์น)',
        'Australia/Perth' => 'เวลาออสเตรเลียตะวันตก (เพิร์ท)',
        'Australia/Sydney' => 'เวลาออสเตรเลียตะวันออก (ซิดนีย์)',
        'CST6CDT' => 'เวลาตอนกลางในอเมริกาเหนือ',
        'EST5EDT' => 'เวลาทางตะวันออกในอเมริกาเหนือ',
        'Etc/GMT' => 'เวลามาตรฐานกรีนิช',
        'Etc/UTC' => 'เวลาสากลเชิงพิกัด',
        'Europe/Amsterdam' => 'เวลายุโรปกลาง (อัมสเตอดัม)',
        'Europe/Andorra' => 'เวลายุโรปกลาง (อันดอร์รา)',
        'Europe/Astrakhan' => 'เวลามอสโก (แอสตราคาน)',
        'Europe/Athens' => 'เวลายุโรปตะวันออก (เอเธนส์)',
        'Europe/Belgrade' => 'เวลายุโรปกลาง (เบลเกรด)',
        'Europe/Berlin' => 'เวลายุโรปกลาง (เบอร์ลิน)',
        'Europe/Bratislava' => 'เวลายุโรปกลาง (บราติสลาวา)',
        'Europe/Brussels' => 'เวลายุโรปกลาง (บรัสเซลส์)',
        'Europe/Bucharest' => 'เวลายุโรปตะวันออก (บูคาเรส)',
        'Europe/Budapest' => 'เวลายุโรปกลาง (บูดาเปส)',
        'Europe/Busingen' => 'เวลายุโรปกลาง (บุสซิงเง็น)',
        'Europe/Chisinau' => 'เวลายุโรปตะวันออก (คีชีเนา)',
        'Europe/Copenhagen' => 'เวลายุโรปกลาง (โคเปนเฮเกน)',
        'Europe/Dublin' => 'เวลามาตรฐานกรีนิช (ดับบลิน)',
        'Europe/Gibraltar' => 'เวลายุโรปกลาง (ยิบรอลตาร์)',
        'Europe/Guernsey' => 'เวลามาตรฐานกรีนิช (เกิร์นซีย์)',
        'Europe/Helsinki' => 'เวลายุโรปตะวันออก (เฮลซิงกิ)',
        'Europe/Isle_of_Man' => 'เวลามาตรฐานกรีนิช (เกาะแมน)',
        'Europe/Istanbul' => 'เวลาตุรกี (อิสตันบูล)',
        'Europe/Jersey' => 'เวลามาตรฐานกรีนิช (เจอร์ซีย์)',
        'Europe/Kaliningrad' => 'เวลายุโรปตะวันออก (คาลินิงกราด)',
        'Europe/Kiev' => 'เวลายุโรปตะวันออก (เคียฟ)',
        'Europe/Kirov' => 'เวลารัสเซีย (คิรอฟ)',
        'Europe/Lisbon' => 'เวลายุโรปตะวันตก (ลิสบอน)',
        'Europe/Ljubljana' => 'เวลายุโรปกลาง (ลูบลิยานา)',
        'Europe/London' => 'เวลามาตรฐานกรีนิช (ลอนดอน)',
        'Europe/Luxembourg' => 'เวลายุโรปกลาง (ลักเซมเบิร์ก)',
        'Europe/Madrid' => 'เวลายุโรปกลาง (มาดริด)',
        'Europe/Malta' => 'เวลายุโรปกลาง (มอลตา)',
        'Europe/Mariehamn' => 'เวลายุโรปตะวันออก (มารีฮามน์)',
        'Europe/Minsk' => 'เวลามอสโก (มินสก์)',
        'Europe/Monaco' => 'เวลายุโรปกลาง (โมนาโก)',
        'Europe/Moscow' => 'เวลามอสโก',
        'Europe/Oslo' => 'เวลายุโรปกลาง (ออสโล)',
        'Europe/Paris' => 'เวลายุโรปกลาง (ปารีส)',
        'Europe/Podgorica' => 'เวลายุโรปกลาง (พอดกอรีตซา)',
        'Europe/Prague' => 'เวลายุโรปกลาง (ปราก)',
        'Europe/Riga' => 'เวลายุโรปตะวันออก (ริกา)',
        'Europe/Rome' => 'เวลายุโรปกลาง (โรม)',
        'Europe/Samara' => 'เวลาซามารา',
        'Europe/San_Marino' => 'เวลายุโรปกลาง (ซานมารีโน)',
        'Europe/Sarajevo' => 'เวลายุโรปกลาง (ซาราเยโว)',
        'Europe/Saratov' => 'เวลามอสโก (ซาราทอฟ)',
        'Europe/Simferopol' => 'เวลามอสโก (ซิมเฟอโรโปล)',
        'Europe/Skopje' => 'เวลายุโรปกลาง (สโกเปีย)',
        'Europe/Sofia' => 'เวลายุโรปตะวันออก (โซเฟีย)',
        'Europe/Stockholm' => 'เวลายุโรปกลาง (สตอกโฮล์ม)',
        'Europe/Tallinn' => 'เวลายุโรปตะวันออก (ทาลลินน์)',
        'Europe/Tirane' => 'เวลายุโรปกลาง (ติรานา)',
        'Europe/Ulyanovsk' => 'เวลามอสโก (อะลิยานอฟ)',
        'Europe/Uzhgorod' => 'เวลายุโรปตะวันออก (อัซโกร็อด)',
        'Europe/Vaduz' => 'เวลายุโรปกลาง (วาดุซ)',
        'Europe/Vatican' => 'เวลายุโรปกลาง (วาติกัน)',
        'Europe/Vienna' => 'เวลายุโรปกลาง (เวียนนา)',
        'Europe/Vilnius' => 'เวลายุโรปตะวันออก (วิลนีอุส)',
        'Europe/Volgograd' => 'เวลาวอลโกกราด',
        'Europe/Warsaw' => 'เวลายุโรปกลาง (วอร์ซอ)',
        'Europe/Zagreb' => 'เวลายุโรปกลาง (ซาเกร็บ)',
        'Europe/Zaporozhye' => 'เวลายุโรปตะวันออก (ซาโปโรซี)',
        'Europe/Zurich' => 'เวลายุโรปกลาง (ซูริค)',
        'Indian/Antananarivo' => 'เวลาแอฟริกาตะวันออก (อันตานานาริโว)',
        'Indian/Chagos' => 'เวลามหาสมุทรอินเดีย (ชากัส)',
        'Indian/Christmas' => 'เวลาเกาะคริสต์มาส',
        'Indian/Cocos' => 'เวลาหมู่เกาะโคโคส',
        'Indian/Comoro' => 'เวลาแอฟริกาตะวันออก (โคโมโร)',
        'Indian/Kerguelen' => 'เวลาเฟรนช์เซาเทิร์นและแอนตาร์กติก (แกร์เกอลอง)',
        'Indian/Mahe' => 'เวลาเซเชลส์ (มาเอ)',
        'Indian/Maldives' => 'เวลามัลดีฟส์',
        'Indian/Mauritius' => 'เวลามอริเชียส',
        'Indian/Mayotte' => 'เวลาแอฟริกาตะวันออก (มาโยเต)',
        'Indian/Reunion' => 'เวลาเรอูนียง',
        'MST7MDT' => 'เวลาแถบภูเขาในอเมริกาเหนือ',
        'PST8PDT' => 'เวลาแปซิฟิกในอเมริกาเหนือ',
        'Pacific/Apia' => 'เวลาอาปีอา',
        'Pacific/Auckland' => 'เวลานิวซีแลนด์ (โอคแลนด์)',
        'Pacific/Bougainville' => 'เวลาปาปัวนิวกินี (บูเกนวิลล์)',
        'Pacific/Chatham' => 'เวลาแชทัม',
        'Pacific/Easter' => 'เวลาเกาะอีสเตอร์',
        'Pacific/Efate' => 'เวลาวานูอาตู (เอฟาเต)',
        'Pacific/Enderbury' => 'เวลาหมู่เกาะฟินิกซ์ (เอนเดอร์เบอรี)',
        'Pacific/Fakaofo' => 'เวลาโตเกเลา (ฟาเคาโฟ)',
        'Pacific/Fiji' => 'เวลาฟิจิ',
        'Pacific/Funafuti' => 'เวลาตูวาลู (ฟูนะฟูตี)',
        'Pacific/Galapagos' => 'เวลากาลาปาโกส',
        'Pacific/Gambier' => 'เวลาแกมเบียร์',
        'Pacific/Guadalcanal' => 'เวลาหมู่เกาะโซโลมอน (กัวดัลคานัล)',
        'Pacific/Guam' => 'เวลาชามอร์โร (กวม)',
        'Pacific/Honolulu' => 'เวลาฮาวาย-อะลูเชียน (โฮโนลูลู)',
        'Pacific/Johnston' => 'เวลาฮาวาย-อะลูเชียน (จอห์นสตัน)',
        'Pacific/Kiritimati' => 'เวลาหมู่เกาะไลน์ (คิริทิมาตี)',
        'Pacific/Kosrae' => 'เวลาคอสไร',
        'Pacific/Kwajalein' => 'เวลาหมู่เกาะมาร์แชลล์ (ควาจาเลน)',
        'Pacific/Majuro' => 'เวลาหมู่เกาะมาร์แชลล์ (มาจูโร)',
        'Pacific/Marquesas' => 'เวลามาร์เคซัส',
        'Pacific/Midway' => 'เวลาซามัว (มิดเวย์)',
        'Pacific/Nauru' => 'เวลานาอูรู',
        'Pacific/Niue' => 'เวลานีอูเอ',
        'Pacific/Norfolk' => 'เวลาเกาะนอร์ฟอล์ก',
        'Pacific/Noumea' => 'เวลานิวแคลิโดเนีย (นูเมอา)',
        'Pacific/Pago_Pago' => 'เวลาซามัว (ปาโก ปาโก)',
        'Pacific/Palau' => 'เวลาปาเลา',
        'Pacific/Pitcairn' => 'เวลาพิตแคร์น',
        'Pacific/Ponape' => 'เวลาโปนาเป',
        'Pacific/Port_Moresby' => 'เวลาปาปัวนิวกินี (พอร์ตมอร์สบี)',
        'Pacific/Rarotonga' => 'เวลาหมู่เกาะคุก (ราโรตองกา)',
        'Pacific/Saipan' => 'เวลาชามอร์โร (ไซปัน)',
        'Pacific/Tahiti' => 'เวลาตาฮีตี',
        'Pacific/Tarawa' => 'เวลาหมู่เกาะกิลเบิร์ต (ตาระวา)',
        'Pacific/Tongatapu' => 'เวลาตองกา (ตองกาตาปู)',
        'Pacific/Truk' => 'เวลาชุก (ทรัก)',
        'Pacific/Wake' => 'เวลาเกาะเวก',
        'Pacific/Wallis' => 'เวลาวาลลิสและฟุตูนา',
    ],
    'Meta' => [
    ],
];
