<?php

declare(strict_types=1);

namespace SAML2\XML\alg;

/**
 * Common definitions for the algsupport metadata extension.
 *
 * @link http://docs.oasis-open.org/security/saml/Post2.0/sstc-saml-metadata-algsupport.pdf
 * @author Jaime Pérez Crespo, UNINETT AS <jaime.perez@uninett.no>
 * @package simplesamlphp/saml2
 */
class Common
{
    const NS = 'urn:oasis:names:tc:SAML:metadata:algsupport';
}
