<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Meán-Am Greenwich (Abidjan)',
        'Africa/Accra' => 'Meán-Am Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Am Oirthear na hAfraice (Addis Ababa)',
        'Africa/Algiers' => 'Am Lár na hEorpa (Cathair na hAilgéire)',
        'Africa/Asmera' => 'Am Oirthear na hAfraice (Asmara)',
        'Africa/Bamako' => 'Meán-Am Greenwich (Bamako)',
        'Africa/Bangui' => 'Am Iarthar na hAfraice (Bangui)',
        'Africa/Banjul' => 'Meán-Am Greenwich (Banjul)',
        'Africa/Bissau' => 'Meán-Am Greenwich (Bissau)',
        'Africa/Blantyre' => 'Am na hAfraice Láir (Blantyre)',
        'Africa/Brazzaville' => 'Am Iarthar na hAfraice (Brazzaville)',
        'Africa/Bujumbura' => 'Am na hAfraice Láir (Bujumbura)',
        'Africa/Cairo' => 'Am Oirthear na hEorpa (Caireo)',
        'Africa/Casablanca' => 'Am Iarthar na hEorpa (Casablanca)',
        'Africa/Ceuta' => 'Am Lár na hEorpa (Ceuta)',
        'Africa/Conakry' => 'Meán-Am Greenwich (Conacraí)',
        'Africa/Dakar' => 'Meán-Am Greenwich (Dacár)',
        'Africa/Dar_es_Salaam' => 'Am Oirthear na hAfraice (Dárasalám)',
        'Africa/Djibouti' => 'Am Oirthear na hAfraice (Djibouti)',
        'Africa/Douala' => 'Am Iarthar na hAfraice (Douala)',
        'Africa/El_Aaiun' => 'Am Iarthar na hEorpa (Láúine)',
        'Africa/Freetown' => 'Meán-Am Greenwich (Freetown)',
        'Africa/Gaborone' => 'Am na hAfraice Láir (Gaborone)',
        'Africa/Harare' => 'Am na hAfraice Láir (Harare)',
        'Africa/Johannesburg' => 'Am na hAfraice Theas (Johannesburg)',
        'Africa/Juba' => 'Am na hAfraice Láir (Juba)',
        'Africa/Kampala' => 'Am Oirthear na hAfraice (Kampala)',
        'Africa/Khartoum' => 'Am na hAfraice Láir (Cartúm)',
        'Africa/Kigali' => 'Am na hAfraice Láir (Kigali)',
        'Africa/Kinshasa' => 'Am Iarthar na hAfraice (Kinshasa)',
        'Africa/Lagos' => 'Am Iarthar na hAfraice (Lagos)',
        'Africa/Libreville' => 'Am Iarthar na hAfraice (Libreville)',
        'Africa/Lome' => 'Meán-Am Greenwich (Lomé)',
        'Africa/Luanda' => 'Am Iarthar na hAfraice (Luanda)',
        'Africa/Lubumbashi' => 'Am na hAfraice Láir (Lubumbashi)',
        'Africa/Lusaka' => 'Am na hAfraice Láir (Lusaka)',
        'Africa/Malabo' => 'Am Iarthar na hAfraice (Malabo)',
        'Africa/Maputo' => 'Am na hAfraice Láir (Mapútó)',
        'Africa/Maseru' => 'Am na hAfraice Theas (Maseru)',
        'Africa/Mbabane' => 'Am na hAfraice Theas (Mbabane)',
        'Africa/Mogadishu' => 'Am Oirthear na hAfraice (Mogaidisiú)',
        'Africa/Monrovia' => 'Meán-Am Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Am Oirthear na hAfraice (Nairobi)',
        'Africa/Ndjamena' => 'Am Iarthar na hAfraice (Ndjamena)',
        'Africa/Niamey' => 'Am Iarthar na hAfraice (Niamey)',
        'Africa/Nouakchott' => 'Meán-Am Greenwich (Nuacsat)',
        'Africa/Ouagadougou' => 'Meán-Am Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Am Iarthar na hAfraice (Porto-Novo)',
        'Africa/Sao_Tome' => 'Meán-Am Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Am Oirthear na hEorpa (Tripilí)',
        'Africa/Tunis' => 'Am Lár na hEorpa (Túinis)',
        'Africa/Windhoek' => 'Am na hAfraice Láir (Windhoek)',
        'America/Adak' => 'Am Haváí-Ailiúit (Adak)',
        'America/Anchorage' => 'Am Alasca (Anchorage)',
        'America/Anguilla' => 'Am an Atlantaigh (Angaíle)',
        'America/Antigua' => 'Am an Atlantaigh (Antigua)',
        'America/Araguaina' => 'Am Bhrasília (Araguaina)',
        'America/Argentina/La_Rioja' => 'Am na hAirgintíne (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Am na hAirgintíne (Rio Gallegos)',
        'America/Argentina/Salta' => 'Am na hAirgintíne (Salta)',
        'America/Argentina/San_Juan' => 'Am na hAirgintíne (San Juan)',
        'America/Argentina/San_Luis' => 'Am na hAirgintíne (San Luis)',
        'America/Argentina/Tucuman' => 'Am na hAirgintíne (Tucuman)',
        'America/Argentina/Ushuaia' => 'Am na hAirgintíne (Ushuaia)',
        'America/Aruba' => 'Am an Atlantaigh (Arúba)',
        'America/Asuncion' => 'Am Pharagua (Asunción)',
        'America/Bahia' => 'Am Bhrasília (Bahia)',
        'America/Bahia_Banderas' => 'Am Lárnach Mheiriceá Thuaidh (Bahia Banderas)',
        'America/Barbados' => 'Am an Atlantaigh (Barbadós)',
        'America/Belem' => 'Am Bhrasília (Belém)',
        'America/Belize' => 'Am Lárnach Mheiriceá Thuaidh (an Bheilís)',
        'America/Blanc-Sablon' => 'Am an Atlantaigh (Blanc-Sablon)',
        'America/Boa_Vista' => 'Am na hAmasóine (Boa Vista)',
        'America/Bogota' => 'Am na Colóime (Bogatá)',
        'America/Boise' => 'Am Sléibhte Mheiriceá Thuaidh (Boise)',
        'America/Buenos_Aires' => 'Am na hAirgintíne (Buenos Aires)',
        'America/Cambridge_Bay' => 'Am Sléibhte Mheiriceá Thuaidh (Cambridge Bay)',
        'America/Campo_Grande' => 'Am na hAmasóine (Campo Grande)',
        'America/Cancun' => 'Am Oirthearach Mheiriceá Thuaidh (Cancún)',
        'America/Caracas' => 'Am Veiniséala (Caracas)',
        'America/Catamarca' => 'Am na hAirgintíne (Catamarca)',
        'America/Cayenne' => 'Am Ghuáin na Fraince (Cayenne)',
        'America/Cayman' => 'Am Oirthearach Mheiriceá Thuaidh (Cayman)',
        'America/Chicago' => 'Am Lárnach Mheiriceá Thuaidh (Chicago)',
        'America/Chihuahua' => 'Am Meicsiceach an Aigéin Chiúin (Chihuahua)',
        'America/Coral_Harbour' => 'Am Oirthearach Mheiriceá Thuaidh (Atikokan)',
        'America/Cordoba' => 'Am na hAirgintíne (Córdoba)',
        'America/Costa_Rica' => 'Am Lárnach Mheiriceá Thuaidh (Cósta Ríce)',
        'America/Creston' => 'Am Sléibhte Mheiriceá Thuaidh (Creston)',
        'America/Cuiaba' => 'Am na hAmasóine (Cuiaba)',
        'America/Curacao' => 'Am an Atlantaigh (Cúrasó)',
        'America/Danmarkshavn' => 'Meán-Am Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Am Yukon (Dawson)',
        'America/Dawson_Creek' => 'Am Sléibhte Mheiriceá Thuaidh (Dawson Creek)',
        'America/Denver' => 'Am Sléibhte Mheiriceá Thuaidh (Denver)',
        'America/Detroit' => 'Am Oirthearach Mheiriceá Thuaidh (Detroit)',
        'America/Dominica' => 'Am an Atlantaigh (Doiminice)',
        'America/Edmonton' => 'Am Sléibhte Mheiriceá Thuaidh (Edmonton)',
        'America/Eirunepe' => 'Am Acre (Eirunepe)',
        'America/El_Salvador' => 'Am Lárnach Mheiriceá Thuaidh (an tSalvadóir)',
        'America/Fort_Nelson' => 'Am Sléibhte Mheiriceá Thuaidh (Fort Nelson)',
        'America/Fortaleza' => 'Am Bhrasília (Fortaleza)',
        'America/Glace_Bay' => 'Am an Atlantaigh (Glace Bay)',
        'America/Godthab' => 'Am Iarthar na Graonlainne (Nuuk)',
        'America/Goose_Bay' => 'Am an Atlantaigh (Goose Bay)',
        'America/Grand_Turk' => 'Am Oirthearach Mheiriceá Thuaidh (Grand Turk)',
        'America/Grenada' => 'Am an Atlantaigh (Greanáda)',
        'America/Guadeloupe' => 'Am an Atlantaigh (Guadalúip)',
        'America/Guatemala' => 'Am Lárnach Mheiriceá Thuaidh (Guatamala)',
        'America/Guayaquil' => 'Am Eacuadór (Guayaquil)',
        'America/Guyana' => 'Am na Guáine (an Ghuáin)',
        'America/Halifax' => 'Am an Atlantaigh (Halifax)',
        'America/Havana' => 'Am Chúba (Havana)',
        'America/Hermosillo' => 'Am Meicsiceach an Aigéin Chiúin (Hermosillo)',
        'America/Indiana/Knox' => 'Am Lárnach Mheiriceá Thuaidh (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Am Oirthearach Mheiriceá Thuaidh (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Am Oirthearach Mheiriceá Thuaidh (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Am Lárnach Mheiriceá Thuaidh (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Am Oirthearach Mheiriceá Thuaidh (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Am Oirthearach Mheiriceá Thuaidh (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Am Oirthearach Mheiriceá Thuaidh (Winamac, Indiana)',
        'America/Indianapolis' => 'Am Oirthearach Mheiriceá Thuaidh (Indianapolis)',
        'America/Inuvik' => 'Am Sléibhte Mheiriceá Thuaidh (Inuvik)',
        'America/Iqaluit' => 'Am Oirthearach Mheiriceá Thuaidh (Iqaluit)',
        'America/Jamaica' => 'Am Oirthearach Mheiriceá Thuaidh (Iamáice)',
        'America/Jujuy' => 'Am na hAirgintíne (Jujuy)',
        'America/Juneau' => 'Am Alasca (Juneau)',
        'America/Kentucky/Monticello' => 'Am Oirthearach Mheiriceá Thuaidh (Monticello, Kentucky)',
        'America/Kralendijk' => 'Am an Atlantaigh (Kralendijk)',
        'America/La_Paz' => 'Am na Bolaive (La Paz)',
        'America/Lima' => 'Am Pheiriú (Líoma)',
        'America/Los_Angeles' => 'Am an Aigéin Chiúin (Los Angeles)',
        'America/Louisville' => 'Am Oirthearach Mheiriceá Thuaidh (Louisville)',
        'America/Lower_Princes' => 'Am an Atlantaigh (Lower Prince’s Quarter)',
        'America/Maceio' => 'Am Bhrasília (Maceio)',
        'America/Managua' => 'Am Lárnach Mheiriceá Thuaidh (Managua)',
        'America/Manaus' => 'Am na hAmasóine (Manaus)',
        'America/Marigot' => 'Am an Atlantaigh (Marigot)',
        'America/Martinique' => 'Am an Atlantaigh (Martinique)',
        'America/Matamoros' => 'Am Lárnach Mheiriceá Thuaidh (Matamoros)',
        'America/Mazatlan' => 'Am Meicsiceach an Aigéin Chiúin (Mazatlan)',
        'America/Mendoza' => 'Am na hAirgintíne (Mendoza)',
        'America/Menominee' => 'Am Lárnach Mheiriceá Thuaidh (Menominee)',
        'America/Merida' => 'Am Lárnach Mheiriceá Thuaidh (Merida)',
        'America/Metlakatla' => 'Am Alasca (Metlakatla)',
        'America/Mexico_City' => 'Am Lárnach Mheiriceá Thuaidh (Cathair Mheicsiceo)',
        'America/Miquelon' => 'Am Saint-Pierre-et-Miquelon',
        'America/Moncton' => 'Am an Atlantaigh (Moncton)',
        'America/Monterrey' => 'Am Lárnach Mheiriceá Thuaidh (Monterrey)',
        'America/Montevideo' => 'Am Uragua (Montevideo)',
        'America/Montreal' => 'Ceanada (Montreal)',
        'America/Montserrat' => 'Am an Atlantaigh (Montsarat)',
        'America/Nassau' => 'Am Oirthearach Mheiriceá Thuaidh (Nassau)',
        'America/New_York' => 'Am Oirthearach Mheiriceá Thuaidh (Nua-Eabhrac)',
        'America/Nipigon' => 'Am Oirthearach Mheiriceá Thuaidh (Nipigon)',
        'America/Nome' => 'Am Alasca (Nome)',
        'America/Noronha' => 'Am Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Am Lárnach Mheiriceá Thuaidh (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Am Lárnach Mheiriceá Thuaidh (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Am Lárnach Mheiriceá Thuaidh (New Salem, North Dakota)',
        'America/Ojinaga' => 'Am Sléibhte Mheiriceá Thuaidh (Ojinaga)',
        'America/Panama' => 'Am Oirthearach Mheiriceá Thuaidh (Panama)',
        'America/Pangnirtung' => 'Am Oirthearach Mheiriceá Thuaidh (Pangnirtung)',
        'America/Paramaribo' => 'Am Shuranam (Paramaribo)',
        'America/Phoenix' => 'Am Sléibhte Mheiriceá Thuaidh (Phoenix)',
        'America/Port-au-Prince' => 'Am Oirthearach Mheiriceá Thuaidh (Port-au-Prince)',
        'America/Port_of_Spain' => 'Am an Atlantaigh (Port of Spain)',
        'America/Porto_Velho' => 'Am na hAmasóine (Porto Velho)',
        'America/Puerto_Rico' => 'Am an Atlantaigh (Pórtó Ríce)',
        'America/Punta_Arenas' => 'Am na Sile (Punta Arenas)',
        'America/Rainy_River' => 'Am Lárnach Mheiriceá Thuaidh (Rainy River)',
        'America/Rankin_Inlet' => 'Am Lárnach Mheiriceá Thuaidh (Rankin Inlet)',
        'America/Recife' => 'Am Bhrasília (Recife)',
        'America/Regina' => 'Am Lárnach Mheiriceá Thuaidh (Regina)',
        'America/Resolute' => 'Am Lárnach Mheiriceá Thuaidh (Resolute)',
        'America/Rio_Branco' => 'Am Acre (Rio Branco)',
        'America/Santa_Isabel' => 'Am Iarthuaisceart Mheicsiceo (Santa Isabel)',
        'America/Santarem' => 'Am Bhrasília (Santarem)',
        'America/Santiago' => 'Am na Sile (Santiago)',
        'America/Santo_Domingo' => 'Am an Atlantaigh (Santo Domingo)',
        'America/Sao_Paulo' => 'Am Bhrasília (São Paulo)',
        'America/Scoresbysund' => 'Am Oirthear na Graonlainne (Ittoqqortoormiit)',
        'America/Sitka' => 'Am Alasca (Sitka)',
        'America/St_Barthelemy' => 'Am an Atlantaigh (Saint Barthélemy)',
        'America/St_Johns' => 'Am Thalamh an Éisc (St. John’s)',
        'America/St_Kitts' => 'Am an Atlantaigh (San Críostóir)',
        'America/St_Lucia' => 'Am an Atlantaigh (Saint Lucia)',
        'America/St_Thomas' => 'Am an Atlantaigh (St. Thomas)',
        'America/St_Vincent' => 'Am an Atlantaigh (San Uinseann)',
        'America/Swift_Current' => 'Am Lárnach Mheiriceá Thuaidh (Swift Current)',
        'America/Tegucigalpa' => 'Am Lárnach Mheiriceá Thuaidh (Tegucigalpa)',
        'America/Thule' => 'Am an Atlantaigh (Inis Tuile)',
        'America/Thunder_Bay' => 'Am Oirthearach Mheiriceá Thuaidh (Thunder Bay)',
        'America/Tijuana' => 'Am an Aigéin Chiúin (Tijuana)',
        'America/Toronto' => 'Am Oirthearach Mheiriceá Thuaidh (Toronto)',
        'America/Tortola' => 'Am an Atlantaigh (Tortola)',
        'America/Vancouver' => 'Am an Aigéin Chiúin (Vancouver)',
        'America/Whitehorse' => 'Am Yukon (Whitehorse)',
        'America/Winnipeg' => 'Am Lárnach Mheiriceá Thuaidh (Winnipeg)',
        'America/Yakutat' => 'Am Alasca (Yakutat)',
        'America/Yellowknife' => 'Am Sléibhte Mheiriceá Thuaidh (Yellowknife)',
        'Antarctica/Casey' => 'Am Stáisiún Casey',
        'Antarctica/Davis' => 'Am Davis',
        'Antarctica/DumontDUrville' => 'Am Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Am Oirthear na hAstráile (Mac Guaire)',
        'Antarctica/Mawson' => 'Am Mawson',
        'Antarctica/McMurdo' => 'Am na Nua-Shéalainne (McMurdo)',
        'Antarctica/Palmer' => 'Am na Sile (Palmer)',
        'Antarctica/Rothera' => 'Am Rothera',
        'Antarctica/Syowa' => 'Am Syowa',
        'Antarctica/Troll' => 'Meán-Am Greenwich (Troll)',
        'Antarctica/Vostok' => 'Am Vostok',
        'Arctic/Longyearbyen' => 'Am Lár na hEorpa (Longyearbyen)',
        'Asia/Aden' => 'Am na hAraibe (Áidin)',
        'Asia/Almaty' => 'Am Oirthear na Casacstáine (Almaty)',
        'Asia/Amman' => 'Am Oirthear na hEorpa (Amman)',
        'Asia/Anadyr' => 'Am Anadyr',
        'Asia/Aqtau' => 'Am Iarthar na Casacstáine (Aqtau)',
        'Asia/Aqtobe' => 'Am Iarthar na Casacstáine (Aqtobe)',
        'Asia/Ashgabat' => 'Am na Tuircméanastáine (Ashgabat)',
        'Asia/Atyrau' => 'Am Iarthar na Casacstáine (Atyrau)',
        'Asia/Baghdad' => 'Am na hAraibe (Bagdad)',
        'Asia/Bahrain' => 'Am na hAraibe (Bairéin)',
        'Asia/Baku' => 'Am na hAsarbaiseáine (Baki)',
        'Asia/Bangkok' => 'Am na hInd-Síne (Bangkok)',
        'Asia/Barnaul' => 'an Rúis (Barnaul)',
        'Asia/Beirut' => 'Am Oirthear na hEorpa (Béiriút)',
        'Asia/Bishkek' => 'Am na Cirgeastáine (Bishkek)',
        'Asia/Brunei' => 'Am Bhrúiné Darasalám (Brúiné)',
        'Asia/Calcutta' => 'Am Caighdeánach na hIndia (Calcúta)',
        'Asia/Chita' => 'Am Iacútsc (Chita)',
        'Asia/Choibalsan' => 'Am Ulánbátar (Choibalsan)',
        'Asia/Colombo' => 'Am Caighdeánach na hIndia (Colombo)',
        'Asia/Damascus' => 'Am Oirthear na hEorpa (an Damaisc)',
        'Asia/Dhaka' => 'Am na Banglaidéise (Dhaka)',
        'Asia/Dili' => 'Am Thíomór Thoir (Dili)',
        'Asia/Dubai' => 'Am Caighdeánach na Murascaille (Dubai)',
        'Asia/Dushanbe' => 'Am na Táidsíceastáine (Dushanbe)',
        'Asia/Famagusta' => 'Am Oirthear na hEorpa (Famagusta)',
        'Asia/Gaza' => 'Am Oirthear na hEorpa (Gaza)',
        'Asia/Hebron' => 'Am Oirthear na hEorpa (Heabrón)',
        'Asia/Hong_Kong' => 'Am Hong Cong',
        'Asia/Hovd' => 'Am Hovd',
        'Asia/Irkutsk' => 'Am Irkutsk',
        'Asia/Jakarta' => 'Am Iarthar na hIndinéise (Iacárta)',
        'Asia/Jayapura' => 'Am Oirthear na hIndinéise (Jayapura)',
        'Asia/Jerusalem' => 'Am Iosrael (Iarúsailéim)',
        'Asia/Kabul' => 'Am na hAfganastáine (Cabúl)',
        'Asia/Kamchatka' => 'Am Phetropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Am na Pacastáine (Karachi)',
        'Asia/Katmandu' => 'Am Neipeal (Kathmandu)',
        'Asia/Khandyga' => 'Am Iacútsc (Khandyga)',
        'Asia/Krasnoyarsk' => 'Am Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Am na Malaeisia (Kuala Lumpur)',
        'Asia/Kuching' => 'Am na Malaeisia (Kuching)',
        'Asia/Kuwait' => 'Am na hAraibe (Cuáit)',
        'Asia/Macau' => 'Am na Síne (Macao)',
        'Asia/Magadan' => 'Am Mhagadan (Magadan)',
        'Asia/Makassar' => 'Am Lár na hIndinéise (Macasar)',
        'Asia/Manila' => 'Am na nOileán Filipíneach (Mainile)',
        'Asia/Muscat' => 'Am Caighdeánach na Murascaille (Muscat)',
        'Asia/Nicosia' => 'Am Oirthear na hEorpa (an Niocóis)',
        'Asia/Novokuznetsk' => 'Am Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Am Novosibirsk',
        'Asia/Omsk' => 'Am Omsk',
        'Asia/Oral' => 'Am Iarthar na Casacstáine (Oral)',
        'Asia/Phnom_Penh' => 'Am na hInd-Síne (Phnom Penh)',
        'Asia/Pontianak' => 'Am Iarthar na hIndinéise (Pontianak)',
        'Asia/Pyongyang' => 'Am na Cóiré (Pyongyang)',
        'Asia/Qatar' => 'Am na hAraibe (Catar)',
        'Asia/Qostanay' => 'Am Oirthear na Casacstáine (Kostanay)',
        'Asia/Qyzylorda' => 'Am Iarthar na Casacstáine (Qyzylorda)',
        'Asia/Rangoon' => 'Am Mhaenmar (Rangún)',
        'Asia/Riyadh' => 'Am na hAraibe (Riyadh)',
        'Asia/Saigon' => 'Am na hInd-Síne (Cathair Ho Chi Minh)',
        'Asia/Sakhalin' => 'Am Shacailín (Sakhalin)',
        'Asia/Samarkand' => 'Am na hÚisbéiceastáine (Samarkand)',
        'Asia/Seoul' => 'Am na Cóiré (Súl)',
        'Asia/Shanghai' => 'Am na Síne (Shang-hai)',
        'Asia/Singapore' => 'Am Caighdeánach Shingeapór (Singeapór)',
        'Asia/Srednekolymsk' => 'Am Mhagadan (Srednekolymsk)',
        'Asia/Taipei' => 'Am Taipei',
        'Asia/Tashkent' => 'Am na hÚisbéiceastáine (Tashkent)',
        'Asia/Tbilisi' => 'Am na Seoirsia (Tbilisi)',
        'Asia/Tehran' => 'Am na hIaráine (Tehran)',
        'Asia/Thimphu' => 'Am na Bútáine (Thimphu)',
        'Asia/Tokyo' => 'Am na Seapáine (Tóiceo)',
        'Asia/Tomsk' => 'an Rúis (Tomsk)',
        'Asia/Ulaanbaatar' => 'Am Ulánbátar (Ulaanbaatar)',
        'Asia/Urumqi' => 'an tSín (Urumqi)',
        'Asia/Ust-Nera' => 'Am Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Am na hInd-Síne (Vientiane)',
        'Asia/Vladivostok' => 'Am Vladivostok',
        'Asia/Yakutsk' => 'Am Iacútsc',
        'Asia/Yekaterinburg' => 'Am Yekaterinburg',
        'Asia/Yerevan' => 'Am na hAirméine (Eireaván)',
        'Atlantic/Azores' => 'Am na nAsór (na hAsóir)',
        'Atlantic/Bermuda' => 'Am an Atlantaigh (Beirmiúda)',
        'Atlantic/Canary' => 'Am Iarthar na hEorpa (na hOileáin Chanáracha)',
        'Atlantic/Cape_Verde' => 'Am Rinn Verde',
        'Atlantic/Faeroe' => 'Am Iarthar na hEorpa (Oileáin Fharó)',
        'Atlantic/Madeira' => 'Am Iarthar na hEorpa (Maidéara)',
        'Atlantic/Reykjavik' => 'Meán-Am Greenwich (Réicivíc)',
        'Atlantic/South_Georgia' => 'Am na Seoirsia Theas (an tSeoirsia Theas)',
        'Atlantic/St_Helena' => 'Meán-Am Greenwich (San Héilin)',
        'Atlantic/Stanley' => 'Am Oileáin Fháclainne (Stanley)',
        'Australia/Adelaide' => 'Am Lár na hAstráile (Adelaide)',
        'Australia/Brisbane' => 'Am Oirthear na hAstráile (Brisbane)',
        'Australia/Broken_Hill' => 'Am Lár na hAstráile (Broken Hill)',
        'Australia/Currie' => 'Am Oirthear na hAstráile (Currie)',
        'Australia/Darwin' => 'Am Lár na hAstráile (Darwin)',
        'Australia/Eucla' => 'Am Mheániarthar na hAstráile (Eucla)',
        'Australia/Hobart' => 'Am Oirthear na hAstráile (Hobart)',
        'Australia/Lindeman' => 'Am Oirthear na hAstráile (Lindeman)',
        'Australia/Lord_Howe' => 'Am Lord Howe',
        'Australia/Melbourne' => 'Am Oirthear na hAstráile (Melbourne)',
        'Australia/Perth' => 'Am Iarthar na hAstráile (Perth)',
        'Australia/Sydney' => 'Am Oirthear na hAstráile (Sydney)',
        'CST6CDT' => 'Am Lárnach Mheiriceá Thuaidh',
        'EST5EDT' => 'Am Oirthearach Mheiriceá Thuaidh',
        'Etc/GMT' => 'Meán-Am Greenwich',
        'Etc/UTC' => 'Am Uilíoch Lárnach',
        'Europe/Amsterdam' => 'Am Lár na hEorpa (Amstardam)',
        'Europe/Andorra' => 'Am Lár na hEorpa (Andóra)',
        'Europe/Astrakhan' => 'Am Mhoscó (an Astracáin)',
        'Europe/Athens' => 'Am Oirthear na hEorpa (an Aithin)',
        'Europe/Belgrade' => 'Am Lár na hEorpa (Béalgrád)',
        'Europe/Berlin' => 'Am Lár na hEorpa (Beirlín)',
        'Europe/Bratislava' => 'Am Lár na hEorpa (an Bhratasláiv)',
        'Europe/Brussels' => 'Am Lár na hEorpa (an Bhruiséil)',
        'Europe/Bucharest' => 'Am Oirthear na hEorpa (Búcairist)',
        'Europe/Budapest' => 'Am Lár na hEorpa (Búdaipeist)',
        'Europe/Busingen' => 'Am Lár na hEorpa (Busingen)',
        'Europe/Chisinau' => 'Am Oirthear na hEorpa (Císineá)',
        'Europe/Copenhagen' => 'Am Lár na hEorpa (Cóbanhávan)',
        'Europe/Dublin' => 'Meán-Am Greenwich (Baile Átha Cliath)',
        'Europe/Gibraltar' => 'Am Lár na hEorpa (Giobráltar)',
        'Europe/Guernsey' => 'Meán-Am Greenwich (Geansaí)',
        'Europe/Helsinki' => 'Am Oirthear na hEorpa (Heilsincí)',
        'Europe/Isle_of_Man' => 'Meán-Am Greenwich (Oileán Mhanann)',
        'Europe/Istanbul' => 'an Tuirc (Iostanbúl)',
        'Europe/Jersey' => 'Meán-Am Greenwich (Geirsí)',
        'Europe/Kaliningrad' => 'Am Oirthear na hEorpa (Kaliningrad)',
        'Europe/Kiev' => 'Am Oirthear na hEorpa (Cív)',
        'Europe/Kirov' => 'an Rúis (Kirov)',
        'Europe/Lisbon' => 'Am Iarthar na hEorpa (Liospóin)',
        'Europe/Ljubljana' => 'Am Lár na hEorpa (Liúibleána)',
        'Europe/London' => 'Meán-Am Greenwich (Londain)',
        'Europe/Luxembourg' => 'Am Lár na hEorpa (Lucsamburg)',
        'Europe/Madrid' => 'Am Lár na hEorpa (Maidrid)',
        'Europe/Malta' => 'Am Lár na hEorpa (Málta)',
        'Europe/Mariehamn' => 'Am Oirthear na hEorpa (Mariehamn)',
        'Europe/Minsk' => 'Am Mhoscó (Mionsc)',
        'Europe/Monaco' => 'Am Lár na hEorpa (Monacó)',
        'Europe/Moscow' => 'Am Mhoscó (Moscó)',
        'Europe/Oslo' => 'Am Lár na hEorpa (Osló)',
        'Europe/Paris' => 'Am Lár na hEorpa (Páras)',
        'Europe/Podgorica' => 'Am Lár na hEorpa (Podgairítse)',
        'Europe/Prague' => 'Am Lár na hEorpa (Prág)',
        'Europe/Riga' => 'Am Oirthear na hEorpa (Ríge)',
        'Europe/Rome' => 'Am Lár na hEorpa (an Róimh)',
        'Europe/Samara' => 'Am Shamara (Samara)',
        'Europe/San_Marino' => 'Am Lár na hEorpa (San Mairíne)',
        'Europe/Sarajevo' => 'Am Lár na hEorpa (Sairéavó)',
        'Europe/Saratov' => 'Am Mhoscó (Saratov)',
        'Europe/Simferopol' => 'Am Mhoscó (Simferopol)',
        'Europe/Skopje' => 'Am Lár na hEorpa (Scóipé)',
        'Europe/Sofia' => 'Am Oirthear na hEorpa (Sóifia)',
        'Europe/Stockholm' => 'Am Lár na hEorpa (Stócólm)',
        'Europe/Tallinn' => 'Am Oirthear na hEorpa (Taillinn)',
        'Europe/Tirane' => 'Am Lár na hEorpa (Tiorána)',
        'Europe/Ulyanovsk' => 'Am Mhoscó (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Am Oirthear na hEorpa (Uzhgorod)',
        'Europe/Vaduz' => 'Am Lár na hEorpa (Vadús)',
        'Europe/Vatican' => 'Am Lár na hEorpa (an Vatacáin)',
        'Europe/Vienna' => 'Am Lár na hEorpa (Vín)',
        'Europe/Vilnius' => 'Am Oirthear na hEorpa (Vilnias)',
        'Europe/Volgograd' => 'Am Volgograd',
        'Europe/Warsaw' => 'Am Lár na hEorpa (Vársá)',
        'Europe/Zagreb' => 'Am Lár na hEorpa (Ságrab)',
        'Europe/Zaporozhye' => 'Am Oirthear na hEorpa (Zaporozhye)',
        'Europe/Zurich' => 'Am Lár na hEorpa (Zürich)',
        'Indian/Antananarivo' => 'Am Oirthear na hAfraice (Antananairíveo)',
        'Indian/Chagos' => 'Am an Aigéin Indiaigh (Chagos)',
        'Indian/Christmas' => 'Am Oileán na Nollag',
        'Indian/Cocos' => 'Am Oileáin Cocos (Oileán Cocos)',
        'Indian/Comoro' => 'Am Oirthear na hAfraice (Oileáin Chomóra)',
        'Indian/Kerguelen' => 'Am Francach Dheisceart an Domhain agus an Antartaigh (Kerguelen)',
        'Indian/Mahe' => 'Am na Séiséal (Mahe)',
        'Indian/Maldives' => 'Am Oileáin Mhaildíve',
        'Indian/Mauritius' => 'Am Oileán Mhuirís',
        'Indian/Mayotte' => 'Am Oirthear na hAfraice (Mayotte)',
        'Indian/Reunion' => 'Am Réunion (La Réunion)',
        'MST7MDT' => 'Am Sléibhte Mheiriceá Thuaidh',
        'PST8PDT' => 'Am an Aigéin Chiúin',
        'Pacific/Apia' => 'Am Apia',
        'Pacific/Auckland' => 'Am na Nua-Shéalainne (Auckland)',
        'Pacific/Bougainville' => 'Am Nua-Ghuine Phapua (Bougainville)',
        'Pacific/Chatham' => 'Am Chatham',
        'Pacific/Easter' => 'Am Oileán na Cásca (Easter)',
        'Pacific/Efate' => 'Am Vanuatú (Efate)',
        'Pacific/Enderbury' => 'Am Oileáin an Fhéinics (Enderbury)',
        'Pacific/Fakaofo' => 'Am Oileáin Tócalá (Fakaofo)',
        'Pacific/Fiji' => 'Am Fhidsí (Fidsí)',
        'Pacific/Funafuti' => 'Am Thúvalú (Funafuti)',
        'Pacific/Galapagos' => 'Am Oileáin Galápagos (Galapagos)',
        'Pacific/Gambier' => 'Am Gambier',
        'Pacific/Guadalcanal' => 'Am Oileáin Sholaimh (Guadalcanal)',
        'Pacific/Guam' => 'Am Caighdeánach Seamórach (Guam)',
        'Pacific/Honolulu' => 'Am Haváí-Ailiúit (Honolulu)',
        'Pacific/Johnston' => 'Am Haváí-Ailiúit (Johnston)',
        'Pacific/Kiritimati' => 'Am Oileáin na Líne (Kiritimati)',
        'Pacific/Kosrae' => 'Am Kosrae',
        'Pacific/Kwajalein' => 'Am Oileáin Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Am Oileáin Marshall (Majuro)',
        'Pacific/Marquesas' => 'Am na nOileán Marcasach (na hOileáin Mharcasacha)',
        'Pacific/Midway' => 'Am Shamó (Oileáin Midway)',
        'Pacific/Nauru' => 'Am Nárú',
        'Pacific/Niue' => 'Am Niue',
        'Pacific/Norfolk' => 'Am Oileán Norfolk',
        'Pacific/Noumea' => 'Am na Nua-Chaladóine (Noumea)',
        'Pacific/Pago_Pago' => 'Am Shamó (Pago Pago)',
        'Pacific/Palau' => 'Am Oileáin Palau',
        'Pacific/Pitcairn' => 'Am Pitcairn',
        'Pacific/Ponape' => 'Am Phohnpei (Pohnpei)',
        'Pacific/Port_Moresby' => 'Am Nua-Ghuine Phapua (Port Moresby)',
        'Pacific/Rarotonga' => 'Am Oileáin Cook (Rarotonga)',
        'Pacific/Saipan' => 'Am Caighdeánach Seamórach (Saipan)',
        'Pacific/Tahiti' => 'Am Thaihítí (Taihítí)',
        'Pacific/Tarawa' => 'Am Chireabaití (Tarawa)',
        'Pacific/Tongatapu' => 'Am Thonga (Tongatapu)',
        'Pacific/Truk' => 'Am Chuuk',
        'Pacific/Wake' => 'Am Oileán Wake',
        'Pacific/Wallis' => 'Am Wallis agus Futuna (Vailís)',
    ],
    'Meta' => [
        'GmtFormat' => 'MAG%s',
    ],
];
