<?php

return [
    'Names' => [
        'aa' => 'àfar',
        'ab' => 'abkhaz',
        'ace' => 'atjeh',
        'ach' => 'acoli',
        'ada' => 'adangme',
        'ady' => 'adigué',
        'ae' => 'avèstic',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'àkan',
        'akk' => 'accadi',
        'akz' => 'alabama',
        'ale' => 'aleuta',
        'aln' => 'albanès geg',
        'alt' => 'altaic meridional',
        'am' => 'amhàric',
        'an' => 'aragonès',
        'ang' => 'anglès antic',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'àrab',
        'arc' => 'arameu',
        'arn' => 'mapudungu',
        'aro' => 'araona',
        'arp' => 'arapaho',
        'ars' => 'àrab najdi',
        'arw' => 'arauac',
        'arz' => 'àrab egipci',
        'as' => 'assamès',
        'asa' => 'pare',
        'ase' => 'llengua de signes americana',
        'ast' => 'asturià',
        'atj' => 'atacama',
        'av' => 'àvar',
        'awa' => 'awadhi',
        'ay' => 'aimara',
        'az' => 'azerbaidjanès',
        'ba' => 'baixkir',
        'bal' => 'balutxi',
        'ban' => 'balinès',
        'bar' => 'bavarès',
        'bas' => 'basa',
        'bax' => 'bamum',
        'bbj' => 'ghomala',
        'be' => 'belarús',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bfq' => 'badaga',
        'bg' => 'búlgar',
        'bgn' => 'balutxi occidental',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bik' => 'bicol',
        'bin' => 'edo',
        'bkm' => 'kom',
        'bla' => 'blackfoot',
        'bm' => 'bambara',
        'bn' => 'bengalí',
        'bo' => 'tibetà',
        'br' => 'bretó',
        'bra' => 'braj',
        'brh' => 'brahui',
        'brx' => 'bodo',
        'bs' => 'bosnià',
        'bss' => 'akoose',
        'bua' => 'buriat',
        'bug' => 'bugui',
        'bum' => 'bulu',
        'byn' => 'bilin',
        'byv' => 'medumba',
        'ca' => 'català',
        'cad' => 'caddo',
        'car' => 'carib',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'txetxè',
        'ceb' => 'cebuà',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'txibtxa',
        'chg' => 'txagatai',
        'chk' => 'chuuk',
        'chm' => 'mari',
        'chn' => 'pidgin chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'xeiene',
        'ckb' => 'kurd central',
        'clc' => 'chilcotin',
        'co' => 'cors',
        'cop' => 'copte',
        'cr' => 'cree',
        'crg' => 'michif',
        'crh' => 'tàtar de Crimea',
        'crj' => 'cree sud-oriental',
        'crk' => 'cree de la plana',
        'crl' => 'cree nord-oriental',
        'crm' => 'moose cree',
        'crr' => 'algonquí de Carolina',
        'crs' => 'francès crioll de les Seychelles',
        'cs' => 'txec',
        'csb' => 'caixubi',
        'csw' => 'swampy cree',
        'cu' => 'eslau eclesiàstic',
        'cv' => 'txuvaix',
        'cy' => 'gal·lès',
        'da' => 'danès',
        'dak' => 'dakota',
        'dar' => 'darguà',
        'dav' => 'taita',
        'de' => 'alemany',
        'del' => 'delaware',
        'den' => 'slavi',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'baix sòrab',
        'dua' => 'douala',
        'dum' => 'neerlandès mitjà',
        'dv' => 'divehi',
        'dyo' => 'diola',
        'dyu' => 'jula',
        'dz' => 'dzongka',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egl' => 'emilià',
        'egy' => 'egipci antic',
        'eka' => 'ekajuk',
        'el' => 'grec',
        'elx' => 'elamita',
        'en' => 'anglès',
        'enm' => 'anglès mitjà',
        'eo' => 'esperanto',
        'es' => 'espanyol',
        'et' => 'estonià',
        'eu' => 'basc',
        'ewo' => 'ewondo',
        'ext' => 'extremeny',
        'fa' => 'persa',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'ful',
        'fi' => 'finès',
        'fil' => 'filipí',
        'fj' => 'fijià',
        'fo' => 'feroès',
        'fon' => 'fon',
        'fr' => 'francès',
        'frc' => 'francès cajun',
        'frm' => 'francès mitjà',
        'fro' => 'francès antic',
        'frr' => 'frisó septentrional',
        'frs' => 'frisó oriental',
        'fur' => 'friülà',
        'fy' => 'frisó occidental',
        'ga' => 'irlandès',
        'gaa' => 'ga',
        'gag' => 'gagaús',
        'gan' => 'xinès gan',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gd' => 'gaèlic escocès',
        'gez' => 'gueez',
        'gil' => 'gilbertès',
        'gl' => 'gallec',
        'glk' => 'gilaki',
        'gmh' => 'alt alemany mitjà',
        'gn' => 'guaraní',
        'goh' => 'alt alemany antic',
        'gom' => 'concani de Goa',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gòtic',
        'grb' => 'grebo',
        'grc' => 'grec antic',
        'gsw' => 'alemany suís',
        'gu' => 'gujarati',
        'guc' => 'wayú',
        'guz' => 'gusí',
        'gv' => 'manx',
        'gwi' => 'gwich’in',
        'ha' => 'haussa',
        'hai' => 'haida',
        'hak' => 'xinès hakka',
        'haw' => 'hawaià',
        'hax' => 'haida meridional',
        'he' => 'hebreu',
        'hi' => 'hindi',
        'hif' => 'hindi de Fiji',
        'hil' => 'híligaynon',
        'hit' => 'hitita',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'croat',
        'hsb' => 'alt sòrab',
        'hsn' => 'xinès xiang',
        'ht' => 'crioll d’Haití',
        'hu' => 'hongarès',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armeni',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesi',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'yi sichuan',
        'ik' => 'inupiak',
        'ikt' => 'inuktitut occidental canadenc',
        'ilo' => 'ilocano',
        'inh' => 'ingúix',
        'io' => 'ido',
        'is' => 'islandès',
        'it' => 'italià',
        'iu' => 'inuktitut',
        'ja' => 'japonès',
        'jam' => 'crioll anglès de Jamaica',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'judeopersa',
        'jrb' => 'judeoàrab',
        'jv' => 'javanès',
        'ka' => 'georgià',
        'kaa' => 'karakalpak',
        'kab' => 'cabilenc',
        'kac' => 'katxin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardí',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'crioll capverdià',
        'ken' => 'kenyang',
        'kfo' => 'koro',
        'kg' => 'kongo',
        'kgp' => 'kaingà',
        'kha' => 'khasi',
        'kho' => 'khotanès',
        'khq' => 'koyra chiini',
        'ki' => 'kikuiu',
        'kj' => 'kuanyama',
        'kk' => 'kazakh',
        'kkj' => 'kako',
        'kl' => 'groenlandès',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'coreà',
        'koi' => 'komi-permiac',
        'kok' => 'concani',
        'kos' => 'kosraeà',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karatxai-balkar',
        'kri' => 'krio',
        'krl' => 'carelià',
        'kru' => 'kurukh',
        'ks' => 'caixmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'kurd',
        'kum' => 'kúmik',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'còrnic',
        'kwk' => 'kwak’wala',
        'ky' => 'kirguís',
        'la' => 'llatí',
        'lad' => 'judeocastellà',
        'lag' => 'langi',
        'lah' => 'panjabi occidental',
        'lam' => 'lamba',
        'lb' => 'luxemburguès',
        'lez' => 'lesguià',
        'lg' => 'ganda',
        'li' => 'limburguès',
        'lij' => 'lígur',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'lmo' => 'llombard',
        'ln' => 'lingala',
        'lo' => 'laosià',
        'lol' => 'mongo',
        'lou' => 'crioll francès de Louisiana',
        'loz' => 'lozi',
        'lrc' => 'luri septentrional',
        'lsm' => 'saamia',
        'lt' => 'lituà',
        'lu' => 'luba katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luisenyo',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'letó',
        'lzh' => 'xinès clàssic',
        'lzz' => 'laz',
        'mad' => 'madurès',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makassar',
        'man' => 'mandinga',
        'mas' => 'massai',
        'mde' => 'maba',
        'mdf' => 'mordovià moksa',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'mauricià',
        'mg' => 'malgaix',
        'mga' => 'gaèlic irlandès mitjà',
        'mgh' => 'makhuwa-metto',
        'mgo' => 'meta’',
        'mh' => 'marshallès',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'macedoni',
        'ml' => 'malaiàlam',
        'mn' => 'mongol',
        'mnc' => 'manxú',
        'mni' => 'manipurí',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'moore',
        'mr' => 'marathi',
        'mrj' => 'mari occidental',
        'ms' => 'malai',
        'mt' => 'maltès',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandès',
        'mwr' => 'marwari',
        'my' => 'birmà',
        'mye' => 'myene',
        'myv' => 'mordovià erza',
        'mzn' => 'mazanderani',
        'na' => 'nauruà',
        'nan' => 'xinès min del sud',
        'nap' => 'napolità',
        'naq' => 'nama',
        'nb' => 'noruec bokmål',
        'nd' => 'ndebele septentrional',
        'nds' => 'baix alemany',
        'ne' => 'nepalès',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niueà',
        'nl' => 'neerlandès',
        'nmg' => 'bissio',
        'nn' => 'noruec nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'noruec',
        'nog' => 'nogai',
        'non' => 'nòrdic antic',
        'nov' => 'novial',
        'nqo' => 'n’Ko',
        'nr' => 'ndebele meridional',
        'nso' => 'sotho septentrional',
        'nus' => 'nuer',
        'nv' => 'navaho',
        'nwc' => 'newari clàssic',
        'ny' => 'nyanja',
        'nym' => 'nyamwesi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzema',
        'oc' => 'occità',
        'oj' => 'ojibwa',
        'ojb' => 'ojibwa septentrional',
        'ojc' => 'ojibwa central',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwa occidental',
        'oka' => 'okanagà',
        'om' => 'oromo',
        'or' => 'oriya',
        'os' => 'osseta',
        'osa' => 'osage',
        'ota' => 'turc otomà',
        'pa' => 'panjabi',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiament',
        'pau' => 'palauà',
        'pcd' => 'picard',
        'pcm' => 'pidgin de Nigèria',
        'pdc' => 'alemany pennsilvanià',
        'peo' => 'persa antic',
        'pfl' => 'alemany palatí',
        'phn' => 'fenici',
        'pi' => 'pali',
        'pis' => 'pidgin',
        'pl' => 'polonès',
        'pms' => 'piemontès',
        'pnt' => 'pòntic',
        'pon' => 'ponapeà',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'prussià',
        'pro' => 'provençal antic',
        'ps' => 'paixtu',
        'pt' => 'portuguès',
        'qu' => 'quítxua',
        'quc' => 'k’iche’',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotongà',
        'rgn' => 'romanyès',
        'rhg' => 'rohingya',
        'rm' => 'retoromànic',
        'rn' => 'rundi',
        'ro' => 'romanès',
        'rof' => 'rombo',
        'rom' => 'romaní',
        'ru' => 'rus',
        'rup' => 'aromanès',
        'rw' => 'ruandès',
        'rwk' => 'rwo',
        'sa' => 'sànscrit',
        'sad' => 'sandawe',
        'sah' => 'iacut',
        'sam' => 'arameu samarità',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sard',
        'scn' => 'sicilià',
        'sco' => 'escocès',
        'sd' => 'sindi',
        'sdc' => 'sasserès',
        'sdh' => 'kurd meridional',
        'se' => 'sami septentrional',
        'see' => 'seneca',
        'seh' => 'sena',
        'sel' => 'selkup',
        'ses' => 'songhai oriental',
        'sg' => 'sango',
        'sga' => 'irlandès antic',
        'sh' => 'serbocroat',
        'shi' => 'taixelhit',
        'shn' => 'xan',
        'shu' => 'àrab txadià',
        'si' => 'singalès',
        'sid' => 'sidamo',
        'sk' => 'eslovac',
        'sl' => 'eslovè',
        'slh' => 'lushootseed meridional',
        'sm' => 'samoà',
        'sma' => 'sami meridional',
        'smj' => 'sami lule',
        'smn' => 'sami d’Inari',
        'sms' => 'sami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somali',
        'sog' => 'sogdià',
        'sq' => 'albanès',
        'sr' => 'serbi',
        'srn' => 'sranan',
        'srr' => 'serer',
        'ss' => 'swazi',
        'ssy' => 'saho',
        'st' => 'sotho meridional',
        'str' => 'straits salish',
        'su' => 'sondanès',
        'suk' => 'sukuma',
        'sus' => 'susú',
        'sux' => 'sumeri',
        'sv' => 'suec',
        'sw' => 'suahili',
        'swb' => 'comorià',
        'syc' => 'siríac clàssic',
        'syr' => 'siríac',
        'szl' => 'silesià',
        'ta' => 'tàmil',
        'tce' => 'tutxone meridional',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'terena',
        'tet' => 'tètum',
        'tg' => 'tadjik',
        'tgx' => 'tagish',
        'th' => 'tai',
        'tht' => 'tahltà',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tiv' => 'tiv',
        'tk' => 'turcman',
        'tkl' => 'tokelauès',
        'tkr' => 'tsakhur',
        'tl' => 'tagal',
        'tlh' => 'klingonià',
        'tli' => 'tlingit',
        'tly' => 'talix',
        'tmh' => 'amazic',
        'tn' => 'setswana',
        'to' => 'tongalès',
        'tog' => 'tonga',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turc',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsi' => 'tsimshià',
        'tt' => 'tàtar',
        'ttm' => 'tutxone septentrional',
        'ttt' => 'tat meridional',
        'tum' => 'tumbuka',
        'tvl' => 'tuvaluà',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitià',
        'tyv' => 'tuvinià',
        'tzm' => 'amazic del Marroc central',
        'udm' => 'udmurt',
        'ug' => 'uigur',
        'uga' => 'ugarític',
        'uk' => 'ucraïnès',
        'umb' => 'umbundu',
        'ur' => 'urdú',
        'uz' => 'uzbek',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'vènet',
        'vep' => 'vepse',
        'vi' => 'vietnamita',
        'vls' => 'flamenc occidental',
        'vo' => 'volapük',
        'vot' => 'vòtic',
        'vun' => 'vunjo',
        'wa' => 'való',
        'wae' => 'walser',
        'wal' => 'wolaita',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'wòlof',
        'wuu' => 'xinès wu',
        'xal' => 'calmuc',
        'xh' => 'xosa',
        'xmf' => 'mingrelià',
        'xog' => 'soga',
        'yao' => 'yao',
        'yap' => 'yapeà',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'ídix',
        'yo' => 'ioruba',
        'yrl' => 'nheengatú',
        'yue' => 'cantonès',
        'za' => 'zhuang',
        'zap' => 'zapoteca',
        'zbl' => 'símbols Bliss',
        'zea' => 'zelandès',
        'zen' => 'zenaga',
        'zgh' => 'amazic estàndard marroquí',
        'zh' => 'xinès',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'àrab estàndard modern',
        'de_AT' => 'alemany austríac',
        'de_CH' => 'alemany estàndard suís',
        'en_AU' => 'anglès australià',
        'en_CA' => 'anglès canadenc',
        'en_GB' => 'anglès britànic',
        'en_US' => 'anglès americà',
        'es_419' => 'espanyol hispanoamericà',
        'es_ES' => 'espanyol europeu',
        'es_MX' => 'espanyol de Mèxic',
        'fa_AF' => 'dari',
        'fr_CA' => 'francès canadenc',
        'fr_CH' => 'francès suís',
        'nds_NL' => 'baix saxó',
        'nl_BE' => 'flamenc',
        'pt_BR' => 'portuguès del Brasil',
        'pt_PT' => 'portuguès de Portugal',
        'ro_MD' => 'moldau',
        'sw_CD' => 'suahili del Congo',
        'zh_Hans' => 'xinès simplificat',
        'zh_Hant' => 'xinès tradicional',
    ],
];
