<?php

return [
    'Names' => [
        'Africa/Casablanca' => 'لوېديزے اروپا وخت (کاسابلانکا)',
        'Africa/El_Aaiun' => 'لوېديزے اروپا وخت (الیون)',
        'Africa/Harare' => 'منځنی افريقا وخت (هرارے)',
        'America/Lower_Princes' => 'اتلانتیک وخت (د کمتر شهزاده درے میاشتنۍ)',
        'Atlantic/Canary' => 'لوېديزے اروپا وخت (کناري)',
        'Atlantic/Faeroe' => 'لوېديزے اروپا وخت (فارو)',
        'Atlantic/Madeira' => 'لوېديزے اروپا وخت (مديرا)',
        'Europe/Lisbon' => 'لوېديزے اروپا وخت (لیسبون)',
        'Indian/Kerguelen' => 'د فرانسے سویل او انټارټيک وخت (کرګولين)',
        'Pacific/Kiritimati' => 'د کرښے ټاټوبي وخت (کيريټماټي)',
    ],
    'Meta' => [
    ],
];
