<?php

return [
    'Names' => [
        'ak' => 'Akan',
        'am' => 'Amarik',
        'ar' => 'Arabik',
        'be' => 'Belarus kasa',
        'bg' => 'Bɔlgeria kasa',
        'bn' => 'Bengali kasa',
        'cs' => 'Kyɛk kasa',
        'de' => 'Gyaaman',
        'el' => 'Greek kasa',
        'en' => 'Borɔfo',
        'es' => 'Spain kasa',
        'fa' => 'Pɛɛhyia kasa',
        'fr' => 'Frɛnkye',
        'ha' => 'Hausa',
        'hi' => 'Hindi',
        'hu' => 'Hangri kasa',
        'id' => 'Indonihyia kasa',
        'ig' => 'Igbo',
        'it' => 'Italy kasa',
        'ja' => 'Gyapan kasa',
        'jv' => 'Gyabanis kasa',
        'km' => 'Kambodia kasa',
        'ko' => 'Korea kasa',
        'ms' => 'Malay kasa',
        'my' => 'Bɛɛmis kasa',
        'ne' => 'Nɛpal kasa',
        'nl' => 'Dɛɛkye',
        'pa' => 'Pungyabi kasa',
        'pl' => 'Pɔland kasa',
        'pt' => 'Pɔɔtugal kasa',
        'ro' => 'Romenia kasa',
        'ru' => 'Rahyia kasa',
        'rw' => 'Rewanda kasa',
        'so' => 'Somalia kasa',
        'sv' => 'Sweden kasa',
        'ta' => 'Tamil kasa',
        'th' => 'Taeland kasa',
        'tr' => 'Tɛɛki kasa',
        'uk' => 'Ukren kasa',
        'ur' => 'Urdu kasa',
        'vi' => 'Viɛtnam kasa',
        'yo' => 'Yoruba',
        'zh' => 'Kyaena kasa',
        'zu' => 'Zulu',
    ],
    'LocalizedNames' => [
    ],
];
