<?php

/**
 * Norwegian Bokmål PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 */

 $PHPMAILER_LANG['authenticate']         = 'SMTP-feil: Kunne ikke autentiseres.';
 $PHPMAILER_LANG['buggy_php']            = 'Din versjon av PHP er berørt av en feil som kan føre til ødelagte meldinger. For å løse problemet kan du bytte til SMTP, deaktivere alternativet mail.add_x_header i php.ini, bytte til MacOS eller Linux eller oppgradere PHP til versjon 7.0.17+ eller 7.1.3+.';
 $PHPMAILER_LANG['connect_host']         = 'SMTP-feil: Kunne ikke koble til SMTP-vert.';
 $PHPMAILER_LANG['data_not_accepted']    = 'SMTP-feil: data ikke akseptert.';
 $PHPMAILER_LANG['empty_message']        = 'Meldingstekst mangler';
 $PHPMAILER_LANG['encoding']             = 'Ukjent koding: ';
 $PHPMAILER_LANG['execute']              = 'Kunne ikke utføres: ';
 $PHPMAILER_LANG['extension_missing']    = 'Utvidelse mangler: ';
 $PHPMAILER_LANG['file_access']          = 'Kunne ikke få tilgang til filen: ';
 $PHPMAILER_LANG['file_open']            = 'Feil i fil: Kunne ikke åpne filen: ';
 $PHPMAILER_LANG['from_failed']          = 'Følgende Fra-adresse mislyktes: ';
 $PHPMAILER_LANG['instantiate']          = 'Kunne ikke instansiere e-postfunksjonen.';
 $PHPMAILER_LANG['invalid_address']      = 'Ugyldig adresse: ';
 $PHPMAILER_LANG['invalid_header']       = 'Ugyldig headernavn eller verdi';
 $PHPMAILER_LANG['invalid_hostentry']    = 'Ugyldig vertsinngang: ';
 $PHPMAILER_LANG['invalid_host']         = 'Ugyldig vert: ';
 $PHPMAILER_LANG['mailer_not_supported'] = ' sender er ikke støttet.';
 $PHPMAILER_LANG['provide_address']      = 'Du må oppgi minst én mottaker-e-postadresse.';
 $PHPMAILER_LANG['recipients_failed']    = 'SMTP Feil: Følgende mottakeradresse feilet: ';
 $PHPMAILER_LANG['signing']              = 'Signeringsfeil: ';
 $PHPMAILER_LANG['smtp_code']            = 'SMTP-kode: ';
 $PHPMAILER_LANG['smtp_code_ex']         = 'Ytterligere SMTP-info: ';
 $PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP connect() mislyktes.';
 $PHPMAILER_LANG['smtp_detail']          = 'Detaljer: ';
 $PHPMAILER_LANG['smtp_error']           = 'SMTP-serverfeil: ';
 $PHPMAILER_LANG['variable_set']         = 'Kan ikke angi eller tilbakestille variabel: ';
