<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'hora medie de Greenwich (Abidjan)',
        'Africa/Accra' => 'hora medie de Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'hora de Ethiopia (Addis Ababa)',
        'Africa/Algiers' => 'hora de Europa central (Algiers)',
        'Africa/Asmera' => 'hora de Eritrea (Asmara)',
        'Africa/Bamako' => 'hora medie de Greenwich (Bamako)',
        'Africa/Bangui' => 'hora de Republica African Central (Bangui)',
        'Africa/Banjul' => 'hora medie de Greenwich (Banjul)',
        'Africa/Bissau' => 'hora medie de Greenwich (Bissau)',
        'Africa/Blantyre' => 'hora de Malawi (Blantyre)',
        'Africa/Brazzaville' => 'hora de Congo - Brazzaville (Brazzaville)',
        'Africa/Bujumbura' => 'hora de Burundi (Bujumbura)',
        'Africa/Cairo' => 'hora de Europa oriental (Cairo)',
        'Africa/Casablanca' => 'hora de Europa occidental (Casablanca)',
        'Africa/Ceuta' => 'hora de Europa central (Ceuta)',
        'Africa/Conakry' => 'hora medie de Greenwich (Conakry)',
        'Africa/Dakar' => 'hora medie de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'hora de Tanzania (Dar es Salaam)',
        'Africa/Djibouti' => 'hora de Djibuti (Djibuti)',
        'Africa/Douala' => 'hora de Camerun (Douala)',
        'Africa/El_Aaiun' => 'hora de Europa occidental (El Aaiun)',
        'Africa/Freetown' => 'hora medie de Greenwich (Freetown)',
        'Africa/Gaborone' => 'hora de Botswana (Gaborone)',
        'Africa/Harare' => 'hora de Zimbabwe (Harare)',
        'Africa/Johannesburg' => 'hora de Africa del Sud (Johannesburg)',
        'Africa/Juba' => 'hora de Sudan del Sud (Juba)',
        'Africa/Kampala' => 'hora de Uganda (Kampala)',
        'Africa/Khartoum' => 'hora de Sudan (Khartoum)',
        'Africa/Kigali' => 'hora de Ruanda (Kigali)',
        'Africa/Kinshasa' => 'hora de Congo - Kinshasa (Kinshasa)',
        'Africa/Lagos' => 'hora de Nigeria (Lagos)',
        'Africa/Libreville' => 'hora de Gabon (Libreville)',
        'Africa/Lome' => 'hora medie de Greenwich (Lome)',
        'Africa/Luanda' => 'hora de Angola (Luanda)',
        'Africa/Lubumbashi' => 'hora de Congo - Kinshasa (Lubumbashi)',
        'Africa/Lusaka' => 'hora de Zambia (Lusaka)',
        'Africa/Malabo' => 'hora de Guinea equatorial (Malabo)',
        'Africa/Maputo' => 'hora de Mozambique (Maputo)',
        'Africa/Maseru' => 'hora de Lesotho (Maseru)',
        'Africa/Mbabane' => 'hora de Eswatini (Mbabane)',
        'Africa/Mogadishu' => 'hora de Somalia (Mogadishu)',
        'Africa/Monrovia' => 'hora medie de Greenwich (Monrovia)',
        'Africa/Nairobi' => 'hora de Kenya (Nairobi)',
        'Africa/Ndjamena' => 'hora de Tchad (Ndjamena)',
        'Africa/Niamey' => 'hora de Niger (Niamey)',
        'Africa/Nouakchott' => 'hora medie de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'hora medie de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'hora de Benin (Porto-Novo)',
        'Africa/Sao_Tome' => 'hora medie de Greenwich (Sao Tome)',
        'Africa/Tripoli' => 'hora de Europa oriental (Tripoli)',
        'Africa/Tunis' => 'hora de Europa central (Tunis)',
        'Africa/Windhoek' => 'hora de Namibia (Windhoek)',
        'America/Adak' => 'hora de Hawaii-Aleutianas (Adak)',
        'America/Anchorage' => 'hora de Alaska (Anchorage)',
        'America/Anguilla' => 'hora atlantic (Anguilla)',
        'America/Antigua' => 'hora atlantic (Antigua)',
        'America/Araguaina' => 'hora de Brasil (Araguaina)',
        'America/Argentina/La_Rioja' => 'hora de Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'hora de Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'hora de Argentina (Salta)',
        'America/Argentina/San_Juan' => 'hora de Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'hora de Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'hora de Argentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'hora de Argentina (Ushuaia)',
        'America/Aruba' => 'hora atlantic (Aruba)',
        'America/Asuncion' => 'hora de Paraguay (Asuncion)',
        'America/Bahia' => 'hora de Brasil (Bahia)',
        'America/Bahia_Banderas' => 'hora central (Bahia de Banderas)',
        'America/Barbados' => 'hora atlantic (Barbados)',
        'America/Belem' => 'hora de Brasil (Belem)',
        'America/Belize' => 'hora central (Belize)',
        'America/Blanc-Sablon' => 'hora atlantic (Blanc-Sablon)',
        'America/Boa_Vista' => 'hora de Brasil (Boa Vista)',
        'America/Bogota' => 'hora de Colombia (Bogota)',
        'America/Boise' => 'hora del montanias (Boise)',
        'America/Buenos_Aires' => 'hora de Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'hora del montanias (Cambridge Bay)',
        'America/Campo_Grande' => 'hora de Brasil (Campo Grande)',
        'America/Cancun' => 'hora del est (Cancun)',
        'America/Caracas' => 'hora de Venezuela (Caracas)',
        'America/Catamarca' => 'hora de Argentina (Catamarca)',
        'America/Cayenne' => 'hora de Guyana francese (Cayenne)',
        'America/Cayman' => 'hora del est (Caiman)',
        'America/Chicago' => 'hora central (Chicago)',
        'America/Chihuahua' => 'hora del Pacifico mexican (Chihuahua)',
        'America/Coral_Harbour' => 'hora del est (Atikokan)',
        'America/Cordoba' => 'hora de Argentina (Cordoba)',
        'America/Costa_Rica' => 'hora central (Costa Rica)',
        'America/Creston' => 'hora del montanias (Creston)',
        'America/Cuiaba' => 'hora de Brasil (Cuiaba)',
        'America/Curacao' => 'hora atlantic (Curaçao)',
        'America/Danmarkshavn' => 'hora medie de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'hora de Canada (Dawson)',
        'America/Dawson_Creek' => 'hora del montanias (Dawson Creek)',
        'America/Denver' => 'hora del montanias (Denver)',
        'America/Detroit' => 'hora del est (Detroit)',
        'America/Dominica' => 'hora atlantic (Dominica)',
        'America/Edmonton' => 'hora del montanias (Edmonton)',
        'America/Eirunepe' => 'hora de Brasil (Eirunepe)',
        'America/El_Salvador' => 'hora central (El Salvador)',
        'America/Fort_Nelson' => 'hora del montanias (Fort Nelson)',
        'America/Fortaleza' => 'hora de Brasil (Fortaleza)',
        'America/Glace_Bay' => 'hora atlantic (Glace Bay)',
        'America/Godthab' => 'hora de Groenlandia occidental (Nuuk)',
        'America/Goose_Bay' => 'hora atlantic (Goose Bay)',
        'America/Grand_Turk' => 'hora del est (Grand Turk)',
        'America/Grenada' => 'hora atlantic (Grenada)',
        'America/Guadeloupe' => 'hora atlantic (Guadeloupe)',
        'America/Guatemala' => 'hora central (Guatemala)',
        'America/Guayaquil' => 'hora de Ecuador (Guayaquil)',
        'America/Guyana' => 'hora de Guyana (Guyana)',
        'America/Halifax' => 'hora atlantic (Halifax)',
        'America/Havana' => 'hora de Cuba (Havana)',
        'America/Hermosillo' => 'hora del Pacifico mexican (Hermosillo)',
        'America/Indiana/Knox' => 'hora central (Knox, Indiana)',
        'America/Indiana/Marengo' => 'hora del est (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'hora del est (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'hora central (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'hora del est (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'hora del est (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'hora del est (Winamac, Indiana)',
        'America/Indianapolis' => 'hora del est (Indianapolis)',
        'America/Inuvik' => 'hora del montanias (Inuvik)',
        'America/Iqaluit' => 'hora del est (Iqaluit)',
        'America/Jamaica' => 'hora del est (Jamaica)',
        'America/Jujuy' => 'hora de Argentina (Jujuy)',
        'America/Juneau' => 'hora de Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'hora del est (Monticello, Kentucky)',
        'America/Kralendijk' => 'hora atlantic (Kralendijk)',
        'America/La_Paz' => 'hora de Bolivia (La Paz)',
        'America/Lima' => 'hora de Peru (Lima)',
        'America/Los_Angeles' => 'hora pacific (Los Angeles)',
        'America/Louisville' => 'hora del est (Louisville)',
        'America/Lower_Princes' => 'hora atlantic (Lower Prince’s Quarter)',
        'America/Maceio' => 'hora de Brasil (Maceio)',
        'America/Managua' => 'hora central (Managua)',
        'America/Manaus' => 'hora de Brasil (Manaus)',
        'America/Marigot' => 'hora atlantic (Marigot)',
        'America/Martinique' => 'hora atlantic (Martinica)',
        'America/Matamoros' => 'hora central (Matamoros)',
        'America/Mazatlan' => 'hora del Pacifico mexican (Mazatlan)',
        'America/Mendoza' => 'hora de Argentina (Mendoza)',
        'America/Menominee' => 'hora central (Menominee)',
        'America/Merida' => 'hora central (Merida)',
        'America/Metlakatla' => 'hora de Alaska (Metlakatla)',
        'America/Mexico_City' => 'hora central (Citate de Mexico)',
        'America/Miquelon' => 'hora de Saint-Pierre e Miquelon',
        'America/Moncton' => 'hora atlantic (Moncton)',
        'America/Monterrey' => 'hora central (Monterrey)',
        'America/Montevideo' => 'hora de Uruguay (Montevideo)',
        'America/Montreal' => 'hora de Canada (Montreal)',
        'America/Montserrat' => 'hora atlantic (Montserrat)',
        'America/Nassau' => 'hora del est (Nassau)',
        'America/New_York' => 'hora del est (Nove York)',
        'America/Nipigon' => 'hora del est (Nipigon)',
        'America/Nome' => 'hora de Alaska (Nome)',
        'America/Noronha' => 'hora de Brasil (Noronha)',
        'America/North_Dakota/Beulah' => 'hora central (Beulah, Dakota del Nord)',
        'America/North_Dakota/Center' => 'hora central (Center, Dakota del Nord)',
        'America/North_Dakota/New_Salem' => 'hora central (New Salem, Dakota del Nord)',
        'America/Ojinaga' => 'hora del montanias (Ojinaga)',
        'America/Panama' => 'hora del est (Panama)',
        'America/Pangnirtung' => 'hora del est (Pangnirtung)',
        'America/Paramaribo' => 'hora de Suriname (Paramaribo)',
        'America/Phoenix' => 'hora del montanias (Phoenix)',
        'America/Port-au-Prince' => 'hora del est (Port-au-Prince)',
        'America/Port_of_Spain' => 'hora atlantic (Port of Spain)',
        'America/Porto_Velho' => 'hora de Brasil (Porto Velho)',
        'America/Puerto_Rico' => 'hora atlantic (Porto Rico)',
        'America/Punta_Arenas' => 'hora de Chile (Punta Arenas)',
        'America/Rainy_River' => 'hora central (Rainy River)',
        'America/Rankin_Inlet' => 'hora central (Rankin Inlet)',
        'America/Recife' => 'hora de Brasil (Recife)',
        'America/Regina' => 'hora central (Regina)',
        'America/Resolute' => 'hora central (Resolute)',
        'America/Rio_Branco' => 'hora de Brasil (Rio Branco)',
        'America/Santa_Isabel' => 'hora del nordwest de Mexico (Santa Isabel)',
        'America/Santarem' => 'hora de Brasil (Santarem)',
        'America/Santiago' => 'hora de Chile (Santiago)',
        'America/Santo_Domingo' => 'hora atlantic (Santo Domingo)',
        'America/Sao_Paulo' => 'hora de Brasil (Sao Paulo)',
        'America/Scoresbysund' => 'hora de Groenlandia oriental (Ittoqqortoormiit)',
        'America/Sitka' => 'hora de Alaska (Sitka)',
        'America/St_Barthelemy' => 'hora atlantic (Sancte Bartholomeo)',
        'America/St_Johns' => 'hora de Terranova (Sancte Johannes de Terranova)',
        'America/St_Kitts' => 'hora atlantic (Sancte Christophoro)',
        'America/St_Lucia' => 'hora atlantic (Sancte Lucia)',
        'America/St_Thomas' => 'hora atlantic (Sancte Thomas)',
        'America/St_Vincent' => 'hora atlantic (Sancte Vincente)',
        'America/Swift_Current' => 'hora central (Swift Current)',
        'America/Tegucigalpa' => 'hora central (Tegucigalpa)',
        'America/Thule' => 'hora atlantic (Thule)',
        'America/Thunder_Bay' => 'hora del est (Thunder Bay)',
        'America/Tijuana' => 'hora pacific (Tijuana)',
        'America/Toronto' => 'hora del est (Toronto)',
        'America/Tortola' => 'hora atlantic (Tortola)',
        'America/Vancouver' => 'hora pacific (Vancouver)',
        'America/Whitehorse' => 'hora de Canada (Whitehorse)',
        'America/Winnipeg' => 'hora central (Winnipeg)',
        'America/Yakutat' => 'hora de Alaska (Yakutat)',
        'America/Yellowknife' => 'hora del montanias (Yellowknife)',
        'Antarctica/Casey' => 'hora de Antarctica (Casey)',
        'Antarctica/Davis' => 'hora de Antarctica (Davis)',
        'Antarctica/DumontDUrville' => 'hora de Antarctica (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'hora de Australia (Macquarie)',
        'Antarctica/Mawson' => 'hora de Antarctica (Mawson)',
        'Antarctica/McMurdo' => 'hora de Antarctica (McMurdo)',
        'Antarctica/Palmer' => 'hora de Antarctica (Palmer)',
        'Antarctica/Rothera' => 'hora de Antarctica (Rothera)',
        'Antarctica/Syowa' => 'hora de Antarctica (Syowa)',
        'Antarctica/Troll' => 'hora medie de Greenwich (Troll)',
        'Antarctica/Vostok' => 'hora de Antarctica (Vostok)',
        'Arctic/Longyearbyen' => 'hora de Europa central (Longyearbyen)',
        'Asia/Aden' => 'hora de Yemen (Aden)',
        'Asia/Almaty' => 'hora de Kazakhstan (Almaty)',
        'Asia/Amman' => 'hora de Europa oriental (Amman)',
        'Asia/Anadyr' => 'hora de Russia (Anadyr)',
        'Asia/Aqtau' => 'hora de Kazakhstan (Aqtau)',
        'Asia/Aqtobe' => 'hora de Kazakhstan (Aqtobe)',
        'Asia/Ashgabat' => 'hora de Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'hora de Kazakhstan (Atyrau)',
        'Asia/Baghdad' => 'hora de Irak (Baghdad)',
        'Asia/Bahrain' => 'hora de Bahrain (Bahrain)',
        'Asia/Baku' => 'hora de Azerbaidzhan (Baku)',
        'Asia/Bangkok' => 'hora de Thailandia (Bangkok)',
        'Asia/Barnaul' => 'hora de Russia (Barnaul)',
        'Asia/Beirut' => 'hora de Europa oriental (Beirut)',
        'Asia/Bishkek' => 'hora de Kirghizistan (Bishkek)',
        'Asia/Brunei' => 'hora de Brunei (Brunei)',
        'Asia/Calcutta' => 'hora de India (Kolkata)',
        'Asia/Chita' => 'hora de Yakutsk (Chita)',
        'Asia/Choibalsan' => 'hora de Mongolia (Choibalsan)',
        'Asia/Colombo' => 'hora de Sri Lanka (Colombo)',
        'Asia/Damascus' => 'hora de Europa oriental (Damascus)',
        'Asia/Dhaka' => 'hora de Bangladesh (Dhaka)',
        'Asia/Dili' => 'hora de Timor del Est (Dili)',
        'Asia/Dubai' => 'hora de Emiratos Arabe Unite (Dubai)',
        'Asia/Dushanbe' => 'hora de Tadzhikistan (Dushanbe)',
        'Asia/Famagusta' => 'hora de Europa oriental (Famagusta)',
        'Asia/Gaza' => 'hora de Europa oriental (Gaza)',
        'Asia/Hebron' => 'hora de Europa oriental (Hebron)',
        'Asia/Hong_Kong' => 'hora de Hongkong, R.A.S. de China (Hongkong)',
        'Asia/Hovd' => 'hora de Mongolia (Hovd)',
        'Asia/Irkutsk' => 'hora de Irkutsk',
        'Asia/Jakarta' => 'hora de Indonesia (Jakarta)',
        'Asia/Jayapura' => 'hora de Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'hora de Israel (Jerusalem)',
        'Asia/Kabul' => 'hora de Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'hora de Russia (Kamchatka)',
        'Asia/Karachi' => 'hora de Pakistan (Karachi)',
        'Asia/Katmandu' => 'hora de Nepal (Kathmandu)',
        'Asia/Khandyga' => 'hora de Yakutsk (Chandyga)',
        'Asia/Krasnoyarsk' => 'hora de Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'hora de Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'hora de Malaysia (Kuching)',
        'Asia/Kuwait' => 'hora de Kuwait (Kuwait)',
        'Asia/Macau' => 'hora de Macao, R.A.S. de China (Macao)',
        'Asia/Magadan' => 'hora de Magadan',
        'Asia/Makassar' => 'hora de Indonesia (Makassar)',
        'Asia/Manila' => 'hora de Philippinas (Manila)',
        'Asia/Muscat' => 'hora de Oman (Muscat)',
        'Asia/Nicosia' => 'hora de Europa oriental (Nicosia)',
        'Asia/Novokuznetsk' => 'hora de Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'hora de Novosibirsk',
        'Asia/Omsk' => 'hora de Omsk',
        'Asia/Oral' => 'hora de Kazakhstan (Oral)',
        'Asia/Phnom_Penh' => 'hora de Cambodgia (Phnom Penh)',
        'Asia/Pontianak' => 'hora de Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'hora de Corea del Nord (Pyongyang)',
        'Asia/Qatar' => 'hora de Qatar (Qatar)',
        'Asia/Qostanay' => 'hora de Kazakhstan (Qostanay)',
        'Asia/Qyzylorda' => 'hora de Kazakhstan (Qyzylorda)',
        'Asia/Rangoon' => 'hora de Myanmar (Birmania) (Yangon)',
        'Asia/Riyadh' => 'hora de Arabia Saudita (Riyadh)',
        'Asia/Saigon' => 'hora de Vietnam (Ho Chi Minh)',
        'Asia/Sakhalin' => 'hora de Sachalin',
        'Asia/Samarkand' => 'hora de Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'hora de Corea del Sud (Seoul)',
        'Asia/Shanghai' => 'hora de China (Shanghai)',
        'Asia/Singapore' => 'hora de Singapur (Singapore)',
        'Asia/Srednekolymsk' => 'hora de Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'hora de Taiwan (Taipei)',
        'Asia/Tashkent' => 'hora de Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'hora de Georgia (Tbilisi)',
        'Asia/Tehran' => 'hora de Iran (Tehran)',
        'Asia/Thimphu' => 'hora de Bhutan (Thimphu)',
        'Asia/Tokyo' => 'hora de Japon (Tokyo)',
        'Asia/Tomsk' => 'hora de Russia (Tomsk)',
        'Asia/Ulaanbaatar' => 'hora de Mongolia (Ulaanbaatar)',
        'Asia/Urumqi' => 'hora de China (Urumqi)',
        'Asia/Ust-Nera' => 'hora de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'hora de Laos (Vientiane)',
        'Asia/Vladivostok' => 'hora de Vladivostok',
        'Asia/Yakutsk' => 'hora de Yakutsk',
        'Asia/Yekaterinburg' => 'hora de Ekaterinburg',
        'Asia/Yerevan' => 'hora de Armenia (Yerevan)',
        'Atlantic/Azores' => 'hora del Azores',
        'Atlantic/Bermuda' => 'hora atlantic (Bermuda)',
        'Atlantic/Canary' => 'hora de Europa occidental (Canarias)',
        'Atlantic/Cape_Verde' => 'hora de Capo Verde (Capo Verde)',
        'Atlantic/Faeroe' => 'hora de Europa occidental (Feroe)',
        'Atlantic/Madeira' => 'hora de Europa occidental (Madeira)',
        'Atlantic/Reykjavik' => 'hora medie de Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'hora de Georgia del Sud e Insulas Sandwich Austral (South Georgia)',
        'Atlantic/St_Helena' => 'hora medie de Greenwich (St. Helena)',
        'Atlantic/Stanley' => 'hora de Insulas Falkland (Stanley)',
        'Australia/Adelaide' => 'hora de Australia (Adelaide)',
        'Australia/Brisbane' => 'hora de Australia (Brisbane)',
        'Australia/Broken_Hill' => 'hora de Australia (Broken Hill)',
        'Australia/Currie' => 'hora de Australia (Currie)',
        'Australia/Darwin' => 'hora de Australia (Darwin)',
        'Australia/Eucla' => 'hora de Australia (Eucla)',
        'Australia/Hobart' => 'hora de Australia (Hobart)',
        'Australia/Lindeman' => 'hora de Australia (Lindeman)',
        'Australia/Lord_Howe' => 'hora de Australia (Lord Howe)',
        'Australia/Melbourne' => 'hora de Australia (Melbourne)',
        'Australia/Perth' => 'hora de Australia (Perth)',
        'Australia/Sydney' => 'hora de Australia (Sydney)',
        'CST6CDT' => 'hora central',
        'EST5EDT' => 'hora del est',
        'Etc/GMT' => 'hora medie de Greenwich',
        'Etc/UTC' => 'Universal Tempore Coordinate',
        'Europe/Amsterdam' => 'hora de Europa central (Amsterdam)',
        'Europe/Andorra' => 'hora de Europa central (Andorra)',
        'Europe/Astrakhan' => 'hora de Moscova (Astrakhan)',
        'Europe/Athens' => 'hora de Europa oriental (Athenas)',
        'Europe/Belgrade' => 'hora de Europa central (Belgrado)',
        'Europe/Berlin' => 'hora de Europa central (Berlin)',
        'Europe/Bratislava' => 'hora de Europa central (Bratislava)',
        'Europe/Brussels' => 'hora de Europa central (Bruxelles)',
        'Europe/Bucharest' => 'hora de Europa oriental (Bucarest)',
        'Europe/Budapest' => 'hora de Europa central (Budapest)',
        'Europe/Busingen' => 'hora de Europa central (Büsingen)',
        'Europe/Chisinau' => 'hora de Europa oriental (Chisinau)',
        'Europe/Copenhagen' => 'hora de Europa central (Copenhagen)',
        'Europe/Dublin' => 'hora medie de Greenwich (Dublin)',
        'Europe/Gibraltar' => 'hora de Europa central (Gibraltar)',
        'Europe/Guernsey' => 'hora medie de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'hora de Europa oriental (Helsinki)',
        'Europe/Isle_of_Man' => 'hora medie de Greenwich (Insula de Man)',
        'Europe/Istanbul' => 'hora de Turchia (Istanbul)',
        'Europe/Jersey' => 'hora medie de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'hora de Europa oriental (Kaliningrad)',
        'Europe/Kiev' => 'hora de Europa oriental (Kiev)',
        'Europe/Kirov' => 'hora de Russia (Kirov)',
        'Europe/Lisbon' => 'hora de Europa occidental (Lisbona)',
        'Europe/Ljubljana' => 'hora de Europa central (Ljubljana)',
        'Europe/London' => 'hora medie de Greenwich (London)',
        'Europe/Luxembourg' => 'hora de Europa central (Luxemburg)',
        'Europe/Madrid' => 'hora de Europa central (Madrid)',
        'Europe/Malta' => 'hora de Europa central (Malta)',
        'Europe/Mariehamn' => 'hora de Europa oriental (Mariehamn)',
        'Europe/Minsk' => 'hora de Moscova (Minsk)',
        'Europe/Monaco' => 'hora de Europa central (Monaco)',
        'Europe/Moscow' => 'hora de Moscova',
        'Europe/Oslo' => 'hora de Europa central (Oslo)',
        'Europe/Paris' => 'hora de Europa central (Paris)',
        'Europe/Podgorica' => 'hora de Europa central (Podgorica)',
        'Europe/Prague' => 'hora de Europa central (Praga)',
        'Europe/Riga' => 'hora de Europa oriental (Riga)',
        'Europe/Rome' => 'hora de Europa central (Roma)',
        'Europe/Samara' => 'hora de Russia (Samara)',
        'Europe/San_Marino' => 'hora de Europa central (San Marino)',
        'Europe/Sarajevo' => 'hora de Europa central (Sarajevo)',
        'Europe/Saratov' => 'hora de Moscova (Saratov)',
        'Europe/Simferopol' => 'hora de Moscova (Simferopol)',
        'Europe/Skopje' => 'hora de Europa central (Skopje)',
        'Europe/Sofia' => 'hora de Europa oriental (Sofia)',
        'Europe/Stockholm' => 'hora de Europa central (Stockholm)',
        'Europe/Tallinn' => 'hora de Europa oriental (Tallinn)',
        'Europe/Tirane' => 'hora de Europa central (Tirana)',
        'Europe/Ulyanovsk' => 'hora de Moscova (Ulyanovsk)',
        'Europe/Uzhgorod' => 'hora de Europa oriental (Uzhgorod)',
        'Europe/Vaduz' => 'hora de Europa central (Vaduz)',
        'Europe/Vatican' => 'hora de Europa central (Vaticano)',
        'Europe/Vienna' => 'hora de Europa central (Vienna)',
        'Europe/Vilnius' => 'hora de Europa oriental (Vilnius)',
        'Europe/Volgograd' => 'hora de Volgograd',
        'Europe/Warsaw' => 'hora de Europa central (Varsovia)',
        'Europe/Zagreb' => 'hora de Europa central (Zagreb)',
        'Europe/Zaporozhye' => 'hora de Europa oriental (Zaporozhye)',
        'Europe/Zurich' => 'hora de Europa central (Zurich)',
        'Indian/Antananarivo' => 'hora de Madagascar (Antananarivo)',
        'Indian/Chagos' => 'hora de Territorio oceanic britanno-indian (Chagos)',
        'Indian/Christmas' => 'hora de Insula de Natal (Christmas)',
        'Indian/Cocos' => 'hora de Insulas Cocos (Keeling) (Cocos)',
        'Indian/Comoro' => 'hora de Comoros (Comoro)',
        'Indian/Kerguelen' => 'hora de Territorios meridional francese (Kerguelen)',
        'Indian/Mahe' => 'hora de Seychelles (Mahe)',
        'Indian/Maldives' => 'hora de Maldivas (Maldivas)',
        'Indian/Mauritius' => 'hora de Mauritio (Mauritio)',
        'Indian/Mayotte' => 'hora de Mayotte (Mayotta)',
        'Indian/Reunion' => 'hora de Reunion (Reunion)',
        'MST7MDT' => 'hora del montanias',
        'PST8PDT' => 'hora pacific',
        'Pacific/Apia' => 'hora de Samoa (Apia)',
        'Pacific/Auckland' => 'hora de Nove Zelanda (Auckland)',
        'Pacific/Bougainville' => 'hora de Papua Nove Guinea (Bougainville)',
        'Pacific/Chatham' => 'hora de Nove Zelanda (Chatham)',
        'Pacific/Easter' => 'hora de Chile (Easter)',
        'Pacific/Efate' => 'hora de Vanuatu (Efate)',
        'Pacific/Enderbury' => 'hora de Kiribati (Enderbury)',
        'Pacific/Fakaofo' => 'hora de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'hora de Fiji (Fiji)',
        'Pacific/Funafuti' => 'hora de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'hora de Ecuador (Galapagos)',
        'Pacific/Gambier' => 'hora de Polynesia francese (Gambier)',
        'Pacific/Guadalcanal' => 'hora de Insulas Solomon (Guadalcanal)',
        'Pacific/Guam' => 'hora de Guam (Guam)',
        'Pacific/Honolulu' => 'hora de Hawaii-Aleutianas (Honolulu)',
        'Pacific/Johnston' => 'hora de Hawaii-Aleutianas (Johnston)',
        'Pacific/Kiritimati' => 'hora de Kiribati (Kiritimati)',
        'Pacific/Kosrae' => 'hora de Micronesia (Kosrae)',
        'Pacific/Kwajalein' => 'hora de Insulas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'hora de Insulas Marshall (Majuro)',
        'Pacific/Marquesas' => 'hora de Polynesia francese (Marquesas)',
        'Pacific/Midway' => 'hora de Insulas peripheric del SUA (Midway)',
        'Pacific/Nauru' => 'hora de Nauru (Nauru)',
        'Pacific/Niue' => 'hora de Niue (Niue)',
        'Pacific/Norfolk' => 'hora de Insula Norfolk (Norfolk)',
        'Pacific/Noumea' => 'hora de Nove Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'hora de Samoa american (Pago Pago)',
        'Pacific/Palau' => 'hora de Palau (Palau)',
        'Pacific/Pitcairn' => 'hora de Insulas Pitcairn (Pitcairn)',
        'Pacific/Ponape' => 'hora de Micronesia (Pohnpei)',
        'Pacific/Port_Moresby' => 'hora de Papua Nove Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'hora de Insulas Cook (Rarotonga)',
        'Pacific/Saipan' => 'hora de Insulas Marianna del Nord (Saipan)',
        'Pacific/Tahiti' => 'hora de Polynesia francese (Tahiti)',
        'Pacific/Tarawa' => 'hora de Kiribati (Tarawa)',
        'Pacific/Tongatapu' => 'hora de Tonga (Tongatapu)',
        'Pacific/Truk' => 'hora de Micronesia (Chuuk)',
        'Pacific/Wake' => 'hora de Insulas peripheric del SUA (Wake)',
        'Pacific/Wallis' => 'hora de Wallis e Futuna (Wallis)',
    ],
    'Meta' => [
    ],
];
