<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arabskie',
        'Aran' => 'nastaliq',
        'Armi' => 'armi',
        'Armn' => 'ormiańskie',
        'Avst' => 'awestyjskie',
        'Bali' => 'balijskie',
        'Bamu' => 'bamun',
        'Batk' => 'batak',
        'Beng' => 'bengalskie',
        'Blis' => 'symbole Blissa',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'Braille’a',
        'Bugi' => 'bugińskie',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'zunifikowane symbole kanadyjskich autochtonów',
        'Cari' => 'karyjskie',
        'Cham' => 'czamskie',
        'Cher' => 'czirokeskie',
        'Cirt' => 'cirth',
        'Copt' => 'koptyjskie',
        'Cprt' => 'cypryjskie',
        'Cyrl' => 'cyrylica',
        'Cyrs' => 'cyrylica staro-cerkiewno-słowiańska',
        'Deva' => 'dewanagari',
        'Dsrt' => 'deseret',
        'Egyd' => 'egipskie demotyczne',
        'Egyh' => 'egipskie hieratyczne',
        'Egyp' => 'hieroglify egipskie',
        'Ethi' => 'etiopskie',
        'Geok' => 'gruzińskie chucuri',
        'Geor' => 'gruzińskie',
        'Glag' => 'głagolica',
        'Goth' => 'gotyckie',
        'Grek' => 'greckie',
        'Gujr' => 'gudżarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'chińskie z bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'chińskie',
        'Hano' => 'hanunoo',
        'Hans' => 'uproszczone',
        'Hant' => 'tradycyjne',
        'Hebr' => 'hebrajskie',
        'Hira' => 'hiragana',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'sylabariusze japońskie',
        'Hung' => 'starowęgierskie',
        'Inds' => 'indus',
        'Ital' => 'starowłoskie',
        'Jamo' => 'jamo',
        'Java' => 'jawajskie',
        'Jpan' => 'japońskie',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'charosti',
        'Khmr' => 'khmerskie',
        'Knda' => 'kannada',
        'Kore' => 'koreańskie',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laotańskie',
        'Latf' => 'łaciński - fraktura',
        'Latg' => 'łaciński - odmiana gaelicka',
        'Latn' => 'łacińskie',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'linearne A',
        'Linb' => 'linearne B',
        'Lyci' => 'likijskie',
        'Lydi' => 'lidyjskie',
        'Mand' => 'mandejskie',
        'Mani' => 'manichejskie',
        'Maya' => 'hieroglify Majów',
        'Mero' => 'meroickie',
        'Mlym' => 'malajalam',
        'Mong' => 'mongolskie',
        'Moon' => 'Moon’a',
        'Mtei' => 'meitei mayek',
        'Mymr' => 'birmańskie',
        'Nkoo' => 'n’ko',
        'Ogam' => 'ogham',
        'Olck' => 'ol ciki',
        'Orkh' => 'orchońskie',
        'Orya' => 'orija',
        'Osma' => 'osmanya',
        'Perm' => 'staropermskie',
        'Phag' => 'phags-pa',
        'Phli' => 'inskrypcyjne pahlawi',
        'Phlp' => 'pahlawi psałterzowy',
        'Phlv' => 'pahlawi książkowy',
        'Phnx' => 'fenicki',
        'Plrd' => 'fonetyczny Pollard’a',
        'Prti' => 'partyjski inskrypcyjny',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'runiczne',
        'Samr' => 'samarytański',
        'Sara' => 'sarati',
        'Saur' => 'saurashtra',
        'Sgnw' => 'pismo znakowe',
        'Shaw' => 'shawa',
        'Sinh' => 'syngaleskie',
        'Sund' => 'sundajskie',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'syryjskie',
        'Syre' => 'syriacki estrangelo',
        'Syrj' => 'syryjski (odmiana zachodnia)',
        'Syrn' => 'syryjski (odmiana wschodnia)',
        'Tagb' => 'tagbanwa',
        'Tale' => 'tai le',
        'Talu' => 'nowy tai lue',
        'Taml' => 'tamilskie',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh (berberski)',
        'Tglg' => 'tagalog',
        'Thaa' => 'taana',
        'Thai' => 'tajskie',
        'Tibt' => 'tybetańskie',
        'Ugar' => 'ugaryckie',
        'Vaii' => 'vai',
        'Visp' => 'Visible Speech',
        'Xpeo' => 'staroperskie',
        'Xsux' => 'klinowe sumero-akadyjskie',
        'Yiii' => 'yi',
        'Zinh' => 'dziedziczone',
        'Zmth' => 'notacja matematyczna',
        'Zsye' => 'emoji',
        'Zsym' => 'symbole',
        'Zxxx' => 'język bez systemu pisma',
        'Zyyy' => 'wspólne',
    ],
];
