<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвич вақти (Abidjan)',
        'Africa/Accra' => 'Гринвич вақти (Akkra)',
        'Africa/Addis_Ababa' => 'Шарқий Африка вақти (Addis-Abeba)',
        'Africa/Algiers' => 'Марказий Европа вақти (Jazoir)',
        'Africa/Asmera' => 'Шарқий Африка вақти (Asmara)',
        'Africa/Bamako' => 'Гринвич вақти (Bamako)',
        'Africa/Bangui' => 'Ғарбий Африка вақти (Bangi)',
        'Africa/Banjul' => 'Гринвич вақти (Banjul)',
        'Africa/Bissau' => 'Гринвич вақти (Bisau)',
        'Africa/Blantyre' => 'Марказий Африка вақти (Blantayr)',
        'Africa/Brazzaville' => 'Ғарбий Африка вақти (Brazzavil)',
        'Africa/Bujumbura' => 'Марказий Африка вақти (Bujumbura)',
        'Africa/Cairo' => 'Шарқий Европа вақти (Qohira)',
        'Africa/Casablanca' => 'Ғарбий Европа вақти (Kasablanka)',
        'Africa/Ceuta' => 'Марказий Европа вақти (Seuta)',
        'Africa/Conakry' => 'Гринвич вақти (Konakri)',
        'Africa/Dakar' => 'Гринвич вақти (Dakar)',
        'Africa/Dar_es_Salaam' => 'Шарқий Африка вақти (Dor-us-Salom)',
        'Africa/Djibouti' => 'Шарқий Африка вақти (Jibuti)',
        'Africa/Douala' => 'Ғарбий Африка вақти (Duala)',
        'Africa/El_Aaiun' => 'Ғарбий Европа вақти (Al-Ayun)',
        'Africa/Freetown' => 'Гринвич вақти (Fritaun)',
        'Africa/Gaborone' => 'Марказий Африка вақти (Gaborone)',
        'Africa/Harare' => 'Марказий Африка вақти (Xarare)',
        'Africa/Johannesburg' => 'Жанубий Африка вақти (Yoxannesburg)',
        'Africa/Juba' => 'Марказий Африка вақти (Juba)',
        'Africa/Kampala' => 'Шарқий Африка вақти (Kampala)',
        'Africa/Khartoum' => 'Марказий Африка вақти (Xartum)',
        'Africa/Kigali' => 'Марказий Африка вақти (Kigali)',
        'Africa/Kinshasa' => 'Ғарбий Африка вақти (Kinshasa)',
        'Africa/Lagos' => 'Ғарбий Африка вақти (Lagos)',
        'Africa/Libreville' => 'Ғарбий Африка вақти (Librevil)',
        'Africa/Lome' => 'Гринвич вақти (Lome)',
        'Africa/Luanda' => 'Ғарбий Африка вақти (Luanda)',
        'Africa/Lubumbashi' => 'Марказий Африка вақти (Lubumbashi)',
        'Africa/Lusaka' => 'Марказий Африка вақти (Lusaka)',
        'Africa/Malabo' => 'Ғарбий Африка вақти (Malabo)',
        'Africa/Maputo' => 'Марказий Африка вақти (Maputu)',
        'Africa/Maseru' => 'Жанубий Африка вақти (Maseru)',
        'Africa/Mbabane' => 'Жанубий Африка вақти (Mbabane)',
        'Africa/Mogadishu' => 'Шарқий Африка вақти (Mogadisho)',
        'Africa/Monrovia' => 'Гринвич вақти (Monroviya)',
        'Africa/Nairobi' => 'Шарқий Африка вақти (Nayrobi)',
        'Africa/Ndjamena' => 'Ғарбий Африка вақти (Ndjamena)',
        'Africa/Niamey' => 'Ғарбий Африка вақти (Niamey)',
        'Africa/Nouakchott' => 'Гринвич вақти (Nouakchott)',
        'Africa/Ouagadougou' => 'Гринвич вақти (Uagadugu)',
        'Africa/Porto-Novo' => 'Ғарбий Африка вақти (Porto-Novo)',
        'Africa/Sao_Tome' => 'Гринвич вақти (San-Tome)',
        'Africa/Tripoli' => 'Шарқий Европа вақти (Tripoli)',
        'Africa/Tunis' => 'Марказий Европа вақти (Tunis)',
        'Africa/Windhoek' => 'Марказий Африка вақти (Vindxuk)',
        'America/Adak' => 'Гавайи-алеут вақти (Adak oroli)',
        'America/Anchorage' => 'Аляска вақти (Ankorij)',
        'America/Anguilla' => 'Атлантика вақти (Angilya)',
        'America/Antigua' => 'Атлантика вақти (Antigua)',
        'America/Araguaina' => 'Бразилия вақти (Araguaina)',
        'America/Argentina/La_Rioja' => 'Аргентина вақти (La-Rioxa)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина вақти (Rio-Galyegos)',
        'America/Argentina/Salta' => 'Аргентина вақти (Salta)',
        'America/Argentina/San_Juan' => 'Аргентина вақти (San-Xuan)',
        'America/Argentina/San_Luis' => 'Аргентина вақти (San-Luis)',
        'America/Argentina/Tucuman' => 'Аргентина вақти (Tukuman)',
        'America/Argentina/Ushuaia' => 'Аргентина вақти (Ushuaya)',
        'America/Aruba' => 'Атлантика вақти (Aruba)',
        'America/Asuncion' => 'Парагвай вақти (Asunson)',
        'America/Bahia' => 'Бразилия вақти (Baiya)',
        'America/Bahia_Banderas' => 'Шимолий Америка (Bahiya-Banderas)',
        'America/Barbados' => 'Атлантика вақти (Barbados)',
        'America/Belem' => 'Бразилия вақти (Belem)',
        'America/Belize' => 'Шимолий Америка (Beliz)',
        'America/Blanc-Sablon' => 'Атлантика вақти (Blank-Sablon)',
        'America/Boa_Vista' => 'Амазонка вақти (Boa-Vista)',
        'America/Bogota' => 'Колумбия вақти (Bogota)',
        'America/Boise' => 'Шимолий Америка тоғ вақти (Boyse)',
        'America/Buenos_Aires' => 'Аргентина вақти (Buenos-Ayres)',
        'America/Cambridge_Bay' => 'Шимолий Америка тоғ вақти (Kembrij-Bey)',
        'America/Campo_Grande' => 'Амазонка вақти (Kampu-Grandi)',
        'America/Cancun' => 'Шимолий Америка шарқий вақти (Kankun)',
        'America/Caracas' => 'Венесуэла вақти (Karakas)',
        'America/Catamarca' => 'Аргентина вақти (Katamarka)',
        'America/Cayenne' => 'Француз Гвианаси вақти (Kayenna)',
        'America/Cayman' => 'Шимолий Америка шарқий вақти (Kayman orollari)',
        'America/Chicago' => 'Шимолий Америка (Chikago)',
        'America/Coral_Harbour' => 'Шимолий Америка шарқий вақти (Atikokan)',
        'America/Cordoba' => 'Аргентина вақти (Kordoba)',
        'America/Costa_Rica' => 'Шимолий Америка (Kosta-Rika)',
        'America/Creston' => 'Шимолий Америка тоғ вақти (Kreston)',
        'America/Cuiaba' => 'Амазонка вақти (Kuyaba)',
        'America/Curacao' => 'Атлантика вақти (Kyurasao)',
        'America/Danmarkshavn' => 'Гринвич вақти (Denmarksxavn)',
        'America/Dawson_Creek' => 'Шимолий Америка тоғ вақти (Douson-Krik)',
        'America/Denver' => 'Шимолий Америка тоғ вақти (Denver)',
        'America/Detroit' => 'Шимолий Америка шарқий вақти (Detroyt)',
        'America/Dominica' => 'Атлантика вақти (Dominika)',
        'America/Edmonton' => 'Шимолий Америка тоғ вақти (Edmonton)',
        'America/Eirunepe' => 'Бразилия вақти (Eyrunepe)',
        'America/El_Salvador' => 'Шимолий Америка (Salvador)',
        'America/Fort_Nelson' => 'Шимолий Америка тоғ вақти (Fort Nelson)',
        'America/Fortaleza' => 'Бразилия вақти (Fortaleza)',
        'America/Glace_Bay' => 'Атлантика вақти (Gleys-Bey)',
        'America/Godthab' => 'Ғарбий Гренландия вақти (Nuuk)',
        'America/Goose_Bay' => 'Атлантика вақти (Gus-Bey)',
        'America/Grand_Turk' => 'Шимолий Америка шарқий вақти (Grand Turk)',
        'America/Grenada' => 'Атлантика вақти (Grenada)',
        'America/Guadeloupe' => 'Атлантика вақти (Gvadelupa)',
        'America/Guatemala' => 'Шимолий Америка (Gvatemala)',
        'America/Guayaquil' => 'Эквадор вақти (Guayakil)',
        'America/Guyana' => 'Гайана вақти (Gayana)',
        'America/Halifax' => 'Атлантика вақти (Galifaks)',
        'America/Havana' => 'Куба вақти (Gavana)',
        'America/Indiana/Knox' => 'Шимолий Америка (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Шимолий Америка шарқий вақти (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Шимолий Америка шарқий вақти (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Шимолий Америка (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Шимолий Америка шарқий вақти (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Шимолий Америка шарқий вақти (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Шимолий Америка шарқий вақти (Winamac, Indiana)',
        'America/Indianapolis' => 'Шимолий Америка шарқий вақти (Indianapolis)',
        'America/Inuvik' => 'Шимолий Америка тоғ вақти (Inuvik)',
        'America/Iqaluit' => 'Шимолий Америка шарқий вақти (Ikaluit)',
        'America/Jamaica' => 'Шимолий Америка шарқий вақти (Yamayka)',
        'America/Jujuy' => 'Аргентина вақти (Jujuy)',
        'America/Juneau' => 'Аляска вақти (Juno)',
        'America/Kentucky/Monticello' => 'Шимолий Америка шарқий вақти (Monticello, Kentucky)',
        'America/Kralendijk' => 'Атлантика вақти (Kralendeyk)',
        'America/La_Paz' => 'Боливия вақти (La-Pas)',
        'America/Lima' => 'Перу вақти (Lima)',
        'America/Los_Angeles' => 'Шимолий Америка тинч океани вақти (Los-Anjeles)',
        'America/Louisville' => 'Шимолий Америка шарқий вақти (Luisvill)',
        'America/Lower_Princes' => 'Атлантика вақти (Lower Princeʼs Quarter)',
        'America/Maceio' => 'Бразилия вақти (Maseyo)',
        'America/Managua' => 'Шимолий Америка (Managua)',
        'America/Manaus' => 'Амазонка вақти (Manaus)',
        'America/Marigot' => 'Атлантика вақти (Marigo)',
        'America/Martinique' => 'Атлантика вақти (Martinika)',
        'America/Matamoros' => 'Шимолий Америка (Matamoros)',
        'America/Mendoza' => 'Аргентина вақти (Mendoza)',
        'America/Menominee' => 'Шимолий Америка (Menomini)',
        'America/Merida' => 'Шимолий Америка (Merida)',
        'America/Metlakatla' => 'Аляска вақти (Metlakatla)',
        'America/Mexico_City' => 'Шимолий Америка (Mexiko)',
        'America/Miquelon' => 'Сент-Пьер ва Микелон вақти (Mikelon)',
        'America/Moncton' => 'Атлантика вақти (Monkton)',
        'America/Monterrey' => 'Шимолий Америка (Monterrey)',
        'America/Montevideo' => 'Уругвай вақти (Montevideo)',
        'America/Montreal' => 'Канада вақти (Montreal)',
        'America/Montserrat' => 'Атлантика вақти (Montserrat)',
        'America/Nassau' => 'Шимолий Америка шарқий вақти (Nassau)',
        'America/New_York' => 'Шимолий Америка шарқий вақти (Nyu-York)',
        'America/Nipigon' => 'Шимолий Америка шарқий вақти (Nipigon)',
        'America/Nome' => 'Аляска вақти (Nom)',
        'America/Noronha' => 'Фернандо де Норонья вақти (Noronya)',
        'America/North_Dakota/Beulah' => 'Шимолий Америка (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Шимолий Америка (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Шимолий Америка (New Salem, North Dakota)',
        'America/Ojinaga' => 'Шимолий Америка тоғ вақти (Oxinaga)',
        'America/Panama' => 'Шимолий Америка шарқий вақти (Panama)',
        'America/Pangnirtung' => 'Шимолий Америка шарқий вақти (Pangnirtang)',
        'America/Paramaribo' => 'Суринам вақти (Paramaribo)',
        'America/Phoenix' => 'Шимолий Америка тоғ вақти (Feniks)',
        'America/Port-au-Prince' => 'Шимолий Америка шарқий вақти (Port-o-Prens)',
        'America/Port_of_Spain' => 'Атлантика вақти (Port-of-Speyn)',
        'America/Porto_Velho' => 'Амазонка вақти (Portu-Velyu)',
        'America/Puerto_Rico' => 'Атлантика вақти (Puerto-Riko)',
        'America/Punta_Arenas' => 'Чили вақти (Punta-Arenas)',
        'America/Rainy_River' => 'Шимолий Америка (Reyni-River)',
        'America/Rankin_Inlet' => 'Шимолий Америка (Rankin-Inlet)',
        'America/Recife' => 'Бразилия вақти (Resifi)',
        'America/Regina' => 'Шимолий Америка (Rejayna)',
        'America/Resolute' => 'Шимолий Америка (Rezolyut)',
        'America/Rio_Branco' => 'Бразилия вақти (Riu-Branku)',
        'America/Santarem' => 'Бразилия вақти (Santarem)',
        'America/Santiago' => 'Чили вақти (Santyago)',
        'America/Santo_Domingo' => 'Атлантика вақти (Santo-Domingo)',
        'America/Sao_Paulo' => 'Бразилия вақти (San-Paulu)',
        'America/Scoresbysund' => 'Шарқий Гренландия вақти (Ittoqqortoormiit)',
        'America/Sitka' => 'Аляска вақти (Sitka)',
        'America/St_Barthelemy' => 'Атлантика вақти (St. Barthelemy)',
        'America/St_Johns' => 'Ньюфаундленд вақти (St. John’s)',
        'America/St_Kitts' => 'Атлантика вақти (St. Kitts)',
        'America/St_Lucia' => 'Атлантика вақти (St. Lucia)',
        'America/St_Thomas' => 'Атлантика вақти (St. Thomas)',
        'America/St_Vincent' => 'Атлантика вақти (St. Vincent)',
        'America/Swift_Current' => 'Шимолий Америка (Svift-Karrent)',
        'America/Tegucigalpa' => 'Шимолий Америка (Tegusigalpa)',
        'America/Thule' => 'Атлантика вақти (Tule)',
        'America/Thunder_Bay' => 'Шимолий Америка шарқий вақти (Tander-Bey)',
        'America/Tijuana' => 'Шимолий Америка тинч океани вақти (Tixuana)',
        'America/Toronto' => 'Шимолий Америка шарқий вақти (Toronto)',
        'America/Tortola' => 'Атлантика вақти (Tortola)',
        'America/Vancouver' => 'Шимолий Америка тинч океани вақти (Vankuver)',
        'America/Winnipeg' => 'Шимолий Америка (Vinnipeg)',
        'America/Yakutat' => 'Аляска вақти (Yakutat)',
        'America/Yellowknife' => 'Шимолий Америка тоғ вақти (Yellounayf)',
        'Antarctica/Casey' => 'Антарктида вақти (Keysi)',
        'Antarctica/Davis' => 'Дэвис вақти (Deyvis)',
        'Antarctica/DumontDUrville' => 'Думонт-д-Урвил вақти (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'Шарқий Австралия вақти (Makkuori)',
        'Antarctica/Mawson' => 'Моувсон вақти (Mouson)',
        'Antarctica/McMurdo' => 'Янги Зеландия вақти (Mak-Merdo)',
        'Antarctica/Palmer' => 'Чили вақти (Palmer)',
        'Antarctica/Rothera' => 'Ротера вақти (Rotera)',
        'Antarctica/Syowa' => 'Сьова вақти (Syova)',
        'Antarctica/Troll' => 'Гринвич вақти (Troll)',
        'Antarctica/Vostok' => 'Восток вақти (Vostok)',
        'Arctic/Longyearbyen' => 'Марказий Европа вақти (Longyir)',
        'Asia/Aden' => 'Арабистон вақти (Adan)',
        'Asia/Almaty' => 'Шарқий Қозоғистон вақти (Almati)',
        'Asia/Amman' => 'Шарқий Европа вақти (Ammon)',
        'Asia/Anadyr' => 'Россия вақти (Anadir)',
        'Asia/Aqtau' => 'Ғарбий Қозоғистон вақти (Oqtov)',
        'Asia/Aqtobe' => 'Ғарбий Қозоғистон вақти (Oqto‘ba)',
        'Asia/Ashgabat' => 'Туркманистон вақти (Ashxobod)',
        'Asia/Atyrau' => 'Ғарбий Қозоғистон вақти (Atirau)',
        'Asia/Baghdad' => 'Арабистон вақти (Bag‘dod)',
        'Asia/Bahrain' => 'Арабистон вақти (Bahrayn)',
        'Asia/Baku' => 'Озарбайжон вақти (Boku)',
        'Asia/Bangkok' => 'Ҳинд-Хитой вақти (Bangkok)',
        'Asia/Barnaul' => 'Россия вақти (Barnaul)',
        'Asia/Beirut' => 'Шарқий Европа вақти (Bayrut)',
        'Asia/Bishkek' => 'Қирғизистон вақти (Bishkek)',
        'Asia/Brunei' => 'Бруней Даруссалом вақти (Bruney)',
        'Asia/Calcutta' => 'Ҳиндистон вақти (Kolkata)',
        'Asia/Chita' => 'Якутск вақти (Chita)',
        'Asia/Choibalsan' => 'Улан-Батор вақти (Choybalsan)',
        'Asia/Colombo' => 'Ҳиндистон вақти (Kolombo)',
        'Asia/Damascus' => 'Шарқий Европа вақти (Damashq)',
        'Asia/Dhaka' => 'Бангладеш вақти (Dakka)',
        'Asia/Dili' => 'Шарқий Тимор вақти (Dili)',
        'Asia/Dubai' => 'Кўрфаз вақти (Dubay)',
        'Asia/Dushanbe' => 'Тожикистон вақти (Dushanbe)',
        'Asia/Famagusta' => 'Шарқий Европа вақти (Famagusta)',
        'Asia/Gaza' => 'Шарқий Европа вақти (G‘azo)',
        'Asia/Hebron' => 'Шарқий Европа вақти (Xevron)',
        'Asia/Hong_Kong' => 'Гонконг вақти (Gonkong)',
        'Asia/Hovd' => 'Ховд вақти (Xovd)',
        'Asia/Irkutsk' => 'Иркутск вақти (Irkutsk)',
        'Asia/Jakarta' => 'Ғарбий Индонезия вақти (Jakarta)',
        'Asia/Jayapura' => 'Шарқий Индонезия вақти (Jaypur)',
        'Asia/Jerusalem' => 'Исроил вақти (Quddus)',
        'Asia/Kabul' => 'Афғонистон вақти (Qobul)',
        'Asia/Kamchatka' => 'Россия вақти (Kamchatka)',
        'Asia/Karachi' => 'Покистон вақти (Karachi)',
        'Asia/Katmandu' => 'Непал вақти (Kathmandu)',
        'Asia/Khandyga' => 'Якутск вақти (Xandiga)',
        'Asia/Krasnoyarsk' => 'Красноярск вақти (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Малайзия вақти (Kuala-Lumpur)',
        'Asia/Kuching' => 'Малайзия вақти (Kuching)',
        'Asia/Kuwait' => 'Арабистон вақти (Quvayt)',
        'Asia/Macau' => 'Хитой вақти (Makao)',
        'Asia/Magadan' => 'Магадан вақти (Magadan)',
        'Asia/Makassar' => 'Марказий Индонезия вақти (Makasar)',
        'Asia/Manila' => 'Филиппин вақти (Manila)',
        'Asia/Muscat' => 'Кўрфаз вақти (Maskat)',
        'Asia/Nicosia' => 'Шарқий Европа вақти (Nikosiya)',
        'Asia/Novokuznetsk' => 'Красноярск вақти (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Новосибирск вақти (Novosibirsk)',
        'Asia/Omsk' => 'Омск вақти (Omsk)',
        'Asia/Oral' => 'Ғарбий Қозоғистон вақти (Uralsk)',
        'Asia/Phnom_Penh' => 'Ҳинд-Хитой вақти (Pnompen)',
        'Asia/Pontianak' => 'Ғарбий Индонезия вақти (Pontianak)',
        'Asia/Pyongyang' => 'Корея вақти (Pxenyan)',
        'Asia/Qatar' => 'Арабистон вақти (Qatar)',
        'Asia/Qostanay' => 'Шарқий Қозоғистон вақти (Kustanay)',
        'Asia/Qyzylorda' => 'Ғарбий Қозоғистон вақти (Qizilo‘rda)',
        'Asia/Rangoon' => 'Мьянма вақти (Rangun)',
        'Asia/Riyadh' => 'Арабистон вақти (Ar-Riyod)',
        'Asia/Saigon' => 'Ҳинд-Хитой вақти (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Сахалин вақти (Saxalin)',
        'Asia/Samarkand' => 'Ўзбекистон вақти (Samarqand)',
        'Asia/Seoul' => 'Корея вақти (Seul)',
        'Asia/Shanghai' => 'Хитой вақти (Shanxay)',
        'Asia/Singapore' => 'Сингапур вақти (Singapur)',
        'Asia/Srednekolymsk' => 'Магадан вақти (Srednekolimsk)',
        'Asia/Taipei' => 'Тайпей вақти (Taypey)',
        'Asia/Tashkent' => 'Ўзбекистон вақти (Toshkent)',
        'Asia/Tbilisi' => 'Грузия вақти (Tbilisi)',
        'Asia/Tehran' => 'Эрон вақти (Tehron)',
        'Asia/Thimphu' => 'Бутан вақти (Thimphu)',
        'Asia/Tokyo' => 'Япония вақти (Tokio)',
        'Asia/Tomsk' => 'Россия вақти (Tomsk)',
        'Asia/Ulaanbaatar' => 'Улан-Батор вақти (Ulan-Bator)',
        'Asia/Urumqi' => 'Хитой вақти (Urumchi)',
        'Asia/Ust-Nera' => 'Владивосток вақти (Ust-Nera)',
        'Asia/Vientiane' => 'Ҳинд-Хитой вақти (Vyentyan)',
        'Asia/Vladivostok' => 'Владивосток вақти (Vladivostok)',
        'Asia/Yakutsk' => 'Якутск вақти (Yakutsk)',
        'Asia/Yekaterinburg' => 'Екатеринбург вақти (Yekaterinburg)',
        'Asia/Yerevan' => 'Арамнистон вақти (Yerevan)',
        'Atlantic/Azores' => 'Азор вақти (Azor orollari)',
        'Atlantic/Bermuda' => 'Атлантика вақти (Bermuda orollari)',
        'Atlantic/Canary' => 'Ғарбий Европа вақти (Kanar orollari)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде вақти (Kabo-Verde)',
        'Atlantic/Faeroe' => 'Ғарбий Европа вақти (Faroe)',
        'Atlantic/Madeira' => 'Ғарбий Европа вақти (Madeyra oroli)',
        'Atlantic/Reykjavik' => 'Гринвич вақти (Reykyavik)',
        'Atlantic/South_Georgia' => 'Жанубий Джорджия вақти (Janubiy Georgiya)',
        'Atlantic/St_Helena' => 'Гринвич вақти (St. Helena)',
        'Atlantic/Stanley' => 'Фолькленд ороллари вақти (Stenli)',
        'Australia/Adelaide' => 'Марказий Австралия вақти (Adelaida)',
        'Australia/Brisbane' => 'Шарқий Австралия вақти (Brisben)',
        'Australia/Broken_Hill' => 'Марказий Австралия вақти (Broken-Xill)',
        'Australia/Currie' => 'Шарқий Австралия вақти (Kerri)',
        'Australia/Darwin' => 'Марказий Австралия вақти (Darvin)',
        'Australia/Eucla' => 'Марказий Австралия Ғарбий вақти (Evkla)',
        'Australia/Hobart' => 'Шарқий Австралия вақти (Xobart)',
        'Australia/Lindeman' => 'Шарқий Австралия вақти (Lindeman)',
        'Australia/Lord_Howe' => 'Лорд Хове вақти (Lord-Xau oroli)',
        'Australia/Melbourne' => 'Шарқий Австралия вақти (Melburn)',
        'Australia/Perth' => 'Ғарбий Австралия вақти (Pert)',
        'Australia/Sydney' => 'Шарқий Австралия вақти (Sidney)',
        'CST6CDT' => 'Шимолий Америка',
        'EST5EDT' => 'Шимолий Америка шарқий вақти',
        'Etc/GMT' => 'Гринвич вақти',
        'Europe/Amsterdam' => 'Марказий Европа вақти (Amsterdam)',
        'Europe/Andorra' => 'Марказий Европа вақти (Andorra)',
        'Europe/Astrakhan' => 'Москва вақти (Astraxan)',
        'Europe/Athens' => 'Шарқий Европа вақти (Afina)',
        'Europe/Belgrade' => 'Марказий Европа вақти (Belgrad)',
        'Europe/Berlin' => 'Марказий Европа вақти (Berlin)',
        'Europe/Bratislava' => 'Марказий Европа вақти (Bratislava)',
        'Europe/Brussels' => 'Марказий Европа вақти (Bryussel)',
        'Europe/Bucharest' => 'Шарқий Европа вақти (Buxarest)',
        'Europe/Budapest' => 'Марказий Европа вақти (Budapesht)',
        'Europe/Busingen' => 'Марказий Европа вақти (Byuzingen)',
        'Europe/Chisinau' => 'Шарқий Европа вақти (Kishinyov)',
        'Europe/Copenhagen' => 'Марказий Европа вақти (Kopengagen)',
        'Europe/Dublin' => 'Гринвич вақти (Dublin)',
        'Europe/Gibraltar' => 'Марказий Европа вақти (Gibraltar)',
        'Europe/Guernsey' => 'Гринвич вақти (Gernsi)',
        'Europe/Helsinki' => 'Шарқий Европа вақти (Xelsinki)',
        'Europe/Isle_of_Man' => 'Гринвич вақти (Men oroli)',
        'Europe/Istanbul' => 'Туркия вақти (Istanbul)',
        'Europe/Jersey' => 'Гринвич вақти (Jersi)',
        'Europe/Kaliningrad' => 'Шарқий Европа вақти (Kaliningrad)',
        'Europe/Kiev' => 'Шарқий Европа вақти (Kiyev)',
        'Europe/Kirov' => 'Россия вақти (Kirov)',
        'Europe/Lisbon' => 'Ғарбий Европа вақти (Lissabon)',
        'Europe/Ljubljana' => 'Марказий Европа вақти (Lyublyana)',
        'Europe/London' => 'Гринвич вақти (London)',
        'Europe/Luxembourg' => 'Марказий Европа вақти (Lyuksemburg)',
        'Europe/Madrid' => 'Марказий Европа вақти (Madrid)',
        'Europe/Malta' => 'Марказий Европа вақти (Malta)',
        'Europe/Mariehamn' => 'Шарқий Европа вақти (Mariyexamn)',
        'Europe/Minsk' => 'Москва вақти (Minsk)',
        'Europe/Monaco' => 'Марказий Европа вақти (Monako)',
        'Europe/Moscow' => 'Москва вақти (Moskva)',
        'Europe/Oslo' => 'Марказий Европа вақти (Oslo)',
        'Europe/Paris' => 'Марказий Европа вақти (Parij)',
        'Europe/Podgorica' => 'Марказий Европа вақти (Podgoritsa)',
        'Europe/Prague' => 'Марказий Европа вақти (Praga)',
        'Europe/Riga' => 'Шарқий Европа вақти (Riga)',
        'Europe/Rome' => 'Марказий Европа вақти (Rim)',
        'Europe/Samara' => 'Россия вақти (Samara)',
        'Europe/San_Marino' => 'Марказий Европа вақти (San-Marino)',
        'Europe/Sarajevo' => 'Марказий Европа вақти (Sarayevo)',
        'Europe/Saratov' => 'Москва вақти (Saratov)',
        'Europe/Simferopol' => 'Москва вақти (Simferopol)',
        'Europe/Skopje' => 'Марказий Европа вақти (Skopye)',
        'Europe/Sofia' => 'Шарқий Европа вақти (Sofiya)',
        'Europe/Stockholm' => 'Марказий Европа вақти (Stokgolm)',
        'Europe/Tallinn' => 'Шарқий Европа вақти (Tallin)',
        'Europe/Tirane' => 'Марказий Европа вақти (Tirana)',
        'Europe/Ulyanovsk' => 'Москва вақти (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Шарқий Европа вақти (Ujgorod)',
        'Europe/Vaduz' => 'Марказий Европа вақти (Vaduts)',
        'Europe/Vatican' => 'Марказий Европа вақти (Vatikan)',
        'Europe/Vienna' => 'Марказий Европа вақти (Vena)',
        'Europe/Vilnius' => 'Шарқий Европа вақти (Vilnyus)',
        'Europe/Volgograd' => 'Волгоград вақти (Volgograd)',
        'Europe/Warsaw' => 'Марказий Европа вақти (Varshava)',
        'Europe/Zagreb' => 'Марказий Европа вақти (Zagreb)',
        'Europe/Zaporozhye' => 'Шарқий Европа вақти (Zaporojye)',
        'Europe/Zurich' => 'Марказий Европа вақти (Syurix)',
        'Indian/Antananarivo' => 'Шарқий Африка вақти (Antananarivu)',
        'Indian/Chagos' => 'Ҳинд океани вақти (Chagos)',
        'Indian/Christmas' => 'Рождество ороли вақти (Rojdestvo oroli)',
        'Indian/Cocos' => 'Кокос ороллари вақти (Kokos orollari)',
        'Indian/Comoro' => 'Шарқий Африка вақти (Komor orollari)',
        'Indian/Kerguelen' => 'Француз жанубий ва Антарктика вақти (Kergelen)',
        'Indian/Mahe' => 'Сейшел ороллари вақти (Mae)',
        'Indian/Maldives' => 'Мальдив ороллар (Maldiv orollari)',
        'Indian/Mauritius' => 'Маврикий вақти (Mavrikiy)',
        'Indian/Mayotte' => 'Шарқий Африка вақти (Mayorka)',
        'Indian/Reunion' => 'Реюньон вақти (Reyunion)',
        'MST7MDT' => 'Шимолий Америка тоғ вақти',
        'PST8PDT' => 'Шимолий Америка тинч океани вақти',
        'Pacific/Auckland' => 'Янги Зеландия вақти (Oklend)',
        'Pacific/Bougainville' => 'Папуа-Янги Гвинея вақти (Bugenvil)',
        'Pacific/Chatham' => 'Чатхам вақти (Chatem oroli)',
        'Pacific/Easter' => 'Пасхи Ороли вақти (Pasxa oroli)',
        'Pacific/Efate' => 'Вануату вақти (Efate)',
        'Pacific/Enderbury' => 'Феникс ороллари вақти (Enderberi oroli)',
        'Pacific/Fakaofo' => 'Токелау вақти (Fakaofo)',
        'Pacific/Fiji' => 'Фижи вақти (Fiji)',
        'Pacific/Funafuti' => 'Тувалу вақти (Funafuti)',
        'Pacific/Galapagos' => 'Галапагос вақти (Galapagos)',
        'Pacific/Gambier' => 'Гамбиер вақти (Gambye oroli)',
        'Pacific/Guadalcanal' => 'Соломон ороллари вақти (Gvadalkanal)',
        'Pacific/Guam' => 'Каморро вақти (Guam)',
        'Pacific/Honolulu' => 'Гавайи-алеут вақти (Gonolulu)',
        'Pacific/Johnston' => 'Гавайи-алеут вақти (Jonston)',
        'Pacific/Kiritimati' => 'Лайн ороллари вақти (Kiritimati)',
        'Pacific/Kosrae' => 'Косрае вақти (Kosrae)',
        'Pacific/Kwajalein' => 'Маршалл ороллари вақти (Kvajaleyn)',
        'Pacific/Majuro' => 'Маршалл ороллари вақти (Majuro)',
        'Pacific/Marquesas' => 'Маркезас вақти (Markiz orollari)',
        'Pacific/Midway' => 'Самоа вақти (Midvey orollari)',
        'Pacific/Nauru' => 'Науру вақти (Nauru)',
        'Pacific/Niue' => 'Ниуе вақти (Niue)',
        'Pacific/Norfolk' => 'Норфолк ороли вақти (Norfolk)',
        'Pacific/Noumea' => 'Янги Каледония вақти (Numea)',
        'Pacific/Pago_Pago' => 'Самоа вақти (Pago-Pago)',
        'Pacific/Palau' => 'Палау вақти (Palau)',
        'Pacific/Pitcairn' => 'Питкерн вақти (Pitkern)',
        'Pacific/Ponape' => 'Понапе вақти (Pohnpei)',
        'Pacific/Port_Moresby' => 'Папуа-Янги Гвинея вақти (Port-Morsbi)',
        'Pacific/Rarotonga' => 'Кук ороллари вақти (Rarotonga)',
        'Pacific/Saipan' => 'Каморро вақти (Saypan)',
        'Pacific/Tahiti' => 'Таити вақти (Taiti oroli)',
        'Pacific/Tarawa' => 'Гилберт ороллари вақти (Tarava)',
        'Pacific/Tongatapu' => 'Тонга вақти (Tongatapu)',
        'Pacific/Truk' => 'Чуук вақти (Chuuk)',
        'Pacific/Wake' => 'Уэйк ороли вақти (Ueyk oroli)',
        'Pacific/Wallis' => 'Уэллис ва Футуна вақти (Uollis)',
    ],
    'Meta' => [
    ],
];
