<?php

return [
    'Names' => [
        'ab' => 'Èdè Abasia',
        'ace' => 'Èdè Akinisi',
        'ada' => 'Èdè Adame',
        'ady' => 'Èdè Adiji',
        'af' => 'Èdè Afrikani',
        'agq' => 'Èdè Ágẹ̀ẹ̀mù',
        'ain' => 'Èdè Ainu',
        'ak' => 'Èdè Akani',
        'ale' => 'Èdè Aleti',
        'alt' => 'Èdè Gusu Ata',
        'am' => 'Èdè Amariki',
        'an' => 'Èdè Aragoni',
        'ann' => 'Èdè Obolo',
        'anp' => 'Èdè Angika',
        'ar' => 'Èdè Árábìkì',
        'arn' => 'Èdè Mapushe',
        'arp' => 'Èdè Arapaho',
        'ars' => 'Èdè Arabiki ti Najidi',
        'as' => 'Èdè Ti Assam',
        'asa' => 'Èdè Asu',
        'ast' => 'Èdè Asturian',
        'atj' => 'Èdè Atikameki',
        'av' => 'Èdè Afariki',
        'awa' => 'Èdè Awadi',
        'ay' => 'Èdè Amara',
        'az' => 'Èdè Azerbaijani',
        'ba' => 'Èdè Bashiri',
        'ban' => 'Èdè Balini',
        'bas' => 'Èdè Basaa',
        'be' => 'Èdè Belarusi',
        'bem' => 'Èdè Béḿbà',
        'bez' => 'Èdè Bẹ́nà',
        'bg' => 'Èdè Bugaria',
        'bho' => 'Èdè Bojuri',
        'bi' => 'Èdè Bisilama',
        'bin' => 'Èdè Bini',
        'bla' => 'Èdè Sikiska',
        'bm' => 'Èdè Báḿbàrà',
        'bn' => 'Èdè Bengali',
        'bo' => 'Tibetán',
        'br' => 'Èdè Bretoni',
        'brx' => 'Èdè Bódò',
        'bs' => 'Èdè Bosnia',
        'bug' => 'Èdè Bugini',
        'byn' => 'Èdè Bilini',
        'ca' => 'Èdè Catala',
        'cay' => 'Èdè Kayuga',
        'ccp' => 'Èdè Chakma',
        'ce' => 'Èdè Chechen',
        'ceb' => 'Èdè Cebuano',
        'cgg' => 'Èdè Chiga',
        'ch' => 'Èdè S̩amoro',
        'chk' => 'Èdè Shuki',
        'chm' => 'Èdè Mari',
        'cho' => 'Èdè Shokita',
        'chp' => 'Èdè Shipewa',
        'chr' => 'Èdè Shẹ́rókiì',
        'chy' => 'Èdè Sheyeni',
        'ckb' => 'Ààrin Gbùngbùn Kurdish',
        'clc' => 'Èdè Shikoti',
        'co' => 'Èdè Corsican',
        'crg' => 'Èdè Misifu',
        'crj' => 'Èdè Gusu Ila-oorun Kri',
        'crk' => 'Èdè Papa Kri',
        'crl' => 'Èdè ti Ila oorun Ariwa Kri',
        'crm' => 'Èdè Moose Kri',
        'crr' => 'Èdè Alonkuia ti Karolina',
        'cs' => 'Èdè Seeki',
        'csw' => 'Èdè Swampi Kri',
        'cu' => 'Èdè Síláfííkì Ilé Ìjọ́sìn',
        'cv' => 'Èdè Shufasi',
        'cy' => 'Èdè Welshi',
        'da' => 'Èdè Ilẹ̀ Denmark',
        'dak' => 'Èdè Dakota',
        'dar' => 'Èdè Dagiwa',
        'dav' => 'Táítà',
        'de' => 'Èdè Jámánì',
        'dgr' => 'Èdè Dogribu',
        'dje' => 'Ṣárúmà',
        'doi' => 'Èdè Dogiri',
        'dsb' => 'Ṣóbíánù Apá Ìṣàlẹ̀',
        'dua' => 'Èdè Duala',
        'dv' => 'Èdè Difehi',
        'dyo' => 'Jola-Fonyi',
        'dz' => 'Èdè Dzongkha',
        'dzg' => 'Èdè Dasaga',
        'ebu' => 'Èdè Ẹmbù',
        'ee' => 'Èdè Ewè',
        'efi' => 'Èdè Efiki',
        'eka' => 'Èdè Ekaju',
        'el' => 'Èdè Giriki',
        'en' => 'Èdè Gẹ̀ẹ́sì',
        'eo' => 'Èdè Esperanto',
        'es' => 'Èdè Sípáníìṣì',
        'et' => 'Èdè Estonia',
        'eu' => 'Èdè Baski',
        'ewo' => 'Èdè Èwóǹdò',
        'fa' => 'Èdè Pasia',
        'ff' => 'Èdè Fúlàní',
        'fi' => 'Èdè Finisi',
        'fil' => 'Èdè Filipino',
        'fj' => 'Èdè Fiji',
        'fo' => 'Èdè Faroesi',
        'fon' => 'Èdè Fon',
        'fr' => 'Èdè Faransé',
        'frc' => 'Èdè Faranse ti Kajun',
        'frr' => 'Èdè Ariwa Frisa',
        'fur' => 'Firiúlíànì',
        'fy' => 'Èdè Frisia',
        'ga' => 'Èdè Ireland',
        'gaa' => 'Èdè Gaa',
        'gd' => 'Èdè Gaelik ti Ilu Scotland',
        'gez' => 'Ede Gẹ́sì',
        'gil' => 'Èdè Gibaati',
        'gl' => 'Èdè Galicia',
        'gn' => 'Èdè Guarani',
        'gor' => 'Èdè Gorontalo',
        'gsw' => 'Súwísì ti Jámánì',
        'gu' => 'Èdè Gujarati',
        'guz' => 'Gusii',
        'gv' => 'Máǹkì',
        'gwi' => 'Èdè giwisi',
        'ha' => 'Èdè Hausa',
        'hai' => 'Èdè Haida',
        'haw' => 'Hawaiian',
        'hax' => 'Èdè Gusu Haida',
        'he' => 'Èdè Heberu',
        'hi' => 'Èdè Híńdì',
        'hil' => 'Èdè Hilgayo',
        'hmn' => 'Hmong',
        'hr' => 'Èdè Kroatia',
        'hsb' => 'Sorbian Apá Òkè',
        'ht' => 'Haitian Creole',
        'hu' => 'Èdè Hungaria',
        'hup' => 'Èdè Hupa',
        'hur' => 'Èdè Hakomelemi',
        'hy' => 'Èdè Ile Armenia',
        'hz' => 'Èdè Herero',
        'ia' => 'Èdè pipo',
        'iba' => 'Èdè Iba',
        'ibb' => 'Èdè Ibibio',
        'id' => 'Èdè Indonéṣíà',
        'ie' => 'Iru Èdè',
        'ig' => 'Èdè Yíbò',
        'ii' => 'Ṣíkuán Yì',
        'ikt' => 'Èdè Iwoorun Inutitu ti Kanada',
        'ilo' => 'Èdè Iloko',
        'inh' => 'Èdè Ingusi',
        'io' => 'Èdè Ido',
        'is' => 'Èdè Icelandic',
        'it' => 'Èdè Ítálì',
        'iu' => 'Èdè Inukitu',
        'ja' => 'Èdè Jàpáànù',
        'jbo' => 'Èdè Lobani',
        'jgo' => 'Ńgòmbà',
        'jmc' => 'Máṣámè',
        'jv' => 'Èdè Javanasi',
        'ka' => 'Èdè Georgia',
        'kab' => 'Kabilè',
        'kac' => 'Èdè Kashini',
        'kaj' => 'Èdè Ju',
        'kam' => 'Káńbà',
        'kbd' => 'Èdè Kabadia',
        'kcg' => 'Èdè Tiyapu',
        'kde' => 'Mákondé',
        'kea' => 'Kabufadíánù',
        'kfo' => 'Èdè Koro',
        'kgp' => 'Èdè Kaigani',
        'kha' => 'Èdè Kasi',
        'khq' => 'Koira Ṣíínì',
        'ki' => 'Kíkúyù',
        'kj' => 'Èdè Kuayama',
        'kk' => 'Kaṣakì',
        'kkj' => 'Kàkó',
        'kl' => 'Kalaalísùtì',
        'kln' => 'Kálẹnjín',
        'km' => 'Èdè kameri',
        'kmb' => 'Èdè Kimbundu',
        'kn' => 'Èdè Kannada',
        'ko' => 'Èdè Kòríà',
        'kok' => 'Kónkánì',
        'kpe' => 'Èdè Pele',
        'kr' => 'Èdè Kanuri',
        'krc' => 'Èdè Karasha-Baka',
        'krl' => 'Èdè Karelia',
        'kru' => 'Èdè Kuruki',
        'ks' => 'Kaṣímirì',
        'ksb' => 'Ṣáńbálà',
        'ksf' => 'Èdè Báfíà',
        'ksh' => 'Èdè Colognian',
        'ku' => 'Kọdiṣì',
        'kum' => 'Èdè Kumiki',
        'kv' => 'Èdè Komi',
        'kw' => 'Èdè Kọ́nììṣì',
        'kwk' => 'Èdè Kwawala',
        'ky' => 'Kírígíìsì',
        'la' => 'Èdè Latini',
        'lad' => 'Èdè Ladino',
        'lag' => 'Láńgì',
        'lb' => 'Lùṣẹ́mbọ́ọ̀gì',
        'lez' => 'Èdè Lesgina',
        'lg' => 'Ganda',
        'li' => 'Èdè Limbogishi',
        'lil' => 'Èdè Liloeti',
        'lkt' => 'Lákota',
        'ln' => 'Lìǹgálà',
        'lo' => 'Láò',
        'lou' => 'Èdè Kreoli ti Louisiana',
        'loz' => 'Èdè Lozi',
        'lrc' => 'Apáàríwá Lúrì',
        'lsm' => 'Èdè Samia',
        'lt' => 'Èdè Lithuania',
        'lu' => 'Lúbà-Katanga',
        'lua' => 'Èdè Luba Lulua',
        'lun' => 'Èdè Lunda',
        'lus' => 'Èdè Miso',
        'luy' => 'Luyíà',
        'lv' => 'Èdè Latvianu',
        'mad' => 'Èdè Maduri',
        'mag' => 'Èdè Magahi',
        'mai' => 'Èdè Matihi',
        'mak' => 'Èdè Makasa',
        'mas' => 'Másáì',
        'mdf' => 'Èdè Mokisa',
        'men' => 'Èdè Mende',
        'mer' => 'Mérù',
        'mfe' => 'Morisiyen',
        'mg' => 'Malagasì',
        'mgh' => 'Makhuwa-Meeto',
        'mgo' => 'Métà',
        'mh' => 'Èdè Mashali',
        'mi' => 'Màórì',
        'mic' => 'Èdè Mikmaki',
        'min' => 'Èdè Minakabau',
        'mk' => 'Èdè Macedonia',
        'ml' => 'Málàyálámù',
        'mn' => 'Mòngólíà',
        'mni' => 'Èdè Manipuri',
        'moe' => 'Èdè Inuamu',
        'moh' => 'Èdè Mohaki',
        'mos' => 'Èdè Mosi',
        'mr' => 'Èdè marathi',
        'ms' => 'Èdè Malaya',
        'mt' => 'Èdè Malta',
        'mua' => 'Múndàngì',
        'mus' => 'Èdè Muskogi',
        'mwl' => 'Èdè Mirandisi',
        'my' => 'Èdè Bumiisi',
        'myv' => 'Èdè Esiya',
        'mzn' => 'Masanderani',
        'na' => 'Èdè Nauru',
        'nap' => 'Èdè Neapolita',
        'naq' => 'Námà',
        'nb' => 'Nọ́ọ́wè Bokímàl',
        'nd' => 'Àríwá Ndebele',
        'nds' => 'Jámánì ìpìlẹ̀',
        'ne' => 'Èdè Nepali',
        'new' => 'Èdè Newari',
        'ng' => 'Èdè Ndonga',
        'nia' => 'Èdè Nia',
        'niu' => 'Èdè Niu',
        'nl' => 'Èdè Dọ́ọ̀ṣì',
        'nmg' => 'Kíwáṣíò',
        'nn' => 'Nọ́ọ́wè Nínọ̀sìkì',
        'nnh' => 'Ngiembùnù',
        'no' => 'Èdè Norway',
        'nog' => 'Èdè Nogai',
        'nqo' => 'Èdè Nko',
        'nr' => 'Èdè Gusu Ndebele',
        'nso' => 'Èdè Ariwa Soto',
        'nus' => 'Núẹ̀',
        'nv' => 'Èdè Nafajo',
        'ny' => 'Ńyájà',
        'nyn' => 'Ńyákọ́lè',
        'oc' => 'Èdè Occitani',
        'ojb' => 'Èdè Ariwa-iwoorun Ojibwa',
        'ojc' => 'Èdè Ojibwa Aarin',
        'ojs' => 'Èdè Oji Kri',
        'ojw' => 'Èdè Iwoorun Ojibwa',
        'oka' => 'Èdè Okanaga',
        'om' => 'Òròmọ́',
        'or' => 'Òdíà',
        'os' => 'Ọṣẹ́tíìkì',
        'pa' => 'Èdè Punjabi',
        'pag' => 'Èdè Pangasina',
        'pam' => 'Èdè Pampanga',
        'pap' => 'Èdè Papiamento',
        'pau' => 'Èdè Pala',
        'pcm' => 'Èdè Pijini ti Naijiriya',
        'pis' => 'Èdè Piji',
        'pl' => 'Èdè Póláǹdì',
        'pqm' => 'Èdè Maliseti-Pasamkodi',
        'prg' => 'Púrúṣíànù',
        'ps' => 'Páshítò',
        'pt' => 'Èdè Pọtogí',
        'qu' => 'Kúẹ́ńjùà',
        'rap' => 'Èdè Rapanu',
        'rar' => 'Èdè Rarotonga',
        'rhg' => 'Èdè Rohinga',
        'rm' => 'Rómáǹṣì',
        'rn' => 'Rúńdì',
        'ro' => 'Èdè Romania',
        'rof' => 'Róńbò',
        'ru' => 'Èdè Rọ́ṣíà',
        'rup' => 'Èdè Aromani',
        'rw' => 'Èdè Ruwanda',
        'rwk' => 'Riwa',
        'sa' => 'Èdè awon ara Indo',
        'sad' => 'Èdè Sandawe',
        'sah' => 'Sàkíhà',
        'saq' => 'Samburu',
        'sat' => 'Èdè Santali',
        'sba' => 'Èdè Ngambayi',
        'sbp' => 'Sangu',
        'sc' => 'Èdè Sadini',
        'scn' => 'Èdè Sikila',
        'sco' => 'Èdè Sikoti',
        'sd' => 'Èdè Sindhi',
        'se' => 'Apáàríwá Sami',
        'seh' => 'Ṣẹnà',
        'ses' => 'Koiraboro Seni',
        'sg' => 'Sango',
        'sh' => 'Èdè Serbo-Croatiani',
        'shi' => 'Taṣelíìtì',
        'shn' => 'Èdè Shani',
        'si' => 'Èdè Sinhalese',
        'sk' => 'Èdè Slovaki',
        'sl' => 'Èdè Slovenia',
        'slh' => 'Èdè Gusu Lushootseed',
        'sm' => 'Sámóánù',
        'smn' => 'Inari Sami',
        'sms' => 'Èdè Sikoti Smi',
        'sn' => 'Ṣọnà',
        'snk' => 'Èdè Sonike',
        'so' => 'Èdè ara Somalia',
        'sq' => 'Èdè Albania',
        'sr' => 'Èdè Serbia',
        'srn' => 'Èdè Sirana Tongo',
        'ss' => 'Èdè Suwati',
        'st' => 'Èdè Sesoto',
        'str' => 'Èdè Sitirati Salisi',
        'su' => 'Èdè Sudanísì',
        'suk' => 'Èdè Sukuma',
        'sv' => 'Èdè Suwidiisi',
        'sw' => 'Èdè Swahili',
        'swb' => 'Èdè Komora',
        'syr' => 'Èdè Siriaki',
        'ta' => 'Èdè Tamili',
        'tce' => 'Èdè Gusu Tushoni',
        'te' => 'Èdè Telugu',
        'tem' => 'Èdè Timne',
        'teo' => 'Tẹ́sò',
        'tet' => 'Èdè Tetum',
        'tg' => 'Tàjíìkì',
        'tgx' => 'Èdè Tagisi',
        'th' => 'Èdè Tai',
        'tht' => 'Èdè Tajiti',
        'ti' => 'Èdè Tigrinya',
        'tig' => 'Èdè Tigre',
        'tk' => 'Èdè Turkmen',
        'tlh' => 'Èdè Klingoni',
        'tli' => 'Èdè Tlingiti',
        'tn' => 'Èdè Suwana',
        'to' => 'Tóńgàn',
        'tok' => 'Èdè Toki Pona',
        'tpi' => 'Èdè Tok Pisini',
        'tr' => 'Èdè Tọọkisi',
        'trv' => 'Èdè Taroko',
        'ts' => 'Èdè Songa',
        'tt' => 'Tatarí',
        'ttm' => 'Èdè Ariwa Tusoni',
        'tum' => 'Èdè Tumbuka',
        'tvl' => 'Èdè Tifalu',
        'twq' => 'Tasawak',
        'ty' => 'Èdè Tahiti',
        'tyv' => 'Èdè Tuvini',
        'tzm' => 'Ààrin Gbùngbùn Atlas Tamazight',
        'udm' => 'Èdè Udmuti',
        'ug' => 'Yúgọ̀',
        'uk' => 'Èdè Ukania',
        'umb' => 'Èdè Umbundu',
        'ur' => 'Èdè Udu',
        'uz' => 'Èdè Uzbek',
        've' => 'Èdè Fenda',
        'vi' => 'Èdè Jetinamu',
        'vo' => 'Fọ́lápùùkù',
        'vun' => 'Funjo',
        'wa' => 'Èdè Waluni',
        'wae' => 'Wọsà',
        'wal' => 'Èdè Wolata',
        'war' => 'Èdè Wara',
        'wo' => 'Wọ́lọ́ọ̀fù',
        'wuu' => 'Èdè Wu ti Saina',
        'xal' => 'Èdè Kalimi',
        'xh' => 'Èdè Xhosa',
        'xog' => 'Ṣógà',
        'yav' => 'Yangbẹn',
        'ybb' => 'Èdè Yemba',
        'yi' => 'Èdè Yiddishi',
        'yo' => 'Èdè Yorùbá',
        'yrl' => 'Èdè Ningatu',
        'yue' => 'Èdè Cantonese',
        'zgh' => 'Àfẹnùkò Támásáìtì ti Mòrókò',
        'zh' => 'Edè Ṣáínà',
        'zu' => 'Èdè Ṣulu',
        'zun' => 'Èdè Suni',
        'zza' => 'Èdè Sasa',
    ],
    'LocalizedNames' => [
        'de_AT' => 'Èdè Jámánì (Ọ́síríà )',
        'de_CH' => 'Èdè Ilẹ̀ Jámánì (Orílẹ́ède swítsàlandì)',
        'en_AU' => 'Èdè Gẹ̀ẹ́sì (órílẹ̀-èdè Ọsirélíà)',
        'en_CA' => 'Èdè Gẹ̀ẹ́sì (Orílẹ̀-èdè Kánádà)',
        'en_GB' => 'Èdè òyìnbó Gẹ̀ẹ́sì',
        'es_419' => 'Èdè Sípáníìṣì (orílẹ̀-èdè Látìn-Amẹ́ríkà)',
        'es_ES' => 'Èdè Sípáníìṣì (orílẹ̀-èdè Yúróòpù)',
        'es_MX' => 'Èdè Sípáníìṣì (orílẹ̀-èdè Mẹ́síkò)',
        'fr_CA' => 'Èdè Faransé (orílẹ̀-èdè Kánádà)',
        'fr_CH' => 'Èdè Faranṣé (Súwísàlaǹdì)',
        'hi_Latn' => 'Èdè Híndì (Látìnì)',
        'pt_BR' => 'Èdè Pọtogí (Orilẹ̀-èdè Bràsíl)',
        'pt_PT' => 'Èdè Pọtogí (orílẹ̀-èdè Yúróòpù)',
        'zh_Hans' => 'Ẹdè Ṣáínà Onírọ̀rùn',
        'zh_Hant' => 'Èdè Ṣáínà Ìbílẹ̀',
    ],
];
