<?php

return [
    'Names' => [
        'aa' => 'afāru',
        'ab' => 'abhāzu',
        'ace' => 'ačinu',
        'ach' => 'ačolu',
        'ada' => 'adangmu',
        'ady' => 'adigu',
        'ae' => 'avesta',
        'af' => 'afrikandu',
        'afh' => 'afrihili',
        'agq' => 'aghemu',
        'ain' => 'ainu',
        'ak' => 'akanu',
        'akk' => 'akadiešu',
        'ale' => 'aleutu',
        'alt' => 'dienvidaltajiešu',
        'am' => 'amharu',
        'an' => 'aragoniešu',
        'ang' => 'senangļu',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arābu',
        'arc' => 'aramiešu',
        'arn' => 'araukāņu',
        'arp' => 'arapahu',
        'ars' => 'ņedžu arābu',
        'arw' => 'aravaku',
        'as' => 'asamiešu',
        'asa' => 'asu',
        'ast' => 'astūriešu',
        'atj' => 'atikameku',
        'av' => 'avāru',
        'awa' => 'avadhu',
        'ay' => 'aimaru',
        'az' => 'azerbaidžāņu',
        'ba' => 'baškīru',
        'bal' => 'beludžu',
        'ban' => 'baliešu',
        'bas' => 'basu',
        'bax' => 'bamumu',
        'bbj' => 'gomalu',
        'be' => 'baltkrievu',
        'bej' => 'bedžu',
        'bem' => 'bembu',
        'bez' => 'bena',
        'bfd' => 'bafutu',
        'bg' => 'bulgāru',
        'bgn' => 'rietumbeludžu',
        'bho' => 'bhodžpūru',
        'bi' => 'bišlamā',
        'bik' => 'bikolu',
        'bin' => 'binu',
        'bkm' => 'komu',
        'bla' => 'siksiku',
        'bm' => 'bambaru',
        'bn' => 'bengāļu',
        'bo' => 'tibetiešu',
        'br' => 'bretoņu',
        'bra' => 'bradžiešu',
        'brx' => 'bodo',
        'bs' => 'bosniešu',
        'bss' => 'nkosi',
        'bua' => 'burjatu',
        'bug' => 'bugu',
        'bum' => 'bulu',
        'byn' => 'bilinu',
        'byv' => 'medumbu',
        'ca' => 'katalāņu',
        'cad' => 'kadu',
        'car' => 'karību',
        'cay' => 'kajuga',
        'cch' => 'atsamu',
        'ccp' => 'čakmu',
        'ce' => 'čečenu',
        'ceb' => 'sebuāņu',
        'cgg' => 'kiga',
        'ch' => 'čamorru',
        'chb' => 'čibču',
        'chg' => 'džagatajs',
        'chk' => 'čūku',
        'chm' => 'mariešu',
        'chn' => 'činuku žargons',
        'cho' => 'čoktavu',
        'chp' => 'čipevaianu',
        'chr' => 'čiroku',
        'chy' => 'šejenu',
        'ckb' => 'centrālkurdu',
        'clc' => 'čilkotīnu',
        'co' => 'korsikāņu',
        'cop' => 'koptu',
        'cr' => 'krī',
        'crg' => 'mičifu',
        'crh' => 'Krimas tatāru',
        'crj' => 'dienvidaustrumu krī',
        'crk' => 'līdzenumu krī',
        'crl' => 'ziemeļaustrumu krī',
        'crm' => 'mūsu krī',
        'crr' => 'Karolīnas algonkinu',
        'crs' => 'franciskā kreoliskā valoda (Seišelu salas)',
        'cs' => 'čehu',
        'csb' => 'kašubu',
        'csw' => 'purvu krī',
        'cu' => 'baznīcslāvu',
        'cv' => 'čuvašu',
        'cy' => 'velsiešu',
        'da' => 'dāņu',
        'dak' => 'dakotu',
        'dar' => 'dargu',
        'dav' => 'taitu',
        'de' => 'vācu',
        'del' => 'delavēru',
        'den' => 'sleivu',
        'dgr' => 'dogribu',
        'din' => 'dinku',
        'dje' => 'zarmu',
        'doi' => 'dogru',
        'dsb' => 'lejassorbu',
        'dua' => 'dualu',
        'dum' => 'vidusholandiešu',
        'dv' => 'maldīviešu',
        'dyo' => 'diola-fonjī',
        'dyu' => 'diūlu',
        'dz' => 'dzongke',
        'dzg' => 'dazu',
        'ebu' => 'kjembu',
        'ee' => 'evu',
        'efi' => 'efiku',
        'egy' => 'ēģiptiešu',
        'eka' => 'ekadžuku',
        'el' => 'grieķu',
        'elx' => 'elamiešu',
        'en' => 'angļu',
        'enm' => 'vidusangļu',
        'eo' => 'esperanto',
        'es' => 'spāņu',
        'et' => 'igauņu',
        'eu' => 'basku',
        'ewo' => 'evondu',
        'fa' => 'persiešu',
        'fan' => 'fangu',
        'fat' => 'fantu',
        'ff' => 'fulu',
        'fi' => 'somu',
        'fil' => 'filipīniešu',
        'fj' => 'fidžiešu',
        'fo' => 'fēru',
        'fon' => 'fonu',
        'fr' => 'franču',
        'frc' => 'kadžūnu franču',
        'frm' => 'vidusfranču',
        'fro' => 'senfranču',
        'frr' => 'ziemeļfrīzu',
        'frs' => 'austrumfrīzu',
        'fur' => 'friūlu',
        'fy' => 'rietumfrīzu',
        'ga' => 'īru',
        'gaa' => 'ga',
        'gag' => 'gagauzu',
        'gay' => 'gajo',
        'gba' => 'gbaju',
        'gd' => 'skotu gēlu',
        'gez' => 'gēzu',
        'gil' => 'kiribatiešu',
        'gl' => 'galisiešu',
        'gmh' => 'vidusaugšvācu',
        'gn' => 'gvaranu',
        'goh' => 'senaugšvācu',
        'gon' => 'gondu valodas',
        'gor' => 'gorontalu',
        'got' => 'gotu',
        'grb' => 'grebo',
        'grc' => 'sengrieķu',
        'gsw' => 'Šveices vācu',
        'gu' => 'gudžaratu',
        'guz' => 'gusii',
        'gv' => 'meniešu',
        'gwi' => 'kučinu',
        'ha' => 'hausu',
        'hai' => 'haidu',
        'haw' => 'havajiešu',
        'hax' => 'dienvidhaidu',
        'he' => 'ivrits',
        'hi' => 'hindi',
        'hil' => 'hiligainonu',
        'hit' => 'hetu',
        'hmn' => 'hmongu',
        'ho' => 'hirimotu',
        'hr' => 'horvātu',
        'hsb' => 'augšsorbu',
        'ht' => 'haitiešu',
        'hu' => 'ungāru',
        'hup' => 'hupu',
        'hur' => 'halkomelenu',
        'hy' => 'armēņu',
        'hz' => 'hereru',
        'ia' => 'interlingva',
        'iba' => 'ibanu',
        'ibb' => 'ibibio',
        'id' => 'indonēziešu',
        'ie' => 'interlingve',
        'ig' => 'igbo',
        'ii' => 'Sičuaņas ji',
        'ik' => 'inupiaku',
        'ikt' => 'Rietumkanādas inuītu',
        'ilo' => 'iloku',
        'inh' => 'ingušu',
        'io' => 'ido',
        'is' => 'islandiešu',
        'it' => 'itāļu',
        'iu' => 'inuītu',
        'ja' => 'japāņu',
        'jbo' => 'ložbans',
        'jgo' => 'ngomba',
        'jmc' => 'mačamu',
        'jpr' => 'jūdpersiešu',
        'jrb' => 'jūdarābu',
        'jv' => 'javiešu',
        'ka' => 'gruzīnu',
        'kaa' => 'karakalpaku',
        'kab' => 'kabilu',
        'kac' => 'kačinu',
        'kaj' => 'kadži',
        'kam' => 'kambu',
        'kaw' => 'kāvi',
        'kbd' => 'kabardiešu',
        'kbl' => 'kaņembu',
        'kcg' => 'katabu',
        'kde' => 'makonde',
        'kea' => 'kaboverdiešu',
        'kfo' => 'koru',
        'kg' => 'kongu',
        'kgp' => 'kaingangs',
        'kha' => 'khasu',
        'kho' => 'hotaniešu',
        'khq' => 'koiračiinī',
        'ki' => 'kikuju',
        'kj' => 'kvaņamu',
        'kk' => 'kazahu',
        'kkj' => 'kako',
        'kl' => 'grenlandiešu',
        'kln' => 'kalendžīnu',
        'km' => 'khmeru',
        'kmb' => 'kimbundu',
        'kn' => 'kannadu',
        'ko' => 'korejiešu',
        'koi' => 'komiešu-permiešu',
        'kok' => 'konkanu',
        'kos' => 'kosrājiešu',
        'kpe' => 'kpellu',
        'kr' => 'kanuru',
        'krc' => 'karačaju un balkāru',
        'krl' => 'karēļu',
        'kru' => 'kuruhu',
        'ks' => 'kašmiriešu',
        'ksb' => 'šambalu',
        'ksf' => 'bafiju',
        'ksh' => 'Ķelnes vācu',
        'ku' => 'kurdu',
        'kum' => 'kumiku',
        'kut' => 'kutenaju',
        'kv' => 'komiešu',
        'kw' => 'korniešu',
        'kwk' => 'kvakvala',
        'ky' => 'kirgīzu',
        'la' => 'latīņu',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'landu',
        'lam' => 'lambu',
        'lb' => 'luksemburgiešu',
        'lez' => 'lezgīnu',
        'lg' => 'gandu',
        'li' => 'limburgiešu',
        'lil' => 'lilluetu',
        'lkt' => 'lakotu',
        'ln' => 'lingala',
        'lo' => 'laosiešu',
        'lol' => 'mongu',
        'lou' => 'Luiziānas kreolu',
        'loz' => 'lozu',
        'lrc' => 'ziemeļluru',
        'lsm' => 'sāmia',
        'lt' => 'lietuviešu',
        'lu' => 'lubakatanga',
        'lua' => 'lubalulva',
        'lui' => 'luisenu',
        'lun' => 'lundu',
        'luo' => 'luo',
        'lus' => 'lušeju',
        'luy' => 'luhju',
        'lv' => 'latviešu',
        'mad' => 'maduriešu',
        'maf' => 'mafu',
        'mag' => 'magahiešu',
        'mai' => 'maithili',
        'mak' => 'makasaru',
        'man' => 'mandingu',
        'mas' => 'masaju',
        'mde' => 'mabu',
        'mdf' => 'mokšu',
        'mdr' => 'mandaru',
        'men' => 'mendu',
        'mer' => 'meru',
        'mfe' => 'Maurīcijas kreolu',
        'mg' => 'malagasu',
        'mga' => 'vidusīru',
        'mgh' => 'makua',
        'mgo' => 'metu',
        'mh' => 'māršaliešu',
        'mi' => 'maoru',
        'mic' => 'mikmaku',
        'min' => 'minangkabavu',
        'mk' => 'maķedoniešu',
        'ml' => 'malajalu',
        'mn' => 'mongoļu',
        'mnc' => 'mandžūru',
        'mni' => 'manipūru',
        'moe' => 'motanju',
        'moh' => 'mohauku',
        'mos' => 'mosu',
        'mr' => 'marathu',
        'ms' => 'malajiešu',
        'mt' => 'maltiešu',
        'mua' => 'mundangu',
        'mus' => 'krīku',
        'mwl' => 'mirandiešu',
        'mwr' => 'marvaru',
        'my' => 'birmiešu',
        'mye' => 'mjenu',
        'myv' => 'erzju',
        'mzn' => 'mazanderāņu',
        'na' => 'nauruiešu',
        'nap' => 'neapoliešu',
        'naq' => 'nama',
        'nb' => 'norvēģu bukmols',
        'nd' => 'ziemeļndebelu',
        'nds' => 'lejasvācu',
        'ne' => 'nepāliešu',
        'new' => 'nevaru',
        'ng' => 'ndongu',
        'nia' => 'njasu',
        'niu' => 'niuāņu',
        'nl' => 'holandiešu',
        'nmg' => 'kvasio',
        'nn' => 'jaunnorvēģu',
        'nnh' => 'ngjembūnu',
        'no' => 'norvēģu',
        'nog' => 'nogaju',
        'non' => 'sennorvēģu',
        'nqo' => 'nko',
        'nr' => 'dienvidndebelu',
        'nso' => 'ziemeļsotu',
        'nus' => 'nueru',
        'nv' => 'navahu',
        'nwc' => 'klasiskā nevaru',
        'ny' => 'čičeva',
        'nym' => 'ņamvezu',
        'nyn' => 'ņankolu',
        'nyo' => 'ņoru',
        'nzi' => 'nzemu',
        'oc' => 'oksitāņu',
        'oj' => 'odžibvu',
        'ojb' => 'ziemeļrietumu odžibvu',
        'ojc' => 'centrālā odžibvu',
        'ojs' => 'odži-krī',
        'ojw' => 'rietumodžibvu',
        'oka' => 'okanaganu',
        'om' => 'oromu',
        'or' => 'oriju',
        'os' => 'osetīnu',
        'osa' => 'važāžu',
        'ota' => 'turku osmaņu',
        'pa' => 'pandžabu',
        'pag' => 'pangasinanu',
        'pal' => 'pehlevi',
        'pam' => 'pampanganu',
        'pap' => 'papjamento',
        'pau' => 'palaviešu',
        'pcm' => 'Nigērijas pidžinvaloda',
        'peo' => 'senpersu',
        'phn' => 'feniķiešu',
        'pi' => 'pāli',
        'pis' => 'pidžinvaloda',
        'pl' => 'poļu',
        'pon' => 'ponapiešu',
        'pqm' => 'malisetu-pasamakvodi',
        'prg' => 'prūšu',
        'pro' => 'senprovansiešu',
        'ps' => 'puštu',
        'pt' => 'portugāļu',
        'qu' => 'kečvu',
        'quc' => 'kiče',
        'raj' => 'radžastāņu',
        'rap' => 'rapanuju',
        'rar' => 'rarotongiešu',
        'rhg' => 'rohindžu',
        'rm' => 'retoromāņu',
        'rn' => 'rundu',
        'ro' => 'rumāņu',
        'rof' => 'rombo',
        'rom' => 'čigānu',
        'ru' => 'krievu',
        'rup' => 'aromūnu',
        'rw' => 'kiņaruanda',
        'rwk' => 'ruanda',
        'sa' => 'sanskrits',
        'sad' => 'sandavu',
        'sah' => 'jakutu',
        'sam' => 'Samārijas aramiešu',
        'saq' => 'samburu',
        'sas' => 'sasaku',
        'sat' => 'santalu',
        'sba' => 'ngambeju',
        'sbp' => 'sangu',
        'sc' => 'sardīniešu',
        'scn' => 'sicīliešu',
        'sco' => 'skotu',
        'sd' => 'sindhu',
        'sdh' => 'dienvidkurdu',
        'se' => 'ziemeļsāmu',
        'see' => 'seneku',
        'seh' => 'senu',
        'sel' => 'selkupu',
        'ses' => 'koiraboro senni',
        'sg' => 'sango',
        'sga' => 'senīru',
        'sh' => 'serbu–horvātu',
        'shi' => 'šilhu',
        'shn' => 'šanu',
        'shu' => 'Čadas arābu',
        'si' => 'singāļu',
        'sid' => 'sidamu',
        'sk' => 'slovāku',
        'sl' => 'slovēņu',
        'slh' => 'dienvidlušucīdu',
        'sm' => 'samoāņu',
        'sma' => 'dienvidsāmu',
        'smj' => 'Luleo sāmu',
        'smn' => 'Inari sāmu',
        'sms' => 'skoltsāmu',
        'sn' => 'šonu',
        'snk' => 'soninku',
        'so' => 'somāļu',
        'sog' => 'sogdiešu',
        'sq' => 'albāņu',
        'sr' => 'serbu',
        'srn' => 'sranantogo',
        'srr' => 'serēru',
        'ss' => 'svatu',
        'ssy' => 'saho',
        'st' => 'dienvidsotu',
        'str' => 'šauruma sališu',
        'su' => 'zundu',
        'suk' => 'sukumu',
        'sus' => 'susu',
        'sux' => 'šumeru',
        'sv' => 'zviedru',
        'sw' => 'svahili',
        'swb' => 'komoru',
        'syc' => 'klasiskā sīriešu',
        'syr' => 'sīriešu',
        'ta' => 'tamilu',
        'tce' => 'dienvidtutčonu',
        'te' => 'telugu',
        'tem' => 'temnu',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetumu',
        'tg' => 'tadžiku',
        'tgx' => 'tagišu',
        'th' => 'taju',
        'tht' => 'tahltanu',
        'ti' => 'tigrinja',
        'tig' => 'tigru',
        'tiv' => 'tivu',
        'tk' => 'turkmēņu',
        'tkl' => 'tokelaviešu',
        'tl' => 'tagalu',
        'tlh' => 'klingoņu',
        'tli' => 'tlinkitu',
        'tmh' => 'tuaregu',
        'tn' => 'cvanu',
        'to' => 'tongiešu',
        'tog' => 'Njasas tongu',
        'tok' => 'tokiponu',
        'tpi' => 'tokpisins',
        'tr' => 'turku',
        'trv' => 'taroko',
        'ts' => 'congu',
        'tsi' => 'cimšiāņu',
        'tt' => 'tatāru',
        'ttm' => 'ziemeļu tučonu',
        'tum' => 'tumbuku',
        'tvl' => 'tuvaliešu',
        'tw' => 'tvī',
        'twq' => 'tasavaku',
        'ty' => 'taitiešu',
        'tyv' => 'tuviešu',
        'tzm' => 'Centrālmarokas tamazīts',
        'udm' => 'udmurtu',
        'ug' => 'uiguru',
        'uga' => 'ugaritiešu',
        'uk' => 'ukraiņu',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbeku',
        'vai' => 'vaju',
        've' => 'vendu',
        'vi' => 'vjetnamiešu',
        'vo' => 'volapiks',
        'vot' => 'votu',
        'vun' => 'vundžo',
        'wa' => 'valoņu',
        'wae' => 'Vallisas vācu',
        'wal' => 'valamu',
        'war' => 'varaju',
        'was' => 'vašo',
        'wbp' => 'varlpirī',
        'wo' => 'volofu',
        'wuu' => 'vu ķīniešu',
        'xal' => 'kalmiku',
        'xh' => 'khosu',
        'xog' => 'sogu',
        'yao' => 'jao',
        'yap' => 'japiešu',
        'yav' => 'janbaņu',
        'ybb' => 'jembu',
        'yi' => 'jidišs',
        'yo' => 'jorubu',
        'yrl' => 'njengatu',
        'yue' => 'kantoniešu',
        'za' => 'džuanu',
        'zap' => 'sapoteku',
        'zbl' => 'blissimbolika',
        'zen' => 'zenagu',
        'zgh' => 'standarta tamazigtu (Maroka)',
        'zh' => 'ķīniešu',
        'zu' => 'zulu',
        'zun' => 'zunju',
        'zza' => 'zazaki',
    ],
    'LocalizedNames' => [
        'ar_001' => 'mūsdienu standarta arābu',
        'az_Arab' => 'dienvidazerbaidžāņu',
        'de_CH' => 'augšvācu (Šveice)',
        'en_GB' => 'angļu (Lielbritānija)',
        'fa_AF' => 'darī',
        'nds_NL' => 'lejassakšu',
        'nl_BE' => 'flāmu',
        'ro_MD' => 'moldāvu',
        'sw_CD' => 'svahili (Kongo)',
        'zh_Hans' => 'ķīniešu vienkāršotā',
        'zh_Hant' => 'ķīniešu tradicionālā',
    ],
];
