<?php

return [
    'Names' => [
        'AD' => 'Anndoora',
        'AE' => 'Emiraat Araab Denntuɗe',
        'AF' => 'Afganistaan',
        'AG' => 'Antiguwaa e Barbudaa',
        'AI' => 'Anngiyaa',
        'AL' => 'Albanii',
        'AM' => 'Armenii',
        'AO' => 'Anngolaa',
        'AR' => 'Arjantiin',
        'AS' => 'Samowa Amerik',
        'AT' => 'Otiriis',
        'AU' => 'Ostaraalii',
        'AW' => 'Aruuba',
        'AZ' => 'Ajerbayjaan',
        'BA' => 'Bosnii Hersegowiin',
        'BB' => 'Barbadoos',
        'BD' => 'Banglaadees',
        'BE' => 'Beljik',
        'BF' => 'Burkibaa Faaso',
        'BG' => 'Bulgarii',
        'BH' => 'Bahreyn',
        'BI' => 'Burunndi',
        'BJ' => 'Benee',
        'BM' => 'Bermudaa',
        'BN' => 'Burnaay',
        'BO' => 'Boliwii',
        'BR' => 'Beresiil',
        'BS' => 'Bahamaas',
        'BT' => 'Butaan',
        'BW' => 'Botswaana',
        'BY' => 'Belaruus',
        'BZ' => 'Beliise',
        'CA' => 'Kanadaa',
        'CD' => 'Ndenndaandi Demokaraasiire Konngo',
        'CF' => 'Ndenndaandi Santarafrik',
        'CG' => 'Konngo',
        'CH' => 'Suwiis',
        'CI' => 'Kodduwaar',
        'CK' => 'Duuɗe Kuuk',
        'CL' => 'Cilii',
        'CM' => 'Kameruun',
        'CN' => 'Siin',
        'CO' => 'Kolombiya',
        'CR' => 'Kosta Rikaa',
        'CU' => 'Kubaa',
        'CV' => 'Duuɗe Kap Weer',
        'CY' => 'Siipar',
        'CZ' => 'Ndenndaandi Cek',
        'DE' => 'Almaañ',
        'DJ' => 'Jibutii',
        'DK' => 'Danmark',
        'DM' => 'Dominika',
        'DO' => 'Ndenndanndi Dominika',
        'DZ' => 'Alaseri',
        'EC' => 'Ekuwatoor',
        'EE' => 'Estoni',
        'EG' => 'Ejipt',
        'ER' => 'Eriteree',
        'ES' => 'Espaañ',
        'ET' => 'Ecoppi',
        'FI' => 'Fenland',
        'FJ' => 'Fijji',
        'FK' => 'Duuɗe Falkland',
        'FM' => 'Mikoronesii',
        'FR' => 'Farayse',
        'GA' => 'Gaboo',
        'GB' => 'Laamateeri Rentundi',
        'GD' => 'Garnaad',
        'GE' => 'Jeorgii',
        'GF' => 'Giyaan Farayse',
        'GH' => 'Ganaa',
        'GI' => 'Jibraltaar',
        'GL' => 'Gorwendland',
        'GM' => 'Gammbi',
        'GN' => 'Gine',
        'GP' => 'Gwaadalup',
        'GQ' => 'Ginee Ekuwaatoriyaal',
        'GR' => 'Gerees',
        'GT' => 'Gwaatemalaa',
        'GU' => 'Guwam',
        'GW' => 'Gine-Bisaawo',
        'GY' => 'Giyaan',
        'HN' => 'Onnduraas',
        'HR' => 'Korwasii',
        'HT' => 'Haytii',
        'HU' => 'Onngiri',
        'ID' => 'Enndonesii',
        'IE' => 'Irlannda',
        'IL' => 'Israa’iila',
        'IN' => 'Enndo',
        'IO' => 'Keeriindi britaani to maayo enndo',
        'IQ' => 'Iraak',
        'IR' => 'Iraan',
        'IS' => 'Islannda',
        'IT' => 'Itali',
        'JM' => 'Jamayka',
        'JO' => 'Jordani',
        'JP' => 'Sapoo',
        'KE' => 'Keñaa',
        'KG' => 'Kirgistaan',
        'KH' => 'Kambodso',
        'KI' => 'Kiribari',
        'KM' => 'Komoor',
        'KN' => 'Sent Kits e Newis',
        'KP' => 'Koree Rewo',
        'KR' => 'Koree Worgo',
        'KW' => 'Kuweyti',
        'KY' => 'Duuɗe Kaymaa',
        'KZ' => 'Kasakstaan',
        'LA' => 'Lawoos',
        'LB' => 'Libaa',
        'LC' => 'Sent Lusiyaa',
        'LI' => 'Lincenstayn',
        'LK' => 'Siri Lanka',
        'LR' => 'Liberiyaa',
        'LS' => 'Lesoto',
        'LT' => 'Lituaanii',
        'LU' => 'Liksembuur',
        'LV' => 'Letonii',
        'LY' => 'Libi',
        'MA' => 'Maruk',
        'MC' => 'Monaakoo',
        'MD' => 'Moldawii',
        'MG' => 'Madagaskaar',
        'MH' => 'Duuɗe Marsaal',
        'ML' => 'Maali',
        'MM' => 'Miyamaar',
        'MN' => 'Monngolii',
        'MP' => 'Duuɗe Mariyaana Rewo',
        'MQ' => 'Martinik',
        'MR' => 'Muritani',
        'MS' => 'Monseraat',
        'MT' => 'Malte',
        'MU' => 'Moriis',
        'MV' => 'Maldiiwe',
        'MW' => 'Malaawi',
        'MX' => 'Meksik',
        'MY' => 'Malesii',
        'MZ' => 'Mosammbik',
        'NA' => 'Namibii',
        'NC' => 'Nuwel Kaledonii',
        'NE' => 'Nijeer',
        'NF' => 'Duuɗe Norfolk',
        'NG' => 'Nijeriyaa',
        'NI' => 'Nikaraguwaa',
        'NL' => 'Nederlannda',
        'NO' => 'Norwees',
        'NP' => 'Nepaal',
        'NR' => 'Nawuru',
        'NU' => 'Niuwe',
        'NZ' => 'Nuwel Selannda',
        'OM' => 'Omaan',
        'PA' => 'Panamaa',
        'PE' => 'Peru',
        'PF' => 'Polinesii Farayse',
        'PG' => 'Papuwaa Nuwel Gine',
        'PH' => 'Filipiin',
        'PK' => 'Pakistaan',
        'PL' => 'Poloñ',
        'PM' => 'See Piyeer e Mikeloo',
        'PN' => 'Pitkern',
        'PR' => 'Porto Rikoo',
        'PS' => 'Palestiin Sisjordani e Gaasaa',
        'PT' => 'Purtugaal',
        'PW' => 'Palawu',
        'PY' => 'Paraguwaay',
        'QA' => 'Kataar',
        'RE' => 'Rewiñoo',
        'RO' => 'Rumanii',
        'RU' => 'Riisii',
        'RW' => 'Ruwanndaa',
        'SA' => 'Arabii Sawdit',
        'SB' => 'Duuɗe Solomon',
        'SC' => 'Seysel',
        'SD' => 'Sudaan',
        'SE' => 'Suweed',
        'SG' => 'Sinngapuur',
        'SH' => 'Sent Helen',
        'SI' => 'Slowenii',
        'SK' => 'Slowakii',
        'SL' => 'Seraa liyon',
        'SM' => 'See Maree',
        'SN' => 'Senegaal',
        'SO' => 'Somalii',
        'SR' => 'Surinaam',
        'ST' => 'Sawo Tome e Perensipe',
        'SV' => 'El Salwador',
        'SY' => 'Sirii',
        'SZ' => 'Swaasilannda',
        'TC' => 'Duuɗe Turke e Keikoos',
        'TD' => 'Caad',
        'TG' => 'Togoo',
        'TH' => 'Taylannda',
        'TJ' => 'Tajikistaan',
        'TK' => 'Tokelaaw',
        'TL' => 'Timoor Fuɗnaange',
        'TM' => 'Turkmenistaan',
        'TN' => 'Tunisii',
        'TO' => 'Tonngaa',
        'TR' => 'Turkii',
        'TT' => 'Tirnidaad e Tobaago',
        'TV' => 'Tuwaluu',
        'TW' => 'Taywaan',
        'TZ' => 'Tansanii',
        'UA' => 'Ukereen',
        'UG' => 'Unganndaa',
        'US' => 'Dowlaaji Dentuɗi Amerik',
        'UY' => 'Uruguwaay',
        'UZ' => 'Usbekistaan',
        'VA' => 'Dowla Waticaan',
        'VC' => 'See Weesaa e Garnadiin',
        'VE' => 'Wenesuwelaa',
        'VG' => 'duuɗe kecce britanii',
        'VI' => 'Duuɗe Kecce Amerik',
        'VN' => 'Wiyetnaam',
        'VU' => 'Wanuwaatuu',
        'WF' => 'Walis e Futuna',
        'WS' => 'Samowaa',
        'YE' => 'Yemen',
        'YT' => 'Mayoot',
        'ZA' => 'Afrik bŋ Worgo',
        'ZM' => 'Sammbi',
        'ZW' => 'Simbaabuwe',
    ],
];
