<?php

return [
    'Names' => [
        'ak' => 'akan',
        'ak_GH' => 'akan (Gana)',
        'am' => 'liamariki',
        'am_ET' => 'liamariki (Etsíopi)',
        'ar' => 'lialabo',
        'ar_AE' => 'lialabo (Lɛmila alabo)',
        'ar_BH' => 'lialabo (Bahrɛnɛ)',
        'ar_DJ' => 'lialabo (Dzibuti)',
        'ar_DZ' => 'lialabo (Alizɛri)',
        'ar_EG' => 'lialabo (Ezípite)',
        'ar_ER' => 'lialabo (Elitelɛ)',
        'ar_IL' => 'lialabo (Isirayelɛ)',
        'ar_IQ' => 'lialabo (Iraki)',
        'ar_JO' => 'lialabo (Zɔdani)',
        'ar_KM' => 'lialabo (Komorɛ)',
        'ar_KW' => 'lialabo (Koweti)',
        'ar_LB' => 'lialabo (Libá)',
        'ar_LY' => 'lialabo (Libí)',
        'ar_MA' => 'lialabo (Marokɛ)',
        'ar_MR' => 'lialabo (Moritani)',
        'ar_OM' => 'lialabo (Ománɛ)',
        'ar_PS' => 'lialabo (Palɛsine)',
        'ar_QA' => 'lialabo (Katari)',
        'ar_SA' => 'lialabo (Alabi Sawuditɛ)',
        'ar_SD' => 'lialabo (Sudá)',
        'ar_SO' => 'lialabo (Somali)',
        'ar_SY' => 'lialabo (Sirí)',
        'ar_TD' => 'lialabo (Tsádi)',
        'ar_TN' => 'lialabo (Tinizi)',
        'ar_YE' => 'lialabo (Yemɛnɛ)',
        'be' => 'libyelorisí',
        'be_BY' => 'libyelorisí (Byelorisi)',
        'bg' => 'libiligali',
        'bg_BG' => 'libiligali (Biligari)',
        'bn' => 'libengali',
        'bn_BD' => 'libengali (Bengalidɛsi)',
        'bn_IN' => 'libengali (Índɛ)',
        'cs' => 'litshekɛ',
        'cs_CZ' => 'litshekɛ (Shekia)',
        'de' => 'lialemá',
        'de_AT' => 'lialemá (Otilisi)',
        'de_BE' => 'lialemá (Beleziki)',
        'de_CH' => 'lialemá (Swisɛ)',
        'de_DE' => 'lialemá (Alemani)',
        'de_IT' => 'lialemá (Itali)',
        'de_LI' => 'lialemá (Lishɛteni)',
        'de_LU' => 'lialemá (Likisambulu)',
        'el' => 'ligeleki',
        'el_CY' => 'ligeleki (Sípɛlɛ)',
        'el_GR' => 'ligeleki (Geleki)',
        'en' => 'lingɛlɛ́sa',
        'en_AE' => 'lingɛlɛ́sa (Lɛmila alabo)',
        'en_AG' => 'lingɛlɛ́sa (Antiga mpé Barbuda)',
        'en_AI' => 'lingɛlɛ́sa (Angiyɛ)',
        'en_AS' => 'lingɛlɛ́sa (Samoa ya Ameriki)',
        'en_AT' => 'lingɛlɛ́sa (Otilisi)',
        'en_AU' => 'lingɛlɛ́sa (Ositáli)',
        'en_BB' => 'lingɛlɛ́sa (Barɛbadɛ)',
        'en_BE' => 'lingɛlɛ́sa (Beleziki)',
        'en_BI' => 'lingɛlɛ́sa (Burundi)',
        'en_BM' => 'lingɛlɛ́sa (Bermuda)',
        'en_BS' => 'lingɛlɛ́sa (Bahamasɛ)',
        'en_BW' => 'lingɛlɛ́sa (Botswana)',
        'en_BZ' => 'lingɛlɛ́sa (Belizɛ)',
        'en_CA' => 'lingɛlɛ́sa (Kanada)',
        'en_CH' => 'lingɛlɛ́sa (Swisɛ)',
        'en_CK' => 'lingɛlɛ́sa (Bisanga bya Kookɛ)',
        'en_CM' => 'lingɛlɛ́sa (Kamɛrune)',
        'en_CY' => 'lingɛlɛ́sa (Sípɛlɛ)',
        'en_DE' => 'lingɛlɛ́sa (Alemani)',
        'en_DK' => 'lingɛlɛ́sa (Danɛmarike)',
        'en_DM' => 'lingɛlɛ́sa (Domínike)',
        'en_ER' => 'lingɛlɛ́sa (Elitelɛ)',
        'en_FI' => 'lingɛlɛ́sa (Filandɛ)',
        'en_FJ' => 'lingɛlɛ́sa (Fidzi)',
        'en_FK' => 'lingɛlɛ́sa (Bisanga bya Maluni)',
        'en_FM' => 'lingɛlɛ́sa (Mikronezi)',
        'en_GB' => 'lingɛlɛ́sa (Angɛlɛtɛ́lɛ)',
        'en_GD' => 'lingɛlɛ́sa (Gelenadɛ)',
        'en_GG' => 'lingɛlɛ́sa (Guernesey)',
        'en_GH' => 'lingɛlɛ́sa (Gana)',
        'en_GI' => 'lingɛlɛ́sa (Zibatalɛ)',
        'en_GM' => 'lingɛlɛ́sa (Gambi)',
        'en_GU' => 'lingɛlɛ́sa (Gwamɛ)',
        'en_GY' => 'lingɛlɛ́sa (Giyane)',
        'en_IE' => 'lingɛlɛ́sa (Irelandɛ)',
        'en_IL' => 'lingɛlɛ́sa (Isirayelɛ)',
        'en_IN' => 'lingɛlɛ́sa (Índɛ)',
        'en_IO' => 'lingɛlɛ́sa (Mabelé ya Angɛlɛtɛ́lɛ na mbú ya Indiya)',
        'en_JM' => 'lingɛlɛ́sa (Zamaiki)',
        'en_KE' => 'lingɛlɛ́sa (Kenya)',
        'en_KI' => 'lingɛlɛ́sa (Kiribati)',
        'en_KN' => 'lingɛlɛ́sa (Sántu krístofe mpé Nevɛ̀s)',
        'en_KY' => 'lingɛlɛ́sa (Bisanga bya Kayíma)',
        'en_LC' => 'lingɛlɛ́sa (Sántu lisi)',
        'en_LR' => 'lingɛlɛ́sa (Libériya)',
        'en_LS' => 'lingɛlɛ́sa (Lesoto)',
        'en_MG' => 'lingɛlɛ́sa (Madagasikari)',
        'en_MH' => 'lingɛlɛ́sa (Bisanga bya Marishalɛ)',
        'en_MP' => 'lingɛlɛ́sa (Bisanga bya Marianɛ ya nɔ́rdi)',
        'en_MS' => 'lingɛlɛ́sa (Mɔsera)',
        'en_MT' => 'lingɛlɛ́sa (Malitɛ)',
        'en_MU' => 'lingɛlɛ́sa (Morisɛ)',
        'en_MV' => 'lingɛlɛ́sa (Madívɛ)',
        'en_MW' => 'lingɛlɛ́sa (Malawi)',
        'en_MY' => 'lingɛlɛ́sa (Malezi)',
        'en_NA' => 'lingɛlɛ́sa (Namibi)',
        'en_NF' => 'lingɛlɛ́sa (Esanga Norfokɛ)',
        'en_NG' => 'lingɛlɛ́sa (Nizerya)',
        'en_NL' => 'lingɛlɛ́sa (Olandɛ)',
        'en_NR' => 'lingɛlɛ́sa (Nauru)',
        'en_NU' => 'lingɛlɛ́sa (Nyué)',
        'en_NZ' => 'lingɛlɛ́sa (Zelandɛ ya sika)',
        'en_PG' => 'lingɛlɛ́sa (Papwazi Ginɛ ya sika)',
        'en_PH' => 'lingɛlɛ́sa (Filipinɛ)',
        'en_PK' => 'lingɛlɛ́sa (Pakisitá)',
        'en_PN' => 'lingɛlɛ́sa (Pikairni)',
        'en_PR' => 'lingɛlɛ́sa (Pɔtoriko)',
        'en_PW' => 'lingɛlɛ́sa (Palau)',
        'en_RW' => 'lingɛlɛ́sa (Rwanda)',
        'en_SB' => 'lingɛlɛ́sa (Bisanga Solomɔ)',
        'en_SC' => 'lingɛlɛ́sa (Sɛshɛlɛ)',
        'en_SD' => 'lingɛlɛ́sa (Sudá)',
        'en_SE' => 'lingɛlɛ́sa (Swédɛ)',
        'en_SG' => 'lingɛlɛ́sa (Singapurɛ)',
        'en_SH' => 'lingɛlɛ́sa (Sántu eleni)',
        'en_SI' => 'lingɛlɛ́sa (Siloveni)',
        'en_SL' => 'lingɛlɛ́sa (Siera Leonɛ)',
        'en_SZ' => 'lingɛlɛ́sa (Swazilandi)',
        'en_TC' => 'lingɛlɛ́sa (Bisanga bya Turki mpé Kaiko)',
        'en_TK' => 'lingɛlɛ́sa (Tokelau)',
        'en_TO' => 'lingɛlɛ́sa (Tonga)',
        'en_TT' => 'lingɛlɛ́sa (Tinidadɛ mpé Tobago)',
        'en_TV' => 'lingɛlɛ́sa (Tuvalu)',
        'en_TZ' => 'lingɛlɛ́sa (Tanzani)',
        'en_UG' => 'lingɛlɛ́sa (Uganda)',
        'en_US' => 'lingɛlɛ́sa (Ameriki)',
        'en_VC' => 'lingɛlɛ́sa (Sántu vesá mpé Gelenadinɛ)',
        'en_VG' => 'lingɛlɛ́sa (Bisanga bya Vierzi ya Angɛlɛtɛ́lɛ)',
        'en_VI' => 'lingɛlɛ́sa (Bisanga bya Vierzi ya Ameriki)',
        'en_VU' => 'lingɛlɛ́sa (Vanuatu)',
        'en_WS' => 'lingɛlɛ́sa (Samoa)',
        'en_ZA' => 'lingɛlɛ́sa (Afríka ya Súdi)',
        'en_ZM' => 'lingɛlɛ́sa (Zambi)',
        'en_ZW' => 'lingɛlɛ́sa (Zimbabwe)',
        'es' => 'lisipanye',
        'es_AR' => 'lisipanye (Arizantinɛ)',
        'es_BO' => 'lisipanye (Bolivi)',
        'es_BR' => 'lisipanye (Brezílɛ)',
        'es_BZ' => 'lisipanye (Belizɛ)',
        'es_CL' => 'lisipanye (Síli)',
        'es_CO' => 'lisipanye (Kolombi)',
        'es_CR' => 'lisipanye (Kositarika)',
        'es_CU' => 'lisipanye (Kiba)',
        'es_DO' => 'lisipanye (Repibiki ya Domínikɛ)',
        'es_EC' => 'lisipanye (Ekwatɛ́lɛ)',
        'es_ES' => 'lisipanye (Esipanye)',
        'es_GQ' => 'lisipanye (Ginɛ́kwatɛ́lɛ)',
        'es_GT' => 'lisipanye (Gwatémala)',
        'es_HN' => 'lisipanye (Ondurasɛ)',
        'es_MX' => 'lisipanye (Meksike)',
        'es_NI' => 'lisipanye (Nikaragwa)',
        'es_PA' => 'lisipanye (Panama)',
        'es_PE' => 'lisipanye (Péru)',
        'es_PH' => 'lisipanye (Filipinɛ)',
        'es_PR' => 'lisipanye (Pɔtoriko)',
        'es_PY' => 'lisipanye (Palagwei)',
        'es_SV' => 'lisipanye (Savadɔrɛ)',
        'es_US' => 'lisipanye (Ameriki)',
        'es_UY' => 'lisipanye (Irigwei)',
        'es_VE' => 'lisipanye (Venézuela)',
        'fa' => 'lipelésanɛ',
        'fa_AF' => 'lipelésanɛ (Afiganisitá)',
        'fa_IR' => 'lipelésanɛ (Irâ)',
        'fr' => 'lifalansɛ́',
        'fr_BE' => 'lifalansɛ́ (Beleziki)',
        'fr_BF' => 'lifalansɛ́ (Bukina Faso)',
        'fr_BI' => 'lifalansɛ́ (Burundi)',
        'fr_BJ' => 'lifalansɛ́ (Benɛ)',
        'fr_CA' => 'lifalansɛ́ (Kanada)',
        'fr_CD' => 'lifalansɛ́ (Republíki ya Kongó Demokratíki)',
        'fr_CF' => 'lifalansɛ́ (Repibiki ya Afríka ya Káti)',
        'fr_CG' => 'lifalansɛ́ (Kongo)',
        'fr_CH' => 'lifalansɛ́ (Swisɛ)',
        'fr_CI' => 'lifalansɛ́ (Kotídivualɛ)',
        'fr_CM' => 'lifalansɛ́ (Kamɛrune)',
        'fr_DJ' => 'lifalansɛ́ (Dzibuti)',
        'fr_DZ' => 'lifalansɛ́ (Alizɛri)',
        'fr_FR' => 'lifalansɛ́ (Falánsɛ)',
        'fr_GA' => 'lifalansɛ́ (Gabɔ)',
        'fr_GF' => 'lifalansɛ́ (Giyanɛ ya Falánsɛ)',
        'fr_GN' => 'lifalansɛ́ (Ginɛ)',
        'fr_GP' => 'lifalansɛ́ (Gwadɛlupɛ)',
        'fr_GQ' => 'lifalansɛ́ (Ginɛ́kwatɛ́lɛ)',
        'fr_HT' => 'lifalansɛ́ (Ayiti)',
        'fr_KM' => 'lifalansɛ́ (Komorɛ)',
        'fr_LU' => 'lifalansɛ́ (Likisambulu)',
        'fr_MA' => 'lifalansɛ́ (Marokɛ)',
        'fr_MC' => 'lifalansɛ́ (Monako)',
        'fr_MG' => 'lifalansɛ́ (Madagasikari)',
        'fr_ML' => 'lifalansɛ́ (Malí)',
        'fr_MQ' => 'lifalansɛ́ (Martiniki)',
        'fr_MR' => 'lifalansɛ́ (Moritani)',
        'fr_MU' => 'lifalansɛ́ (Morisɛ)',
        'fr_NC' => 'lifalansɛ́ (Kaledoni ya sika)',
        'fr_NE' => 'lifalansɛ́ (Nizɛrɛ)',
        'fr_PF' => 'lifalansɛ́ (Polinezi ya Falánsɛ)',
        'fr_PM' => 'lifalansɛ́ (Sántu pététo mpé Mikelɔ)',
        'fr_RE' => 'lifalansɛ́ (Lenyo)',
        'fr_RW' => 'lifalansɛ́ (Rwanda)',
        'fr_SC' => 'lifalansɛ́ (Sɛshɛlɛ)',
        'fr_SN' => 'lifalansɛ́ (Senegalɛ)',
        'fr_SY' => 'lifalansɛ́ (Sirí)',
        'fr_TD' => 'lifalansɛ́ (Tsádi)',
        'fr_TG' => 'lifalansɛ́ (Togo)',
        'fr_TN' => 'lifalansɛ́ (Tinizi)',
        'fr_VU' => 'lifalansɛ́ (Vanuatu)',
        'fr_WF' => 'lifalansɛ́ (Walisɛ mpé Futuna)',
        'fr_YT' => 'lifalansɛ́ (Mayotɛ)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Gana)',
        'ha_NE' => 'hausa (Nizɛrɛ)',
        'ha_NG' => 'hausa (Nizerya)',
        'hi' => 'lihindi',
        'hi_IN' => 'lihindi (Índɛ)',
        'hu' => 'liongili',
        'hu_HU' => 'liongili (Ongili)',
        'id' => 'lindonezi',
        'id_ID' => 'lindonezi (Indonezi)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nizerya)',
        'it' => 'litaliano',
        'it_CH' => 'litaliano (Swisɛ)',
        'it_IT' => 'litaliano (Itali)',
        'it_SM' => 'litaliano (Sántu Marinɛ)',
        'it_VA' => 'litaliano (Vatiká)',
        'ja' => 'lizapɔ',
        'ja_JP' => 'lizapɔ (Zapɔ)',
        'jv' => 'lizava',
        'jv_ID' => 'lizava (Indonezi)',
        'km' => 'likambodza',
        'km_KH' => 'likambodza (Kambodza)',
        'ko' => 'likoreya',
        'ko_KP' => 'likoreya (Korɛ ya nɔ́rdi)',
        'ko_KR' => 'likoreya (Korɛ ya súdi)',
        'ln' => 'lingála',
        'ln_AO' => 'lingála (Angóla)',
        'ln_CD' => 'lingála (Republíki ya Kongó Demokratíki)',
        'ln_CF' => 'lingála (Repibiki ya Afríka ya Káti)',
        'ln_CG' => 'lingála (Kongo)',
        'ms' => 'limalezi',
        'ms_BN' => 'limalezi (Brineyi)',
        'ms_ID' => 'limalezi (Indonezi)',
        'ms_MY' => 'limalezi (Malezi)',
        'ms_SG' => 'limalezi (Singapurɛ)',
        'my' => 'libilimá',
        'my_MM' => 'libilimá (Birmanie)',
        'ne' => 'linepalɛ',
        'ne_IN' => 'linepalɛ (Índɛ)',
        'ne_NP' => 'linepalɛ (Nepálɛ)',
        'nl' => 'lifalamá',
        'nl_AW' => 'lifalamá (Aruba)',
        'nl_BE' => 'lifalamá (Beleziki)',
        'nl_NL' => 'lifalamá (Olandɛ)',
        'nl_SR' => 'lifalamá (Surinamɛ)',
        'pa' => 'lipendzabi',
        'pa_IN' => 'lipendzabi (Índɛ)',
        'pa_PK' => 'lipendzabi (Pakisitá)',
        'pl' => 'lipolonɛ',
        'pl_PL' => 'lipolonɛ (Poloni)',
        'pt' => 'lipulutugɛ́si',
        'pt_AO' => 'lipulutugɛ́si (Angóla)',
        'pt_BR' => 'lipulutugɛ́si (Brezílɛ)',
        'pt_CH' => 'lipulutugɛ́si (Swisɛ)',
        'pt_CV' => 'lipulutugɛ́si (Bisanga bya Kapevɛrɛ)',
        'pt_GQ' => 'lipulutugɛ́si (Ginɛ́kwatɛ́lɛ)',
        'pt_GW' => 'lipulutugɛ́si (Ginɛbisau)',
        'pt_LU' => 'lipulutugɛ́si (Likisambulu)',
        'pt_MZ' => 'lipulutugɛ́si (Mozambíki)',
        'pt_PT' => 'lipulutugɛ́si (Putúlugɛsi)',
        'pt_ST' => 'lipulutugɛ́si (Sao Tomé mpé Presipɛ)',
        'pt_TL' => 'lipulutugɛ́si (Timorɛ ya Moniɛlɛ)',
        'ro' => 'liromani',
        'ro_MD' => 'liromani (Molidavi)',
        'ro_RO' => 'liromani (Romani)',
        'ru' => 'lirisí',
        'ru_BY' => 'lirisí (Byelorisi)',
        'ru_KG' => 'lirisí (Kigizisitá)',
        'ru_KZ' => 'lirisí (Kazakisitá)',
        'ru_MD' => 'lirisí (Molidavi)',
        'ru_RU' => 'lirisí (Risí)',
        'ru_UA' => 'lirisí (Ikrɛni)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Rwanda)',
        'so' => 'lisomali',
        'so_DJ' => 'lisomali (Dzibuti)',
        'so_ET' => 'lisomali (Etsíopi)',
        'so_KE' => 'lisomali (Kenya)',
        'so_SO' => 'lisomali (Somali)',
        'sv' => 'lisuwedɛ',
        'sv_FI' => 'lisuwedɛ (Filandɛ)',
        'sv_SE' => 'lisuwedɛ (Swédɛ)',
        'ta' => 'litamuli',
        'ta_IN' => 'litamuli (Índɛ)',
        'ta_LK' => 'litamuli (Sirilanka)',
        'ta_MY' => 'litamuli (Malezi)',
        'ta_SG' => 'litamuli (Singapurɛ)',
        'th' => 'litaye',
        'th_TH' => 'litaye (Tailandɛ)',
        'tr' => 'litiliki',
        'tr_CY' => 'litiliki (Sípɛlɛ)',
        'tr_TR' => 'litiliki (Tiliki)',
        'uk' => 'likrɛni',
        'uk_UA' => 'likrɛni (Ikrɛni)',
        'ur' => 'liurdu',
        'ur_IN' => 'liurdu (Índɛ)',
        'ur_PK' => 'liurdu (Pakisitá)',
        'vi' => 'liviyetinámi',
        'vi_VN' => 'liviyetinámi (Viyetinamɛ)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benɛ)',
        'yo_NG' => 'yoruba (Nizerya)',
        'zh' => 'lisinwa',
        'zh_CN' => 'lisinwa (Sinɛ)',
        'zh_SG' => 'lisinwa (Singapurɛ)',
        'zh_TW' => 'lisinwa (Taiwanin)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Afríka ya Súdi)',
    ],
];
