<?php

return [
    'Names' => [
        'af' => 'afrikanščina',
        'af_NA' => 'afrikanščina (Namibija)',
        'af_ZA' => 'afrikanščina (Južnoafriška republika)',
        'ak' => 'akanščina',
        'ak_GH' => 'akanščina (Gana)',
        'am' => 'amharščina',
        'am_ET' => 'amharščina (Etiopija)',
        'ar' => 'arabščina',
        'ar_001' => 'arabščina (svet)',
        'ar_AE' => 'arabščina (Združeni arabski emirati)',
        'ar_BH' => 'arabščina (Bahrajn)',
        'ar_DJ' => 'arabščina (Džibuti)',
        'ar_DZ' => 'arabščina (Alžirija)',
        'ar_EG' => 'arabščina (Egipt)',
        'ar_EH' => 'arabščina (Zahodna Sahara)',
        'ar_ER' => 'arabščina (Eritreja)',
        'ar_IL' => 'arabščina (Izrael)',
        'ar_IQ' => 'arabščina (Irak)',
        'ar_JO' => 'arabščina (Jordanija)',
        'ar_KM' => 'arabščina (Komori)',
        'ar_KW' => 'arabščina (Kuvajt)',
        'ar_LB' => 'arabščina (Libanon)',
        'ar_LY' => 'arabščina (Libija)',
        'ar_MA' => 'arabščina (Maroko)',
        'ar_MR' => 'arabščina (Mavretanija)',
        'ar_OM' => 'arabščina (Oman)',
        'ar_PS' => 'arabščina (Palestinsko ozemlje)',
        'ar_QA' => 'arabščina (Katar)',
        'ar_SA' => 'arabščina (Saudova Arabija)',
        'ar_SD' => 'arabščina (Sudan)',
        'ar_SO' => 'arabščina (Somalija)',
        'ar_SS' => 'arabščina (Južni Sudan)',
        'ar_SY' => 'arabščina (Sirija)',
        'ar_TD' => 'arabščina (Čad)',
        'ar_TN' => 'arabščina (Tunizija)',
        'ar_YE' => 'arabščina (Jemen)',
        'as' => 'asamščina',
        'as_IN' => 'asamščina (Indija)',
        'az' => 'azerbajdžanščina',
        'az_AZ' => 'azerbajdžanščina (Azerbajdžan)',
        'az_Cyrl' => 'azerbajdžanščina (cirilica)',
        'az_Cyrl_AZ' => 'azerbajdžanščina (cirilica, Azerbajdžan)',
        'az_Latn' => 'azerbajdžanščina (latinica)',
        'az_Latn_AZ' => 'azerbajdžanščina (latinica, Azerbajdžan)',
        'be' => 'beloruščina',
        'be_BY' => 'beloruščina (Belorusija)',
        'bg' => 'bolgarščina',
        'bg_BG' => 'bolgarščina (Bolgarija)',
        'bm' => 'bambarščina',
        'bm_ML' => 'bambarščina (Mali)',
        'bn' => 'bengalščina',
        'bn_BD' => 'bengalščina (Bangladeš)',
        'bn_IN' => 'bengalščina (Indija)',
        'bo' => 'tibetanščina',
        'bo_CN' => 'tibetanščina (Kitajska)',
        'bo_IN' => 'tibetanščina (Indija)',
        'br' => 'bretonščina',
        'br_FR' => 'bretonščina (Francija)',
        'bs' => 'bosanščina',
        'bs_BA' => 'bosanščina (Bosna in Hercegovina)',
        'bs_Cyrl' => 'bosanščina (cirilica)',
        'bs_Cyrl_BA' => 'bosanščina (cirilica, Bosna in Hercegovina)',
        'bs_Latn' => 'bosanščina (latinica)',
        'bs_Latn_BA' => 'bosanščina (latinica, Bosna in Hercegovina)',
        'ca' => 'katalonščina',
        'ca_AD' => 'katalonščina (Andora)',
        'ca_ES' => 'katalonščina (Španija)',
        'ca_FR' => 'katalonščina (Francija)',
        'ca_IT' => 'katalonščina (Italija)',
        'ce' => 'čečenščina',
        'ce_RU' => 'čečenščina (Rusija)',
        'cs' => 'češčina',
        'cs_CZ' => 'češčina (Češka)',
        'cv' => 'čuvaščina',
        'cv_RU' => 'čuvaščina (Rusija)',
        'cy' => 'valižanščina',
        'cy_GB' => 'valižanščina (Združeno kraljestvo)',
        'da' => 'danščina',
        'da_DK' => 'danščina (Danska)',
        'da_GL' => 'danščina (Grenlandija)',
        'de' => 'nemščina',
        'de_AT' => 'nemščina (Avstrija)',
        'de_BE' => 'nemščina (Belgija)',
        'de_CH' => 'nemščina (Švica)',
        'de_DE' => 'nemščina (Nemčija)',
        'de_IT' => 'nemščina (Italija)',
        'de_LI' => 'nemščina (Lihtenštajn)',
        'de_LU' => 'nemščina (Luksemburg)',
        'dz' => 'dzonka',
        'dz_BT' => 'dzonka (Butan)',
        'ee' => 'evenščina',
        'ee_GH' => 'evenščina (Gana)',
        'ee_TG' => 'evenščina (Togo)',
        'el' => 'grščina',
        'el_CY' => 'grščina (Ciper)',
        'el_GR' => 'grščina (Grčija)',
        'en' => 'angleščina',
        'en_001' => 'angleščina (svet)',
        'en_150' => 'angleščina (Evropa)',
        'en_AE' => 'angleščina (Združeni arabski emirati)',
        'en_AG' => 'angleščina (Antigva in Barbuda)',
        'en_AI' => 'angleščina (Angvila)',
        'en_AS' => 'angleščina (Ameriška Samoa)',
        'en_AT' => 'angleščina (Avstrija)',
        'en_AU' => 'angleščina (Avstralija)',
        'en_BB' => 'angleščina (Barbados)',
        'en_BE' => 'angleščina (Belgija)',
        'en_BI' => 'angleščina (Burundi)',
        'en_BM' => 'angleščina (Bermudi)',
        'en_BS' => 'angleščina (Bahami)',
        'en_BW' => 'angleščina (Bocvana)',
        'en_BZ' => 'angleščina (Belize)',
        'en_CA' => 'angleščina (Kanada)',
        'en_CC' => 'angleščina (Kokosovi otoki)',
        'en_CH' => 'angleščina (Švica)',
        'en_CK' => 'angleščina (Cookovi otoki)',
        'en_CM' => 'angleščina (Kamerun)',
        'en_CX' => 'angleščina (Božični otok)',
        'en_CY' => 'angleščina (Ciper)',
        'en_DE' => 'angleščina (Nemčija)',
        'en_DK' => 'angleščina (Danska)',
        'en_DM' => 'angleščina (Dominika)',
        'en_ER' => 'angleščina (Eritreja)',
        'en_FI' => 'angleščina (Finska)',
        'en_FJ' => 'angleščina (Fidži)',
        'en_FK' => 'angleščina (Falklandski otoki)',
        'en_FM' => 'angleščina (Mikronezija)',
        'en_GB' => 'angleščina (Združeno kraljestvo)',
        'en_GD' => 'angleščina (Grenada)',
        'en_GG' => 'angleščina (Guernsey)',
        'en_GH' => 'angleščina (Gana)',
        'en_GI' => 'angleščina (Gibraltar)',
        'en_GM' => 'angleščina (Gambija)',
        'en_GU' => 'angleščina (Guam)',
        'en_GY' => 'angleščina (Gvajana)',
        'en_HK' => 'angleščina (Posebno upravno območje Ljudske republike Kitajske Hongkong)',
        'en_IE' => 'angleščina (Irska)',
        'en_IL' => 'angleščina (Izrael)',
        'en_IM' => 'angleščina (Otok Man)',
        'en_IN' => 'angleščina (Indija)',
        'en_IO' => 'angleščina (Britansko ozemlje v Indijskem oceanu)',
        'en_JE' => 'angleščina (Jersey)',
        'en_JM' => 'angleščina (Jamajka)',
        'en_KE' => 'angleščina (Kenija)',
        'en_KI' => 'angleščina (Kiribati)',
        'en_KN' => 'angleščina (Saint Kitts in Nevis)',
        'en_KY' => 'angleščina (Kajmanski otoki)',
        'en_LC' => 'angleščina (Saint Lucia)',
        'en_LR' => 'angleščina (Liberija)',
        'en_LS' => 'angleščina (Lesoto)',
        'en_MG' => 'angleščina (Madagaskar)',
        'en_MH' => 'angleščina (Marshallovi otoki)',
        'en_MO' => 'angleščina (Posebno upravno območje Ljudske republike Kitajske Macao)',
        'en_MP' => 'angleščina (Severni Marianski otoki)',
        'en_MS' => 'angleščina (Montserrat)',
        'en_MT' => 'angleščina (Malta)',
        'en_MU' => 'angleščina (Mauritius)',
        'en_MV' => 'angleščina (Maldivi)',
        'en_MW' => 'angleščina (Malavi)',
        'en_MY' => 'angleščina (Malezija)',
        'en_NA' => 'angleščina (Namibija)',
        'en_NF' => 'angleščina (Norfolški otok)',
        'en_NG' => 'angleščina (Nigerija)',
        'en_NL' => 'angleščina (Nizozemska)',
        'en_NR' => 'angleščina (Nauru)',
        'en_NU' => 'angleščina (Niue)',
        'en_NZ' => 'angleščina (Nova Zelandija)',
        'en_PG' => 'angleščina (Papua Nova Gvineja)',
        'en_PH' => 'angleščina (Filipini)',
        'en_PK' => 'angleščina (Pakistan)',
        'en_PN' => 'angleščina (Pitcairn)',
        'en_PR' => 'angleščina (Portoriko)',
        'en_PW' => 'angleščina (Palau)',
        'en_RW' => 'angleščina (Ruanda)',
        'en_SB' => 'angleščina (Salomonovi otoki)',
        'en_SC' => 'angleščina (Sejšeli)',
        'en_SD' => 'angleščina (Sudan)',
        'en_SE' => 'angleščina (Švedska)',
        'en_SG' => 'angleščina (Singapur)',
        'en_SH' => 'angleščina (Sveta Helena)',
        'en_SI' => 'angleščina (Slovenija)',
        'en_SL' => 'angleščina (Sierra Leone)',
        'en_SS' => 'angleščina (Južni Sudan)',
        'en_SX' => 'angleščina (Sint Maarten)',
        'en_SZ' => 'angleščina (Esvatini)',
        'en_TC' => 'angleščina (Otoki Turks in Caicos)',
        'en_TK' => 'angleščina (Tokelau)',
        'en_TO' => 'angleščina (Tonga)',
        'en_TT' => 'angleščina (Trinidad in Tobago)',
        'en_TV' => 'angleščina (Tuvalu)',
        'en_TZ' => 'angleščina (Tanzanija)',
        'en_UG' => 'angleščina (Uganda)',
        'en_UM' => 'angleščina (Stranski zunanji otoki Združenih držav)',
        'en_US' => 'angleščina (Združene države Amerike)',
        'en_VC' => 'angleščina (Saint Vincent in Grenadine)',
        'en_VG' => 'angleščina (Britanski Deviški otoki)',
        'en_VI' => 'angleščina (Ameriški Deviški otoki)',
        'en_VU' => 'angleščina (Vanuatu)',
        'en_WS' => 'angleščina (Samoa)',
        'en_ZA' => 'angleščina (Južnoafriška republika)',
        'en_ZM' => 'angleščina (Zambija)',
        'en_ZW' => 'angleščina (Zimbabve)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (svet)',
        'es' => 'španščina',
        'es_419' => 'španščina (Latinska Amerika)',
        'es_AR' => 'španščina (Argentina)',
        'es_BO' => 'španščina (Bolivija)',
        'es_BR' => 'španščina (Brazilija)',
        'es_BZ' => 'španščina (Belize)',
        'es_CL' => 'španščina (Čile)',
        'es_CO' => 'španščina (Kolumbija)',
        'es_CR' => 'španščina (Kostarika)',
        'es_CU' => 'španščina (Kuba)',
        'es_DO' => 'španščina (Dominikanska republika)',
        'es_EC' => 'španščina (Ekvador)',
        'es_ES' => 'španščina (Španija)',
        'es_GQ' => 'španščina (Ekvatorialna Gvineja)',
        'es_GT' => 'španščina (Gvatemala)',
        'es_HN' => 'španščina (Honduras)',
        'es_MX' => 'španščina (Mehika)',
        'es_NI' => 'španščina (Nikaragva)',
        'es_PA' => 'španščina (Panama)',
        'es_PE' => 'španščina (Peru)',
        'es_PH' => 'španščina (Filipini)',
        'es_PR' => 'španščina (Portoriko)',
        'es_PY' => 'španščina (Paragvaj)',
        'es_SV' => 'španščina (Salvador)',
        'es_US' => 'španščina (Združene države Amerike)',
        'es_UY' => 'španščina (Urugvaj)',
        'es_VE' => 'španščina (Venezuela)',
        'et' => 'estonščina',
        'et_EE' => 'estonščina (Estonija)',
        'eu' => 'baskovščina',
        'eu_ES' => 'baskovščina (Španija)',
        'fa' => 'perzijščina',
        'fa_AF' => 'perzijščina (Afganistan)',
        'fa_IR' => 'perzijščina (Iran)',
        'ff' => 'fulščina',
        'ff_Adlm' => 'fulščina (adlamski)',
        'ff_Adlm_BF' => 'fulščina (adlamski, Burkina Faso)',
        'ff_Adlm_CM' => 'fulščina (adlamski, Kamerun)',
        'ff_Adlm_GH' => 'fulščina (adlamski, Gana)',
        'ff_Adlm_GM' => 'fulščina (adlamski, Gambija)',
        'ff_Adlm_GN' => 'fulščina (adlamski, Gvineja)',
        'ff_Adlm_GW' => 'fulščina (adlamski, Gvineja Bissau)',
        'ff_Adlm_LR' => 'fulščina (adlamski, Liberija)',
        'ff_Adlm_MR' => 'fulščina (adlamski, Mavretanija)',
        'ff_Adlm_NE' => 'fulščina (adlamski, Niger)',
        'ff_Adlm_NG' => 'fulščina (adlamski, Nigerija)',
        'ff_Adlm_SL' => 'fulščina (adlamski, Sierra Leone)',
        'ff_Adlm_SN' => 'fulščina (adlamski, Senegal)',
        'ff_CM' => 'fulščina (Kamerun)',
        'ff_GN' => 'fulščina (Gvineja)',
        'ff_Latn' => 'fulščina (latinica)',
        'ff_Latn_BF' => 'fulščina (latinica, Burkina Faso)',
        'ff_Latn_CM' => 'fulščina (latinica, Kamerun)',
        'ff_Latn_GH' => 'fulščina (latinica, Gana)',
        'ff_Latn_GM' => 'fulščina (latinica, Gambija)',
        'ff_Latn_GN' => 'fulščina (latinica, Gvineja)',
        'ff_Latn_GW' => 'fulščina (latinica, Gvineja Bissau)',
        'ff_Latn_LR' => 'fulščina (latinica, Liberija)',
        'ff_Latn_MR' => 'fulščina (latinica, Mavretanija)',
        'ff_Latn_NE' => 'fulščina (latinica, Niger)',
        'ff_Latn_NG' => 'fulščina (latinica, Nigerija)',
        'ff_Latn_SL' => 'fulščina (latinica, Sierra Leone)',
        'ff_Latn_SN' => 'fulščina (latinica, Senegal)',
        'ff_MR' => 'fulščina (Mavretanija)',
        'ff_SN' => 'fulščina (Senegal)',
        'fi' => 'finščina',
        'fi_FI' => 'finščina (Finska)',
        'fo' => 'ferščina',
        'fo_DK' => 'ferščina (Danska)',
        'fo_FO' => 'ferščina (Ferski otoki)',
        'fr' => 'francoščina',
        'fr_BE' => 'francoščina (Belgija)',
        'fr_BF' => 'francoščina (Burkina Faso)',
        'fr_BI' => 'francoščina (Burundi)',
        'fr_BJ' => 'francoščina (Benin)',
        'fr_BL' => 'francoščina (Saint Barthélemy)',
        'fr_CA' => 'francoščina (Kanada)',
        'fr_CD' => 'francoščina (Demokratična republika Kongo)',
        'fr_CF' => 'francoščina (Srednjeafriška republika)',
        'fr_CG' => 'francoščina (Kongo - Brazzaville)',
        'fr_CH' => 'francoščina (Švica)',
        'fr_CI' => 'francoščina (Slonokoščena obala)',
        'fr_CM' => 'francoščina (Kamerun)',
        'fr_DJ' => 'francoščina (Džibuti)',
        'fr_DZ' => 'francoščina (Alžirija)',
        'fr_FR' => 'francoščina (Francija)',
        'fr_GA' => 'francoščina (Gabon)',
        'fr_GF' => 'francoščina (Francoska Gvajana)',
        'fr_GN' => 'francoščina (Gvineja)',
        'fr_GP' => 'francoščina (Guadeloupe)',
        'fr_GQ' => 'francoščina (Ekvatorialna Gvineja)',
        'fr_HT' => 'francoščina (Haiti)',
        'fr_KM' => 'francoščina (Komori)',
        'fr_LU' => 'francoščina (Luksemburg)',
        'fr_MA' => 'francoščina (Maroko)',
        'fr_MC' => 'francoščina (Monako)',
        'fr_MF' => 'francoščina (Saint Martin)',
        'fr_MG' => 'francoščina (Madagaskar)',
        'fr_ML' => 'francoščina (Mali)',
        'fr_MQ' => 'francoščina (Martinik)',
        'fr_MR' => 'francoščina (Mavretanija)',
        'fr_MU' => 'francoščina (Mauritius)',
        'fr_NC' => 'francoščina (Nova Kaledonija)',
        'fr_NE' => 'francoščina (Niger)',
        'fr_PF' => 'francoščina (Francoska Polinezija)',
        'fr_PM' => 'francoščina (Saint Pierre in Miquelon)',
        'fr_RE' => 'francoščina (Reunion)',
        'fr_RW' => 'francoščina (Ruanda)',
        'fr_SC' => 'francoščina (Sejšeli)',
        'fr_SN' => 'francoščina (Senegal)',
        'fr_SY' => 'francoščina (Sirija)',
        'fr_TD' => 'francoščina (Čad)',
        'fr_TG' => 'francoščina (Togo)',
        'fr_TN' => 'francoščina (Tunizija)',
        'fr_VU' => 'francoščina (Vanuatu)',
        'fr_WF' => 'francoščina (Wallis in Futuna)',
        'fr_YT' => 'francoščina (Mayotte)',
        'fy' => 'zahodna frizijščina',
        'fy_NL' => 'zahodna frizijščina (Nizozemska)',
        'ga' => 'irščina',
        'ga_GB' => 'irščina (Združeno kraljestvo)',
        'ga_IE' => 'irščina (Irska)',
        'gd' => 'škotska gelščina',
        'gd_GB' => 'škotska gelščina (Združeno kraljestvo)',
        'gl' => 'galicijščina',
        'gl_ES' => 'galicijščina (Španija)',
        'gu' => 'gudžaratščina',
        'gu_IN' => 'gudžaratščina (Indija)',
        'gv' => 'manščina',
        'gv_IM' => 'manščina (Otok Man)',
        'ha' => 'havščina',
        'ha_GH' => 'havščina (Gana)',
        'ha_NE' => 'havščina (Niger)',
        'ha_NG' => 'havščina (Nigerija)',
        'he' => 'hebrejščina',
        'he_IL' => 'hebrejščina (Izrael)',
        'hi' => 'hindijščina',
        'hi_IN' => 'hindijščina (Indija)',
        'hi_Latn' => 'hindijščina (latinica)',
        'hi_Latn_IN' => 'hindijščina (latinica, Indija)',
        'hr' => 'hrvaščina',
        'hr_BA' => 'hrvaščina (Bosna in Hercegovina)',
        'hr_HR' => 'hrvaščina (Hrvaška)',
        'hu' => 'madžarščina',
        'hu_HU' => 'madžarščina (Madžarska)',
        'hy' => 'armenščina',
        'hy_AM' => 'armenščina (Armenija)',
        'ia' => 'interlingva',
        'ia_001' => 'interlingva (svet)',
        'id' => 'indonezijščina',
        'id_ID' => 'indonezijščina (Indonezija)',
        'ig' => 'igboščina',
        'ig_NG' => 'igboščina (Nigerija)',
        'ii' => 'sečuanska jiščina',
        'ii_CN' => 'sečuanska jiščina (Kitajska)',
        'is' => 'islandščina',
        'is_IS' => 'islandščina (Islandija)',
        'it' => 'italijanščina',
        'it_CH' => 'italijanščina (Švica)',
        'it_IT' => 'italijanščina (Italija)',
        'it_SM' => 'italijanščina (San Marino)',
        'it_VA' => 'italijanščina (Vatikan)',
        'ja' => 'japonščina',
        'ja_JP' => 'japonščina (Japonska)',
        'jv' => 'javanščina',
        'jv_ID' => 'javanščina (Indonezija)',
        'ka' => 'gruzijščina',
        'ka_GE' => 'gruzijščina (Gruzija)',
        'ki' => 'kikujščina',
        'ki_KE' => 'kikujščina (Kenija)',
        'kk' => 'kazaščina',
        'kk_KZ' => 'kazaščina (Kazahstan)',
        'kl' => 'grenlandščina',
        'kl_GL' => 'grenlandščina (Grenlandija)',
        'km' => 'kmerščina',
        'km_KH' => 'kmerščina (Kambodža)',
        'kn' => 'kanareščina',
        'kn_IN' => 'kanareščina (Indija)',
        'ko' => 'korejščina',
        'ko_KP' => 'korejščina (Severna Koreja)',
        'ko_KR' => 'korejščina (Južna Koreja)',
        'ks' => 'kašmirščina',
        'ks_Arab' => 'kašmirščina (arabski)',
        'ks_Arab_IN' => 'kašmirščina (arabski, Indija)',
        'ks_Deva' => 'kašmirščina (devanagarščica)',
        'ks_Deva_IN' => 'kašmirščina (devanagarščica, Indija)',
        'ks_IN' => 'kašmirščina (Indija)',
        'ku' => 'kurdščina',
        'ku_TR' => 'kurdščina (Turčija)',
        'kw' => 'kornijščina',
        'kw_GB' => 'kornijščina (Združeno kraljestvo)',
        'ky' => 'kirgiščina',
        'ky_KG' => 'kirgiščina (Kirgizistan)',
        'lb' => 'luksemburščina',
        'lb_LU' => 'luksemburščina (Luksemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Demokratična republika Kongo)',
        'ln_CF' => 'lingala (Srednjeafriška republika)',
        'ln_CG' => 'lingala (Kongo - Brazzaville)',
        'lo' => 'laoščina',
        'lo_LA' => 'laoščina (Laos)',
        'lt' => 'litovščina',
        'lt_LT' => 'litovščina (Litva)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Demokratična republika Kongo)',
        'lv' => 'latvijščina',
        'lv_LV' => 'latvijščina (Latvija)',
        'mg' => 'malgaščina',
        'mg_MG' => 'malgaščina (Madagaskar)',
        'mi' => 'maorščina',
        'mi_NZ' => 'maorščina (Nova Zelandija)',
        'mk' => 'makedonščina',
        'mk_MK' => 'makedonščina (Severna Makedonija)',
        'ml' => 'malajalamščina',
        'ml_IN' => 'malajalamščina (Indija)',
        'mn' => 'mongolščina',
        'mn_MN' => 'mongolščina (Mongolija)',
        'mr' => 'maratščina',
        'mr_IN' => 'maratščina (Indija)',
        'ms' => 'malajščina',
        'ms_BN' => 'malajščina (Brunej)',
        'ms_ID' => 'malajščina (Indonezija)',
        'ms_MY' => 'malajščina (Malezija)',
        'ms_SG' => 'malajščina (Singapur)',
        'mt' => 'malteščina',
        'mt_MT' => 'malteščina (Malta)',
        'my' => 'burmanščina',
        'my_MM' => 'burmanščina (Mjanmar [Burma])',
        'nb' => 'knjižna norveščina',
        'nb_NO' => 'knjižna norveščina (Norveška)',
        'nb_SJ' => 'knjižna norveščina (Svalbard in Jan Mayen)',
        'nd' => 'severna ndebelščina',
        'nd_ZW' => 'severna ndebelščina (Zimbabve)',
        'ne' => 'nepalščina',
        'ne_IN' => 'nepalščina (Indija)',
        'ne_NP' => 'nepalščina (Nepal)',
        'nl' => 'nizozemščina',
        'nl_AW' => 'nizozemščina (Aruba)',
        'nl_BE' => 'nizozemščina (Belgija)',
        'nl_BQ' => 'nizozemščina (Nizozemski Karibi)',
        'nl_CW' => 'nizozemščina (Curaçao)',
        'nl_NL' => 'nizozemščina (Nizozemska)',
        'nl_SR' => 'nizozemščina (Surinam)',
        'nl_SX' => 'nizozemščina (Sint Maarten)',
        'nn' => 'novonorveščina',
        'nn_NO' => 'novonorveščina (Norveška)',
        'no' => 'norveščina',
        'no_NO' => 'norveščina (Norveška)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopija)',
        'om_KE' => 'oromo (Kenija)',
        'or' => 'odijščina',
        'or_IN' => 'odijščina (Indija)',
        'os' => 'osetinščina',
        'os_GE' => 'osetinščina (Gruzija)',
        'os_RU' => 'osetinščina (Rusija)',
        'pa' => 'pandžabščina',
        'pa_Arab' => 'pandžabščina (arabski)',
        'pa_Arab_PK' => 'pandžabščina (arabski, Pakistan)',
        'pa_Guru' => 'pandžabščina (gurmuki)',
        'pa_Guru_IN' => 'pandžabščina (gurmuki, Indija)',
        'pa_IN' => 'pandžabščina (Indija)',
        'pa_PK' => 'pandžabščina (Pakistan)',
        'pl' => 'poljščina',
        'pl_PL' => 'poljščina (Poljska)',
        'ps' => 'paštunščina',
        'ps_AF' => 'paštunščina (Afganistan)',
        'ps_PK' => 'paštunščina (Pakistan)',
        'pt' => 'portugalščina',
        'pt_AO' => 'portugalščina (Angola)',
        'pt_BR' => 'portugalščina (Brazilija)',
        'pt_CH' => 'portugalščina (Švica)',
        'pt_CV' => 'portugalščina (Zelenortski otoki)',
        'pt_GQ' => 'portugalščina (Ekvatorialna Gvineja)',
        'pt_GW' => 'portugalščina (Gvineja Bissau)',
        'pt_LU' => 'portugalščina (Luksemburg)',
        'pt_MO' => 'portugalščina (Posebno upravno območje Ljudske republike Kitajske Macao)',
        'pt_MZ' => 'portugalščina (Mozambik)',
        'pt_PT' => 'portugalščina (Portugalska)',
        'pt_ST' => 'portugalščina (Sao Tome in Principe)',
        'pt_TL' => 'portugalščina (Timor-Leste)',
        'qu' => 'kečuanščina',
        'qu_BO' => 'kečuanščina (Bolivija)',
        'qu_EC' => 'kečuanščina (Ekvador)',
        'qu_PE' => 'kečuanščina (Peru)',
        'rm' => 'retoromanščina',
        'rm_CH' => 'retoromanščina (Švica)',
        'rn' => 'rundščina',
        'rn_BI' => 'rundščina (Burundi)',
        'ro' => 'romunščina',
        'ro_MD' => 'romunščina (Moldavija)',
        'ro_RO' => 'romunščina (Romunija)',
        'ru' => 'ruščina',
        'ru_BY' => 'ruščina (Belorusija)',
        'ru_KG' => 'ruščina (Kirgizistan)',
        'ru_KZ' => 'ruščina (Kazahstan)',
        'ru_MD' => 'ruščina (Moldavija)',
        'ru_RU' => 'ruščina (Rusija)',
        'ru_UA' => 'ruščina (Ukrajina)',
        'rw' => 'ruandščina',
        'rw_RW' => 'ruandščina (Ruanda)',
        'sa' => 'sanskrt',
        'sa_IN' => 'sanskrt (Indija)',
        'sc' => 'sardinščina',
        'sc_IT' => 'sardinščina (Italija)',
        'sd' => 'sindščina',
        'sd_Arab' => 'sindščina (arabski)',
        'sd_Arab_PK' => 'sindščina (arabski, Pakistan)',
        'sd_Deva' => 'sindščina (devanagarščica)',
        'sd_Deva_IN' => 'sindščina (devanagarščica, Indija)',
        'sd_IN' => 'sindščina (Indija)',
        'sd_PK' => 'sindščina (Pakistan)',
        'se' => 'severna samijščina',
        'se_FI' => 'severna samijščina (Finska)',
        'se_NO' => 'severna samijščina (Norveška)',
        'se_SE' => 'severna samijščina (Švedska)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Srednjeafriška republika)',
        'sh' => 'srbohrvaščina',
        'sh_BA' => 'srbohrvaščina (Bosna in Hercegovina)',
        'si' => 'sinhalščina',
        'si_LK' => 'sinhalščina (Šrilanka)',
        'sk' => 'slovaščina',
        'sk_SK' => 'slovaščina (Slovaška)',
        'sl' => 'slovenščina',
        'sl_SI' => 'slovenščina (Slovenija)',
        'sn' => 'šonščina',
        'sn_ZW' => 'šonščina (Zimbabve)',
        'so' => 'somalščina',
        'so_DJ' => 'somalščina (Džibuti)',
        'so_ET' => 'somalščina (Etiopija)',
        'so_KE' => 'somalščina (Kenija)',
        'so_SO' => 'somalščina (Somalija)',
        'sq' => 'albanščina',
        'sq_AL' => 'albanščina (Albanija)',
        'sq_MK' => 'albanščina (Severna Makedonija)',
        'sr' => 'srbščina',
        'sr_BA' => 'srbščina (Bosna in Hercegovina)',
        'sr_Cyrl' => 'srbščina (cirilica)',
        'sr_Cyrl_BA' => 'srbščina (cirilica, Bosna in Hercegovina)',
        'sr_Cyrl_ME' => 'srbščina (cirilica, Črna gora)',
        'sr_Cyrl_RS' => 'srbščina (cirilica, Srbija)',
        'sr_Latn' => 'srbščina (latinica)',
        'sr_Latn_BA' => 'srbščina (latinica, Bosna in Hercegovina)',
        'sr_Latn_ME' => 'srbščina (latinica, Črna gora)',
        'sr_Latn_RS' => 'srbščina (latinica, Srbija)',
        'sr_ME' => 'srbščina (Črna gora)',
        'sr_RS' => 'srbščina (Srbija)',
        'su' => 'sundanščina',
        'su_ID' => 'sundanščina (Indonezija)',
        'su_Latn' => 'sundanščina (latinica)',
        'su_Latn_ID' => 'sundanščina (latinica, Indonezija)',
        'sv' => 'švedščina',
        'sv_AX' => 'švedščina (Ålandski otoki)',
        'sv_FI' => 'švedščina (Finska)',
        'sv_SE' => 'švedščina (Švedska)',
        'sw' => 'svahili',
        'sw_CD' => 'svahili (Demokratična republika Kongo)',
        'sw_KE' => 'svahili (Kenija)',
        'sw_TZ' => 'svahili (Tanzanija)',
        'sw_UG' => 'svahili (Uganda)',
        'ta' => 'tamilščina',
        'ta_IN' => 'tamilščina (Indija)',
        'ta_LK' => 'tamilščina (Šrilanka)',
        'ta_MY' => 'tamilščina (Malezija)',
        'ta_SG' => 'tamilščina (Singapur)',
        'te' => 'telugijščina',
        'te_IN' => 'telugijščina (Indija)',
        'tg' => 'tadžiščina',
        'tg_TJ' => 'tadžiščina (Tadžikistan)',
        'th' => 'tajščina',
        'th_TH' => 'tajščina (Tajska)',
        'ti' => 'tigrajščina',
        'ti_ER' => 'tigrajščina (Eritreja)',
        'ti_ET' => 'tigrajščina (Etiopija)',
        'tk' => 'turkmenščina',
        'tk_TM' => 'turkmenščina (Turkmenistan)',
        'tl' => 'tagalogščina',
        'tl_PH' => 'tagalogščina (Filipini)',
        'to' => 'tongščina',
        'to_TO' => 'tongščina (Tonga)',
        'tr' => 'turščina',
        'tr_CY' => 'turščina (Ciper)',
        'tr_TR' => 'turščina (Turčija)',
        'tt' => 'tatarščina',
        'tt_RU' => 'tatarščina (Rusija)',
        'ug' => 'ujgurščina',
        'ug_CN' => 'ujgurščina (Kitajska)',
        'uk' => 'ukrajinščina',
        'uk_UA' => 'ukrajinščina (Ukrajina)',
        'ur' => 'urdujščina',
        'ur_IN' => 'urdujščina (Indija)',
        'ur_PK' => 'urdujščina (Pakistan)',
        'uz' => 'uzbeščina',
        'uz_AF' => 'uzbeščina (Afganistan)',
        'uz_Arab' => 'uzbeščina (arabski)',
        'uz_Arab_AF' => 'uzbeščina (arabski, Afganistan)',
        'uz_Cyrl' => 'uzbeščina (cirilica)',
        'uz_Cyrl_UZ' => 'uzbeščina (cirilica, Uzbekistan)',
        'uz_Latn' => 'uzbeščina (latinica)',
        'uz_Latn_UZ' => 'uzbeščina (latinica, Uzbekistan)',
        'uz_UZ' => 'uzbeščina (Uzbekistan)',
        'vi' => 'vietnamščina',
        'vi_VN' => 'vietnamščina (Vietnam)',
        'wo' => 'volofščina',
        'wo_SN' => 'volofščina (Senegal)',
        'xh' => 'koščina',
        'xh_ZA' => 'koščina (Južnoafriška republika)',
        'yi' => 'jidiš',
        'yi_001' => 'jidiš (svet)',
        'yo' => 'jorubščina',
        'yo_BJ' => 'jorubščina (Benin)',
        'yo_NG' => 'jorubščina (Nigerija)',
        'zh' => 'kitajščina',
        'zh_CN' => 'kitajščina (Kitajska)',
        'zh_HK' => 'kitajščina (Posebno upravno območje Ljudske republike Kitajske Hongkong)',
        'zh_Hans' => 'kitajščina (poenostavljena pisava)',
        'zh_Hans_CN' => 'kitajščina (poenostavljena pisava, Kitajska)',
        'zh_Hans_HK' => 'kitajščina (poenostavljena pisava, Posebno upravno območje Ljudske republike Kitajske Hongkong)',
        'zh_Hans_MO' => 'kitajščina (poenostavljena pisava, Posebno upravno območje Ljudske republike Kitajske Macao)',
        'zh_Hans_SG' => 'kitajščina (poenostavljena pisava, Singapur)',
        'zh_Hant' => 'kitajščina (tradicionalna pisava)',
        'zh_Hant_HK' => 'kitajščina (tradicionalna pisava, Posebno upravno območje Ljudske republike Kitajske Hongkong)',
        'zh_Hant_MO' => 'kitajščina (tradicionalna pisava, Posebno upravno območje Ljudske republike Kitajske Macao)',
        'zh_Hant_TW' => 'kitajščina (tradicionalna pisava, Tajvan)',
        'zh_MO' => 'kitajščina (Posebno upravno območje Ljudske republike Kitajske Macao)',
        'zh_SG' => 'kitajščina (Singapur)',
        'zh_TW' => 'kitajščina (Tajvan)',
        'zu' => 'zulujščina',
        'zu_ZA' => 'zulujščina (Južnoafriška republika)',
    ],
];
