<?php

return [
    'Names' => [
        'af' => 'Afrikaanca',
        'af_NA' => 'Afrikaanca (Namibya)',
        'af_ZA' => 'Afrikaanca (Güney Afrika)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Gana)',
        'am' => 'Amharca',
        'am_ET' => 'Amharca (Etiyopya)',
        'ar' => 'Arapça',
        'ar_001' => 'Arapça (Dünya)',
        'ar_AE' => 'Arapça (Birleşik Arap Emirlikleri)',
        'ar_BH' => 'Arapça (Bahreyn)',
        'ar_DJ' => 'Arapça (Cibuti)',
        'ar_DZ' => 'Arapça (Cezayir)',
        'ar_EG' => 'Arapça (Mısır)',
        'ar_EH' => 'Arapça (Batı Sahra)',
        'ar_ER' => 'Arapça (Eritre)',
        'ar_IL' => 'Arapça (İsrail)',
        'ar_IQ' => 'Arapça (Irak)',
        'ar_JO' => 'Arapça (Ürdün)',
        'ar_KM' => 'Arapça (Komorlar)',
        'ar_KW' => 'Arapça (Kuveyt)',
        'ar_LB' => 'Arapça (Lübnan)',
        'ar_LY' => 'Arapça (Libya)',
        'ar_MA' => 'Arapça (Fas)',
        'ar_MR' => 'Arapça (Moritanya)',
        'ar_OM' => 'Arapça (Umman)',
        'ar_PS' => 'Arapça (Filistin Bölgeleri)',
        'ar_QA' => 'Arapça (Katar)',
        'ar_SA' => 'Arapça (Suudi Arabistan)',
        'ar_SD' => 'Arapça (Sudan)',
        'ar_SO' => 'Arapça (Somali)',
        'ar_SS' => 'Arapça (Güney Sudan)',
        'ar_SY' => 'Arapça (Suriye)',
        'ar_TD' => 'Arapça (Çad)',
        'ar_TN' => 'Arapça (Tunus)',
        'ar_YE' => 'Arapça (Yemen)',
        'as' => 'Assamca',
        'as_IN' => 'Assamca (Hindistan)',
        'az' => 'Azerbaycan dili',
        'az_AZ' => 'Azerbaycan dili (Azerbaycan)',
        'az_Cyrl' => 'Azerbaycan dili (Kiril)',
        'az_Cyrl_AZ' => 'Azerbaycan dili (Kiril, Azerbaycan)',
        'az_Latn' => 'Azerbaycan dili (Latin)',
        'az_Latn_AZ' => 'Azerbaycan dili (Latin, Azerbaycan)',
        'be' => 'Belarusça',
        'be_BY' => 'Belarusça (Belarus)',
        'bg' => 'Bulgarca',
        'bg_BG' => 'Bulgarca (Bulgaristan)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengalce',
        'bn_BD' => 'Bengalce (Bangladeş)',
        'bn_IN' => 'Bengalce (Hindistan)',
        'bo' => 'Tibetçe',
        'bo_CN' => 'Tibetçe (Çin)',
        'bo_IN' => 'Tibetçe (Hindistan)',
        'br' => 'Bretonca',
        'br_FR' => 'Bretonca (Fransa)',
        'bs' => 'Boşnakça',
        'bs_BA' => 'Boşnakça (Bosna-Hersek)',
        'bs_Cyrl' => 'Boşnakça (Kiril)',
        'bs_Cyrl_BA' => 'Boşnakça (Kiril, Bosna-Hersek)',
        'bs_Latn' => 'Boşnakça (Latin)',
        'bs_Latn_BA' => 'Boşnakça (Latin, Bosna-Hersek)',
        'ca' => 'Katalanca',
        'ca_AD' => 'Katalanca (Andorra)',
        'ca_ES' => 'Katalanca (İspanya)',
        'ca_FR' => 'Katalanca (Fransa)',
        'ca_IT' => 'Katalanca (İtalya)',
        'ce' => 'Çeçence',
        'ce_RU' => 'Çeçence (Rusya)',
        'cs' => 'Çekçe',
        'cs_CZ' => 'Çekçe (Çekya)',
        'cv' => 'Çuvaşça',
        'cv_RU' => 'Çuvaşça (Rusya)',
        'cy' => 'Galce',
        'cy_GB' => 'Galce (Birleşik Krallık)',
        'da' => 'Danca',
        'da_DK' => 'Danca (Danimarka)',
        'da_GL' => 'Danca (Grönland)',
        'de' => 'Almanca',
        'de_AT' => 'Almanca (Avusturya)',
        'de_BE' => 'Almanca (Belçika)',
        'de_CH' => 'Almanca (İsviçre)',
        'de_DE' => 'Almanca (Almanya)',
        'de_IT' => 'Almanca (İtalya)',
        'de_LI' => 'Almanca (Liechtenstein)',
        'de_LU' => 'Almanca (Lüksemburg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Butan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Gana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Yunanca',
        'el_CY' => 'Yunanca (Kıbrıs)',
        'el_GR' => 'Yunanca (Yunanistan)',
        'en' => 'İngilizce',
        'en_001' => 'İngilizce (Dünya)',
        'en_150' => 'İngilizce (Avrupa)',
        'en_AE' => 'İngilizce (Birleşik Arap Emirlikleri)',
        'en_AG' => 'İngilizce (Antigua ve Barbuda)',
        'en_AI' => 'İngilizce (Anguilla)',
        'en_AS' => 'İngilizce (Amerikan Samoası)',
        'en_AT' => 'İngilizce (Avusturya)',
        'en_AU' => 'İngilizce (Avustralya)',
        'en_BB' => 'İngilizce (Barbados)',
        'en_BE' => 'İngilizce (Belçika)',
        'en_BI' => 'İngilizce (Burundi)',
        'en_BM' => 'İngilizce (Bermuda)',
        'en_BS' => 'İngilizce (Bahamalar)',
        'en_BW' => 'İngilizce (Botsvana)',
        'en_BZ' => 'İngilizce (Belize)',
        'en_CA' => 'İngilizce (Kanada)',
        'en_CC' => 'İngilizce (Cocos [Keeling] Adaları)',
        'en_CH' => 'İngilizce (İsviçre)',
        'en_CK' => 'İngilizce (Cook Adaları)',
        'en_CM' => 'İngilizce (Kamerun)',
        'en_CX' => 'İngilizce (Christmas Adası)',
        'en_CY' => 'İngilizce (Kıbrıs)',
        'en_DE' => 'İngilizce (Almanya)',
        'en_DK' => 'İngilizce (Danimarka)',
        'en_DM' => 'İngilizce (Dominika)',
        'en_ER' => 'İngilizce (Eritre)',
        'en_FI' => 'İngilizce (Finlandiya)',
        'en_FJ' => 'İngilizce (Fiji)',
        'en_FK' => 'İngilizce (Falkland Adaları)',
        'en_FM' => 'İngilizce (Mikronezya)',
        'en_GB' => 'İngilizce (Birleşik Krallık)',
        'en_GD' => 'İngilizce (Grenada)',
        'en_GG' => 'İngilizce (Guernsey)',
        'en_GH' => 'İngilizce (Gana)',
        'en_GI' => 'İngilizce (Cebelitarık)',
        'en_GM' => 'İngilizce (Gambiya)',
        'en_GU' => 'İngilizce (Guam)',
        'en_GY' => 'İngilizce (Guyana)',
        'en_HK' => 'İngilizce (Çin Hong Kong ÖİB)',
        'en_IE' => 'İngilizce (İrlanda)',
        'en_IL' => 'İngilizce (İsrail)',
        'en_IM' => 'İngilizce (Man Adası)',
        'en_IN' => 'İngilizce (Hindistan)',
        'en_IO' => 'İngilizce (Britanya Hint Okyanusu Toprakları)',
        'en_JE' => 'İngilizce (Jersey)',
        'en_JM' => 'İngilizce (Jamaika)',
        'en_KE' => 'İngilizce (Kenya)',
        'en_KI' => 'İngilizce (Kiribati)',
        'en_KN' => 'İngilizce (Saint Kitts ve Nevis)',
        'en_KY' => 'İngilizce (Cayman Adaları)',
        'en_LC' => 'İngilizce (Saint Lucia)',
        'en_LR' => 'İngilizce (Liberya)',
        'en_LS' => 'İngilizce (Lesotho)',
        'en_MG' => 'İngilizce (Madagaskar)',
        'en_MH' => 'İngilizce (Marshall Adaları)',
        'en_MO' => 'İngilizce (Çin Makao ÖİB)',
        'en_MP' => 'İngilizce (Kuzey Mariana Adaları)',
        'en_MS' => 'İngilizce (Montserrat)',
        'en_MT' => 'İngilizce (Malta)',
        'en_MU' => 'İngilizce (Mauritius)',
        'en_MV' => 'İngilizce (Maldivler)',
        'en_MW' => 'İngilizce (Malavi)',
        'en_MY' => 'İngilizce (Malezya)',
        'en_NA' => 'İngilizce (Namibya)',
        'en_NF' => 'İngilizce (Norfolk Adası)',
        'en_NG' => 'İngilizce (Nijerya)',
        'en_NL' => 'İngilizce (Hollanda)',
        'en_NR' => 'İngilizce (Nauru)',
        'en_NU' => 'İngilizce (Niue)',
        'en_NZ' => 'İngilizce (Yeni Zelanda)',
        'en_PG' => 'İngilizce (Papua Yeni Gine)',
        'en_PH' => 'İngilizce (Filipinler)',
        'en_PK' => 'İngilizce (Pakistan)',
        'en_PN' => 'İngilizce (Pitcairn Adaları)',
        'en_PR' => 'İngilizce (Porto Riko)',
        'en_PW' => 'İngilizce (Palau)',
        'en_RW' => 'İngilizce (Ruanda)',
        'en_SB' => 'İngilizce (Solomon Adaları)',
        'en_SC' => 'İngilizce (Seyşeller)',
        'en_SD' => 'İngilizce (Sudan)',
        'en_SE' => 'İngilizce (İsveç)',
        'en_SG' => 'İngilizce (Singapur)',
        'en_SH' => 'İngilizce (Saint Helena)',
        'en_SI' => 'İngilizce (Slovenya)',
        'en_SL' => 'İngilizce (Sierra Leone)',
        'en_SS' => 'İngilizce (Güney Sudan)',
        'en_SX' => 'İngilizce (Sint Maarten)',
        'en_SZ' => 'İngilizce (Esvatini)',
        'en_TC' => 'İngilizce (Turks ve Caicos Adaları)',
        'en_TK' => 'İngilizce (Tokelau)',
        'en_TO' => 'İngilizce (Tonga)',
        'en_TT' => 'İngilizce (Trinidad ve Tobago)',
        'en_TV' => 'İngilizce (Tuvalu)',
        'en_TZ' => 'İngilizce (Tanzanya)',
        'en_UG' => 'İngilizce (Uganda)',
        'en_UM' => 'İngilizce (ABD Küçük Harici Adaları)',
        'en_US' => 'İngilizce (Amerika Birleşik Devletleri)',
        'en_VC' => 'İngilizce (Saint Vincent ve Grenadinler)',
        'en_VG' => 'İngilizce (Britanya Virjin Adaları)',
        'en_VI' => 'İngilizce (ABD Virjin Adaları)',
        'en_VU' => 'İngilizce (Vanuatu)',
        'en_WS' => 'İngilizce (Samoa)',
        'en_ZA' => 'İngilizce (Güney Afrika)',
        'en_ZM' => 'İngilizce (Zambiya)',
        'en_ZW' => 'İngilizce (Zimbabve)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Dünya)',
        'es' => 'İspanyolca',
        'es_419' => 'İspanyolca (Latin Amerika)',
        'es_AR' => 'İspanyolca (Arjantin)',
        'es_BO' => 'İspanyolca (Bolivya)',
        'es_BR' => 'İspanyolca (Brezilya)',
        'es_BZ' => 'İspanyolca (Belize)',
        'es_CL' => 'İspanyolca (Şili)',
        'es_CO' => 'İspanyolca (Kolombiya)',
        'es_CR' => 'İspanyolca (Kosta Rika)',
        'es_CU' => 'İspanyolca (Küba)',
        'es_DO' => 'İspanyolca (Dominik Cumhuriyeti)',
        'es_EC' => 'İspanyolca (Ekvador)',
        'es_ES' => 'İspanyolca (İspanya)',
        'es_GQ' => 'İspanyolca (Ekvator Ginesi)',
        'es_GT' => 'İspanyolca (Guatemala)',
        'es_HN' => 'İspanyolca (Honduras)',
        'es_MX' => 'İspanyolca (Meksika)',
        'es_NI' => 'İspanyolca (Nikaragua)',
        'es_PA' => 'İspanyolca (Panama)',
        'es_PE' => 'İspanyolca (Peru)',
        'es_PH' => 'İspanyolca (Filipinler)',
        'es_PR' => 'İspanyolca (Porto Riko)',
        'es_PY' => 'İspanyolca (Paraguay)',
        'es_SV' => 'İspanyolca (El Salvador)',
        'es_US' => 'İspanyolca (Amerika Birleşik Devletleri)',
        'es_UY' => 'İspanyolca (Uruguay)',
        'es_VE' => 'İspanyolca (Venezuela)',
        'et' => 'Estonca',
        'et_EE' => 'Estonca (Estonya)',
        'eu' => 'Baskça',
        'eu_ES' => 'Baskça (İspanya)',
        'fa' => 'Farsça',
        'fa_AF' => 'Farsça (Afganistan)',
        'fa_IR' => 'Farsça (İran)',
        'ff' => 'Fula dili',
        'ff_Adlm' => 'Fula dili (Adlam)',
        'ff_Adlm_BF' => 'Fula dili (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fula dili (Adlam, Kamerun)',
        'ff_Adlm_GH' => 'Fula dili (Adlam, Gana)',
        'ff_Adlm_GM' => 'Fula dili (Adlam, Gambiya)',
        'ff_Adlm_GN' => 'Fula dili (Adlam, Gine)',
        'ff_Adlm_GW' => 'Fula dili (Adlam, Gine-Bissau)',
        'ff_Adlm_LR' => 'Fula dili (Adlam, Liberya)',
        'ff_Adlm_MR' => 'Fula dili (Adlam, Moritanya)',
        'ff_Adlm_NE' => 'Fula dili (Adlam, Nijer)',
        'ff_Adlm_NG' => 'Fula dili (Adlam, Nijerya)',
        'ff_Adlm_SL' => 'Fula dili (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fula dili (Adlam, Senegal)',
        'ff_CM' => 'Fula dili (Kamerun)',
        'ff_GN' => 'Fula dili (Gine)',
        'ff_Latn' => 'Fula dili (Latin)',
        'ff_Latn_BF' => 'Fula dili (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fula dili (Latin, Kamerun)',
        'ff_Latn_GH' => 'Fula dili (Latin, Gana)',
        'ff_Latn_GM' => 'Fula dili (Latin, Gambiya)',
        'ff_Latn_GN' => 'Fula dili (Latin, Gine)',
        'ff_Latn_GW' => 'Fula dili (Latin, Gine-Bissau)',
        'ff_Latn_LR' => 'Fula dili (Latin, Liberya)',
        'ff_Latn_MR' => 'Fula dili (Latin, Moritanya)',
        'ff_Latn_NE' => 'Fula dili (Latin, Nijer)',
        'ff_Latn_NG' => 'Fula dili (Latin, Nijerya)',
        'ff_Latn_SL' => 'Fula dili (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fula dili (Latin, Senegal)',
        'ff_MR' => 'Fula dili (Moritanya)',
        'ff_SN' => 'Fula dili (Senegal)',
        'fi' => 'Fince',
        'fi_FI' => 'Fince (Finlandiya)',
        'fo' => 'Faroe dili',
        'fo_DK' => 'Faroe dili (Danimarka)',
        'fo_FO' => 'Faroe dili (Faroe Adaları)',
        'fr' => 'Fransızca',
        'fr_BE' => 'Fransızca (Belçika)',
        'fr_BF' => 'Fransızca (Burkina Faso)',
        'fr_BI' => 'Fransızca (Burundi)',
        'fr_BJ' => 'Fransızca (Benin)',
        'fr_BL' => 'Fransızca (Saint Barthelemy)',
        'fr_CA' => 'Fransızca (Kanada)',
        'fr_CD' => 'Fransızca (Kongo - Kinşasa)',
        'fr_CF' => 'Fransızca (Orta Afrika Cumhuriyeti)',
        'fr_CG' => 'Fransızca (Kongo - Brazavil)',
        'fr_CH' => 'Fransızca (İsviçre)',
        'fr_CI' => 'Fransızca (Côte d’Ivoire)',
        'fr_CM' => 'Fransızca (Kamerun)',
        'fr_DJ' => 'Fransızca (Cibuti)',
        'fr_DZ' => 'Fransızca (Cezayir)',
        'fr_FR' => 'Fransızca (Fransa)',
        'fr_GA' => 'Fransızca (Gabon)',
        'fr_GF' => 'Fransızca (Fransız Guyanası)',
        'fr_GN' => 'Fransızca (Gine)',
        'fr_GP' => 'Fransızca (Guadeloupe)',
        'fr_GQ' => 'Fransızca (Ekvator Ginesi)',
        'fr_HT' => 'Fransızca (Haiti)',
        'fr_KM' => 'Fransızca (Komorlar)',
        'fr_LU' => 'Fransızca (Lüksemburg)',
        'fr_MA' => 'Fransızca (Fas)',
        'fr_MC' => 'Fransızca (Monako)',
        'fr_MF' => 'Fransızca (Saint Martin)',
        'fr_MG' => 'Fransızca (Madagaskar)',
        'fr_ML' => 'Fransızca (Mali)',
        'fr_MQ' => 'Fransızca (Martinik)',
        'fr_MR' => 'Fransızca (Moritanya)',
        'fr_MU' => 'Fransızca (Mauritius)',
        'fr_NC' => 'Fransızca (Yeni Kaledonya)',
        'fr_NE' => 'Fransızca (Nijer)',
        'fr_PF' => 'Fransızca (Fransız Polinezyası)',
        'fr_PM' => 'Fransızca (Saint Pierre ve Miquelon)',
        'fr_RE' => 'Fransızca (Reunion)',
        'fr_RW' => 'Fransızca (Ruanda)',
        'fr_SC' => 'Fransızca (Seyşeller)',
        'fr_SN' => 'Fransızca (Senegal)',
        'fr_SY' => 'Fransızca (Suriye)',
        'fr_TD' => 'Fransızca (Çad)',
        'fr_TG' => 'Fransızca (Togo)',
        'fr_TN' => 'Fransızca (Tunus)',
        'fr_VU' => 'Fransızca (Vanuatu)',
        'fr_WF' => 'Fransızca (Wallis ve Futuna)',
        'fr_YT' => 'Fransızca (Mayotte)',
        'fy' => 'Batı Frizcesi',
        'fy_NL' => 'Batı Frizcesi (Hollanda)',
        'ga' => 'İrlandaca',
        'ga_GB' => 'İrlandaca (Birleşik Krallık)',
        'ga_IE' => 'İrlandaca (İrlanda)',
        'gd' => 'İskoç Gaelcesi',
        'gd_GB' => 'İskoç Gaelcesi (Birleşik Krallık)',
        'gl' => 'Galiçyaca',
        'gl_ES' => 'Galiçyaca (İspanya)',
        'gu' => 'Güceratça',
        'gu_IN' => 'Güceratça (Hindistan)',
        'gv' => 'Man dili',
        'gv_IM' => 'Man dili (Man Adası)',
        'ha' => 'Hausa dili',
        'ha_GH' => 'Hausa dili (Gana)',
        'ha_NE' => 'Hausa dili (Nijer)',
        'ha_NG' => 'Hausa dili (Nijerya)',
        'he' => 'İbranice',
        'he_IL' => 'İbranice (İsrail)',
        'hi' => 'Hintçe',
        'hi_IN' => 'Hintçe (Hindistan)',
        'hi_Latn' => 'Hintçe (Latin)',
        'hi_Latn_IN' => 'Hintçe (Latin, Hindistan)',
        'hr' => 'Hırvatça',
        'hr_BA' => 'Hırvatça (Bosna-Hersek)',
        'hr_HR' => 'Hırvatça (Hırvatistan)',
        'hu' => 'Macarca',
        'hu_HU' => 'Macarca (Macaristan)',
        'hy' => 'Ermenice',
        'hy_AM' => 'Ermenice (Ermenistan)',
        'ia' => 'İnterlingua',
        'ia_001' => 'İnterlingua (Dünya)',
        'id' => 'Endonezce',
        'id_ID' => 'Endonezce (Endonezya)',
        'ig' => 'İbo dili',
        'ig_NG' => 'İbo dili (Nijerya)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (Çin)',
        'is' => 'İzlandaca',
        'is_IS' => 'İzlandaca (İzlanda)',
        'it' => 'İtalyanca',
        'it_CH' => 'İtalyanca (İsviçre)',
        'it_IT' => 'İtalyanca (İtalya)',
        'it_SM' => 'İtalyanca (San Marino)',
        'it_VA' => 'İtalyanca (Vatikan)',
        'ja' => 'Japonca',
        'ja_JP' => 'Japonca (Japonya)',
        'jv' => 'Cava dili',
        'jv_ID' => 'Cava dili (Endonezya)',
        'ka' => 'Gürcüce',
        'ka_GE' => 'Gürcüce (Gürcistan)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenya)',
        'kk' => 'Kazakça',
        'kk_KZ' => 'Kazakça (Kazakistan)',
        'kl' => 'Grönland dili',
        'kl_GL' => 'Grönland dili (Grönland)',
        'km' => 'Khmer dili',
        'km_KH' => 'Khmer dili (Kamboçya)',
        'kn' => 'Kannada dili',
        'kn_IN' => 'Kannada dili (Hindistan)',
        'ko' => 'Korece',
        'ko_KP' => 'Korece (Kuzey Kore)',
        'ko_KR' => 'Korece (Güney Kore)',
        'ks' => 'Keşmir dili',
        'ks_Arab' => 'Keşmir dili (Arap)',
        'ks_Arab_IN' => 'Keşmir dili (Arap, Hindistan)',
        'ks_Deva' => 'Keşmir dili (Devanagari)',
        'ks_Deva_IN' => 'Keşmir dili (Devanagari, Hindistan)',
        'ks_IN' => 'Keşmir dili (Hindistan)',
        'ku' => 'Kürtçe',
        'ku_TR' => 'Kürtçe (Türkiye)',
        'kw' => 'Kernevekçe',
        'kw_GB' => 'Kernevekçe (Birleşik Krallık)',
        'ky' => 'Kırgızca',
        'ky_KG' => 'Kırgızca (Kırgızistan)',
        'lb' => 'Lüksemburgca',
        'lb_LU' => 'Lüksemburgca (Lüksemburg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Kongo - Kinşasa)',
        'ln_CF' => 'Lingala (Orta Afrika Cumhuriyeti)',
        'ln_CG' => 'Lingala (Kongo - Brazavil)',
        'lo' => 'Lao dili',
        'lo_LA' => 'Lao dili (Laos)',
        'lt' => 'Litvanca',
        'lt_LT' => 'Litvanca (Litvanya)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Kongo - Kinşasa)',
        'lv' => 'Letonca',
        'lv_LV' => 'Letonca (Letonya)',
        'mg' => 'Malgaşça',
        'mg_MG' => 'Malgaşça (Madagaskar)',
        'mi' => 'Maori dili',
        'mi_NZ' => 'Maori dili (Yeni Zelanda)',
        'mk' => 'Makedonca',
        'mk_MK' => 'Makedonca (Kuzey Makedonya)',
        'ml' => 'Malayalam dili',
        'ml_IN' => 'Malayalam dili (Hindistan)',
        'mn' => 'Moğolca',
        'mn_MN' => 'Moğolca (Moğolistan)',
        'mr' => 'Marathi dili',
        'mr_IN' => 'Marathi dili (Hindistan)',
        'ms' => 'Malayca',
        'ms_BN' => 'Malayca (Brunei)',
        'ms_ID' => 'Malayca (Endonezya)',
        'ms_MY' => 'Malayca (Malezya)',
        'ms_SG' => 'Malayca (Singapur)',
        'mt' => 'Maltaca',
        'mt_MT' => 'Maltaca (Malta)',
        'my' => 'Birman dili',
        'my_MM' => 'Birman dili (Myanmar [Burma])',
        'nb' => 'Norveççe Bokmål',
        'nb_NO' => 'Norveççe Bokmål (Norveç)',
        'nb_SJ' => 'Norveççe Bokmål (Svalbard ve Jan Mayen)',
        'nd' => 'Kuzey Ndebele',
        'nd_ZW' => 'Kuzey Ndebele (Zimbabve)',
        'ne' => 'Nepalce',
        'ne_IN' => 'Nepalce (Hindistan)',
        'ne_NP' => 'Nepalce (Nepal)',
        'nl' => 'Felemenkçe',
        'nl_AW' => 'Felemenkçe (Aruba)',
        'nl_BE' => 'Felemenkçe (Belçika)',
        'nl_BQ' => 'Felemenkçe (Karayip Hollandası)',
        'nl_CW' => 'Felemenkçe (Curaçao)',
        'nl_NL' => 'Felemenkçe (Hollanda)',
        'nl_SR' => 'Felemenkçe (Surinam)',
        'nl_SX' => 'Felemenkçe (Sint Maarten)',
        'nn' => 'Norveççe Nynorsk',
        'nn_NO' => 'Norveççe Nynorsk (Norveç)',
        'no' => 'Norveççe',
        'no_NO' => 'Norveççe (Norveç)',
        'om' => 'Oromo dili',
        'om_ET' => 'Oromo dili (Etiyopya)',
        'om_KE' => 'Oromo dili (Kenya)',
        'or' => 'Oriya dili',
        'or_IN' => 'Oriya dili (Hindistan)',
        'os' => 'Osetçe',
        'os_GE' => 'Osetçe (Gürcistan)',
        'os_RU' => 'Osetçe (Rusya)',
        'pa' => 'Pencapça',
        'pa_Arab' => 'Pencapça (Arap)',
        'pa_Arab_PK' => 'Pencapça (Arap, Pakistan)',
        'pa_Guru' => 'Pencapça (Gurmukhi)',
        'pa_Guru_IN' => 'Pencapça (Gurmukhi, Hindistan)',
        'pa_IN' => 'Pencapça (Hindistan)',
        'pa_PK' => 'Pencapça (Pakistan)',
        'pl' => 'Lehçe',
        'pl_PL' => 'Lehçe (Polonya)',
        'ps' => 'Peştuca',
        'ps_AF' => 'Peştuca (Afganistan)',
        'ps_PK' => 'Peştuca (Pakistan)',
        'pt' => 'Portekizce',
        'pt_AO' => 'Portekizce (Angola)',
        'pt_BR' => 'Portekizce (Brezilya)',
        'pt_CH' => 'Portekizce (İsviçre)',
        'pt_CV' => 'Portekizce (Cape Verde)',
        'pt_GQ' => 'Portekizce (Ekvator Ginesi)',
        'pt_GW' => 'Portekizce (Gine-Bissau)',
        'pt_LU' => 'Portekizce (Lüksemburg)',
        'pt_MO' => 'Portekizce (Çin Makao ÖİB)',
        'pt_MZ' => 'Portekizce (Mozambik)',
        'pt_PT' => 'Portekizce (Portekiz)',
        'pt_ST' => 'Portekizce (Sao Tome ve Principe)',
        'pt_TL' => 'Portekizce (Timor-Leste)',
        'qu' => 'Keçuva dili',
        'qu_BO' => 'Keçuva dili (Bolivya)',
        'qu_EC' => 'Keçuva dili (Ekvador)',
        'qu_PE' => 'Keçuva dili (Peru)',
        'rm' => 'Romanşça',
        'rm_CH' => 'Romanşça (İsviçre)',
        'rn' => 'Kirundi',
        'rn_BI' => 'Kirundi (Burundi)',
        'ro' => 'Rumence',
        'ro_MD' => 'Rumence (Moldova)',
        'ro_RO' => 'Rumence (Romanya)',
        'ru' => 'Rusça',
        'ru_BY' => 'Rusça (Belarus)',
        'ru_KG' => 'Rusça (Kırgızistan)',
        'ru_KZ' => 'Rusça (Kazakistan)',
        'ru_MD' => 'Rusça (Moldova)',
        'ru_RU' => 'Rusça (Rusya)',
        'ru_UA' => 'Rusça (Ukrayna)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Ruanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (Hindistan)',
        'sc' => 'Sardunya dili',
        'sc_IT' => 'Sardunya dili (İtalya)',
        'sd' => 'Sindhi dili',
        'sd_Arab' => 'Sindhi dili (Arap)',
        'sd_Arab_PK' => 'Sindhi dili (Arap, Pakistan)',
        'sd_Deva' => 'Sindhi dili (Devanagari)',
        'sd_Deva_IN' => 'Sindhi dili (Devanagari, Hindistan)',
        'sd_IN' => 'Sindhi dili (Hindistan)',
        'sd_PK' => 'Sindhi dili (Pakistan)',
        'se' => 'Kuzey Laponcası',
        'se_FI' => 'Kuzey Laponcası (Finlandiya)',
        'se_NO' => 'Kuzey Laponcası (Norveç)',
        'se_SE' => 'Kuzey Laponcası (İsveç)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Orta Afrika Cumhuriyeti)',
        'sh' => 'Sırp-Hırvat Dili',
        'sh_BA' => 'Sırp-Hırvat Dili (Bosna-Hersek)',
        'si' => 'Sinhali dili',
        'si_LK' => 'Sinhali dili (Sri Lanka)',
        'sk' => 'Slovakça',
        'sk_SK' => 'Slovakça (Slovakya)',
        'sl' => 'Slovence',
        'sl_SI' => 'Slovence (Slovenya)',
        'sn' => 'Şona dili',
        'sn_ZW' => 'Şona dili (Zimbabve)',
        'so' => 'Somalice',
        'so_DJ' => 'Somalice (Cibuti)',
        'so_ET' => 'Somalice (Etiyopya)',
        'so_KE' => 'Somalice (Kenya)',
        'so_SO' => 'Somalice (Somali)',
        'sq' => 'Arnavutça',
        'sq_AL' => 'Arnavutça (Arnavutluk)',
        'sq_MK' => 'Arnavutça (Kuzey Makedonya)',
        'sr' => 'Sırpça',
        'sr_BA' => 'Sırpça (Bosna-Hersek)',
        'sr_Cyrl' => 'Sırpça (Kiril)',
        'sr_Cyrl_BA' => 'Sırpça (Kiril, Bosna-Hersek)',
        'sr_Cyrl_ME' => 'Sırpça (Kiril, Karadağ)',
        'sr_Cyrl_RS' => 'Sırpça (Kiril, Sırbistan)',
        'sr_Latn' => 'Sırpça (Latin)',
        'sr_Latn_BA' => 'Sırpça (Latin, Bosna-Hersek)',
        'sr_Latn_ME' => 'Sırpça (Latin, Karadağ)',
        'sr_Latn_RS' => 'Sırpça (Latin, Sırbistan)',
        'sr_ME' => 'Sırpça (Karadağ)',
        'sr_RS' => 'Sırpça (Sırbistan)',
        'su' => 'Sunda dili',
        'su_ID' => 'Sunda dili (Endonezya)',
        'su_Latn' => 'Sunda dili (Latin)',
        'su_Latn_ID' => 'Sunda dili (Latin, Endonezya)',
        'sv' => 'İsveççe',
        'sv_AX' => 'İsveççe (Åland Adaları)',
        'sv_FI' => 'İsveççe (Finlandiya)',
        'sv_SE' => 'İsveççe (İsveç)',
        'sw' => 'Svahili dili',
        'sw_CD' => 'Svahili dili (Kongo - Kinşasa)',
        'sw_KE' => 'Svahili dili (Kenya)',
        'sw_TZ' => 'Svahili dili (Tanzanya)',
        'sw_UG' => 'Svahili dili (Uganda)',
        'ta' => 'Tamilce',
        'ta_IN' => 'Tamilce (Hindistan)',
        'ta_LK' => 'Tamilce (Sri Lanka)',
        'ta_MY' => 'Tamilce (Malezya)',
        'ta_SG' => 'Tamilce (Singapur)',
        'te' => 'Telugu dili',
        'te_IN' => 'Telugu dili (Hindistan)',
        'tg' => 'Tacikçe',
        'tg_TJ' => 'Tacikçe (Tacikistan)',
        'th' => 'Tayca',
        'th_TH' => 'Tayca (Tayland)',
        'ti' => 'Tigrinya dili',
        'ti_ER' => 'Tigrinya dili (Eritre)',
        'ti_ET' => 'Tigrinya dili (Etiyopya)',
        'tk' => 'Türkmence',
        'tk_TM' => 'Türkmence (Türkmenistan)',
        'tl' => 'Tagalogca',
        'tl_PH' => 'Tagalogca (Filipinler)',
        'to' => 'Tonga dili',
        'to_TO' => 'Tonga dili (Tonga)',
        'tr' => 'Türkçe',
        'tr_CY' => 'Türkçe (Kıbrıs)',
        'tr_TR' => 'Türkçe (Türkiye)',
        'tt' => 'Tatarca',
        'tt_RU' => 'Tatarca (Rusya)',
        'ug' => 'Uygurca',
        'ug_CN' => 'Uygurca (Çin)',
        'uk' => 'Ukraynaca',
        'uk_UA' => 'Ukraynaca (Ukrayna)',
        'ur' => 'Urduca',
        'ur_IN' => 'Urduca (Hindistan)',
        'ur_PK' => 'Urduca (Pakistan)',
        'uz' => 'Özbekçe',
        'uz_AF' => 'Özbekçe (Afganistan)',
        'uz_Arab' => 'Özbekçe (Arap)',
        'uz_Arab_AF' => 'Özbekçe (Arap, Afganistan)',
        'uz_Cyrl' => 'Özbekçe (Kiril)',
        'uz_Cyrl_UZ' => 'Özbekçe (Kiril, Özbekistan)',
        'uz_Latn' => 'Özbekçe (Latin)',
        'uz_Latn_UZ' => 'Özbekçe (Latin, Özbekistan)',
        'uz_UZ' => 'Özbekçe (Özbekistan)',
        'vi' => 'Vietnamca',
        'vi_VN' => 'Vietnamca (Vietnam)',
        'wo' => 'Volofça',
        'wo_SN' => 'Volofça (Senegal)',
        'xh' => 'Zosa dili',
        'xh_ZA' => 'Zosa dili (Güney Afrika)',
        'yi' => 'Yidiş',
        'yi_001' => 'Yidiş (Dünya)',
        'yo' => 'Yorubaca',
        'yo_BJ' => 'Yorubaca (Benin)',
        'yo_NG' => 'Yorubaca (Nijerya)',
        'zh' => 'Çince',
        'zh_CN' => 'Çince (Çin)',
        'zh_HK' => 'Çince (Çin Hong Kong ÖİB)',
        'zh_Hans' => 'Çince (Basitleştirilmiş)',
        'zh_Hans_CN' => 'Çince (Basitleştirilmiş, Çin)',
        'zh_Hans_HK' => 'Çince (Basitleştirilmiş, Çin Hong Kong ÖİB)',
        'zh_Hans_MO' => 'Çince (Basitleştirilmiş, Çin Makao ÖİB)',
        'zh_Hans_SG' => 'Çince (Basitleştirilmiş, Singapur)',
        'zh_Hant' => 'Çince (Geleneksel)',
        'zh_Hant_HK' => 'Çince (Geleneksel, Çin Hong Kong ÖİB)',
        'zh_Hant_MO' => 'Çince (Geleneksel, Çin Makao ÖİB)',
        'zh_Hant_TW' => 'Çince (Geleneksel, Tayvan)',
        'zh_MO' => 'Çince (Çin Makao ÖİB)',
        'zh_SG' => 'Çince (Singapur)',
        'zh_TW' => 'Çince (Tayvan)',
        'zu' => 'Zuluca',
        'zu_ZA' => 'Zuluca (Güney Afrika)',
    ],
];
