<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Бириккен Араб Эмираттарынын дирхамы',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Афганстан афганиси',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'албан леги',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Армения драмы',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'нидерланд-антил гулдени',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Ангола кванзасы',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'аргентина песосу',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'Австралия доллары',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'аруба флорини',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Азербайжан манаты',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'босния-герцоговина конвертациялануучу маркасы',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'барбадос доллары',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Бангладеш такасы',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'болгар левиси',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Бахрейн динары',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Бурунди франкы',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'бермуд доллары',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Бруней доллары',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'боливия боливианосу',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'бразилия реалы',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'багама доллары',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Бутан нгултруму',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ботсвана пуласы',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'беларусь рублу',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'беларусь рублу (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'белиз доллары',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'канада доллары',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Конго франкы',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'швейцария франкы',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'чили песосу',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Кытай юаны (оффшор)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Кытай юаны',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'колумбия песосу',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'коста-рика колону',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'кубанын конвертациялануучу песосу',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'куба песосу',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Кабо-Верде эскудосу',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'чех кронасы',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Жибути франкы',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'дания крону',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'доминикан песосу',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'алжир динары',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'египет фунту',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Эритреа накфасы',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Эфиопия бирри',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Евро',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Фижи доллары',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'фолкленд аралдарынын фунту',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'британия фунт стерлинги',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Грузия лариси',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Гана седиси',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'гибралтар фунту',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Гамбия даласиси',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Гине франкы',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'гватемала кетсалы',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'гуйана доллары',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Гонконг доллары',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'гондурас лемпирасы',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'хорват кунасы',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'гаити гурдусу',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'венгр форинти',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Индонезия рупийасы',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Израилдин жаңы шекели',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Индия руписи',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Ирак динары',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Иран риалы',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'исландия крону',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'ямайка доллары',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Йордания динары',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Жапан йени',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Кения шиллинги',
        ],
        'KGS' => [
            0 => 'сом',
            1 => 'Кыргызстан сому',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Камбожа риели',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Коморос франкы',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Түндүк Корея вону',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'Түштүк Корея вону',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Кувейт динары',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'кайман доллары',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Казакстан теңгеси',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Лаос киби',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Ливан фунту',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Шри Ланка руписи',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Либерия доллары',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Лесото лотиси',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'литва литасы',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'латвия латы',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'ливия динары',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'марокко дирхамы',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'молдован лейи',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Мадагаскар ариариси',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'македон денары',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Мйанмар кйаты',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Монгол тугриги',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Макау патакасы',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Мавритания угиясы (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Мавритания угиясы',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Мавританий руписи',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Малдив руфийасы',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Малави квачасы',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'мексика песосу',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Малайзия ринггити',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Мозамбик метикалы',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Намибия доллары',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Нигерия найрасы',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'никарагуа кордобасы',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'норвегия крону',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Непал руписи',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'Жаңы Зеландия доллары',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Оман риалы',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'панама балбоасы',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'перу солу',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Папуа Жаңы Гвинея кинасы',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Филиппин песосу',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Пакистан руписи',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'польша злотыйы',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'парагвай гуараниси',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Катар риалы',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'румын лейи',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'серб динары',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'орус рублу',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Руанда франкы',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Сауд риалы',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Соломон аралдарынын доллары',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Сейшел руписи',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'судан фунту',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'швеция крону',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Сингапур доллары',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Ыйык Елена аралынын фунту',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Сиерра-Леоне леонеси',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Сомали шиллинги',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'суринам доллары',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Түштүк Судан фунту',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Сао Томе жана Принсипе добрасы (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Сао Томе жана Принсипе добрасы',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Сирия фунту',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Свази лилангени',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Тай баты',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Тажикстан сомониси',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Түркмөнстан манаты',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'тунис динары',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Тонга паангасы',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Түркия лирасы',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'тринидад жана тобаго доллары',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'Тайвань жаңы доллары',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Танзания шиллинги',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'украин гривени',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Уганда шиллинги',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'АКШ доллары',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'уругвай песосу',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Өзбекстан суму',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'венесуэла боливары (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Венесуэла боливары',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Вьетнам доңу',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Вануату ватусу',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Самоа таласы',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Борбордук Африка КФА франкы',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'чыгыш кариб доллары',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'КФА франкы',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'КФП франкы',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Йемен риалы',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Түштүк Африка ранды',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Замбия квачасы',
        ],
    ],
];
