<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Amser Safonol Greenwich (Abidjan)',
        'Africa/Accra' => 'Amser Safonol Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Amser Dwyrain Affrica (Addis Ababa)',
        'Africa/Algiers' => 'Amser Canolbarth Ewrop (Alger)',
        'Africa/Asmera' => 'Amser Dwyrain Affrica (Asmara)',
        'Africa/Bamako' => 'Amser Safonol Greenwich (Bamako)',
        'Africa/Bangui' => 'Amser Gorllewin Affrica (Bangui)',
        'Africa/Banjul' => 'Amser Safonol Greenwich (Banjul)',
        'Africa/Bissau' => 'Amser Safonol Greenwich (Bissau)',
        'Africa/Blantyre' => 'Amser Canolbarth Affrica (Blantyre)',
        'Africa/Brazzaville' => 'Amser Gorllewin Affrica (Brazzaville)',
        'Africa/Bujumbura' => 'Amser Canolbarth Affrica (Bujumbura)',
        'Africa/Cairo' => 'Amser Dwyrain Ewrop (Cairo)',
        'Africa/Casablanca' => 'Amser Gorllewin Ewrop (Casablanca)',
        'Africa/Ceuta' => 'Amser Canolbarth Ewrop (Ceuta)',
        'Africa/Conakry' => 'Amser Safonol Greenwich (Conakry)',
        'Africa/Dakar' => 'Amser Safonol Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Amser Dwyrain Affrica (Dar es Salaam)',
        'Africa/Djibouti' => 'Amser Dwyrain Affrica (Djibouti)',
        'Africa/Douala' => 'Amser Gorllewin Affrica (Douala)',
        'Africa/El_Aaiun' => 'Amser Gorllewin Ewrop (El Aaiun)',
        'Africa/Freetown' => 'Amser Safonol Greenwich (Freetown)',
        'Africa/Gaborone' => 'Amser Canolbarth Affrica (Gaborone)',
        'Africa/Harare' => 'Amser Canolbarth Affrica (Harare)',
        'Africa/Johannesburg' => 'Amser Safonol De Affrica (Johannesburg)',
        'Africa/Juba' => 'Amser Canolbarth Affrica (Juba)',
        'Africa/Kampala' => 'Amser Dwyrain Affrica (Kampala)',
        'Africa/Khartoum' => 'Amser Canolbarth Affrica (Khartoum)',
        'Africa/Kigali' => 'Amser Canolbarth Affrica (Kigali)',
        'Africa/Kinshasa' => 'Amser Gorllewin Affrica (Kinshasa)',
        'Africa/Lagos' => 'Amser Gorllewin Affrica (Lagos)',
        'Africa/Libreville' => 'Amser Gorllewin Affrica (Libreville)',
        'Africa/Lome' => 'Amser Safonol Greenwich (Lome)',
        'Africa/Luanda' => 'Amser Gorllewin Affrica (Luanda)',
        'Africa/Lubumbashi' => 'Amser Canolbarth Affrica (Lubumbashi)',
        'Africa/Lusaka' => 'Amser Canolbarth Affrica (Lusaka)',
        'Africa/Malabo' => 'Amser Gorllewin Affrica (Malabo)',
        'Africa/Maputo' => 'Amser Canolbarth Affrica (Maputo)',
        'Africa/Maseru' => 'Amser Safonol De Affrica (Maseru)',
        'Africa/Mbabane' => 'Amser Safonol De Affrica (Mbabane)',
        'Africa/Mogadishu' => 'Amser Dwyrain Affrica (Mogadishu)',
        'Africa/Monrovia' => 'Amser Safonol Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Amser Dwyrain Affrica (Nairobi)',
        'Africa/Ndjamena' => 'Amser Gorllewin Affrica (Ndjamena)',
        'Africa/Niamey' => 'Amser Gorllewin Affrica (Niamey)',
        'Africa/Nouakchott' => 'Amser Safonol Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Amser Safonol Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Amser Gorllewin Affrica (Porto-Novo)',
        'Africa/Sao_Tome' => 'Amser Safonol Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Amser Dwyrain Ewrop (Tripoli)',
        'Africa/Tunis' => 'Amser Canolbarth Ewrop (Tunis)',
        'Africa/Windhoek' => 'Amser Canolbarth Affrica (Windhoek)',
        'America/Adak' => 'Amser Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Amser Alaska (Anchorage)',
        'America/Anguilla' => 'Amser Cefnfor yr Iwerydd (Anguilla)',
        'America/Antigua' => 'Amser Cefnfor yr Iwerydd (Antigua)',
        'America/Araguaina' => 'Amser Brasília (Araguaina)',
        'America/Argentina/La_Rioja' => 'Amser yr Ariannin (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Amser yr Ariannin (Rio Gallegos)',
        'America/Argentina/Salta' => 'Amser yr Ariannin (Salta)',
        'America/Argentina/San_Juan' => 'Amser yr Ariannin (San Juan)',
        'America/Argentina/San_Luis' => 'Amser yr Ariannin (San Luis)',
        'America/Argentina/Tucuman' => 'Amser yr Ariannin (Tucumán)',
        'America/Argentina/Ushuaia' => 'Amser yr Ariannin (Ushuaia)',
        'America/Aruba' => 'Amser Cefnfor yr Iwerydd (Aruba)',
        'America/Asuncion' => 'Amser Paraguay (Asunción)',
        'America/Bahia' => 'Amser Brasília (Bahia)',
        'America/Bahia_Banderas' => 'Amser Canolbarth Gogledd America (Bae Banderas)',
        'America/Barbados' => 'Amser Cefnfor yr Iwerydd (Barbados)',
        'America/Belem' => 'Amser Brasília (Belém)',
        'America/Belize' => 'Amser Canolbarth Gogledd America (Belize)',
        'America/Blanc-Sablon' => 'Amser Cefnfor yr Iwerydd (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amser Amazonas (Boa Vista)',
        'America/Bogota' => 'Amser Colombia (Bogotá)',
        'America/Boise' => 'Amser Mynyddoedd Gogledd America (Boise)',
        'America/Buenos_Aires' => 'Amser yr Ariannin (Buenos Aires)',
        'America/Cambridge_Bay' => 'Amser Mynyddoedd Gogledd America (Bae Cambridge)',
        'America/Campo_Grande' => 'Amser Amazonas (Campo Grande)',
        'America/Cancun' => 'Amser Dwyrain Gogledd America (Cancún)',
        'America/Caracas' => 'Amser Venezuela (Caracas)',
        'America/Catamarca' => 'Amser yr Ariannin (Catamarca)',
        'America/Cayenne' => 'Amser Guyane Ffrengig (Cayenne)',
        'America/Cayman' => 'Amser Dwyrain Gogledd America (Cayman)',
        'America/Chicago' => 'Amser Canolbarth Gogledd America (Chicago)',
        'America/Chihuahua' => 'Amser Pasiffig Mecsico (Chihuahua)',
        'America/Coral_Harbour' => 'Amser Dwyrain Gogledd America (Atikokan)',
        'America/Cordoba' => 'Amser yr Ariannin (Cordoba)',
        'America/Costa_Rica' => 'Amser Canolbarth Gogledd America (Costa Rica)',
        'America/Creston' => 'Amser Mynyddoedd Gogledd America (Creston)',
        'America/Cuiaba' => 'Amser Amazonas (Cuiabá)',
        'America/Curacao' => 'Amser Cefnfor yr Iwerydd (Curaçao)',
        'America/Danmarkshavn' => 'Amser Safonol Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Amser Yukon (Dawson)',
        'America/Dawson_Creek' => 'Amser Mynyddoedd Gogledd America (Dawson Creek)',
        'America/Denver' => 'Amser Mynyddoedd Gogledd America (Denver)',
        'America/Detroit' => 'Amser Dwyrain Gogledd America (Detroit)',
        'America/Dominica' => 'Amser Cefnfor yr Iwerydd (Dominica)',
        'America/Edmonton' => 'Amser Mynyddoedd Gogledd America (Edmonton)',
        'America/Eirunepe' => 'Amser Brasil (Eirunepé)',
        'America/El_Salvador' => 'Amser Canolbarth Gogledd America (El Salvador)',
        'America/Fort_Nelson' => 'Amser Mynyddoedd Gogledd America (Fort Nelson)',
        'America/Fortaleza' => 'Amser Brasília (Fortaleza)',
        'America/Glace_Bay' => 'Amser Cefnfor yr Iwerydd (Glace Bay)',
        'America/Godthab' => 'Amser Gorllewin yr Ynys Las (Nuuk)',
        'America/Goose_Bay' => 'Amser Cefnfor yr Iwerydd (Goose Bay)',
        'America/Grand_Turk' => 'Amser Dwyrain Gogledd America (Grand Turk)',
        'America/Grenada' => 'Amser Cefnfor yr Iwerydd (Grenada)',
        'America/Guadeloupe' => 'Amser Cefnfor yr Iwerydd (Guadeloupe)',
        'America/Guatemala' => 'Amser Canolbarth Gogledd America (Guatemala)',
        'America/Guayaquil' => 'Amser Ecuador (Guayaquil)',
        'America/Guyana' => 'Amser Guyana',
        'America/Halifax' => 'Amser Cefnfor yr Iwerydd (Halifax)',
        'America/Havana' => 'Amser Ciwba (Havana)',
        'America/Hermosillo' => 'Amser Pasiffig Mecsico (Hermosillo)',
        'America/Indiana/Knox' => 'Amser Canolbarth Gogledd America (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Amser Dwyrain Gogledd America (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Amser Dwyrain Gogledd America (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Amser Canolbarth Gogledd America (Dinas Tell, Indiana)',
        'America/Indiana/Vevay' => 'Amser Dwyrain Gogledd America (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Amser Dwyrain Gogledd America (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Amser Dwyrain Gogledd America (Winamac, Indiana)',
        'America/Indianapolis' => 'Amser Dwyrain Gogledd America (Indianapolis)',
        'America/Inuvik' => 'Amser Mynyddoedd Gogledd America (Inuvik)',
        'America/Iqaluit' => 'Amser Dwyrain Gogledd America (Iqaluit)',
        'America/Jamaica' => 'Amser Dwyrain Gogledd America (Jamaica)',
        'America/Jujuy' => 'Amser yr Ariannin (Jujuy)',
        'America/Juneau' => 'Amser Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Amser Dwyrain Gogledd America (Monticello, Kentucky)',
        'America/Kralendijk' => 'Amser Cefnfor yr Iwerydd (Kralendijk)',
        'America/La_Paz' => 'Amser Bolifia (La Paz)',
        'America/Lima' => 'Amser Periw (Lima)',
        'America/Los_Angeles' => 'Amser Cefnfor Tawel Gogledd America (Los Angeles)',
        'America/Louisville' => 'Amser Dwyrain Gogledd America (Louisville)',
        'America/Lower_Princes' => 'Amser Cefnfor yr Iwerydd (Lower Prince’s Quarter)',
        'America/Maceio' => 'Amser Brasília (Maceio)',
        'America/Managua' => 'Amser Canolbarth Gogledd America (Managua)',
        'America/Manaus' => 'Amser Amazonas (Manaus)',
        'America/Marigot' => 'Amser Cefnfor yr Iwerydd (Marigot)',
        'America/Martinique' => 'Amser Cefnfor yr Iwerydd (Martinique)',
        'America/Matamoros' => 'Amser Canolbarth Gogledd America (Matamoros)',
        'America/Mazatlan' => 'Amser Pasiffig Mecsico (Mazatlan)',
        'America/Mendoza' => 'Amser yr Ariannin (Mendoza)',
        'America/Menominee' => 'Amser Canolbarth Gogledd America (Menominee)',
        'America/Merida' => 'Amser Canolbarth Gogledd America (Merida)',
        'America/Metlakatla' => 'Amser Alaska (Metlakatla)',
        'America/Mexico_City' => 'Amser Canolbarth Gogledd America (Dinas Mecsico)',
        'America/Miquelon' => 'Amser Saint-Pierre-et-Miquelon',
        'America/Moncton' => 'Amser Cefnfor yr Iwerydd (Moncton)',
        'America/Monterrey' => 'Amser Canolbarth Gogledd America (Monterrey)',
        'America/Montevideo' => 'Amser Uruguay (Montevideo)',
        'America/Montreal' => 'Amser Canada (Montreal)',
        'America/Montserrat' => 'Amser Cefnfor yr Iwerydd (Montserrat)',
        'America/Nassau' => 'Amser Dwyrain Gogledd America (Nassau)',
        'America/New_York' => 'Amser Dwyrain Gogledd America (Efrog Newydd)',
        'America/Nipigon' => 'Amser Dwyrain Gogledd America (Nipigon)',
        'America/Nome' => 'Amser Alaska (Nome)',
        'America/Noronha' => 'Amser Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Amser Canolbarth Gogledd America (Beulah, Gogledd Dakota)',
        'America/North_Dakota/Center' => 'Amser Canolbarth Gogledd America (Center, Gogledd Dakota)',
        'America/North_Dakota/New_Salem' => 'Amser Canolbarth Gogledd America (New Salem, Gogledd Dakota)',
        'America/Ojinaga' => 'Amser Mynyddoedd Gogledd America (Ojinaga)',
        'America/Panama' => 'Amser Dwyrain Gogledd America (Panama)',
        'America/Pangnirtung' => 'Amser Dwyrain Gogledd America (Pangnirtung)',
        'America/Paramaribo' => 'Amser Suriname (Paramaribo)',
        'America/Phoenix' => 'Amser Mynyddoedd Gogledd America (Phoenix)',
        'America/Port-au-Prince' => 'Amser Dwyrain Gogledd America (Port-au-Prince)',
        'America/Port_of_Spain' => 'Amser Cefnfor yr Iwerydd (Port of Spain)',
        'America/Porto_Velho' => 'Amser Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'Amser Cefnfor yr Iwerydd (Puerto Rico)',
        'America/Punta_Arenas' => 'Amser Chile (Punta Arenas)',
        'America/Rainy_River' => 'Amser Canolbarth Gogledd America (Rainy River)',
        'America/Rankin_Inlet' => 'Amser Canolbarth Gogledd America (Rankin Inlet)',
        'America/Recife' => 'Amser Brasília (Recife)',
        'America/Regina' => 'Amser Canolbarth Gogledd America (Regina)',
        'America/Resolute' => 'Amser Canolbarth Gogledd America (Resolute)',
        'America/Rio_Branco' => 'Amser Brasil (Rio Branco)',
        'America/Santa_Isabel' => 'Amser Gogledd Orllewin Mecsico (Santa Isabel)',
        'America/Santarem' => 'Amser Brasília (Santarem)',
        'America/Santiago' => 'Amser Chile (Santiago)',
        'America/Santo_Domingo' => 'Amser Cefnfor yr Iwerydd (Santo Domingo)',
        'America/Sao_Paulo' => 'Amser Brasília (Sao Paulo)',
        'America/Scoresbysund' => 'Amser Dwyrain yr Ynys Las (Ittoqqortoormiit)',
        'America/Sitka' => 'Amser Alaska (Sitka)',
        'America/St_Barthelemy' => 'Amser Cefnfor yr Iwerydd (St. Barthélemy)',
        'America/St_Johns' => 'Amser Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Amser Cefnfor yr Iwerydd (St. Kitts)',
        'America/St_Lucia' => 'Amser Cefnfor yr Iwerydd (St. Lucia)',
        'America/St_Thomas' => 'Amser Cefnfor yr Iwerydd (St. Thomas)',
        'America/St_Vincent' => 'Amser Cefnfor yr Iwerydd (St. Vincent)',
        'America/Swift_Current' => 'Amser Canolbarth Gogledd America (Swift Current)',
        'America/Tegucigalpa' => 'Amser Canolbarth Gogledd America (Tegucigalpa)',
        'America/Thule' => 'Amser Cefnfor yr Iwerydd (Thule)',
        'America/Thunder_Bay' => 'Amser Dwyrain Gogledd America (Thunder Bay)',
        'America/Tijuana' => 'Amser Cefnfor Tawel Gogledd America (Tijuana)',
        'America/Toronto' => 'Amser Dwyrain Gogledd America (Toronto)',
        'America/Tortola' => 'Amser Cefnfor yr Iwerydd (Tortola)',
        'America/Vancouver' => 'Amser Cefnfor Tawel Gogledd America (Vancouver)',
        'America/Whitehorse' => 'Amser Yukon (Whitehorse)',
        'America/Winnipeg' => 'Amser Canolbarth Gogledd America (Winnipeg)',
        'America/Yakutat' => 'Amser Alaska (Yakutat)',
        'America/Yellowknife' => 'Amser Mynyddoedd Gogledd America (Yellowknife)',
        'Antarctica/Casey' => 'Amser Antarctica (Casey)',
        'Antarctica/Davis' => 'Amser Davis',
        'Antarctica/DumontDUrville' => 'Amser Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Amser Dwyrain Awstralia (Macquarie)',
        'Antarctica/Mawson' => 'Amser Mawson',
        'Antarctica/McMurdo' => 'Amser Seland Newydd (McMurdo)',
        'Antarctica/Palmer' => 'Amser Chile (Palmer)',
        'Antarctica/Rothera' => 'Amser Rothera',
        'Antarctica/Syowa' => 'Amser Syowa',
        'Antarctica/Troll' => 'Amser Safonol Greenwich (Troll)',
        'Antarctica/Vostok' => 'Amser Vostok',
        'Arctic/Longyearbyen' => 'Amser Canolbarth Ewrop (Longyearbyen)',
        'Asia/Aden' => 'Amser Arabaidd (Aden)',
        'Asia/Almaty' => 'Amser Dwyrain Kazakhstan (Almaty)',
        'Asia/Amman' => 'Amser Dwyrain Ewrop (Amman)',
        'Asia/Anadyr' => 'Amser Rwsia (Anadyr)',
        'Asia/Aqtau' => 'Amser Gorllewin Kazakhstan (Aqtau)',
        'Asia/Aqtobe' => 'Amser Gorllewin Kazakhstan (Aqtobe)',
        'Asia/Ashgabat' => 'Amser Tyrcmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Amser Gorllewin Kazakhstan (Atyrau)',
        'Asia/Baghdad' => 'Amser Arabaidd (Baghdad)',
        'Asia/Bahrain' => 'Amser Arabaidd (Bahrain)',
        'Asia/Baku' => 'Amser Aserbaijan (Baku)',
        'Asia/Bangkok' => 'Amser Indo-Tsieina (Bangkok)',
        'Asia/Barnaul' => 'Amser Rwsia (Barnaul)',
        'Asia/Beirut' => 'Amser Dwyrain Ewrop (Beirut)',
        'Asia/Bishkek' => 'Amser Kyrgyzstan (Bishkek)',
        'Asia/Brunei' => 'Amser Brunei Darussalam',
        'Asia/Calcutta' => 'Amser India (Kolkata)',
        'Asia/Chita' => 'Amser Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Amser Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Amser India (Colombo)',
        'Asia/Damascus' => 'Amser Dwyrain Ewrop (Damascus)',
        'Asia/Dhaka' => 'Amser Bangladesh (Dhaka)',
        'Asia/Dili' => 'Amser Dwyrain Timor (Dili)',
        'Asia/Dubai' => 'Amser Safonol y Gwlff (Dubai)',
        'Asia/Dushanbe' => 'Amser Tajicistan (Dushanbe)',
        'Asia/Famagusta' => 'Amser Dwyrain Ewrop (Famagusta)',
        'Asia/Gaza' => 'Amser Dwyrain Ewrop (Gasa)',
        'Asia/Hebron' => 'Amser Dwyrain Ewrop (Hebron)',
        'Asia/Hong_Kong' => 'Amser Hong Kong',
        'Asia/Hovd' => 'Amser Hovd',
        'Asia/Irkutsk' => 'Amser Irkutsk',
        'Asia/Jakarta' => 'Amser Gorllewin Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Amser Dwyrain Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'Amser Israel (Jerwsalem)',
        'Asia/Kabul' => 'Amser Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Amser Rwsia (Kamchatka)',
        'Asia/Karachi' => 'Amser Pakistan (Karachi)',
        'Asia/Katmandu' => 'Amser Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Amser Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Amser Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Amser Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Amser Malaysia (Kuching)',
        'Asia/Kuwait' => 'Amser Arabaidd (Kuwait)',
        'Asia/Macau' => 'Amser Tsieina (Macau)',
        'Asia/Magadan' => 'Amser Magadan',
        'Asia/Makassar' => 'Amser Canolbarth Indonesia (Makassar)',
        'Asia/Manila' => 'Amser Pilipinas (Manila)',
        'Asia/Muscat' => 'Amser Safonol y Gwlff (Muscat)',
        'Asia/Nicosia' => 'Amser Dwyrain Ewrop (Nicosia)',
        'Asia/Novokuznetsk' => 'Amser Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Amser Novosibirsk',
        'Asia/Omsk' => 'Amser Omsk',
        'Asia/Oral' => 'Amser Gorllewin Kazakhstan (Oral)',
        'Asia/Phnom_Penh' => 'Amser Indo-Tsieina (Phnom Penh)',
        'Asia/Pontianak' => 'Amser Gorllewin Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'Amser Corea (Pyongyang)',
        'Asia/Qatar' => 'Amser Arabaidd (Qatar)',
        'Asia/Qostanay' => 'Amser Dwyrain Kazakhstan (Kostanay)',
        'Asia/Qyzylorda' => 'Amser Gorllewin Kazakhstan (Qyzylorda)',
        'Asia/Rangoon' => 'Amser Myanmar (Yangon)',
        'Asia/Riyadh' => 'Amser Arabaidd (Riyadh)',
        'Asia/Saigon' => 'Amser Indo-Tsieina (Dinas Hô Chi Minh)',
        'Asia/Sakhalin' => 'Amser Sakhalin',
        'Asia/Samarkand' => 'Amser Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'Amser Corea (Seoul)',
        'Asia/Shanghai' => 'Amser Tsieina (Shanghai)',
        'Asia/Singapore' => 'Amser Singapore',
        'Asia/Srednekolymsk' => 'Amser Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Amser Taipei',
        'Asia/Tashkent' => 'Amser Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Amser Georgia (Tiflis)',
        'Asia/Tehran' => 'Amser Iran (Tehran)',
        'Asia/Thimphu' => 'Amser Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Amser Japan (Tokyo)',
        'Asia/Tomsk' => 'Amser Rwsia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Amser Ulan Bator',
        'Asia/Urumqi' => 'Amser Tsieina (Urumqi)',
        'Asia/Ust-Nera' => 'Amser Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Amser Indo-Tsieina (Vientiane)',
        'Asia/Vladivostok' => 'Amser Vladivostok',
        'Asia/Yakutsk' => 'Amser Yakutsk',
        'Asia/Yekaterinburg' => 'Amser Yekaterinburg',
        'Asia/Yerevan' => 'Amser Armenia (Yerevan)',
        'Atlantic/Azores' => 'Amser yr Azores',
        'Atlantic/Bermuda' => 'Amser Cefnfor yr Iwerydd (Bermuda)',
        'Atlantic/Canary' => 'Amser Gorllewin Ewrop (Yr Ynysoedd Dedwydd)',
        'Atlantic/Cape_Verde' => 'Amser Cabo Verde (Cape Verde)',
        'Atlantic/Faeroe' => 'Amser Gorllewin Ewrop (Ffaro)',
        'Atlantic/Madeira' => 'Amser Gorllewin Ewrop (Madeira)',
        'Atlantic/Reykjavik' => 'Amser Safonol Greenwich (Reykjavík)',
        'Atlantic/South_Georgia' => 'Amser De Georgia',
        'Atlantic/St_Helena' => 'Amser Safonol Greenwich (St. Helena)',
        'Atlantic/Stanley' => 'Amser Ynysoedd Falklands/Malvinas (Stanley)',
        'Australia/Adelaide' => 'Amser Canolbarth Awstralia (Adelaide)',
        'Australia/Brisbane' => 'Amser Dwyrain Awstralia (Brisbane)',
        'Australia/Broken_Hill' => 'Amser Canolbarth Awstralia (Broken Hill)',
        'Australia/Currie' => 'Amser Dwyrain Awstralia (Currie)',
        'Australia/Darwin' => 'Amser Canolbarth Awstralia (Darwin)',
        'Australia/Eucla' => 'Amser Canolbarth Gorllewin Awstralia (Eucla)',
        'Australia/Hobart' => 'Amser Dwyrain Awstralia (Hobart)',
        'Australia/Lindeman' => 'Amser Dwyrain Awstralia (Lindeman)',
        'Australia/Lord_Howe' => 'Amser yr Arglwydd Howe (Lord Howe)',
        'Australia/Melbourne' => 'Amser Dwyrain Awstralia (Melbourne)',
        'Australia/Perth' => 'Amser Gorllewin Awstralia (Perth)',
        'Australia/Sydney' => 'Amser Dwyrain Awstralia (Sydney)',
        'CST6CDT' => 'Amser Canolbarth Gogledd America',
        'EST5EDT' => 'Amser Dwyrain Gogledd America',
        'Etc/GMT' => 'Amser Safonol Greenwich',
        'Etc/UTC' => 'Amser Cyffredniol Cydlynol',
        'Europe/Amsterdam' => 'Amser Canolbarth Ewrop (Amsterdam)',
        'Europe/Andorra' => 'Amser Canolbarth Ewrop (Andorra)',
        'Europe/Astrakhan' => 'Amser Moscfa (Astrakhan)',
        'Europe/Athens' => 'Amser Dwyrain Ewrop (Athens)',
        'Europe/Belgrade' => 'Amser Canolbarth Ewrop (Belgrade)',
        'Europe/Berlin' => 'Amser Canolbarth Ewrop (Berlin)',
        'Europe/Bratislava' => 'Amser Canolbarth Ewrop (Bratislava)',
        'Europe/Brussels' => 'Amser Canolbarth Ewrop (Brwsel)',
        'Europe/Bucharest' => 'Amser Dwyrain Ewrop (Bwcarést)',
        'Europe/Budapest' => 'Amser Canolbarth Ewrop (Budapest)',
        'Europe/Busingen' => 'Amser Canolbarth Ewrop (Busingen)',
        'Europe/Chisinau' => 'Amser Dwyrain Ewrop (Chisinau)',
        'Europe/Copenhagen' => 'Amser Canolbarth Ewrop (Copenhagen)',
        'Europe/Dublin' => 'Amser Safonol Greenwich (Dulyn)',
        'Europe/Gibraltar' => 'Amser Canolbarth Ewrop (Gibraltar)',
        'Europe/Guernsey' => 'Amser Safonol Greenwich (Ynys y Garn)',
        'Europe/Helsinki' => 'Amser Dwyrain Ewrop (Helsinki)',
        'Europe/Isle_of_Man' => 'Amser Safonol Greenwich (Ynys Manaw)',
        'Europe/Istanbul' => 'Amser Twrci (Caergystennin)',
        'Europe/Jersey' => 'Amser Safonol Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Amser Dwyrain Ewrop (Kaliningrad)',
        'Europe/Kiev' => 'Amser Dwyrain Ewrop (Kiev)',
        'Europe/Kirov' => 'Amser Rwsia (Kirov)',
        'Europe/Lisbon' => 'Amser Gorllewin Ewrop (Lisbon)',
        'Europe/Ljubljana' => 'Amser Canolbarth Ewrop (Ljubljana)',
        'Europe/London' => 'Amser Safonol Greenwich (Llundain)',
        'Europe/Luxembourg' => 'Amser Canolbarth Ewrop (Lwcsembwrg)',
        'Europe/Madrid' => 'Amser Canolbarth Ewrop (Madrid)',
        'Europe/Malta' => 'Amser Canolbarth Ewrop (Malta)',
        'Europe/Mariehamn' => 'Amser Dwyrain Ewrop (Mariehamn)',
        'Europe/Minsk' => 'Amser Moscfa (Minsk)',
        'Europe/Monaco' => 'Amser Canolbarth Ewrop (Monaco)',
        'Europe/Moscow' => 'Amser Moscfa (Moscow)',
        'Europe/Oslo' => 'Amser Canolbarth Ewrop (Oslo)',
        'Europe/Paris' => 'Amser Canolbarth Ewrop (Paris)',
        'Europe/Podgorica' => 'Amser Canolbarth Ewrop (Podgorica)',
        'Europe/Prague' => 'Amser Canolbarth Ewrop (Prag)',
        'Europe/Riga' => 'Amser Dwyrain Ewrop (Riga)',
        'Europe/Rome' => 'Amser Canolbarth Ewrop (Rhufain)',
        'Europe/Samara' => 'Amser Samara',
        'Europe/San_Marino' => 'Amser Canolbarth Ewrop (San Marino)',
        'Europe/Sarajevo' => 'Amser Canolbarth Ewrop (Sarajevo)',
        'Europe/Saratov' => 'Amser Moscfa (Saratov)',
        'Europe/Simferopol' => 'Amser Moscfa (Simferopol)',
        'Europe/Skopje' => 'Amser Canolbarth Ewrop (Skopje)',
        'Europe/Sofia' => 'Amser Dwyrain Ewrop (Sofia)',
        'Europe/Stockholm' => 'Amser Canolbarth Ewrop (Stockholm)',
        'Europe/Tallinn' => 'Amser Dwyrain Ewrop (Tallinn)',
        'Europe/Tirane' => 'Amser Canolbarth Ewrop (Tirane)',
        'Europe/Ulyanovsk' => 'Amser Moscfa (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Amser Dwyrain Ewrop (Uzhhorod)',
        'Europe/Vaduz' => 'Amser Canolbarth Ewrop (Vaduz)',
        'Europe/Vatican' => 'Amser Canolbarth Ewrop (Y Fatican)',
        'Europe/Vienna' => 'Amser Canolbarth Ewrop (Fienna)',
        'Europe/Vilnius' => 'Amser Dwyrain Ewrop (Vilnius)',
        'Europe/Volgograd' => 'Amser Volgograd',
        'Europe/Warsaw' => 'Amser Canolbarth Ewrop (Warsaw)',
        'Europe/Zagreb' => 'Amser Canolbarth Ewrop (Zagreb)',
        'Europe/Zaporozhye' => 'Amser Dwyrain Ewrop (Zaporozhye)',
        'Europe/Zurich' => 'Amser Canolbarth Ewrop (Zurich)',
        'Indian/Antananarivo' => 'Amser Dwyrain Affrica (Antananarivo)',
        'Indian/Chagos' => 'Amser Cefnfor India (Chagos)',
        'Indian/Christmas' => 'Amser Ynys Y Nadolig',
        'Indian/Cocos' => 'Amser Ynysoedd Cocos',
        'Indian/Comoro' => 'Amser Dwyrain Affrica (Comoro)',
        'Indian/Kerguelen' => 'Amser Tiroedd Ffrainc yn y De a’r Antarctig (Kerguelen)',
        'Indian/Mahe' => 'Amser Seychelles (Mahe)',
        'Indian/Maldives' => 'Amser Y Maldives',
        'Indian/Mauritius' => 'Amser Mauritius',
        'Indian/Mayotte' => 'Amser Dwyrain Affrica (Mayotte)',
        'Indian/Reunion' => 'Amser Réunion',
        'MST7MDT' => 'Amser Mynyddoedd Gogledd America',
        'PST8PDT' => 'Amser Cefnfor Tawel Gogledd America',
        'Pacific/Apia' => 'Amser Apia',
        'Pacific/Auckland' => 'Amser Seland Newydd (Auckland)',
        'Pacific/Bougainville' => 'Amser Papua Guinea Newydd (Bougainville)',
        'Pacific/Chatham' => 'Amser Chatham',
        'Pacific/Easter' => 'Amser Ynys y Pasg',
        'Pacific/Efate' => 'Amser Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Amser Ynysoedd Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Amser Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Amser Fiji',
        'Pacific/Funafuti' => 'Amser Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Amser Galapagos',
        'Pacific/Gambier' => 'Amser Gambier',
        'Pacific/Guadalcanal' => 'Amser Ynysoedd Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Amser Chamorro (Guam)',
        'Pacific/Honolulu' => 'Amser Hawaii-Aleutian (Honolulu)',
        'Pacific/Johnston' => 'Amser Hawaii-Aleutian (Johnston)',
        'Pacific/Kiritimati' => 'Amser Ynysoedd Line (Kiritimati)',
        'Pacific/Kosrae' => 'Amser Kosrae',
        'Pacific/Kwajalein' => 'Amser Ynysoedd Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Amser Ynysoedd Marshall (Majuro)',
        'Pacific/Marquesas' => 'Amser Marquises (Marquesas)',
        'Pacific/Midway' => 'Amser Samoa (Midway)',
        'Pacific/Nauru' => 'Amser Nauru',
        'Pacific/Niue' => 'Amser Niue',
        'Pacific/Norfolk' => 'Amser Ynys Norfolk',
        'Pacific/Noumea' => 'Amser Caledonia Newydd (Noumea)',
        'Pacific/Pago_Pago' => 'Amser Samoa (Pago Pago)',
        'Pacific/Palau' => 'Amser Palau',
        'Pacific/Pitcairn' => 'Amser Pitcairn',
        'Pacific/Ponape' => 'Amser Pohnpei',
        'Pacific/Port_Moresby' => 'Amser Papua Guinea Newydd (Port Moresby)',
        'Pacific/Rarotonga' => 'Amser Ynysoedd Cook (Rarotonga)',
        'Pacific/Saipan' => 'Amser Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Amser Tahiti',
        'Pacific/Tarawa' => 'Amser Ynysoedd Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Amser Tonga (Tongatapu)',
        'Pacific/Truk' => 'Amser Chuuk',
        'Pacific/Wake' => 'Amser Ynys Wake',
        'Pacific/Wallis' => 'Amser Wallis a Futuna',
    ],
    'Meta' => [
    ],
];
