<?php

return [
    'Names' => [
        'Armi' => 'armisk',
        'Cans' => 'felles kanadiske urspråksstavingar',
        'Cyrs' => 'kyrillisk (kyrkjeslavisk variant)',
        'Egyp' => 'egyptiske hieroglyfar',
        'Geok' => 'khutsuri (asomtavruli og nuskhuri)',
        'Hanb' => 'hanb',
        'Hans' => 'forenkla',
        'Hmng' => 'pahawk hmong',
        'Hrkt' => 'japansk stavingsskrifter',
        'Hung' => 'gammalungarsk',
        'Ital' => 'gammalitalisk',
        'Latf' => 'latinsk (frakturvariant)',
        'Latg' => 'latinsk (gælisk variant)',
        'Limb' => 'lumbu',
        'Maya' => 'maya-hieroglyfar',
        'Perm' => 'gammalpermisk',
        'Phlp' => 'salmepahlavi',
        'Sgnw' => 'teiknskrift',
        'Syrc' => 'syriakisk',
        'Syre' => 'syriakisk (estrangelo-variant)',
        'Syrj' => 'syriakisk (vestleg variant)',
        'Syrn' => 'syriakisk (austleg variant)',
        'Thaa' => 'thaana',
        'Visp' => 'synleg tale',
        'Xpeo' => 'gammalpersisk',
        'Xsux' => 'sumero-akkadisk kileskrift',
        'Zinh' => 'nedarva',
        'Zsym' => 'symbol',
        'Zxxx' => 'språk utan skrift',
    ],
];
