<?php

return [
    'Names' => [
        'AD' => 'ኣንዶራ',
        'AE' => 'ሕቡራት ኢማራት ዓረብ',
        'AF' => 'ኣፍጋኒስታን',
        'AG' => 'ኣንቲጓን ባርቡዳን',
        'AI' => 'ኣንጒላ',
        'AL' => 'ኣልባንያ',
        'AM' => 'ኣርሜንያ',
        'AO' => 'ኣንጎላ',
        'AQ' => 'ኣንታርክቲካ',
        'AR' => 'ኣርጀንቲና',
        'AS' => 'ኣመሪካዊት ሳሞኣ',
        'AT' => 'ኦስትርያ',
        'AU' => 'ኣውስትራልያ',
        'AW' => 'ኣሩባ',
        'AX' => 'ደሴታት ኣላንድ',
        'AZ' => 'ኣዘርባጃን',
        'BA' => 'ቦዝንያን ሄርዘጎቪናን',
        'BB' => 'ባርባዶስ',
        'BD' => 'ባንግላደሽ',
        'BE' => 'ቤልጅዩም',
        'BF' => 'ቡርኪና ፋሶ',
        'BG' => 'ቡልጋርያ',
        'BH' => 'ባሕሬን',
        'BI' => 'ብሩንዲ',
        'BJ' => 'ቤኒን',
        'BL' => 'ቅዱስ ባርተለሚ',
        'BM' => 'በርሙዳ',
        'BN' => 'ብሩነይ',
        'BO' => 'ቦሊቭያ',
        'BQ' => 'ካሪብያን ኔዘርላንድ',
        'BR' => 'ብራዚል',
        'BS' => 'ባሃማስ',
        'BT' => 'ቡታን',
        'BV' => 'ደሴት ቡቨት',
        'BW' => 'ቦትስዋና',
        'BY' => 'ቤላሩስ',
        'BZ' => 'በሊዝ',
        'CA' => 'ካናዳ',
        'CC' => 'ደሴታት ኮኮስ',
        'CD' => 'ደሞክራስያዊት ሪፓብሊክ ኮንጎ',
        'CF' => 'ሪፓብሊክ ማእከላይ ኣፍሪቃ',
        'CG' => 'ኮንጎ',
        'CH' => 'ስዊዘርላንድ',
        'CI' => 'ኮት ዲቭዋር',
        'CK' => 'ደሴታት ኩክ',
        'CL' => 'ቺሌ',
        'CM' => 'ካሜሩን',
        'CN' => 'ቻይና',
        'CO' => 'ኮሎምብያ',
        'CR' => 'ኮስታ ሪካ',
        'CU' => 'ኩባ',
        'CV' => 'ኬፕ ቨርደ',
        'CW' => 'ኩራሳው',
        'CX' => 'ደሴት ክሪስማስ',
        'CY' => 'ቆጵሮስ',
        'CZ' => 'ቸክያ',
        'DE' => 'ጀርመን',
        'DJ' => 'ጅቡቲ',
        'DK' => 'ደንማርክ',
        'DM' => 'ዶሚኒካ',
        'DO' => 'ዶሚኒካዊት ሪፓብሊክ',
        'DZ' => 'ኣልጀርያ',
        'EC' => 'ኤኳዶር',
        'EE' => 'ኤስቶንያ',
        'EG' => 'ግብጺ',
        'EH' => 'ምዕራባዊ ሰሃራ',
        'ER' => 'ኤርትራ',
        'ES' => 'ስጳኛ',
        'ET' => 'ኢትዮጵያ',
        'FI' => 'ፊንላንድ',
        'FJ' => 'ፊጂ',
        'FK' => 'ደሴታት ፎክላንድ',
        'FM' => 'ማይክሮነዥያ',
        'FO' => 'ደሴታት ፋሮ',
        'FR' => 'ፈረንሳ',
        'GA' => 'ጋቦን',
        'GB' => 'ብሪጣንያ',
        'GD' => 'ግረናዳ',
        'GE' => 'ጆርጅያ',
        'GF' => 'ፈረንሳዊት ጊያና',
        'GG' => 'ገርንዚ',
        'GH' => 'ጋና',
        'GI' => 'ጂብራልታር',
        'GL' => 'ግሪንላንድ',
        'GM' => 'ጋምብያ',
        'GN' => 'ጊኒ',
        'GP' => 'ጓደሉፕ',
        'GQ' => 'ኢኳቶርያል ጊኒ',
        'GR' => 'ግሪኽ',
        'GS' => 'ደሴታት ደቡብ ጆርጅያን ደቡብ ሳንድዊችን',
        'GT' => 'ጓቲማላ',
        'GU' => 'ጓም',
        'GW' => 'ጊኒ-ቢሳው',
        'GY' => 'ጉያና',
        'HK' => 'ፍሉይ ምምሕዳራዊ ዞባ ሆንግ ኮንግ (ቻይና)',
        'HM' => 'ደሴታት ሄርድን ማክዶናልድን',
        'HN' => 'ሆንዱራስ',
        'HR' => 'ክሮኤሽያ',
        'HT' => 'ሃይቲ',
        'HU' => 'ሃንጋሪ',
        'ID' => 'ኢንዶነዥያ',
        'IE' => 'ኣየርላንድ',
        'IL' => 'እስራኤል',
        'IM' => 'ኣይል ኦፍ ማን',
        'IN' => 'ህንዲ',
        'IO' => 'ብሪጣንያዊ ህንዳዊ ውቅያኖስ ግዝኣት',
        'IQ' => 'ዒራቕ',
        'IR' => 'ኢራን',
        'IS' => 'ኣይስላንድ',
        'IT' => 'ኢጣልያ',
        'JE' => 'ጀርዚ',
        'JM' => 'ጃማይካ',
        'JO' => 'ዮርዳኖስ',
        'JP' => 'ጃፓን',
        'KE' => 'ኬንያ',
        'KG' => 'ኪርጊዝስታን',
        'KH' => 'ካምቦድያ',
        'KI' => 'ኪሪባቲ',
        'KM' => 'ኮሞሮስ',
        'KN' => 'ቅዱስ ኪትስን ኔቪስን',
        'KP' => 'ሰሜን ኮርያ',
        'KR' => 'ደቡብ ኮርያ',
        'KW' => 'ኩዌት',
        'KY' => 'ደሴታት ካይማን',
        'KZ' => 'ካዛኪስታን',
        'LA' => 'ላኦስ',
        'LB' => 'ሊባኖስ',
        'LC' => 'ቅድስቲ ሉስያ',
        'LI' => 'ሊኽተንሽታይን',
        'LK' => 'ስሪ ላንካ',
        'LR' => 'ላይበርያ',
        'LS' => 'ሌሶቶ',
        'LT' => 'ሊትዌንያ',
        'LU' => 'ሉክሰምበርግ',
        'LV' => 'ላትቭያ',
        'LY' => 'ሊብያ',
        'MA' => 'ሞሮኮ',
        'MC' => 'ሞናኮ',
        'MD' => 'ሞልዶቫ',
        'ME' => 'ሞንተኔግሮ',
        'MF' => 'ቅዱስ ማርቲን',
        'MG' => 'ማዳጋስካር',
        'MH' => 'ደሴታት ማርሻል',
        'MK' => 'ሰሜን መቄዶንያ',
        'ML' => 'ማሊ',
        'MM' => 'ሚያንማር (በርማ)',
        'MN' => 'ሞንጎልያ',
        'MO' => 'ፍሉይ ምምሕዳራዊ ዞባ ማካው (ቻይና)',
        'MP' => 'ሰሜናዊ ደሴታት ማርያና',
        'MQ' => 'ማርቲኒክ',
        'MR' => 'ማውሪታንያ',
        'MS' => 'ሞንትሰራት',
        'MT' => 'ማልታ',
        'MU' => 'ማውሪሸስ',
        'MV' => 'ማልዲቭስ',
        'MW' => 'ማላዊ',
        'MX' => 'ሜክሲኮ',
        'MY' => 'ማለዥያ',
        'MZ' => 'ሞዛምቢክ',
        'NA' => 'ናሚብያ',
        'NC' => 'ኒው ካለዶንያ',
        'NE' => 'ኒጀር',
        'NF' => 'ደሴት ኖርፎልክ',
        'NG' => 'ናይጀርያ',
        'NI' => 'ኒካራጓ',
        'NL' => 'ኔዘርላንድ',
        'NO' => 'ኖርወይ',
        'NP' => 'ኔፓል',
        'NR' => 'ናውሩ',
        'NU' => 'ኒዩ',
        'NZ' => 'ኒው ዚላንድ',
        'OM' => 'ዖማን',
        'PA' => 'ፓናማ',
        'PE' => 'ፔሩ',
        'PF' => 'ፈረንሳዊት ፖሊነዥያ',
        'PG' => 'ፓፕዋ ኒው ጊኒ',
        'PH' => 'ፊሊፒንስ',
        'PK' => 'ፓኪስታን',
        'PL' => 'ፖላንድ',
        'PM' => 'ቅዱስ ፕየርን ሚከሎንን',
        'PN' => 'ደሴታት ፒትካርን',
        'PR' => 'ፖርቶ ሪኮ',
        'PS' => 'ግዝኣታት ፍልስጤም',
        'PT' => 'ፖርቱጋል',
        'PW' => 'ፓላው',
        'PY' => 'ፓራጓይ',
        'QA' => 'ቐጠር',
        'RE' => 'ርዩንየን',
        'RO' => 'ሩማንያ',
        'RS' => 'ሰርብያ',
        'RU' => 'ሩስያ',
        'RW' => 'ርዋንዳ',
        'SA' => 'ስዑዲ ዓረብ',
        'SB' => 'ደሴታት ሰሎሞን',
        'SC' => 'ሲሸልስ',
        'SD' => 'ሱዳን',
        'SE' => 'ሽወደን',
        'SG' => 'ሲንጋፖር',
        'SH' => 'ቅድስቲ ሄለና',
        'SI' => 'ስሎቬንያ',
        'SJ' => 'ስቫልባርድን ጃን ማየንን',
        'SK' => 'ስሎቫክያ',
        'SL' => 'ሴራ ልዮን',
        'SM' => 'ሳን ማሪኖ',
        'SN' => 'ሰነጋል',
        'SO' => 'ሶማልያ',
        'SR' => 'ሱሪናም',
        'SS' => 'ደቡብ ሱዳን',
        'ST' => 'ሳኦ ቶመን ፕሪንሲፐን',
        'SV' => 'ኤል ሳልቫዶር',
        'SX' => 'ሲንት ማርተን',
        'SY' => 'ሶርያ',
        'SZ' => 'ኤስዋቲኒ',
        'TC' => 'ደሴታት ቱርካትን ካይኮስን',
        'TD' => 'ጫድ',
        'TF' => 'ፈረንሳዊ ደቡባዊ ግዝኣታት',
        'TG' => 'ቶጎ',
        'TH' => 'ታይላንድ',
        'TJ' => 'ታጂኪስታን',
        'TK' => 'ቶከላው',
        'TL' => 'ቲሞር-ለስተ',
        'TM' => 'ቱርክመኒስታን',
        'TN' => 'ቱኒዝያ',
        'TO' => 'ቶንጋ',
        'TR' => 'ቱርኪ',
        'TT' => 'ትሪኒዳድን ቶባጎን',
        'TV' => 'ቱቫሉ',
        'TW' => 'ታይዋን',
        'TZ' => 'ታንዛንያ',
        'UA' => 'ዩክሬን',
        'UG' => 'ኡጋንዳ',
        'UM' => 'ካብ ኣመሪካ ርሒቐን ንኣሽቱ ደሴታት',
        'US' => 'ኣመሪካ',
        'UY' => 'ኡራጓይ',
        'UZ' => 'ኡዝበኪስታን',
        'VA' => 'ከተማ ቫቲካን',
        'VC' => 'ቅዱስ ቪንሰንትን ግረነዲነዝን',
        'VE' => 'ቬኔዝዌላ',
        'VG' => 'ደሴታት ደናግል ብሪጣንያ',
        'VI' => 'ደሴታት ደናግል ኣመሪካ',
        'VN' => 'ቬትናም',
        'VU' => 'ቫንዋቱ',
        'WF' => 'ዋሊስን ፉቱናን',
        'WS' => 'ሳሞኣ',
        'YE' => 'የመን',
        'YT' => 'ማዮት',
        'ZA' => 'ደቡብ ኣፍሪቃ',
        'ZM' => 'ዛምብያ',
        'ZW' => 'ዚምባብዌ',
    ],
];
