<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'houa fakakiliniuisi mālie (Abidjan)',
        'Africa/Accra' => 'houa fakakiliniuisi mālie (Accra)',
        'Africa/Addis_Ababa' => 'houa fakaʻafelika-hahake (Addis Ababa)',
        'Africa/Algiers' => 'houa fakaʻeulope-loto (Algiers)',
        'Africa/Asmera' => 'houa fakaʻafelika-hahake (Asmara)',
        'Africa/Bamako' => 'houa fakakiliniuisi mālie (Bamako)',
        'Africa/Bangui' => 'houa fakaʻafelika-hihifo (Bangui)',
        'Africa/Banjul' => 'houa fakakiliniuisi mālie (Banjul)',
        'Africa/Bissau' => 'houa fakakiliniuisi mālie (Bissau)',
        'Africa/Blantyre' => 'houa fakaʻafelika-loto (Blantyre)',
        'Africa/Brazzaville' => 'houa fakaʻafelika-hihifo (Brazzaville)',
        'Africa/Bujumbura' => 'houa fakaʻafelika-loto (Bujumbura)',
        'Africa/Cairo' => 'houa fakaʻeulope-hahake (Cairo)',
        'Africa/Casablanca' => 'houa fakaʻeulope-hihifo (Casablanca)',
        'Africa/Ceuta' => 'houa fakaʻeulope-loto (Ceuta)',
        'Africa/Conakry' => 'houa fakakiliniuisi mālie (Conakry)',
        'Africa/Dakar' => 'houa fakakiliniuisi mālie (Dakar)',
        'Africa/Dar_es_Salaam' => 'houa fakaʻafelika-hahake (Dar es Salaam)',
        'Africa/Djibouti' => 'houa fakaʻafelika-hahake (Djibouti)',
        'Africa/Douala' => 'houa fakaʻafelika-hihifo (Douala)',
        'Africa/El_Aaiun' => 'houa fakaʻeulope-hihifo (El Aaiun)',
        'Africa/Freetown' => 'houa fakakiliniuisi mālie (Freetown)',
        'Africa/Gaborone' => 'houa fakaʻafelika-loto (Gaborone)',
        'Africa/Harare' => 'houa fakaʻafelika-loto (Harare)',
        'Africa/Johannesburg' => 'houa fakaʻafelika-tonga (Johannesburg)',
        'Africa/Juba' => 'houa fakaʻafelika-loto (Juba)',
        'Africa/Kampala' => 'houa fakaʻafelika-hahake (Kampala)',
        'Africa/Khartoum' => 'houa fakaʻafelika-loto (Khartoum)',
        'Africa/Kigali' => 'houa fakaʻafelika-loto (Kigali)',
        'Africa/Kinshasa' => 'houa fakaʻafelika-hihifo (Kinshasa)',
        'Africa/Lagos' => 'houa fakaʻafelika-hihifo (Lagos)',
        'Africa/Libreville' => 'houa fakaʻafelika-hihifo (Libreville)',
        'Africa/Lome' => 'houa fakakiliniuisi mālie (Lome)',
        'Africa/Luanda' => 'houa fakaʻafelika-hihifo (Luanda)',
        'Africa/Lubumbashi' => 'houa fakaʻafelika-loto (Lubumbashi)',
        'Africa/Lusaka' => 'houa fakaʻafelika-loto (Lusaka)',
        'Africa/Malabo' => 'houa fakaʻafelika-hihifo (Malabo)',
        'Africa/Maputo' => 'houa fakaʻafelika-loto (Maputo)',
        'Africa/Maseru' => 'houa fakaʻafelika-tonga (Maseru)',
        'Africa/Mbabane' => 'houa fakaʻafelika-tonga (Mbabane)',
        'Africa/Mogadishu' => 'houa fakaʻafelika-hahake (Mogadishu)',
        'Africa/Monrovia' => 'houa fakakiliniuisi mālie (Monrovia)',
        'Africa/Nairobi' => 'houa fakaʻafelika-hahake (Nairobi)',
        'Africa/Ndjamena' => 'houa fakaʻafelika-hihifo (Ndjamena)',
        'Africa/Niamey' => 'houa fakaʻafelika-hihifo (Niamey)',
        'Africa/Nouakchott' => 'houa fakakiliniuisi mālie (Nouakchott)',
        'Africa/Ouagadougou' => 'houa fakakiliniuisi mālie (Ouagadougou)',
        'Africa/Porto-Novo' => 'houa fakaʻafelika-hihifo (Porto-Novo)',
        'Africa/Sao_Tome' => 'houa fakakiliniuisi mālie (Sao Tomé)',
        'Africa/Tripoli' => 'houa fakaʻeulope-hahake (Tripoli)',
        'Africa/Tunis' => 'houa fakaʻeulope-loto (Tunis)',
        'Africa/Windhoek' => 'houa fakaʻafelika-loto (Windhoek)',
        'America/Adak' => 'houa fakahauaʻi (Adak)',
        'America/Anchorage' => 'houa fakaʻalasika (Anchorage)',
        'America/Anguilla' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Anguilla)',
        'America/Antigua' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Antigua)',
        'America/Araguaina' => 'houa fakapalāsila (Araguaina)',
        'America/Argentina/La_Rioja' => 'houa fakaʻasenitina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'houa fakaʻasenitina (Rio Gallegos)',
        'America/Argentina/Salta' => 'houa fakaʻasenitina (Salta)',
        'America/Argentina/San_Juan' => 'houa fakaʻasenitina (San Juan)',
        'America/Argentina/San_Luis' => 'houa fakaʻasenitina (San Luis)',
        'America/Argentina/Tucuman' => 'houa fakaʻasenitina (Tucuman)',
        'America/Argentina/Ushuaia' => 'houa fakaʻasenitina (Ushuaia)',
        'America/Aruba' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Aruba)',
        'America/Asuncion' => 'houa fakapalakuai (Asunción)',
        'America/Bahia' => 'houa fakapalāsila (Bahia)',
        'America/Bahia_Banderas' => 'houa fakaʻamelika-tokelau loto (Bahia Banderas)',
        'America/Barbados' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Barbados)',
        'America/Belem' => 'houa fakapalāsila (Belem)',
        'America/Belize' => 'houa fakaʻamelika-tokelau loto (Belize)',
        'America/Blanc-Sablon' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Blanc-Sablon)',
        'America/Boa_Vista' => 'houa fakaʻamasōne (Boa Vista)',
        'America/Bogota' => 'houa fakakolomipia (Bogota)',
        'America/Boise' => 'houa fakaʻamelika-tokelau moʻunga (Boise)',
        'America/Buenos_Aires' => 'houa fakaʻasenitina (Buenos Aires)',
        'America/Cambridge_Bay' => 'houa fakaʻamelika-tokelau moʻunga (Cambridge Bay)',
        'America/Campo_Grande' => 'houa fakaʻamasōne (Campo Grande)',
        'America/Cancun' => 'houa fakaʻamelika-tokelau hahake (Cancun)',
        'America/Caracas' => 'houa fakavenesuela (Caracas)',
        'America/Catamarca' => 'houa fakaʻasenitina (Catamarca)',
        'America/Cayenne' => 'houa fakakuiana-fakafalanisē (Cayenne)',
        'America/Cayman' => 'houa fakaʻamelika-tokelau hahake (Cayman)',
        'America/Chicago' => 'houa fakaʻamelika-tokelau loto (Chicago)',
        'America/Chihuahua' => 'houa fakamekisikou-pasifika (Chihuahua)',
        'America/Coral_Harbour' => 'houa fakaʻamelika-tokelau hahake (Atikokan)',
        'America/Cordoba' => 'houa fakaʻasenitina (Cordoba)',
        'America/Costa_Rica' => 'houa fakaʻamelika-tokelau loto (Costa Rica)',
        'America/Creston' => 'houa fakaʻamelika-tokelau moʻunga (Creston)',
        'America/Cuiaba' => 'houa fakaʻamasōne (Cuiaba)',
        'America/Curacao' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Curaçao)',
        'America/Danmarkshavn' => 'houa fakakiliniuisi mālie (Danmarkshavn)',
        'America/Dawson' => 'houa fakaiukoni (Dawson)',
        'America/Dawson_Creek' => 'houa fakaʻamelika-tokelau moʻunga (Dawson Creek)',
        'America/Denver' => 'houa fakaʻamelika-tokelau moʻunga (Denver)',
        'America/Detroit' => 'houa fakaʻamelika-tokelau hahake (Detroit)',
        'America/Dominica' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Dominica)',
        'America/Edmonton' => 'houa fakaʻamelika-tokelau moʻunga (Edmonton)',
        'America/Eirunepe' => 'houa fakaʻakelī (Eirunepe)',
        'America/El_Salvador' => 'houa fakaʻamelika-tokelau loto (El Salvador)',
        'America/Fort_Nelson' => 'houa fakaʻamelika-tokelau moʻunga (Fort Nelson)',
        'America/Fortaleza' => 'houa fakapalāsila (Fortaleza)',
        'America/Glace_Bay' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Glace Bay)',
        'America/Godthab' => 'houa fakafonuamata-hihifo (Nuuk)',
        'America/Goose_Bay' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Goose Bay)',
        'America/Grand_Turk' => 'houa fakaʻamelika-tokelau hahake (Grand Turk)',
        'America/Grenada' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Grenada)',
        'America/Guadeloupe' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Guadeloupe)',
        'America/Guatemala' => 'houa fakaʻamelika-tokelau loto (Guatemala)',
        'America/Guayaquil' => 'houa fakaʻekuetoa (Guayaquil)',
        'America/Guyana' => 'houa fakakuiana (Guyana)',
        'America/Halifax' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Halifax)',
        'America/Havana' => 'houa fakakiupa (Havana)',
        'America/Hermosillo' => 'houa fakamekisikou-pasifika (Hermosillo)',
        'America/Indiana/Knox' => 'houa fakaʻamelika-tokelau loto (Knox, Indiana)',
        'America/Indiana/Marengo' => 'houa fakaʻamelika-tokelau hahake (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'houa fakaʻamelika-tokelau hahake (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'houa fakaʻamelika-tokelau loto (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'houa fakaʻamelika-tokelau hahake (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'houa fakaʻamelika-tokelau hahake (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'houa fakaʻamelika-tokelau hahake (Winamac, Indiana)',
        'America/Indianapolis' => 'houa fakaʻamelika-tokelau hahake (Indianapolis)',
        'America/Inuvik' => 'houa fakaʻamelika-tokelau moʻunga (Inuvik)',
        'America/Iqaluit' => 'houa fakaʻamelika-tokelau hahake (Iqaluit)',
        'America/Jamaica' => 'houa fakaʻamelika-tokelau hahake (Jamaica)',
        'America/Jujuy' => 'houa fakaʻasenitina (Jujuy)',
        'America/Juneau' => 'houa fakaʻalasika (Juneau)',
        'America/Kentucky/Monticello' => 'houa fakaʻamelika-tokelau hahake (Monticello, Kentucky)',
        'America/Kralendijk' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Kralendijk)',
        'America/La_Paz' => 'houa fakapolīvia (La Paz)',
        'America/Lima' => 'houa fakapelū (Lima)',
        'America/Los_Angeles' => 'houa fakaʻamelika-tokelau pasifika (Los Angeles)',
        'America/Louisville' => 'houa fakaʻamelika-tokelau hahake (Louisville)',
        'America/Lower_Princes' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Lower Prince’s Quarter)',
        'America/Maceio' => 'houa fakapalāsila (Maceio)',
        'America/Managua' => 'houa fakaʻamelika-tokelau loto (Managua)',
        'America/Manaus' => 'houa fakaʻamasōne (Manaus)',
        'America/Marigot' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Marigot)',
        'America/Martinique' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Martinique)',
        'America/Matamoros' => 'houa fakaʻamelika-tokelau loto (Matamoros)',
        'America/Mazatlan' => 'houa fakamekisikou-pasifika (Mazatlan)',
        'America/Mendoza' => 'houa fakaʻasenitina (Mendoza)',
        'America/Menominee' => 'houa fakaʻamelika-tokelau loto (Menominee)',
        'America/Merida' => 'houa fakaʻamelika-tokelau loto (Merida)',
        'America/Metlakatla' => 'houa fakaʻalasika (Metlakatla)',
        'America/Mexico_City' => 'houa fakaʻamelika-tokelau loto (Mexico City)',
        'America/Miquelon' => 'houa fakasā-piea-mo-mikeloni (Miquelon)',
        'America/Moncton' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Moncton)',
        'America/Monterrey' => 'houa fakaʻamelika-tokelau loto (Monterrey)',
        'America/Montevideo' => 'houa fakaʻulukuai (Montevideo)',
        'America/Montreal' => 'Taimi Kānata (Montreal)',
        'America/Montserrat' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Montserrat)',
        'America/Nassau' => 'houa fakaʻamelika-tokelau hahake (Nassau)',
        'America/New_York' => 'houa fakaʻamelika-tokelau hahake (Niu ʻIoke)',
        'America/Nipigon' => 'houa fakaʻamelika-tokelau hahake (Nipigon)',
        'America/Nome' => 'houa fakaʻalasika (Nome)',
        'America/Noronha' => 'houa fakafēnanito-te-nolōnia (Noronha)',
        'America/North_Dakota/Beulah' => 'houa fakaʻamelika-tokelau loto (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'houa fakaʻamelika-tokelau loto (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'houa fakaʻamelika-tokelau loto (New Salem, North Dakota)',
        'America/Ojinaga' => 'houa fakaʻamelika-tokelau moʻunga (Ojinaga)',
        'America/Panama' => 'houa fakaʻamelika-tokelau hahake (Panama)',
        'America/Pangnirtung' => 'houa fakaʻamelika-tokelau hahake (Pangnirtung)',
        'America/Paramaribo' => 'houa fakasuliname (Paramaribo)',
        'America/Phoenix' => 'houa fakaʻamelika-tokelau moʻunga (Phoenix)',
        'America/Port-au-Prince' => 'houa fakaʻamelika-tokelau hahake (Port-au-Prince)',
        'America/Port_of_Spain' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Port of Spain)',
        'America/Porto_Velho' => 'houa fakaʻamasōne (Porto Velho)',
        'America/Puerto_Rico' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Puerto Rico)',
        'America/Punta_Arenas' => 'houa fakasili (Punta Arenas)',
        'America/Rainy_River' => 'houa fakaʻamelika-tokelau loto (Rainy River)',
        'America/Rankin_Inlet' => 'houa fakaʻamelika-tokelau loto (Rankin Inlet)',
        'America/Recife' => 'houa fakapalāsila (Recife)',
        'America/Regina' => 'houa fakaʻamelika-tokelau loto (Regina)',
        'America/Resolute' => 'houa fakaʻamelika-tokelau loto (Resolute)',
        'America/Rio_Branco' => 'houa fakaʻakelī (Rio Branco)',
        'America/Santa_Isabel' => 'houa fakamekisikou-tokelauhihifo (Santa Isabel)',
        'America/Santarem' => 'houa fakapalāsila (Santarem)',
        'America/Santiago' => 'houa fakasili (Santiago)',
        'America/Santo_Domingo' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Santo Domingo)',
        'America/Sao_Paulo' => 'houa fakapalāsila (Sao Paulo)',
        'America/Scoresbysund' => 'houa fakafonuamata-hahake (Ittoqqortoormiit)',
        'America/Sitka' => 'houa fakaʻalasika (Sitka)',
        'America/St_Barthelemy' => 'houa fakaʻamelika-tokelau ʻatalanitiki (St. Barthélemy)',
        'America/St_Johns' => 'houa fakafonuaʻilofoʻou (St. John’s)',
        'America/St_Kitts' => 'houa fakaʻamelika-tokelau ʻatalanitiki (St. Kitts)',
        'America/St_Lucia' => 'houa fakaʻamelika-tokelau ʻatalanitiki (St. Lucia)',
        'America/St_Thomas' => 'houa fakaʻamelika-tokelau ʻatalanitiki (St. Thomas)',
        'America/St_Vincent' => 'houa fakaʻamelika-tokelau ʻatalanitiki (St. Vincent)',
        'America/Swift_Current' => 'houa fakaʻamelika-tokelau loto (Swift Current)',
        'America/Tegucigalpa' => 'houa fakaʻamelika-tokelau loto (Tegucigalpa)',
        'America/Thule' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Thule)',
        'America/Thunder_Bay' => 'houa fakaʻamelika-tokelau hahake (Thunder Bay)',
        'America/Tijuana' => 'houa fakaʻamelika-tokelau pasifika (Tijuana)',
        'America/Toronto' => 'houa fakaʻamelika-tokelau hahake (Toronto)',
        'America/Tortola' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Tortola)',
        'America/Vancouver' => 'houa fakaʻamelika-tokelau pasifika (Vancouver)',
        'America/Whitehorse' => 'houa fakaiukoni (Whitehorse)',
        'America/Winnipeg' => 'houa fakaʻamelika-tokelau loto (Winnipeg)',
        'America/Yakutat' => 'houa fakaʻalasika (Yakutat)',
        'America/Yellowknife' => 'houa fakaʻamelika-tokelau moʻunga (Yellowknife)',
        'Antarctica/Casey' => 'houa fakakeesi (Casey)',
        'Antarctica/Davis' => 'houa fakatavisi (Davis)',
        'Antarctica/DumontDUrville' => 'houa fakatūmoni-tūvile (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'houa fakaʻaositelēlia-hahake (Macquarie)',
        'Antarctica/Mawson' => 'houa fakamausoni (Mawson)',
        'Antarctica/McMurdo' => 'houa fakanuʻusila (McMurdo)',
        'Antarctica/Palmer' => 'houa fakasili (Palmer)',
        'Antarctica/Rothera' => 'houa fakalotela (Rothera)',
        'Antarctica/Syowa' => 'houa fakasioua (Syowa)',
        'Antarctica/Troll' => 'houa fakakiliniuisi mālie (Troll)',
        'Antarctica/Vostok' => 'houa fakavositoki (Vostok)',
        'Arctic/Longyearbyen' => 'houa fakaʻeulope-loto (Longyearbyen)',
        'Asia/Aden' => 'houa fakaʻalepea (Aden)',
        'Asia/Almaty' => 'houa fakakasakitani-hahake (Almaty)',
        'Asia/Amman' => 'houa fakaʻeulope-hahake (Amman)',
        'Asia/Anadyr' => 'houa fakalūsia-ʻanatili (Anadyr)',
        'Asia/Aqtau' => 'houa fakakasakitani-hihifo (Aqtau)',
        'Asia/Aqtobe' => 'houa fakakasakitani-hihifo (Aqtobe)',
        'Asia/Ashgabat' => 'houa fakatūkimenisitani (Ashgabat)',
        'Asia/Atyrau' => 'houa fakakasakitani-hihifo (Atyrau)',
        'Asia/Baghdad' => 'houa fakaʻalepea (Baghdad)',
        'Asia/Bahrain' => 'houa fakaʻalepea (Bahrain)',
        'Asia/Baku' => 'houa fakaʻasapaisani (Baku)',
        'Asia/Bangkok' => 'houa fakaʻinitosiaina (Bangkok)',
        'Asia/Barnaul' => 'Taimi Lūsia (Barnaul)',
        'Asia/Beirut' => 'houa fakaʻeulope-hahake (Beirut)',
        'Asia/Bishkek' => 'houa fakakīkisitani (Bishkek)',
        'Asia/Brunei' => 'houa fakapulunei (Brunei)',
        'Asia/Calcutta' => 'houa fakaʻinitia (Kolkata)',
        'Asia/Chita' => 'houa fakalūsia-ʻiākutisiki (Chita)',
        'Asia/Choibalsan' => 'houa fakaʻulānipātā (Choibalsan)',
        'Asia/Colombo' => 'houa fakaʻinitia (Colombo)',
        'Asia/Damascus' => 'houa fakaʻeulope-hahake (Damascus)',
        'Asia/Dhaka' => 'houa fakapāngilātesi (Dhaka)',
        'Asia/Dili' => 'houa fakatimoa-hahake (Dili)',
        'Asia/Dubai' => 'houa fakakūlifi (Dubai)',
        'Asia/Dushanbe' => 'houa fakatasikitani (Dushanbe)',
        'Asia/Famagusta' => 'houa fakaʻeulope-hahake (Famagusta)',
        'Asia/Gaza' => 'houa fakaʻeulope-hahake (Gaza)',
        'Asia/Hebron' => 'houa fakaʻeulope-hahake (Hebron)',
        'Asia/Hong_Kong' => 'houa fakahongi-kongi (Hong Kong)',
        'Asia/Hovd' => 'houa fakahovite (Hovd)',
        'Asia/Irkutsk' => 'houa fakalūsia-ʻīkutisiki (Irkutsk)',
        'Asia/Jakarta' => 'houa fakaʻinitonisia-hihifo (Jakarta)',
        'Asia/Jayapura' => 'houa fakaʻinitonisia-hahake (Jayapura)',
        'Asia/Jerusalem' => 'houa fakaʻisileli (Selūsalema)',
        'Asia/Kabul' => 'houa fakaʻafikānisitani (Kabul)',
        'Asia/Kamchatka' => 'houa fakalūsia-petelopavilovisiki (Kamchatka)',
        'Asia/Karachi' => 'houa fakapākisitani (Karachi)',
        'Asia/Katmandu' => 'houa fakanepali (Kathmandu)',
        'Asia/Khandyga' => 'houa fakalūsia-ʻiākutisiki (Khandyga)',
        'Asia/Krasnoyarsk' => 'houa fakalūsia-kalasinoiāsiki (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'houa fakamaleisia (Kuala Lumpur)',
        'Asia/Kuching' => 'houa fakamaleisia (Kuching)',
        'Asia/Kuwait' => 'houa fakaʻalepea (Kuwait)',
        'Asia/Macau' => 'houa fakasiaina (Macau)',
        'Asia/Magadan' => 'houa fakalūsia-makatani (Magadan)',
        'Asia/Makassar' => 'houa fakaʻinitonisia-loto (Makassar)',
        'Asia/Manila' => 'houa fakafilipaine (Manila)',
        'Asia/Muscat' => 'houa fakakūlifi (Muscat)',
        'Asia/Nicosia' => 'houa fakaʻeulope-hahake (Nicosia)',
        'Asia/Novokuznetsk' => 'houa fakalūsia-kalasinoiāsiki (Novokuznetsk)',
        'Asia/Novosibirsk' => 'houa fakalūsia-novosipīsiki (Novosibirsk)',
        'Asia/Omsk' => 'houa fakalūsia-ʻomisiki (Omsk)',
        'Asia/Oral' => 'houa fakakasakitani-hihifo (Oral)',
        'Asia/Phnom_Penh' => 'houa fakaʻinitosiaina (Phnom Penh)',
        'Asia/Pontianak' => 'houa fakaʻinitonisia-hihifo (Pontianak)',
        'Asia/Pyongyang' => 'houa fakakōlea (Pyongyang)',
        'Asia/Qatar' => 'houa fakaʻalepea (Qatar)',
        'Asia/Qostanay' => 'houa fakakasakitani-hahake (Qostanay)',
        'Asia/Qyzylorda' => 'houa fakakasakitani-hihifo (Qyzylorda)',
        'Asia/Rangoon' => 'houa fakapema (Rangoon)',
        'Asia/Riyadh' => 'houa fakaʻalepea (Riyadh)',
        'Asia/Saigon' => 'houa fakaʻinitosiaina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'houa fakalūsia-sakāline (Sakhalin)',
        'Asia/Samarkand' => 'houa fakaʻusipekitani (Samarkand)',
        'Asia/Seoul' => 'houa fakakōlea (Seoul)',
        'Asia/Shanghai' => 'houa fakasiaina (Shanghai)',
        'Asia/Singapore' => 'houa fakasingapoa (Singapore)',
        'Asia/Srednekolymsk' => 'houa fakalūsia-makatani (Srednekolymsk)',
        'Asia/Taipei' => 'houa fakataipei',
        'Asia/Tashkent' => 'houa fakaʻusipekitani (Tashkent)',
        'Asia/Tbilisi' => 'houa fakaseōsia (Tbilisi)',
        'Asia/Tehran' => 'houa fakaʻilaani (Tehran)',
        'Asia/Thimphu' => 'houa fakapūtani (Thimphu)',
        'Asia/Tokyo' => 'houa fakasiapani (Tokyo)',
        'Asia/Tomsk' => 'Taimi Lūsia (Tomsk)',
        'Asia/Ulaanbaatar' => 'houa fakaʻulānipātā (Ulaanbaatar)',
        'Asia/Urumqi' => 'Taimi Siaina (Urumqi)',
        'Asia/Ust-Nera' => 'houa fakalūsia-valativositoki (Ust-Nera)',
        'Asia/Vientiane' => 'houa fakaʻinitosiaina (Vientiane)',
        'Asia/Vladivostok' => 'houa fakalūsia-valativositoki (Vladivostok)',
        'Asia/Yakutsk' => 'houa fakalūsia-ʻiākutisiki (Yakutsk)',
        'Asia/Yekaterinburg' => 'houa fakalūsia-ʻiekatelinepūki (Yekaterinburg)',
        'Asia/Yerevan' => 'houa fakaʻāmenia (Yerevan)',
        'Atlantic/Azores' => 'houa fakaʻāsolesi (Azores)',
        'Atlantic/Bermuda' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Bermuda)',
        'Atlantic/Canary' => 'houa fakaʻeulope-hihifo (Canary)',
        'Atlantic/Cape_Verde' => 'houa fakamuiʻi-vēte (Cape Verde)',
        'Atlantic/Faeroe' => 'houa fakaʻeulope-hihifo (Faroe)',
        'Atlantic/Madeira' => 'houa fakaʻeulope-hihifo (Madeira)',
        'Atlantic/Reykjavik' => 'houa fakakiliniuisi mālie (Reykjavik)',
        'Atlantic/South_Georgia' => 'houa fakasiosiatonga (South Georgia)',
        'Atlantic/St_Helena' => 'houa fakakiliniuisi mālie (St. Helena)',
        'Atlantic/Stanley' => 'houa fakaʻotumotu-fokulani (Stanley)',
        'Australia/Adelaide' => 'houa fakaʻaositelēlia-loto (Atelaite)',
        'Australia/Brisbane' => 'houa fakaʻaositelēlia-hahake (Pelisipane)',
        'Australia/Broken_Hill' => 'houa fakaʻaositelēlia-loto (Broken Hill)',
        'Australia/Currie' => 'houa fakaʻaositelēlia-hahake (Currie)',
        'Australia/Darwin' => 'houa fakaʻaositelēlia-loto (Darwin)',
        'Australia/Eucla' => 'houa fakaʻaositelēlia-loto-hihifo (Eucla)',
        'Australia/Hobart' => 'houa fakaʻaositelēlia-hahake (Hobart)',
        'Australia/Lindeman' => 'houa fakaʻaositelēlia-hahake (Lindeman)',
        'Australia/Lord_Howe' => 'houa fakamotuʻeikihoue (Lord Howe)',
        'Australia/Melbourne' => 'houa fakaʻaositelēlia-hahake (Melipoane)',
        'Australia/Perth' => 'houa fakaʻaositelēlia-hihifo (Perth)',
        'Australia/Sydney' => 'houa fakaʻaositelēlia-hahake (Senē)',
        'CST6CDT' => 'houa fakaʻamelika-tokelau loto',
        'EST5EDT' => 'houa fakaʻamelika-tokelau hahake',
        'Etc/GMT' => 'houa fakakiliniuisi mālie',
        'Etc/UTC' => 'taimi fakaemāmani',
        'Europe/Amsterdam' => 'houa fakaʻeulope-loto (Amsterdam)',
        'Europe/Andorra' => 'houa fakaʻeulope-loto (Andorra)',
        'Europe/Astrakhan' => 'houa fakalūsia-mosikou (Astrakhan)',
        'Europe/Athens' => 'houa fakaʻeulope-hahake (ʻAtenisi)',
        'Europe/Belgrade' => 'houa fakaʻeulope-loto (Belgrade)',
        'Europe/Berlin' => 'houa fakaʻeulope-loto (Berlin)',
        'Europe/Bratislava' => 'houa fakaʻeulope-loto (Bratislava)',
        'Europe/Brussels' => 'houa fakaʻeulope-loto (Brussels)',
        'Europe/Bucharest' => 'houa fakaʻeulope-hahake (Bucharest)',
        'Europe/Budapest' => 'houa fakaʻeulope-loto (Budapest)',
        'Europe/Busingen' => 'houa fakaʻeulope-loto (Busingen)',
        'Europe/Chisinau' => 'houa fakaʻeulope-hahake (Chisinau)',
        'Europe/Copenhagen' => 'houa fakaʻeulope-loto (Copenhagen)',
        'Europe/Dublin' => 'houa fakakiliniuisi mālie (Dublin)',
        'Europe/Gibraltar' => 'houa fakaʻeulope-loto (Gibraltar)',
        'Europe/Guernsey' => 'houa fakakiliniuisi mālie (Guernsey)',
        'Europe/Helsinki' => 'houa fakaʻeulope-hahake (Helsinki)',
        'Europe/Isle_of_Man' => 'houa fakakiliniuisi mālie (Isle of Man)',
        'Europe/Istanbul' => 'Taimi Toake (Istanbul)',
        'Europe/Jersey' => 'houa fakakiliniuisi mālie (Jersey)',
        'Europe/Kaliningrad' => 'houa fakaʻeulope-hahake (Kaliningrad)',
        'Europe/Kiev' => 'houa fakaʻeulope-hahake (Kiev)',
        'Europe/Kirov' => 'Taimi Lūsia (Kirov)',
        'Europe/Lisbon' => 'houa fakaʻeulope-hihifo (Lisbon)',
        'Europe/Ljubljana' => 'houa fakaʻeulope-loto (Ljubljana)',
        'Europe/London' => 'houa fakakiliniuisi mālie (Lonitoni)',
        'Europe/Luxembourg' => 'houa fakaʻeulope-loto (Luxembourg)',
        'Europe/Madrid' => 'houa fakaʻeulope-loto (Madrid)',
        'Europe/Malta' => 'houa fakaʻeulope-loto (Malta)',
        'Europe/Mariehamn' => 'houa fakaʻeulope-hahake (Mariehamn)',
        'Europe/Minsk' => 'houa fakalūsia-mosikou (Minsk)',
        'Europe/Monaco' => 'houa fakaʻeulope-loto (Monaco)',
        'Europe/Moscow' => 'houa fakalūsia-mosikou',
        'Europe/Oslo' => 'houa fakaʻeulope-loto (Oslo)',
        'Europe/Paris' => 'houa fakaʻeulope-loto (Palesi)',
        'Europe/Podgorica' => 'houa fakaʻeulope-loto (Podgorica)',
        'Europe/Prague' => 'houa fakaʻeulope-loto (Prague)',
        'Europe/Riga' => 'houa fakaʻeulope-hahake (Riga)',
        'Europe/Rome' => 'houa fakaʻeulope-loto (Loma)',
        'Europe/Samara' => 'houa fakalūsia-samala (Samara)',
        'Europe/San_Marino' => 'houa fakaʻeulope-loto (San Marino)',
        'Europe/Sarajevo' => 'houa fakaʻeulope-loto (Sarajevo)',
        'Europe/Saratov' => 'houa fakalūsia-mosikou (Saratov)',
        'Europe/Simferopol' => 'houa fakalūsia-mosikou (Simferopol)',
        'Europe/Skopje' => 'houa fakaʻeulope-loto (Skopje)',
        'Europe/Sofia' => 'houa fakaʻeulope-hahake (Sofia)',
        'Europe/Stockholm' => 'houa fakaʻeulope-loto (Stockholm)',
        'Europe/Tallinn' => 'houa fakaʻeulope-hahake (Tallinn)',
        'Europe/Tirane' => 'houa fakaʻeulope-loto (Tirane)',
        'Europe/Ulyanovsk' => 'houa fakalūsia-mosikou (Ulyanovsk)',
        'Europe/Uzhgorod' => 'houa fakaʻeulope-hahake (Uzhhorod)',
        'Europe/Vaduz' => 'houa fakaʻeulope-loto (Vaduz)',
        'Europe/Vatican' => 'houa fakaʻeulope-loto (Vatikani)',
        'Europe/Vienna' => 'houa fakaʻeulope-loto (Vienna)',
        'Europe/Vilnius' => 'houa fakaʻeulope-hahake (Vilnius)',
        'Europe/Volgograd' => 'houa fakalūsia-volikokalati (Volgograd)',
        'Europe/Warsaw' => 'houa fakaʻeulope-loto (Warsaw)',
        'Europe/Zagreb' => 'houa fakaʻeulope-loto (Zagreb)',
        'Europe/Zaporozhye' => 'houa fakaʻeulope-hahake (Zaporozhye)',
        'Europe/Zurich' => 'houa fakaʻeulope-loto (Zurich)',
        'Indian/Antananarivo' => 'houa fakaʻafelika-hahake (Antananarivo)',
        'Indian/Chagos' => 'houa fakamoanaʻinitia (Chagos)',
        'Indian/Christmas' => 'houa fakamotukilisimasi (Christmas)',
        'Indian/Cocos' => 'houa fakamotukokosi (Cocos)',
        'Indian/Comoro' => 'houa fakaʻafelika-hahake (Comoro)',
        'Indian/Kerguelen' => 'houa fakaʻanetātikafalanisē (Kerguelen)',
        'Indian/Mahe' => 'houa fakaʻotumotu-seiseli (Mahe)',
        'Indian/Maldives' => 'houa fakamalativisi (Maldives)',
        'Indian/Mauritius' => 'houa fakamaulitiusi (Mauritius)',
        'Indian/Mayotte' => 'houa fakaʻafelika-hahake (Mayotte)',
        'Indian/Reunion' => 'houa fakalēunioni (Réunion)',
        'MST7MDT' => 'houa fakaʻamelika-tokelau moʻunga',
        'PST8PDT' => 'houa fakaʻamelika-tokelau pasifika',
        'Pacific/Apia' => 'houa fakaapia',
        'Pacific/Auckland' => 'houa fakanuʻusila (ʻAokalani)',
        'Pacific/Bougainville' => 'houa fakapapuaniukini (Pukanivila)',
        'Pacific/Chatham' => 'houa fakasatihami (Chatham)',
        'Pacific/Easter' => 'houa fakalapanui',
        'Pacific/Efate' => 'houa fakavanuatu (Efate)',
        'Pacific/Enderbury' => 'houa fakaʻotumotufoinikisi (ʻEnitipulī)',
        'Pacific/Fakaofo' => 'houa fakatokelau (Fakaofo)',
        'Pacific/Fiji' => 'houa fakafisi',
        'Pacific/Funafuti' => 'houa fakatūvalu (Funafuti)',
        'Pacific/Galapagos' => 'houa fakakalapakosi (Galapagos)',
        'Pacific/Gambier' => 'houa fakakamipiē',
        'Pacific/Guadalcanal' => 'houa fakaʻotumotusolomone (Kuatākanali)',
        'Pacific/Guam' => 'houa fakakamolo (Kuami)',
        'Pacific/Honolulu' => 'houa fakahauaʻi (Honolulu)',
        'Pacific/Johnston' => 'houa fakahauaʻi (Sionesitoni)',
        'Pacific/Kiritimati' => 'houa fakaʻotumotulaine (Kilisimasi)',
        'Pacific/Kosrae' => 'houa fakakosilae',
        'Pacific/Kwajalein' => 'houa fakaʻotumotumasolo (Kuasaleni)',
        'Pacific/Majuro' => 'houa fakaʻotumotumasolo (Masulo)',
        'Pacific/Marquesas' => 'houa fakamākesasi (Malikuesa)',
        'Pacific/Midway' => 'houa fakahaʻamoa (Mitiuai)',
        'Pacific/Nauru' => 'houa fakanaulu',
        'Pacific/Niue' => 'houa fakaniuē',
        'Pacific/Norfolk' => 'houa fakanoafōki',
        'Pacific/Noumea' => 'houa fakakaletōniafoʻou (Noumea)',
        'Pacific/Pago_Pago' => 'houa fakahaʻamoa (Pangopango)',
        'Pacific/Palau' => 'houa fakapalau',
        'Pacific/Pitcairn' => 'houa fakapitikani (Pitikeni)',
        'Pacific/Ponape' => 'houa fakapōnapē (Ponapē)',
        'Pacific/Port_Moresby' => 'houa fakapapuaniukini (Taulanga Molesipi)',
        'Pacific/Rarotonga' => 'houa fakaʻotumotukuki (Lalotonga)',
        'Pacific/Saipan' => 'houa fakakamolo (Saʻipani)',
        'Pacific/Tahiti' => 'houa fakatahisi',
        'Pacific/Tarawa' => 'houa fakakilipasi (Talava)',
        'Pacific/Tongatapu' => 'houa fakatonga (Tongatapu)',
        'Pacific/Truk' => 'houa fakatūke',
        'Pacific/Wake' => 'houa fakamotuueke',
        'Pacific/Wallis' => 'houa fakaʻuvea mo futuna',
    ],
    'Meta' => [
    ],
];
