<?php

return [
    'Names' => [
        'en_KN' => 'English (St Kitts & Nevis)',
        'en_LC' => 'English (St Lucia)',
        'en_SH' => 'English (St Helena)',
        'en_UM' => 'English (US Outlying Islands)',
        'en_VC' => 'English (St Vincent & the Grenadines)',
        'en_VI' => 'English (US Virgin Islands)',
        'fr_BL' => 'French (St Barthélemy)',
        'fr_MF' => 'French (St Martin)',
        'fr_PM' => 'French (St Pierre & Miquelon)',
    ],
];
