<?php

return [
    'Names' => [
        'fa' => 'دری',
        'fa_AF' => 'دری (افغانستان)',
        'fa_IR' => 'دری (Eron)',
        'ks_Arab' => 'kashmircha (عربی)',
        'ks_Arab_IN' => 'kashmircha (عربی, Hindiston)',
        'pa_Arab' => 'panjobcha (عربی)',
        'pa_Arab_PK' => 'panjobcha (عربی, Pokiston)',
        'ps' => 'پشتو',
        'ps_AF' => 'پشتو (افغانستان)',
        'ps_PK' => 'پشتو (Pokiston)',
        'sd_Arab' => 'sindhi (عربی)',
        'sd_Arab_PK' => 'sindhi (عربی, Pokiston)',
        'uz' => 'اوزبیک',
        'uz_AF' => 'اوزبیک (افغانستان)',
        'uz_Arab' => 'اوزبیک (عربی)',
        'uz_Arab_AF' => 'اوزبیک (عربی, افغانستان)',
        'uz_Cyrl' => 'اوزبیک (kirill)',
        'uz_Cyrl_UZ' => 'اوزبیک (kirill, Oʻzbekiston)',
        'uz_Latn' => 'اوزبیک (lotin)',
        'uz_Latn_UZ' => 'اوزبیک (lotin, Oʻzbekiston)',
        'uz_UZ' => 'اوزبیک (Oʻzbekiston)',
    ],
];
