<?php

return [
    'Names' => [
        'aa' => 'afarština',
        'ab' => 'abcházština',
        'ace' => 'acehština',
        'ach' => 'akolština',
        'ada' => 'adangme',
        'ady' => 'adygejština',
        'ae' => 'avestánština',
        'aeb' => 'arabština (tuniská)',
        'af' => 'afrikánština',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainština',
        'ak' => 'akanština',
        'akk' => 'akkadština',
        'akz' => 'alabamština',
        'ale' => 'aleutština',
        'aln' => 'albánština (Gheg)',
        'alt' => 'altajština (jižní)',
        'am' => 'amharština',
        'an' => 'aragonština',
        'ang' => 'staroangličtina',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabština',
        'arc' => 'aramejština',
        'arn' => 'mapudungun',
        'aro' => 'araonština',
        'arp' => 'arapažština',
        'arq' => 'arabština (alžírská)',
        'ars' => 'arabština (Nadžd)',
        'arw' => 'arawacké jazyky',
        'ary' => 'arabština (marocká)',
        'arz' => 'arabština (egyptská)',
        'as' => 'ásámština',
        'asa' => 'asu',
        'ase' => 'znaková řeč (americká)',
        'ast' => 'asturština',
        'atj' => 'atikamekština',
        'av' => 'avarština',
        'avk' => 'kotava',
        'awa' => 'awadhština',
        'ay' => 'ajmarština',
        'az' => 'ázerbájdžánština',
        'ba' => 'baškirština',
        'bal' => 'balúčština',
        'ban' => 'balijština',
        'bar' => 'bavorština',
        'bas' => 'basa',
        'bax' => 'bamun',
        'bbc' => 'batak toba',
        'bbj' => 'ghomala',
        'be' => 'běloruština',
        'bej' => 'bedža',
        'bem' => 'bembština',
        'bew' => 'batavština',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bfq' => 'badagština',
        'bg' => 'bulharština',
        'bgn' => 'balúčština (západní)',
        'bho' => 'bhódžpurština',
        'bi' => 'bislamština',
        'bik' => 'bikolština',
        'bin' => 'bini',
        'bjn' => 'bandžarština',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'bm' => 'bambarština',
        'bn' => 'bengálština',
        'bo' => 'tibetština',
        'bpy' => 'bišnuprijskomanipurština',
        'bqi' => 'bachtijárština',
        'br' => 'bretonština',
        'bra' => 'bradžština',
        'brh' => 'brahujština',
        'brx' => 'bodoština',
        'bs' => 'bosenština',
        'bss' => 'akoose',
        'bua' => 'burjatština',
        'bug' => 'bugiština',
        'bum' => 'bulu',
        'byn' => 'blinština',
        'byv' => 'medumba',
        'ca' => 'katalánština',
        'cad' => 'caddo',
        'car' => 'karibština',
        'cay' => 'kajugština',
        'cch' => 'atsam',
        'ccp' => 'čakma',
        'ce' => 'čečenština',
        'ceb' => 'cebuánština',
        'cgg' => 'kiga',
        'ch' => 'čamoro',
        'chb' => 'čibča',
        'chg' => 'čagatajština',
        'chk' => 'čukština',
        'chm' => 'marijština',
        'chn' => 'činuk pidžin',
        'cho' => 'čoktština',
        'chp' => 'čipevajština',
        'chr' => 'čerokézština',
        'chy' => 'čejenština',
        'ckb' => 'kurdština (sorání)',
        'clc' => 'čilkotinština',
        'co' => 'korsičtina',
        'cop' => 'koptština',
        'cps' => 'kapiznonština',
        'cr' => 'kríjština',
        'crg' => 'mičif',
        'crh' => 'tatarština (krymská)',
        'crj' => 'kríjština (jihovýchodní)',
        'crk' => 'kríjština (z plání)',
        'crl' => 'kríjština (severovýchodní)',
        'crm' => 'kríjština (Moose)',
        'crr' => 'algonkinština (Karolína)',
        'crs' => 'kreolština (seychelská)',
        'cs' => 'čeština',
        'csb' => 'kašubština',
        'csw' => 'kríjština (z bažin)',
        'cu' => 'staroslověnština',
        'cv' => 'čuvaština',
        'cy' => 'velština',
        'da' => 'dánština',
        'dak' => 'dakotština',
        'dar' => 'dargština',
        'dav' => 'taita',
        'de' => 'němčina',
        'del' => 'delawarština',
        'den' => 'slejvština (athabaský jazyk)',
        'dgr' => 'dogrib',
        'din' => 'dinkština',
        'dje' => 'zarmština',
        'doi' => 'dogarština',
        'dsb' => 'dolnolužická srbština',
        'dtp' => 'kadazandusunština',
        'dua' => 'dualština',
        'dum' => 'holandština (středověká)',
        'dv' => 'maledivština',
        'dyo' => 'jola-fonyi',
        'dyu' => 'djula',
        'dz' => 'dzongkä',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'eweština',
        'efi' => 'efikština',
        'egl' => 'emilijština',
        'egy' => 'egyptština stará',
        'eka' => 'ekajuk',
        'el' => 'řečtina',
        'elx' => 'elamitština',
        'en' => 'angličtina',
        'enm' => 'angličtina (středověká)',
        'eo' => 'esperanto',
        'es' => 'španělština',
        'esu' => 'jupikština (středoaljašská)',
        'et' => 'estonština',
        'eu' => 'baskičtina',
        'ewo' => 'ewondo',
        'ext' => 'extremadurština',
        'fa' => 'perština',
        'fan' => 'fang',
        'fat' => 'fantština',
        'ff' => 'fulbština',
        'fi' => 'finština',
        'fil' => 'filipínština',
        'fit' => 'finština (tornedalská)',
        'fj' => 'fidžijština',
        'fo' => 'faerština',
        'fon' => 'fonština',
        'fr' => 'francouzština',
        'frc' => 'francouzština (cajunská)',
        'frm' => 'francouzština (středověká)',
        'fro' => 'francouzština (stará)',
        'frp' => 'franko-provensálština',
        'frr' => 'fríština (severní)',
        'frs' => 'fríština (východní)',
        'fur' => 'furlanština',
        'fy' => 'fríština (západní)',
        'ga' => 'irština',
        'gaa' => 'gaština',
        'gag' => 'gagauzština',
        'gan' => 'čínština (dialekty Gan)',
        'gay' => 'gayo',
        'gba' => 'gbaja',
        'gbz' => 'daríjština (zoroastrijská)',
        'gd' => 'skotská gaelština',
        'gez' => 'geez',
        'gil' => 'kiribatština',
        'gl' => 'galicijština',
        'glk' => 'gilačtina',
        'gmh' => 'hornoněmčina (středověká)',
        'gn' => 'guaranština',
        'goh' => 'hornoněmčina (stará)',
        'gom' => 'konkánština (Goa)',
        'gon' => 'góndština',
        'gor' => 'gorontalo',
        'got' => 'gótština',
        'grb' => 'grebo',
        'grc' => 'starořečtina',
        'gsw' => 'němčina (Švýcarsko)',
        'gu' => 'gudžarátština',
        'guc' => 'wayúuština',
        'gur' => 'frafra',
        'guz' => 'gusii',
        'gv' => 'manština',
        'gwi' => 'gwichʼin',
        'ha' => 'hauština',
        'hai' => 'haidština',
        'hak' => 'čínština (dialekty Hakka)',
        'haw' => 'havajština',
        'hax' => 'haidština (jižní)',
        'he' => 'hebrejština',
        'hi' => 'hindština',
        'hif' => 'hindština (Fidži)',
        'hil' => 'hiligajnonština',
        'hit' => 'chetitština',
        'hmn' => 'hmongština',
        'ho' => 'hiri motu',
        'hr' => 'chorvatština',
        'hsb' => 'hornolužická srbština',
        'hsn' => 'čínština (dialekty Xiang)',
        'ht' => 'haitština',
        'hu' => 'maďarština',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'arménština',
        'hz' => 'hererština',
        'ia' => 'interlingua',
        'iba' => 'ibanština',
        'ibb' => 'ibibio',
        'id' => 'indonéština',
        'ie' => 'interlingue',
        'ig' => 'igboština',
        'ii' => 'iština (sečuánská)',
        'ik' => 'inupiakština',
        'ikt' => 'inuktitutština (západokanadská)',
        'ilo' => 'ilokánština',
        'inh' => 'inguština',
        'io' => 'ido',
        'is' => 'islandština',
        'it' => 'italština',
        'iu' => 'inuktitutština',
        'izh' => 'ingrijština',
        'ja' => 'japonština',
        'jam' => 'jamajská kreolština',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'mašame',
        'jpr' => 'judeoperština',
        'jrb' => 'judeoarabština',
        'jut' => 'jutština',
        'jv' => 'javánština',
        'ka' => 'gruzínština',
        'kaa' => 'karakalpačtina',
        'kab' => 'kabylština',
        'kac' => 'kačijština',
        'kaj' => 'jju',
        'kam' => 'kambština',
        'kaw' => 'kawi',
        'kbd' => 'kabardinština',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kapverdština',
        'ken' => 'kenyang',
        'kfo' => 'koro',
        'kg' => 'konžština',
        'kgp' => 'kaingang',
        'kha' => 'khásí',
        'kho' => 'chotánština',
        'khq' => 'koyra chiini',
        'khw' => 'chovarština',
        'ki' => 'kikujština',
        'kiu' => 'zazakština',
        'kj' => 'kuaňamština',
        'kk' => 'kazaština',
        'kkj' => 'kako',
        'kl' => 'grónština',
        'kln' => 'kalendžin',
        'km' => 'khmérština',
        'kmb' => 'kimbundština',
        'kn' => 'kannadština',
        'ko' => 'korejština',
        'koi' => 'komi-permjačtina',
        'kok' => 'konkánština',
        'kos' => 'kosrajština',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karačajevo-balkarština',
        'kri' => 'krio',
        'krj' => 'kinaraj-a',
        'krl' => 'karelština',
        'kru' => 'kuruchština',
        'ks' => 'kašmírština',
        'ksb' => 'šambala',
        'ksf' => 'bafia',
        'ksh' => 'kolínština',
        'ku' => 'kurdština',
        'kum' => 'kumyčtina',
        'kut' => 'kutenajština',
        'kv' => 'komijština',
        'kw' => 'kornština',
        'kwk' => 'kvakiutština',
        'ky' => 'kyrgyzština',
        'la' => 'latina',
        'lad' => 'ladinština',
        'lag' => 'langi',
        'lah' => 'lahndština',
        'lam' => 'lambština',
        'lb' => 'lucemburština',
        'lez' => 'lezginština',
        'lfn' => 'lingua franca nova',
        'lg' => 'gandština',
        'li' => 'limburština',
        'lij' => 'ligurština',
        'lil' => 'lillooetština',
        'liv' => 'livonština',
        'lkt' => 'lakotština',
        'lmo' => 'lombardština',
        'ln' => 'lingalština',
        'lo' => 'laoština',
        'lol' => 'mongština',
        'lou' => 'kreolština (Louisiana)',
        'loz' => 'lozština',
        'lrc' => 'lúrština (severní)',
        'lsm' => 'samia',
        'lt' => 'litevština',
        'ltg' => 'latgalština',
        'lu' => 'lubu-katanžština',
        'lua' => 'luba-luluaština',
        'lui' => 'luiseňo',
        'lun' => 'lundština',
        'luo' => 'luoština',
        'lus' => 'mizoština',
        'luy' => 'luhja',
        'lv' => 'lotyština',
        'lzh' => 'čínština (klasická)',
        'lzz' => 'lazština',
        'mad' => 'madurština',
        'maf' => 'mafa',
        'mag' => 'magahijština',
        'mai' => 'maithiliština',
        'mak' => 'makasarština',
        'man' => 'mandingština',
        'mas' => 'masajština',
        'mde' => 'maba',
        'mdf' => 'mokšanština',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'mauricijská kreolština',
        'mg' => 'malgaština',
        'mga' => 'irština (středověká)',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'maršálština',
        'mi' => 'maorština',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'makedonština',
        'ml' => 'malajálamština',
        'mn' => 'mongolština',
        'mnc' => 'mandžuština',
        'mni' => 'manipurština',
        'moe' => 'innu-aimun',
        'moh' => 'mohawkština',
        'mos' => 'mosi',
        'mr' => 'maráthština',
        'mrj' => 'marijština (západní)',
        'ms' => 'malajština',
        'mt' => 'maltština',
        'mua' => 'mundang',
        'mus' => 'kríkština',
        'mwl' => 'mirandština',
        'mwr' => 'márvárština',
        'mwv' => 'mentavajština',
        'my' => 'barmština',
        'mye' => 'myene',
        'myv' => 'erzjanština',
        'mzn' => 'mázandaránština',
        'na' => 'naurština',
        'nan' => 'čínština (dialekty Minnan)',
        'nap' => 'neapolština',
        'naq' => 'namaština',
        'nb' => 'norština (bokmål)',
        'nd' => 'ndebele (Zimbabwe)',
        'nds' => 'dolnoněmčina',
        'ne' => 'nepálština',
        'new' => 'névárština',
        'ng' => 'ndondština',
        'nia' => 'nias',
        'niu' => 'niueština',
        'njo' => 'ao (jazyky Nágálandu)',
        'nl' => 'nizozemština',
        'nmg' => 'kwasio',
        'nn' => 'norština (nynorsk)',
        'nnh' => 'ngiemboon',
        'no' => 'norština',
        'nog' => 'nogajština',
        'non' => 'norština historická',
        'nov' => 'novial',
        'nqo' => 'n’ko',
        'nr' => 'ndebele (Jižní Afrika)',
        'nso' => 'sotština (severní)',
        'nus' => 'nuerština',
        'nv' => 'navažština',
        'nwc' => 'newarština (klasická)',
        'ny' => 'ňandžština',
        'nym' => 'ňamwežština',
        'nyn' => 'ňankolština',
        'nyo' => 'ňorština',
        'nzi' => 'nzima',
        'oc' => 'okcitánština',
        'oj' => 'odžibvejština',
        'ojb' => 'odžibvejština (severozápadní)',
        'ojc' => 'odžibvejština (střední)',
        'ojs' => 'odžibvejština (severní)',
        'ojw' => 'odžibvejština (západní)',
        'oka' => 'okanaganština',
        'om' => 'oromština',
        'or' => 'urijština',
        'os' => 'osetština',
        'osa' => 'osage',
        'ota' => 'turečtina (osmanská)',
        'pa' => 'paňdžábština',
        'pag' => 'pangasinanština',
        'pal' => 'pahlavština',
        'pam' => 'papangau',
        'pap' => 'papiamento',
        'pau' => 'palauština',
        'pcd' => 'picardština',
        'pcm' => 'nigerijský pidžin',
        'pdc' => 'němčina (pensylvánská)',
        'pdt' => 'němčina (plautdietsch)',
        'peo' => 'staroperština',
        'pfl' => 'falčtina',
        'phn' => 'féničtina',
        'pi' => 'pálí',
        'pis' => 'pidžin (Šalomounovy ostrovy)',
        'pl' => 'polština',
        'pms' => 'piemonština',
        'pnt' => 'pontština',
        'pon' => 'pohnpeiština',
        'pqm' => 'malesitština-passamaquoddština',
        'prg' => 'pruština',
        'pro' => 'provensálština',
        'ps' => 'paštština',
        'pt' => 'portugalština',
        'qu' => 'kečuánština',
        'quc' => 'kičé',
        'qug' => 'kečuánština (chimborazo)',
        'raj' => 'rádžastánština',
        'rap' => 'rapanujština',
        'rar' => 'rarotongánština',
        'rgn' => 'romaňolština',
        'rhg' => 'rohingština',
        'rif' => 'rífština',
        'rm' => 'rétorománština',
        'rn' => 'kirundština',
        'ro' => 'rumunština',
        'rof' => 'rombo',
        'rom' => 'romština',
        'rtm' => 'rotumanština',
        'ru' => 'ruština',
        'rue' => 'rusínština',
        'rug' => 'rovianština',
        'rup' => 'arumunština',
        'rw' => 'kiňarwandština',
        'rwk' => 'rwa',
        'sa' => 'sanskrt',
        'sad' => 'sandawština',
        'sah' => 'jakutština',
        'sam' => 'samarština',
        'saq' => 'samburu',
        'sas' => 'sasakština',
        'sat' => 'santálština',
        'saz' => 'saurášterština',
        'sba' => 'ngambay',
        'sbp' => 'sangoština',
        'sc' => 'sardština',
        'scn' => 'sicilština',
        'sco' => 'skotština',
        'sd' => 'sindhština',
        'sdc' => 'sassarština',
        'sdh' => 'kurdština (jižní)',
        'se' => 'sámština (severní)',
        'see' => 'seneca',
        'seh' => 'sena',
        'sei' => 'seriština',
        'sel' => 'selkupština',
        'ses' => 'koyraboro senni',
        'sg' => 'sangština',
        'sga' => 'irština (stará)',
        'sgs' => 'žemaitština',
        'sh' => 'srbochorvatština',
        'shi' => 'tašelhit',
        'shn' => 'šanština',
        'shu' => 'arabština (čadská)',
        'si' => 'sinhálština',
        'sid' => 'sidamo',
        'sk' => 'slovenština',
        'sl' => 'slovinština',
        'slh' => 'lushootseed (jižní)',
        'sli' => 'němčina (slezská)',
        'sly' => 'selajarština',
        'sm' => 'samojština',
        'sma' => 'sámština (jižní)',
        'smj' => 'sámština (lulejská)',
        'smn' => 'sámština (inarijská)',
        'sms' => 'sámština (skoltská)',
        'sn' => 'šonština',
        'snk' => 'sonikština',
        'so' => 'somálština',
        'sog' => 'sogdština',
        'sq' => 'albánština',
        'sr' => 'srbština',
        'srn' => 'sranan tongo',
        'srr' => 'sererština',
        'ss' => 'siswatština',
        'ssy' => 'saho',
        'st' => 'sotština (jižní)',
        'stq' => 'fríština (saterlandská)',
        'str' => 'saliština (z úžin)',
        'su' => 'sundština',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumerština',
        'sv' => 'švédština',
        'sw' => 'svahilština',
        'swb' => 'komorština',
        'syc' => 'syrština (klasická)',
        'syr' => 'syrština',
        'szl' => 'slezština',
        'ta' => 'tamilština',
        'tce' => 'tutčonština (jižní)',
        'tcy' => 'tuluština',
        'te' => 'telugština',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetumština',
        'tg' => 'tádžičtina',
        'tgx' => 'tagiš',
        'th' => 'thajština',
        'tht' => 'tahltan',
        'ti' => 'tigrinijština',
        'tig' => 'tigrejština',
        'tiv' => 'tivština',
        'tk' => 'turkmenština',
        'tkl' => 'tokelauština',
        'tkr' => 'cachurština',
        'tl' => 'tagalog',
        'tlh' => 'klingonština',
        'tli' => 'tlingit',
        'tly' => 'talyština',
        'tmh' => 'tamašek',
        'tn' => 'setswanština',
        'to' => 'tongánština',
        'tog' => 'tonžština (nyasa)',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turečtina',
        'tru' => 'turojština',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsd' => 'tsakonština',
        'tsi' => 'tsimšijské jazyky',
        'tt' => 'tatarština',
        'ttm' => 'tutčonština (severní)',
        'ttt' => 'tatština',
        'tum' => 'tumbukština',
        'tvl' => 'tuvalština',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitština',
        'tyv' => 'tuvinština',
        'tzm' => 'tamazight (střední Maroko)',
        'udm' => 'udmurtština',
        'ug' => 'ujgurština',
        'uga' => 'ugaritština',
        'uk' => 'ukrajinština',
        'umb' => 'umbundu',
        'ur' => 'urdština',
        'uz' => 'uzbečtina',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'benátština',
        'vep' => 'vepština',
        'vi' => 'vietnamština',
        'vls' => 'vlámština (západní)',
        'vmf' => 'němčina (mohansko-franské dialekty)',
        'vo' => 'volapük',
        'vot' => 'votština',
        'vro' => 'võruština',
        'vun' => 'vunjo',
        'wa' => 'valonština',
        'wae' => 'němčina (walser)',
        'wal' => 'wolajtština',
        'war' => 'warajština',
        'was' => 'waština',
        'wbp' => 'warlpiri',
        'wo' => 'wolofština',
        'wuu' => 'čínština (dialekty Wu)',
        'xal' => 'kalmyčtina',
        'xh' => 'xhoština',
        'xmf' => 'mingrelština',
        'xog' => 'sogština',
        'yao' => 'jaoština',
        'yap' => 'japština',
        'yav' => 'jangbenština',
        'ybb' => 'yemba',
        'yi' => 'jidiš',
        'yo' => 'jorubština',
        'yrl' => 'nheengatu',
        'yue' => 'kantonština',
        'za' => 'čuangština',
        'zap' => 'zapotéčtina',
        'zbl' => 'bliss systém',
        'zea' => 'zélandština',
        'zen' => 'zenaga',
        'zgh' => 'tamazight (standardní marocký)',
        'zh' => 'čínština',
        'zu' => 'zuluština',
        'zun' => 'zunijština',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabština (moderní standardní)',
        'de_CH' => 'němčina standardní (Švýcarsko)',
        'en_GB' => 'angličtina (Velká Británie)',
        'en_US' => 'angličtina (USA)',
        'es_ES' => 'španělština (Evropa)',
        'fa_AF' => 'darí',
        'nds_NL' => 'dolnosaština',
        'nl_BE' => 'vlámština',
        'pt_PT' => 'portugalština (Evropa)',
        'ro_MD' => 'moldavština',
        'sw_CD' => 'svahilština (Kongo)',
        'zh_Hans' => 'čínština (zjednodušená)',
    ],
];
