{% set pagetitle = 'Error report sent'|trans %}
{% extends "base.twig" %}

{% block content %}
    <h2>{{ pagetitle }}</h2>

    <p>{{ 'The error report has been sent to the administrators.' |trans }}</p>
{% endblock %}
