<?php

return [
    'Names' => [
        'aa' => 'афар тілі',
        'ab' => 'абхаз тілі',
        'ace' => 'ачех тілі',
        'ada' => 'адангме тілі',
        'ady' => 'адыгей тілі',
        'af' => 'африкаанс тілі',
        'agq' => 'агем тілі',
        'ain' => 'айну тілі',
        'ak' => 'акан тілі',
        'ale' => 'алеут тілі',
        'alt' => 'оңтүстік алтай тілі',
        'am' => 'амхар тілі',
        'an' => 'арагон тілі',
        'ann' => 'оболо тілі',
        'anp' => 'ангика тілі',
        'ar' => 'араб тілі',
        'arn' => 'мапуче тілі',
        'arp' => 'арапахо тілі',
        'ars' => 'араб тілі (Неджда)',
        'as' => 'ассам тілі',
        'asa' => 'асу тілі',
        'ast' => 'астурия тілі',
        'atj' => 'атикамек тілі',
        'av' => 'авар тілі',
        'awa' => 'авадхи тілі',
        'ay' => 'аймара тілі',
        'az' => 'әзірбайжан тілі',
        'ba' => 'башқұрт тілі',
        'ban' => 'бали тілі',
        'bas' => 'баса тілі',
        'be' => 'беларусь тілі',
        'bem' => 'бемба тілі',
        'bez' => 'бена тілі',
        'bg' => 'болгар тілі',
        'bgn' => 'батыс балучи тілі',
        'bho' => 'бходжпури тілі',
        'bi' => 'бислама тілі',
        'bin' => 'бини тілі',
        'bla' => 'сиксика тілі',
        'bm' => 'бамбара тілі',
        'bn' => 'бенгал тілі',
        'bo' => 'тибет тілі',
        'br' => 'бретон тілі',
        'brx' => 'бодо тілі',
        'bs' => 'босния тілі',
        'bug' => 'бугис тілі',
        'byn' => 'блин тілі',
        'ca' => 'каталан тілі',
        'cay' => 'кайюга тілі',
        'ccp' => 'чакма тілі',
        'ce' => 'шешен тілі',
        'ceb' => 'себуано тілі',
        'cgg' => 'кига тілі',
        'ch' => 'чаморро тілі',
        'chk' => 'чуук тілі',
        'chm' => 'мари тілі',
        'cho' => 'чокто тілі',
        'chp' => 'чипевайан тілі',
        'chr' => 'чероки тілі',
        'chy' => 'шайен тілі',
        'ckb' => 'сорани тілі',
        'clc' => 'чилкотин тілі',
        'co' => 'корсика тілі',
        'crg' => 'мичиф тілі',
        'crj' => 'оңтүстік-шығыс кри тілі',
        'crk' => 'жазықтағы кри тілі',
        'crl' => 'солтүстік-шығыс кри тілі',
        'crm' => 'мус кри тілі',
        'crr' => 'каролиналық алгонкин тілі',
        'crs' => 'сейшельдік креол тілі',
        'cs' => 'чех тілі',
        'csw' => 'батпақты жердің кри тілі',
        'cu' => 'шіркеулік славян тілі',
        'cv' => 'чуваш тілі',
        'cy' => 'валлий тілі',
        'da' => 'дат тілі',
        'dak' => 'дакота тілі',
        'dar' => 'даргин тілі',
        'dav' => 'таита тілі',
        'de' => 'неміс тілі',
        'dgr' => 'догриб тілі',
        'dje' => 'зарма тілі',
        'doi' => 'догри тілі',
        'dsb' => 'төменгі лужица тілі',
        'dua' => 'дуала тілі',
        'dv' => 'дивехи тілі',
        'dyo' => 'диола тілі',
        'dz' => 'дзонг-кэ тілі',
        'dzg' => 'дазага тілі',
        'ebu' => 'эмбу тілі',
        'ee' => 'эве тілі',
        'efi' => 'эфик тілі',
        'eka' => 'экаджук тілі',
        'el' => 'грек тілі',
        'en' => 'ағылшын тілі',
        'eo' => 'эсперанто тілі',
        'es' => 'испан тілі',
        'et' => 'эстон тілі',
        'eu' => 'баск тілі',
        'ewo' => 'эвондо тілі',
        'fa' => 'парсы тілі',
        'ff' => 'фула тілі',
        'fi' => 'фин тілі',
        'fil' => 'филиппин тілі',
        'fj' => 'фиджи тілі',
        'fo' => 'фарер тілі',
        'fon' => 'фон тілі',
        'fr' => 'француз тілі',
        'frc' => 'каджун тілі (француз)',
        'frr' => 'солтүстік фриз тілі',
        'fur' => 'фриуль тілі',
        'fy' => 'батыс фриз тілі',
        'ga' => 'ирланд тілі',
        'gaa' => 'га тілі',
        'gag' => 'гагауз тілі',
        'gd' => 'шотландиялық гэль тілі',
        'gez' => 'геэз тілі',
        'gil' => 'гильберт тілі',
        'gl' => 'галисия тілі',
        'gn' => 'гуарани тілі',
        'gor' => 'горонтало тілі',
        'gsw' => 'неміс тілі (Швейцария)',
        'gu' => 'гуджарати тілі',
        'guz' => 'гусии тілі',
        'gv' => 'мэн тілі',
        'gwi' => 'гвичин тілі',
        'ha' => 'хауса тілі',
        'hai' => 'хайда тілі',
        'haw' => 'гавайи тілі',
        'hax' => 'оңтүстік хайда тілі',
        'he' => 'иврит тілі',
        'hi' => 'хинди тілі',
        'hil' => 'хилигайнон тілі',
        'hmn' => 'хмонг тілі',
        'hr' => 'хорват тілі',
        'hsb' => 'жоғарғы лужица тілі',
        'ht' => 'гаити тілі',
        'hu' => 'венгр тілі',
        'hup' => 'хупа тілі',
        'hur' => 'халкомелем тілі',
        'hy' => 'армян тілі',
        'hz' => 'гереро тілі',
        'ia' => 'интерлингва тілі',
        'iba' => 'ибан тілі',
        'ibb' => 'ибибио тілі',
        'id' => 'индонезия тілі',
        'ie' => 'интерлингве тілі',
        'ig' => 'игбо тілі',
        'ii' => 'сычуан и тілі',
        'ikt' => 'батыс канадалық инуктитут тілі',
        'ilo' => 'илоко тілі',
        'inh' => 'ингуш тілі',
        'io' => 'идо тілі',
        'is' => 'исланд тілі',
        'it' => 'итальян тілі',
        'iu' => 'инуктитут тілі',
        'ja' => 'жапон тілі',
        'jbo' => 'ложбан тілі',
        'jgo' => 'нгомба тілі',
        'jmc' => 'мачаме тілі',
        'jv' => 'ява тілі',
        'ka' => 'грузин тілі',
        'kab' => 'кабил тілі',
        'kac' => 'качин тілі',
        'kaj' => 'каджи тілі',
        'kam' => 'камба тілі',
        'kbd' => 'кабардин тілі',
        'kcg' => 'тьяп тілі',
        'kde' => 'маконде тілі',
        'kea' => 'кабувердьяну тілі',
        'kfo' => 'коро тілі',
        'kgp' => 'кайнганг тілі',
        'kha' => 'кхаси тілі',
        'khq' => 'койра чини тілі',
        'ki' => 'кикуйю тілі',
        'kj' => 'кваньяма тілі',
        'kk' => 'қазақ тілі',
        'kkj' => 'како тілі',
        'kl' => 'калаалисут тілі',
        'kln' => 'каленжин тілі',
        'km' => 'кхмер тілі',
        'kmb' => 'кимбунду тілі',
        'kn' => 'каннада тілі',
        'ko' => 'корей тілі',
        'koi' => 'коми-пермяк тілі',
        'kok' => 'конкани тілі',
        'kpe' => 'кпелле тілі',
        'kr' => 'канури тілі',
        'krc' => 'қарашай-балқар тілі',
        'krl' => 'карель тілі',
        'kru' => 'курух тілі',
        'ks' => 'кашмир тілі',
        'ksb' => 'шамбала тілі',
        'ksf' => 'бафиа тілі',
        'ksh' => 'кёльн тілі',
        'ku' => 'күрд тілі',
        'kum' => 'құмық тілі',
        'kv' => 'коми тілі',
        'kw' => 'корн тілі',
        'kwk' => 'квакиутль тілі',
        'ky' => 'қырғыз тілі',
        'la' => 'латын тілі',
        'lad' => 'ладино тілі',
        'lag' => 'ланги тілі',
        'lb' => 'люксембург тілі',
        'lez' => 'лезгин тілі',
        'lg' => 'ганда тілі',
        'li' => 'лимбург тілі',
        'lij' => 'лигур тілі',
        'lil' => 'лиллуэт тілі',
        'lkt' => 'лакота тілі',
        'ln' => 'лингала тілі',
        'lo' => 'лаос тілі',
        'lou' => 'креоль тілі (Луизиана)',
        'loz' => 'лози тілі',
        'lrc' => 'солтүстік люри тілі',
        'lsm' => 'самия тілі',
        'lt' => 'литва тілі',
        'lu' => 'луба-катанга тілі',
        'lua' => 'луба-лулуа тілі',
        'lun' => 'лунда тілі',
        'luo' => 'луо тілі',
        'lus' => 'мизо тілі',
        'luy' => 'лухиа тілі',
        'lv' => 'латыш тілі',
        'mad' => 'мадур тілі',
        'mag' => 'магахи тілі',
        'mai' => 'майтхили тілі',
        'mak' => 'макасар тілі',
        'mas' => 'масай тілі',
        'mdf' => 'мокша тілі',
        'men' => 'менде тілі',
        'mer' => 'меру тілі',
        'mfe' => 'морисиен тілі',
        'mg' => 'малагаси тілі',
        'mgh' => 'макуа-меетто тілі',
        'mgo' => 'мета тілі',
        'mh' => 'маршалл тілі',
        'mi' => 'маори тілі',
        'mic' => 'микмак тілі',
        'min' => 'минангкабау тілі',
        'mk' => 'македон тілі',
        'ml' => 'малаялам тілі',
        'mn' => 'моңғол тілі',
        'mni' => 'манипури тілі',
        'moe' => 'инну-аймун тілі',
        'moh' => 'могавк тілі',
        'mos' => 'мосси тілі',
        'mr' => 'маратхи тілі',
        'ms' => 'малай тілі',
        'mt' => 'мальта тілі',
        'mua' => 'мунданг тілі',
        'mus' => 'крик тілі',
        'mwl' => 'миранд тілі',
        'my' => 'бирма тілі',
        'myv' => 'эрзя тілі',
        'mzn' => 'мазандеран тілі',
        'na' => 'науру тілі',
        'nap' => 'неаполитан тілі',
        'naq' => 'нама тілі',
        'nb' => 'норвегиялық букмол тілі',
        'nd' => 'солтүстік ндебеле тілі',
        'nds' => 'төменгі неміс тілі',
        'ne' => 'непал тілі',
        'new' => 'невар тілі',
        'ng' => 'ндонга тілі',
        'nia' => 'ниас тілі',
        'niu' => 'ниуэ тілі',
        'nl' => 'нидерланд тілі',
        'nmg' => 'квасио тілі',
        'nn' => 'норвегиялық нюнорск тілі',
        'nnh' => 'нгиембун тілі',
        'no' => 'норвег тілі',
        'nog' => 'ноғай тілі',
        'nqo' => 'нко тілі',
        'nr' => 'оңтүстік ндебеле тілі',
        'nso' => 'солтүстік сото тілі',
        'nus' => 'нуэр тілі',
        'nv' => 'навахо тілі',
        'ny' => 'ньянджа тілі',
        'nyn' => 'нианколе тілі',
        'oc' => 'окситан тілі',
        'ojb' => 'солтүстік-батыс оджибве тілі',
        'ojc' => 'орталық оджибве тілі',
        'ojs' => 'оджи-кри тілі',
        'ojw' => 'батыс оджибве тілі',
        'oka' => 'оканаган тілі',
        'om' => 'оромо тілі',
        'or' => 'ория тілі',
        'os' => 'осетин тілі',
        'pa' => 'пенджаб тілі',
        'pag' => 'пангасинан тілі',
        'pam' => 'пампанга тілі',
        'pap' => 'папьяменто тілі',
        'pau' => 'палау тілі',
        'pcm' => 'нигериялық пиджин тілі',
        'pis' => 'пиджин тілі',
        'pl' => 'поляк тілі',
        'pqm' => 'малесит-пассамакводди тілі',
        'prg' => 'пруссия тілі',
        'ps' => 'пушту тілі',
        'pt' => 'португал тілі',
        'qu' => 'кечуа тілі',
        'quc' => 'киче тілі',
        'rap' => 'рапануй тілі',
        'rar' => 'раротонган тілі',
        'rhg' => 'рохинджа',
        'rm' => 'романш тілі',
        'rn' => 'рунди тілі',
        'ro' => 'румын тілі',
        'rof' => 'ромбо тілі',
        'ru' => 'орыс тілі',
        'rup' => 'арумын тілі',
        'rw' => 'киньяруанда тілі',
        'rwk' => 'руа тілі',
        'sa' => 'санскрит тілі',
        'sad' => 'сандаве тілі',
        'sah' => 'саха тілі',
        'saq' => 'самбуру тілі',
        'sat' => 'сантали тілі',
        'sba' => 'нгамбай тілі',
        'sbp' => 'сангу тілі',
        'sc' => 'сардин тілі',
        'scn' => 'сицилия тілі',
        'sco' => 'шотланд тілі',
        'sd' => 'синдхи тілі',
        'sdh' => 'оңтүстік күрд тілі',
        'se' => 'солтүстік саам тілі',
        'seh' => 'сена тілі',
        'ses' => 'койраборо сенни тілі',
        'sg' => 'санго тілі',
        'sh' => 'серб-хорват тілі',
        'shi' => 'ташелхит тілі',
        'shn' => 'шан тілі',
        'si' => 'сингал тілі',
        'sk' => 'словак тілі',
        'sl' => 'словен тілі',
        'slh' => 'оңтүстік лушуцид тілі',
        'sm' => 'самоа тілі',
        'sma' => 'оңтүстік саам тілі',
        'smj' => 'луле саам тілі',
        'smn' => 'инари саам тілі',
        'sms' => 'колтта саам тілі',
        'sn' => 'шона тілі',
        'snk' => 'сонинке тілі',
        'so' => 'сомали тілі',
        'sq' => 'албан тілі',
        'sr' => 'серб тілі',
        'srn' => 'сранан тонго тілі',
        'ss' => 'свати тілі',
        'ssy' => 'сахо тілі',
        'st' => 'оңтүстік сото тілі',
        'str' => 'солтүстік стрейтс тілі',
        'su' => 'сундан тілі',
        'suk' => 'сукума тілі',
        'sv' => 'швед тілі',
        'sw' => 'суахили тілі',
        'swb' => 'комор тілі',
        'syr' => 'сирия тілі',
        'ta' => 'тамил тілі',
        'tce' => 'оңтүстік тутчоне тілі',
        'te' => 'телугу тілі',
        'tem' => 'темне тілі',
        'teo' => 'тесо тілі',
        'tet' => 'тетум тілі',
        'tg' => 'тәжік тілі',
        'tgx' => 'тагиш тілі',
        'th' => 'тай тілі',
        'tht' => 'тальтан тілі',
        'ti' => 'тигринья тілі',
        'tig' => 'тигре тілі',
        'tk' => 'түрікмен тілі',
        'tlh' => 'клингон тілі',
        'tli' => 'тлинкит тілі',
        'tn' => 'тсвана тілі',
        'to' => 'тонган тілі',
        'tok' => 'токипона тілі',
        'tpi' => 'ток-писин тілі',
        'tr' => 'түрік тілі',
        'trv' => 'тароко тілі',
        'ts' => 'тсонга тілі',
        'tt' => 'татар тілі',
        'ttm' => 'солтүстік тутчоне тілі',
        'tum' => 'тумбука тілі',
        'tvl' => 'тувалу тілі',
        'tw' => 'тви тілі',
        'twq' => 'тасавак тілі',
        'ty' => 'таити тілі',
        'tyv' => 'тувин тілі',
        'tzm' => 'орталық атлас тамазигхт тілі',
        'udm' => 'удмурт тілі',
        'ug' => 'ұйғыр тілі',
        'uk' => 'украин тілі',
        'umb' => 'умбунду тілі',
        'ur' => 'урду тілі',
        'uz' => 'өзбек тілі',
        'vai' => 'вай тілі',
        've' => 'венда тілі',
        'vec' => 'венеция тілі',
        'vi' => 'вьетнам тілі',
        'vo' => 'волапюк тілі',
        'vun' => 'вунджо тілі',
        'wa' => 'валлон тілі',
        'wae' => 'вальзер тілі',
        'wal' => 'волайта тілі',
        'war' => 'варай тілі',
        'wbp' => 'вальбири тілі',
        'wo' => 'волоф тілі',
        'wuu' => 'қытай тілі (У)',
        'xal' => 'қалмақ тілі',
        'xh' => 'кхоса тілі',
        'xog' => 'сога тілі',
        'yav' => 'янгбен тілі',
        'ybb' => 'йемба тілі',
        'yi' => 'идиш тілі',
        'yo' => 'йоруба тілі',
        'yrl' => 'ньенгату тілі',
        'yue' => 'кантон тілі',
        'zgh' => 'марокколық стандартты тамазигхт тілі',
        'zh' => 'қытай тілі',
        'zu' => 'зулу тілі',
        'zun' => 'зуни тілі',
        'zza' => 'заза тілі',
    ],
    'LocalizedNames' => [
        'ar_001' => 'қазіргі стандартты араб тілі',
        'de_CH' => 'швейцариялық әдеби неміс тілі',
        'fa_AF' => 'дари тілі',
        'hi_Latn' => 'Хинди (латын жазуы)',
        'nds_NL' => 'төменгі саксон тілі',
        'nl_BE' => 'фламанд тілі',
        'pt_BR' => 'бразилиялық португал тілі',
        'pt_PT' => 'еуропалық португал тілі',
        'ro_MD' => 'молдован тілі',
        'sw_CD' => 'конго суахили тілі',
        'zh_Hans' => 'жеңілдетілген қытай тілі',
        'zh_Hant' => 'дәстүрлі қытай тілі',
    ],
];
