<?php

return [
    'Names' => [
        'Arab' => 'Араббаг',
        'Cyrl' => 'Киррилицӕ',
        'Hans' => 'Ӕнцонгонд китайаг',
        'Hant' => 'Традицион китайаг',
        'Latn' => 'Латинаг',
        'Zxxx' => 'Нӕфысгӕ',
    ],
];
