<?php

return [
    'Names' => [
        'Aghb' => 'albanais dal Caucasus',
        'Ahom' => 'ahom',
        'Arab' => 'arab',
        'Armi' => 'arameic imperial',
        'Armn' => 'armen',
        'Avst' => 'avestic',
        'Bali' => 'balinais',
        'Batk' => 'batak',
        'Beng' => 'bengal',
        'Blis' => 'simbols da Bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'scrittira da Braille',
        'Bugi' => 'buginais',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'simbols autoctons canadais unifitgads',
        'Cari' => 'carian',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'coptic',
        'Cprt' => 'cipriot',
        'Cyrl' => 'cirillic',
        'Cyrs' => 'slav da baselgia vegl',
        'Deva' => 'devanagari',
        'Dsrt' => 'deseret',
        'Egyd' => 'egipzian demotic',
        'Egyh' => 'egipzian ieratic',
        'Egyp' => 'ieroglifas egipzianas',
        'Ethi' => 'etiopic',
        'Geok' => 'kutsuri',
        'Geor' => 'georgian',
        'Glag' => 'glagolitic',
        'Goth' => 'gotic',
        'Grek' => 'grec',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han cun bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplifitgà',
        'Hant' => 'tradiziunal',
        'Hebr' => 'ebraic',
        'Hira' => 'hiragana',
        'Hmng' => 'pahawn hmong',
        'Hrkt' => 'scrittira da silbas giapunaisa',
        'Hung' => 'ungarais vegl',
        'Inds' => 'indus',
        'Ital' => 'italic vegl',
        'Jamo' => 'jamo',
        'Java' => 'javanais',
        'Jpan' => 'giapunais',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer/cambodschan',
        'Knda' => 'kannada',
        'Kore' => 'corean',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laot',
        'Latf' => 'latin (scrittira gotica)',
        'Latg' => 'latin (scrittira gaelica)',
        'Latn' => 'latin',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'linear A',
        'Linb' => 'linear B',
        'Lyci' => 'lichic',
        'Lydi' => 'lidic',
        'Mand' => 'mandaic',
        'Mani' => 'manicheic',
        'Maya' => 'ieroglifas maya',
        'Mero' => 'meroitic',
        'Mlym' => 'malaisian',
        'Mong' => 'mongolic',
        'Moon' => 'moon',
        'Mtei' => 'meetei mayek',
        'Mymr' => 'burmais',
        'Narb' => 'arab vegl dal nord',
        'Nkoo' => 'n’ko',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'oriya',
        'Osma' => 'osman',
        'Perm' => 'permic vegl',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavi dad inscripziuns',
        'Phlp' => 'pahlavi da psalms',
        'Phlv' => 'pahlavi da cudeschs',
        'Phnx' => 'fenizian',
        'Plrd' => 'fonetica da Pollard',
        'Prti' => 'partic dad inscripziuns',
        'Rjng' => 'rejang',
        'Roro' => 'rongorongo',
        'Runr' => 'runic',
        'Samr' => 'samaritan',
        'Sara' => 'sarati',
        'Sarb' => 'arab vegl dal sid',
        'Saur' => 'saurashtra',
        'Sgnw' => 'lingua da segns',
        'Shaw' => 'shavian',
        'Shrd' => 'sharada',
        'Sinh' => 'singalais',
        'Sund' => 'sundanais',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siric',
        'Syre' => 'siric estrangelo',
        'Syrj' => 'siric dal vest',
        'Syrn' => 'siric da l’ost',
        'Tagb' => 'tagbanwa',
        'Tale' => 'tai le',
        'Talu' => 'tai lue',
        'Taml' => 'tamil',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'tailandais',
        'Tibt' => 'tibetan',
        'Ugar' => 'ugaritic',
        'Vaii' => 'vaii',
        'Visp' => 'alfabet visibel',
        'Xpeo' => 'persian vegl',
        'Xsux' => 'scrittira a cugn sumeric-accadica',
        'Yiii' => 'yi',
        'Zinh' => 'ertà',
        'Zmth' => 'notaziun matematica',
        'Zsye' => 'emojis',
        'Zsym' => 'simbols',
        'Zxxx' => 'betg scrit',
        'Zyyy' => 'betg determinà',
    ],
];
