<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'арабын нэгдсэн эмиратын дирхам',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Афганистаны афгани',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Албанийн лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Арменийн драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Нидерландын Антиллийн гулдер',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Анголын кванза',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Аргентины песо',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Австралийн доллар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Арубын флорин',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Азербайжаны манат',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Босни-Герцеговины хөрвөгч марк',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'барбадос доллар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Бангладешийн така',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Болгарын лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Бахрейн динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Бурундийн франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Бермудын доллар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Брунейн доллар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Боливийн боливиано',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Бразилийн реал',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Багамын доллар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Бутаны нгултрум',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ботсванийн пула',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Беларусийн рубль',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'беларусь рубль (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Белизийн доллар',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'канад доллар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Конгогийн франк',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Швейцарийн франк',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Чилийн песо',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Хятадын юань (офшор)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Хятадын юань',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Колумбын песо',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Коста-Рикагийн колон',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Кубын хөрвөгч песо',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Кубын песо',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Кабо-Вердийн эскудо',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Чехийн крон',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Жибутийн франк',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Данийн крон',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Доминиканы песо',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Алжирийн доллар',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Египетийн фунт',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Эритрейн накфа',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Этиопын бирр',
        ],
        'EUR' => [
            0 => '€',
            1 => 'евро',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Фижигийн доллар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Фолклендийн арлуудын паунд',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Британийн фунт',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Гүржийн лари',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ганагийн седи',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Гибралтарын фунт',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Гамбийн даласи',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Гвинейн франк',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Гватемалын кецал',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Гайанын доллар',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Хонг Конгийн доллар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Гондурасын лемпира',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Хорватын куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Гаитийн гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Унгарын форинт',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Индонезийн рупи',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Израилийн шинэ шекел',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Энэтхэгийн рупи',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Иракийн динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Ираны риял',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Исландын крон',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ямайкийн доллар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Йорданы динар',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Японы иен',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Кенийн шиллинг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Кыргызын сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Камбожийн риел',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Коморын франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Хойд Солонгосын вон',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Өмнөд Солонгосын вон',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Кувейтийн динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Кайманы арлуудын доллар',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Казахстаны тэнгэ',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Лаосын кип',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Ливаны фунт',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Шри-Ланкийн рупи',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Либерийн доллар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Лесото лоти',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'литвийн литас',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'латвийн лац',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Ливийн доллар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Мороккогийн дирхэм',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Молдовын лей',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Малагасийн ариари',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Македонийн динар',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Мьянмарын киат',
        ],
        'MNT' => [
            0 => '₮',
            1 => 'Монгол төгрөг',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Макаогийн патака',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'мавритан угия (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Мавританийн угия',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Маврикийн рупи',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Мальдивийн руфия',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Малавийн квача',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Мексикийн песо',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Малайзын рингит',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Мозамбикийн метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Намибийн доллар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Нигерийн найра',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Никарагуагийн кордоба',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Норвегийн крон',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Балбын рупи',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Шинэ Зеландын доллар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Оманийн риал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Панамын бальбоа',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Перугийн соль',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Папуа-Шинэ Гвинейн кина',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Филиппиний песо',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Пакистаны рупи',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Польшийн злот',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Парагвайн гуарани',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Катарын риал',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Румыны лей',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Сербийн динар',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Оросын рубль',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Руандагийн франк',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Саудын риял',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Соломоны арлуудын доллар',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Сейшелийн рупи',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Суданы фунт',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Шведийн крон',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Сингапурын доллар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Сент Хеленагийн фунт',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Сьерра-Леоны леон',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Сомалийн шиллинг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Суринамын доллар',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Өмнөд Суданы фунт',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'сан-томе ба принсипи добра (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Сан-Томе ба Принсипигийн добра',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Сирийн фунт',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Свазиландын лилангени',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Тайландын бат',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Тажикийн сомон',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Туркмены манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Тунисын доллар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Тонгагийн панга',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Туркийн лира',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Тринидад ба Тобагогийн доллар',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Шинэ Тайванийн доллар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Танзанийн шиллинг',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Украины гривна',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Угандагийн шиллинг',
        ],
        'USD' => [
            0 => '$',
            1 => 'америк доллар',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Уругвайн песо',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Узбекийн сом',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'венесуэлийн боливар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Венесуэлийн боливар',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Вьетнамын донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Вануатугийн вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Самоагийн тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Төв Африкийн франк',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Зүүн Карибийн доллар',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Баруун Африкийн франк',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Францын колонийн франк',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Йемений риял',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Өмнөд Африкийн ранд',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Замби квача (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Замбийн квача',
        ],
    ],
];
