<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abház',
        'ace' => 'achinéz',
        'ach' => 'akoli',
        'ada' => 'adangme',
        'ady' => 'adyghe',
        'ae' => 'avesztán',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'agem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'akkád',
        'ale' => 'aleut',
        'alt' => 'dél-altaji',
        'am' => 'amhara',
        'an' => 'aragonéz',
        'ang' => 'óangol',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arab',
        'arc' => 'arámi',
        'arn' => 'mapucse',
        'arp' => 'arapaho',
        'ars' => 'nedzsdi arab',
        'arw' => 'aravak',
        'as' => 'asszámi',
        'asa' => 'asu',
        'ast' => 'asztúr',
        'atj' => 'attikamek',
        'av' => 'avar',
        'awa' => 'awádi',
        'ay' => 'ajmara',
        'az' => 'azerbajdzsáni',
        'ba' => 'baskír',
        'bal' => 'balucsi',
        'ban' => 'balinéz',
        'bas' => 'basza',
        'bax' => 'bamun',
        'bbj' => 'gomala',
        'be' => 'belarusz',
        'bej' => 'bedzsa',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bg' => 'bolgár',
        'bgn' => 'nyugati beludzs',
        'bho' => 'bodzspuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bangla',
        'bo' => 'tibeti',
        'br' => 'breton',
        'bra' => 'braj',
        'brx' => 'bodo',
        'bs' => 'bosnyák',
        'bss' => 'koszi',
        'bua' => 'burját',
        'bug' => 'buginéz',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumba',
        'ca' => 'katalán',
        'cad' => 'caddo',
        'car' => 'karib',
        'cay' => 'kajuga',
        'cch' => 'atszam',
        'ccp' => 'csakma',
        'ce' => 'csecsen',
        'ceb' => 'szebuano',
        'cgg' => 'kiga',
        'ch' => 'csamoró',
        'chb' => 'csibcsa',
        'chg' => 'csagatáj',
        'chk' => 'csukéz',
        'chm' => 'mari',
        'chn' => 'csinuk zsargon',
        'cho' => 'csoktó',
        'chp' => 'csipevé',
        'chr' => 'cseroki',
        'chy' => 'csejen',
        'ckb' => 'közép-ázsiai kurd',
        'clc' => 'csilkotin',
        'co' => 'korzikai',
        'cop' => 'kopt',
        'cr' => 'krí',
        'crg' => 'micsif',
        'crh' => 'krími tatár',
        'crj' => 'délkeleti krí',
        'crk' => 'síksági krí',
        'crl' => 'északkeleti krí',
        'crm' => 'moose krí',
        'crr' => 'karolinai algonkin',
        'crs' => 'szeszelva kreol francia',
        'cs' => 'cseh',
        'csb' => 'kasub',
        'csw' => 'mocsári krí',
        'cu' => 'egyházi szláv',
        'cv' => 'csuvas',
        'cy' => 'walesi',
        'da' => 'dán',
        'dak' => 'dakota',
        'dar' => 'dargva',
        'dav' => 'taita',
        'de' => 'német',
        'del' => 'delavár',
        'den' => 'szlevi',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'alsó-szorb',
        'dua' => 'duala',
        'dum' => 'közép holland',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dyu' => 'diula',
        'dz' => 'dzsonga',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'eve',
        'efi' => 'efik',
        'egy' => 'óegyiptomi',
        'eka' => 'ekadzsuk',
        'el' => 'görög',
        'elx' => 'elamit',
        'en' => 'angol',
        'enm' => 'közép angol',
        'eo' => 'eszperantó',
        'es' => 'spanyol',
        'et' => 'észt',
        'eu' => 'baszk',
        'ewo' => 'evondo',
        'fa' => 'perzsa',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulani',
        'fi' => 'finn',
        'fil' => 'filippínó',
        'fj' => 'fidzsi',
        'fo' => 'feröeri',
        'fon' => 'fon',
        'fr' => 'francia',
        'frc' => 'cajun francia',
        'frm' => 'közép francia',
        'fro' => 'ófrancia',
        'frr' => 'északi fríz',
        'frs' => 'keleti fríz',
        'fur' => 'friuli',
        'fy' => 'nyugati fríz',
        'ga' => 'ír',
        'gaa' => 'ga',
        'gag' => 'gagauz',
        'gan' => 'gan kínai',
        'gay' => 'gajo',
        'gba' => 'gbaja',
        'gd' => 'skóciai kelta',
        'gez' => 'geez',
        'gil' => 'ikiribati',
        'gl' => 'gallego',
        'gmh' => 'közép felső német',
        'gn' => 'guarani',
        'goh' => 'ófelső német',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gót',
        'grb' => 'grebó',
        'grc' => 'ógörög',
        'gsw' => 'svájci német',
        'gu' => 'gudzsaráti',
        'guz' => 'guszii',
        'gv' => 'man-szigeti',
        'gwi' => 'gvicsin',
        'ha' => 'hausza',
        'hai' => 'haida',
        'hak' => 'hakka kínai',
        'haw' => 'hawaii',
        'hax' => 'déli haida',
        'he' => 'héber',
        'hi' => 'hindi',
        'hil' => 'ilokano',
        'hit' => 'hettita',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'horvát',
        'hsb' => 'felső-szorb',
        'hsn' => 'xiang kínai',
        'ht' => 'haiti kreol',
        'hu' => 'magyar',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'örmény',
        'hz' => 'herero',
        'ia' => 'interlingva',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonéz',
        'ie' => 'interlingue',
        'ig' => 'igbó',
        'ii' => 'szecsuán ji',
        'ik' => 'inupiak',
        'ikt' => 'nyugat-kanadai inuit',
        'ilo' => 'ilokó',
        'inh' => 'ingus',
        'io' => 'idó',
        'is' => 'izlandi',
        'it' => 'olasz',
        'iu' => 'inuktitut',
        'ja' => 'japán',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'zsidó-perzsa',
        'jrb' => 'zsidó-arab',
        'jv' => 'jávai',
        'ka' => 'grúz',
        'kaa' => 'kara-kalpak',
        'kab' => 'kabije',
        'kac' => 'kacsin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardi',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kabuverdianu',
        'kfo' => 'koro',
        'kg' => 'kongo',
        'kgp' => 'kaingang',
        'kha' => 'kaszi',
        'kho' => 'kotanéz',
        'khq' => 'kojra-csíni',
        'ki' => 'kikuju',
        'kj' => 'kuanyama',
        'kk' => 'kazah',
        'kkj' => 'kakó',
        'kl' => 'grönlandi',
        'kln' => 'kalendzsin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreai',
        'koi' => 'komi-permják',
        'kok' => 'konkani',
        'kos' => 'kosrei',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karacsáj-balkár',
        'krl' => 'karelai',
        'kru' => 'kuruh',
        'ks' => 'kasmíri',
        'ksb' => 'sambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'kurd',
        'kum' => 'kumük',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'korni',
        'kwk' => 'kwakʼwala',
        'ky' => 'kirgiz',
        'la' => 'latin',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxemburgi',
        'lez' => 'lezg',
        'lg' => 'ganda',
        'li' => 'limburgi',
        'lij' => 'ligur',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'lao',
        'lol' => 'mongó',
        'lou' => 'louisianai kreol',
        'loz' => 'lozi',
        'lrc' => 'északi luri',
        'lsm' => 'samia',
        'lt' => 'litván',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'lushai',
        'luy' => 'lujia',
        'lv' => 'lett',
        'mad' => 'madurai',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makaszar',
        'man' => 'mandingó',
        'mas' => 'masai',
        'mde' => 'maba',
        'mdf' => 'moksán',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'mauritiusi kreol',
        'mg' => 'malgas',
        'mga' => 'közép ír',
        'mgh' => 'makua-metó',
        'mgo' => 'meta’',
        'mh' => 'marshalli',
        'mi' => 'maori',
        'mic' => 'mikmak',
        'min' => 'minangkabau',
        'mk' => 'macedón',
        'ml' => 'malajálam',
        'mn' => 'mongol',
        'mnc' => 'mandzsu',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'moszi',
        'mr' => 'maráthi',
        'ms' => 'maláj',
        'mt' => 'máltai',
        'mua' => 'mundang',
        'mus' => 'krík',
        'mwl' => 'mirandéz',
        'mwr' => 'márvári',
        'my' => 'burmai',
        'mye' => 'myene',
        'myv' => 'erzjány',
        'mzn' => 'mázanderáni',
        'na' => 'naurui',
        'nan' => 'min nan kínai',
        'nap' => 'nápolyi',
        'naq' => 'nama',
        'nb' => 'norvég (bokmål)',
        'nd' => 'északi ndebele',
        'nds' => 'alsónémet',
        'ne' => 'nepáli',
        'new' => 'nevari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niuei',
        'nl' => 'holland',
        'nmg' => 'ngumba',
        'nn' => 'norvég (nynorsk)',
        'nnh' => 'ngiemboon',
        'no' => 'norvég',
        'nog' => 'nogaj',
        'non' => 'óskandináv',
        'nqo' => 'n’kó',
        'nr' => 'déli ndebele',
        'nso' => 'északi szeszotó',
        'nus' => 'nuer',
        'nv' => 'navahó',
        'nwc' => 'klasszikus newari',
        'ny' => 'nyandzsa',
        'nym' => 'nyamvézi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoró',
        'nzi' => 'nzima',
        'oc' => 'okszitán',
        'oj' => 'ojibva',
        'ojb' => 'északnyugati odzsibva',
        'ojc' => 'középvidéki odzsibva',
        'ojs' => 'odzsi-krí',
        'ojw' => 'nyugati odzsibva',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'odia',
        'os' => 'oszét',
        'osa' => 'osage',
        'ota' => 'ottomán török',
        'pa' => 'pandzsábi',
        'pag' => 'pangaszinan',
        'pal' => 'pahlavi',
        'pam' => 'pampangan',
        'pap' => 'papiamento',
        'pau' => 'palaui',
        'pcm' => 'nigériai pidgin',
        'peo' => 'óperzsa',
        'phn' => 'főniciai',
        'pi' => 'pali',
        'pis' => 'pidzsin',
        'pl' => 'lengyel',
        'pon' => 'pohnpei',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'porosz',
        'pro' => 'óprovánszi',
        'ps' => 'pastu',
        'pt' => 'portugál',
        'qu' => 'kecsua',
        'quc' => 'kicse',
        'raj' => 'radzsasztáni',
        'rap' => 'rapanui',
        'rar' => 'rarotongai',
        'rhg' => 'rohingja',
        'rm' => 'rétoromán',
        'rn' => 'kirundi',
        'ro' => 'román',
        'rof' => 'rombo',
        'rom' => 'roma',
        'ru' => 'orosz',
        'rup' => 'aromán',
        'rw' => 'kinyarvanda',
        'rwk' => 'rwo',
        'sa' => 'szanszkrit',
        'sad' => 'szandave',
        'sah' => 'szaha',
        'sam' => 'szamaritánus arámi',
        'saq' => 'szamburu',
        'sas' => 'sasak',
        'sat' => 'szantáli',
        'sba' => 'ngambay',
        'sbp' => 'szangu',
        'sc' => 'szardíniai',
        'scn' => 'szicíliai',
        'sco' => 'skót',
        'sd' => 'szindhi',
        'sdh' => 'dél-kurd',
        'se' => 'északi számi',
        'see' => 'szeneka',
        'seh' => 'szena',
        'sel' => 'szölkup',
        'ses' => 'kojra-szenni',
        'sg' => 'szangó',
        'sga' => 'óír',
        'sh' => 'szerbhorvát',
        'shi' => 'tachelhit',
        'shn' => 'san',
        'shu' => 'csádi arab',
        'si' => 'szingaléz',
        'sid' => 'szidamó',
        'sk' => 'szlovák',
        'sl' => 'szlovén',
        'slh' => 'déli lushootseed',
        'sm' => 'szamoai',
        'sma' => 'déli számi',
        'smj' => 'lulei számi',
        'smn' => 'inari számi',
        'sms' => 'kolta számi',
        'sn' => 'sona',
        'snk' => 'szoninke',
        'so' => 'szomáli',
        'sog' => 'sogdien',
        'sq' => 'albán',
        'sr' => 'szerb',
        'srn' => 'szranai tongó',
        'srr' => 'szerer',
        'ss' => 'sziszuati',
        'ssy' => 'szahó',
        'st' => 'déli szeszotó',
        'str' => 'szorosmenti salish',
        'su' => 'szundanéz',
        'suk' => 'szukuma',
        'sus' => 'szuszu',
        'sux' => 'sumér',
        'sv' => 'svéd',
        'sw' => 'szuahéli',
        'swb' => 'comorei',
        'syc' => 'klasszikus szír',
        'syr' => 'szír',
        'ta' => 'tamil',
        'tce' => 'déli tutchone',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teszó',
        'ter' => 'terenó',
        'tet' => 'tetum',
        'tg' => 'tadzsik',
        'tgx' => 'tagish',
        'th' => 'thai',
        'tht' => 'tahltan',
        'ti' => 'tigrinya',
        'tig' => 'tigré',
        'tiv' => 'tiv',
        'tk' => 'türkmén',
        'tkl' => 'tokelaui',
        'tl' => 'tagalog',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tmh' => 'tamasek',
        'tn' => 'szecsuáni',
        'to' => 'tongai',
        'tog' => 'nyugati nyasza',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'török',
        'trv' => 'tarokó',
        'ts' => 'conga',
        'tsi' => 'csimsiáni',
        'tt' => 'tatár',
        'ttm' => 'északi tutchone',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'szavák',
        'ty' => 'tahiti',
        'tyv' => 'tuvai',
        'tzm' => 'közép-atlaszi tamazigt',
        'udm' => 'udmurt',
        'ug' => 'ujgur',
        'uga' => 'ugariti',
        'uk' => 'ukrán',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'üzbég',
        'vai' => 'vai',
        've' => 'venda',
        'vi' => 'vietnámi',
        'vo' => 'volapük',
        'vot' => 'votják',
        'vun' => 'vunjo',
        'wa' => 'vallon',
        'wae' => 'walser',
        'wal' => 'valamo',
        'war' => 'varaó',
        'was' => 'vasó',
        'wbp' => 'warlpiri',
        'wo' => 'volof',
        'wuu' => 'wu kínai',
        'xal' => 'kalmük',
        'xh' => 'xhosza',
        'xog' => 'szoga',
        'yao' => 'jaó',
        'yap' => 'japi',
        'yav' => 'jangben',
        'ybb' => 'jemba',
        'yi' => 'jiddis',
        'yo' => 'joruba',
        'yrl' => 'nheengatu',
        'yue' => 'kantoni',
        'za' => 'zsuang',
        'zap' => 'zapoték',
        'zbl' => 'Bliss jelképrendszer',
        'zen' => 'zenaga',
        'zgh' => 'marokkói tamazight',
        'zh' => 'kínai',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'modern szabványos arab',
        'de_AT' => 'osztrák német',
        'de_CH' => 'svájci felnémet',
        'en_AU' => 'ausztrál angol',
        'en_CA' => 'kanadai angol',
        'en_GB' => 'brit angol',
        'en_US' => 'amerikai angol',
        'es_419' => 'latin-amerikai spanyol',
        'es_ES' => 'európai spanyol',
        'es_MX' => 'spanyol (mexikói)',
        'fa_AF' => 'dari',
        'fr_CA' => 'kanadai francia',
        'fr_CH' => 'svájci francia',
        'nds_NL' => 'alsószász',
        'nl_BE' => 'flamand',
        'pt_BR' => 'brazíliai portugál',
        'pt_PT' => 'európai portugál',
        'ro_MD' => 'moldvai',
        'sw_CD' => 'kongói szuahéli',
        'zh_Hans' => 'egyszerűsített kínai',
        'zh_Hant' => 'hagyományos kínai',
    ],
];
