<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Peseta Andóra',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Dirham Aontas na nÉimíríochtaí Arabacha',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afgainí (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghani na hAfganastáine',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Lek na hAlbáine (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lek na hAlbáine',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dram na hAirméine',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Gildear Aintillí na hÍsiltíre',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza Angóla',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Kwanza Angólach (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Kwanza Nua Angólach (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Kwanza Reajustado Angólach (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Austral Airgintíneach',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'ARL',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Peso na hAirgintíne (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Peso na hAirgintíne (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Peso na hAirgintíne',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Scilling na hOstaire',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dollar na hAstráile',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Flóirín Arúba',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Manat na hAsarbaiseáine (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manat na hAsarbaiseáine',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Dínear Bhoisnia-Heirseagaivéin (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Marg Inmhalartaithe na Boisnia-Heirseagaivéine',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'BAN',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dollar Bharbadós',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka na Banglaidéise',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Franc na Beilge (inmhalartaithe)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Franc Beilgeach',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Franc na Beilge (airgeadais)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Lev Crua na Bulgáire',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Lev na Bulgáire',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Lev na Bulgáire (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinar Bhairéin',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Franc na Burúine',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dollar Bheirmiúda',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dollar Bhrúiné',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'BOL',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Peso na Bolaive',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Mvdol na Bolaive',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Cruzeiro Nua na Brasaíle (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Cruzado na Brasaíle (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Cruzeiro na Brasaíle (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Real na Brasaíle',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Cruzado Nua na Brasaíle (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Cruzeiro na Brasaíle (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Cruzeiro na Brasaíle (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dollar na mBahámaí',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrum na Bútáine',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Kyat Bhurma',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula na Botsuáine',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Rúbal Nua na Bealarúise (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rúbal na Bealarúise',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Rúbal na Bealarúise (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dollar na Beilíse',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dollar Cheanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Franc an Chongó',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Franc na hEilvéise',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Escudo na Sile',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Unidades de Fomento na Sile',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Peso na Sile',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuan na Síne (seachairgeadra)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan na Síne',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Peso na Colóime',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'COU',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Colón Chósta Ríce',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Dinar na Seirbia (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Koruna Crua na Seicslóvaice',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Peso Inmhalartaithe Chúba',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Peso Chúba',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo Rinn Verde',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Punt na Cipire',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna Phoblacht na Seice',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Marc Ghearmáin an Oirthir',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Deutsche Mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Franc Djibouti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Coróin na Danmhairge',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Peso na Poblachta Doiminicí',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinar na hAilgéire',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Sucre Eacuadóir',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Unidad de Valor Constante (UVC) Eacuadóir',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Kroon na hEastóine',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Punt na hÉigipte',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa na hEiritré',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'ESA',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'ESB',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Peseta na Spáinne',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birr na hAetóipe',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Markka Fionnlannach',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dollar Fhidsí',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Punt Oileáin Fháclainne',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franc na Fraince',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Punt Steirling',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Kupon Larit na Grúise',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lari na Seoirsia',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Cedi Ghána (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Cedi Ghána',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Punt Ghiobráltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi na Gaimbia',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Franc na Guine',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Syli Guine',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ekwele Guineana na Guine Meánchiorclaí',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Drachma Gréagach',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Quetzal Ghuatamala',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Escudo na Guine Portaingéalaí',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Peso Guine-Bhissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dollar na Guáine',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dollar Hong Cong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira Hondúras',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Dínear na Cróite',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna na Cróite',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gourde Háítí',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Forint na hUngáire',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupiah na hIndinéise',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Punt Éireannach',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Punt Iosraelach',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Seiceal Nua Iosrael',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rúipí na hIndia',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinar na hIaráice',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Rial na hIaráine',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Króna na hÍoslainne',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Lira na hIodáile',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dollar na hIamáice',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinar na hIordáine',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Yen na Seapáine',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Scilling na Céinia',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Som na Cirgeastáine',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riel na Cambóide',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Franc Oileáin Chomóra',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Won na Cóiré Thuaidh',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'KRH',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'KRO',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Won na Cóiré Theas',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinar Chuáit',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dollar Oileáin Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge na Casacstáine',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kip Laos',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Punt na Liobáine',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rúipí Shrí Lanca',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dollar na Libéire',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti Leosóta',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litas na Liotuáine',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Talonas Liotuánach',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Franc Inmhalartach Lucsamburgach',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Franc Lucsamburg',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lats na Laitvia',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Rúbal na Laitvia',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinar na Libia',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham Mharacó',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Franc Mharacó',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leu na Moldóive',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariary Mhadagascar',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Franc Madagascar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Denar na Macadóine',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'MKN',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Franc Mhailí',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kyat Mhaenmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrik na Mongóile',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataca Mhacao',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya na Máratáine (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya na Máratáine',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Lira Mhálta',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Punt Mhálta',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rúipí Oileán Mhuirís',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'Rúipí Oileáin Mhaildíve',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiyaa Oileáin Mhaildíve',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha na Maláive',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Peso Mheicsiceo',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Peso Airgid Mheicsiceo (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Aonad Infheistíochta Meicsiceach',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringgit na Malaeisia',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Escudo Mósaimbíce',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metical Mósaimbíce',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metical Mhósaimbíc',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dollar na Namaibe',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira na Nigéire',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Córdoba Nicearagua (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Córdoba Nicearagua',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Guilder Ísiltíreach',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Coróin na hIorua',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rúipí Neipeal',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dollar na Nua-Shéalainne',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Rial Óman',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa Phanama',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Inti Pheiriú',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Sol Pheiriú',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Sol Pheiriú (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina Nua-Ghuine Phapua',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'Peso na nOileán Filipíneach',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rúipí na Pacastáine',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Zloty na Polainne',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Zloty Polannach (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Escudo na Portaingéile',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guaraní Pharagua',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Riyal Chatar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Leu na Rómáine (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Leu na Rómáine',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinar na Seirbia',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rúbal na Rúise',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rúbal na Rúise (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Franc Ruanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal na hAraibe Sádaí',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dollar Oileáin Sholomón',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rúipí na Séiséal',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Dinar na Súdáine (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Punt na Súdáine',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Punt na Súdáine (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Coróin na Sualainne',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dollar Shingeapór',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Punt San Héilin',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Tolar na Slóivéine',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Koruna na Slóvaice',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone Shiarra Leon',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Scilling na Somáile',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dollar Shuranam',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Gildear Shuranam',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Punt na Súdáine Theas',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra São Tomé agus Príncipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra São Tomé agus Príncipe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Rúbal an Aontais Shóivéadaigh',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Colón na Salvadóire',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Punt na Siria',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni na Suasalainne',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Baht na Téalainne',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Rúbal na Táidsíceastáine',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni na Táidsíceastáine',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Manat na Tuircméanastáine (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manat na Tuircméanastáine',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinar na Túinéise',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Paʻanga Thonga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Escudo Tíomóir',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Lira na Tuirce (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lira na Tuirce',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dollar Oileán na Tríonóide agus Tobága',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dollar Nua na Téaváine',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Scilling na Tansáine',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Hryvnia na hÚcráine',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Karbovanets Úcránach',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Scilling Uganda (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Scilling Uganda',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dollar S.A.M.',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Dollar S.A.M. (an chéad lá eile)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Dollar S.A.M. (an lá céanna)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Peso Uragua (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso Uragua',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Sum na hÚisbéiceastáine',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Bolívar Veiniséala (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolívar Veiniséala (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolívar Veiniséala',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dong Vítneam',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Dong Vítneam (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatu Vanuatú',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala Shamó',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Franc CFA na hAfraice Láir',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dollar na Cairibe Thoir',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Aonad Airgeadra Eorpach',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franc Ór Francach',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'UIC-Franc Francach',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Franc CFA Iarthar na hAfraice',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Franc CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'XRE',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Dínear Éimin',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Rial Éimin',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Dínear Crua Iúgslavach (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Dínear Nua Iúgslavach (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Dinar Inmhalartaithe Iúgslavach (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'YUR',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Rand na hAfraice Theas (airgeadúil)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rand na hAfraice Theas',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha Saimbiach (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha na Saimbia',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zaire Nua Sáíreach',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zaire Sáíreach',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dollar Siombábach (1980–2008)',
        ],
    ],
];
