<?php

return [
    'Names' => [
        'Gujr' => 'gujarati',
        'Hrkt' => 'katakana o hiragana',
        'Laoo' => 'lao',
        'Latn' => 'latín',
        'Mlym' => 'malabar',
        'Mtei' => 'manipuri',
        'Syrc' => 'siríaco',
    ],
];
