<?php

return [
    'Names' => [
        'CG' => 'Конго',
        'CV' => 'Кабо Верде',
        'CZ' => 'Чешка Република',
        'HK' => 'САР Хонгконг',
        'KN' => 'Свети Китс и Невис',
        'MO' => 'САР Макао',
        'PM' => 'Свети Пјер и Микелон',
        'RE' => 'Реунион',
        'UM' => 'Мања удаљена острва САД',
        'VC' => 'Свети Винсент и Гренадини',
    ],
];
