<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Wakhtiga Giriinwij (Abidjaan)',
        'Africa/Accra' => 'Wakhtiga Giriinwij (Akra)',
        'Africa/Addis_Ababa' => 'Waqtiga Bariga Afrika (Addis Ababa)',
        'Africa/Algiers' => 'Waqtiga Bartamaha Yurub (Aljeeris)',
        'Africa/Asmera' => 'Waqtiga Bariga Afrika (Asmara)',
        'Africa/Bamako' => 'Wakhtiga Giriinwij (Bamaako)',
        'Africa/Bangui' => 'Waqtiga Galbeedka Afrika (Baagi)',
        'Africa/Banjul' => 'Wakhtiga Giriinwij (Banjul)',
        'Africa/Bissau' => 'Wakhtiga Giriinwij (Bisaaw)',
        'Africa/Blantyre' => 'Waqtiga Bartamaha Afrika (Balantire)',
        'Africa/Brazzaville' => 'Waqtiga Galbeedka Afrika (Barasafil)',
        'Africa/Bujumbura' => 'Waqtiga Bartamaha Afrika (Bujumbura)',
        'Africa/Cairo' => 'Waqtiga Bariga Yurub (Qaahira)',
        'Africa/Casablanca' => 'Waqtiga Galbeedka Yurub (Kasabalaanka)',
        'Africa/Ceuta' => 'Waqtiga Bartamaha Yurub (Seuta)',
        'Africa/Conakry' => 'Wakhtiga Giriinwij (Conakri)',
        'Africa/Dakar' => 'Wakhtiga Giriinwij (Dakar)',
        'Africa/Dar_es_Salaam' => 'Waqtiga Bariga Afrika (Daresalaam)',
        'Africa/Djibouti' => 'Waqtiga Bariga Afrika (Jibuuti)',
        'Africa/Douala' => 'Waqtiga Galbeedka Afrika (Douaala)',
        'Africa/El_Aaiun' => 'Waqtiga Galbeedka Yurub (El Ceyuun)',
        'Africa/Freetown' => 'Wakhtiga Giriinwij (Firiitawn)',
        'Africa/Gaborone' => 'Waqtiga Bartamaha Afrika (Gabroon)',
        'Africa/Harare' => 'Waqtiga Bartamaha Afrika (Haraare)',
        'Africa/Johannesburg' => 'Waqtiyada Caadiga Ah ee Koonfur Afrika (Johansbaag)',
        'Africa/Juba' => 'Waqtiga Bartamaha Afrika (Juba)',
        'Africa/Kampala' => 'Waqtiga Bariga Afrika (Kambaala)',
        'Africa/Khartoum' => 'Waqtiga Bartamaha Afrika (Khartuum)',
        'Africa/Kigali' => 'Waqtiga Bartamaha Afrika (Kigali)',
        'Africa/Kinshasa' => 'Waqtiga Galbeedka Afrika (Kinshasa)',
        'Africa/Lagos' => 'Waqtiga Galbeedka Afrika (Laagoos)',
        'Africa/Libreville' => 'Waqtiga Galbeedka Afrika (Librefil)',
        'Africa/Lome' => 'Wakhtiga Giriinwij (Loom)',
        'Africa/Luanda' => 'Waqtiga Galbeedka Afrika (Luwaanda)',
        'Africa/Lubumbashi' => 'Waqtiga Bartamaha Afrika (Lubumbaashi)',
        'Africa/Lusaka' => 'Waqtiga Bartamaha Afrika (Lusaaka)',
        'Africa/Malabo' => 'Waqtiga Galbeedka Afrika (Malabo)',
        'Africa/Maputo' => 'Waqtiga Bartamaha Afrika (Mabuuto)',
        'Africa/Maseru' => 'Waqtiyada Caadiga Ah ee Koonfur Afrika (Maseero)',
        'Africa/Mbabane' => 'Waqtiyada Caadiga Ah ee Koonfur Afrika (Mababaane)',
        'Africa/Mogadishu' => 'Waqtiga Bariga Afrika (Muqdisho)',
        'Africa/Monrovia' => 'Wakhtiga Giriinwij (Monrofiya)',
        'Africa/Nairobi' => 'Waqtiga Bariga Afrika (Nayroobi)',
        'Africa/Ndjamena' => 'Waqtiga Galbeedka Afrika (Injamina)',
        'Africa/Niamey' => 'Waqtiga Galbeedka Afrika (Nijame)',
        'Africa/Nouakchott' => 'Wakhtiga Giriinwij (Nookjot)',
        'Africa/Ouagadougou' => 'Wakhtiga Giriinwij (Wagadugu)',
        'Africa/Porto-Novo' => 'Waqtiga Galbeedka Afrika (Boorto-Noofo)',
        'Africa/Sao_Tome' => 'Wakhtiga Giriinwij (Saw Toom)',
        'Africa/Tripoli' => 'Waqtiga Bariga Yurub (Tiribooli)',
        'Africa/Tunis' => 'Waqtiga Bartamaha Yurub (Tuunis)',
        'Africa/Windhoek' => 'Waqtiga Bartamaha Afrika (Windhook)',
        'America/Adak' => 'Waqtiga Hawaay-Alutiyaan (Adak)',
        'America/Anchorage' => 'Waqtiga Alaska (Anjorage)',
        'America/Anguilla' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Anguwila)',
        'America/Antigua' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Antiguwa)',
        'America/Araguaina' => 'Waqtiga Baraasiliya (Araguwayna)',
        'America/Argentina/La_Rioja' => 'Waqtia Arjentiina (La Riyoja)',
        'America/Argentina/Rio_Gallegos' => 'Waqtia Arjentiina (Riyo Jalejos)',
        'America/Argentina/Salta' => 'Waqtia Arjentiina (Salta)',
        'America/Argentina/San_Juan' => 'Waqtia Arjentiina (San Juwaan)',
        'America/Argentina/San_Luis' => 'Waqtia Arjentiina (San Luwis)',
        'America/Argentina/Tucuman' => 'Waqtia Arjentiina (Tukuumaan)',
        'America/Argentina/Ushuaia' => 'Waqtia Arjentiina (Ushuaay)',
        'America/Aruba' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Aruba)',
        'America/Asuncion' => 'Waqtiga Baragwaay (Asunkiyon)',
        'America/Bahia' => 'Waqtiga Baraasiliya (Baahiya)',
        'America/Bahia_Banderas' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Bahiya Banderas)',
        'America/Barbados' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Barbados)',
        'America/Belem' => 'Waqtiga Baraasiliya (Belem)',
        'America/Belize' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Beliise)',
        'America/Blanc-Sablon' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Balank-Sablon)',
        'America/Boa_Vista' => 'Waqtiga Amason (Bow Fista)',
        'America/Bogota' => 'Waqtiga Kolambiya (Bogota)',
        'America/Boise' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Boyse)',
        'America/Buenos_Aires' => 'Waqtia Arjentiina (Buwenos Ayris)',
        'America/Cambridge_Bay' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Kambiriij Baay)',
        'America/Campo_Grande' => 'Waqtiga Amason (Kaambo Garandi)',
        'America/Cancun' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Kaankuun)',
        'America/Caracas' => 'Waqtiga Fenezuweela (Karakaas)',
        'America/Catamarca' => 'Waqtia Arjentiina (Katamaarka)',
        'America/Cayenne' => 'Waqtiga Ferenj Guyana (Kayeen)',
        'America/Cayman' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Keymaan)',
        'America/Chicago' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Jikaago)',
        'America/Chihuahua' => 'Waqtiga Baasifikada Meksiko (Jiwaahuu)',
        'America/Coral_Harbour' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Atikokaan)',
        'America/Cordoba' => 'Waqtia Arjentiina (Kordooba)',
        'America/Costa_Rica' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Kosta Riika)',
        'America/Creston' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Karestoon)',
        'America/Cuiaba' => 'Waqtiga Amason (Kuyaaba)',
        'America/Curacao' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Kurakoow)',
        'America/Danmarkshavn' => 'Wakhtiga Giriinwij (Daanmaakshaan)',
        'America/Dawson' => 'Waqtiga Yukon (Doosan)',
        'America/Dawson_Creek' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Doosan Kireek)',
        'America/Denver' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Denfar)',
        'America/Detroit' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Detoroyt)',
        'America/Dominica' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Dominiika)',
        'America/Edmonton' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Edmonton)',
        'America/Eirunepe' => 'Wakhtiga Acre (Iiruneeb)',
        'America/El_Salvador' => 'Waqtiga Bartamaha Waqooyiga Ameerika (El Salfadoor)',
        'America/Fort_Nelson' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Foot Nelson)',
        'America/Fortaleza' => 'Waqtiga Baraasiliya (Footalesa)',
        'America/Glace_Bay' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Galeys Baay)',
        'America/Godthab' => 'Waqtiga Galbeedka Giriinlaan (Nuuk)',
        'America/Goose_Bay' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Guus Baay)',
        'America/Grand_Turk' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Garaan Turk)',
        'America/Grenada' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Garenaada)',
        'America/Guadeloupe' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Guwadeluub)',
        'America/Guatemala' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Guwatemaala)',
        'America/Guayaquil' => 'Waqtiga Ekuwadoor (Guwayaquwil)',
        'America/Guyana' => 'Waqtiga Guyaana',
        'America/Halifax' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Halifakas)',
        'America/Havana' => 'Waqtiga Kuuba (Hafaana)',
        'America/Hermosillo' => 'Waqtiga Baasifikada Meksiko (Harmosilo)',
        'America/Indiana/Knox' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Nokis, Indiyaana)',
        'America/Indiana/Marengo' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Mareengo, Indiyaana)',
        'America/Indiana/Petersburg' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Betesbaag, Indiyaana)',
        'America/Indiana/Tell_City' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Tel Siti, Indiyaana)',
        'America/Indiana/Vevay' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Feefaay, Indiyaana)',
        'America/Indiana/Vincennes' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Finseenes, Indiyaana)',
        'America/Indiana/Winamac' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Winaamak, Indiyaana)',
        'America/Indianapolis' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Indiyaanabolis)',
        'America/Inuvik' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Inuufik)',
        'America/Iqaluit' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Iqaaluut)',
        'America/Jamaica' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Jamayka)',
        'America/Jujuy' => 'Waqtia Arjentiina (Jujuy)',
        'America/Juneau' => 'Waqtiga Alaska (Juniyuu)',
        'America/Kentucky/Monticello' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Montiseelo, Kentaki)',
        'America/Kralendijk' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Kiraalendik)',
        'America/La_Paz' => 'Waqtiga Boliifiya (Laa Baas)',
        'America/Lima' => 'Waqtiga Beeru (Liima)',
        'America/Los_Angeles' => 'Waqtiga Basifika ee Waqooyiga Ameerika (Loos Anjalis)',
        'America/Louisville' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Luusfile)',
        'America/Lower_Princes' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Loowa Birinses Kuwaata)',
        'America/Maceio' => 'Waqtiga Baraasiliya (Maasiiyo)',
        'America/Managua' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Manaaguwa)',
        'America/Manaus' => 'Waqtiga Amason (Manaauus)',
        'America/Marigot' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Maarigot)',
        'America/Martinique' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Maartiniikuyuu)',
        'America/Matamoros' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Matamoros)',
        'America/Mazatlan' => 'Waqtiga Baasifikada Meksiko (Mazaatlan)',
        'America/Mendoza' => 'Waqtia Arjentiina (Meendoosa)',
        'America/Menominee' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Menoominee)',
        'America/Merida' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Meriida)',
        'America/Metlakatla' => 'Waqtiga Alaska (Metlaakatla)',
        'America/Mexico_City' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Meksiko Siti)',
        'America/Miquelon' => 'Waqtiga St. Beere & Mikiwelon (Miiquulon)',
        'America/Moncton' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Moonktoon)',
        'America/Monterrey' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Moonteerey)',
        'America/Montevideo' => 'Waqtiga Urugwaay (Moontafiidiyo)',
        'America/Montreal' => 'Waqtiga Kanada (Montreal)',
        'America/Montserrat' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Moontseraat)',
        'America/Nassau' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Nasaaw)',
        'America/New_York' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Niyuu Yook)',
        'America/Nipigon' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Nibiigoon)',
        'America/Nome' => 'Waqtiga Alaska (Noom)',
        'America/Noronha' => 'Waqtiga Farnaando de Noronha (Noroonha)',
        'America/North_Dakota/Beulah' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Biyuulah, Waqooyiga Dakoota)',
        'America/North_Dakota/Center' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Bartamaha, Waqooyiga Dakoota)',
        'America/North_Dakota/New_Salem' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Niyuu Saalem, Waqooyiga Dakoota)',
        'America/Ojinaga' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Ojinaaga)',
        'America/Panama' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Banaama)',
        'America/Pangnirtung' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Bangnirtuung)',
        'America/Paramaribo' => 'Waqtiga Surineym (Baramaribo)',
        'America/Phoenix' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Foonikis)',
        'America/Port-au-Prince' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Boort-aw-Biriins)',
        'America/Port_of_Spain' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Boort of Isbayn)',
        'America/Porto_Velho' => 'Waqtiga Amason (Boorto Felho)',
        'America/Puerto_Rico' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Boorta Riiko)',
        'America/Punta_Arenas' => 'Waqtiga Jili (Bunta Arinaas)',
        'America/Rainy_River' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Reyni Rifer)',
        'America/Rankin_Inlet' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Raankin Inleet)',
        'America/Recife' => 'Waqtiga Baraasiliya (Receyf)',
        'America/Regina' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Rejiina)',
        'America/Resolute' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Resoluut)',
        'America/Rio_Branco' => 'Wakhtiga Acre (Riyo Baraanko)',
        'America/Santa_Isabel' => 'Waqtiga Waqooyi-Galbeed Meksiko (Santa Isabel)',
        'America/Santarem' => 'Waqtiga Baraasiliya (Santareem)',
        'America/Santiago' => 'Waqtiga Jili (Santiyaago)',
        'America/Santo_Domingo' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Saanto Domingo)',
        'America/Sao_Paulo' => 'Waqtiga Baraasiliya (Saaw Boolo)',
        'America/Scoresbysund' => 'Waqtiga Bariga ee Giriinlaan (Itoqortoomiit)',
        'America/Sitka' => 'Waqtiga Alaska (Siitka)',
        'America/St_Barthelemy' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (St. Baartelemi)',
        'America/St_Johns' => 'Waqtiga Niyuufoonlaan (St. Joon)',
        'America/St_Kitts' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (St. Kitis)',
        'America/St_Lucia' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (St. Lusiya)',
        'America/St_Thomas' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (St. Toomas)',
        'America/St_Vincent' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (St. Finsent)',
        'America/Swift_Current' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Iswift Karent)',
        'America/Tegucigalpa' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Tegusigalba)',
        'America/Thule' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Tuul)',
        'America/Thunder_Bay' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Tanda Baay)',
        'America/Tijuana' => 'Waqtiga Basifika ee Waqooyiga Ameerika (Tijuwaana)',
        'America/Toronto' => 'Waqtiga Bariga ee Waqooyiga Ameerika (Toronto)',
        'America/Tortola' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Tortoola)',
        'America/Vancouver' => 'Waqtiga Basifika ee Waqooyiga Ameerika (Fankuufar)',
        'America/Whitehorse' => 'Waqtiga Yukon (Waythoras)',
        'America/Winnipeg' => 'Waqtiga Bartamaha Waqooyiga Ameerika (Winibeg)',
        'America/Yakutat' => 'Waqtiga Alaska (Yakutaat)',
        'America/Yellowknife' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika (Yelowneyf)',
        'Antarctica/Casey' => 'Waqtiga Antaarktika (Kaysee)',
        'Antarctica/Davis' => 'Waqtiga Dafis',
        'Antarctica/DumontDUrville' => 'Waqtiga Dumont - d’urfille (Dumont d’urfile)',
        'Antarctica/Macquarie' => 'Waqtiga Bariga Astaraaliya (Makquwariy)',
        'Antarctica/Mawson' => 'Waqtiga Mawson',
        'Antarctica/McMurdo' => 'Waqtiga Niyuu Si’laan (MakMurdo)',
        'Antarctica/Palmer' => 'Waqtiga Jili (Baamar)',
        'Antarctica/Rothera' => 'Waqtiga Rotera',
        'Antarctica/Syowa' => 'Waqtiga Siyowa',
        'Antarctica/Troll' => 'Wakhtiga Giriinwij (Torool)',
        'Antarctica/Vostok' => 'Waqtiga Fostok',
        'Arctic/Longyearbyen' => 'Waqtiga Bartamaha Yurub (Lonjirbyeen)',
        'Asia/Aden' => 'Waqtiga Carabta (Cadan)',
        'Asia/Almaty' => 'Waqtiga Bariga Kasakhistaan (Almati)',
        'Asia/Amman' => 'Waqtiga Bariga Yurub (Ammaan)',
        'Asia/Anadyr' => 'Wakhtiga Anadyr (Anadiyr)',
        'Asia/Aqtau' => 'Waqtiga Koonfurta Kasakhistan (Aktaw)',
        'Asia/Aqtobe' => 'Waqtiga Koonfurta Kasakhistan (Aqtobe)',
        'Asia/Ashgabat' => 'Waqtiga Turkmenistaan (Ashgabat)',
        'Asia/Atyrau' => 'Waqtiga Koonfurta Kasakhistan (Atiyraw)',
        'Asia/Baghdad' => 'Waqtiga Carabta (Baqdaad)',
        'Asia/Bahrain' => 'Waqtiga Carabta (Baxreyn)',
        'Asia/Baku' => 'Waqtiga Asarbeyjan (Baku)',
        'Asia/Bangkok' => 'Waqtiga Indoshiina (Bangkook)',
        'Asia/Barnaul' => 'Waqtiga Ruush (Barnaauul)',
        'Asia/Beirut' => 'Waqtiga Bariga Yurub (Beyruud)',
        'Asia/Bishkek' => 'Waqtiga Kiyrigistaan (Bishkek)',
        'Asia/Brunei' => 'Waqtiga Buruney Daarusalaam',
        'Asia/Calcutta' => 'Waqtiga Caadiga Ah ee Hindiya (Kolkaata)',
        'Asia/Chita' => 'Waqtiyada Yakut (Jiita)',
        'Asia/Choibalsan' => 'Waqtiga Ulaanbaataar (Joybalsan)',
        'Asia/Colombo' => 'Waqtiga Caadiga Ah ee Hindiya (Kolombo)',
        'Asia/Damascus' => 'Waqtiga Bariga Yurub (Dimishiq)',
        'Asia/Dhaka' => 'Waqtiga Bangledeesh (Dhaaka)',
        'Asia/Dili' => 'Waqtiga Iist Timoor (Dili)',
        'Asia/Dubai' => 'Waqtiga Gacanka (Dubay)',
        'Asia/Dushanbe' => 'Waqtiga Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Waqtiga Bariga Yurub (Famagusta)',
        'Asia/Gaza' => 'Waqtiga Bariga Yurub (Qasa)',
        'Asia/Hebron' => 'Waqtiga Bariga Yurub (Hebron)',
        'Asia/Hong_Kong' => 'Waqtiga Hoong Koong',
        'Asia/Hovd' => 'Waqtiga Hofud',
        'Asia/Irkutsk' => 'Waqtiga Irkutsik',
        'Asia/Jakarta' => 'Waqtiga Galbeedka Indoneeysiya (Jakaarta)',
        'Asia/Jayapura' => 'Waqtiga Indoneeysiya (Jayabura)',
        'Asia/Jerusalem' => 'Waqtiga Israaiil (Jeerusaalem)',
        'Asia/Kabul' => 'Waqtiga Afggaanistaan (Kaabuul)',
        'Asia/Kamchatka' => 'Wakhtiga Petropavlovsk-Kamchatski (Kamkatka)',
        'Asia/Karachi' => 'Waqtiga Bakistaan (Karaaji)',
        'Asia/Katmandu' => 'Waqtiga Neebaal (Katmandu)',
        'Asia/Khandyga' => 'Waqtiyada Yakut (Khandiyga)',
        'Asia/Krasnoyarsk' => 'Waqtiga Karasnoyarsik (Karasnoyarska)',
        'Asia/Kuala_Lumpur' => 'Waqtiga Maleyshiya (Kuala Lambuur)',
        'Asia/Kuching' => 'Waqtiga Maleyshiya (Kujing)',
        'Asia/Kuwait' => 'Waqtiga Carabta (Kuweyt)',
        'Asia/Macau' => 'Waqtiga Shiinaha (Makow)',
        'Asia/Magadan' => 'Watiga Magedan',
        'Asia/Makassar' => 'Waqtiga Bartamaha Indoneeysiya (Makasar)',
        'Asia/Manila' => 'Waqtiga Filibiin (Maniila)',
        'Asia/Muscat' => 'Waqtiga Gacanka (Muskat)',
        'Asia/Nicosia' => 'Waqtiga Bariga Yurub (Nikosiya)',
        'Asia/Novokuznetsk' => 'Waqtiga Karasnoyarsik (Nofokusnetsik)',
        'Asia/Novosibirsk' => 'Waqtiga Nofosibirsik',
        'Asia/Omsk' => 'Waqtiga Omsk',
        'Asia/Oral' => 'Waqtiga Koonfurta Kasakhistan (Oral)',
        'Asia/Phnom_Penh' => 'Waqtiga Indoshiina (Benom Ben)',
        'Asia/Pontianak' => 'Waqtiga Galbeedka Indoneeysiya (Botiyaanak)',
        'Asia/Pyongyang' => 'Waqtiga Kuuriya (Boyongyang)',
        'Asia/Qatar' => 'Waqtiga Carabta (Qaddar)',
        'Asia/Qostanay' => 'Waqtiga Bariga Kasakhistaan (Kostanay)',
        'Asia/Qyzylorda' => 'Waqtiga Koonfurta Kasakhistan (Qiyslorda)',
        'Asia/Rangoon' => 'Waqtiga Mayanmaar (Yangon)',
        'Asia/Riyadh' => 'Waqtiga Carabta (Riyaad)',
        'Asia/Saigon' => 'Waqtiga Indoshiina (Hoo Ji Mih Siti)',
        'Asia/Sakhalin' => 'Waqtiga Sakhalin',
        'Asia/Samarkand' => 'Waqtiga Usbekistan (Samarkaan)',
        'Asia/Seoul' => 'Waqtiga Kuuriya (Soul)',
        'Asia/Shanghai' => 'Waqtiga Shiinaha (Shanghaay)',
        'Asia/Singapore' => 'Waqtiga Singabuur',
        'Asia/Srednekolymsk' => 'Watiga Magedan (Sarednokoleymisk)',
        'Asia/Taipei' => 'Waqtiga Teybey',
        'Asia/Tashkent' => 'Waqtiga Usbekistan (Toshkeent)',
        'Asia/Tbilisi' => 'Waqtiga Joorjiya (Tibilisi)',
        'Asia/Tehran' => 'Waqtiga Iiraan (Tehraan)',
        'Asia/Thimphu' => 'Waqtiga Butaan (Timbu)',
        'Asia/Tokyo' => 'Waqtiga Jabaan (Tokyo)',
        'Asia/Tomsk' => 'Waqtiga Ruush (Tomsk)',
        'Asia/Ulaanbaatar' => 'Waqtiga Ulaanbaataar (Ulaanbaatar)',
        'Asia/Urumqi' => 'Waqtiga Shiinaha (Urumqi)',
        'Asia/Ust-Nera' => 'Waqtiga Faladifostok (Ust-Nera)',
        'Asia/Vientiane' => 'Waqtiga Indoshiina (Fiyaantiyaan)',
        'Asia/Vladivostok' => 'Waqtiga Faladifostok',
        'Asia/Yakutsk' => 'Waqtiyada Yakut',
        'Asia/Yekaterinburg' => 'Waqtiga Yekaterinbaag',
        'Asia/Yerevan' => 'Waqtiga Armeeniya (Yerefan)',
        'Atlantic/Azores' => 'Waqtiga Asores',
        'Atlantic/Bermuda' => 'Waqtiga Atlantika ee Waqooyiga Ameerika (Barmuuda)',
        'Atlantic/Canary' => 'Waqtiga Galbeedka Yurub (Kanari)',
        'Atlantic/Cape_Verde' => 'Waqtiga Keyb Faarde',
        'Atlantic/Faeroe' => 'Waqtiga Galbeedka Yurub (Farow)',
        'Atlantic/Madeira' => 'Waqtiga Galbeedka Yurub (Madira)',
        'Atlantic/Reykjavik' => 'Wakhtiga Giriinwij (Reykjafik)',
        'Atlantic/South_Georgia' => 'Waqtiga Sowt Joorjiya',
        'Atlantic/St_Helena' => 'Wakhtiga Giriinwij (St. Helena)',
        'Atlantic/Stanley' => 'Waqtiga Faalklaan Aylaanis (Istaanley)',
        'Australia/Adelaide' => 'Waqtiga Bartamaha Astaraaliya (Adelayde)',
        'Australia/Brisbane' => 'Waqtiga Bariga Astaraaliya (Birisban)',
        'Australia/Broken_Hill' => 'Waqtiga Bartamaha Astaraaliya (Boroken Hil)',
        'Australia/Currie' => 'Waqtiga Bariga Astaraaliya (Kuriy)',
        'Australia/Darwin' => 'Waqtiga Bartamaha Astaraaliya (Darwin)',
        'Australia/Eucla' => 'Waqtiga Bartamaha Galbeedka Astaraaliya (Yukla)',
        'Australia/Hobart' => 'Waqtiga Bariga Astaraaliya (Hubaart)',
        'Australia/Lindeman' => 'Waqtiga Bariga Astaraaliya (Lindeman)',
        'Australia/Lord_Howe' => 'Waqtiga Lod How',
        'Australia/Melbourne' => 'Waqtiga Bariga Astaraaliya (Melboon)',
        'Australia/Perth' => 'Waqtiga Galbeedka Astaraaliya (Bert)',
        'Australia/Sydney' => 'Waqtiga Bariga Astaraaliya (Sidney)',
        'CST6CDT' => 'Waqtiga Bartamaha Waqooyiga Ameerika',
        'EST5EDT' => 'Waqtiga Bariga ee Waqooyiga Ameerika',
        'Etc/GMT' => 'Wakhtiga Giriinwij',
        'Etc/UTC' => 'Waqtiga Isku-xiran ee Caalamka',
        'Europe/Amsterdam' => 'Waqtiga Bartamaha Yurub (Amsterdaam)',
        'Europe/Andorra' => 'Waqtiga Bartamaha Yurub (Andoora)',
        'Europe/Astrakhan' => 'Waqtiga Moskow (Astarakhaan)',
        'Europe/Athens' => 'Waqtiga Bariga Yurub (Atens)',
        'Europe/Belgrade' => 'Waqtiga Bartamaha Yurub (Belgaraydh)',
        'Europe/Berlin' => 'Waqtiga Bartamaha Yurub (Barliin)',
        'Europe/Bratislava' => 'Waqtiga Bartamaha Yurub (Baratislafa)',
        'Europe/Brussels' => 'Waqtiga Bartamaha Yurub (Barasalis)',
        'Europe/Bucharest' => 'Waqtiga Bariga Yurub (Bujarest)',
        'Europe/Budapest' => 'Waqtiga Bartamaha Yurub (Budabest)',
        'Europe/Busingen' => 'Waqtiga Bartamaha Yurub (Busingeen)',
        'Europe/Chisinau' => 'Waqtiga Bariga Yurub (Jisinaaw)',
        'Europe/Copenhagen' => 'Waqtiga Bartamaha Yurub (Kobenhaagan)',
        'Europe/Dublin' => 'Wakhtiga Giriinwij (Dhaablin)',
        'Europe/Gibraltar' => 'Waqtiga Bartamaha Yurub (Gibraltar)',
        'Europe/Guernsey' => 'Wakhtiga Giriinwij (Geernisi)',
        'Europe/Helsinki' => 'Waqtiga Bariga Yurub (Heleniski)',
        'Europe/Isle_of_Man' => 'Wakhtiga Giriinwij (Ayle of Maan)',
        'Europe/Istanbul' => 'Waqtiga Turki (Istanbuul)',
        'Europe/Jersey' => 'Wakhtiga Giriinwij (Jaarsey)',
        'Europe/Kaliningrad' => 'Waqtiga Bariga Yurub (Kaliningrad)',
        'Europe/Kiev' => 'Waqtiga Bariga Yurub (Kiyeef)',
        'Europe/Kirov' => 'Waqtiga Ruush (Kiroof)',
        'Europe/Lisbon' => 'Waqtiga Galbeedka Yurub (Lisbon)',
        'Europe/Ljubljana' => 'Waqtiga Bartamaha Yurub (Lubalaana)',
        'Europe/London' => 'Wakhtiga Giriinwij (Landan)',
        'Europe/Luxembourg' => 'Waqtiga Bartamaha Yurub (Luksemberg)',
        'Europe/Madrid' => 'Waqtiga Bartamaha Yurub (Madriid)',
        'Europe/Malta' => 'Waqtiga Bartamaha Yurub (Malta)',
        'Europe/Mariehamn' => 'Waqtiga Bariga Yurub (Maarihaam)',
        'Europe/Minsk' => 'Waqtiga Moskow (Minisk)',
        'Europe/Monaco' => 'Waqtiga Bartamaha Yurub (Monako)',
        'Europe/Moscow' => 'Waqtiga Moskow',
        'Europe/Oslo' => 'Waqtiga Bartamaha Yurub (Oslo)',
        'Europe/Paris' => 'Waqtiga Bartamaha Yurub (Baariis)',
        'Europe/Podgorica' => 'Waqtiga Bartamaha Yurub (Bodgorika)',
        'Europe/Prague' => 'Waqtiga Bartamaha Yurub (Baraag)',
        'Europe/Riga' => 'Waqtiga Bariga Yurub (Riija)',
        'Europe/Rome' => 'Waqtiga Bartamaha Yurub (Rooma)',
        'Europe/Samara' => 'Wakhtiga Samara',
        'Europe/San_Marino' => 'Waqtiga Bartamaha Yurub (San Mariino)',
        'Europe/Sarajevo' => 'Waqtiga Bartamaha Yurub (Sarayeefo)',
        'Europe/Saratov' => 'Waqtiga Moskow (Saratoof)',
        'Europe/Simferopol' => 'Waqtiga Moskow (Simferobol)',
        'Europe/Skopje' => 'Waqtiga Bartamaha Yurub (Iskoobje)',
        'Europe/Sofia' => 'Waqtiga Bariga Yurub (Sofiya)',
        'Europe/Stockholm' => 'Waqtiga Bartamaha Yurub (Istokhoom)',
        'Europe/Tallinn' => 'Waqtiga Bariga Yurub (Taalin)',
        'Europe/Tirane' => 'Waqtiga Bartamaha Yurub (Tiraane)',
        'Europe/Ulyanovsk' => 'Waqtiga Moskow (Ulyanofisk)',
        'Europe/Uzhgorod' => 'Waqtiga Bariga Yurub (Usgorod)',
        'Europe/Vaduz' => 'Waqtiga Bartamaha Yurub (Faduus)',
        'Europe/Vatican' => 'Waqtiga Bartamaha Yurub (Fatikaan)',
        'Europe/Vienna' => 'Waqtiga Bartamaha Yurub (Fiyeena)',
        'Europe/Vilnius' => 'Waqtiga Bariga Yurub (Finiyuus)',
        'Europe/Volgograd' => 'Waqtiga Folgograd',
        'Europe/Warsaw' => 'Waqtiga Bartamaha Yurub (Warsaw)',
        'Europe/Zagreb' => 'Waqtiga Bartamaha Yurub (Saqrib)',
        'Europe/Zaporozhye' => 'Waqtiga Bariga Yurub (Saborosey)',
        'Europe/Zurich' => 'Waqtiga Bartamaha Yurub (Suurikh)',
        'Indian/Antananarivo' => 'Waqtiga Bariga Afrika (Antananarifo)',
        'Indian/Chagos' => 'Waqtiga Badweynta Hindiya (Jagos)',
        'Indian/Christmas' => 'Waqtiga Kirismas Aylaan (Kiristmas)',
        'Indian/Cocos' => 'Waqtiga Kokos Aylaan',
        'Indian/Comoro' => 'Waqtiga Bariga Afrika (Komoro)',
        'Indian/Kerguelen' => 'Waqtiga Koonfurta Faransiiska & Antaarktik (Kergalen)',
        'Indian/Mahe' => 'Waqtiga Siishalis (Mahe)',
        'Indian/Maldives' => 'Waqtiga Maldifis',
        'Indian/Mauritius' => 'Waqtiga Morishiyaas',
        'Indian/Mayotte' => 'Waqtiga Bariga Afrika (Mayoote)',
        'Indian/Reunion' => 'Waqtiga Riyuuniyon',
        'MST7MDT' => 'Waqtiga Buuraleyda ee Waqooyiga Ameerika',
        'PST8PDT' => 'Waqtiga Basifika ee Waqooyiga Ameerika',
        'Pacific/Apia' => 'Waqtiga Abiya',
        'Pacific/Auckland' => 'Waqtiga Niyuu Si’laan (Owklaan)',
        'Pacific/Bougainville' => 'Waqtiga Babuw Niyuu Giniya (Boogaynfil)',
        'Pacific/Chatham' => 'Waqtiga Jaatam (Jatam)',
        'Pacific/Easter' => 'Waqtiga Iistar Aylaan',
        'Pacific/Efate' => 'Waqtiga Fanuutu (Efate)',
        'Pacific/Enderbury' => 'Waqtiga Foonikis Aylaanis (Enderburi)',
        'Pacific/Fakaofo' => 'Waqtiga Tokeluu (fakofo)',
        'Pacific/Fiji' => 'Waqtiga Fiji',
        'Pacific/Funafuti' => 'Waqtiga Tufalu (Funafuti)',
        'Pacific/Galapagos' => 'Waqtiga Galabagos',
        'Pacific/Gambier' => 'Waqtiga Gambiyar (Gambiyr)',
        'Pacific/Guadalcanal' => 'Waqtiga Solomon Aylaanis (Cuadalkanal)',
        'Pacific/Guam' => 'Waqtiga Jamoro (Guwam)',
        'Pacific/Honolulu' => 'Waqtiga Hawaay-Alutiyaan (Honolulu)',
        'Pacific/Johnston' => 'Waqtiga Hawaay-Alutiyaan (Joonston)',
        'Pacific/Kiritimati' => 'Waqtiga Leyn Aylaan (Kiritimaati)',
        'Pacific/Kosrae' => 'Waqtiga Kosriy (Kosrii)',
        'Pacific/Kwajalein' => 'Waqtiga Maarshaal Aylaanis (Kuwajaleyn)',
        'Pacific/Majuro' => 'Waqtiga Maarshaal Aylaanis (Majro)',
        'Pacific/Marquesas' => 'Waqtiga Marquwesas',
        'Pacific/Midway' => 'Waqtiga Samoa (Midway)',
        'Pacific/Nauru' => 'Waqtiga Nawroo',
        'Pacific/Niue' => 'Waqtiga Niyuu',
        'Pacific/Norfolk' => 'Waqtiga Norfolk Island (Noorfek)',
        'Pacific/Noumea' => 'Waqtiga Niyuu Kaledonya (Noomiya)',
        'Pacific/Pago_Pago' => 'Waqtiga Samoa (Bago Bago)',
        'Pacific/Palau' => 'Waqtiga Balaw',
        'Pacific/Pitcairn' => 'Waqtiga Bitkeen (Bitkayrn)',
        'Pacific/Ponape' => 'Waqtiga Bonabe (Bonbey)',
        'Pacific/Port_Moresby' => 'Waqtiga Babuw Niyuu Giniya (Boort Moresbi)',
        'Pacific/Rarotonga' => 'Waqtiga Kuuk Aylaanis (Rarotonga)',
        'Pacific/Saipan' => 'Waqtiga Jamoro (Seyban)',
        'Pacific/Tahiti' => 'Waqtiga Tahiti',
        'Pacific/Tarawa' => 'Waqtiga Jilbeert Aylaan (Tarawa)',
        'Pacific/Tongatapu' => 'Waqtiga Tonga (Tongatabu)',
        'Pacific/Truk' => 'Waqtiga Juuk',
        'Pacific/Wake' => 'Waqtiga Wayk Iylaanis (Wake)',
        'Pacific/Wallis' => 'Waqtiga Walis & Futuna',
    ],
    'Meta' => [
    ],
];
