<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Addis_Ababa' => 'Àm Afraga an Ear (Addis Abäba)',
        'Africa/Algiers' => 'Àm Meadhan na Roinn-Eòrpa (Algiers)',
        'Africa/Asmera' => 'Àm Afraga an Ear (Asmarà)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Bangui' => 'Àm Afraga an Iar (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Blantyre' => 'Àm Meadhan Afraga (Blantyre)',
        'Africa/Brazzaville' => 'Àm Afraga an Iar (Brazzaville)',
        'Africa/Bujumbura' => 'Àm Meadhan Afraga (Bujumbura)',
        'Africa/Cairo' => 'Àm na Roinn-Eòrpa an Ear (Cairo)',
        'Africa/Casablanca' => 'Àm na Roinn-Eòrpa an Iar (Casablanca)',
        'Africa/Ceuta' => 'Àm Meadhan na Roinn-Eòrpa (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Dar_es_Salaam' => 'Àm Afraga an Ear (Dàr as-Salàm)',
        'Africa/Djibouti' => 'Àm Afraga an Ear (Diobùtaidh)',
        'Africa/Douala' => 'Àm Afraga an Iar (Douala)',
        'Africa/El_Aaiun' => 'Àm na Roinn-Eòrpa an Iar (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Gaborone' => 'Àm Meadhan Afraga (Gaborone)',
        'Africa/Harare' => 'Àm Meadhan Afraga (Harare)',
        'Africa/Johannesburg' => 'Àm Afraga a Deas (Hannsaborgh)',
        'Africa/Juba' => 'Àm Meadhan Afraga (Juba)',
        'Africa/Kampala' => 'Àm Afraga an Ear (Kampala)',
        'Africa/Khartoum' => 'Àm Meadhan Afraga (Khartoum)',
        'Africa/Kigali' => 'Àm Meadhan Afraga (Kigali)',
        'Africa/Kinshasa' => 'Àm Afraga an Iar (Kinshasa)',
        'Africa/Lagos' => 'Àm Afraga an Iar (Lagos)',
        'Africa/Libreville' => 'Àm Afraga an Iar (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Luanda' => 'Àm Afraga an Iar (Luanda)',
        'Africa/Lubumbashi' => 'Àm Meadhan Afraga (Lubumbashi)',
        'Africa/Lusaka' => 'Àm Meadhan Afraga (Lusaka)',
        'Africa/Malabo' => 'Àm Afraga an Iar (Malabo)',
        'Africa/Maputo' => 'Àm Meadhan Afraga (Maputo)',
        'Africa/Maseru' => 'Àm Afraga a Deas (Maseru)',
        'Africa/Mbabane' => 'Àm Afraga a Deas (Mbabane)',
        'Africa/Mogadishu' => 'Àm Afraga an Ear (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nairobi' => 'Àm Afraga an Ear (Nairobi)',
        'Africa/Ndjamena' => 'Àm Afraga an Iar (N’Djaména)',
        'Africa/Niamey' => 'Àm Afraga an Iar (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Porto-Novo' => 'Àm Afraga an Iar (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (São Tomé)',
        'Africa/Tripoli' => 'Àm na Roinn-Eòrpa an Ear (Tripoli)',
        'Africa/Tunis' => 'Àm Meadhan na Roinn-Eòrpa (Tunis)',
        'Africa/Windhoek' => 'Àm Meadhan Afraga (Windhoek)',
        'America/Adak' => 'Àm nan Eileanan Hawai’i ’s Aleutach (Adak)',
        'America/Anchorage' => 'Àm Alaska (Anchorage)',
        'America/Anguilla' => 'Àm a’ Chuain Siar (Anguillia)',
        'America/Antigua' => 'Àm a’ Chuain Siar (Aintìoga)',
        'America/Araguaina' => 'Àm Bhrasília (Araguaína)',
        'America/Argentina/La_Rioja' => 'Àm na h-Argantaine (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Àm na h-Argantaine (Río Gallegos)',
        'America/Argentina/Salta' => 'Àm na h-Argantaine (Salta)',
        'America/Argentina/San_Juan' => 'Àm na h-Argantaine (San Juan)',
        'America/Argentina/San_Luis' => 'Àm na h-Argantaine (San Luis)',
        'America/Argentina/Tucuman' => 'Àm na h-Argantaine (Tucumán)',
        'America/Argentina/Ushuaia' => 'Àm na h-Argantaine (Ushuaia)',
        'America/Aruba' => 'Àm a’ Chuain Siar (Arùba)',
        'America/Asuncion' => 'Àm Paraguaidh (Asunción)',
        'America/Bahia' => 'Àm Bhrasília (Bahia)',
        'America/Bahia_Banderas' => 'Àm Meadhan Aimeireaga a Tuath (Bahía de Banderas)',
        'America/Barbados' => 'Àm a’ Chuain Siar (Barbados)',
        'America/Belem' => 'Àm Bhrasília (Belém)',
        'America/Belize' => 'Àm Meadhan Aimeireaga a Tuath (A’ Bheilìs)',
        'America/Blanc-Sablon' => 'Àm a’ Chuain Siar (Blanc-Sablon)',
        'America/Boa_Vista' => 'Àm Amasoin (Boa Vista)',
        'America/Bogota' => 'Àm Coloimbia (Bogotá)',
        'America/Boise' => 'Àm Monadh Aimeireaga a Tuath (Boise)',
        'America/Buenos_Aires' => 'Àm na h-Argantaine (Buenos Aires)',
        'America/Cambridge_Bay' => 'Àm Monadh Aimeireaga a Tuath (Cambridge Bay)',
        'America/Campo_Grande' => 'Àm Amasoin (Campo Grande)',
        'America/Cancun' => 'Àm Aimeireaga a Tuath an Ear (Cancún)',
        'America/Caracas' => 'Àm na Bheiniseala (Caracas)',
        'America/Catamarca' => 'Àm na h-Argantaine (Catamarca)',
        'America/Cayenne' => 'Àm Guidheàna na Frainge (Cayenne)',
        'America/Cayman' => 'Àm Aimeireaga a Tuath an Ear (Caimean)',
        'America/Chicago' => 'Àm Meadhan Aimeireaga a Tuath (Chicago)',
        'America/Chihuahua' => 'Àm a’ Chuain Sèimh Mheagsago (Chihuahua)',
        'America/Coral_Harbour' => 'Àm Aimeireaga a Tuath an Ear (Atikokan)',
        'America/Cordoba' => 'Àm na h-Argantaine (Córdoba)',
        'America/Costa_Rica' => 'Àm Meadhan Aimeireaga a Tuath (Costa Rìcea)',
        'America/Creston' => 'Àm Monadh Aimeireaga a Tuath (Creston)',
        'America/Cuiaba' => 'Àm Amasoin (Cuiabá)',
        'America/Curacao' => 'Àm a’ Chuain Siar (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (Danmarkshavn)',
        'America/Dawson' => 'Àm Yukon (Dawson)',
        'America/Dawson_Creek' => 'Àm Monadh Aimeireaga a Tuath (Dawson Creek)',
        'America/Denver' => 'Àm Monadh Aimeireaga a Tuath (Denver)',
        'America/Detroit' => 'Àm Aimeireaga a Tuath an Ear (Detroit)',
        'America/Dominica' => 'Àm a’ Chuain Siar (Doiminicea)',
        'America/Edmonton' => 'Àm Monadh Aimeireaga a Tuath (Edmonton)',
        'America/Eirunepe' => 'Àm Acre (Eirunepé)',
        'America/El_Salvador' => 'Àm Meadhan Aimeireaga a Tuath (An Salbhador)',
        'America/Fort_Nelson' => 'Àm Monadh Aimeireaga a Tuath (Fort Nelson)',
        'America/Fortaleza' => 'Àm Bhrasília (Fortaleza)',
        'America/Glace_Bay' => 'Àm a’ Chuain Siar (Glasbaidh)',
        'America/Godthab' => 'Àm na Graonlainn an Iar (Nuuk)',
        'America/Goose_Bay' => 'Àm a’ Chuain Siar (Goose Bay)',
        'America/Grand_Turk' => 'Àm Aimeireaga a Tuath an Ear (An Turc Mhòr)',
        'America/Grenada' => 'Àm a’ Chuain Siar (Greanàda)',
        'America/Guadeloupe' => 'Àm a’ Chuain Siar (Guadalup)',
        'America/Guatemala' => 'Àm Meadhan Aimeireaga a Tuath (Guatamala)',
        'America/Guayaquil' => 'Àm Eacuadoir (Guayaquil)',
        'America/Guyana' => 'Àm Guidheàna',
        'America/Halifax' => 'Àm a’ Chuain Siar (Halifax)',
        'America/Havana' => 'Àm Cùba (Havana)',
        'America/Hermosillo' => 'Àm a’ Chuain Sèimh Mheagsago (Hermosillo)',
        'America/Indiana/Knox' => 'Àm Meadhan Aimeireaga a Tuath (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Àm Aimeireaga a Tuath an Ear (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Àm Aimeireaga a Tuath an Ear (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Àm Meadhan Aimeireaga a Tuath (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Àm Aimeireaga a Tuath an Ear (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Àm Aimeireaga a Tuath an Ear (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Àm Aimeireaga a Tuath an Ear (Winamac, Indiana)',
        'America/Indianapolis' => 'Àm Aimeireaga a Tuath an Ear (Indianapolis)',
        'America/Inuvik' => 'Àm Monadh Aimeireaga a Tuath (Inuuvik)',
        'America/Iqaluit' => 'Àm Aimeireaga a Tuath an Ear (Iqaluit)',
        'America/Jamaica' => 'Àm Aimeireaga a Tuath an Ear (Diameuga)',
        'America/Jujuy' => 'Àm na h-Argantaine (Jujuy)',
        'America/Juneau' => 'Àm Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Àm Aimeireaga a Tuath an Ear (Monticello, Kentucky)',
        'America/Kralendijk' => 'Àm a’ Chuain Siar (Kralendijk)',
        'America/La_Paz' => 'Àm Boilibhia (La Paz)',
        'America/Lima' => 'Àm Pearù (Lima)',
        'America/Los_Angeles' => 'Àm a’ Chuain Sèimh (Los Angeles)',
        'America/Louisville' => 'Àm Aimeireaga a Tuath an Ear (Louisville)',
        'America/Lower_Princes' => 'Àm a’ Chuain Siar (Lower Prince’s Quarter)',
        'America/Maceio' => 'Àm Bhrasília (Maceió)',
        'America/Managua' => 'Àm Meadhan Aimeireaga a Tuath (Managua)',
        'America/Manaus' => 'Àm Amasoin (Manaus)',
        'America/Marigot' => 'Àm a’ Chuain Siar (Marigot)',
        'America/Martinique' => 'Àm a’ Chuain Siar (Mairtinic)',
        'America/Matamoros' => 'Àm Meadhan Aimeireaga a Tuath (Matamoros)',
        'America/Mazatlan' => 'Àm a’ Chuain Sèimh Mheagsago (Mazatlán)',
        'America/Mendoza' => 'Àm na h-Argantaine (Mendoza)',
        'America/Menominee' => 'Àm Meadhan Aimeireaga a Tuath (Menominee)',
        'America/Merida' => 'Àm Meadhan Aimeireaga a Tuath (Mérida)',
        'America/Metlakatla' => 'Àm Alaska (Metlakatla)',
        'America/Mexico_City' => 'Àm Meadhan Aimeireaga a Tuath (Cathair Mheagsago)',
        'America/Miquelon' => 'Àm Saint Pierre agus Miquelon',
        'America/Moncton' => 'Àm a’ Chuain Siar (Moncton)',
        'America/Monterrey' => 'Àm Meadhan Aimeireaga a Tuath (Monterrey)',
        'America/Montevideo' => 'Àm Uruguaidh (Montevideo)',
        'America/Montreal' => 'Canada (Montreal)',
        'America/Montserrat' => 'Àm a’ Chuain Siar (Montsarat)',
        'America/Nassau' => 'Àm Aimeireaga a Tuath an Ear (Nassau)',
        'America/New_York' => 'Àm Aimeireaga a Tuath an Ear (Nuadh Eabhrac)',
        'America/Nipigon' => 'Àm Aimeireaga a Tuath an Ear (Nipigon)',
        'America/Nome' => 'Àm Alaska (Nome)',
        'America/Noronha' => 'Àm Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Àm Meadhan Aimeireaga a Tuath (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Àm Meadhan Aimeireaga a Tuath (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Àm Meadhan Aimeireaga a Tuath (New Salem, North Dakota)',
        'America/Ojinaga' => 'Àm Monadh Aimeireaga a Tuath (Ojinaga)',
        'America/Panama' => 'Àm Aimeireaga a Tuath an Ear (Panama)',
        'America/Pangnirtung' => 'Àm Aimeireaga a Tuath an Ear (Pangniqtuuq)',
        'America/Paramaribo' => 'Àm Suranaim (Paramaribo)',
        'America/Phoenix' => 'Àm Monadh Aimeireaga a Tuath (Phoenix)',
        'America/Port-au-Prince' => 'Àm Aimeireaga a Tuath an Ear (Port-au-Prince)',
        'America/Port_of_Spain' => 'Àm a’ Chuain Siar (Port na Spàinne)',
        'America/Porto_Velho' => 'Àm Amasoin (Porto Velho)',
        'America/Puerto_Rico' => 'Àm a’ Chuain Siar (Porto Rìceo)',
        'America/Punta_Arenas' => 'Àm na Sile (Punta Arenas)',
        'America/Rainy_River' => 'Àm Meadhan Aimeireaga a Tuath (Rainy River)',
        'America/Rankin_Inlet' => 'Àm Meadhan Aimeireaga a Tuath (Kangiqliniq)',
        'America/Recife' => 'Àm Bhrasília (Recife)',
        'America/Regina' => 'Àm Meadhan Aimeireaga a Tuath (Regina)',
        'America/Resolute' => 'Àm Meadhan Aimeireaga a Tuath (Qausuittuq)',
        'America/Rio_Branco' => 'Àm Acre (Rio Branco)',
        'America/Santa_Isabel' => 'Àm Mheagsago an Iar-thuath (Santa Isabel)',
        'America/Santarem' => 'Àm Bhrasília (Santarém)',
        'America/Santiago' => 'Àm na Sile (Santiago)',
        'America/Santo_Domingo' => 'Àm a’ Chuain Siar (Santo Domingo)',
        'America/Sao_Paulo' => 'Àm Bhrasília (São Paulo)',
        'America/Scoresbysund' => 'Àm na Graonlainn an Ear (Ittoqqortoormiit)',
        'America/Sitka' => 'Àm Alaska (Sitka)',
        'America/St_Barthelemy' => 'Àm a’ Chuain Siar (Saint Barthélemy)',
        'America/St_Johns' => 'Àm Talamh an Èisg (St. John’s)',
        'America/St_Kitts' => 'Àm a’ Chuain Siar (Naomh Crìstean)',
        'America/St_Lucia' => 'Àm a’ Chuain Siar (Naomh Lùisea)',
        'America/St_Thomas' => 'Àm a’ Chuain Siar (St. Thomas)',
        'America/St_Vincent' => 'Àm a’ Chuain Siar (Naomh Bhionsant)',
        'America/Swift_Current' => 'Àm Meadhan Aimeireaga a Tuath (Swift Current)',
        'America/Tegucigalpa' => 'Àm Meadhan Aimeireaga a Tuath (Tegucigalpa)',
        'America/Thule' => 'Àm a’ Chuain Siar (Qaanaaq)',
        'America/Thunder_Bay' => 'Àm Aimeireaga a Tuath an Ear (Thunder Bay)',
        'America/Tijuana' => 'Àm a’ Chuain Sèimh (Tijuana)',
        'America/Toronto' => 'Àm Aimeireaga a Tuath an Ear (Toronto)',
        'America/Tortola' => 'Àm a’ Chuain Siar (Tortola)',
        'America/Vancouver' => 'Àm a’ Chuain Sèimh (Vancouver)',
        'America/Whitehorse' => 'Àm Yukon (Whitehorse)',
        'America/Winnipeg' => 'Àm Meadhan Aimeireaga a Tuath (Winnipeg)',
        'America/Yakutat' => 'Àm Alaska (Yakutat)',
        'America/Yellowknife' => 'Àm Monadh Aimeireaga a Tuath (Yellowknife)',
        'Antarctica/Casey' => 'Àm Chasey (Casey)',
        'Antarctica/Davis' => 'Àm Dhavis (Davis)',
        'Antarctica/DumontDUrville' => 'Àm Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Àm Astràilia an Ear (Eilean MhicGuaire)',
        'Antarctica/Mawson' => 'Àm Mhawson (Mawson)',
        'Antarctica/McMurdo' => 'Àm Shealainn Nuaidh (McMurdo)',
        'Antarctica/Palmer' => 'Àm na Sile (Palmer)',
        'Antarctica/Rothera' => 'Àm Rothera',
        'Antarctica/Syowa' => 'Àm Shyowa (Syowa)',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
        'Antarctica/Vostok' => 'Àm Vostok',
        'Arctic/Longyearbyen' => 'Àm Meadhan na Roinn-Eòrpa (Longyearbyen)',
        'Asia/Aden' => 'Àm Arabach (Aden)',
        'Asia/Almaty' => 'Àm Casachstàin an Ear (Almaty)',
        'Asia/Amman' => 'Àm na Roinn-Eòrpa an Ear (Ammān)',
        'Asia/Anadyr' => 'Àm Anadyr',
        'Asia/Aqtau' => 'Àm Casachstàin an Iar (Aqtau)',
        'Asia/Aqtobe' => 'Àm Casachstàin an Iar (Aqtöbe)',
        'Asia/Ashgabat' => 'Àm Turcmanastàin (Aşgabat)',
        'Asia/Atyrau' => 'Àm Casachstàin an Iar (Atyrau)',
        'Asia/Baghdad' => 'Àm Arabach (Baghdād)',
        'Asia/Bahrain' => 'Àm Arabach (Bachrain)',
        'Asia/Baku' => 'Àm Asarbaideàin (Baku)',
        'Asia/Bangkok' => 'Àm Sìn-Innseanach (Bangkok)',
        'Asia/Barnaul' => 'An Ruis (Barnaul)',
        'Asia/Beirut' => 'Àm na Roinn-Eòrpa an Ear (Beirut)',
        'Asia/Bishkek' => 'Àm Cìorgastain (Biškek)',
        'Asia/Brunei' => 'Àm Bhrùnaigh Dàr as-Salàm (Brùnaigh)',
        'Asia/Calcutta' => 'Àm nan Innseachan (Kolkata)',
        'Asia/Chita' => 'Àm Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Àm Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Àm nan Innseachan (Colombo)',
        'Asia/Damascus' => 'Àm na Roinn-Eòrpa an Ear (Damascus)',
        'Asia/Dhaka' => 'Àm Bangladais (Dhaka)',
        'Asia/Dili' => 'Àm Thìomor an Ear (Dili)',
        'Asia/Dubai' => 'Àm a’ Chamais (Dubai)',
        'Asia/Dushanbe' => 'Àm Taidigeastàin (Dušanbe)',
        'Asia/Famagusta' => 'Àm na Roinn-Eòrpa an Ear (Famagusta)',
        'Asia/Gaza' => 'Àm na Roinn-Eòrpa an Ear (Gàsa)',
        'Asia/Hebron' => 'Àm na Roinn-Eòrpa an Ear (Hebron)',
        'Asia/Hong_Kong' => 'Àm Hong Kong',
        'Asia/Hovd' => 'Àm Hovd (Khovd)',
        'Asia/Irkutsk' => 'Àm Irkutsk',
        'Asia/Jakarta' => 'Àm nan Innd-Innse an Iar (Jakarta)',
        'Asia/Jayapura' => 'Àm nan Innd-Innse an Ear (Jayapura)',
        'Asia/Jerusalem' => 'Àm Iosrael (Ierusalam)',
        'Asia/Kabul' => 'Àm Afghanastàin (Kabul)',
        'Asia/Kamchatka' => 'Àm Petropavlovsk-Kamchatsky (Kamchatka)',
        'Asia/Karachi' => 'Àm Pagastàin (Karācī)',
        'Asia/Katmandu' => 'Àm Neapàl (Kathmandu)',
        'Asia/Khandyga' => 'Àm Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Àm Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Àm Mhalaidhsea (Kuala Lumpur)',
        'Asia/Kuching' => 'Àm Mhalaidhsea (Kuching)',
        'Asia/Kuwait' => 'Àm Arabach (Cuibhèit)',
        'Asia/Macau' => 'Àm na Sìne (Macàthu)',
        'Asia/Magadan' => 'Àm Magadan',
        'Asia/Makassar' => 'Àm Meadhan nan Innd-Innse (Makassar)',
        'Asia/Manila' => 'Àm nan Eilean Filipineach (Manila)',
        'Asia/Muscat' => 'Àm a’ Chamais (Muscat)',
        'Asia/Nicosia' => 'Àm na Roinn-Eòrpa an Ear (Nicosia)',
        'Asia/Novokuznetsk' => 'Àm Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Àm Novosibirsk',
        'Asia/Omsk' => 'Àm Omsk',
        'Asia/Oral' => 'Àm Casachstàin an Iar (Oral)',
        'Asia/Phnom_Penh' => 'Àm Sìn-Innseanach (Phnom Penh)',
        'Asia/Pontianak' => 'Àm nan Innd-Innse an Iar (Pontianak)',
        'Asia/Pyongyang' => 'Àm Choirèa (Pyeongyang)',
        'Asia/Qatar' => 'Àm Arabach (Catar)',
        'Asia/Qostanay' => 'Àm Casachstàin an Ear (Qostanaı)',
        'Asia/Qyzylorda' => 'Àm Casachstàin an Iar (Qızılorda)',
        'Asia/Rangoon' => 'Àm Miànmar (Rangun)',
        'Asia/Riyadh' => 'Àm Arabach (Riyadh)',
        'Asia/Saigon' => 'Àm Sìn-Innseanach (Cathair Ho Chi Minh)',
        'Asia/Sakhalin' => 'Àm Sakhalin',
        'Asia/Samarkand' => 'Àm Usbagastàn (Samarkand)',
        'Asia/Seoul' => 'Àm Choirèa (Seoul)',
        'Asia/Shanghai' => 'Àm na Sìne (Shanghai)',
        'Asia/Singapore' => 'Àm Singeapòr',
        'Asia/Srednekolymsk' => 'Àm Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Àm Taipei',
        'Asia/Tashkent' => 'Àm Usbagastàn (Toškent)',
        'Asia/Tbilisi' => 'Àm na Cairtbheile (T’bilisi)',
        'Asia/Tehran' => 'Àm Ioràin (Tehrān)',
        'Asia/Thimphu' => 'Àm Butàin (Thimphu)',
        'Asia/Tokyo' => 'Àm na Seapaine (Tōkyō)',
        'Asia/Tomsk' => 'An Ruis (Tomsk)',
        'Asia/Ulaanbaatar' => 'Àm Ulan Bator (Ulaanbaatar)',
        'Asia/Urumqi' => 'An t-Sìn (Ürümqi)',
        'Asia/Ust-Nera' => 'Àm Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Àm Sìn-Innseanach (Viang Chan)',
        'Asia/Vladivostok' => 'Àm Vladivostok',
        'Asia/Yakutsk' => 'Àm Yakutsk',
        'Asia/Yekaterinburg' => 'Àm Yekaterinburg',
        'Asia/Yerevan' => 'Àm Airmeinia (Yerevan)',
        'Atlantic/Azores' => 'Àm nan Eileanan Asorach (Ponta Delgada)',
        'Atlantic/Bermuda' => 'Àm a’ Chuain Siar (Bearmùda)',
        'Atlantic/Canary' => 'Àm na Roinn-Eòrpa an Iar (Na h-Eileanan Canàrach)',
        'Atlantic/Cape_Verde' => 'Àm a’ Chip Uaine (An Ceap Uaine)',
        'Atlantic/Faeroe' => 'Àm na Roinn-Eòrpa an Iar (Fàro)',
        'Atlantic/Madeira' => 'Àm na Roinn-Eòrpa an Iar (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavík)',
        'Atlantic/South_Georgia' => 'Àm Seòrsea a Deas',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (Eilean Naomh Eilidh)',
        'Atlantic/Stanley' => 'Àm nan Eileanan Fàclannach (Stanley)',
        'Australia/Adelaide' => 'Àm Meadhan Astràilia (Adelaide)',
        'Australia/Brisbane' => 'Àm Astràilia an Ear (Brisbane)',
        'Australia/Broken_Hill' => 'Àm Meadhan Astràilia (Broken Hill)',
        'Australia/Currie' => 'Àm Astràilia an Ear (Currie)',
        'Australia/Darwin' => 'Àm Meadhan Astràilia (Darwin)',
        'Australia/Eucla' => 'Àm Meadhan Astràilia an Iar (Eucla)',
        'Australia/Hobart' => 'Àm Astràilia an Ear (Hobart)',
        'Australia/Lindeman' => 'Àm Astràilia an Ear (Lindeman)',
        'Australia/Lord_Howe' => 'Àm Lord Howe',
        'Australia/Melbourne' => 'Àm Astràilia an Ear (Melbourne)',
        'Australia/Perth' => 'Àm Astràilia an Iar (Perth)',
        'Australia/Sydney' => 'Àm Astràilia an Ear (Sidni)',
        'CST6CDT' => 'Àm Meadhan Aimeireaga a Tuath',
        'EST5EDT' => 'Àm Aimeireaga a Tuath an Ear',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Etc/UTC' => 'Àm Uile-choitcheann Co-òrdanaichte',
        'Europe/Amsterdam' => 'Àm Meadhan na Roinn-Eòrpa (Amsterdam)',
        'Europe/Andorra' => 'Àm Meadhan na Roinn-Eòrpa (Andorra)',
        'Europe/Astrakhan' => 'Àm Mhosgo (Astrakhan)',
        'Europe/Athens' => 'Àm na Roinn-Eòrpa an Ear (An Àithne)',
        'Europe/Belgrade' => 'Àm Meadhan na Roinn-Eòrpa (Belgrade)',
        'Europe/Berlin' => 'Àm Meadhan na Roinn-Eòrpa (Berlin)',
        'Europe/Bratislava' => 'Àm Meadhan na Roinn-Eòrpa (Bratislava)',
        'Europe/Brussels' => 'Àm Meadhan na Roinn-Eòrpa (A’ Bhruiseal)',
        'Europe/Bucharest' => 'Àm na Roinn-Eòrpa an Ear (Bucharest)',
        'Europe/Budapest' => 'Àm Meadhan na Roinn-Eòrpa (Budapest)',
        'Europe/Busingen' => 'Àm Meadhan na Roinn-Eòrpa (Busingen)',
        'Europe/Chisinau' => 'Àm na Roinn-Eòrpa an Ear (Chișinău)',
        'Europe/Copenhagen' => 'Àm Meadhan na Roinn-Eòrpa (Beirbh)',
        'Europe/Dublin' => 'Greenwich Mean Time (Baile Àtha Cliath)',
        'Europe/Gibraltar' => 'Àm Meadhan na Roinn-Eòrpa (Diobraltar)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Geàrnsaidh)',
        'Europe/Helsinki' => 'Àm na Roinn-Eòrpa an Ear (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Eilean Mhanainn)',
        'Europe/Istanbul' => 'An Tuirc (Istanbul)',
        'Europe/Jersey' => 'Greenwich Mean Time (Deàrsaidh)',
        'Europe/Kaliningrad' => 'Àm na Roinn-Eòrpa an Ear (Kaliningrad)',
        'Europe/Kiev' => 'Àm na Roinn-Eòrpa an Ear (Kiev)',
        'Europe/Kirov' => 'An Ruis (Kirov)',
        'Europe/Lisbon' => 'Àm na Roinn-Eòrpa an Iar (Lisbon)',
        'Europe/Ljubljana' => 'Àm Meadhan na Roinn-Eòrpa (Ljubljana)',
        'Europe/London' => 'Greenwich Mean Time (Dùn Èideann/Lunnainn)',
        'Europe/Luxembourg' => 'Àm Meadhan na Roinn-Eòrpa (Lugsamburg)',
        'Europe/Madrid' => 'Àm Meadhan na Roinn-Eòrpa (Madrid)',
        'Europe/Malta' => 'Àm Meadhan na Roinn-Eòrpa (Malta)',
        'Europe/Mariehamn' => 'Àm na Roinn-Eòrpa an Ear (Mariehamn)',
        'Europe/Minsk' => 'Àm Mhosgo (Minsk)',
        'Europe/Monaco' => 'Àm Meadhan na Roinn-Eòrpa (Monaco)',
        'Europe/Moscow' => 'Àm Mhosgo (Mosgo)',
        'Europe/Oslo' => 'Àm Meadhan na Roinn-Eòrpa (Oslo)',
        'Europe/Paris' => 'Àm Meadhan na Roinn-Eòrpa (Paras)',
        'Europe/Podgorica' => 'Àm Meadhan na Roinn-Eòrpa (Podgorica)',
        'Europe/Prague' => 'Àm Meadhan na Roinn-Eòrpa (Pràg)',
        'Europe/Riga' => 'Àm na Roinn-Eòrpa an Ear (Rīga)',
        'Europe/Rome' => 'Àm Meadhan na Roinn-Eòrpa (An Ròimh)',
        'Europe/Samara' => 'Àm Samara',
        'Europe/San_Marino' => 'Àm Meadhan na Roinn-Eòrpa (San Marino)',
        'Europe/Sarajevo' => 'Àm Meadhan na Roinn-Eòrpa (Sarajevo)',
        'Europe/Saratov' => 'Àm Mhosgo (Saratov)',
        'Europe/Simferopol' => 'Àm Mhosgo (Simferopol)',
        'Europe/Skopje' => 'Àm Meadhan na Roinn-Eòrpa (Skopje)',
        'Europe/Sofia' => 'Àm na Roinn-Eòrpa an Ear (Sofiya)',
        'Europe/Stockholm' => 'Àm Meadhan na Roinn-Eòrpa (Stockholm)',
        'Europe/Tallinn' => 'Àm na Roinn-Eòrpa an Ear (Tallinn)',
        'Europe/Tirane' => 'Àm Meadhan na Roinn-Eòrpa (Tiranë)',
        'Europe/Ulyanovsk' => 'Àm Mhosgo (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Àm na Roinn-Eòrpa an Ear (Uzhgorod)',
        'Europe/Vaduz' => 'Àm Meadhan na Roinn-Eòrpa (Vaduz)',
        'Europe/Vatican' => 'Àm Meadhan na Roinn-Eòrpa (A’ Bhatacan)',
        'Europe/Vienna' => 'Àm Meadhan na Roinn-Eòrpa (Vienna)',
        'Europe/Vilnius' => 'Àm na Roinn-Eòrpa an Ear (Vilnius)',
        'Europe/Volgograd' => 'Àm Volgograd',
        'Europe/Warsaw' => 'Àm Meadhan na Roinn-Eòrpa (Warsaw)',
        'Europe/Zagreb' => 'Àm Meadhan na Roinn-Eòrpa (Zagreb)',
        'Europe/Zaporozhye' => 'Àm na Roinn-Eòrpa an Ear (Zaporozhye)',
        'Europe/Zurich' => 'Àm Meadhan na Roinn-Eòrpa (Zürich)',
        'Indian/Antananarivo' => 'Àm Afraga an Ear (Antananarivo)',
        'Indian/Chagos' => 'Àm Cuan nan Innseachan (Chagos)',
        'Indian/Christmas' => 'Àm Eilean na Nollaig',
        'Indian/Cocos' => 'Àm Eileanan Chocos (Cocos)',
        'Indian/Comoro' => 'Àm Afraga an Ear (Comoro)',
        'Indian/Kerguelen' => 'Àm Deasach agus Antartaigeach na Frainge (Kergelenn)',
        'Indian/Mahe' => 'Àm nan Eileanan Sheiseall (Mahé)',
        'Indian/Maldives' => 'Àm nan Eileanan Mhaladaibh (Na h-Eileanan Mhaladaibh)',
        'Indian/Mauritius' => 'Àm nan Eileanan Mhoiriseas (Na h-Eileanan Mhoiriseas)',
        'Indian/Mayotte' => 'Àm Afraga an Ear (Mayotte)',
        'Indian/Reunion' => 'Àm Reunion (Réunion)',
        'MST7MDT' => 'Àm Monadh Aimeireaga a Tuath',
        'PST8PDT' => 'Àm a’ Chuain Sèimh',
        'Pacific/Apia' => 'Àm Apia',
        'Pacific/Auckland' => 'Àm Shealainn Nuaidh (Auckland)',
        'Pacific/Bougainville' => 'Àm Gini Nuaidh Paputhaiche (Bougainville)',
        'Pacific/Chatham' => 'Àm Chatham',
        'Pacific/Easter' => 'Àm Eilean na Càisge (Rapa Nui)',
        'Pacific/Efate' => 'Àm Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Àm Eileanan Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Àm Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Àm Fìdi',
        'Pacific/Funafuti' => 'Àm Tubhalu (Funafuti)',
        'Pacific/Galapagos' => 'Àm Ghalapagos (Galápagos)',
        'Pacific/Gambier' => 'Àm Ghambier (Mangareva)',
        'Pacific/Guadalcanal' => 'Àm Eileanan Sholaimh (Guadalcanal)',
        'Pacific/Guam' => 'Àm Chamorro (Guam)',
        'Pacific/Honolulu' => 'Àm nan Eileanan Hawai’i ’s Aleutach (Honolulu)',
        'Pacific/Johnston' => 'Àm nan Eileanan Hawai’i ’s Aleutach (Johnston)',
        'Pacific/Kiritimati' => 'Àm Eileanan Teraina (Kiritimati)',
        'Pacific/Kosrae' => 'Àm Kosrae',
        'Pacific/Kwajalein' => 'Àm Eileanan Mharshall (Kwajalein)',
        'Pacific/Majuro' => 'Àm Eileanan Mharshall (Majuro)',
        'Pacific/Marquesas' => 'Àm Eileanan a’ Mharcais',
        'Pacific/Midway' => 'Àm Samotha (Midway)',
        'Pacific/Nauru' => 'Àm Nabhru',
        'Pacific/Niue' => 'Àm Niue',
        'Pacific/Norfolk' => 'Àm Eilein Norfolk',
        'Pacific/Noumea' => 'Àm Chailleann Nuaidh (Noumea)',
        'Pacific/Pago_Pago' => 'Àm Samotha (Pago Pago)',
        'Pacific/Palau' => 'Àm Palabh',
        'Pacific/Pitcairn' => 'Àm Peit a’ Chàirn',
        'Pacific/Ponape' => 'Àm Pohnpei',
        'Pacific/Port_Moresby' => 'Àm Gini Nuaidh Paputhaiche (Port Moresby)',
        'Pacific/Rarotonga' => 'Àm Eileanan Cook (Rarotonga)',
        'Pacific/Saipan' => 'Àm Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Àm Tahiti',
        'Pacific/Tarawa' => 'Àm Eileanan Ghileabairt (Tarawa)',
        'Pacific/Tongatapu' => 'Àm Tonga (Tongatapu)',
        'Pacific/Truk' => 'Àm Chuuk',
        'Pacific/Wake' => 'Àm Eilean Wake',
        'Pacific/Wallis' => 'Àm Uallas agus Futuna',
    ],
    'Meta' => [
    ],
];
