<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Suðurafrika)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Gana)',
        'am' => 'amhariskt',
        'am_ET' => 'amhariskt (Etiopia)',
        'ar' => 'arabiskt',
        'ar_001' => 'arabiskt (heimur)',
        'ar_AE' => 'arabiskt (Sameindu Emirríkini)',
        'ar_BH' => 'arabiskt (Barein)',
        'ar_DJ' => 'arabiskt (Djibuti)',
        'ar_DZ' => 'arabiskt (Algeria)',
        'ar_EG' => 'arabiskt (Egyptaland)',
        'ar_EH' => 'arabiskt (Vestursahara)',
        'ar_ER' => 'arabiskt (Eritrea)',
        'ar_IL' => 'arabiskt (Ísrael)',
        'ar_IQ' => 'arabiskt (Irak)',
        'ar_JO' => 'arabiskt (Jordan)',
        'ar_KM' => 'arabiskt (Komoroyggjar)',
        'ar_KW' => 'arabiskt (Kuvait)',
        'ar_LB' => 'arabiskt (Libanon)',
        'ar_LY' => 'arabiskt (Libya)',
        'ar_MA' => 'arabiskt (Marokko)',
        'ar_MR' => 'arabiskt (Móritania)',
        'ar_OM' => 'arabiskt (Oman)',
        'ar_PS' => 'arabiskt (Palestinskt landøki)',
        'ar_QA' => 'arabiskt (Katar)',
        'ar_SA' => 'arabiskt (Saudiarabia)',
        'ar_SD' => 'arabiskt (Sudan)',
        'ar_SO' => 'arabiskt (Somalia)',
        'ar_SS' => 'arabiskt (Suðursudan)',
        'ar_SY' => 'arabiskt (Sýria)',
        'ar_TD' => 'arabiskt (Kjad)',
        'ar_TN' => 'arabiskt (Tunesia)',
        'ar_YE' => 'arabiskt (Jemen)',
        'as' => 'assamesiskt',
        'as_IN' => 'assamesiskt (India)',
        'az' => 'aserbajdsjanskt',
        'az_AZ' => 'aserbajdsjanskt (Aserbadjan)',
        'az_Cyrl' => 'aserbajdsjanskt (kyrilliskt)',
        'az_Cyrl_AZ' => 'aserbajdsjanskt (kyrilliskt, Aserbadjan)',
        'az_Latn' => 'aserbajdsjanskt (latínskt)',
        'az_Latn_AZ' => 'aserbajdsjanskt (latínskt, Aserbadjan)',
        'be' => 'hvitarussiskt',
        'be_BY' => 'hvitarussiskt (Hvítarussland)',
        'bg' => 'bulgarskt',
        'bg_BG' => 'bulgarskt (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bangla',
        'bn_BD' => 'bangla (Bangladesj)',
        'bn_IN' => 'bangla (India)',
        'bo' => 'tibetskt',
        'bo_CN' => 'tibetskt (Kina)',
        'bo_IN' => 'tibetskt (India)',
        'br' => 'bretonskt',
        'br_FR' => 'bretonskt (Frakland)',
        'bs' => 'bosniskt',
        'bs_BA' => 'bosniskt (Bosnia-Hersegovina)',
        'bs_Cyrl' => 'bosniskt (kyrilliskt)',
        'bs_Cyrl_BA' => 'bosniskt (kyrilliskt, Bosnia-Hersegovina)',
        'bs_Latn' => 'bosniskt (latínskt)',
        'bs_Latn_BA' => 'bosniskt (latínskt, Bosnia-Hersegovina)',
        'ca' => 'katalani',
        'ca_AD' => 'katalani (Andorra)',
        'ca_ES' => 'katalani (Spania)',
        'ca_FR' => 'katalani (Frakland)',
        'ca_IT' => 'katalani (Italia)',
        'ce' => 'tjetjenskt',
        'ce_RU' => 'tjetjenskt (Russland)',
        'cs' => 'kekkiskt',
        'cs_CZ' => 'kekkiskt (Kekkia)',
        'cv' => 'chuvash',
        'cv_RU' => 'chuvash (Russland)',
        'cy' => 'walisiskt',
        'cy_GB' => 'walisiskt (Stórabretland)',
        'da' => 'danskt',
        'da_DK' => 'danskt (Danmark)',
        'da_GL' => 'danskt (Grønland)',
        'de' => 'týskt',
        'de_AT' => 'týskt (Eysturríki)',
        'de_BE' => 'týskt (Belgia)',
        'de_CH' => 'týskt (Sveis)',
        'de_DE' => 'týskt (Týskland)',
        'de_IT' => 'týskt (Italia)',
        'de_LI' => 'týskt (Liktinstein)',
        'de_LU' => 'týskt (Luksemborg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Butan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Gana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'grikskt',
        'el_CY' => 'grikskt (Kýpros)',
        'el_GR' => 'grikskt (Grikkaland)',
        'en' => 'enskt',
        'en_001' => 'enskt (heimur)',
        'en_150' => 'enskt (Evropa)',
        'en_AE' => 'enskt (Sameindu Emirríkini)',
        'en_AG' => 'enskt (Antigua & Barbuda)',
        'en_AI' => 'enskt (Anguilla)',
        'en_AS' => 'enskt (Amerikanska Samoa)',
        'en_AT' => 'enskt (Eysturríki)',
        'en_AU' => 'enskt (Avstralia)',
        'en_BB' => 'enskt (Barbados)',
        'en_BE' => 'enskt (Belgia)',
        'en_BI' => 'enskt (Burundi)',
        'en_BM' => 'enskt (Bermuda)',
        'en_BS' => 'enskt (Bahamaoyggjar)',
        'en_BW' => 'enskt (Botsvana)',
        'en_BZ' => 'enskt (Belis)',
        'en_CA' => 'enskt (Kanada)',
        'en_CC' => 'enskt (Kokosoyggjar)',
        'en_CH' => 'enskt (Sveis)',
        'en_CK' => 'enskt (Cooksoyggjar)',
        'en_CM' => 'enskt (Kamerun)',
        'en_CX' => 'enskt (Jólaoyggjin)',
        'en_CY' => 'enskt (Kýpros)',
        'en_DE' => 'enskt (Týskland)',
        'en_DK' => 'enskt (Danmark)',
        'en_DM' => 'enskt (Dominika)',
        'en_ER' => 'enskt (Eritrea)',
        'en_FI' => 'enskt (Finnland)',
        'en_FJ' => 'enskt (Fiji)',
        'en_FK' => 'enskt (Falklandsoyggjar)',
        'en_FM' => 'enskt (Mikronesiasamveldið)',
        'en_GB' => 'enskt (Stórabretland)',
        'en_GD' => 'enskt (Grenada)',
        'en_GG' => 'enskt (Guernsey)',
        'en_GH' => 'enskt (Gana)',
        'en_GI' => 'enskt (Gibraltar)',
        'en_GM' => 'enskt (Gambia)',
        'en_GU' => 'enskt (Guam)',
        'en_GY' => 'enskt (Gujana)',
        'en_HK' => 'enskt (Hong Kong SAR Kina)',
        'en_IE' => 'enskt (Írland)',
        'en_IL' => 'enskt (Ísrael)',
        'en_IM' => 'enskt (Isle of Man)',
        'en_IN' => 'enskt (India)',
        'en_IO' => 'enskt (Stóra Bretlands Indiahavoyggjar)',
        'en_JE' => 'enskt (Jersey)',
        'en_JM' => 'enskt (Jamaika)',
        'en_KE' => 'enskt (Kenja)',
        'en_KI' => 'enskt (Kiribati)',
        'en_KN' => 'enskt (St. Kitts & Nevis)',
        'en_KY' => 'enskt (Caymanoyggjar)',
        'en_LC' => 'enskt (St. Lusia)',
        'en_LR' => 'enskt (Liberia)',
        'en_LS' => 'enskt (Lesoto)',
        'en_MG' => 'enskt (Madagaskar)',
        'en_MH' => 'enskt (Marshalloyggjar)',
        'en_MO' => 'enskt (Makao SAR Kina)',
        'en_MP' => 'enskt (Norðaru Mariuoyggjar)',
        'en_MS' => 'enskt (Montserrat)',
        'en_MT' => 'enskt (Malta)',
        'en_MU' => 'enskt (Móritius)',
        'en_MV' => 'enskt (Maldivoyggjar)',
        'en_MW' => 'enskt (Malavi)',
        'en_MY' => 'enskt (Malaisia)',
        'en_NA' => 'enskt (Namibia)',
        'en_NF' => 'enskt (Norfolksoyggj)',
        'en_NG' => 'enskt (Nigeria)',
        'en_NL' => 'enskt (Niðurlond)',
        'en_NR' => 'enskt (Nauru)',
        'en_NU' => 'enskt (Niue)',
        'en_NZ' => 'enskt (Nýsæland)',
        'en_PG' => 'enskt (Papua Nýguinea)',
        'en_PH' => 'enskt (Filipsoyggjar)',
        'en_PK' => 'enskt (Pakistan)',
        'en_PN' => 'enskt (Pitcairnoyggjar)',
        'en_PR' => 'enskt (Puerto Riko)',
        'en_PW' => 'enskt (Palau)',
        'en_RW' => 'enskt (Ruanda)',
        'en_SB' => 'enskt (Salomonoyggjar)',
        'en_SC' => 'enskt (Seyskelloyggjar)',
        'en_SD' => 'enskt (Sudan)',
        'en_SE' => 'enskt (Svøríki)',
        'en_SG' => 'enskt (Singapor)',
        'en_SH' => 'enskt (St. Helena)',
        'en_SI' => 'enskt (Slovenia)',
        'en_SL' => 'enskt (Sierra Leona)',
        'en_SS' => 'enskt (Suðursudan)',
        'en_SX' => 'enskt (Sint Maarten)',
        'en_SZ' => 'enskt (Esvatini)',
        'en_TC' => 'enskt (Turks- og Caicosoyggjar)',
        'en_TK' => 'enskt (Tokelau)',
        'en_TO' => 'enskt (Tonga)',
        'en_TT' => 'enskt (Trinidad & Tobago)',
        'en_TV' => 'enskt (Tuvalu)',
        'en_TZ' => 'enskt (Tansania)',
        'en_UG' => 'enskt (Uganda)',
        'en_UM' => 'enskt (Sambandsríki Amerikas fjarskotnu oyggjar)',
        'en_US' => 'enskt (Sambandsríki Amerika)',
        'en_VC' => 'enskt (St. Vinsent & Grenadinoyggjar)',
        'en_VG' => 'enskt (Stóra Bretlands Jomfrúoyggjar)',
        'en_VI' => 'enskt (Sambandsríki Amerikas Jomfrúoyggjar)',
        'en_VU' => 'enskt (Vanuatu)',
        'en_WS' => 'enskt (Samoa)',
        'en_ZA' => 'enskt (Suðurafrika)',
        'en_ZM' => 'enskt (Sambia)',
        'en_ZW' => 'enskt (Simbabvi)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (heimur)',
        'es' => 'spanskt',
        'es_419' => 'spanskt (Latínamerika)',
        'es_AR' => 'spanskt (Argentina)',
        'es_BO' => 'spanskt (Bolivia)',
        'es_BR' => 'spanskt (Brasil)',
        'es_BZ' => 'spanskt (Belis)',
        'es_CL' => 'spanskt (Kili)',
        'es_CO' => 'spanskt (Kolombia)',
        'es_CR' => 'spanskt (Kosta Rika)',
        'es_CU' => 'spanskt (Kuba)',
        'es_DO' => 'spanskt (Dominikalýðveldið)',
        'es_EC' => 'spanskt (Ekvador)',
        'es_ES' => 'spanskt (Spania)',
        'es_GQ' => 'spanskt (Ekvatorguinea)',
        'es_GT' => 'spanskt (Guatemala)',
        'es_HN' => 'spanskt (Honduras)',
        'es_MX' => 'spanskt (Meksiko)',
        'es_NI' => 'spanskt (Nikaragua)',
        'es_PA' => 'spanskt (Panama)',
        'es_PE' => 'spanskt (Peru)',
        'es_PH' => 'spanskt (Filipsoyggjar)',
        'es_PR' => 'spanskt (Puerto Riko)',
        'es_PY' => 'spanskt (Paraguai)',
        'es_SV' => 'spanskt (El Salvador)',
        'es_US' => 'spanskt (Sambandsríki Amerika)',
        'es_UY' => 'spanskt (Uruguai)',
        'es_VE' => 'spanskt (Venesuela)',
        'et' => 'estiskt',
        'et_EE' => 'estiskt (Estland)',
        'eu' => 'baskiskt',
        'eu_ES' => 'baskiskt (Spania)',
        'fa' => 'persiskt',
        'fa_AF' => 'persiskt (Afganistan)',
        'fa_IR' => 'persiskt (Iran)',
        'ff' => 'fulah',
        'ff_CM' => 'fulah (Kamerun)',
        'ff_GN' => 'fulah (Guinea)',
        'ff_Latn' => 'fulah (latínskt)',
        'ff_Latn_BF' => 'fulah (latínskt, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latínskt, Kamerun)',
        'ff_Latn_GH' => 'fulah (latínskt, Gana)',
        'ff_Latn_GM' => 'fulah (latínskt, Gambia)',
        'ff_Latn_GN' => 'fulah (latínskt, Guinea)',
        'ff_Latn_GW' => 'fulah (latínskt, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulah (latínskt, Liberia)',
        'ff_Latn_MR' => 'fulah (latínskt, Móritania)',
        'ff_Latn_NE' => 'fulah (latínskt, Niger)',
        'ff_Latn_NG' => 'fulah (latínskt, Nigeria)',
        'ff_Latn_SL' => 'fulah (latínskt, Sierra Leona)',
        'ff_Latn_SN' => 'fulah (latínskt, Senegal)',
        'ff_MR' => 'fulah (Móritania)',
        'ff_SN' => 'fulah (Senegal)',
        'fi' => 'finskt',
        'fi_FI' => 'finskt (Finnland)',
        'fo' => 'føroyskt',
        'fo_DK' => 'føroyskt (Danmark)',
        'fo_FO' => 'føroyskt (Føroyar)',
        'fr' => 'franskt',
        'fr_BE' => 'franskt (Belgia)',
        'fr_BF' => 'franskt (Burkina Faso)',
        'fr_BI' => 'franskt (Burundi)',
        'fr_BJ' => 'franskt (Benin)',
        'fr_BL' => 'franskt (St. Barthélemy)',
        'fr_CA' => 'franskt (Kanada)',
        'fr_CD' => 'franskt (Kongo, Dem. Lýðveldið)',
        'fr_CF' => 'franskt (Miðafrikalýðveldið)',
        'fr_CG' => 'franskt (Kongo)',
        'fr_CH' => 'franskt (Sveis)',
        'fr_CI' => 'franskt (Fílabeinsstrondin)',
        'fr_CM' => 'franskt (Kamerun)',
        'fr_DJ' => 'franskt (Djibuti)',
        'fr_DZ' => 'franskt (Algeria)',
        'fr_FR' => 'franskt (Frakland)',
        'fr_GA' => 'franskt (Gabon)',
        'fr_GF' => 'franskt (Franska Gujana)',
        'fr_GN' => 'franskt (Guinea)',
        'fr_GP' => 'franskt (Guadeloupe)',
        'fr_GQ' => 'franskt (Ekvatorguinea)',
        'fr_HT' => 'franskt (Haiti)',
        'fr_KM' => 'franskt (Komoroyggjar)',
        'fr_LU' => 'franskt (Luksemborg)',
        'fr_MA' => 'franskt (Marokko)',
        'fr_MC' => 'franskt (Monako)',
        'fr_MF' => 'franskt (St-Martin)',
        'fr_MG' => 'franskt (Madagaskar)',
        'fr_ML' => 'franskt (Mali)',
        'fr_MQ' => 'franskt (Martinique)',
        'fr_MR' => 'franskt (Móritania)',
        'fr_MU' => 'franskt (Móritius)',
        'fr_NC' => 'franskt (Nýkaledónia)',
        'fr_NE' => 'franskt (Niger)',
        'fr_PF' => 'franskt (Franska Polynesia)',
        'fr_PM' => 'franskt (Saint Pierre & Miquelon)',
        'fr_RE' => 'franskt (Réunion)',
        'fr_RW' => 'franskt (Ruanda)',
        'fr_SC' => 'franskt (Seyskelloyggjar)',
        'fr_SN' => 'franskt (Senegal)',
        'fr_SY' => 'franskt (Sýria)',
        'fr_TD' => 'franskt (Kjad)',
        'fr_TG' => 'franskt (Togo)',
        'fr_TN' => 'franskt (Tunesia)',
        'fr_VU' => 'franskt (Vanuatu)',
        'fr_WF' => 'franskt (Wallis- og Futunaoyggjar)',
        'fr_YT' => 'franskt (Mayotte)',
        'fy' => 'vestur frísiskt',
        'fy_NL' => 'vestur frísiskt (Niðurlond)',
        'ga' => 'írskt',
        'ga_GB' => 'írskt (Stórabretland)',
        'ga_IE' => 'írskt (Írland)',
        'gd' => 'skotskt gæliskt',
        'gd_GB' => 'skotskt gæliskt (Stórabretland)',
        'gl' => 'galisiskt',
        'gl_ES' => 'galisiskt (Spania)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'gv' => 'manx',
        'gv_IM' => 'manx (Isle of Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Gana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'hebraiskt',
        'he_IL' => 'hebraiskt (Ísrael)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latínskt)',
        'hi_Latn_IN' => 'hindi (latínskt, India)',
        'hr' => 'kroatiskt',
        'hr_BA' => 'kroatiskt (Bosnia-Hersegovina)',
        'hr_HR' => 'kroatiskt (Kroatia)',
        'hu' => 'ungarskt',
        'hu_HU' => 'ungarskt (Ungarn)',
        'hy' => 'armenskt',
        'hy_AM' => 'armenskt (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (heimur)',
        'id' => 'indonesiskt',
        'id_ID' => 'indonesiskt (Indonesia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'sichuan yi',
        'ii_CN' => 'sichuan yi (Kina)',
        'is' => 'íslendskt',
        'is_IS' => 'íslendskt (Ísland)',
        'it' => 'italskt',
        'it_CH' => 'italskt (Sveis)',
        'it_IT' => 'italskt (Italia)',
        'it_SM' => 'italskt (San Marino)',
        'it_VA' => 'italskt (Vatikanbýur)',
        'ja' => 'japanskt',
        'ja_JP' => 'japanskt (Japan)',
        'jv' => 'javanskt',
        'jv_ID' => 'javanskt (Indonesia)',
        'ka' => 'georgiskt',
        'ka_GE' => 'georgiskt (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenja)',
        'kk' => 'kazakh',
        'kk_KZ' => 'kazakh (Kasakstan)',
        'kl' => 'kalaallisut',
        'kl_GL' => 'kalaallisut (Grønland)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Kambodja)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'koreanskt',
        'ko_KP' => 'koreanskt (Norðurkorea)',
        'ko_KR' => 'koreanskt (Suðurkorea)',
        'ks' => 'kashmiri',
        'ks_Arab' => 'kashmiri (arabisk)',
        'ks_Arab_IN' => 'kashmiri (arabisk, India)',
        'ks_Deva' => 'kashmiri (devanagari)',
        'ks_Deva_IN' => 'kashmiri (devanagari, India)',
        'ks_IN' => 'kashmiri (India)',
        'ku' => 'kurdiskt',
        'ku_TR' => 'kurdiskt (Turkaland)',
        'kw' => 'corniskt',
        'kw_GB' => 'corniskt (Stórabretland)',
        'ky' => 'kyrgyz',
        'ky_KG' => 'kyrgyz (Kirgisia)',
        'lb' => 'luksemborgskt',
        'lb_LU' => 'luksemborgskt (Luksemborg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo, Dem. Lýðveldið)',
        'ln_CF' => 'lingala (Miðafrikalýðveldið)',
        'ln_CG' => 'lingala (Kongo)',
        'lo' => 'laoskt',
        'lo_LA' => 'laoskt (Laos)',
        'lt' => 'litaviskt',
        'lt_LT' => 'litaviskt (Litava)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Kongo, Dem. Lýðveldið)',
        'lv' => 'lettiskt',
        'lv_LV' => 'lettiskt (Lettland)',
        'mg' => 'malagassiskt',
        'mg_MG' => 'malagassiskt (Madagaskar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nýsæland)',
        'mk' => 'makedónskt',
        'mk_MK' => 'makedónskt (Norður Makedónia)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (India)',
        'mn' => 'mongolskt',
        'mn_MN' => 'mongolskt (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malaiiskt',
        'ms_BN' => 'malaiiskt (Brunei)',
        'ms_ID' => 'malaiiskt (Indonesia)',
        'ms_MY' => 'malaiiskt (Malaisia)',
        'ms_SG' => 'malaiiskt (Singapor)',
        'mt' => 'maltiskt',
        'mt_MT' => 'maltiskt (Malta)',
        'my' => 'burmesiskt',
        'my_MM' => 'burmesiskt (Myanmar [Burma])',
        'nb' => 'norskt bókmál',
        'nb_NO' => 'norskt bókmál (Noreg)',
        'nb_SJ' => 'norskt bókmál (Svalbard & Jan Mayen)',
        'nd' => 'norður ndebele',
        'nd_ZW' => 'norður ndebele (Simbabvi)',
        'ne' => 'nepalskt',
        'ne_IN' => 'nepalskt (India)',
        'ne_NP' => 'nepalskt (Nepal)',
        'nl' => 'hálendskt',
        'nl_AW' => 'hálendskt (Aruba)',
        'nl_BE' => 'hálendskt (Belgia)',
        'nl_BQ' => 'hálendskt (Niðurlonds Karibia)',
        'nl_CW' => 'hálendskt (Curaçao)',
        'nl_NL' => 'hálendskt (Niðurlond)',
        'nl_SR' => 'hálendskt (Surinam)',
        'nl_SX' => 'hálendskt (Sint Maarten)',
        'nn' => 'nýnorskt',
        'nn_NO' => 'nýnorskt (Noreg)',
        'no' => 'norskt',
        'no_NO' => 'norskt (Noreg)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopia)',
        'om_KE' => 'oromo (Kenja)',
        'or' => 'odia',
        'or_IN' => 'odia (India)',
        'os' => 'ossetiskt',
        'os_GE' => 'ossetiskt (Georgia)',
        'os_RU' => 'ossetiskt (Russland)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (arabisk)',
        'pa_Arab_PK' => 'punjabi (arabisk, Pakistan)',
        'pa_Guru' => 'punjabi (gurmukhi)',
        'pa_Guru_IN' => 'punjabi (gurmukhi, India)',
        'pa_IN' => 'punjabi (India)',
        'pa_PK' => 'punjabi (Pakistan)',
        'pl' => 'pólskt',
        'pl_PL' => 'pólskt (Pólland)',
        'ps' => 'pashto',
        'ps_AF' => 'pashto (Afganistan)',
        'ps_PK' => 'pashto (Pakistan)',
        'pt' => 'portugiskiskt',
        'pt_AO' => 'portugiskiskt (Angola)',
        'pt_BR' => 'portugiskiskt (Brasil)',
        'pt_CH' => 'portugiskiskt (Sveis)',
        'pt_CV' => 'portugiskiskt (Grønhøvdaoyggjar)',
        'pt_GQ' => 'portugiskiskt (Ekvatorguinea)',
        'pt_GW' => 'portugiskiskt (Guinea-Bissau)',
        'pt_LU' => 'portugiskiskt (Luksemborg)',
        'pt_MO' => 'portugiskiskt (Makao SAR Kina)',
        'pt_MZ' => 'portugiskiskt (Mosambik)',
        'pt_PT' => 'portugiskiskt (Portugal)',
        'pt_ST' => 'portugiskiskt (Sao Tome & Prinsipi)',
        'pt_TL' => 'portugiskiskt (Eysturtimor)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ekvador)',
        'qu_PE' => 'quechua (Peru)',
        'rm' => 'retoromanskt',
        'rm_CH' => 'retoromanskt (Sveis)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumenskt',
        'ro_MD' => 'rumenskt (Moldova)',
        'ro_RO' => 'rumenskt (Rumenia)',
        'ru' => 'russiskt',
        'ru_BY' => 'russiskt (Hvítarussland)',
        'ru_KG' => 'russiskt (Kirgisia)',
        'ru_KZ' => 'russiskt (Kasakstan)',
        'ru_MD' => 'russiskt (Moldova)',
        'ru_RU' => 'russiskt (Russland)',
        'ru_UA' => 'russiskt (Ukraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Ruanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (India)',
        'sc' => 'sardiskt',
        'sc_IT' => 'sardiskt (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabisk)',
        'sd_Arab_PK' => 'sindhi (arabisk, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'norður sámiskt',
        'se_FI' => 'norður sámiskt (Finnland)',
        'se_NO' => 'norður sámiskt (Noreg)',
        'se_SE' => 'norður sámiskt (Svøríki)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Miðafrikalýðveldið)',
        'sh' => 'serbokroatiskt',
        'sh_BA' => 'serbokroatiskt (Bosnia-Hersegovina)',
        'si' => 'singalesiskt',
        'si_LK' => 'singalesiskt (Sri Lanka)',
        'sk' => 'slovakiskt',
        'sk_SK' => 'slovakiskt (Slovakia)',
        'sl' => 'slovenskt',
        'sl_SI' => 'slovenskt (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Simbabvi)',
        'so' => 'somaliskt',
        'so_DJ' => 'somaliskt (Djibuti)',
        'so_ET' => 'somaliskt (Etiopia)',
        'so_KE' => 'somaliskt (Kenja)',
        'so_SO' => 'somaliskt (Somalia)',
        'sq' => 'albanskt',
        'sq_AL' => 'albanskt (Albania)',
        'sq_MK' => 'albanskt (Norður Makedónia)',
        'sr' => 'serbiskt',
        'sr_BA' => 'serbiskt (Bosnia-Hersegovina)',
        'sr_Cyrl' => 'serbiskt (kyrilliskt)',
        'sr_Cyrl_BA' => 'serbiskt (kyrilliskt, Bosnia-Hersegovina)',
        'sr_Cyrl_ME' => 'serbiskt (kyrilliskt, Montenegro)',
        'sr_Cyrl_RS' => 'serbiskt (kyrilliskt, Serbia)',
        'sr_Latn' => 'serbiskt (latínskt)',
        'sr_Latn_BA' => 'serbiskt (latínskt, Bosnia-Hersegovina)',
        'sr_Latn_ME' => 'serbiskt (latínskt, Montenegro)',
        'sr_Latn_RS' => 'serbiskt (latínskt, Serbia)',
        'sr_ME' => 'serbiskt (Montenegro)',
        'sr_RS' => 'serbiskt (Serbia)',
        'su' => 'sundanesiskt',
        'su_ID' => 'sundanesiskt (Indonesia)',
        'su_Latn' => 'sundanesiskt (latínskt)',
        'su_Latn_ID' => 'sundanesiskt (latínskt, Indonesia)',
        'sv' => 'svenskt',
        'sv_AX' => 'svenskt (Áland)',
        'sv_FI' => 'svenskt (Finnland)',
        'sv_SE' => 'svenskt (Svøríki)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Kongo, Dem. Lýðveldið)',
        'sw_KE' => 'swahili (Kenja)',
        'sw_TZ' => 'swahili (Tansania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamilskt',
        'ta_IN' => 'tamilskt (India)',
        'ta_LK' => 'tamilskt (Sri Lanka)',
        'ta_MY' => 'tamilskt (Malaisia)',
        'ta_SG' => 'tamilskt (Singapor)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tajik',
        'tg_TJ' => 'tajik (Tadsjikistan)',
        'th' => 'tailendskt',
        'th_TH' => 'tailendskt (Tailand)',
        'ti' => 'tigrinya',
        'ti_ER' => 'tigrinya (Eritrea)',
        'ti_ET' => 'tigrinya (Etiopia)',
        'tk' => 'turkmenskt',
        'tk_TM' => 'turkmenskt (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filipsoyggjar)',
        'to' => 'tonganskt',
        'to_TO' => 'tonganskt (Tonga)',
        'tr' => 'turkiskt',
        'tr_CY' => 'turkiskt (Kýpros)',
        'tr_TR' => 'turkiskt (Turkaland)',
        'tt' => 'tatar',
        'tt_RU' => 'tatar (Russland)',
        'ug' => 'uyghur',
        'ug_CN' => 'uyghur (Kina)',
        'uk' => 'ukrainskt',
        'uk_UA' => 'ukrainskt (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'usbekiskt',
        'uz_AF' => 'usbekiskt (Afganistan)',
        'uz_Arab' => 'usbekiskt (arabisk)',
        'uz_Arab_AF' => 'usbekiskt (arabisk, Afganistan)',
        'uz_Cyrl' => 'usbekiskt (kyrilliskt)',
        'uz_Cyrl_UZ' => 'usbekiskt (kyrilliskt, Usbekistan)',
        'uz_Latn' => 'usbekiskt (latínskt)',
        'uz_Latn_UZ' => 'usbekiskt (latínskt, Usbekistan)',
        'uz_UZ' => 'usbekiskt (Usbekistan)',
        'vi' => 'vjetnamesiskt',
        'vi_VN' => 'vjetnamesiskt (Vjetnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Suðurafrika)',
        'yi' => 'jiddiskt',
        'yi_001' => 'jiddiskt (heimur)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'zh' => 'kinesiskt',
        'zh_CN' => 'kinesiskt (Kina)',
        'zh_HK' => 'kinesiskt (Hong Kong SAR Kina)',
        'zh_Hans' => 'kinesiskt (einkult)',
        'zh_Hans_CN' => 'kinesiskt (einkult, Kina)',
        'zh_Hans_HK' => 'kinesiskt (einkult, Hong Kong SAR Kina)',
        'zh_Hans_MO' => 'kinesiskt (einkult, Makao SAR Kina)',
        'zh_Hans_SG' => 'kinesiskt (einkult, Singapor)',
        'zh_Hant' => 'kinesiskt (vanligt)',
        'zh_Hant_HK' => 'kinesiskt (vanligt, Hong Kong SAR Kina)',
        'zh_Hant_MO' => 'kinesiskt (vanligt, Makao SAR Kina)',
        'zh_Hant_TW' => 'kinesiskt (vanligt, Taivan)',
        'zh_MO' => 'kinesiskt (Makao SAR Kina)',
        'zh_SG' => 'kinesiskt (Singapor)',
        'zh_TW' => 'kinesiskt (Taivan)',
        'zu' => 'sulu',
        'zu_ZA' => 'sulu (Suðurafrika)',
    ],
];
