<?php

return [
    'Names' => [
        'Asia/Brunei' => 'Brunei-Zeit',
        'Asia/Macau' => 'Chinesische Zeit (Macao)',
        'Europe/Saratov' => 'Moskauer Zeit (Saratov)',
        'Pacific/Guadalcanal' => 'Salomoninseln-Zeit (Guadalcanal)',
    ],
    'Meta' => [
    ],
];
