<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Amzer keitat Greenwich (AKG) (Abidjan)',
        'Africa/Accra' => 'Amzer keitat Greenwich (AKG) (Accra)',
        'Africa/Addis_Ababa' => 'eur Afrika ar Reter (Adis Abeba)',
        'Africa/Algiers' => 'eur Kreizeuropa (Aljer)',
        'Africa/Asmera' => 'eur Afrika ar Reter (Asmara)',
        'Africa/Bamako' => 'Amzer keitat Greenwich (AKG) (Bamako)',
        'Africa/Bangui' => 'eur Afrika ar Cʼhornôg (Bangui)',
        'Africa/Banjul' => 'Amzer keitat Greenwich (AKG) (Banjul)',
        'Africa/Bissau' => 'Amzer keitat Greenwich (AKG) (Bissau)',
        'Africa/Blantyre' => 'eur Kreizafrika (Blantyre)',
        'Africa/Brazzaville' => 'eur Afrika ar Cʼhornôg (Brazzaville)',
        'Africa/Bujumbura' => 'eur Kreizafrika (Bujumbura)',
        'Africa/Cairo' => 'eur Europa ar Reter (Kaero)',
        'Africa/Casablanca' => 'eur Europa ar Cʼhornôg (Dar el Beida (Casablanca))',
        'Africa/Ceuta' => 'eur Kreizeuropa (Ceuta)',
        'Africa/Conakry' => 'Amzer keitat Greenwich (AKG) (Conakry)',
        'Africa/Dakar' => 'Amzer keitat Greenwich (AKG) (Dakar)',
        'Africa/Dar_es_Salaam' => 'eur Afrika ar Reter (Dar es Salaam)',
        'Africa/Djibouti' => 'eur Afrika ar Reter (Djibouti)',
        'Africa/Douala' => 'eur Afrika ar Cʼhornôg (Douala)',
        'Africa/El_Aaiun' => 'eur Europa ar Cʼhornôg (LaʼYoun)',
        'Africa/Freetown' => 'Amzer keitat Greenwich (AKG) (Freetown)',
        'Africa/Gaborone' => 'eur Kreizafrika (Gaborone)',
        'Africa/Harare' => 'eur Kreizafrika (Harare)',
        'Africa/Johannesburg' => 'eur cʼhoañv Suafrika (Johannesburg)',
        'Africa/Juba' => 'eur Kreizafrika (Juba)',
        'Africa/Kampala' => 'eur Afrika ar Reter (Kampala)',
        'Africa/Khartoum' => 'eur Kreizafrika (Khartoum)',
        'Africa/Kigali' => 'eur Kreizafrika (Kigali)',
        'Africa/Kinshasa' => 'eur Afrika ar Cʼhornôg (Kinshasa)',
        'Africa/Lagos' => 'eur Afrika ar Cʼhornôg (Lagos)',
        'Africa/Libreville' => 'eur Afrika ar Cʼhornôg (Libreville)',
        'Africa/Lome' => 'Amzer keitat Greenwich (AKG) (Lomé)',
        'Africa/Luanda' => 'eur Afrika ar Cʼhornôg (Luanda)',
        'Africa/Lubumbashi' => 'eur Kreizafrika (Lubumbashi)',
        'Africa/Lusaka' => 'eur Kreizafrika (Lusaka)',
        'Africa/Malabo' => 'eur Afrika ar Cʼhornôg (Malabo)',
        'Africa/Maputo' => 'eur Kreizafrika (Maputo)',
        'Africa/Maseru' => 'eur cʼhoañv Suafrika (Maseru)',
        'Africa/Mbabane' => 'eur cʼhoañv Suafrika (Mbabane)',
        'Africa/Mogadishu' => 'eur Afrika ar Reter (Muqdisho)',
        'Africa/Monrovia' => 'Amzer keitat Greenwich (AKG) (Monrovia)',
        'Africa/Nairobi' => 'eur Afrika ar Reter (Nairobi)',
        'Africa/Ndjamena' => 'eur Afrika ar Cʼhornôg (NʼDjamena)',
        'Africa/Niamey' => 'eur Afrika ar Cʼhornôg (Niamey)',
        'Africa/Nouakchott' => 'Amzer keitat Greenwich (AKG) (Nouakchott)',
        'Africa/Ouagadougou' => 'Amzer keitat Greenwich (AKG) (Ouagadougou)',
        'Africa/Porto-Novo' => 'eur Afrika ar Cʼhornôg (Porto-Novo)',
        'Africa/Sao_Tome' => 'Amzer keitat Greenwich (AKG) (São Tomé)',
        'Africa/Tripoli' => 'eur Europa ar Reter (Tarabulus (Tripoli))',
        'Africa/Tunis' => 'eur Kreizeuropa (Tuniz)',
        'Africa/Windhoek' => 'eur Kreizafrika (Windhoek)',
        'America/Adak' => 'eur Hawaii hag an Aleouted (Adak)',
        'America/Anchorage' => 'eur Alaska (Anchorage)',
        'America/Anguilla' => 'eur an Atlantel (Anguilla)',
        'America/Antigua' => 'eur an Atlantel (Antigua)',
        'America/Araguaina' => 'eur Brasília (Araguaina)',
        'America/Argentina/La_Rioja' => 'eur Arcʼhantina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'eur Arcʼhantina (Rio Gallegos)',
        'America/Argentina/Salta' => 'eur Arcʼhantina (Salta)',
        'America/Argentina/San_Juan' => 'eur Arcʼhantina (San Juan)',
        'America/Argentina/San_Luis' => 'eur Arcʼhantina (San Luis)',
        'America/Argentina/Tucuman' => 'eur Arcʼhantina (Tucuman)',
        'America/Argentina/Ushuaia' => 'eur Arcʼhantina (Ushuaia)',
        'America/Aruba' => 'eur an Atlantel (Aruba)',
        'America/Asuncion' => 'eur Paraguay (Asunción)',
        'America/Bahia' => 'eur Brasília (Bahia)',
        'America/Bahia_Banderas' => 'eur ar Cʼhreiz (Bahia Banderas)',
        'America/Barbados' => 'eur an Atlantel (Barbados)',
        'America/Belem' => 'eur Brasília (Belém)',
        'America/Belize' => 'eur ar Cʼhreiz (Belize)',
        'America/Blanc-Sablon' => 'eur an Atlantel (Blanc-Sablon)',
        'America/Boa_Vista' => 'eur an Amazon (Boa Vista)',
        'America/Bogota' => 'eur Kolombia (Bogotá)',
        'America/Boise' => 'eur ar Menezioù (Boise)',
        'America/Buenos_Aires' => 'eur Arcʼhantina (Buenos Aires)',
        'America/Cambridge_Bay' => 'eur ar Menezioù (Cambridge Bay)',
        'America/Campo_Grande' => 'eur an Amazon (Campo Grande)',
        'America/Cancun' => 'eur ar Reter (Cancun)',
        'America/Caracas' => 'eur Venezuela (Caracas)',
        'America/Catamarca' => 'eur Arcʼhantina (Catamarca)',
        'America/Cayenne' => 'eur Gwiana cʼhall (Cayenne)',
        'America/Cayman' => 'eur ar Reter (Cayman)',
        'America/Chicago' => 'eur ar Cʼhreiz (Chicago)',
        'America/Chihuahua' => 'eur an Habask mecʼhikan (Chihuahua)',
        'America/Coral_Harbour' => 'eur ar Reter (Atikokan)',
        'America/Cordoba' => 'eur Arcʼhantina (Cordoba)',
        'America/Costa_Rica' => 'eur ar Cʼhreiz (Costa Rica)',
        'America/Creston' => 'eur ar Menezioù (Creston)',
        'America/Cuiaba' => 'eur an Amazon (Cuiaba)',
        'America/Curacao' => 'eur an Atlantel (Curacao)',
        'America/Danmarkshavn' => 'Amzer keitat Greenwich (AKG) (Danmarkshavn)',
        'America/Dawson' => 'eur Kanada (Dawson)',
        'America/Dawson_Creek' => 'eur ar Menezioù (Dawson Creek)',
        'America/Denver' => 'eur ar Menezioù (Denver)',
        'America/Detroit' => 'eur ar Reter (Detroit)',
        'America/Dominica' => 'eur an Atlantel (Dominica)',
        'America/Edmonton' => 'eur ar Menezioù (Edmonton)',
        'America/Eirunepe' => 'eur Brazil (Eirunepe)',
        'America/El_Salvador' => 'eur ar Cʼhreiz (Salvador)',
        'America/Fort_Nelson' => 'eur ar Menezioù (Fort Nelson)',
        'America/Fortaleza' => 'eur Brasília (Fortaleza)',
        'America/Glace_Bay' => 'eur an Atlantel (Glace Bay)',
        'America/Godthab' => 'eur Greunland ar Cʼhornôg (Nuuk (Godthåb))',
        'America/Goose_Bay' => 'eur an Atlantel (Goose Bay)',
        'America/Grand_Turk' => 'eur ar Reter (Grand Turk)',
        'America/Grenada' => 'eur an Atlantel (Grenada)',
        'America/Guadeloupe' => 'eur an Atlantel (Gwadeloup)',
        'America/Guatemala' => 'eur ar Cʼhreiz (Guatemala)',
        'America/Guayaquil' => 'eur Ecuador (Guayaquil)',
        'America/Guyana' => 'eur Guyana',
        'America/Halifax' => 'eur an Atlantel (Halifax)',
        'America/Havana' => 'eur Kuba (La Habana)',
        'America/Hermosillo' => 'eur an Habask mecʼhikan (Hermosillo)',
        'America/Indiana/Knox' => 'eur ar Cʼhreiz (Knox, Indiana)',
        'America/Indiana/Marengo' => 'eur ar Reter (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'eur ar Reter (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'eur ar Cʼhreiz (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'eur ar Reter (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'eur ar Reter (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'eur ar Reter (Winamac, Indiana)',
        'America/Indianapolis' => 'eur ar Reter (Indianapolis)',
        'America/Inuvik' => 'eur ar Menezioù (Inuvik)',
        'America/Iqaluit' => 'eur ar Reter (Iqaluit)',
        'America/Jamaica' => 'eur ar Reter (Jamaika)',
        'America/Jujuy' => 'eur Arcʼhantina (Jujuy)',
        'America/Juneau' => 'eur Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'eur ar Reter (Monticello, Kentucky)',
        'America/Kralendijk' => 'eur an Atlantel (Kralendijk)',
        'America/La_Paz' => 'eur Bolivia (La Paz)',
        'America/Lima' => 'eur Perou (Lima)',
        'America/Los_Angeles' => 'eur an Habask (Los Angeles)',
        'America/Louisville' => 'eur ar Reter (Louisville)',
        'America/Lower_Princes' => 'eur an Atlantel (Lower Prince’s Quarter)',
        'America/Maceio' => 'eur Brasília (Maceio)',
        'America/Managua' => 'eur ar Cʼhreiz (Managua)',
        'America/Manaus' => 'eur an Amazon (Manaus)',
        'America/Marigot' => 'eur an Atlantel (Marigot)',
        'America/Martinique' => 'eur an Atlantel (Martinik)',
        'America/Matamoros' => 'eur ar Cʼhreiz (Matamoros)',
        'America/Mazatlan' => 'eur an Habask mecʼhikan (Mazatlan)',
        'America/Mendoza' => 'eur Arcʼhantina (Mendoza)',
        'America/Menominee' => 'eur ar Cʼhreiz (Menominee)',
        'America/Merida' => 'eur ar Cʼhreiz (Merida)',
        'America/Metlakatla' => 'eur Alaska (Metlakatla)',
        'America/Mexico_City' => 'eur ar Cʼhreiz (Kêr Vecʼhiko)',
        'America/Miquelon' => 'eur Sant-Pêr-ha-Mikelon',
        'America/Moncton' => 'eur an Atlantel (Moncton)',
        'America/Monterrey' => 'eur ar Cʼhreiz (Monterrey)',
        'America/Montevideo' => 'eur Uruguay (Montevideo)',
        'America/Montreal' => 'eur Kanada (Montreal)',
        'America/Montserrat' => 'eur an Atlantel (Montserrat)',
        'America/Nassau' => 'eur ar Reter (Nassau)',
        'America/New_York' => 'eur ar Reter (New York)',
        'America/Nipigon' => 'eur ar Reter (Nipigon)',
        'America/Nome' => 'eur Alaska (Nome)',
        'America/Noronha' => 'eur Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'eur ar Cʼhreiz (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'eur ar Cʼhreiz (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'eur ar Cʼhreiz (New Salem, North Dakota)',
        'America/Ojinaga' => 'eur ar Menezioù (Ojinaga)',
        'America/Panama' => 'eur ar Reter (Panamá)',
        'America/Pangnirtung' => 'eur ar Reter (Pangnirtung)',
        'America/Paramaribo' => 'eur Surinam (Paramaribo)',
        'America/Phoenix' => 'eur ar Menezioù (Phoenix)',
        'America/Port-au-Prince' => 'eur ar Reter (Port-au-Prince)',
        'America/Port_of_Spain' => 'eur an Atlantel (Port of Spain)',
        'America/Porto_Velho' => 'eur an Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'eur an Atlantel (Puerto Rico)',
        'America/Punta_Arenas' => 'eur Chile (Punta Arenas)',
        'America/Rainy_River' => 'eur ar Cʼhreiz (Rainy River)',
        'America/Rankin_Inlet' => 'eur ar Cʼhreiz (Rankin Inlet)',
        'America/Recife' => 'eur Brasília (Recife)',
        'America/Regina' => 'eur ar Cʼhreiz (Regina)',
        'America/Resolute' => 'eur ar Cʼhreiz (Resolute)',
        'America/Rio_Branco' => 'eur Brazil (Rio Branco)',
        'America/Santa_Isabel' => 'eur Gwalarn Mecʼhiko (Santa Isabel)',
        'America/Santarem' => 'eur Brasília (Santarem)',
        'America/Santiago' => 'eur Chile (Santiago)',
        'America/Santo_Domingo' => 'eur an Atlantel (Santo Domingo)',
        'America/Sao_Paulo' => 'eur Brasília (São Paulo)',
        'America/Scoresbysund' => 'eur Greunland ar Reter (Ittoqqortoormiit)',
        'America/Sitka' => 'eur Alaska (Sitka)',
        'America/St_Barthelemy' => 'eur an Atlantel (Saint Barthélemy)',
        'America/St_Johns' => 'eur Newfoundland (Saint Johnʼs)',
        'America/St_Kitts' => 'eur an Atlantel (Saint Kitts)',
        'America/St_Lucia' => 'eur an Atlantel (Saint Lucia)',
        'America/St_Thomas' => 'eur an Atlantel (St. Thomas)',
        'America/St_Vincent' => 'eur an Atlantel (Sant Visant)',
        'America/Swift_Current' => 'eur ar Cʼhreiz (Swift Current)',
        'America/Tegucigalpa' => 'eur ar Cʼhreiz (Tegucigalpa)',
        'America/Thule' => 'eur an Atlantel (Qânâq)',
        'America/Thunder_Bay' => 'eur ar Reter (Thunder Bay)',
        'America/Tijuana' => 'eur an Habask (Tijuana)',
        'America/Toronto' => 'eur ar Reter (Toronto)',
        'America/Tortola' => 'eur an Atlantel (Tortola)',
        'America/Vancouver' => 'eur an Habask (Vancouver)',
        'America/Whitehorse' => 'eur Kanada (Whitehorse)',
        'America/Winnipeg' => 'eur ar Cʼhreiz (Winnipeg)',
        'America/Yakutat' => 'eur Alaska (Yakutat)',
        'America/Yellowknife' => 'eur ar Menezioù (Yellowknife)',
        'Antarctica/Casey' => 'eur Antarktika (Casey)',
        'Antarctica/Davis' => 'eur Davis',
        'Antarctica/DumontDUrville' => 'eur Dumont-d’Urville',
        'Antarctica/Macquarie' => 'eur Aostralia ar Reter (Macquarie)',
        'Antarctica/Mawson' => 'eur Mawson',
        'Antarctica/McMurdo' => 'eur Zeland-Nevez (McMurdo)',
        'Antarctica/Palmer' => 'eur Chile (Palmer)',
        'Antarctica/Rothera' => 'eur Rothera',
        'Antarctica/Syowa' => 'eur Syowa',
        'Antarctica/Troll' => 'Amzer keitat Greenwich (AKG) (Troll)',
        'Antarctica/Vostok' => 'eur Vostok',
        'Arctic/Longyearbyen' => 'eur Kreizeuropa (Longyearbyen)',
        'Asia/Aden' => 'eur Arabia (Aden)',
        'Asia/Almaty' => 'eur Kazakstan ar Reter (Almaty)',
        'Asia/Amman' => 'eur Europa ar Reter (Amman)',
        'Asia/Anadyr' => 'eur Anadyrʼ',
        'Asia/Aqtau' => 'eur Kazakstan ar Cʼhornôg (Aqtau)',
        'Asia/Aqtobe' => 'eur Kazakstan ar Cʼhornôg (Aqtobe)',
        'Asia/Ashgabat' => 'eur Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'eur Kazakstan ar Cʼhornôg (Atyrau)',
        'Asia/Baghdad' => 'eur Arabia (Baghdad)',
        'Asia/Bahrain' => 'eur Arabia (Bahrein)',
        'Asia/Baku' => 'eur Azerbaidjan (Bakou)',
        'Asia/Bangkok' => 'eur Indez-Sina (Bangkok)',
        'Asia/Barnaul' => 'eur Rusia (Barnaul)',
        'Asia/Beirut' => 'eur Europa ar Reter (Bayrut)',
        'Asia/Bishkek' => 'eur Kyrgyzstan (Bishkek)',
        'Asia/Brunei' => 'eur Brunei Darussalam',
        'Asia/Calcutta' => 'eur cʼhoañv India (Calcutta)',
        'Asia/Chita' => 'eur Yakutsk (Tchita)',
        'Asia/Choibalsan' => 'eur Ulaanbaatar (Choibalsan)',
        'Asia/Colombo' => 'eur cʼhoañv India (Kolamba)',
        'Asia/Damascus' => 'eur Europa ar Reter (Damask)',
        'Asia/Dhaka' => 'eur Bangladesh (Dhaka)',
        'Asia/Dili' => 'eur Timor ar Reter (Dili)',
        'Asia/Dubai' => 'eur cʼhoañv ar Pleg-mor Arab-ha-Pers (Dubai)',
        'Asia/Dushanbe' => 'eur Tadjikistan (Dushanbe)',
        'Asia/Famagusta' => 'eur Europa ar Reter (Famagusta)',
        'Asia/Gaza' => 'eur Europa ar Reter (Gaza)',
        'Asia/Hebron' => 'eur Europa ar Reter (Hebron)',
        'Asia/Hong_Kong' => 'eur Hong Kong',
        'Asia/Hovd' => 'eur Hovd',
        'Asia/Irkutsk' => 'eur Irkutsk',
        'Asia/Jakarta' => 'eur Indonezia ar Cʼhornôg (Jakarta)',
        'Asia/Jayapura' => 'eur Indonezia ar Reter (Jayapura)',
        'Asia/Jerusalem' => 'eur Israel (Jeruzalem)',
        'Asia/Kabul' => 'eur Afghanistan (Kaboul)',
        'Asia/Kamchatka' => 'eur Rusia (Kamtchatka)',
        'Asia/Karachi' => 'eur Pakistan (Karachi)',
        'Asia/Katmandu' => 'eur Nepal (Kathmandu)',
        'Asia/Khandyga' => 'eur Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'eur Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'eur Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'eur Malaysia (Kuching)',
        'Asia/Kuwait' => 'eur Arabia (Koweit)',
        'Asia/Macau' => 'eur Sina (Macau)',
        'Asia/Magadan' => 'eur Magadan',
        'Asia/Makassar' => 'eur Kreiz Indonezia (Makassar)',
        'Asia/Manila' => 'eur ar Filipinez (Manila)',
        'Asia/Muscat' => 'eur cʼhoañv ar Pleg-mor Arab-ha-Pers (Masqat)',
        'Asia/Nicosia' => 'eur Europa ar Reter (Levkosía)',
        'Asia/Novokuznetsk' => 'eur Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'eur Novosibirsk',
        'Asia/Omsk' => 'eur Omsk',
        'Asia/Oral' => 'eur Kazakstan ar Cʼhornôg (Oral)',
        'Asia/Phnom_Penh' => 'eur Indez-Sina (Phnum Pénh)',
        'Asia/Pontianak' => 'eur Indonezia ar Cʼhornôg (Pontianak)',
        'Asia/Pyongyang' => 'eur Korea (Pʼyongyang)',
        'Asia/Qatar' => 'eur Arabia (Qatar)',
        'Asia/Qostanay' => 'eur Kazakstan ar Reter (Qostanay)',
        'Asia/Qyzylorda' => 'eur Kazakstan ar Cʼhornôg (Qyzylorda)',
        'Asia/Rangoon' => 'eur Myanmar (Yangon)',
        'Asia/Riyadh' => 'eur Arabia (Riyadh)',
        'Asia/Saigon' => 'eur Indez-Sina (Kêr Hô-Chi-Minh)',
        'Asia/Sakhalin' => 'eur Sakhalin',
        'Asia/Samarkand' => 'eur Ouzbekistan (Samarkand)',
        'Asia/Seoul' => 'eur Korea (Seoul)',
        'Asia/Shanghai' => 'eur Sina (Shanghai)',
        'Asia/Singapore' => 'eur cʼhoañv Singapour',
        'Asia/Srednekolymsk' => 'eur Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'eur Taipei',
        'Asia/Tashkent' => 'eur Ouzbekistan (Toshkent)',
        'Asia/Tbilisi' => 'eur Jorjia (Tbilisi)',
        'Asia/Tehran' => 'eur Iran (Tehran)',
        'Asia/Thimphu' => 'eur Bhoutan (Thimphu)',
        'Asia/Tokyo' => 'eur Japan (Tokyo)',
        'Asia/Tomsk' => 'eur Rusia (Tomsk)',
        'Asia/Ulaanbaatar' => 'eur Ulaanbaatar',
        'Asia/Urumqi' => 'eur Sina (Ürümqi)',
        'Asia/Ust-Nera' => 'eur Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'eur Indez-Sina (Viangchan)',
        'Asia/Vladivostok' => 'eur Vladivostok',
        'Asia/Yakutsk' => 'eur Yakutsk',
        'Asia/Yekaterinburg' => 'eur Yekaterinbourg',
        'Asia/Yerevan' => 'eur Armenia (Yerevan)',
        'Atlantic/Azores' => 'eur an Azorez',
        'Atlantic/Bermuda' => 'eur an Atlantel (Bermudez)',
        'Atlantic/Canary' => 'eur Europa ar Cʼhornôg (Kanariez)',
        'Atlantic/Cape_Verde' => 'eur ar Cʼhab-Glas (Kab Glas)',
        'Atlantic/Faeroe' => 'eur Europa ar Cʼhornôg (Faero)',
        'Atlantic/Madeira' => 'eur Europa ar Cʼhornôg (Madeira)',
        'Atlantic/Reykjavik' => 'Amzer keitat Greenwich (AKG) (Reykjavík)',
        'Atlantic/South_Georgia' => 'eur Georgia ar Su',
        'Atlantic/St_Helena' => 'Amzer keitat Greenwich (AKG) (Saint Helena)',
        'Atlantic/Stanley' => 'eur Inizi Falkland (Stanley)',
        'Australia/Adelaide' => 'eur Kreizaostralia (Adelaide)',
        'Australia/Brisbane' => 'eur Aostralia ar Reter (Brisbane)',
        'Australia/Broken_Hill' => 'eur Kreizaostralia (Broken Hill)',
        'Australia/Currie' => 'eur Aostralia ar Reter (Currie)',
        'Australia/Darwin' => 'eur Kreizaostralia (Darwin)',
        'Australia/Eucla' => 'eur Kreizaostralia ar Cʼhornôg (Eucla)',
        'Australia/Hobart' => 'eur Aostralia ar Reter (Hobart)',
        'Australia/Lindeman' => 'eur Aostralia ar Reter (Lindeman)',
        'Australia/Lord_Howe' => 'eur Lord Howe',
        'Australia/Melbourne' => 'eur Aostralia ar Reter (Melbourne)',
        'Australia/Perth' => 'eur Aostralia ar Cʼhornôg (Perth)',
        'Australia/Sydney' => 'eur Aostralia ar Reter (Sydney)',
        'CST6CDT' => 'eur ar Cʼhreiz',
        'EST5EDT' => 'eur ar Reter',
        'Etc/GMT' => 'Amzer keitat Greenwich (AKG)',
        'Etc/UTC' => 'amzer hollvedel kenurzhiet',
        'Europe/Amsterdam' => 'eur Kreizeuropa (Amsterdam)',
        'Europe/Andorra' => 'eur Kreizeuropa (Andorra)',
        'Europe/Astrakhan' => 'eur Moskov (Astrakhan)',
        'Europe/Athens' => 'eur Europa ar Reter (Aten)',
        'Europe/Belgrade' => 'eur Kreizeuropa (Beograd)',
        'Europe/Berlin' => 'eur Kreizeuropa (Berlin)',
        'Europe/Bratislava' => 'eur Kreizeuropa (Bratislava)',
        'Europe/Brussels' => 'eur Kreizeuropa (Brusel)',
        'Europe/Bucharest' => 'eur Europa ar Reter (Bukarest)',
        'Europe/Budapest' => 'eur Kreizeuropa (Budapest)',
        'Europe/Busingen' => 'eur Kreizeuropa (Busingen)',
        'Europe/Chisinau' => 'eur Europa ar Reter (Chisinau)',
        'Europe/Copenhagen' => 'eur Kreizeuropa (Kopenhagen)',
        'Europe/Dublin' => 'Amzer keitat Greenwich (AKG) (Dulenn)',
        'Europe/Gibraltar' => 'eur Kreizeuropa (Jibraltar)',
        'Europe/Guernsey' => 'Amzer keitat Greenwich (AKG) (Gwernenez)',
        'Europe/Helsinki' => 'eur Europa ar Reter (Helsinki)',
        'Europe/Isle_of_Man' => 'Amzer keitat Greenwich (AKG) (Manav)',
        'Europe/Istanbul' => 'eur Turkia (Istanbul)',
        'Europe/Jersey' => 'Amzer keitat Greenwich (AKG) (Jerzenez)',
        'Europe/Kaliningrad' => 'eur Europa ar Reter (Kaliningrad)',
        'Europe/Kiev' => 'eur Europa ar Reter (Kiev)',
        'Europe/Kirov' => 'eur Rusia (Kirov)',
        'Europe/Lisbon' => 'eur Europa ar Cʼhornôg (Lisboa)',
        'Europe/Ljubljana' => 'eur Kreizeuropa (Ljubljana)',
        'Europe/London' => 'Amzer keitat Greenwich (AKG) (Londrez)',
        'Europe/Luxembourg' => 'eur Kreizeuropa (Luksembourg)',
        'Europe/Madrid' => 'eur Kreizeuropa (Madrid)',
        'Europe/Malta' => 'eur Kreizeuropa (Malta)',
        'Europe/Mariehamn' => 'eur Europa ar Reter (Marjehamn)',
        'Europe/Minsk' => 'eur Moskov (Mensk)',
        'Europe/Monaco' => 'eur Kreizeuropa (Monaco)',
        'Europe/Moscow' => 'eur Moskov',
        'Europe/Oslo' => 'eur Kreizeuropa (Oslo)',
        'Europe/Paris' => 'eur Kreizeuropa (Pariz)',
        'Europe/Podgorica' => 'eur Kreizeuropa (Podgorica)',
        'Europe/Prague' => 'eur Kreizeuropa (Praha)',
        'Europe/Riga' => 'eur Europa ar Reter (Riga)',
        'Europe/Rome' => 'eur Kreizeuropa (Roma)',
        'Europe/Samara' => 'eur Rusia (Samara)',
        'Europe/San_Marino' => 'eur Kreizeuropa (San Marino)',
        'Europe/Sarajevo' => 'eur Kreizeuropa (Sarajevo)',
        'Europe/Saratov' => 'eur Moskov (Saratov)',
        'Europe/Simferopol' => 'eur Moskov (Simferopol)',
        'Europe/Skopje' => 'eur Kreizeuropa (Skopje)',
        'Europe/Sofia' => 'eur Europa ar Reter (Sofia)',
        'Europe/Stockholm' => 'eur Kreizeuropa (Stockholm)',
        'Europe/Tallinn' => 'eur Europa ar Reter (Tallinn)',
        'Europe/Tirane' => 'eur Kreizeuropa (Tiranë)',
        'Europe/Ulyanovsk' => 'eur Moskov (Ulyanovsk)',
        'Europe/Uzhgorod' => 'eur Europa ar Reter (Uzhgorod)',
        'Europe/Vaduz' => 'eur Kreizeuropa (Vaduz)',
        'Europe/Vatican' => 'eur Kreizeuropa (Vatikan)',
        'Europe/Vienna' => 'eur Kreizeuropa (Vienna)',
        'Europe/Vilnius' => 'eur Europa ar Reter (Vilnius)',
        'Europe/Volgograd' => 'eur Volgograd',
        'Europe/Warsaw' => 'eur Kreizeuropa (Varsovia)',
        'Europe/Zagreb' => 'eur Kreizeuropa (Zagreb)',
        'Europe/Zaporozhye' => 'eur Europa ar Reter (Zaporozhye)',
        'Europe/Zurich' => 'eur Kreizeuropa (Zurich)',
        'Indian/Antananarivo' => 'eur Afrika ar Reter (Antananarivo)',
        'Indian/Chagos' => 'eur Meurvor Indez (Chagos)',
        'Indian/Christmas' => 'eur Enez Christmas',
        'Indian/Cocos' => 'eur Inizi Kokoz',
        'Indian/Comoro' => 'eur Afrika ar Reter (Komorez)',
        'Indian/Kerguelen' => 'eur Douaroù aostral Frañs hag Antarktika (Kergelenn)',
        'Indian/Mahe' => 'eur Sechelez (Mahe)',
        'Indian/Maldives' => 'eur ar Maldivez',
        'Indian/Mauritius' => 'eur Moris',
        'Indian/Mayotte' => 'eur Afrika ar Reter (Mayotte)',
        'Indian/Reunion' => 'eur ar Reünion',
        'MST7MDT' => 'eur ar Menezioù',
        'PST8PDT' => 'eur an Habask',
        'Pacific/Apia' => 'eur Apia',
        'Pacific/Auckland' => 'eur Zeland-Nevez (Auckland)',
        'Pacific/Bougainville' => 'eur Papoua-Ginea-Nevez (Bougainville)',
        'Pacific/Chatham' => 'eur Chatham',
        'Pacific/Easter' => 'eur Enez Pask',
        'Pacific/Efate' => 'eur Vanuatu (Efate)',
        'Pacific/Enderbury' => 'eur Inizi Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'eur Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'eur Fidji',
        'Pacific/Funafuti' => 'eur Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'eur Inizi Galápagos',
        'Pacific/Gambier' => 'eur Inizi Gambier',
        'Pacific/Guadalcanal' => 'eur Inizi Salomon (Guadalcanal)',
        'Pacific/Guam' => 'eur Chamorro (Guam)',
        'Pacific/Honolulu' => 'eur Hawaii hag an Aleouted (Honolulu)',
        'Pacific/Johnston' => 'eur Hawaii hag an Aleouted (Johnston)',
        'Pacific/Kiritimati' => 'eur Line Islands (Kiritimati)',
        'Pacific/Kosrae' => 'eur Kosrae',
        'Pacific/Kwajalein' => 'eur Inizi Marshall (Kwajalein)',
        'Pacific/Majuro' => 'eur Inizi Marshall (Majuro)',
        'Pacific/Marquesas' => 'eur Inizi Markiz',
        'Pacific/Midway' => 'eur Samoa (Midway)',
        'Pacific/Nauru' => 'eur Nauru',
        'Pacific/Niue' => 'eur Niue',
        'Pacific/Norfolk' => 'eur Enez Norfolk',
        'Pacific/Noumea' => 'eur Kaledonia Nevez (Noumea)',
        'Pacific/Pago_Pago' => 'eur Samoa (Pago Pago)',
        'Pacific/Palau' => 'eur Palau',
        'Pacific/Pitcairn' => 'eur Pitcairn',
        'Pacific/Ponape' => 'eur Pohnpei',
        'Pacific/Port_Moresby' => 'eur Papoua-Ginea-Nevez (Port Moresby)',
        'Pacific/Rarotonga' => 'eur Inizi Cook (Rarotonga)',
        'Pacific/Saipan' => 'eur Chamorro (Saipan)',
        'Pacific/Tahiti' => 'eur Tahiti',
        'Pacific/Tarawa' => 'eur Inizi Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'eur Tonga (Tongatapu)',
        'Pacific/Truk' => 'eur Chuuk',
        'Pacific/Wake' => 'eur Wake Island',
        'Pacific/Wallis' => 'eur Wallis ha Futuna',
    ],
    'Meta' => [
    ],
];
