<?php

return [
    'Names' => [
        'Adlm' => 'Адлам бичиг',
        'Aghb' => 'Кавказийн албани',
        'Ahom' => 'Ахом',
        'Arab' => 'араб',
        'Aran' => 'Насталик бичиг',
        'Armi' => 'Арамайк',
        'Armn' => 'армени',
        'Avst' => 'Авестан',
        'Bali' => 'Бали',
        'Bamu' => 'Баму',
        'Bass' => 'Басс',
        'Batk' => 'Батк',
        'Beng' => 'бенгал',
        'Bhks' => 'Байксуки',
        'Bopo' => 'вопомофо',
        'Brah' => 'Брахми',
        'Brai' => 'брайл',
        'Bugi' => 'Бугинез',
        'Buhd' => 'Бухид',
        'Cakm' => 'Чакма бичиг',
        'Cans' => 'Канадын уугуул иргэдийн тэмдэгт бичиг',
        'Cari' => 'Кари',
        'Cham' => 'Чам',
        'Cher' => 'Чероки бичиг',
        'Chrs' => 'Корасми',
        'Copt' => 'Коптик',
        'Cpmn' => 'Кипр-Миноан',
        'Cprt' => 'Киприот',
        'Cyrl' => 'кирилл',
        'Deva' => 'деванагари',
        'Diak' => 'Диак',
        'Dogr' => 'Догра',
        'Dsrt' => 'Дезерет',
        'Dupl' => 'Дуплоян',
        'Egyp' => 'Египетийн дүрс бичиг',
        'Elba' => 'Элбасан',
        'Elym' => 'Элимайк',
        'Ethi' => 'этиоп',
        'Geor' => 'гүрж',
        'Glag' => 'Глаголитик',
        'Gong' => 'Гонг',
        'Gonm' => 'Масарам Гонди',
        'Goth' => 'Готик',
        'Gran' => 'Гранта',
        'Grek' => 'грек',
        'Gujr' => 'гужарати',
        'Guru' => 'гүрмүх',
        'Hanb' => 'Бопомофотой ханз',
        'Hang' => 'хангыль',
        'Hani' => 'ханз',
        'Hano' => 'Хануноо',
        'Hans' => 'хялбаршуулсан',
        'Hant' => 'уламжлалт',
        'Hatr' => 'Хатран',
        'Hebr' => 'еврей',
        'Hira' => 'хирагана',
        'Hluw' => 'Анатолийн дүрс бичиг',
        'Hmng' => 'Пахав Хмонг',
        'Hmnp' => 'Хмнп',
        'Hrkt' => 'япон хэлний үеийн цагаан толгой',
        'Hung' => 'Хуучин Унгар',
        'Ital' => 'Хуучин итали',
        'Jamo' => 'жамо',
        'Java' => 'Жава',
        'Jpan' => 'япон',
        'Kali' => 'Кали',
        'Kana' => 'катакана',
        'Kawi' => 'Кави',
        'Khar' => 'Карошти',
        'Khmr' => 'кхмер',
        'Khoj' => 'Кожки',
        'Kits' => 'Китан бага бичвэр',
        'Knda' => 'каннада',
        'Kore' => 'солонгос',
        'Kthi' => 'Кайти',
        'Lana' => 'Лана',
        'Laoo' => 'лаос',
        'Latn' => 'латин',
        'Lepc' => 'Лепк',
        'Limb' => 'Лимб',
        'Lina' => 'Зураасан A',
        'Linb' => 'Зураасан B',
        'Lisu' => 'Лису',
        'Lyci' => 'Лиси',
        'Lydi' => 'Лиди',
        'Mahj' => 'Махажани',
        'Maka' => 'Макасар',
        'Mand' => 'Манд',
        'Mani' => 'Манич',
        'Marc' => 'Марк',
        'Medf' => 'Медефайдрин',
        'Mend' => 'Менди',
        'Merc' => 'Меройтик Курсив',
        'Mero' => 'Меройтик',
        'Mlym' => 'малаялам',
        'Modi' => 'Моди',
        'Mong' => 'монгол бичиг',
        'Mroo' => 'Мру',
        'Mtei' => 'Мейтей маек бичиг',
        'Mult' => 'Мултани',
        'Mymr' => 'мьянмар',
        'Nagm' => 'Наг Мундари',
        'Nand' => 'Нандинагари',
        'Narb' => 'Хуучин Хойд Араб бичиг',
        'Nbat' => 'Набата',
        'Newa' => 'Нева',
        'Nkoo' => 'Нко бичиг',
        'Nshu' => 'Нүшү',
        'Ogam' => 'Огам',
        'Olck' => 'Ол чики бичиг',
        'Orkh' => 'Орхон',
        'Orya' => 'ория',
        'Osge' => 'Осге',
        'Osma' => 'Османи',
        'Ougr' => 'Хуучин уйгар',
        'Palm' => 'Палмирен',
        'Pauc' => 'Пай Чин Хау',
        'Perm' => 'Хуучин Пермик',
        'Phag' => 'Фагс-па',
        'Phli' => 'Пахлави',
        'Phlp' => 'Псалтер Пахлави',
        'Phnx' => 'Финик',
        'Plrd' => 'Пирд',
        'Prti' => 'Партиан',
        'Qaag' => 'Каак',
        'Rjng' => 'Режанг',
        'Rohg' => 'Ханафи бичиг',
        'Runr' => 'Руни',
        'Samr' => 'Самаритан',
        'Sarb' => 'Хуучин Өмнөд Араб',
        'Saur' => 'Саураштра',
        'Sgnw' => 'Тэмдэгт бичиг',
        'Shaw' => 'Шави',
        'Shrd' => 'Шарада',
        'Sidd' => 'Сиддхам',
        'Sind' => 'Кудавади',
        'Sinh' => 'синхала',
        'Sogd' => 'Согди',
        'Sogo' => 'Хуучин согди',
        'Sora' => 'Сора сомпенг',
        'Soyo' => 'Соёмбо',
        'Sund' => 'Сундан бичиг',
        'Sylo' => 'Сило',
        'Syrc' => 'Сирийк бичиг',
        'Tagb' => 'Тагбанва',
        'Takr' => 'Такри',
        'Tale' => 'Тале',
        'Talu' => 'Талу',
        'Taml' => 'тамил',
        'Tang' => 'Тангут',
        'Tavt' => 'Тай Вьетнам',
        'Telu' => 'тэлүгү',
        'Tfng' => 'Тифинаг бичиг',
        'Tglg' => 'Тагалог',
        'Thaa' => 'тана',
        'Thai' => 'тай',
        'Tibt' => 'төвд',
        'Tirh' => 'Тирхута',
        'Tnsa' => 'Тангса',
        'Toto' => 'Тото',
        'Ugar' => 'Угаритик',
        'Vaii' => 'Ваи бичиг',
        'Vith' => 'Виткуки',
        'Wara' => 'Варанг Кшити',
        'Wcho' => 'Ванчу',
        'Xpeo' => 'Хуучин перс',
        'Xsux' => 'Сумеро-Аккадиан шаантаг бичиг',
        'Yezi' => 'Езиди',
        'Yiii' => 'И бичиг',
        'Zanb' => 'Занабазарын дөрвөлжин бичиг',
        'Zinh' => 'Зинх',
        'Zmth' => 'математик тооллын систем',
        'Zsye' => 'эможи',
        'Zsym' => 'тэмдэг',
        'Zxxx' => 'бичигдээгүй',
        'Zyyy' => 'нийтлэг',
    ],
];
