<?php

return [
    'Names' => [
        'BR' => 'Brasil',
        'CN' => 'Tiongkok',
        'DE' => 'Jérman',
        'FR' => 'Prancis',
        'GB' => 'Britania Raya',
        'ID' => 'Indonesia',
        'IN' => 'India',
        'IT' => 'Italia',
        'JP' => 'Jepang',
        'RU' => 'Rusia',
        'US' => 'Amérika Sarikat',
    ],
];
