<h3>{{ 'Suggestions for resolving this problem:'|trans }}</h3>
<ul>
    <li>{{ 'Check that the link you used to access the web site is correct.'|trans }}</li>
    <li>{{ 'Go back to the previous page and try again.'|trans }}</li>
    <li>{{ 'Close the web browser, and try again.'|trans }}</li>
</ul>

<h3>{{ 'This error may be caused by:'|trans }}</h3>
<ul>
    <li>{{ 'The link used to get here was bad, perhaps a bookmark.'|trans }}</li>
    <li>{{ 'Using the back and forward buttons in the web browser.'|trans }}</li>
    <li>{{ 'Opened the web browser with tabs saved from the previous session.'|trans }}</li>
    <li>{{ 'Cookies may be disabled in the web browser.'|trans }}</li>
</ul>
