<?php

return [
    'Names' => [
        'af' => 'Èdè Afrikani',
        'af_NA' => 'Èdè Afrikani (Namibia)',
        'af_ZA' => 'Èdè Afrikani (Gúúṣù Áfíríkà)',
        'ak' => 'Èdè Akani',
        'ak_GH' => 'Èdè Akani (Gana)',
        'am' => 'Èdè Amariki',
        'am_ET' => 'Èdè Amariki (Etopia)',
        'ar' => 'Èdè Árábìkì',
        'ar_001' => 'Èdè Árábìkì (Agbáyé)',
        'ar_AE' => 'Èdè Árábìkì (Ẹmirate ti Awọn Arabu)',
        'ar_BH' => 'Èdè Árábìkì (Báránì)',
        'ar_DJ' => 'Èdè Árábìkì (Díbọ́ótì)',
        'ar_DZ' => 'Èdè Árábìkì (Àlùgèríánì)',
        'ar_EG' => 'Èdè Árábìkì (Égípítì)',
        'ar_EH' => 'Èdè Árábìkì (Ìwọ̀òòrùn Sàhárà)',
        'ar_ER' => 'Èdè Árábìkì (Eritira)',
        'ar_IL' => 'Èdè Árábìkì (Iserẹli)',
        'ar_IQ' => 'Èdè Árábìkì (Iraki)',
        'ar_JO' => 'Èdè Árábìkì (Jọdani)',
        'ar_KM' => 'Èdè Árábìkì (Kòmòrósì)',
        'ar_KW' => 'Èdè Árábìkì (Kuweti)',
        'ar_LB' => 'Èdè Árábìkì (Lebanoni)',
        'ar_LY' => 'Èdè Árábìkì (Libiya)',
        'ar_MA' => 'Èdè Árábìkì (Moroko)',
        'ar_MR' => 'Èdè Árábìkì (Maritania)',
        'ar_OM' => 'Èdè Árábìkì (Ọọma)',
        'ar_PS' => 'Èdè Árábìkì (Agbègbè ara Palẹsítínì)',
        'ar_QA' => 'Èdè Árábìkì (Kota)',
        'ar_SA' => 'Èdè Árábìkì (Saudi Arabia)',
        'ar_SD' => 'Èdè Árábìkì (Sudani)',
        'ar_SO' => 'Èdè Árábìkì (Somalia)',
        'ar_SS' => 'Èdè Árábìkì (Gúúsù Sudan)',
        'ar_SY' => 'Èdè Árábìkì (Siria)',
        'ar_TD' => 'Èdè Árábìkì (Ṣààdì)',
        'ar_TN' => 'Èdè Árábìkì (Tuniṣia)',
        'ar_YE' => 'Èdè Árábìkì (Yemeni)',
        'as' => 'Èdè Ti Assam',
        'as_IN' => 'Èdè Ti Assam (India)',
        'az' => 'Èdè Azerbaijani',
        'az_AZ' => 'Èdè Azerbaijani (Asẹ́bájánì)',
        'az_Cyrl' => 'Èdè Azerbaijani (èdè ilẹ̀ Rọ́ṣíà)',
        'az_Cyrl_AZ' => 'Èdè Azerbaijani (èdè ilẹ̀ Rọ́ṣíà, Asẹ́bájánì)',
        'az_Latn' => 'Èdè Azerbaijani (Èdè Látìn)',
        'az_Latn_AZ' => 'Èdè Azerbaijani (Èdè Látìn, Asẹ́bájánì)',
        'be' => 'Èdè Belarusi',
        'be_BY' => 'Èdè Belarusi (Bélárúsì)',
        'bg' => 'Èdè Bugaria',
        'bg_BG' => 'Èdè Bugaria (Bùùgáríà)',
        'bm' => 'Èdè Báḿbàrà',
        'bm_ML' => 'Èdè Báḿbàrà (Mali)',
        'bn' => 'Èdè Bengali',
        'bn_BD' => 'Èdè Bengali (Bángáládésì)',
        'bn_IN' => 'Èdè Bengali (India)',
        'bo' => 'Tibetán',
        'bo_CN' => 'Tibetán (Ṣáínà)',
        'bo_IN' => 'Tibetán (India)',
        'br' => 'Èdè Bretoni',
        'br_FR' => 'Èdè Bretoni (Faranse)',
        'bs' => 'Èdè Bosnia',
        'bs_BA' => 'Èdè Bosnia (Bọ̀síníà àti Ẹtisẹgófínà)',
        'bs_Cyrl' => 'Èdè Bosnia (èdè ilẹ̀ Rọ́ṣíà)',
        'bs_Cyrl_BA' => 'Èdè Bosnia (èdè ilẹ̀ Rọ́ṣíà, Bọ̀síníà àti Ẹtisẹgófínà)',
        'bs_Latn' => 'Èdè Bosnia (Èdè Látìn)',
        'bs_Latn_BA' => 'Èdè Bosnia (Èdè Látìn, Bọ̀síníà àti Ẹtisẹgófínà)',
        'ca' => 'Èdè Catala',
        'ca_AD' => 'Èdè Catala (Ààndórà)',
        'ca_ES' => 'Èdè Catala (Sipani)',
        'ca_FR' => 'Èdè Catala (Faranse)',
        'ca_IT' => 'Èdè Catala (Itáli)',
        'ce' => 'Èdè Chechen',
        'ce_RU' => 'Èdè Chechen (Rọṣia)',
        'cs' => 'Èdè Seeki',
        'cs_CZ' => 'Èdè Seeki (Ṣẹ́ẹ́kì)',
        'cv' => 'Èdè Shufasi',
        'cv_RU' => 'Èdè Shufasi (Rọṣia)',
        'cy' => 'Èdè Welshi',
        'cy_GB' => 'Èdè Welshi (Gẹ̀ẹ́sì)',
        'da' => 'Èdè Ilẹ̀ Denmark',
        'da_DK' => 'Èdè Ilẹ̀ Denmark (Dẹ́mákì)',
        'da_GL' => 'Èdè Ilẹ̀ Denmark (Gerelandi)',
        'de' => 'Èdè Jámánì',
        'de_AT' => 'Èdè Jámánì (Asítíríà)',
        'de_BE' => 'Èdè Jámánì (Bégíọ́mù)',
        'de_CH' => 'Èdè Jámánì (switiṣilandi)',
        'de_DE' => 'Èdè Jámánì (Jámánì)',
        'de_IT' => 'Èdè Jámánì (Itáli)',
        'de_LI' => 'Èdè Jámánì (Lẹṣitẹnisiteni)',
        'de_LU' => 'Èdè Jámánì (Lusemogi)',
        'dz' => 'Èdè Dzongkha',
        'dz_BT' => 'Èdè Dzongkha (Bútánì)',
        'ee' => 'Èdè Ewè',
        'ee_GH' => 'Èdè Ewè (Gana)',
        'ee_TG' => 'Èdè Ewè (Togo)',
        'el' => 'Èdè Giriki',
        'el_CY' => 'Èdè Giriki (Kúrúsì)',
        'el_GR' => 'Èdè Giriki (Geriisi)',
        'en' => 'Èdè Gẹ̀ẹ́sì',
        'en_001' => 'Èdè Gẹ̀ẹ́sì (Agbáyé)',
        'en_150' => 'Èdè Gẹ̀ẹ́sì (Yúróòpù)',
        'en_AE' => 'Èdè Gẹ̀ẹ́sì (Ẹmirate ti Awọn Arabu)',
        'en_AG' => 'Èdè Gẹ̀ẹ́sì (Ààntígúà àti Báríbúdà)',
        'en_AI' => 'Èdè Gẹ̀ẹ́sì (Ààngúlílà)',
        'en_AS' => 'Èdè Gẹ̀ẹ́sì (Sámóánì ti Orílẹ́ède Àméríkà)',
        'en_AT' => 'Èdè Gẹ̀ẹ́sì (Asítíríà)',
        'en_AU' => 'Èdè Gẹ̀ẹ́sì (Ástràlìá)',
        'en_BB' => 'Èdè Gẹ̀ẹ́sì (Bábádósì)',
        'en_BE' => 'Èdè Gẹ̀ẹ́sì (Bégíọ́mù)',
        'en_BI' => 'Èdè Gẹ̀ẹ́sì (Bùùrúndì)',
        'en_BM' => 'Èdè Gẹ̀ẹ́sì (Bémúdà)',
        'en_BS' => 'Èdè Gẹ̀ẹ́sì (Bàhámásì)',
        'en_BW' => 'Èdè Gẹ̀ẹ́sì (Bọ̀tìsúwánà)',
        'en_BZ' => 'Èdè Gẹ̀ẹ́sì (Bèlísẹ̀)',
        'en_CA' => 'Èdè Gẹ̀ẹ́sì (Kánádà)',
        'en_CC' => 'Èdè Gẹ̀ẹ́sì (Erékùsù Cocos [Keeling])',
        'en_CH' => 'Èdè Gẹ̀ẹ́sì (switiṣilandi)',
        'en_CK' => 'Èdè Gẹ̀ẹ́sì (Etíokun Kùúkù)',
        'en_CM' => 'Èdè Gẹ̀ẹ́sì (Kamerúúnì)',
        'en_CX' => 'Èdè Gẹ̀ẹ́sì (Erékùsù Christmas)',
        'en_CY' => 'Èdè Gẹ̀ẹ́sì (Kúrúsì)',
        'en_DE' => 'Èdè Gẹ̀ẹ́sì (Jámánì)',
        'en_DK' => 'Èdè Gẹ̀ẹ́sì (Dẹ́mákì)',
        'en_DM' => 'Èdè Gẹ̀ẹ́sì (Dòmíníkà)',
        'en_ER' => 'Èdè Gẹ̀ẹ́sì (Eritira)',
        'en_FI' => 'Èdè Gẹ̀ẹ́sì (Filandi)',
        'en_FJ' => 'Èdè Gẹ̀ẹ́sì (Fiji)',
        'en_FK' => 'Èdè Gẹ̀ẹ́sì (Etikun Fakalandi)',
        'en_FM' => 'Èdè Gẹ̀ẹ́sì (Makoronesia)',
        'en_GB' => 'Èdè Gẹ̀ẹ́sì (Gẹ̀ẹ́sì)',
        'en_GD' => 'Èdè Gẹ̀ẹ́sì (Genada)',
        'en_GG' => 'Èdè Gẹ̀ẹ́sì (Guernsey)',
        'en_GH' => 'Èdè Gẹ̀ẹ́sì (Gana)',
        'en_GI' => 'Èdè Gẹ̀ẹ́sì (Gibaratara)',
        'en_GM' => 'Èdè Gẹ̀ẹ́sì (Gambia)',
        'en_GU' => 'Èdè Gẹ̀ẹ́sì (Guamu)',
        'en_GY' => 'Èdè Gẹ̀ẹ́sì (Guyana)',
        'en_HK' => 'Èdè Gẹ̀ẹ́sì (Agbègbè Ìṣàkóso Ìṣúná Hong Kong Tí Ṣánà Ń Darí)',
        'en_IE' => 'Èdè Gẹ̀ẹ́sì (Ailandi)',
        'en_IL' => 'Èdè Gẹ̀ẹ́sì (Iserẹli)',
        'en_IM' => 'Èdè Gẹ̀ẹ́sì (Isle of Man)',
        'en_IN' => 'Èdè Gẹ̀ẹ́sì (India)',
        'en_IO' => 'Èdè Gẹ̀ẹ́sì (Etíkun Índíánì ti Ìlú Bírítísì)',
        'en_JE' => 'Èdè Gẹ̀ẹ́sì (Jersey)',
        'en_JM' => 'Èdè Gẹ̀ẹ́sì (Jamaika)',
        'en_KE' => 'Èdè Gẹ̀ẹ́sì (Kenya)',
        'en_KI' => 'Èdè Gẹ̀ẹ́sì (Kiribati)',
        'en_KN' => 'Èdè Gẹ̀ẹ́sì (Kiiti ati Neefi)',
        'en_KY' => 'Èdè Gẹ̀ẹ́sì (Etíokun Kámánì)',
        'en_LC' => 'Èdè Gẹ̀ẹ́sì (Luṣia)',
        'en_LR' => 'Èdè Gẹ̀ẹ́sì (Laberia)',
        'en_LS' => 'Èdè Gẹ̀ẹ́sì (Lesoto)',
        'en_MG' => 'Èdè Gẹ̀ẹ́sì (Madasika)',
        'en_MH' => 'Èdè Gẹ̀ẹ́sì (Etikun Máṣali)',
        'en_MO' => 'Èdè Gẹ̀ẹ́sì (Agbègbè Ìṣàkóso Pàtàkì Macao)',
        'en_MP' => 'Èdè Gẹ̀ẹ́sì (Etikun Guusu Mariana)',
        'en_MS' => 'Èdè Gẹ̀ẹ́sì (Motserati)',
        'en_MT' => 'Èdè Gẹ̀ẹ́sì (Malata)',
        'en_MU' => 'Èdè Gẹ̀ẹ́sì (Maritiusi)',
        'en_MV' => 'Èdè Gẹ̀ẹ́sì (Maladifi)',
        'en_MW' => 'Èdè Gẹ̀ẹ́sì (Malawi)',
        'en_MY' => 'Èdè Gẹ̀ẹ́sì (Malasia)',
        'en_NA' => 'Èdè Gẹ̀ẹ́sì (Namibia)',
        'en_NF' => 'Èdè Gẹ̀ẹ́sì (Etikun Nọ́úfókì)',
        'en_NG' => 'Èdè Gẹ̀ẹ́sì (Nàìjíríà)',
        'en_NL' => 'Èdè Gẹ̀ẹ́sì (Nedalandi)',
        'en_NR' => 'Èdè Gẹ̀ẹ́sì (Nauru)',
        'en_NU' => 'Èdè Gẹ̀ẹ́sì (Niue)',
        'en_NZ' => 'Èdè Gẹ̀ẹ́sì (Ṣilandi Titun)',
        'en_PG' => 'Èdè Gẹ̀ẹ́sì (Paapu ti Giini)',
        'en_PH' => 'Èdè Gẹ̀ẹ́sì (Filipini)',
        'en_PK' => 'Èdè Gẹ̀ẹ́sì (Pakisitan)',
        'en_PN' => 'Èdè Gẹ̀ẹ́sì (Pikarini)',
        'en_PR' => 'Èdè Gẹ̀ẹ́sì (Pọto Riko)',
        'en_PW' => 'Èdè Gẹ̀ẹ́sì (Paalu)',
        'en_RW' => 'Èdè Gẹ̀ẹ́sì (Ruwanda)',
        'en_SB' => 'Èdè Gẹ̀ẹ́sì (Etikun Solomoni)',
        'en_SC' => 'Èdè Gẹ̀ẹ́sì (Ṣeṣẹlẹsi)',
        'en_SD' => 'Èdè Gẹ̀ẹ́sì (Sudani)',
        'en_SE' => 'Èdè Gẹ̀ẹ́sì (Swidini)',
        'en_SG' => 'Èdè Gẹ̀ẹ́sì (Singapo)',
        'en_SH' => 'Èdè Gẹ̀ẹ́sì (Hẹlena)',
        'en_SI' => 'Èdè Gẹ̀ẹ́sì (Silofania)',
        'en_SL' => 'Èdè Gẹ̀ẹ́sì (Siria looni)',
        'en_SS' => 'Èdè Gẹ̀ẹ́sì (Gúúsù Sudan)',
        'en_SX' => 'Èdè Gẹ̀ẹ́sì (Síntì Mátẹ́ẹ̀nì)',
        'en_SZ' => 'Èdè Gẹ̀ẹ́sì (Saṣiland)',
        'en_TC' => 'Èdè Gẹ̀ẹ́sì (Tọọki ati Etikun Kakọsi)',
        'en_TK' => 'Èdè Gẹ̀ẹ́sì (Tokelau)',
        'en_TO' => 'Èdè Gẹ̀ẹ́sì (Tonga)',
        'en_TT' => 'Èdè Gẹ̀ẹ́sì (Tirinida ati Tobaga)',
        'en_TV' => 'Èdè Gẹ̀ẹ́sì (Tufalu)',
        'en_TZ' => 'Èdè Gẹ̀ẹ́sì (Tàǹsáníà)',
        'en_UG' => 'Èdè Gẹ̀ẹ́sì (Uganda)',
        'en_UM' => 'Èdè Gẹ̀ẹ́sì (Àwọn Erékùsù Kékèké Agbègbè US)',
        'en_US' => 'Èdè Gẹ̀ẹ́sì (Amẹrikà)',
        'en_VC' => 'Èdè Gẹ̀ẹ́sì (Fisẹnnti ati Genadina)',
        'en_VG' => 'Èdè Gẹ̀ẹ́sì (Etíkun Fágínì ti ìlú Bírítísì)',
        'en_VI' => 'Èdè Gẹ̀ẹ́sì (Etikun Fagini ti Amẹrika)',
        'en_VU' => 'Èdè Gẹ̀ẹ́sì (Faniatu)',
        'en_WS' => 'Èdè Gẹ̀ẹ́sì (Samọ)',
        'en_ZA' => 'Èdè Gẹ̀ẹ́sì (Gúúṣù Áfíríkà)',
        'en_ZM' => 'Èdè Gẹ̀ẹ́sì (Ṣamibia)',
        'en_ZW' => 'Èdè Gẹ̀ẹ́sì (Ṣimibabe)',
        'eo' => 'Èdè Esperanto',
        'eo_001' => 'Èdè Esperanto (Agbáyé)',
        'es' => 'Èdè Sípáníìṣì',
        'es_419' => 'Èdè Sípáníìṣì (Látín Amẹ́ríkà)',
        'es_AR' => 'Èdè Sípáníìṣì (Agentínà)',
        'es_BO' => 'Èdè Sípáníìṣì (Bọ̀lífíyà)',
        'es_BR' => 'Èdè Sípáníìṣì (Bàràsílì)',
        'es_BZ' => 'Èdè Sípáníìṣì (Bèlísẹ̀)',
        'es_CL' => 'Èdè Sípáníìṣì (Ṣílè)',
        'es_CO' => 'Èdè Sípáníìṣì (Kòlómíbìa)',
        'es_CR' => 'Èdè Sípáníìṣì (Kuusita Ríkà)',
        'es_CU' => 'Èdè Sípáníìṣì (Kúbà)',
        'es_DO' => 'Èdè Sípáníìṣì (Dòmíníkánì)',
        'es_EC' => 'Èdè Sípáníìṣì (Ekuádò)',
        'es_ES' => 'Èdè Sípáníìṣì (Sipani)',
        'es_GQ' => 'Èdè Sípáníìṣì (Ekutoria Gini)',
        'es_GT' => 'Èdè Sípáníìṣì (Guatemala)',
        'es_HN' => 'Èdè Sípáníìṣì (Hondurasi)',
        'es_MX' => 'Èdè Sípáníìṣì (Mesiko)',
        'es_NI' => 'Èdè Sípáníìṣì (Nikaragua)',
        'es_PA' => 'Èdè Sípáníìṣì (Panama)',
        'es_PE' => 'Èdè Sípáníìṣì (Peru)',
        'es_PH' => 'Èdè Sípáníìṣì (Filipini)',
        'es_PR' => 'Èdè Sípáníìṣì (Pọto Riko)',
        'es_PY' => 'Èdè Sípáníìṣì (Paraguye)',
        'es_SV' => 'Èdè Sípáníìṣì (Ẹẹsáfádò)',
        'es_US' => 'Èdè Sípáníìṣì (Amẹrikà)',
        'es_UY' => 'Èdè Sípáníìṣì (Nruguayi)',
        'es_VE' => 'Èdè Sípáníìṣì (Fẹnẹṣuẹla)',
        'et' => 'Èdè Estonia',
        'et_EE' => 'Èdè Estonia (Esitonia)',
        'eu' => 'Èdè Baski',
        'eu_ES' => 'Èdè Baski (Sipani)',
        'fa' => 'Èdè Pasia',
        'fa_AF' => 'Èdè Pasia (Àfùgànístánì)',
        'fa_IR' => 'Èdè Pasia (Irani)',
        'ff' => 'Èdè Fúlàní',
        'ff_Adlm' => 'Èdè Fúlàní (Èdè Adam)',
        'ff_Adlm_BF' => 'Èdè Fúlàní (Èdè Adam, Bùùkíná Fasò)',
        'ff_Adlm_CM' => 'Èdè Fúlàní (Èdè Adam, Kamerúúnì)',
        'ff_Adlm_GH' => 'Èdè Fúlàní (Èdè Adam, Gana)',
        'ff_Adlm_GM' => 'Èdè Fúlàní (Èdè Adam, Gambia)',
        'ff_Adlm_GN' => 'Èdè Fúlàní (Èdè Adam, Gene)',
        'ff_Adlm_GW' => 'Èdè Fúlàní (Èdè Adam, Gene-Busau)',
        'ff_Adlm_LR' => 'Èdè Fúlàní (Èdè Adam, Laberia)',
        'ff_Adlm_MR' => 'Èdè Fúlàní (Èdè Adam, Maritania)',
        'ff_Adlm_NE' => 'Èdè Fúlàní (Èdè Adam, Nàìjá)',
        'ff_Adlm_NG' => 'Èdè Fúlàní (Èdè Adam, Nàìjíríà)',
        'ff_Adlm_SL' => 'Èdè Fúlàní (Èdè Adam, Siria looni)',
        'ff_Adlm_SN' => 'Èdè Fúlàní (Èdè Adam, Sẹnẹga)',
        'ff_CM' => 'Èdè Fúlàní (Kamerúúnì)',
        'ff_GN' => 'Èdè Fúlàní (Gene)',
        'ff_Latn' => 'Èdè Fúlàní (Èdè Látìn)',
        'ff_Latn_BF' => 'Èdè Fúlàní (Èdè Látìn, Bùùkíná Fasò)',
        'ff_Latn_CM' => 'Èdè Fúlàní (Èdè Látìn, Kamerúúnì)',
        'ff_Latn_GH' => 'Èdè Fúlàní (Èdè Látìn, Gana)',
        'ff_Latn_GM' => 'Èdè Fúlàní (Èdè Látìn, Gambia)',
        'ff_Latn_GN' => 'Èdè Fúlàní (Èdè Látìn, Gene)',
        'ff_Latn_GW' => 'Èdè Fúlàní (Èdè Látìn, Gene-Busau)',
        'ff_Latn_LR' => 'Èdè Fúlàní (Èdè Látìn, Laberia)',
        'ff_Latn_MR' => 'Èdè Fúlàní (Èdè Látìn, Maritania)',
        'ff_Latn_NE' => 'Èdè Fúlàní (Èdè Látìn, Nàìjá)',
        'ff_Latn_NG' => 'Èdè Fúlàní (Èdè Látìn, Nàìjíríà)',
        'ff_Latn_SL' => 'Èdè Fúlàní (Èdè Látìn, Siria looni)',
        'ff_Latn_SN' => 'Èdè Fúlàní (Èdè Látìn, Sẹnẹga)',
        'ff_MR' => 'Èdè Fúlàní (Maritania)',
        'ff_SN' => 'Èdè Fúlàní (Sẹnẹga)',
        'fi' => 'Èdè Finisi',
        'fi_FI' => 'Èdè Finisi (Filandi)',
        'fo' => 'Èdè Faroesi',
        'fo_DK' => 'Èdè Faroesi (Dẹ́mákì)',
        'fo_FO' => 'Èdè Faroesi (Àwọn Erékùsù ti Faroe)',
        'fr' => 'Èdè Faransé',
        'fr_BE' => 'Èdè Faransé (Bégíọ́mù)',
        'fr_BF' => 'Èdè Faransé (Bùùkíná Fasò)',
        'fr_BI' => 'Èdè Faransé (Bùùrúndì)',
        'fr_BJ' => 'Èdè Faransé (Bẹ̀nẹ̀)',
        'fr_BL' => 'Èdè Faransé (Ìlú Bátílẹ́mì)',
        'fr_CA' => 'Èdè Faransé (Kánádà)',
        'fr_CD' => 'Èdè Faransé (Kóńgò – Kinshasa)',
        'fr_CF' => 'Èdè Faransé (Àrin gùngun Áfíríkà)',
        'fr_CG' => 'Èdè Faransé (Kóńgò – Brazaville)',
        'fr_CH' => 'Èdè Faransé (switiṣilandi)',
        'fr_CI' => 'Èdè Faransé (Kóútè forà)',
        'fr_CM' => 'Èdè Faransé (Kamerúúnì)',
        'fr_DJ' => 'Èdè Faransé (Díbọ́ótì)',
        'fr_DZ' => 'Èdè Faransé (Àlùgèríánì)',
        'fr_FR' => 'Èdè Faransé (Faranse)',
        'fr_GA' => 'Èdè Faransé (Gabon)',
        'fr_GF' => 'Èdè Faransé (Firenṣi Guana)',
        'fr_GN' => 'Èdè Faransé (Gene)',
        'fr_GP' => 'Èdè Faransé (Gadelope)',
        'fr_GQ' => 'Èdè Faransé (Ekutoria Gini)',
        'fr_HT' => 'Èdè Faransé (Haati)',
        'fr_KM' => 'Èdè Faransé (Kòmòrósì)',
        'fr_LU' => 'Èdè Faransé (Lusemogi)',
        'fr_MA' => 'Èdè Faransé (Moroko)',
        'fr_MC' => 'Èdè Faransé (Monako)',
        'fr_MF' => 'Èdè Faransé (Ìlú Mátíìnì)',
        'fr_MG' => 'Èdè Faransé (Madasika)',
        'fr_ML' => 'Èdè Faransé (Mali)',
        'fr_MQ' => 'Èdè Faransé (Matinikuwi)',
        'fr_MR' => 'Èdè Faransé (Maritania)',
        'fr_MU' => 'Èdè Faransé (Maritiusi)',
        'fr_NC' => 'Èdè Faransé (Kaledonia Titun)',
        'fr_NE' => 'Èdè Faransé (Nàìjá)',
        'fr_PF' => 'Èdè Faransé (Firenṣi Polinesia)',
        'fr_PM' => 'Èdè Faransé (Pẹẹri ati mikuloni)',
        'fr_RE' => 'Èdè Faransé (Riuniyan)',
        'fr_RW' => 'Èdè Faransé (Ruwanda)',
        'fr_SC' => 'Èdè Faransé (Ṣeṣẹlẹsi)',
        'fr_SN' => 'Èdè Faransé (Sẹnẹga)',
        'fr_SY' => 'Èdè Faransé (Siria)',
        'fr_TD' => 'Èdè Faransé (Ṣààdì)',
        'fr_TG' => 'Èdè Faransé (Togo)',
        'fr_TN' => 'Èdè Faransé (Tuniṣia)',
        'fr_VU' => 'Èdè Faransé (Faniatu)',
        'fr_WF' => 'Èdè Faransé (Wali ati futuna)',
        'fr_YT' => 'Èdè Faransé (Mayote)',
        'fy' => 'Èdè Frisia',
        'fy_NL' => 'Èdè Frisia (Nedalandi)',
        'ga' => 'Èdè Ireland',
        'ga_GB' => 'Èdè Ireland (Gẹ̀ẹ́sì)',
        'ga_IE' => 'Èdè Ireland (Ailandi)',
        'gd' => 'Èdè Gaelik ti Ilu Scotland',
        'gd_GB' => 'Èdè Gaelik ti Ilu Scotland (Gẹ̀ẹ́sì)',
        'gl' => 'Èdè Galicia',
        'gl_ES' => 'Èdè Galicia (Sipani)',
        'gu' => 'Èdè Gujarati',
        'gu_IN' => 'Èdè Gujarati (India)',
        'gv' => 'Máǹkì',
        'gv_IM' => 'Máǹkì (Isle of Man)',
        'ha' => 'Èdè Hausa',
        'ha_GH' => 'Èdè Hausa (Gana)',
        'ha_NE' => 'Èdè Hausa (Nàìjá)',
        'ha_NG' => 'Èdè Hausa (Nàìjíríà)',
        'he' => 'Èdè Heberu',
        'he_IL' => 'Èdè Heberu (Iserẹli)',
        'hi' => 'Èdè Híńdì',
        'hi_IN' => 'Èdè Híńdì (India)',
        'hi_Latn' => 'Èdè Híńdì (Èdè Látìn)',
        'hi_Latn_IN' => 'Èdè Híńdì (Èdè Látìn, India)',
        'hr' => 'Èdè Kroatia',
        'hr_BA' => 'Èdè Kroatia (Bọ̀síníà àti Ẹtisẹgófínà)',
        'hr_HR' => 'Èdè Kroatia (Kòróátíà)',
        'hu' => 'Èdè Hungaria',
        'hu_HU' => 'Èdè Hungaria (Hungari)',
        'hy' => 'Èdè Ile Armenia',
        'hy_AM' => 'Èdè Ile Armenia (Améníà)',
        'ia' => 'Èdè pipo',
        'ia_001' => 'Èdè pipo (Agbáyé)',
        'id' => 'Èdè Indonéṣíà',
        'id_ID' => 'Èdè Indonéṣíà (Indonesia)',
        'ig' => 'Èdè Yíbò',
        'ig_NG' => 'Èdè Yíbò (Nàìjíríà)',
        'ii' => 'Ṣíkuán Yì',
        'ii_CN' => 'Ṣíkuán Yì (Ṣáínà)',
        'is' => 'Èdè Icelandic',
        'is_IS' => 'Èdè Icelandic (Aṣilandi)',
        'it' => 'Èdè Ítálì',
        'it_CH' => 'Èdè Ítálì (switiṣilandi)',
        'it_IT' => 'Èdè Ítálì (Itáli)',
        'it_SM' => 'Èdè Ítálì (Sani Marino)',
        'it_VA' => 'Èdè Ítálì (Ìlú Vatican)',
        'ja' => 'Èdè Jàpáànù',
        'ja_JP' => 'Èdè Jàpáànù (Japani)',
        'jv' => 'Èdè Javanasi',
        'jv_ID' => 'Èdè Javanasi (Indonesia)',
        'ka' => 'Èdè Georgia',
        'ka_GE' => 'Èdè Georgia (Gọgia)',
        'ki' => 'Kíkúyù',
        'ki_KE' => 'Kíkúyù (Kenya)',
        'kk' => 'Kaṣakì',
        'kk_KZ' => 'Kaṣakì (Kaṣaṣatani)',
        'kl' => 'Kalaalísùtì',
        'kl_GL' => 'Kalaalísùtì (Gerelandi)',
        'km' => 'Èdè kameri',
        'km_KH' => 'Èdè kameri (Kàmùbódíà)',
        'kn' => 'Èdè Kannada',
        'kn_IN' => 'Èdè Kannada (India)',
        'ko' => 'Èdè Kòríà',
        'ko_KP' => 'Èdè Kòríà (Guusu Kọria)',
        'ko_KR' => 'Èdè Kòríà (Ariwa Kọria)',
        'ks' => 'Kaṣímirì',
        'ks_Arab' => 'Kaṣímirì (èdè Lárúbáwá)',
        'ks_Arab_IN' => 'Kaṣímirì (èdè Lárúbáwá, India)',
        'ks_Deva' => 'Kaṣímirì (Dẹfanagárì)',
        'ks_Deva_IN' => 'Kaṣímirì (Dẹfanagárì, India)',
        'ks_IN' => 'Kaṣímirì (India)',
        'ku' => 'Kọdiṣì',
        'ku_TR' => 'Kọdiṣì (Tọọki)',
        'kw' => 'Èdè Kọ́nììṣì',
        'kw_GB' => 'Èdè Kọ́nììṣì (Gẹ̀ẹ́sì)',
        'ky' => 'Kírígíìsì',
        'ky_KG' => 'Kírígíìsì (Kuriṣisitani)',
        'lb' => 'Lùṣẹ́mbọ́ọ̀gì',
        'lb_LU' => 'Lùṣẹ́mbọ́ọ̀gì (Lusemogi)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lìǹgálà',
        'ln_AO' => 'Lìǹgálà (Ààngólà)',
        'ln_CD' => 'Lìǹgálà (Kóńgò – Kinshasa)',
        'ln_CF' => 'Lìǹgálà (Àrin gùngun Áfíríkà)',
        'ln_CG' => 'Lìǹgálà (Kóńgò – Brazaville)',
        'lo' => 'Láò',
        'lo_LA' => 'Láò (Laosi)',
        'lt' => 'Èdè Lithuania',
        'lt_LT' => 'Èdè Lithuania (Lituania)',
        'lu' => 'Lúbà-Katanga',
        'lu_CD' => 'Lúbà-Katanga (Kóńgò – Kinshasa)',
        'lv' => 'Èdè Latvianu',
        'lv_LV' => 'Èdè Latvianu (Latifia)',
        'mg' => 'Malagasì',
        'mg_MG' => 'Malagasì (Madasika)',
        'mi' => 'Màórì',
        'mi_NZ' => 'Màórì (Ṣilandi Titun)',
        'mk' => 'Èdè Macedonia',
        'mk_MK' => 'Èdè Macedonia (Àríwá Macedonia)',
        'ml' => 'Málàyálámù',
        'ml_IN' => 'Málàyálámù (India)',
        'mn' => 'Mòngólíà',
        'mn_MN' => 'Mòngólíà (Mogolia)',
        'mr' => 'Èdè marathi',
        'mr_IN' => 'Èdè marathi (India)',
        'ms' => 'Èdè Malaya',
        'ms_BN' => 'Èdè Malaya (Búrúnẹ́lì)',
        'ms_ID' => 'Èdè Malaya (Indonesia)',
        'ms_MY' => 'Èdè Malaya (Malasia)',
        'ms_SG' => 'Èdè Malaya (Singapo)',
        'mt' => 'Èdè Malta',
        'mt_MT' => 'Èdè Malta (Malata)',
        'my' => 'Èdè Bumiisi',
        'my_MM' => 'Èdè Bumiisi (Manamari)',
        'nb' => 'Nọ́ọ́wè Bokímàl',
        'nb_NO' => 'Nọ́ọ́wè Bokímàl (Nọọwii)',
        'nb_SJ' => 'Nọ́ọ́wè Bokímàl (Sífábáàdì àti Jánì Máyẹ̀nì)',
        'nd' => 'Àríwá Ndebele',
        'nd_ZW' => 'Àríwá Ndebele (Ṣimibabe)',
        'ne' => 'Èdè Nepali',
        'ne_IN' => 'Èdè Nepali (India)',
        'ne_NP' => 'Èdè Nepali (Nepa)',
        'nl' => 'Èdè Dọ́ọ̀ṣì',
        'nl_AW' => 'Èdè Dọ́ọ̀ṣì (Árúbà)',
        'nl_BE' => 'Èdè Dọ́ọ̀ṣì (Bégíọ́mù)',
        'nl_BQ' => 'Èdè Dọ́ọ̀ṣì (Káríbíánì ti Nẹ́dálándì)',
        'nl_CW' => 'Èdè Dọ́ọ̀ṣì (Kúrásáò)',
        'nl_NL' => 'Èdè Dọ́ọ̀ṣì (Nedalandi)',
        'nl_SR' => 'Èdè Dọ́ọ̀ṣì (Surinami)',
        'nl_SX' => 'Èdè Dọ́ọ̀ṣì (Síntì Mátẹ́ẹ̀nì)',
        'nn' => 'Nọ́ọ́wè Nínọ̀sìkì',
        'nn_NO' => 'Nọ́ọ́wè Nínọ̀sìkì (Nọọwii)',
        'no' => 'Èdè Norway',
        'no_NO' => 'Èdè Norway (Nọọwii)',
        'om' => 'Òròmọ́',
        'om_ET' => 'Òròmọ́ (Etopia)',
        'om_KE' => 'Òròmọ́ (Kenya)',
        'or' => 'Òdíà',
        'or_IN' => 'Òdíà (India)',
        'os' => 'Ọṣẹ́tíìkì',
        'os_GE' => 'Ọṣẹ́tíìkì (Gọgia)',
        'os_RU' => 'Ọṣẹ́tíìkì (Rọṣia)',
        'pa' => 'Èdè Punjabi',
        'pa_Arab' => 'Èdè Punjabi (èdè Lárúbáwá)',
        'pa_Arab_PK' => 'Èdè Punjabi (èdè Lárúbáwá, Pakisitan)',
        'pa_Guru' => 'Èdè Punjabi (Gurumúkhì)',
        'pa_Guru_IN' => 'Èdè Punjabi (Gurumúkhì, India)',
        'pa_IN' => 'Èdè Punjabi (India)',
        'pa_PK' => 'Èdè Punjabi (Pakisitan)',
        'pl' => 'Èdè Póláǹdì',
        'pl_PL' => 'Èdè Póláǹdì (Polandi)',
        'ps' => 'Páshítò',
        'ps_AF' => 'Páshítò (Àfùgànístánì)',
        'ps_PK' => 'Páshítò (Pakisitan)',
        'pt' => 'Èdè Pọtogí',
        'pt_AO' => 'Èdè Pọtogí (Ààngólà)',
        'pt_BR' => 'Èdè Pọtogí (Bàràsílì)',
        'pt_CH' => 'Èdè Pọtogí (switiṣilandi)',
        'pt_CV' => 'Èdè Pọtogí (Etíokun Kápé féndè)',
        'pt_GQ' => 'Èdè Pọtogí (Ekutoria Gini)',
        'pt_GW' => 'Èdè Pọtogí (Gene-Busau)',
        'pt_LU' => 'Èdè Pọtogí (Lusemogi)',
        'pt_MO' => 'Èdè Pọtogí (Agbègbè Ìṣàkóso Pàtàkì Macao)',
        'pt_MZ' => 'Èdè Pọtogí (Moṣamibiku)',
        'pt_PT' => 'Èdè Pọtogí (Pọ́túgà)',
        'pt_ST' => 'Èdè Pọtogí (Sao tomi ati piriiṣipi)',
        'pt_TL' => 'Èdè Pọtogí (ÌlàOòrùn Tímọ̀)',
        'qu' => 'Kúẹ́ńjùà',
        'qu_BO' => 'Kúẹ́ńjùà (Bọ̀lífíyà)',
        'qu_EC' => 'Kúẹ́ńjùà (Ekuádò)',
        'qu_PE' => 'Kúẹ́ńjùà (Peru)',
        'rm' => 'Rómáǹṣì',
        'rm_CH' => 'Rómáǹṣì (switiṣilandi)',
        'rn' => 'Rúńdì',
        'rn_BI' => 'Rúńdì (Bùùrúndì)',
        'ro' => 'Èdè Romania',
        'ro_MD' => 'Èdè Romania (Modofia)',
        'ro_RO' => 'Èdè Romania (Romaniya)',
        'ru' => 'Èdè Rọ́ṣíà',
        'ru_BY' => 'Èdè Rọ́ṣíà (Bélárúsì)',
        'ru_KG' => 'Èdè Rọ́ṣíà (Kuriṣisitani)',
        'ru_KZ' => 'Èdè Rọ́ṣíà (Kaṣaṣatani)',
        'ru_MD' => 'Èdè Rọ́ṣíà (Modofia)',
        'ru_RU' => 'Èdè Rọ́ṣíà (Rọṣia)',
        'ru_UA' => 'Èdè Rọ́ṣíà (Ukarini)',
        'rw' => 'Èdè Ruwanda',
        'rw_RW' => 'Èdè Ruwanda (Ruwanda)',
        'sa' => 'Èdè awon ara Indo',
        'sa_IN' => 'Èdè awon ara Indo (India)',
        'sc' => 'Èdè Sadini',
        'sc_IT' => 'Èdè Sadini (Itáli)',
        'sd' => 'Èdè Sindhi',
        'sd_Arab' => 'Èdè Sindhi (èdè Lárúbáwá)',
        'sd_Arab_PK' => 'Èdè Sindhi (èdè Lárúbáwá, Pakisitan)',
        'sd_Deva' => 'Èdè Sindhi (Dẹfanagárì)',
        'sd_Deva_IN' => 'Èdè Sindhi (Dẹfanagárì, India)',
        'sd_IN' => 'Èdè Sindhi (India)',
        'sd_PK' => 'Èdè Sindhi (Pakisitan)',
        'se' => 'Apáàríwá Sami',
        'se_FI' => 'Apáàríwá Sami (Filandi)',
        'se_NO' => 'Apáàríwá Sami (Nọọwii)',
        'se_SE' => 'Apáàríwá Sami (Swidini)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Àrin gùngun Áfíríkà)',
        'sh' => 'Èdè Serbo-Croatiani',
        'sh_BA' => 'Èdè Serbo-Croatiani (Bọ̀síníà àti Ẹtisẹgófínà)',
        'si' => 'Èdè Sinhalese',
        'si_LK' => 'Èdè Sinhalese (Siri Lanka)',
        'sk' => 'Èdè Slovaki',
        'sk_SK' => 'Èdè Slovaki (Silofakia)',
        'sl' => 'Èdè Slovenia',
        'sl_SI' => 'Èdè Slovenia (Silofania)',
        'sn' => 'Ṣọnà',
        'sn_ZW' => 'Ṣọnà (Ṣimibabe)',
        'so' => 'Èdè ara Somalia',
        'so_DJ' => 'Èdè ara Somalia (Díbọ́ótì)',
        'so_ET' => 'Èdè ara Somalia (Etopia)',
        'so_KE' => 'Èdè ara Somalia (Kenya)',
        'so_SO' => 'Èdè ara Somalia (Somalia)',
        'sq' => 'Èdè Albania',
        'sq_AL' => 'Èdè Albania (Àlùbàníánì)',
        'sq_MK' => 'Èdè Albania (Àríwá Macedonia)',
        'sr' => 'Èdè Serbia',
        'sr_BA' => 'Èdè Serbia (Bọ̀síníà àti Ẹtisẹgófínà)',
        'sr_Cyrl' => 'Èdè Serbia (èdè ilẹ̀ Rọ́ṣíà)',
        'sr_Cyrl_BA' => 'Èdè Serbia (èdè ilẹ̀ Rọ́ṣíà, Bọ̀síníà àti Ẹtisẹgófínà)',
        'sr_Cyrl_ME' => 'Èdè Serbia (èdè ilẹ̀ Rọ́ṣíà, Montenegro)',
        'sr_Cyrl_RS' => 'Èdè Serbia (èdè ilẹ̀ Rọ́ṣíà, Sẹ́bíà)',
        'sr_Latn' => 'Èdè Serbia (Èdè Látìn)',
        'sr_Latn_BA' => 'Èdè Serbia (Èdè Látìn, Bọ̀síníà àti Ẹtisẹgófínà)',
        'sr_Latn_ME' => 'Èdè Serbia (Èdè Látìn, Montenegro)',
        'sr_Latn_RS' => 'Èdè Serbia (Èdè Látìn, Sẹ́bíà)',
        'sr_ME' => 'Èdè Serbia (Montenegro)',
        'sr_RS' => 'Èdè Serbia (Sẹ́bíà)',
        'su' => 'Èdè Sudanísì',
        'su_ID' => 'Èdè Sudanísì (Indonesia)',
        'su_Latn' => 'Èdè Sudanísì (Èdè Látìn)',
        'su_Latn_ID' => 'Èdè Sudanísì (Èdè Látìn, Indonesia)',
        'sv' => 'Èdè Suwidiisi',
        'sv_AX' => 'Èdè Suwidiisi (Àwọn Erékùsù ti Åland)',
        'sv_FI' => 'Èdè Suwidiisi (Filandi)',
        'sv_SE' => 'Èdè Suwidiisi (Swidini)',
        'sw' => 'Èdè Swahili',
        'sw_CD' => 'Èdè Swahili (Kóńgò – Kinshasa)',
        'sw_KE' => 'Èdè Swahili (Kenya)',
        'sw_TZ' => 'Èdè Swahili (Tàǹsáníà)',
        'sw_UG' => 'Èdè Swahili (Uganda)',
        'ta' => 'Èdè Tamili',
        'ta_IN' => 'Èdè Tamili (India)',
        'ta_LK' => 'Èdè Tamili (Siri Lanka)',
        'ta_MY' => 'Èdè Tamili (Malasia)',
        'ta_SG' => 'Èdè Tamili (Singapo)',
        'te' => 'Èdè Telugu',
        'te_IN' => 'Èdè Telugu (India)',
        'tg' => 'Tàjíìkì',
        'tg_TJ' => 'Tàjíìkì (Takisitani)',
        'th' => 'Èdè Tai',
        'th_TH' => 'Èdè Tai (Tailandi)',
        'ti' => 'Èdè Tigrinya',
        'ti_ER' => 'Èdè Tigrinya (Eritira)',
        'ti_ET' => 'Èdè Tigrinya (Etopia)',
        'tk' => 'Èdè Turkmen',
        'tk_TM' => 'Èdè Turkmen (Tọọkimenisita)',
        'to' => 'Tóńgàn',
        'to_TO' => 'Tóńgàn (Tonga)',
        'tr' => 'Èdè Tọọkisi',
        'tr_CY' => 'Èdè Tọọkisi (Kúrúsì)',
        'tr_TR' => 'Èdè Tọọkisi (Tọọki)',
        'tt' => 'Tatarí',
        'tt_RU' => 'Tatarí (Rọṣia)',
        'ug' => 'Yúgọ̀',
        'ug_CN' => 'Yúgọ̀ (Ṣáínà)',
        'uk' => 'Èdè Ukania',
        'uk_UA' => 'Èdè Ukania (Ukarini)',
        'ur' => 'Èdè Udu',
        'ur_IN' => 'Èdè Udu (India)',
        'ur_PK' => 'Èdè Udu (Pakisitan)',
        'uz' => 'Èdè Uzbek',
        'uz_AF' => 'Èdè Uzbek (Àfùgànístánì)',
        'uz_Arab' => 'Èdè Uzbek (èdè Lárúbáwá)',
        'uz_Arab_AF' => 'Èdè Uzbek (èdè Lárúbáwá, Àfùgànístánì)',
        'uz_Cyrl' => 'Èdè Uzbek (èdè ilẹ̀ Rọ́ṣíà)',
        'uz_Cyrl_UZ' => 'Èdè Uzbek (èdè ilẹ̀ Rọ́ṣíà, Nṣibẹkisitani)',
        'uz_Latn' => 'Èdè Uzbek (Èdè Látìn)',
        'uz_Latn_UZ' => 'Èdè Uzbek (Èdè Látìn, Nṣibẹkisitani)',
        'uz_UZ' => 'Èdè Uzbek (Nṣibẹkisitani)',
        'vi' => 'Èdè Jetinamu',
        'vi_VN' => 'Èdè Jetinamu (Fẹtinami)',
        'wo' => 'Wọ́lọ́ọ̀fù',
        'wo_SN' => 'Wọ́lọ́ọ̀fù (Sẹnẹga)',
        'xh' => 'Èdè Xhosa',
        'xh_ZA' => 'Èdè Xhosa (Gúúṣù Áfíríkà)',
        'yi' => 'Èdè Yiddishi',
        'yi_001' => 'Èdè Yiddishi (Agbáyé)',
        'yo' => 'Èdè Yorùbá',
        'yo_BJ' => 'Èdè Yorùbá (Bẹ̀nẹ̀)',
        'yo_NG' => 'Èdè Yorùbá (Nàìjíríà)',
        'zh' => 'Edè Ṣáínà',
        'zh_CN' => 'Edè Ṣáínà (Ṣáínà)',
        'zh_HK' => 'Edè Ṣáínà (Agbègbè Ìṣàkóso Ìṣúná Hong Kong Tí Ṣánà Ń Darí)',
        'zh_Hans' => 'Edè Ṣáínà (tí wọ́n mú rọrùn.)',
        'zh_Hans_CN' => 'Edè Ṣáínà (tí wọ́n mú rọrùn., Ṣáínà)',
        'zh_Hans_HK' => 'Edè Ṣáínà (tí wọ́n mú rọrùn., Agbègbè Ìṣàkóso Ìṣúná Hong Kong Tí Ṣánà Ń Darí)',
        'zh_Hans_MO' => 'Edè Ṣáínà (tí wọ́n mú rọrùn., Agbègbè Ìṣàkóso Pàtàkì Macao)',
        'zh_Hans_SG' => 'Edè Ṣáínà (tí wọ́n mú rọrùn., Singapo)',
        'zh_Hant' => 'Edè Ṣáínà (Hans àtọwọ́dọ́wọ́)',
        'zh_Hant_HK' => 'Edè Ṣáínà (Hans àtọwọ́dọ́wọ́, Agbègbè Ìṣàkóso Ìṣúná Hong Kong Tí Ṣánà Ń Darí)',
        'zh_Hant_MO' => 'Edè Ṣáínà (Hans àtọwọ́dọ́wọ́, Agbègbè Ìṣàkóso Pàtàkì Macao)',
        'zh_Hant_TW' => 'Edè Ṣáínà (Hans àtọwọ́dọ́wọ́, Taiwani)',
        'zh_MO' => 'Edè Ṣáínà (Agbègbè Ìṣàkóso Pàtàkì Macao)',
        'zh_SG' => 'Edè Ṣáínà (Singapo)',
        'zh_TW' => 'Edè Ṣáínà (Taiwani)',
        'zu' => 'Èdè Ṣulu',
        'zu_ZA' => 'Èdè Ṣulu (Gúúṣù Áfíríkà)',
    ],
];
