<?php

return [
    'Names' => [
        'ak' => 'Liakan',
        'ak_GH' => 'Liakan (Ngana)',
        'am' => 'Liamhariki',
        'am_ET' => 'Liamhariki (Etshiopi)',
        'ar' => 'Arabi',
        'ar_AE' => 'Arabi (Lemila alabu)',
        'ar_BH' => 'Arabi (Bahrene)',
        'ar_DJ' => 'Arabi (Djibuti)',
        'ar_DZ' => 'Arabi (Alijeri)',
        'ar_EG' => 'Arabi (Mushidi)',
        'ar_ER' => 'Arabi (Elitele)',
        'ar_IL' => 'Arabi (Isirayele)',
        'ar_IQ' => 'Arabi (Iraki)',
        'ar_JO' => 'Arabi (Jodani)',
        'ar_KM' => 'Arabi (Komoru)',
        'ar_KW' => 'Arabi (Koweti)',
        'ar_LB' => 'Arabi (Liba)',
        'ar_LY' => 'Arabi (Libi)',
        'ar_MA' => 'Arabi (Maroke)',
        'ar_MR' => 'Arabi (Moritani)',
        'ar_OM' => 'Arabi (Omane)',
        'ar_PS' => 'Arabi (Palesine)',
        'ar_QA' => 'Arabi (Katari)',
        'ar_SA' => 'Arabi (Alabu Nsawudi)',
        'ar_SD' => 'Arabi (Suda)',
        'ar_SO' => 'Arabi (Somali)',
        'ar_SY' => 'Arabi (Siri)',
        'ar_TD' => 'Arabi (Tshadi)',
        'ar_TN' => 'Arabi (Tinizi)',
        'ar_YE' => 'Arabi (Yemenu)',
        'be' => 'Belarusi',
        'be_BY' => 'Belarusi (Byelorisi)',
        'bg' => 'Bulegari',
        'bg_BG' => 'Bulegari (Biligari)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (Benguladeshi)',
        'bn_IN' => 'Bengali (Inde)',
        'cs' => 'Tsheki',
        'cs_CZ' => 'Tsheki (Ditunga dya Tsheka)',
        'de' => 'Lizelumani',
        'de_AT' => 'Lizelumani (Otilisi)',
        'de_BE' => 'Lizelumani (Belejiki)',
        'de_CH' => 'Lizelumani (Swise)',
        'de_DE' => 'Lizelumani (Alemanu)',
        'de_IT' => 'Lizelumani (Itali)',
        'de_LI' => 'Lizelumani (Lishuteni)',
        'de_LU' => 'Lizelumani (Likisambulu)',
        'el' => 'Giliki',
        'el_CY' => 'Giliki (Shipele)',
        'el_GR' => 'Giliki (Ngeleka)',
        'en' => 'Lingelesa',
        'en_AE' => 'Lingelesa (Lemila alabu)',
        'en_AG' => 'Lingelesa (Antiga ne Barbuda)',
        'en_AI' => 'Lingelesa (Angiye)',
        'en_AS' => 'Lingelesa (Samoa wa Ameriki)',
        'en_AT' => 'Lingelesa (Otilisi)',
        'en_AU' => 'Lingelesa (Ositali)',
        'en_BB' => 'Lingelesa (Barebade)',
        'en_BE' => 'Lingelesa (Belejiki)',
        'en_BI' => 'Lingelesa (Burundi)',
        'en_BM' => 'Lingelesa (Bermuda)',
        'en_BS' => 'Lingelesa (Bahamase)',
        'en_BW' => 'Lingelesa (Mbotswana)',
        'en_BZ' => 'Lingelesa (Belize)',
        'en_CA' => 'Lingelesa (Kanada)',
        'en_CH' => 'Lingelesa (Swise)',
        'en_CK' => 'Lingelesa (Lutanda lua Kookɛ)',
        'en_CM' => 'Lingelesa (Kamerune)',
        'en_CY' => 'Lingelesa (Shipele)',
        'en_DE' => 'Lingelesa (Alemanu)',
        'en_DK' => 'Lingelesa (Danemalaku)',
        'en_DM' => 'Lingelesa (Duminiku)',
        'en_ER' => 'Lingelesa (Elitele)',
        'en_FI' => 'Lingelesa (Filande)',
        'en_FJ' => 'Lingelesa (Fuji)',
        'en_FK' => 'Lingelesa (Lutanda lua Maluni)',
        'en_FM' => 'Lingelesa (Mikronezi)',
        'en_GB' => 'Lingelesa (Angeletele)',
        'en_GD' => 'Lingelesa (Ngelenade)',
        'en_GH' => 'Lingelesa (Ngana)',
        'en_GI' => 'Lingelesa (Jibeletale)',
        'en_GM' => 'Lingelesa (Gambi)',
        'en_GU' => 'Lingelesa (Ngwame)',
        'en_GY' => 'Lingelesa (Ngiyane)',
        'en_IE' => 'Lingelesa (Irelande)',
        'en_IL' => 'Lingelesa (Isirayele)',
        'en_IN' => 'Lingelesa (Inde)',
        'en_IO' => 'Lingelesa (Lutanda lwa Angeletele ku mbu wa Indiya)',
        'en_JM' => 'Lingelesa (Jamaiki)',
        'en_KE' => 'Lingelesa (Kenya)',
        'en_KI' => 'Lingelesa (Kiribati)',
        'en_KN' => 'Lingelesa (Santu krístofe ne Neves)',
        'en_KY' => 'Lingelesa (Lutanda lua Kayima)',
        'en_LC' => 'Lingelesa (Santu lisi)',
        'en_LR' => 'Lingelesa (Liberiya)',
        'en_LS' => 'Lingelesa (Lesoto)',
        'en_MG' => 'Lingelesa (Madagasikari)',
        'en_MH' => 'Lingelesa (Lutanda lua Marishale)',
        'en_MP' => 'Lingelesa (Lutanda lua Mariane wa muulu)',
        'en_MS' => 'Lingelesa (Musera)',
        'en_MT' => 'Lingelesa (Malite)',
        'en_MU' => 'Lingelesa (Morise)',
        'en_MV' => 'Lingelesa (Madive)',
        'en_MW' => 'Lingelesa (Malawi)',
        'en_MY' => 'Lingelesa (Malezi)',
        'en_NA' => 'Lingelesa (Namibi)',
        'en_NF' => 'Lingelesa (Lutanda lua Norfok)',
        'en_NG' => 'Lingelesa (Nijerya)',
        'en_NL' => 'Lingelesa (Olandɛ)',
        'en_NR' => 'Lingelesa (Nauru)',
        'en_NU' => 'Lingelesa (Nyue)',
        'en_NZ' => 'Lingelesa (Zelanda wa mumu)',
        'en_PG' => 'Lingelesa (Papwazi wa Nginɛ wa mumu)',
        'en_PH' => 'Lingelesa (Nfilipi)',
        'en_PK' => 'Lingelesa (Pakisita)',
        'en_PN' => 'Lingelesa (Pikairni)',
        'en_PR' => 'Lingelesa (Mpotoriku)',
        'en_PW' => 'Lingelesa (Palau)',
        'en_RW' => 'Lingelesa (Rwanda)',
        'en_SB' => 'Lingelesa (Lutanda lua Solomu)',
        'en_SC' => 'Lingelesa (Seshele)',
        'en_SD' => 'Lingelesa (Suda)',
        'en_SE' => 'Lingelesa (Suwedi)',
        'en_SG' => 'Lingelesa (Singapure)',
        'en_SH' => 'Lingelesa (Santu eleni)',
        'en_SI' => 'Lingelesa (Siloveni)',
        'en_SL' => 'Lingelesa (Siera Leone)',
        'en_SZ' => 'Lingelesa (Swazilandi)',
        'en_TC' => 'Lingelesa (Lutanda lua Tuluki ne Kaiko)',
        'en_TK' => 'Lingelesa (Tokelau)',
        'en_TO' => 'Lingelesa (Tonga)',
        'en_TT' => 'Lingelesa (Tinidade ne Tobago)',
        'en_TV' => 'Lingelesa (Tuvalu)',
        'en_TZ' => 'Lingelesa (Tanzani)',
        'en_UG' => 'Lingelesa (Uganda)',
        'en_US' => 'Lingelesa (Ameriki)',
        'en_VC' => 'Lingelesa (Santu vesa ne Ngelenadine)',
        'en_VG' => 'Lingelesa (Lutanda lua Vierzi wa Angeletele)',
        'en_VI' => 'Lingelesa (Lutanda lua Vierzi wa Ameriki)',
        'en_VU' => 'Lingelesa (Vanuatu)',
        'en_WS' => 'Lingelesa (Samoa)',
        'en_ZA' => 'Lingelesa (Afrika ya Súdi)',
        'en_ZM' => 'Lingelesa (Zambi)',
        'en_ZW' => 'Lingelesa (Zimbabwe)',
        'es' => 'Lihispania',
        'es_AR' => 'Lihispania (Alijantine)',
        'es_BO' => 'Lihispania (Mbolivi)',
        'es_BR' => 'Lihispania (Mnulezile)',
        'es_BZ' => 'Lihispania (Belize)',
        'es_CL' => 'Lihispania (Shili)',
        'es_CO' => 'Lihispania (Kolombi)',
        'es_CR' => 'Lihispania (Kositarika)',
        'es_CU' => 'Lihispania (Kuba)',
        'es_DO' => 'Lihispania (Ditunga wa Duminiku)',
        'es_EC' => 'Lihispania (Ekwatele)',
        'es_ES' => 'Lihispania (Nsipani)',
        'es_GQ' => 'Lihispania (Gine Ekwatele)',
        'es_GT' => 'Lihispania (Ngwatemala)',
        'es_HN' => 'Lihispania (Ondurase)',
        'es_MX' => 'Lihispania (Meksike)',
        'es_NI' => 'Lihispania (Nikaragwa)',
        'es_PA' => 'Lihispania (Panama)',
        'es_PE' => 'Lihispania (Peru)',
        'es_PH' => 'Lihispania (Nfilipi)',
        'es_PR' => 'Lihispania (Mpotoriku)',
        'es_PY' => 'Lihispania (Palagwei)',
        'es_SV' => 'Lihispania (Savadore)',
        'es_US' => 'Lihispania (Ameriki)',
        'es_UY' => 'Lihispania (Irigwei)',
        'es_VE' => 'Lihispania (Venezuela)',
        'fa' => 'Mpepajemi',
        'fa_AF' => 'Mpepajemi (Afuganisita)',
        'fa_IR' => 'Mpepajemi (Ira)',
        'fr' => 'Mfwàlànsa',
        'fr_BE' => 'Mfwàlànsa (Belejiki)',
        'fr_BF' => 'Mfwàlànsa (Bukinafaso)',
        'fr_BI' => 'Mfwàlànsa (Burundi)',
        'fr_BJ' => 'Mfwàlànsa (Bene)',
        'fr_CA' => 'Mfwàlànsa (Kanada)',
        'fr_CD' => 'Mfwàlànsa (Ditunga wa Kongu)',
        'fr_CF' => 'Mfwàlànsa (Ditunga dya Afrika wa munkatshi)',
        'fr_CG' => 'Mfwàlànsa (Kongu)',
        'fr_CH' => 'Mfwàlànsa (Swise)',
        'fr_CI' => 'Mfwàlànsa (Kotedivuale)',
        'fr_CM' => 'Mfwàlànsa (Kamerune)',
        'fr_DJ' => 'Mfwàlànsa (Djibuti)',
        'fr_DZ' => 'Mfwàlànsa (Alijeri)',
        'fr_FR' => 'Mfwàlànsa (Nfalanse)',
        'fr_GA' => 'Mfwàlànsa (Ngabu)',
        'fr_GF' => 'Mfwàlànsa (Giyane wa Nfalanse)',
        'fr_GN' => 'Mfwàlànsa (Ngine)',
        'fr_GP' => 'Mfwàlànsa (Ngwadelupe)',
        'fr_GQ' => 'Mfwàlànsa (Gine Ekwatele)',
        'fr_HT' => 'Mfwàlànsa (Ayiti)',
        'fr_KM' => 'Mfwàlànsa (Komoru)',
        'fr_LU' => 'Mfwàlànsa (Likisambulu)',
        'fr_MA' => 'Mfwàlànsa (Maroke)',
        'fr_MC' => 'Mfwàlànsa (Monaku)',
        'fr_MG' => 'Mfwàlànsa (Madagasikari)',
        'fr_ML' => 'Mfwàlànsa (Mali)',
        'fr_MQ' => 'Mfwàlànsa (Martiniki)',
        'fr_MR' => 'Mfwàlànsa (Moritani)',
        'fr_MU' => 'Mfwàlànsa (Morise)',
        'fr_NC' => 'Mfwàlànsa (Kaledoni wa mumu)',
        'fr_NE' => 'Mfwàlànsa (Nijere)',
        'fr_PF' => 'Mfwàlànsa (Polinezi wa Nfalanse)',
        'fr_PM' => 'Mfwàlànsa (Santu pététo ne Mikelu)',
        'fr_RE' => 'Mfwàlànsa (Lenyo)',
        'fr_RW' => 'Mfwàlànsa (Rwanda)',
        'fr_SC' => 'Mfwàlànsa (Seshele)',
        'fr_SN' => 'Mfwàlànsa (Senegale)',
        'fr_SY' => 'Mfwàlànsa (Siri)',
        'fr_TD' => 'Mfwàlànsa (Tshadi)',
        'fr_TG' => 'Mfwàlànsa (Togu)',
        'fr_TN' => 'Mfwàlànsa (Tinizi)',
        'fr_VU' => 'Mfwàlànsa (Vanuatu)',
        'fr_WF' => 'Mfwàlànsa (Walise ne Futuna)',
        'fr_YT' => 'Mfwàlànsa (Mayote)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ngana)',
        'ha_NE' => 'Hausa (Nijere)',
        'ha_NG' => 'Hausa (Nijerya)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (Inde)',
        'hu' => 'Hongili',
        'hu_HU' => 'Hongili (Ongili)',
        'id' => 'Lindonezia',
        'id_ID' => 'Lindonezia (Indonezi)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nijerya)',
        'it' => 'Litali',
        'it_CH' => 'Litali (Swise)',
        'it_IT' => 'Litali (Itali)',
        'it_SM' => 'Litali (Santu Marine)',
        'it_VA' => 'Litali (Nvatika)',
        'ja' => 'Liyapani',
        'ja_JP' => 'Liyapani (Japu)',
        'jv' => 'Java',
        'jv_ID' => 'Java (Indonezi)',
        'ko' => 'Likoreya',
        'ko_KP' => 'Likoreya (Kore wa muulu)',
        'ko_KR' => 'Likoreya (Kore wa mwinshi)',
        'lu' => 'Tshiluba',
        'lu_CD' => 'Tshiluba (Ditunga wa Kongu)',
        'ms' => 'Limalezia',
        'ms_BN' => 'Limalezia (Brineyi)',
        'ms_ID' => 'Limalezia (Indonezi)',
        'ms_MY' => 'Limalezia (Malezi)',
        'ms_SG' => 'Limalezia (Singapure)',
        'ne' => 'nepali',
        'ne_IN' => 'nepali (Inde)',
        'ne_NP' => 'nepali (Nepálɛ)',
        'nl' => 'olandi',
        'nl_AW' => 'olandi (Aruba)',
        'nl_BE' => 'olandi (Belejiki)',
        'nl_NL' => 'olandi (Olandɛ)',
        'nl_SR' => 'olandi (Suriname)',
        'pa' => 'Lipunjabi',
        'pa_IN' => 'Lipunjabi (Inde)',
        'pa_PK' => 'Lipunjabi (Pakisita)',
        'pl' => 'Mpoloni',
        'pl_PL' => 'Mpoloni (Mpoloni)',
        'pt' => 'Mputulugɛsi',
        'pt_AO' => 'Mputulugɛsi (Angola)',
        'pt_BR' => 'Mputulugɛsi (Mnulezile)',
        'pt_CH' => 'Mputulugɛsi (Swise)',
        'pt_CV' => 'Mputulugɛsi (Lutanda lua Kapevele)',
        'pt_GQ' => 'Mputulugɛsi (Gine Ekwatele)',
        'pt_GW' => 'Mputulugɛsi (Nginebisau)',
        'pt_LU' => 'Mputulugɛsi (Likisambulu)',
        'pt_MZ' => 'Mputulugɛsi (Mozambiki)',
        'pt_PT' => 'Mputulugɛsi (Mputulugeshi)',
        'pt_ST' => 'Mputulugɛsi (Sao Tome ne Presipɛ)',
        'pt_TL' => 'Mputulugɛsi (Timoru wa diboku)',
        'ro' => 'Liromani',
        'ro_MD' => 'Liromani (Molidavi)',
        'ro_RO' => 'Liromani (Romani)',
        'ru' => 'Lirisi',
        'ru_BY' => 'Lirisi (Byelorisi)',
        'ru_KG' => 'Lirisi (Kigizisita)',
        'ru_KZ' => 'Lirisi (Kazakusita)',
        'ru_MD' => 'Lirisi (Molidavi)',
        'ru_RU' => 'Lirisi (Risi)',
        'ru_UA' => 'Lirisi (Ukreni)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Rwanda)',
        'so' => 'Lisomali',
        'so_DJ' => 'Lisomali (Djibuti)',
        'so_ET' => 'Lisomali (Etshiopi)',
        'so_KE' => 'Lisomali (Kenya)',
        'so_SO' => 'Lisomali (Somali)',
        'sv' => 'Lisuwidi',
        'sv_FI' => 'Lisuwidi (Filande)',
        'sv_SE' => 'Lisuwidi (Suwedi)',
        'ta' => 'Mtamuili',
        'ta_IN' => 'Mtamuili (Inde)',
        'ta_LK' => 'Mtamuili (Sirilanka)',
        'ta_MY' => 'Mtamuili (Malezi)',
        'ta_SG' => 'Mtamuili (Singapure)',
        'th' => 'Ntailandi',
        'th_TH' => 'Ntailandi (Tayilanda)',
        'tr' => 'Ntuluki',
        'tr_CY' => 'Ntuluki (Shipele)',
        'tr_TR' => 'Ntuluki (Tuluki)',
        'uk' => 'Nkrani',
        'uk_UA' => 'Nkrani (Ukreni)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (Inde)',
        'ur_PK' => 'Urdu (Pakisita)',
        'vi' => 'Liviyetinamu',
        'vi_VN' => 'Liviyetinamu (Viyetiname)',
        'yo' => 'Nyoruba',
        'yo_BJ' => 'Nyoruba (Bene)',
        'yo_NG' => 'Nyoruba (Nijerya)',
        'zh' => 'shinɛ',
        'zh_CN' => 'shinɛ (Shine)',
        'zh_SG' => 'shinɛ (Singapure)',
        'zh_TW' => 'shinɛ (Taiwani)',
        'zu' => 'Nzulu',
        'zu_ZA' => 'Nzulu (Afrika ya Súdi)',
    ],
];
