<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'за Гринвічем (Абіджан)',
        'Africa/Accra' => 'за Гринвічем (Аккра)',
        'Africa/Addis_Ababa' => 'за східноафриканським часом (Аддис-Абеба)',
        'Africa/Algiers' => 'за центральноєвропейським часом (Алжир)',
        'Africa/Asmera' => 'за східноафриканським часом (Асмера)',
        'Africa/Bamako' => 'за Гринвічем (Бамако)',
        'Africa/Bangui' => 'за західноафриканським часом (Банґі)',
        'Africa/Banjul' => 'за Гринвічем (Банжул)',
        'Africa/Bissau' => 'за Гринвічем (Бісау)',
        'Africa/Blantyre' => 'за центральноафриканським часом (Блантайр)',
        'Africa/Brazzaville' => 'за західноафриканським часом (Браззавіль)',
        'Africa/Bujumbura' => 'за центральноафриканським часом (Бужумбура)',
        'Africa/Cairo' => 'за східноєвропейським часом (Каїр)',
        'Africa/Casablanca' => 'за західноєвропейським часом (Касабланка)',
        'Africa/Ceuta' => 'за центральноєвропейським часом (Сеута)',
        'Africa/Conakry' => 'за Гринвічем (Конакрі)',
        'Africa/Dakar' => 'за Гринвічем (Дакар)',
        'Africa/Dar_es_Salaam' => 'за східноафриканським часом (Дар-ес-Салам)',
        'Africa/Djibouti' => 'за східноафриканським часом (Джібуті)',
        'Africa/Douala' => 'за західноафриканським часом (Дуала)',
        'Africa/El_Aaiun' => 'за західноєвропейським часом (Ель-Аюн)',
        'Africa/Freetown' => 'за Гринвічем (Фрітаун)',
        'Africa/Gaborone' => 'за центральноафриканським часом (Ґабороне)',
        'Africa/Harare' => 'за центральноафриканським часом (Хараре)',
        'Africa/Johannesburg' => 'за південноафриканським часом (Йоганнесбурґ)',
        'Africa/Juba' => 'за центральноафриканським часом (Джуба)',
        'Africa/Kampala' => 'за східноафриканським часом (Кампала)',
        'Africa/Khartoum' => 'за центральноафриканським часом (Хартум)',
        'Africa/Kigali' => 'за центральноафриканським часом (Кігалі)',
        'Africa/Kinshasa' => 'за західноафриканським часом (Кіншаса)',
        'Africa/Lagos' => 'за західноафриканським часом (Лаґос)',
        'Africa/Libreville' => 'за західноафриканським часом (Лібревіль)',
        'Africa/Lome' => 'за Гринвічем (Ломе)',
        'Africa/Luanda' => 'за західноафриканським часом (Луанда)',
        'Africa/Lubumbashi' => 'за центральноафриканським часом (Лубумбаші)',
        'Africa/Lusaka' => 'за центральноафриканським часом (Лусака)',
        'Africa/Malabo' => 'за західноафриканським часом (Малабо)',
        'Africa/Maputo' => 'за центральноафриканським часом (Мапуту)',
        'Africa/Maseru' => 'за південноафриканським часом (Масеру)',
        'Africa/Mbabane' => 'за південноафриканським часом (Мбабане)',
        'Africa/Mogadishu' => 'за східноафриканським часом (Моґадішо)',
        'Africa/Monrovia' => 'за Гринвічем (Монровія)',
        'Africa/Nairobi' => 'за східноафриканським часом (Найробі)',
        'Africa/Ndjamena' => 'за західноафриканським часом (Нджамена)',
        'Africa/Niamey' => 'за західноафриканським часом (Ніамей)',
        'Africa/Nouakchott' => 'за Гринвічем (Нуакшотт)',
        'Africa/Ouagadougou' => 'за Гринвічем (Уаґадуґу)',
        'Africa/Porto-Novo' => 'за західноафриканським часом (Порто-Ново)',
        'Africa/Sao_Tome' => 'за Гринвічем (Сан-Томе)',
        'Africa/Tripoli' => 'за східноєвропейським часом (Триполі)',
        'Africa/Tunis' => 'за центральноєвропейським часом (Туніс)',
        'Africa/Windhoek' => 'за центральноафриканським часом (Віндгук)',
        'America/Adak' => 'за гавайсько-алеутським часом (Адак)',
        'America/Anchorage' => 'за часом на Алясці (Анкоридж)',
        'America/Anguilla' => 'за атлантичним часом (Анґілья)',
        'America/Antigua' => 'за атлантичним часом (Антиґуа)',
        'America/Araguaina' => 'за бразильським часом (Араґуаіна)',
        'America/Argentina/La_Rioja' => 'за аргентинським часом (Ла-Ріоха)',
        'America/Argentina/Rio_Gallegos' => 'за аргентинським часом (Ріо-Ґальєґос)',
        'America/Argentina/Salta' => 'за аргентинським часом (Сальта)',
        'America/Argentina/San_Juan' => 'за аргентинським часом (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'за аргентинським часом (Сан-Луїс)',
        'America/Argentina/Tucuman' => 'за аргентинським часом (Тукуман)',
        'America/Argentina/Ushuaia' => 'за аргентинським часом (Ушуая)',
        'America/Aruba' => 'за атлантичним часом (Аруба)',
        'America/Asuncion' => 'за параґвайським часом (Асунсьйон)',
        'America/Bahia' => 'за бразильським часом (Байя)',
        'America/Bahia_Banderas' => 'за північноамериканським центральним часом (Баїя Бандерас)',
        'America/Barbados' => 'за атлантичним часом (Барбадос)',
        'America/Belem' => 'за бразильським часом (Белен)',
        'America/Belize' => 'за північноамериканським центральним часом (Беліз)',
        'America/Blanc-Sablon' => 'за атлантичним часом (Блан-Саблон)',
        'America/Boa_Vista' => 'за часом на Амазонці (Боа-Віста)',
        'America/Bogota' => 'за колумбійським часом (Боґота)',
        'America/Boise' => 'за північноамериканським гірським часом (Бойсе)',
        'America/Buenos_Aires' => 'за аргентинським часом (Буенос-Айрес)',
        'America/Cambridge_Bay' => 'за північноамериканським гірським часом (Кеймбрідж-Бей)',
        'America/Campo_Grande' => 'за часом на Амазонці (Кампу-Ґранді)',
        'America/Cancun' => 'за північноамериканським східним часом (Канкун)',
        'America/Caracas' => 'за часом у Венесуелі (Каракас)',
        'America/Catamarca' => 'за аргентинським часом (Катамарка)',
        'America/Cayenne' => 'за часом Французької Ґвіани (Каєнна)',
        'America/Cayman' => 'за північноамериканським східним часом (Кайманові Острови)',
        'America/Chicago' => 'за північноамериканським центральним часом (Чікаґо)',
        'America/Chihuahua' => 'за тихоокеанським часом у Мексиці (Чіуауа)',
        'America/Coral_Harbour' => 'за північноамериканським східним часом (Атікокан)',
        'America/Cordoba' => 'за аргентинським часом (Кордова)',
        'America/Costa_Rica' => 'за північноамериканським центральним часом (Коста-Ріка)',
        'America/Creston' => 'за північноамериканським гірським часом (Крестон)',
        'America/Cuiaba' => 'за часом на Амазонці (Куяба)',
        'America/Curacao' => 'за атлантичним часом (Кюрасао)',
        'America/Danmarkshavn' => 'за Гринвічем (Денмарксхавн)',
        'America/Dawson' => 'за стандартним часом на Юконі (Доусон)',
        'America/Dawson_Creek' => 'за північноамериканським гірським часом (Доусон-Крік)',
        'America/Denver' => 'за північноамериканським гірським часом (Денвер)',
        'America/Detroit' => 'за північноамериканським східним часом (Детройт)',
        'America/Dominica' => 'за атлантичним часом (Домініка)',
        'America/Edmonton' => 'за північноамериканським гірським часом (Едмонтон)',
        'America/Eirunepe' => 'час: Акрі (Ейрунепе)',
        'America/El_Salvador' => 'за північноамериканським центральним часом (Сальвадор)',
        'America/Fort_Nelson' => 'за північноамериканським гірським часом (Форт Нельсон)',
        'America/Fortaleza' => 'за бразильським часом (Форталеза)',
        'America/Glace_Bay' => 'за атлантичним часом (Ґлейс-Бей)',
        'America/Godthab' => 'за західним часом у Ґренландії (Нуук)',
        'America/Goose_Bay' => 'за атлантичним часом (Ґус-Бей)',
        'America/Grand_Turk' => 'за північноамериканським східним часом (Ґранд-Терк)',
        'America/Grenada' => 'за атлантичним часом (Ґренада)',
        'America/Guadeloupe' => 'за атлантичним часом (Ґваделупа)',
        'America/Guatemala' => 'за північноамериканським центральним часом (Ґватемала)',
        'America/Guayaquil' => 'за часом в Еквадорі (Ґуаякіль)',
        'America/Guyana' => 'за часом у Ґаяні (Ґайана)',
        'America/Halifax' => 'за атлантичним часом (Галіфакс)',
        'America/Havana' => 'за часом на Кубі (Гавана)',
        'America/Hermosillo' => 'за тихоокеанським часом у Мексиці (Ермосільйо)',
        'America/Indiana/Knox' => 'за північноамериканським центральним часом (Нокс, Індіана)',
        'America/Indiana/Marengo' => 'за північноамериканським східним часом (Маренго, Індіана)',
        'America/Indiana/Petersburg' => 'за північноамериканським східним часом (Пітерсберг, Індіана)',
        'America/Indiana/Tell_City' => 'за північноамериканським центральним часом (Телл-Сіті, Індіана)',
        'America/Indiana/Vevay' => 'за північноамериканським східним часом (Вівей, Індіана)',
        'America/Indiana/Vincennes' => 'за північноамериканським східним часом (Вінсенс, Індіана)',
        'America/Indiana/Winamac' => 'за північноамериканським східним часом (Вінамак, Індіана)',
        'America/Indianapolis' => 'за північноамериканським східним часом (Індіанаполіс)',
        'America/Inuvik' => 'за північноамериканським гірським часом (Інувік)',
        'America/Iqaluit' => 'за північноамериканським східним часом (Ікалуїт)',
        'America/Jamaica' => 'за північноамериканським східним часом (Ямайка)',
        'America/Jujuy' => 'за аргентинським часом (Жужуй)',
        'America/Juneau' => 'за часом на Алясці (Джуно)',
        'America/Kentucky/Monticello' => 'за північноамериканським східним часом (Монтіселло, Кентуккі)',
        'America/Kralendijk' => 'за атлантичним часом (Кралендейк)',
        'America/La_Paz' => 'за болівійським часом (Ла-Пас)',
        'America/Lima' => 'за часом у Перу (Ліма)',
        'America/Los_Angeles' => 'за північноамериканським тихоокеанським часом (Лос-Анджелес)',
        'America/Louisville' => 'за північноамериканським східним часом (Луїсвілл)',
        'America/Lower_Princes' => 'за атлантичним часом (Лоуер-Принсес-Квотер)',
        'America/Maceio' => 'за бразильським часом (Масейо)',
        'America/Managua' => 'за північноамериканським центральним часом (Манаґуа)',
        'America/Manaus' => 'за часом на Амазонці (Манаус)',
        'America/Marigot' => 'за атлантичним часом (Маріґо)',
        'America/Martinique' => 'за атлантичним часом (Мартініка)',
        'America/Matamoros' => 'за північноамериканським центральним часом (Матаморос)',
        'America/Mazatlan' => 'за тихоокеанським часом у Мексиці (Масатлан)',
        'America/Mendoza' => 'за аргентинським часом (Мендоса)',
        'America/Menominee' => 'за північноамериканським центральним часом (Меноміні)',
        'America/Merida' => 'за північноамериканським центральним часом (Меріда)',
        'America/Metlakatla' => 'за часом на Алясці (Метлакатла)',
        'America/Mexico_City' => 'за північноамериканським центральним часом (Мехіко)',
        'America/Miquelon' => 'за часом на островах Сен-П’єр і Мікелон',
        'America/Moncton' => 'за атлантичним часом (Монктон)',
        'America/Monterrey' => 'за північноамериканським центральним часом (Монтерей)',
        'America/Montevideo' => 'за часом в Уруґваї (Монтевідео)',
        'America/Montreal' => 'час: Канада (Montreal)',
        'America/Montserrat' => 'за атлантичним часом (Монтсеррат)',
        'America/Nassau' => 'за північноамериканським східним часом (Насау)',
        'America/New_York' => 'за північноамериканським східним часом (Нью-Йорк)',
        'America/Nipigon' => 'за північноамериканським східним часом (Ніпігон)',
        'America/Nome' => 'за часом на Алясці (Ном)',
        'America/Noronha' => 'за часом на архіпелазі Фернанду-ді-Норонья',
        'America/North_Dakota/Beulah' => 'за північноамериканським центральним часом (Бʼюла, Північна Дакота)',
        'America/North_Dakota/Center' => 'за північноамериканським центральним часом (Сентр, Північна Дакота)',
        'America/North_Dakota/New_Salem' => 'за північноамериканським центральним часом (Нью-Салем, Північна Дакота)',
        'America/Ojinaga' => 'за північноамериканським гірським часом (Охінаґа)',
        'America/Panama' => 'за північноамериканським східним часом (Панама)',
        'America/Pangnirtung' => 'за північноамериканським східним часом (Панґніртанґ)',
        'America/Paramaribo' => 'за часом у Суринамі (Парамарибо)',
        'America/Phoenix' => 'за північноамериканським гірським часом (Фінікс)',
        'America/Port-au-Prince' => 'за північноамериканським східним часом (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'за атлантичним часом (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'за часом на Амазонці (Порту-Велью)',
        'America/Puerto_Rico' => 'за атлантичним часом (Пуерто-Ріко)',
        'America/Punta_Arenas' => 'за чилійським часом (Пунта-Аренас)',
        'America/Rainy_River' => 'за північноамериканським центральним часом (Рейні-Рівер)',
        'America/Rankin_Inlet' => 'за північноамериканським центральним часом (Ренкін-Інлет)',
        'America/Recife' => 'за бразильським часом (Ресіфі)',
        'America/Regina' => 'за північноамериканським центральним часом (Реджайна)',
        'America/Resolute' => 'за північноамериканським центральним часом (Резольют)',
        'America/Rio_Branco' => 'час: Акрі (Ріо-Бранко)',
        'America/Santa_Isabel' => 'за північнозахідним часом у Мексиці (Санта-Ісабель)',
        'America/Santarem' => 'за бразильським часом (Сантарен)',
        'America/Santiago' => 'за чилійським часом (Сантьяґо)',
        'America/Santo_Domingo' => 'за атлантичним часом (Санто-Домінґо)',
        'America/Sao_Paulo' => 'за бразильським часом (Сан-Паулу)',
        'America/Scoresbysund' => 'за східним часом у Ґренландії (Іттоккортоорміут)',
        'America/Sitka' => 'за часом на Алясці (Сітка)',
        'America/St_Barthelemy' => 'за атлантичним часом (Сен-Бартелемі)',
        'America/St_Johns' => 'за часом на острові Ньюфаундленд (Сент-Джонс)',
        'America/St_Kitts' => 'за атлантичним часом (Сент-Кіттс)',
        'America/St_Lucia' => 'за атлантичним часом (Сент-Люсія)',
        'America/St_Thomas' => 'за атлантичним часом (Сент-Томас)',
        'America/St_Vincent' => 'за атлантичним часом (Сент-Вінсент)',
        'America/Swift_Current' => 'за північноамериканським центральним часом (Свіфт-Каррент)',
        'America/Tegucigalpa' => 'за північноамериканським центральним часом (Теґусіґальпа)',
        'America/Thule' => 'за атлантичним часом (Туле)',
        'America/Thunder_Bay' => 'за північноамериканським східним часом (Тандер-Бей)',
        'America/Tijuana' => 'за північноамериканським тихоокеанським часом (Тіхуана)',
        'America/Toronto' => 'за північноамериканським східним часом (Торонто)',
        'America/Tortola' => 'за атлантичним часом (Тортола)',
        'America/Vancouver' => 'за північноамериканським тихоокеанським часом (Ванкувер)',
        'America/Whitehorse' => 'за стандартним часом на Юконі (Вайтгорс)',
        'America/Winnipeg' => 'за північноамериканським центральним часом (Вінніпеґ)',
        'America/Yakutat' => 'за часом на Алясці (Якутат)',
        'America/Yellowknife' => 'за північноамериканським гірським часом (Єллоунайф)',
        'Antarctica/Casey' => 'час: Антарктика (Кейсі)',
        'Antarctica/Davis' => 'за часом у Девіс',
        'Antarctica/DumontDUrville' => 'за часом у Дюмон дʼЮрвіль',
        'Antarctica/Macquarie' => 'за східноавстралійським часом (Маккуорі)',
        'Antarctica/Mawson' => 'за часом на станції Моусон',
        'Antarctica/McMurdo' => 'за часом у Новій Зеландії (Мак-Мердо)',
        'Antarctica/Palmer' => 'за чилійським часом (Палмер)',
        'Antarctica/Rothera' => 'за часом на станції Ротера',
        'Antarctica/Syowa' => 'за часом на станції Сева (Сьова)',
        'Antarctica/Troll' => 'за Гринвічем (Тролл)',
        'Antarctica/Vostok' => 'за часом на станції Восток',
        'Arctic/Longyearbyen' => 'за центральноєвропейським часом (Лонгʼїр)',
        'Asia/Aden' => 'за арабським часом (Аден)',
        'Asia/Almaty' => 'за східним часом у Казахстані (Алмати)',
        'Asia/Amman' => 'за східноєвропейським часом (Амман)',
        'Asia/Anadyr' => 'час: Анадир',
        'Asia/Aqtau' => 'за західним часом у Казахстані (Актау)',
        'Asia/Aqtobe' => 'за західним часом у Казахстані (Актобе)',
        'Asia/Ashgabat' => 'за часом у Туркменістані (Ашгабат)',
        'Asia/Atyrau' => 'за західним часом у Казахстані (Атирау)',
        'Asia/Baghdad' => 'за арабським часом (Багдад)',
        'Asia/Bahrain' => 'за арабським часом (Бахрейн)',
        'Asia/Baku' => 'за часом в Азербайджані (Баку)',
        'Asia/Bangkok' => 'за часом в Індокитаї (Бангкок)',
        'Asia/Barnaul' => 'час: Росія (Барнаул)',
        'Asia/Beirut' => 'за східноєвропейським часом (Бейрут)',
        'Asia/Bishkek' => 'за часом у Киргизстані (Бішкек)',
        'Asia/Brunei' => 'за часом у Брунеї (Бруней)',
        'Asia/Calcutta' => 'за індійським стандартним часом (Колката)',
        'Asia/Chita' => 'за якутським часом (Чита)',
        'Asia/Choibalsan' => 'за часом в Улан-Баторі (Чойбалсан)',
        'Asia/Colombo' => 'за індійським стандартним часом (Коломбо)',
        'Asia/Damascus' => 'за східноєвропейським часом (Дамаск)',
        'Asia/Dhaka' => 'за часом у Бангладеш (Дакка)',
        'Asia/Dili' => 'за часом у Східному Тиморі (Ділі)',
        'Asia/Dubai' => 'за часом Перської затоки (Дубай)',
        'Asia/Dushanbe' => 'за часом у Таджикистані (Душанбе)',
        'Asia/Famagusta' => 'за східноєвропейським часом (Фамагуста)',
        'Asia/Gaza' => 'за східноєвропейським часом (Газа)',
        'Asia/Hebron' => 'за східноєвропейським часом (Хеврон)',
        'Asia/Hong_Kong' => 'за часом у Гонконзі (Гонконг)',
        'Asia/Hovd' => 'за часом у Ховді',
        'Asia/Irkutsk' => 'за іркутським часом',
        'Asia/Jakarta' => 'за західноіндонезійським часом (Джакарта)',
        'Asia/Jayapura' => 'за східноіндонезійським часом (Джайпур)',
        'Asia/Jerusalem' => 'за ізраїльським часом (Єрусалим)',
        'Asia/Kabul' => 'за часом в Афганістані (Кабул)',
        'Asia/Kamchatka' => 'за камчатським часом (Камчатка)',
        'Asia/Karachi' => 'за часом у Пакистані (Карачі)',
        'Asia/Katmandu' => 'за часом у Непалі (Катманду)',
        'Asia/Khandyga' => 'за якутським часом (Хандига)',
        'Asia/Krasnoyarsk' => 'за красноярським часом',
        'Asia/Kuala_Lumpur' => 'за часом у Малайзії (Куала-Лумпур)',
        'Asia/Kuching' => 'за часом у Малайзії (Кучинг)',
        'Asia/Kuwait' => 'за арабським часом (Кувейт)',
        'Asia/Macau' => 'за китайським часом (Макао)',
        'Asia/Magadan' => 'за магаданським часом',
        'Asia/Makassar' => 'за центральноіндонезійським часом (Макассар)',
        'Asia/Manila' => 'за часом на Філіппінах (Маніла)',
        'Asia/Muscat' => 'за часом Перської затоки (Маскат)',
        'Asia/Nicosia' => 'за східноєвропейським часом (Нікосія)',
        'Asia/Novokuznetsk' => 'за красноярським часом (Новокузнецьк)',
        'Asia/Novosibirsk' => 'за новосибірським часом',
        'Asia/Omsk' => 'за омським часом',
        'Asia/Oral' => 'за західним часом у Казахстані (Орал)',
        'Asia/Phnom_Penh' => 'за часом в Індокитаї (Пномпень)',
        'Asia/Pontianak' => 'за західноіндонезійським часом (Понтіанак)',
        'Asia/Pyongyang' => 'за корейським часом (Пхеньян)',
        'Asia/Qatar' => 'за арабським часом (Катар)',
        'Asia/Qostanay' => 'за східним часом у Казахстані (Костанай)',
        'Asia/Qyzylorda' => 'за західним часом у Казахстані (Кизилорда)',
        'Asia/Rangoon' => 'за часом у Мʼянмі (Янгон)',
        'Asia/Riyadh' => 'за арабським часом (Ер-Ріяд)',
        'Asia/Saigon' => 'за часом в Індокитаї (Хошимін)',
        'Asia/Sakhalin' => 'за сахалінським часом',
        'Asia/Samarkand' => 'за часом в Узбекистані (Самарканд)',
        'Asia/Seoul' => 'за корейським часом (Сеул)',
        'Asia/Shanghai' => 'за китайським часом (Шанхай)',
        'Asia/Singapore' => 'за часом у Сінгапурі',
        'Asia/Srednekolymsk' => 'за магаданським часом (Середньоколимськ)',
        'Asia/Taipei' => 'за часом у Тайбеї (Тайбей)',
        'Asia/Tashkent' => 'за часом в Узбекистані (Ташкент)',
        'Asia/Tbilisi' => 'за часом у Грузії (Тбілісі)',
        'Asia/Tehran' => 'за іранським часом (Тегеран)',
        'Asia/Thimphu' => 'за часом у Бутані (Тхімпху)',
        'Asia/Tokyo' => 'за японським часом (Токіо)',
        'Asia/Tomsk' => 'час: Росія (Томськ)',
        'Asia/Ulaanbaatar' => 'за часом в Улан-Баторі',
        'Asia/Urumqi' => 'час: Китай (Урумчі)',
        'Asia/Ust-Nera' => 'за владивостоцьким часом (Усть-Нера)',
        'Asia/Vientiane' => 'за часом в Індокитаї (Вʼєнтьян)',
        'Asia/Vladivostok' => 'за владивостоцьким часом (Владивосток)',
        'Asia/Yakutsk' => 'за якутським часом',
        'Asia/Yekaterinburg' => 'за єкатеринбурзьким часом (Єкатеринбург)',
        'Asia/Yerevan' => 'за вірменським часом (Єреван)',
        'Atlantic/Azores' => 'за часом на Азорських Островах (Азорські Острови)',
        'Atlantic/Bermuda' => 'за атлантичним часом (Бермуди)',
        'Atlantic/Canary' => 'за західноєвропейським часом (Канарські Острови)',
        'Atlantic/Cape_Verde' => 'за часом на островах Кабо-Верде',
        'Atlantic/Faeroe' => 'за західноєвропейським часом (Фарерські Острови)',
        'Atlantic/Madeira' => 'за західноєвропейським часом (Мадейра)',
        'Atlantic/Reykjavik' => 'за Гринвічем (Рейкʼявік)',
        'Atlantic/South_Georgia' => 'за часом на острові Південна Джорджія',
        'Atlantic/St_Helena' => 'за Гринвічем (Острів Святої Єлени)',
        'Atlantic/Stanley' => 'за часом на Фолклендських Островах (Стенлі)',
        'Australia/Adelaide' => 'за центральноавстралійським часом (Аделаїда)',
        'Australia/Brisbane' => 'за східноавстралійським часом (Брісбен)',
        'Australia/Broken_Hill' => 'за центральноавстралійським часом (Брокен-Хілл)',
        'Australia/Currie' => 'за східноавстралійським часом (Каррі)',
        'Australia/Darwin' => 'за центральноавстралійським часом (Дарвін)',
        'Australia/Eucla' => 'за центральнозахідним австралійським часом (Евкла)',
        'Australia/Hobart' => 'за східноавстралійським часом (Гобарт)',
        'Australia/Lindeman' => 'за східноавстралійським часом (Ліндеман)',
        'Australia/Lord_Howe' => 'за часом на острові Лорд-Хау',
        'Australia/Melbourne' => 'за східноавстралійським часом (Мельбурн)',
        'Australia/Perth' => 'за західноавстралійським часом (Перт)',
        'Australia/Sydney' => 'за східноавстралійським часом (Сідней)',
        'CST6CDT' => 'за північноамериканським центральним часом',
        'EST5EDT' => 'за північноамериканським східним часом',
        'Etc/GMT' => 'за Гринвічем',
        'Etc/UTC' => 'за всесвітнім координованим часом',
        'Europe/Amsterdam' => 'за центральноєвропейським часом (Амстердам)',
        'Europe/Andorra' => 'за центральноєвропейським часом (Андорра)',
        'Europe/Astrakhan' => 'за московським часом (Астрахань)',
        'Europe/Athens' => 'за східноєвропейським часом (Афіни)',
        'Europe/Belgrade' => 'за центральноєвропейським часом (Белград)',
        'Europe/Berlin' => 'за центральноєвропейським часом (Берлін)',
        'Europe/Bratislava' => 'за центральноєвропейським часом (Братислава)',
        'Europe/Brussels' => 'за центральноєвропейським часом (Брюссель)',
        'Europe/Bucharest' => 'за східноєвропейським часом (Бухарест)',
        'Europe/Budapest' => 'за центральноєвропейським часом (Будапешт)',
        'Europe/Busingen' => 'за центральноєвропейським часом (Бюзінген)',
        'Europe/Chisinau' => 'за східноєвропейським часом (Кишинів)',
        'Europe/Copenhagen' => 'за центральноєвропейським часом (Копенгаген)',
        'Europe/Dublin' => 'за Гринвічем (Дублін)',
        'Europe/Gibraltar' => 'за центральноєвропейським часом (Гібралтар)',
        'Europe/Guernsey' => 'за Гринвічем (Гернсі)',
        'Europe/Helsinki' => 'за східноєвропейським часом (Гельсінкі)',
        'Europe/Isle_of_Man' => 'за Гринвічем (Острів Мен)',
        'Europe/Istanbul' => 'час: Туреччина (Стамбул)',
        'Europe/Jersey' => 'за Гринвічем (Джерсі)',
        'Europe/Kaliningrad' => 'за східноєвропейським часом (Калінінград)',
        'Europe/Kiev' => 'за східноєвропейським часом (Київ)',
        'Europe/Kirov' => 'час: Росія (Кіров)',
        'Europe/Lisbon' => 'за західноєвропейським часом (Лісабон)',
        'Europe/Ljubljana' => 'за центральноєвропейським часом (Любляна)',
        'Europe/London' => 'за Гринвічем (Лондон)',
        'Europe/Luxembourg' => 'за центральноєвропейським часом (Люксембург)',
        'Europe/Madrid' => 'за центральноєвропейським часом (Мадрид)',
        'Europe/Malta' => 'за центральноєвропейським часом (Мальта)',
        'Europe/Mariehamn' => 'за східноєвропейським часом (Марієгамн)',
        'Europe/Minsk' => 'за московським часом (Мінськ)',
        'Europe/Monaco' => 'за центральноєвропейським часом (Монако)',
        'Europe/Moscow' => 'за московським часом (Москва)',
        'Europe/Oslo' => 'за центральноєвропейським часом (Осло)',
        'Europe/Paris' => 'за центральноєвропейським часом (Париж)',
        'Europe/Podgorica' => 'за центральноєвропейським часом (Подгориця)',
        'Europe/Prague' => 'за центральноєвропейським часом (Прага)',
        'Europe/Riga' => 'за східноєвропейським часом (Рига)',
        'Europe/Rome' => 'за центральноєвропейським часом (Рим)',
        'Europe/Samara' => 'за самарським часом (Самара)',
        'Europe/San_Marino' => 'за центральноєвропейським часом (Сан-Марино)',
        'Europe/Sarajevo' => 'за центральноєвропейським часом (Сараєво)',
        'Europe/Saratov' => 'за московським часом (Саратов)',
        'Europe/Simferopol' => 'за московським часом (Сімферополь)',
        'Europe/Skopje' => 'за центральноєвропейським часом (Скопʼє)',
        'Europe/Sofia' => 'за східноєвропейським часом (Софія)',
        'Europe/Stockholm' => 'за центральноєвропейським часом (Стокгольм)',
        'Europe/Tallinn' => 'за східноєвропейським часом (Таллінн)',
        'Europe/Tirane' => 'за центральноєвропейським часом (Тирана)',
        'Europe/Ulyanovsk' => 'за московським часом (Ульяновськ)',
        'Europe/Uzhgorod' => 'за східноєвропейським часом (Ужгород)',
        'Europe/Vaduz' => 'за центральноєвропейським часом (Вадуц)',
        'Europe/Vatican' => 'за центральноєвропейським часом (Ватикан)',
        'Europe/Vienna' => 'за центральноєвропейським часом (Відень)',
        'Europe/Vilnius' => 'за східноєвропейським часом (Вільнюс)',
        'Europe/Volgograd' => 'за волгоградським часом',
        'Europe/Warsaw' => 'за центральноєвропейським часом (Варшава)',
        'Europe/Zagreb' => 'за центральноєвропейським часом (Загреб)',
        'Europe/Zaporozhye' => 'за східноєвропейським часом (Запоріжжя)',
        'Europe/Zurich' => 'за центральноєвропейським часом (Цюріх)',
        'Indian/Antananarivo' => 'за східноафриканським часом (Антананаріву)',
        'Indian/Chagos' => 'за часом в Індійському Океані (Чаґос)',
        'Indian/Christmas' => 'за часом на острові Різдва (Острів Різдва)',
        'Indian/Cocos' => 'за часом на Кокосових Островах (Кокосові Острови)',
        'Indian/Comoro' => 'за східноафриканським часом (Комори)',
        'Indian/Kerguelen' => 'за часом на Французьких Південних і Антарктичних територіях (Керґелен)',
        'Indian/Mahe' => 'за часом на Сейшельських Островах (Махе)',
        'Indian/Maldives' => 'за часом на Мальдівах (Мальдіви)',
        'Indian/Mauritius' => 'за часом на острові Маврикій',
        'Indian/Mayotte' => 'за східноафриканським часом (Майотта)',
        'Indian/Reunion' => 'за часом на острові Реюньйон',
        'MST7MDT' => 'за північноамериканським гірським часом',
        'PST8PDT' => 'за північноамериканським тихоокеанським часом',
        'Pacific/Apia' => 'за часом в Апіа',
        'Pacific/Auckland' => 'за часом у Новій Зеландії (Окленд)',
        'Pacific/Bougainville' => 'за часом на островах Папуа-Нова Ґвінея (Буґенвіль)',
        'Pacific/Chatham' => 'за часом на архіпелазі Чатем',
        'Pacific/Easter' => 'за часом на острові Пасхи (Острів Пасхи)',
        'Pacific/Efate' => 'за часом на островах Вануату (Ефате)',
        'Pacific/Enderbury' => 'за часом на островах Фенікс (Ендербері)',
        'Pacific/Fakaofo' => 'за часом на островах Токелау (Факаофо)',
        'Pacific/Fiji' => 'за часом на Фіджі',
        'Pacific/Funafuti' => 'за часом на островах Тувалу (Фунафуті)',
        'Pacific/Galapagos' => 'за часом Ґалапаґосу',
        'Pacific/Gambier' => 'за часом на острові Ґамбʼє (Гамбʼє)',
        'Pacific/Guadalcanal' => 'за часом на Соломонових Островах (Гуадалканал)',
        'Pacific/Guam' => 'за часом на Північних Маріанських островах (Гуам)',
        'Pacific/Honolulu' => 'за гавайсько-алеутським часом (Гонолулу)',
        'Pacific/Johnston' => 'за гавайсько-алеутським часом (Джонстон)',
        'Pacific/Kiritimati' => 'за часом на острові Лайн (Кірітіматі)',
        'Pacific/Kosrae' => 'за часом на острові Косрае',
        'Pacific/Kwajalein' => 'за часом на Маршаллових Островах (Кваджалейн)',
        'Pacific/Majuro' => 'за часом на Маршаллових Островах (Маджуро)',
        'Pacific/Marquesas' => 'за часом на Маркізьких островах (Маркізькі острови)',
        'Pacific/Midway' => 'за часом на острові Самоа (Мідвей)',
        'Pacific/Nauru' => 'за часом на острові Науру',
        'Pacific/Niue' => 'за часом на острові Ніуе',
        'Pacific/Norfolk' => 'за часом на острові Норфолк',
        'Pacific/Noumea' => 'за часом на островах Нової Каледонії (Нумеа)',
        'Pacific/Pago_Pago' => 'за часом на острові Самоа (Паго-Паго)',
        'Pacific/Palau' => 'за часом на острові Палау',
        'Pacific/Pitcairn' => 'за часом на островах Піткерн',
        'Pacific/Ponape' => 'за часом на острові Понапе',
        'Pacific/Port_Moresby' => 'за часом на островах Папуа-Нова Ґвінея (Порт-Морсбі)',
        'Pacific/Rarotonga' => 'за часом на Островах Кука (Раротонга)',
        'Pacific/Saipan' => 'за часом на Північних Маріанських островах (Сайпан)',
        'Pacific/Tahiti' => 'за часом на острові Таїті',
        'Pacific/Tarawa' => 'за часом на островах Гілберта (Тарава)',
        'Pacific/Tongatapu' => 'за часом на островах Тонга (Тонгатапу)',
        'Pacific/Truk' => 'за часом на островах Чуук',
        'Pacific/Wake' => 'за часом на острові Вейк',
        'Pacific/Wallis' => 'за часом на островах Уолліс і Футуна',
    ],
    'Meta' => [
    ],
];
