<?php

return [
    'Names' => [
        'af' => 'աֆրիկաանս',
        'af_NA' => 'աֆրիկաանս (Նամիբիա)',
        'af_ZA' => 'աֆրիկաանս (Հարավաֆրիկյան Հանրապետություն)',
        'ak' => 'աքան',
        'ak_GH' => 'աքան (Գանա)',
        'am' => 'ամհարերեն',
        'am_ET' => 'ամհարերեն (Եթովպիա)',
        'ar' => 'արաբերեն',
        'ar_001' => 'արաբերեն (Աշխարհ)',
        'ar_AE' => 'արաբերեն (Արաբական Միացյալ Էմիրություններ)',
        'ar_BH' => 'արաբերեն (Բահրեյն)',
        'ar_DJ' => 'արաբերեն (Ջիբութի)',
        'ar_DZ' => 'արաբերեն (Ալժիր)',
        'ar_EG' => 'արաբերեն (Եգիպտոս)',
        'ar_EH' => 'արաբերեն (Արևմտյան Սահարա)',
        'ar_ER' => 'արաբերեն (Էրիթրեա)',
        'ar_IL' => 'արաբերեն (Իսրայել)',
        'ar_IQ' => 'արաբերեն (Իրաք)',
        'ar_JO' => 'արաբերեն (Հորդանան)',
        'ar_KM' => 'արաբերեն (Կոմորյան կղզիներ)',
        'ar_KW' => 'արաբերեն (Քուվեյթ)',
        'ar_LB' => 'արաբերեն (Լիբանան)',
        'ar_LY' => 'արաբերեն (Լիբիա)',
        'ar_MA' => 'արաբերեն (Մարոկկո)',
        'ar_MR' => 'արաբերեն (Մավրիտանիա)',
        'ar_OM' => 'արաբերեն (Օման)',
        'ar_PS' => 'արաբերեն (Պաղեստինյան տարածքներ)',
        'ar_QA' => 'արաբերեն (Կատար)',
        'ar_SA' => 'արաբերեն (Սաուդյան Արաբիա)',
        'ar_SD' => 'արաբերեն (Սուդան)',
        'ar_SO' => 'արաբերեն (Սոմալի)',
        'ar_SS' => 'արաբերեն (Հարավային Սուդան)',
        'ar_SY' => 'արաբերեն (Սիրիա)',
        'ar_TD' => 'արաբերեն (Չադ)',
        'ar_TN' => 'արաբերեն (Թունիս)',
        'ar_YE' => 'արաբերեն (Եմեն)',
        'as' => 'ասամերեն',
        'as_IN' => 'ասամերեն (Հնդկաստան)',
        'az' => 'ադրբեջաներեն',
        'az_AZ' => 'ադրբեջաներեն (Ադրբեջան)',
        'az_Cyrl' => 'ադրբեջաներեն (կյուրեղագիր)',
        'az_Cyrl_AZ' => 'ադրբեջաներեն (կյուրեղագիր, Ադրբեջան)',
        'az_Latn' => 'ադրբեջաներեն (լատինական)',
        'az_Latn_AZ' => 'ադրբեջաներեն (լատինական, Ադրբեջան)',
        'be' => 'բելառուսերեն',
        'be_BY' => 'բելառուսերեն (Բելառուս)',
        'bg' => 'բուլղարերեն',
        'bg_BG' => 'բուլղարերեն (Բուլղարիա)',
        'bm' => 'բամբարա',
        'bm_ML' => 'բամբարա (Մալի)',
        'bn' => 'բենգալերեն',
        'bn_BD' => 'բենգալերեն (Բանգլադեշ)',
        'bn_IN' => 'բենգալերեն (Հնդկաստան)',
        'bo' => 'տիբեթերեն',
        'bo_CN' => 'տիբեթերեն (Չինաստան)',
        'bo_IN' => 'տիբեթերեն (Հնդկաստան)',
        'br' => 'բրետոներեն',
        'br_FR' => 'բրետոներեն (Ֆրանսիա)',
        'bs' => 'բոսնիերեն',
        'bs_BA' => 'բոսնիերեն (Բոսնիա և Հերցեգովինա)',
        'bs_Cyrl' => 'բոսնիերեն (կյուրեղագիր)',
        'bs_Cyrl_BA' => 'բոսնիերեն (կյուրեղագիր, Բոսնիա և Հերցեգովինա)',
        'bs_Latn' => 'բոսնիերեն (լատինական)',
        'bs_Latn_BA' => 'բոսնիերեն (լատինական, Բոսնիա և Հերցեգովինա)',
        'ca' => 'կատալաներեն',
        'ca_AD' => 'կատալաներեն (Անդորրա)',
        'ca_ES' => 'կատալաներեն (Իսպանիա)',
        'ca_FR' => 'կատալաներեն (Ֆրանսիա)',
        'ca_IT' => 'կատալաներեն (Իտալիա)',
        'ce' => 'չեչեներեն',
        'ce_RU' => 'չեչեներեն (Ռուսաստան)',
        'cs' => 'չեխերեն',
        'cs_CZ' => 'չեխերեն (Չեխիա)',
        'cv' => 'չուվաշերեն',
        'cv_RU' => 'չուվաշերեն (Ռուսաստան)',
        'cy' => 'ուելսերեն',
        'cy_GB' => 'ուելսերեն (Միացյալ Թագավորություն)',
        'da' => 'դանիերեն',
        'da_DK' => 'դանիերեն (Դանիա)',
        'da_GL' => 'դանիերեն (Գրենլանդիա)',
        'de' => 'գերմաներեն',
        'de_AT' => 'գերմաներեն (Ավստրիա)',
        'de_BE' => 'գերմաներեն (Բելգիա)',
        'de_CH' => 'գերմաներեն (Շվեյցարիա)',
        'de_DE' => 'գերմաներեն (Գերմանիա)',
        'de_IT' => 'գերմաներեն (Իտալիա)',
        'de_LI' => 'գերմաներեն (Լիխտենշտեյն)',
        'de_LU' => 'գերմաներեն (Լյուքսեմբուրգ)',
        'dz' => 'ջոնգքհա',
        'dz_BT' => 'ջոնգքհա (Բութան)',
        'ee' => 'էվե',
        'ee_GH' => 'էվե (Գանա)',
        'ee_TG' => 'էվե (Տոգո)',
        'el' => 'հունարեն',
        'el_CY' => 'հունարեն (Կիպրոս)',
        'el_GR' => 'հունարեն (Հունաստան)',
        'en' => 'անգլերեն',
        'en_001' => 'անգլերեն (Աշխարհ)',
        'en_150' => 'անգլերեն (Եվրոպա)',
        'en_AE' => 'անգլերեն (Արաբական Միացյալ Էմիրություններ)',
        'en_AG' => 'անգլերեն (Անտիգուա և Բարբուդա)',
        'en_AI' => 'անգլերեն (Անգուիլա)',
        'en_AS' => 'անգլերեն (Ամերիկյան Սամոա)',
        'en_AT' => 'անգլերեն (Ավստրիա)',
        'en_AU' => 'անգլերեն (Ավստրալիա)',
        'en_BB' => 'անգլերեն (Բարբադոս)',
        'en_BE' => 'անգլերեն (Բելգիա)',
        'en_BI' => 'անգլերեն (Բուրունդի)',
        'en_BM' => 'անգլերեն (Բերմուդներ)',
        'en_BS' => 'անգլերեն (Բահամյան կղզիներ)',
        'en_BW' => 'անգլերեն (Բոթսվանա)',
        'en_BZ' => 'անգլերեն (Բելիզ)',
        'en_CA' => 'անգլերեն (Կանադա)',
        'en_CC' => 'անգլերեն (Կոկոսյան [Քիլինգ] կղզիներ)',
        'en_CH' => 'անգլերեն (Շվեյցարիա)',
        'en_CK' => 'անգլերեն (Կուկի կղզիներ)',
        'en_CM' => 'անգլերեն (Կամերուն)',
        'en_CX' => 'անգլերեն (Սուրբ Ծննդյան կղզի)',
        'en_CY' => 'անգլերեն (Կիպրոս)',
        'en_DE' => 'անգլերեն (Գերմանիա)',
        'en_DK' => 'անգլերեն (Դանիա)',
        'en_DM' => 'անգլերեն (Դոմինիկա)',
        'en_ER' => 'անգլերեն (Էրիթրեա)',
        'en_FI' => 'անգլերեն (Ֆինլանդիա)',
        'en_FJ' => 'անգլերեն (Ֆիջի)',
        'en_FK' => 'անգլերեն (Ֆոլքլենդյան կղզիներ)',
        'en_FM' => 'անգլերեն (Միկրոնեզիա)',
        'en_GB' => 'անգլերեն (Միացյալ Թագավորություն)',
        'en_GD' => 'անգլերեն (Գրենադա)',
        'en_GG' => 'անգլերեն (Գերնսի)',
        'en_GH' => 'անգլերեն (Գանա)',
        'en_GI' => 'անգլերեն (Ջիբրալթար)',
        'en_GM' => 'անգլերեն (Գամբիա)',
        'en_GU' => 'անգլերեն (Գուամ)',
        'en_GY' => 'անգլերեն (Գայանա)',
        'en_HK' => 'անգլերեն (Հոնկոնգի ՀՎՇ)',
        'en_IE' => 'անգլերեն (Իռլանդիա)',
        'en_IL' => 'անգլերեն (Իսրայել)',
        'en_IM' => 'անգլերեն (Մեն կղզի)',
        'en_IN' => 'անգլերեն (Հնդկաստան)',
        'en_IO' => 'անգլերեն (Բրիտանական Տարածք Հնդկական Օվկիանոսում)',
        'en_JE' => 'անգլերեն (Ջերսի)',
        'en_JM' => 'անգլերեն (Ճամայկա)',
        'en_KE' => 'անգլերեն (Քենիա)',
        'en_KI' => 'անգլերեն (Կիրիբատի)',
        'en_KN' => 'անգլերեն (Սենթ Քիտս և Նևիս)',
        'en_KY' => 'անգլերեն (Կայմանյան կղզիներ)',
        'en_LC' => 'անգլերեն (Սենթ Լյուսիա)',
        'en_LR' => 'անգլերեն (Լիբերիա)',
        'en_LS' => 'անգլերեն (Լեսոտո)',
        'en_MG' => 'անգլերեն (Մադագասկար)',
        'en_MH' => 'անգլերեն (Մարշալյան կղզիներ)',
        'en_MO' => 'անգլերեն (Չինաստանի Մակաո ՀՎՇ)',
        'en_MP' => 'անգլերեն (Հյուսիսային Մարիանյան կղզիներ)',
        'en_MS' => 'անգլերեն (Մոնսեռատ)',
        'en_MT' => 'անգլերեն (Մալթա)',
        'en_MU' => 'անգլերեն (Մավրիկիոս)',
        'en_MV' => 'անգլերեն (Մալդիվներ)',
        'en_MW' => 'անգլերեն (Մալավի)',
        'en_MY' => 'անգլերեն (Մալայզիա)',
        'en_NA' => 'անգլերեն (Նամիբիա)',
        'en_NF' => 'անգլերեն (Նորֆոլկ կղզի)',
        'en_NG' => 'անգլերեն (Նիգերիա)',
        'en_NL' => 'անգլերեն (Նիդեռլանդներ)',
        'en_NR' => 'անգլերեն (Նաուրու)',
        'en_NU' => 'անգլերեն (Նիուե)',
        'en_NZ' => 'անգլերեն (Նոր Զելանդիա)',
        'en_PG' => 'անգլերեն (Պապուա Նոր Գվինեա)',
        'en_PH' => 'անգլերեն (Ֆիլիպիններ)',
        'en_PK' => 'անգլերեն (Պակիստան)',
        'en_PN' => 'անգլերեն (Պիտկեռն կղզիներ)',
        'en_PR' => 'անգլերեն (Պուերտո Ռիկո)',
        'en_PW' => 'անգլերեն (Պալաու)',
        'en_RW' => 'անգլերեն (Ռուանդա)',
        'en_SB' => 'անգլերեն (Սողոմոնյան կղզիներ)',
        'en_SC' => 'անգլերեն (Սեյշելներ)',
        'en_SD' => 'անգլերեն (Սուդան)',
        'en_SE' => 'անգլերեն (Շվեդիա)',
        'en_SG' => 'անգլերեն (Սինգապուր)',
        'en_SH' => 'անգլերեն (Սուրբ Հեղինեի կղզի)',
        'en_SI' => 'անգլերեն (Սլովենիա)',
        'en_SL' => 'անգլերեն (Սիեռա Լեոնե)',
        'en_SS' => 'անգլերեն (Հարավային Սուդան)',
        'en_SX' => 'անգլերեն (Սինտ Մարտեն)',
        'en_SZ' => 'անգլերեն (Էսվատինի)',
        'en_TC' => 'անգլերեն (Թըրքս և Կայկոս կղզիներ)',
        'en_TK' => 'անգլերեն (Տոկելաու)',
        'en_TO' => 'անգլերեն (Տոնգա)',
        'en_TT' => 'անգլերեն (Տրինիդադ և Տոբագո)',
        'en_TV' => 'անգլերեն (Տուվալու)',
        'en_TZ' => 'անգլերեն (Տանզանիա)',
        'en_UG' => 'անգլերեն (Ուգանդա)',
        'en_UM' => 'անգլերեն (Արտաքին կղզիներ [ԱՄՆ])',
        'en_US' => 'անգլերեն (Միացյալ Նահանգներ)',
        'en_VC' => 'անգլերեն (Սենթ Վինսենթ և Գրենադիններ)',
        'en_VG' => 'անգլերեն (Բրիտանական Վիրջինյան կղզիներ)',
        'en_VI' => 'անգլերեն (ԱՄՆ Վիրջինյան կղզիներ)',
        'en_VU' => 'անգլերեն (Վանուատու)',
        'en_WS' => 'անգլերեն (Սամոա)',
        'en_ZA' => 'անգլերեն (Հարավաֆրիկյան Հանրապետություն)',
        'en_ZM' => 'անգլերեն (Զամբիա)',
        'en_ZW' => 'անգլերեն (Զիմբաբվե)',
        'eo' => 'էսպերանտո',
        'eo_001' => 'էսպերանտո (Աշխարհ)',
        'es' => 'իսպաներեն',
        'es_419' => 'իսպաներեն (Լատինական Ամերիկա)',
        'es_AR' => 'իսպաներեն (Արգենտինա)',
        'es_BO' => 'իսպաներեն (Բոլիվիա)',
        'es_BR' => 'իսպաներեն (Բրազիլիա)',
        'es_BZ' => 'իսպաներեն (Բելիզ)',
        'es_CL' => 'իսպաներեն (Չիլի)',
        'es_CO' => 'իսպաներեն (Կոլումբիա)',
        'es_CR' => 'իսպաներեն (Կոստա Ռիկա)',
        'es_CU' => 'իսպաներեն (Կուբա)',
        'es_DO' => 'իսպաներեն (Դոմինիկյան Հանրապետություն)',
        'es_EC' => 'իսպաներեն (Էկվադոր)',
        'es_ES' => 'իսպաներեն (Իսպանիա)',
        'es_GQ' => 'իսպաներեն (Հասարակածային Գվինեա)',
        'es_GT' => 'իսպաներեն (Գվատեմալա)',
        'es_HN' => 'իսպաներեն (Հոնդուրաս)',
        'es_MX' => 'իսպաներեն (Մեքսիկա)',
        'es_NI' => 'իսպաներեն (Նիկարագուա)',
        'es_PA' => 'իսպաներեն (Պանամա)',
        'es_PE' => 'իսպաներեն (Պերու)',
        'es_PH' => 'իսպաներեն (Ֆիլիպիններ)',
        'es_PR' => 'իսպաներեն (Պուերտո Ռիկո)',
        'es_PY' => 'իսպաներեն (Պարագվայ)',
        'es_SV' => 'իսպաներեն (Սալվադոր)',
        'es_US' => 'իսպաներեն (Միացյալ Նահանգներ)',
        'es_UY' => 'իսպաներեն (Ուրուգվայ)',
        'es_VE' => 'իսպաներեն (Վենեսուելա)',
        'et' => 'էստոներեն',
        'et_EE' => 'էստոներեն (Էստոնիա)',
        'eu' => 'բասկերեն',
        'eu_ES' => 'բասկերեն (Իսպանիա)',
        'fa' => 'պարսկերեն',
        'fa_AF' => 'պարսկերեն (Աֆղանստան)',
        'fa_IR' => 'պարսկերեն (Իրան)',
        'ff' => 'ֆուլահ',
        'ff_Adlm' => 'ֆուլահ (ադլամ)',
        'ff_Adlm_BF' => 'ֆուլահ (ադլամ, Բուրկինա Ֆասո)',
        'ff_Adlm_CM' => 'ֆուլահ (ադլամ, Կամերուն)',
        'ff_Adlm_GH' => 'ֆուլահ (ադլամ, Գանա)',
        'ff_Adlm_GM' => 'ֆուլահ (ադլամ, Գամբիա)',
        'ff_Adlm_GN' => 'ֆուլահ (ադլամ, Գվինեա)',
        'ff_Adlm_GW' => 'ֆուլահ (ադլամ, Գվինեա-Բիսաու)',
        'ff_Adlm_LR' => 'ֆուլահ (ադլամ, Լիբերիա)',
        'ff_Adlm_MR' => 'ֆուլահ (ադլամ, Մավրիտանիա)',
        'ff_Adlm_NE' => 'ֆուլահ (ադլամ, Նիգեր)',
        'ff_Adlm_NG' => 'ֆուլահ (ադլամ, Նիգերիա)',
        'ff_Adlm_SL' => 'ֆուլահ (ադլամ, Սիեռա Լեոնե)',
        'ff_Adlm_SN' => 'ֆուլահ (ադլամ, Սենեգալ)',
        'ff_CM' => 'ֆուլահ (Կամերուն)',
        'ff_GN' => 'ֆուլահ (Գվինեա)',
        'ff_Latn' => 'ֆուլահ (լատինական)',
        'ff_Latn_BF' => 'ֆուլահ (լատինական, Բուրկինա Ֆասո)',
        'ff_Latn_CM' => 'ֆուլահ (լատինական, Կամերուն)',
        'ff_Latn_GH' => 'ֆուլահ (լատինական, Գանա)',
        'ff_Latn_GM' => 'ֆուլահ (լատինական, Գամբիա)',
        'ff_Latn_GN' => 'ֆուլահ (լատինական, Գվինեա)',
        'ff_Latn_GW' => 'ֆուլահ (լատինական, Գվինեա-Բիսաու)',
        'ff_Latn_LR' => 'ֆուլահ (լատինական, Լիբերիա)',
        'ff_Latn_MR' => 'ֆուլահ (լատինական, Մավրիտանիա)',
        'ff_Latn_NE' => 'ֆուլահ (լատինական, Նիգեր)',
        'ff_Latn_NG' => 'ֆուլահ (լատինական, Նիգերիա)',
        'ff_Latn_SL' => 'ֆուլահ (լատինական, Սիեռա Լեոնե)',
        'ff_Latn_SN' => 'ֆուլահ (լատինական, Սենեգալ)',
        'ff_MR' => 'ֆուլահ (Մավրիտանիա)',
        'ff_SN' => 'ֆուլահ (Սենեգալ)',
        'fi' => 'ֆիններեն',
        'fi_FI' => 'ֆիններեն (Ֆինլանդիա)',
        'fo' => 'ֆարյորերեն',
        'fo_DK' => 'ֆարյորերեն (Դանիա)',
        'fo_FO' => 'ֆարյորերեն (Ֆարերյան կղզիներ)',
        'fr' => 'ֆրանսերեն',
        'fr_BE' => 'ֆրանսերեն (Բելգիա)',
        'fr_BF' => 'ֆրանսերեն (Բուրկինա Ֆասո)',
        'fr_BI' => 'ֆրանսերեն (Բուրունդի)',
        'fr_BJ' => 'ֆրանսերեն (Բենին)',
        'fr_BL' => 'ֆրանսերեն (Սուրբ Բարդուղիմեոս)',
        'fr_CA' => 'ֆրանսերեն (Կանադա)',
        'fr_CD' => 'ֆրանսերեն (Կոնգո - Կինշասա)',
        'fr_CF' => 'ֆրանսերեն (Կենտրոնական Աֆրիկյան Հանրապետություն)',
        'fr_CG' => 'ֆրանսերեն (Կոնգո - Բրազավիլ)',
        'fr_CH' => 'ֆրանսերեն (Շվեյցարիա)',
        'fr_CI' => 'ֆրանսերեն (Կոտ դ՚Իվուար)',
        'fr_CM' => 'ֆրանսերեն (Կամերուն)',
        'fr_DJ' => 'ֆրանսերեն (Ջիբութի)',
        'fr_DZ' => 'ֆրանսերեն (Ալժիր)',
        'fr_FR' => 'ֆրանսերեն (Ֆրանսիա)',
        'fr_GA' => 'ֆրանսերեն (Գաբոն)',
        'fr_GF' => 'ֆրանսերեն (Ֆրանսիական Գվիանա)',
        'fr_GN' => 'ֆրանսերեն (Գվինեա)',
        'fr_GP' => 'ֆրանսերեն (Գվադելուպա)',
        'fr_GQ' => 'ֆրանսերեն (Հասարակածային Գվինեա)',
        'fr_HT' => 'ֆրանսերեն (Հայիթի)',
        'fr_KM' => 'ֆրանսերեն (Կոմորյան կղզիներ)',
        'fr_LU' => 'ֆրանսերեն (Լյուքսեմբուրգ)',
        'fr_MA' => 'ֆրանսերեն (Մարոկկո)',
        'fr_MC' => 'ֆրանսերեն (Մոնակո)',
        'fr_MF' => 'ֆրանսերեն (Սեն Մարտեն)',
        'fr_MG' => 'ֆրանսերեն (Մադագասկար)',
        'fr_ML' => 'ֆրանսերեն (Մալի)',
        'fr_MQ' => 'ֆրանսերեն (Մարտինիկա)',
        'fr_MR' => 'ֆրանսերեն (Մավրիտանիա)',
        'fr_MU' => 'ֆրանսերեն (Մավրիկիոս)',
        'fr_NC' => 'ֆրանսերեն (Նոր Կալեդոնիա)',
        'fr_NE' => 'ֆրանսերեն (Նիգեր)',
        'fr_PF' => 'ֆրանսերեն (Ֆրանսիական Պոլինեզիա)',
        'fr_PM' => 'ֆրանսերեն (Սեն Պիեռ և Միքելոն)',
        'fr_RE' => 'ֆրանսերեն (Ռեյունիոն)',
        'fr_RW' => 'ֆրանսերեն (Ռուանդա)',
        'fr_SC' => 'ֆրանսերեն (Սեյշելներ)',
        'fr_SN' => 'ֆրանսերեն (Սենեգալ)',
        'fr_SY' => 'ֆրանսերեն (Սիրիա)',
        'fr_TD' => 'ֆրանսերեն (Չադ)',
        'fr_TG' => 'ֆրանսերեն (Տոգո)',
        'fr_TN' => 'ֆրանսերեն (Թունիս)',
        'fr_VU' => 'ֆրանսերեն (Վանուատու)',
        'fr_WF' => 'ֆրանսերեն (Ուոլիս և Ֆուտունա)',
        'fr_YT' => 'ֆրանսերեն (Մայոտ)',
        'fy' => 'արևմտաֆրիզերեն',
        'fy_NL' => 'արևմտաֆրիզերեն (Նիդեռլանդներ)',
        'ga' => 'իռլանդերեն',
        'ga_GB' => 'իռլանդերեն (Միացյալ Թագավորություն)',
        'ga_IE' => 'իռլանդերեն (Իռլանդիա)',
        'gd' => 'շոտլանդական գաելերեն',
        'gd_GB' => 'շոտլանդական գաելերեն (Միացյալ Թագավորություն)',
        'gl' => 'գալիսերեն',
        'gl_ES' => 'գալիսերեն (Իսպանիա)',
        'gu' => 'գուջարաթի',
        'gu_IN' => 'գուջարաթի (Հնդկաստան)',
        'gv' => 'մեներեն',
        'gv_IM' => 'մեներեն (Մեն կղզի)',
        'ha' => 'հաուսա',
        'ha_GH' => 'հաուսա (Գանա)',
        'ha_NE' => 'հաուսա (Նիգեր)',
        'ha_NG' => 'հաուսա (Նիգերիա)',
        'he' => 'եբրայերեն',
        'he_IL' => 'եբրայերեն (Իսրայել)',
        'hi' => 'հինդի',
        'hi_IN' => 'հինդի (Հնդկաստան)',
        'hi_Latn' => 'հինդի (լատինական)',
        'hi_Latn_IN' => 'հինդի (լատինական, Հնդկաստան)',
        'hr' => 'խորվաթերեն',
        'hr_BA' => 'խորվաթերեն (Բոսնիա և Հերցեգովինա)',
        'hr_HR' => 'խորվաթերեն (Խորվաթիա)',
        'hu' => 'հունգարերեն',
        'hu_HU' => 'հունգարերեն (Հունգարիա)',
        'hy' => 'հայերեն',
        'hy_AM' => 'հայերեն (Հայաստան)',
        'ia' => 'ինտերլինգուա',
        'ia_001' => 'ինտերլինգուա (Աշխարհ)',
        'id' => 'ինդոնեզերեն',
        'id_ID' => 'ինդոնեզերեն (Ինդոնեզիա)',
        'ig' => 'իգբո',
        'ig_NG' => 'իգբո (Նիգերիա)',
        'ii' => 'սիչուան',
        'ii_CN' => 'սիչուան (Չինաստան)',
        'is' => 'իսլանդերեն',
        'is_IS' => 'իսլանդերեն (Իսլանդիա)',
        'it' => 'իտալերեն',
        'it_CH' => 'իտալերեն (Շվեյցարիա)',
        'it_IT' => 'իտալերեն (Իտալիա)',
        'it_SM' => 'իտալերեն (Սան Մարինո)',
        'it_VA' => 'իտալերեն (Վատիկան)',
        'ja' => 'ճապոներեն',
        'ja_JP' => 'ճապոներեն (Ճապոնիա)',
        'jv' => 'ճավայերեն',
        'jv_ID' => 'ճավայերեն (Ինդոնեզիա)',
        'ka' => 'վրացերեն',
        'ka_GE' => 'վրացերեն (Վրաստան)',
        'ki' => 'կիկույու',
        'ki_KE' => 'կիկույու (Քենիա)',
        'kk' => 'ղազախերեն',
        'kk_KZ' => 'ղազախերեն (Ղազախստան)',
        'kl' => 'կալաալիսուտ',
        'kl_GL' => 'կալաալիսուտ (Գրենլանդիա)',
        'km' => 'քմերերեն',
        'km_KH' => 'քմերերեն (Կամբոջա)',
        'kn' => 'կաննադա',
        'kn_IN' => 'կաննադա (Հնդկաստան)',
        'ko' => 'կորեերեն',
        'ko_KP' => 'կորեերեն (Հյուսիսային Կորեա)',
        'ko_KR' => 'կորեերեն (Հարավային Կորեա)',
        'ks' => 'քաշմիրերեն',
        'ks_Arab' => 'քաշմիրերեն (արաբական)',
        'ks_Arab_IN' => 'քաշմիրերեն (արաբական, Հնդկաստան)',
        'ks_Deva' => 'քաշմիրերեն (դեւանագարի)',
        'ks_Deva_IN' => 'քաշմիրերեն (դեւանագարի, Հնդկաստան)',
        'ks_IN' => 'քաշմիրերեն (Հնդկաստան)',
        'ku' => 'քրդերեն',
        'ku_TR' => 'քրդերեն (Թուրքիա)',
        'kw' => 'կոռներեն',
        'kw_GB' => 'կոռներեն (Միացյալ Թագավորություն)',
        'ky' => 'ղրղզերեն',
        'ky_KG' => 'ղրղզերեն (Ղրղզստան)',
        'lb' => 'լյուքսեմբուրգերեն',
        'lb_LU' => 'լյուքսեմբուրգերեն (Լյուքսեմբուրգ)',
        'lg' => 'գանդա',
        'lg_UG' => 'գանդա (Ուգանդա)',
        'ln' => 'լինգալա',
        'ln_AO' => 'լինգալա (Անգոլա)',
        'ln_CD' => 'լինգալա (Կոնգո - Կինշասա)',
        'ln_CF' => 'լինգալա (Կենտրոնական Աֆրիկյան Հանրապետություն)',
        'ln_CG' => 'լինգալա (Կոնգո - Բրազավիլ)',
        'lo' => 'լաոսերեն',
        'lo_LA' => 'լաոսերեն (Լաոս)',
        'lt' => 'լիտվերեն',
        'lt_LT' => 'լիտվերեն (Լիտվա)',
        'lu' => 'լուբա-կատանգա',
        'lu_CD' => 'լուբա-կատանգա (Կոնգո - Կինշասա)',
        'lv' => 'լատվիերեն',
        'lv_LV' => 'լատվիերեն (Լատվիա)',
        'mg' => 'մալգաշերեն',
        'mg_MG' => 'մալգաշերեն (Մադագասկար)',
        'mi' => 'մաորի',
        'mi_NZ' => 'մաորի (Նոր Զելանդիա)',
        'mk' => 'մակեդոներեն',
        'mk_MK' => 'մակեդոներեն (Հյուսիսային Մակեդոնիա)',
        'ml' => 'մալայալամ',
        'ml_IN' => 'մալայալամ (Հնդկաստան)',
        'mn' => 'մոնղոլերեն',
        'mn_MN' => 'մոնղոլերեն (Մոնղոլիա)',
        'mr' => 'մարաթի',
        'mr_IN' => 'մարաթի (Հնդկաստան)',
        'ms' => 'մալայերեն',
        'ms_BN' => 'մալայերեն (Բրունեյ)',
        'ms_ID' => 'մալայերեն (Ինդոնեզիա)',
        'ms_MY' => 'մալայերեն (Մալայզիա)',
        'ms_SG' => 'մալայերեն (Սինգապուր)',
        'mt' => 'մալթայերեն',
        'mt_MT' => 'մալթայերեն (Մալթա)',
        'my' => 'բիրմայերեն',
        'my_MM' => 'բիրմայերեն (Մյանմա [Բիրմա])',
        'nb' => 'գրքային նորվեգերեն',
        'nb_NO' => 'գրքային նորվեգերեն (Նորվեգիա)',
        'nb_SJ' => 'գրքային նորվեգերեն (Սվալբարդ և Յան Մայեն)',
        'nd' => 'հյուսիսային նդեբելե',
        'nd_ZW' => 'հյուսիսային նդեբելե (Զիմբաբվե)',
        'ne' => 'նեպալերեն',
        'ne_IN' => 'նեպալերեն (Հնդկաստան)',
        'ne_NP' => 'նեպալերեն (Նեպալ)',
        'nl' => 'հոլանդերեն',
        'nl_AW' => 'հոլանդերեն (Արուբա)',
        'nl_BE' => 'հոլանդերեն (Բելգիա)',
        'nl_BQ' => 'հոլանդերեն (Կարիբյան Նիդեռլանդներ)',
        'nl_CW' => 'հոլանդերեն (Կյուրասաո)',
        'nl_NL' => 'հոլանդերեն (Նիդեռլանդներ)',
        'nl_SR' => 'հոլանդերեն (Սուրինամ)',
        'nl_SX' => 'հոլանդերեն (Սինտ Մարտեն)',
        'nn' => 'նոր նորվեգերեն',
        'nn_NO' => 'նոր նորվեգերեն (Նորվեգիա)',
        'no' => 'նորվեգերեն',
        'no_NO' => 'նորվեգերեն (Նորվեգիա)',
        'om' => 'օրոմո',
        'om_ET' => 'օրոմո (Եթովպիա)',
        'om_KE' => 'օրոմո (Քենիա)',
        'or' => 'օրիյա',
        'or_IN' => 'օրիյա (Հնդկաստան)',
        'os' => 'օսերեն',
        'os_GE' => 'օսերեն (Վրաստան)',
        'os_RU' => 'օսերեն (Ռուսաստան)',
        'pa' => 'փենջաբերեն',
        'pa_Arab' => 'փենջաբերեն (արաբական)',
        'pa_Arab_PK' => 'փենջաբերեն (արաբական, Պակիստան)',
        'pa_Guru' => 'փենջաբերեն (գուրմուխի)',
        'pa_Guru_IN' => 'փենջաբերեն (գուրմուխի, Հնդկաստան)',
        'pa_IN' => 'փենջաբերեն (Հնդկաստան)',
        'pa_PK' => 'փենջաբերեն (Պակիստան)',
        'pl' => 'լեհերեն',
        'pl_PL' => 'լեհերեն (Լեհաստան)',
        'ps' => 'փուշթու',
        'ps_AF' => 'փուշթու (Աֆղանստան)',
        'ps_PK' => 'փուշթու (Պակիստան)',
        'pt' => 'պորտուգալերեն',
        'pt_AO' => 'պորտուգալերեն (Անգոլա)',
        'pt_BR' => 'պորտուգալերեն (Բրազիլիա)',
        'pt_CH' => 'պորտուգալերեն (Շվեյցարիա)',
        'pt_CV' => 'պորտուգալերեն (Կաբո Վերդե)',
        'pt_GQ' => 'պորտուգալերեն (Հասարակածային Գվինեա)',
        'pt_GW' => 'պորտուգալերեն (Գվինեա-Բիսաու)',
        'pt_LU' => 'պորտուգալերեն (Լյուքսեմբուրգ)',
        'pt_MO' => 'պորտուգալերեն (Չինաստանի Մակաո ՀՎՇ)',
        'pt_MZ' => 'պորտուգալերեն (Մոզամբիկ)',
        'pt_PT' => 'պորտուգալերեն (Պորտուգալիա)',
        'pt_ST' => 'պորտուգալերեն (Սան Տոմե և Փրինսիպի)',
        'pt_TL' => 'պորտուգալերեն (Թիմոր Լեշտի)',
        'qu' => 'կեչուա',
        'qu_BO' => 'կեչուա (Բոլիվիա)',
        'qu_EC' => 'կեչուա (Էկվադոր)',
        'qu_PE' => 'կեչուա (Պերու)',
        'rm' => 'ռոմանշերեն',
        'rm_CH' => 'ռոմանշերեն (Շվեյցարիա)',
        'rn' => 'ռունդի',
        'rn_BI' => 'ռունդի (Բուրունդի)',
        'ro' => 'ռումիներեն',
        'ro_MD' => 'ռումիներեն (Մոլդովա)',
        'ro_RO' => 'ռումիներեն (Ռումինիա)',
        'ru' => 'ռուսերեն',
        'ru_BY' => 'ռուսերեն (Բելառուս)',
        'ru_KG' => 'ռուսերեն (Ղրղզստան)',
        'ru_KZ' => 'ռուսերեն (Ղազախստան)',
        'ru_MD' => 'ռուսերեն (Մոլդովա)',
        'ru_RU' => 'ռուսերեն (Ռուսաստան)',
        'ru_UA' => 'ռուսերեն (Ուկրաինա)',
        'rw' => 'կինյառուանդա',
        'rw_RW' => 'կինյառուանդա (Ռուանդա)',
        'sa' => 'սանսկրիտ',
        'sa_IN' => 'սանսկրիտ (Հնդկաստան)',
        'sc' => 'սարդիներեն',
        'sc_IT' => 'սարդիներեն (Իտալիա)',
        'sd' => 'սինդհի',
        'sd_Arab' => 'սինդհի (արաբական)',
        'sd_Arab_PK' => 'սինդհի (արաբական, Պակիստան)',
        'sd_Deva' => 'սինդհի (դեւանագարի)',
        'sd_Deva_IN' => 'սինդհի (դեւանագարի, Հնդկաստան)',
        'sd_IN' => 'սինդհի (Հնդկաստան)',
        'sd_PK' => 'սինդհի (Պակիստան)',
        'se' => 'հյուսիսային սաամի',
        'se_FI' => 'հյուսիսային սաամի (Ֆինլանդիա)',
        'se_NO' => 'հյուսիսային սաամի (Նորվեգիա)',
        'se_SE' => 'հյուսիսային սաամի (Շվեդիա)',
        'sg' => 'սանգո',
        'sg_CF' => 'սանգո (Կենտրոնական Աֆրիկյան Հանրապետություն)',
        'sh' => 'սերբա-խորվաթերեն',
        'sh_BA' => 'սերբա-խորվաթերեն (Բոսնիա և Հերցեգովինա)',
        'si' => 'սինհալերեն',
        'si_LK' => 'սինհալերեն (Շրի Լանկա)',
        'sk' => 'սլովակերեն',
        'sk_SK' => 'սլովակերեն (Սլովակիա)',
        'sl' => 'սլովեներեն',
        'sl_SI' => 'սլովեներեն (Սլովենիա)',
        'sn' => 'շոնա',
        'sn_ZW' => 'շոնա (Զիմբաբվե)',
        'so' => 'սոմալիերեն',
        'so_DJ' => 'սոմալիերեն (Ջիբութի)',
        'so_ET' => 'սոմալիերեն (Եթովպիա)',
        'so_KE' => 'սոմալիերեն (Քենիա)',
        'so_SO' => 'սոմալիերեն (Սոմալի)',
        'sq' => 'ալբաներեն',
        'sq_AL' => 'ալբաներեն (Ալբանիա)',
        'sq_MK' => 'ալբաներեն (Հյուսիսային Մակեդոնիա)',
        'sr' => 'սերբերեն',
        'sr_BA' => 'սերբերեն (Բոսնիա և Հերցեգովինա)',
        'sr_Cyrl' => 'սերբերեն (կյուրեղագիր)',
        'sr_Cyrl_BA' => 'սերբերեն (կյուրեղագիր, Բոսնիա և Հերցեգովինա)',
        'sr_Cyrl_ME' => 'սերբերեն (կյուրեղագիր, Չեռնոգորիա)',
        'sr_Cyrl_RS' => 'սերբերեն (կյուրեղագիր, Սերբիա)',
        'sr_Latn' => 'սերբերեն (լատինական)',
        'sr_Latn_BA' => 'սերբերեն (լատինական, Բոսնիա և Հերցեգովինա)',
        'sr_Latn_ME' => 'սերբերեն (լատինական, Չեռնոգորիա)',
        'sr_Latn_RS' => 'սերբերեն (լատինական, Սերբիա)',
        'sr_ME' => 'սերբերեն (Չեռնոգորիա)',
        'sr_RS' => 'սերբերեն (Սերբիա)',
        'su' => 'սունդաներեն',
        'su_ID' => 'սունդաներեն (Ինդոնեզիա)',
        'su_Latn' => 'սունդաներեն (լատինական)',
        'su_Latn_ID' => 'սունդաներեն (լատինական, Ինդոնեզիա)',
        'sv' => 'շվեդերեն',
        'sv_AX' => 'շվեդերեն (Ալանդյան կղզիներ)',
        'sv_FI' => 'շվեդերեն (Ֆինլանդիա)',
        'sv_SE' => 'շվեդերեն (Շվեդիա)',
        'sw' => 'սուահիլի',
        'sw_CD' => 'սուահիլի (Կոնգո - Կինշասա)',
        'sw_KE' => 'սուահիլի (Քենիա)',
        'sw_TZ' => 'սուահիլի (Տանզանիա)',
        'sw_UG' => 'սուահիլի (Ուգանդա)',
        'ta' => 'թամիլերեն',
        'ta_IN' => 'թամիլերեն (Հնդկաստան)',
        'ta_LK' => 'թամիլերեն (Շրի Լանկա)',
        'ta_MY' => 'թամիլերեն (Մալայզիա)',
        'ta_SG' => 'թամիլերեն (Սինգապուր)',
        'te' => 'թելուգու',
        'te_IN' => 'թելուգու (Հնդկաստան)',
        'tg' => 'տաջիկերեն',
        'tg_TJ' => 'տաջիկերեն (Տաջիկստան)',
        'th' => 'թայերեն',
        'th_TH' => 'թայերեն (Թայլանդ)',
        'ti' => 'տիգրինյա',
        'ti_ER' => 'տիգրինյա (Էրիթրեա)',
        'ti_ET' => 'տիգրինյա (Եթովպիա)',
        'tk' => 'թուրքմեներեն',
        'tk_TM' => 'թուրքմեներեն (Թուրքմենստան)',
        'tl' => 'տագալերեն',
        'tl_PH' => 'տագալերեն (Ֆիլիպիններ)',
        'to' => 'տոնգերեն',
        'to_TO' => 'տոնգերեն (Տոնգա)',
        'tr' => 'թուրքերեն',
        'tr_CY' => 'թուրքերեն (Կիպրոս)',
        'tr_TR' => 'թուրքերեն (Թուրքիա)',
        'tt' => 'թաթարերեն',
        'tt_RU' => 'թաթարերեն (Ռուսաստան)',
        'ug' => 'ույղուրերեն',
        'ug_CN' => 'ույղուրերեն (Չինաստան)',
        'uk' => 'ուկրաիներեն',
        'uk_UA' => 'ուկրաիներեն (Ուկրաինա)',
        'ur' => 'ուրդու',
        'ur_IN' => 'ուրդու (Հնդկաստան)',
        'ur_PK' => 'ուրդու (Պակիստան)',
        'uz' => 'ուզբեկերեն',
        'uz_AF' => 'ուզբեկերեն (Աֆղանստան)',
        'uz_Arab' => 'ուզբեկերեն (արաբական)',
        'uz_Arab_AF' => 'ուզբեկերեն (արաբական, Աֆղանստան)',
        'uz_Cyrl' => 'ուզբեկերեն (կյուրեղագիր)',
        'uz_Cyrl_UZ' => 'ուզբեկերեն (կյուրեղագիր, Ուզբեկստան)',
        'uz_Latn' => 'ուզբեկերեն (լատինական)',
        'uz_Latn_UZ' => 'ուզբեկերեն (լատինական, Ուզբեկստան)',
        'uz_UZ' => 'ուզբեկերեն (Ուզբեկստան)',
        'vi' => 'վիետնամերեն',
        'vi_VN' => 'վիետնամերեն (Վիետնամ)',
        'wo' => 'վոլոֆ',
        'wo_SN' => 'վոլոֆ (Սենեգալ)',
        'xh' => 'քոսա',
        'xh_ZA' => 'քոսա (Հարավաֆրիկյան Հանրապետություն)',
        'yi' => 'իդիշ',
        'yi_001' => 'իդիշ (Աշխարհ)',
        'yo' => 'յորուբա',
        'yo_BJ' => 'յորուբա (Բենին)',
        'yo_NG' => 'յորուբա (Նիգերիա)',
        'zh' => 'չինարեն',
        'zh_CN' => 'չինարեն (Չինաստան)',
        'zh_HK' => 'չինարեն (Հոնկոնգի ՀՎՇ)',
        'zh_Hans' => 'չինարեն (պարզեցված)',
        'zh_Hans_CN' => 'չինարեն (պարզեցված, Չինաստան)',
        'zh_Hans_HK' => 'չինարեն (պարզեցված, Հոնկոնգի ՀՎՇ)',
        'zh_Hans_MO' => 'չինարեն (պարզեցված, Չինաստանի Մակաո ՀՎՇ)',
        'zh_Hans_SG' => 'չինարեն (պարզեցված, Սինգապուր)',
        'zh_Hant' => 'չինարեն (ավանդական)',
        'zh_Hant_HK' => 'չինարեն (ավանդական, Հոնկոնգի ՀՎՇ)',
        'zh_Hant_MO' => 'չինարեն (ավանդական, Չինաստանի Մակաո ՀՎՇ)',
        'zh_Hant_TW' => 'չինարեն (ավանդական, Թայվան)',
        'zh_MO' => 'չինարեն (Չինաստանի Մակաո ՀՎՇ)',
        'zh_SG' => 'չինարեն (Սինգապուր)',
        'zh_TW' => 'չինարեն (Թայվան)',
        'zu' => 'զուլուերեն',
        'zu_ZA' => 'զուլուերեն (Հարավաֆրիկյան Հանրապետություն)',
    ],
];
