<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Peseta Andorrach',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Dirham nan Iomaratan Arabach Aonaichte',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afghani Afghanach (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghani Afghanach',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Lek Albàineach (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lek Albàineach',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dram Airmeineach',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Gulden Eileanan Aintilia nan Tìrean Ìsle',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza Angòlach',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Kwanza Angòlach (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Kwanza ùr Angòlach (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Kwanza ath-ghleusaichte Angòlach (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Austral Argantaineach',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Peso ley Argantaineach (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Peso Argantaineach (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Peso Argantaineach (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Peso Argantaineach',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Schilling Ostaireach',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dolar Astràilianach',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Florin Arùbach',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Manat Asarbaideànach (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manat Asarbaideànach',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Dinar Bhosna agus Hearsagobhana (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Mark iompachail Bhosna agus Hearsagobhana',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Dinar ùr Bhosna agus Hearsagobhana (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dolar Barbadach',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka Bangladaiseach',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Franc Beilgeach (iompachail)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Franc Beilgeach',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Franc Beilgeach (ionmhasail)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Lev cruaidh Bulgarach',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Lev sòisealach Bulgarach',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Lev Bulgarach',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Lev Bulgarach (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinar Bachraineach',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Franc Burundaidheach',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dolar Bearmùdach',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dolar Brùnaigheach',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviano Boilibhiach',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Boliviano Boilibhiach (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Peso Boilibhiach',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Mvdol Boilibhiach',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Cruzeiro ùr Braisileach (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Cruzado Braisileach (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Cruzeiro Braisileach (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Real Braisileach',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Cruzado ùr Braisileach (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Cruzeiro Braisileach (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Cruzeiro Braisileach (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dolar Bathamach',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrum Butànach',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Kyat Burmach',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula Botsuanach',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Rùbal ùr Bealaruiseach (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rùbal Bealaruiseach',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Rùbal Bealaruiseach (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dolar Beilìseach',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dolar Canadach',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Franc Congothach',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'Eòro WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Franc Eilbheiseach',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'Franc WIR',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Escudo Sileach',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Aonad cunntasachd Sileach (UF)',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Peso Sileach',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuan Sìneach (far-thìreach)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Dolar an t-sluagh-bhanca Shìnich',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan Sìneach',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Peso Coloimbeach',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Aonad fìor-luach Coloimbeach',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Colón Costa Rìceach',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Dinar Sèirbeach (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Koruna cruaidh Seic-Slòbhacach',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Peso iompachail Cùbach',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Peso Cùbach',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo a’ Chip Uaine',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Punnd Cìoprasach',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna Seiceach',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Mark na Gearmailte an Ear',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Mark Gearmailteach',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Franc Diobùtaidheach',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Krone Danmhairgeach',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Peso Doiminiceach',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinar Aildireach',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Sucre Eacuadorach',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Aonad luach chunbhalaich Eacuadorach',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Kroon Eastoineach',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Punnd Èipheiteach',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa Eartrach',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Peseta Spàinnteach (cunntas A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Peseta Spàinnteach (cunntas iompachail)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Peseta Spàinnteach',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birr Itiopach',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Eòro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Markka Fionnlannach',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dolar Fìditheach',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Punnd Fàclannach',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franc Frangach',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Punnd Sasannach',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Kupon larit Cairtbheileach',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lari Cairtbheileach',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Cedi Gànach (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Cedi Gànach',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Punnd Diobraltarach',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi Gaimbitheach',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Franc Ginitheach',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Syli Ginitheach',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ekwele Gini Meadhan-Chriosaich',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Drachma Greugach',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Quetzal Guatamalach',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Escudo Gini na Portagaile',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Peso Gini-Biosothach',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dolar Guidheànach',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dolar Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira Hondùrach',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Dinar Cròthaiseach',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna Cròthaiseach',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gourde Haidhteach',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Forint Ungaireach',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupiah Innd-Innseach',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Punnd Èireannach',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Punnd Iosraeleach',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'Sheqel Iosraeleach (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Sheqel ùr Iosraeleach',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupee Innseanach',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinar Ioràcach',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Rial Iorànach',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'Króna Innis Tìleach (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Króna Innis Tìleach',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Lira Eadailteach',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dolar Diameugach',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinar Iòrdanach',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yen Seapanach',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shilling Ceineach',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Som Cìorgasach',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riel Cambuideach',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Franc Comorosach',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Won Choirèa a Tuath',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Hwan Choirèa a Deas (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Won Choirèa a Deas (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Won Choirèa a Deas',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinar Cuibhèiteach',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dolar Caimeanach',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge Casachach',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kip Làthosach',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Punnd Leabanach',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rupee Sri Lancach',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dolar Libèireach',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti Leasotach',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litas Liotuaineach',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Talonas Liotuaineach',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Franc iompachail Lugsamburgach',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Franc Lugsamburgach',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Franc ionmhasail Lugsamburgach',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lats Laitbheach',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Rùbal Laitbheach',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinar Libitheach',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham Morocach',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Franc Morocach',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Franc Monacach',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Cupon Moldobhach',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leu Moldobhach',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariary Madagasgarach',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Franc Madagasgarach',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Denar Masadonach',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Denar Masadonach (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Franc Màilitheach',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kyat Miànmarach',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrik Mongolach',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataca Macàthuach',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya Moratàineach (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya Moratàineach',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Lira Maltach',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Punnd Maltach',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupee Moiriseasach',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'Rupee Maladaibheach',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiyaa Maladaibheach',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha Malabhaidheach',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Peso Meagsagach',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Peso airgid Meagsagach (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Aonad inbheistidh Meagsagach',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringgit Malaidheach',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Escudo Mòsaimbiceach',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metical Mòsaimbiceach (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metical Mòsaimbiceach',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dolar Naimibitheach',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira Nigèiriach',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Córdoba Niocaragach (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Córdoba Niocaragach',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Gulden Duitseach',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Krone Nirribheach',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupee Neapàlach',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dolar Shealainn Nuaidh',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Rial Omànach',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa Panamach',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Inti Pearùthach',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Sol Pearùthach',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Sol Pearùthach (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina Ghini Nuaidh Paputhaiche',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Peso Filipineach',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupee Pagastànach',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Złoty Pòlainneach',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Złoty Pòlainneach (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Escudo Portagaileach',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guaraní Paraguaidheach',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Rial Catarach',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Dolar Rhodesiach',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Leu Romàineach (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Leu Romàineach',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinar Sèirbeach',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rùbal Ruiseach',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rùbal Ruiseach (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Franc Rubhandach',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal Sabhdach',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dolar Eileanan Sholaimh',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupee Seiseallach',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Dinar Sudànach (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Punnd Sudànach',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Punnd Sudànach (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Krona Suaineach',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dolar Singeapòrach',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Punnd Eilean Naomh Eilidh',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Tolar Slòbhaineach',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Koruna Slòbhacach',
        ],
        'SLE' => [
            0 => 'SLE',
            1 => 'Leone Siarra Leòmhannach ùr',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone Siarra Leòmhannach',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shilling Somàilitheach',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dolar Suranamach',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Gulden Suranamach',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Punnd Sudàin a Deas',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra São Tomé agus Príncipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra São Tomé agus Príncipe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Rùbal Sovietach',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Colón Salbhadorach',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Punnd Siridheach',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni Suasaidheach',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Baht Tàidheach',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Rùbal Taidigeach',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni Taidigeach',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Manat Turcmanach (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manat Turcmanach',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinar Tuiniseach',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Paʻanga Tongach',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Escudo Tìomorach',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Lira Turcach (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lira Turcach',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dolar Thrianaid agus Thobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dolar ùr Taidh-Bhànach',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shilling Tansanaidheach',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Hryvnia Ucràineach',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Karbovanets Ucràineach',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Shilling Ugandach (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilling Ugandach',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dolar nan Stàitean Aonaichte',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Dolar nan SA (an ath–latha)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Dolar nan SA (an aon latha)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Peso Uruguaidheach (aonadan inneacsaichte)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Peso Uruguaidheach (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso Uruguaidheach',
        ],
        'UYW' => [
            0 => 'UYW',
            1 => 'Aonad inneacs tuarastail ainmeach Uruguaidh',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Som Usbagach',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Bolívar Bheinisealach (1871–2008)',
        ],
        'VED' => [
            0 => 'VED',
            1 => 'Bolívar Soberano',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolívar Bheinisealach (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolívar Bheinisealach',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dong Bhiet-Namach',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Dong Bhiet-Namach (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatu Vanuatuthach',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala Samothach',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Franc CFA Meadhan-Afragach',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dolar Caraibeach earach',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Aonad airgeadra Eòrpach',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franc òir Frangach',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Franc UIC Frangach',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Franc CFA Afraga an Iar',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Franc CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'Aonad maoine RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Dinar Eamanach',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Rial Eamanach',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Dinar cruaidh Iùgoslabhach (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Dinar ùr Iùgoslabhach (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Dinar iompachail Iùgoslabhach (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Dinar ath-leasaichte Iùgoslabhach (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Rand Afraga a Deas (ionmhasail)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rand Afraga a Deas',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha Sàimbitheach (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha Sàimbitheach',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zaïre ùr Zaïreach (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zaïre Zaïreach (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dolar Sìombabuthach (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Dolar Sìombabuthach (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Dolar Sìombabuthach (2008)',
        ],
    ],
];
