<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Андорска пезета',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'дирхам УАЕ',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Авганистански авгани (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'авганистански авгани',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'албански лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'јерменски драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'холандскоантилски гулден',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'анголска кванза',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Анголијска кванза (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Анголијска нова кванза (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Анголијска кванза реађустадо (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Аргентински аустрал',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Аргентински пезо (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'аргентински пезос',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Аустријски шилинг',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'аустралијски долар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'арубански флорин',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Азербејџански манат (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'азербејџански манат',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Босанско-Херцеговачки динар',
        ],
        'BAM' => [
            0 => 'КМ',
            1 => 'босанско-херцеговачка конвертибилна марка',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'барбадошки долар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'бангладешка така',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Белгијски франак (конвертибилни)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Белгијски франак',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Белгијски франак (финансијски)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Бугарски тврди лев',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'бугарски лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'бахреински динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'бурундски франак',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'бермудски долар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'брунејски долар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'боливијски боливијано',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Боливијски пезо',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Боливијски мвдол',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Бразилски нови крузеиро (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Бразилијски крузадо',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Бразилски крузеиро (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'бразилски реал',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Бразилијски нови крузадо',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Бразилски крузеиро',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'бахамски долар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'бутански нгултрум',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Бурмански кјат',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'боцванска пула',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Белоруска нова рубља (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'белоруска рубља',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Белоруска рубља (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'белиски долар',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'канадски долар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'конгоански франак',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR евро',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'швајцарски франак',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR франак',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Чилеовски унидадес се фоменто',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'чилеански пезос',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'кинески јуан (острвски)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'кинески јуан',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'колумбијски пезос',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Унидад де валоршки реал',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'костарикански колон',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Стари српски динар',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Чехословачка тврда круна',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'кубански конвертибилни пезос',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'кубански пезос',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'зеленортски ескудо',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Кипарска фунта',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'чешка круна',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Источно-немачка марка',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Немачка марка',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'џибутски франак',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'данска круна',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'доминикански пезос',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'алжирски динар',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Еквадорски сакр',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Еквадорски унидад де валор константе',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Естонска кроон',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'египатска фунта',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'еритрејска накфа',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Шпанска пезета (рачун)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Шпанска пезета (конвертибилнирачун)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Шпанска пезета',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'етиопијски бир',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Евро',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Финска марка',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'фиџијски долар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'фолкландска фунта',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Француски франак',
        ],
        'GBP' => [
            0 => '£',
            1 => 'британска фунта',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Грузијски купон ларит',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'грузијски лари',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Гански цеди (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'гански седи',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'гибралтарска фунта',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'гамбијски даласи',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'гвинејски франак',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Гвинејски сили',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Екваторијално-гвинејски еквеле',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Грчка драхма',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'гватемалски кецал',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Португалска гвинеја ескудо',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Гвинеја Бисао Пезо',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'гвајански долар',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'хонгконшки долар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'хондурашка лемпира',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Хрватски динар',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'хрватска куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'хаићански гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'мађарска форинта',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'индонежанска рупија',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Ирска фунта',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Израелска фунта',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'Стари израелски шекели',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'израелски нови шекел',
        ],
        'INR' => [
            0 => '₹',
            1 => 'индијска рупија',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'ирачки динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'ирански ријал',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'Стара исландска круна',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'исландска круна',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Италијанска лира',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'јамајчански долар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'јордански динар',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'јапански јен',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'кенијски шилинг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'киргистански сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'камбоџански ријел',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'коморски франак',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'севернокорејски вон',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'јужнокорејски вон',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'кувајтски динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'кајмански долар',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'казахстански тенге',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'лаоски кип',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'либанска фунта',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'шриланчанска рупија',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'либеријски долар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'лесотски лоти',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Литвански литас',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Литвански талонас',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Луксембуршки конвертибилни франак',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Луксембуршки франак',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Луксембуршки финансијски франак',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Латвијски лати',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Латвијска рубља',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'либијски динар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'марокански дирхам',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Марокански франак',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'молдавски леј',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'малгашки аријари',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Малагасијски франак',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'македонски денар',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Малијански франак',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'мјанмарски кјат',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'монголски тугрик',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'макаоска патака',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Мауританијска oгија (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'мауританска огија',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Малтешка лира',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Малтешка фунта',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'маурицијска рупија',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'малдивска руфија',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'малавијска квача',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'мексички пезос',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Мексички сребрни пезо (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Мексички унидад де инверсион (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'малезијски рингит',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Мозамбијски ескудо',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Стари мозамбијски метикал',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'мозамбички метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'намибијски долар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'нигеријска наира',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'никарагванска кордоба (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'никарагванска кордоба',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Холандски гулден',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'норвешка круна',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'непалска рупија',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'новозеландски долар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'омански ријал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'панамска балбоа',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Перуански инти',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'перуански сол',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Перуански сол (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'папуанска кина',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'филипински пезос',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'пакистанска рупија',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'пољски злот',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Пољски злоти (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Португалски ескудо',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'парагвајски гварани',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'катарски ријал',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Родејскидолар',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Румунски леј (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'румунски леј',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'српски динар',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'руска рубља',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Руска рубља (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'руандски франак',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'саудијски ријал',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'соломонски долар',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'сејшелска рупија',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Стари судански динар',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'суданска фунта',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Стара суданска фунта',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'шведска круна',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'сингапурски долар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'фунта Свете Јелене',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Словеначки толар',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Словачка круна',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'сијералеонски леоне',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'сомалијски шилинг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'суринамски долар',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Суринамски гилдер',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'јужносуданска фунта',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Саотомска добра (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'саотомска добра',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Совјетска рубља',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Салвадорски колон',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'сиријска фунта',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'свазилендски лилангени',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'тајландски бат',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Таџихистанска рубља',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'таџикистански сомон',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Туркменистански манат (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'туркменистански манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'туниски динар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'тонганска панга',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Тиморшки ескудо',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Турска лира (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'турска лира',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Тринидад-тобагошки долар',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'нови тајвански долар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'танзанијски шилинг',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'украјинска гривна',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Украјински карбованети',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Угандски шилинг (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'угандски шилинг',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'амерички долар',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'САД долар (следећи дан)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'САД долар (исти дан)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Уругвајски пезо ен унидадес индексадас',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Уругвајски пезо (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'уругвајски пезос',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'узбекистански сом',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Венецуелански боливар (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Венецуелански боливар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'венецуелански боливар',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'вијетнамски донг',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Вијетнамски донг (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'вануатски вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'самоанска тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'централноафрички франак',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'источнокарипски долар',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Европска валутна јединица',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Француски златни франак',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Француски UIC-франак',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'западноафрички франак',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP франак',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET фонд',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Јеменски динар',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'јеменски ријал',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Југословенски тврди динар',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Југословенски нови динар',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Југословенски конвертибилни динар',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Јужно-афрички ранд (финансијски)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'јужноафрички ранд',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Замбијска квача (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'замбијска квача',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Заирски нови заир',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Заирски заир',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Зимбабвеански долар (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Зимбабвеански долар (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Зимбабвеански долар (2008)',
        ],
    ],
];
