<?php

return [
    'Names' => [
        'BR' => 'Бразили',
        'CN' => 'Китай',
        'DE' => 'Герман',
        'FR' => 'Франц',
        'GB' => 'Стыр Британи',
        'GE' => 'Гуырдзыстон',
        'IN' => 'Инди',
        'IT' => 'Итали',
        'JP' => 'Япон',
        'RU' => 'Уӕрӕсе',
        'US' => 'АИШ',
    ],
];
