<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namíbia)',
        'af_ZA' => 'afrikaans (República de Sud-àfrica)',
        'ak' => 'àkan',
        'ak_GH' => 'àkan (Ghana)',
        'am' => 'amhàric',
        'am_ET' => 'amhàric (Etiòpia)',
        'ar' => 'àrab',
        'ar_001' => 'àrab (Món)',
        'ar_AE' => 'àrab (Emirats Àrabs Units)',
        'ar_BH' => 'àrab (Bahrain)',
        'ar_DJ' => 'àrab (Djibouti)',
        'ar_DZ' => 'àrab (Algèria)',
        'ar_EG' => 'àrab (Egipte)',
        'ar_EH' => 'àrab (Sàhara Occidental)',
        'ar_ER' => 'àrab (Eritrea)',
        'ar_IL' => 'àrab (Israel)',
        'ar_IQ' => 'àrab (Iraq)',
        'ar_JO' => 'àrab (Jordània)',
        'ar_KM' => 'àrab (Comores)',
        'ar_KW' => 'àrab (Kuwait)',
        'ar_LB' => 'àrab (Líban)',
        'ar_LY' => 'àrab (Líbia)',
        'ar_MA' => 'àrab (Marroc)',
        'ar_MR' => 'àrab (Mauritània)',
        'ar_OM' => 'àrab (Oman)',
        'ar_PS' => 'àrab (Territoris palestins)',
        'ar_QA' => 'àrab (Qatar)',
        'ar_SA' => 'àrab (Aràbia Saudita)',
        'ar_SD' => 'àrab (Sudan)',
        'ar_SO' => 'àrab (Somàlia)',
        'ar_SS' => 'àrab (Sudan del Sud)',
        'ar_SY' => 'àrab (Síria)',
        'ar_TD' => 'àrab (Txad)',
        'ar_TN' => 'àrab (Tunísia)',
        'ar_YE' => 'àrab (Iemen)',
        'as' => 'assamès',
        'as_IN' => 'assamès (Índia)',
        'az' => 'azerbaidjanès',
        'az_AZ' => 'azerbaidjanès (Azerbaidjan)',
        'az_Cyrl' => 'azerbaidjanès (ciríl·lic)',
        'az_Cyrl_AZ' => 'azerbaidjanès (ciríl·lic, Azerbaidjan)',
        'az_Latn' => 'azerbaidjanès (llatí)',
        'az_Latn_AZ' => 'azerbaidjanès (llatí, Azerbaidjan)',
        'be' => 'belarús',
        'be_BY' => 'belarús (Belarús)',
        'bg' => 'búlgar',
        'bg_BG' => 'búlgar (Bulgària)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengalí',
        'bn_BD' => 'bengalí (Bangladesh)',
        'bn_IN' => 'bengalí (Índia)',
        'bo' => 'tibetà',
        'bo_CN' => 'tibetà (Xina)',
        'bo_IN' => 'tibetà (Índia)',
        'br' => 'bretó',
        'br_FR' => 'bretó (França)',
        'bs' => 'bosnià',
        'bs_BA' => 'bosnià (Bòsnia i Hercegovina)',
        'bs_Cyrl' => 'bosnià (ciríl·lic)',
        'bs_Cyrl_BA' => 'bosnià (ciríl·lic, Bòsnia i Hercegovina)',
        'bs_Latn' => 'bosnià (llatí)',
        'bs_Latn_BA' => 'bosnià (llatí, Bòsnia i Hercegovina)',
        'ca' => 'català',
        'ca_AD' => 'català (Andorra)',
        'ca_ES' => 'català (Espanya)',
        'ca_FR' => 'català (França)',
        'ca_IT' => 'català (Itàlia)',
        'ce' => 'txetxè',
        'ce_RU' => 'txetxè (Rússia)',
        'cs' => 'txec',
        'cs_CZ' => 'txec (Txèquia)',
        'cv' => 'txuvaix',
        'cv_RU' => 'txuvaix (Rússia)',
        'cy' => 'gal·lès',
        'cy_GB' => 'gal·lès (Regne Unit)',
        'da' => 'danès',
        'da_DK' => 'danès (Dinamarca)',
        'da_GL' => 'danès (Groenlàndia)',
        'de' => 'alemany',
        'de_AT' => 'alemany (Àustria)',
        'de_BE' => 'alemany (Bèlgica)',
        'de_CH' => 'alemany (Suïssa)',
        'de_DE' => 'alemany (Alemanya)',
        'de_IT' => 'alemany (Itàlia)',
        'de_LI' => 'alemany (Liechtenstein)',
        'de_LU' => 'alemany (Luxemburg)',
        'dz' => 'dzongka',
        'dz_BT' => 'dzongka (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'grec',
        'el_CY' => 'grec (Xipre)',
        'el_GR' => 'grec (Grècia)',
        'en' => 'anglès',
        'en_001' => 'anglès (Món)',
        'en_150' => 'anglès (Europa)',
        'en_AE' => 'anglès (Emirats Àrabs Units)',
        'en_AG' => 'anglès (Antigua i Barbuda)',
        'en_AI' => 'anglès (Anguilla)',
        'en_AS' => 'anglès (Samoa Nord-americana)',
        'en_AT' => 'anglès (Àustria)',
        'en_AU' => 'anglès (Austràlia)',
        'en_BB' => 'anglès (Barbados)',
        'en_BE' => 'anglès (Bèlgica)',
        'en_BI' => 'anglès (Burundi)',
        'en_BM' => 'anglès (Bermudes)',
        'en_BS' => 'anglès (Bahames)',
        'en_BW' => 'anglès (Botswana)',
        'en_BZ' => 'anglès (Belize)',
        'en_CA' => 'anglès (Canadà)',
        'en_CC' => 'anglès (Illes Cocos)',
        'en_CH' => 'anglès (Suïssa)',
        'en_CK' => 'anglès (Illes Cook)',
        'en_CM' => 'anglès (Camerun)',
        'en_CX' => 'anglès (Illa Christmas)',
        'en_CY' => 'anglès (Xipre)',
        'en_DE' => 'anglès (Alemanya)',
        'en_DK' => 'anglès (Dinamarca)',
        'en_DM' => 'anglès (Dominica)',
        'en_ER' => 'anglès (Eritrea)',
        'en_FI' => 'anglès (Finlàndia)',
        'en_FJ' => 'anglès (Fiji)',
        'en_FK' => 'anglès (Illes Malvines)',
        'en_FM' => 'anglès (Micronèsia)',
        'en_GB' => 'anglès (Regne Unit)',
        'en_GD' => 'anglès (Grenada)',
        'en_GG' => 'anglès (Guernsey)',
        'en_GH' => 'anglès (Ghana)',
        'en_GI' => 'anglès (Gibraltar)',
        'en_GM' => 'anglès (Gàmbia)',
        'en_GU' => 'anglès (Guam)',
        'en_GY' => 'anglès (Guyana)',
        'en_HK' => 'anglès (Hong Kong [RAE Xina])',
        'en_IE' => 'anglès (Irlanda)',
        'en_IL' => 'anglès (Israel)',
        'en_IM' => 'anglès (Illa de Man)',
        'en_IN' => 'anglès (Índia)',
        'en_IO' => 'anglès (Territori Britànic de l’Oceà Índic)',
        'en_JE' => 'anglès (Jersey)',
        'en_JM' => 'anglès (Jamaica)',
        'en_KE' => 'anglès (Kenya)',
        'en_KI' => 'anglès (Kiribati)',
        'en_KN' => 'anglès (Saint Kitts i Nevis)',
        'en_KY' => 'anglès (Illes Caiman)',
        'en_LC' => 'anglès (Saint Lucia)',
        'en_LR' => 'anglès (Libèria)',
        'en_LS' => 'anglès (Lesotho)',
        'en_MG' => 'anglès (Madagascar)',
        'en_MH' => 'anglès (Illes Marshall)',
        'en_MO' => 'anglès (Macau [RAE Xina])',
        'en_MP' => 'anglès (Illes Mariannes Septentrionals)',
        'en_MS' => 'anglès (Montserrat)',
        'en_MT' => 'anglès (Malta)',
        'en_MU' => 'anglès (Maurici)',
        'en_MV' => 'anglès (Maldives)',
        'en_MW' => 'anglès (Malawi)',
        'en_MY' => 'anglès (Malàisia)',
        'en_NA' => 'anglès (Namíbia)',
        'en_NF' => 'anglès (Norfolk)',
        'en_NG' => 'anglès (Nigèria)',
        'en_NL' => 'anglès (Països Baixos)',
        'en_NR' => 'anglès (Nauru)',
        'en_NU' => 'anglès (Niue)',
        'en_NZ' => 'anglès (Nova Zelanda)',
        'en_PG' => 'anglès (Papua Nova Guinea)',
        'en_PH' => 'anglès (Filipines)',
        'en_PK' => 'anglès (Pakistan)',
        'en_PN' => 'anglès (Illes Pitcairn)',
        'en_PR' => 'anglès (Puerto Rico)',
        'en_PW' => 'anglès (Palau)',
        'en_RW' => 'anglès (Ruanda)',
        'en_SB' => 'anglès (Illes Salomó)',
        'en_SC' => 'anglès (Seychelles)',
        'en_SD' => 'anglès (Sudan)',
        'en_SE' => 'anglès (Suècia)',
        'en_SG' => 'anglès (Singapur)',
        'en_SH' => 'anglès (Santa Helena)',
        'en_SI' => 'anglès (Eslovènia)',
        'en_SL' => 'anglès (Sierra Leone)',
        'en_SS' => 'anglès (Sudan del Sud)',
        'en_SX' => 'anglès (Sint Maarten)',
        'en_SZ' => 'anglès (Eswatini)',
        'en_TC' => 'anglès (Illes Turks i Caicos)',
        'en_TK' => 'anglès (Tokelau)',
        'en_TO' => 'anglès (Tonga)',
        'en_TT' => 'anglès (Trinitat i Tobago)',
        'en_TV' => 'anglès (Tuvalu)',
        'en_TZ' => 'anglès (Tanzània)',
        'en_UG' => 'anglès (Uganda)',
        'en_UM' => 'anglès (Illes Perifèriques Menors dels EUA)',
        'en_US' => 'anglès (Estats Units)',
        'en_VC' => 'anglès (Saint Vincent i les Grenadines)',
        'en_VG' => 'anglès (Illes Verges britàniques)',
        'en_VI' => 'anglès (Illes Verges nord-americanes)',
        'en_VU' => 'anglès (Vanuatu)',
        'en_WS' => 'anglès (Samoa)',
        'en_ZA' => 'anglès (República de Sud-àfrica)',
        'en_ZM' => 'anglès (Zàmbia)',
        'en_ZW' => 'anglès (Zimbàbue)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Món)',
        'es' => 'espanyol',
        'es_419' => 'espanyol (Amèrica Llatina)',
        'es_AR' => 'espanyol (Argentina)',
        'es_BO' => 'espanyol (Bolívia)',
        'es_BR' => 'espanyol (Brasil)',
        'es_BZ' => 'espanyol (Belize)',
        'es_CL' => 'espanyol (Xile)',
        'es_CO' => 'espanyol (Colòmbia)',
        'es_CR' => 'espanyol (Costa Rica)',
        'es_CU' => 'espanyol (Cuba)',
        'es_DO' => 'espanyol (República Dominicana)',
        'es_EC' => 'espanyol (Equador)',
        'es_ES' => 'espanyol (Espanya)',
        'es_GQ' => 'espanyol (Guinea Equatorial)',
        'es_GT' => 'espanyol (Guatemala)',
        'es_HN' => 'espanyol (Hondures)',
        'es_MX' => 'espanyol (Mèxic)',
        'es_NI' => 'espanyol (Nicaragua)',
        'es_PA' => 'espanyol (Panamà)',
        'es_PE' => 'espanyol (Perú)',
        'es_PH' => 'espanyol (Filipines)',
        'es_PR' => 'espanyol (Puerto Rico)',
        'es_PY' => 'espanyol (Paraguai)',
        'es_SV' => 'espanyol (El Salvador)',
        'es_US' => 'espanyol (Estats Units)',
        'es_UY' => 'espanyol (Uruguai)',
        'es_VE' => 'espanyol (Veneçuela)',
        'et' => 'estonià',
        'et_EE' => 'estonià (Estònia)',
        'eu' => 'basc',
        'eu_ES' => 'basc (Espanya)',
        'fa' => 'persa',
        'fa_AF' => 'persa (Afganistan)',
        'fa_IR' => 'persa (Iran)',
        'ff' => 'ful',
        'ff_Adlm' => 'ful (adlam)',
        'ff_Adlm_BF' => 'ful (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'ful (adlam, Camerun)',
        'ff_Adlm_GH' => 'ful (adlam, Ghana)',
        'ff_Adlm_GM' => 'ful (adlam, Gàmbia)',
        'ff_Adlm_GN' => 'ful (adlam, Guinea)',
        'ff_Adlm_GW' => 'ful (adlam, Guinea Bissau)',
        'ff_Adlm_LR' => 'ful (adlam, Libèria)',
        'ff_Adlm_MR' => 'ful (adlam, Mauritània)',
        'ff_Adlm_NE' => 'ful (adlam, Níger)',
        'ff_Adlm_NG' => 'ful (adlam, Nigèria)',
        'ff_Adlm_SL' => 'ful (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'ful (adlam, Senegal)',
        'ff_CM' => 'ful (Camerun)',
        'ff_GN' => 'ful (Guinea)',
        'ff_Latn' => 'ful (llatí)',
        'ff_Latn_BF' => 'ful (llatí, Burkina Faso)',
        'ff_Latn_CM' => 'ful (llatí, Camerun)',
        'ff_Latn_GH' => 'ful (llatí, Ghana)',
        'ff_Latn_GM' => 'ful (llatí, Gàmbia)',
        'ff_Latn_GN' => 'ful (llatí, Guinea)',
        'ff_Latn_GW' => 'ful (llatí, Guinea Bissau)',
        'ff_Latn_LR' => 'ful (llatí, Libèria)',
        'ff_Latn_MR' => 'ful (llatí, Mauritània)',
        'ff_Latn_NE' => 'ful (llatí, Níger)',
        'ff_Latn_NG' => 'ful (llatí, Nigèria)',
        'ff_Latn_SL' => 'ful (llatí, Sierra Leone)',
        'ff_Latn_SN' => 'ful (llatí, Senegal)',
        'ff_MR' => 'ful (Mauritània)',
        'ff_SN' => 'ful (Senegal)',
        'fi' => 'finès',
        'fi_FI' => 'finès (Finlàndia)',
        'fo' => 'feroès',
        'fo_DK' => 'feroès (Dinamarca)',
        'fo_FO' => 'feroès (Illes Fèroe)',
        'fr' => 'francès',
        'fr_BE' => 'francès (Bèlgica)',
        'fr_BF' => 'francès (Burkina Faso)',
        'fr_BI' => 'francès (Burundi)',
        'fr_BJ' => 'francès (Benín)',
        'fr_BL' => 'francès (Saint-Barthélemy)',
        'fr_CA' => 'francès (Canadà)',
        'fr_CD' => 'francès (Congo - Kinshasa)',
        'fr_CF' => 'francès (República Centreafricana)',
        'fr_CG' => 'francès (Congo - Brazzaville)',
        'fr_CH' => 'francès (Suïssa)',
        'fr_CI' => 'francès (Côte d’Ivoire)',
        'fr_CM' => 'francès (Camerun)',
        'fr_DJ' => 'francès (Djibouti)',
        'fr_DZ' => 'francès (Algèria)',
        'fr_FR' => 'francès (França)',
        'fr_GA' => 'francès (Gabon)',
        'fr_GF' => 'francès (Guaiana Francesa)',
        'fr_GN' => 'francès (Guinea)',
        'fr_GP' => 'francès (Guadalupe)',
        'fr_GQ' => 'francès (Guinea Equatorial)',
        'fr_HT' => 'francès (Haití)',
        'fr_KM' => 'francès (Comores)',
        'fr_LU' => 'francès (Luxemburg)',
        'fr_MA' => 'francès (Marroc)',
        'fr_MC' => 'francès (Mònaco)',
        'fr_MF' => 'francès (Saint Martin)',
        'fr_MG' => 'francès (Madagascar)',
        'fr_ML' => 'francès (Mali)',
        'fr_MQ' => 'francès (Martinica)',
        'fr_MR' => 'francès (Mauritània)',
        'fr_MU' => 'francès (Maurici)',
        'fr_NC' => 'francès (Nova Caledònia)',
        'fr_NE' => 'francès (Níger)',
        'fr_PF' => 'francès (Polinèsia Francesa)',
        'fr_PM' => 'francès (Saint-Pierre-et-Miquelon)',
        'fr_RE' => 'francès (Illa de la Reunió)',
        'fr_RW' => 'francès (Ruanda)',
        'fr_SC' => 'francès (Seychelles)',
        'fr_SN' => 'francès (Senegal)',
        'fr_SY' => 'francès (Síria)',
        'fr_TD' => 'francès (Txad)',
        'fr_TG' => 'francès (Togo)',
        'fr_TN' => 'francès (Tunísia)',
        'fr_VU' => 'francès (Vanuatu)',
        'fr_WF' => 'francès (Wallis i Futuna)',
        'fr_YT' => 'francès (Mayotte)',
        'fy' => 'frisó occidental',
        'fy_NL' => 'frisó occidental (Països Baixos)',
        'ga' => 'irlandès',
        'ga_GB' => 'irlandès (Regne Unit)',
        'ga_IE' => 'irlandès (Irlanda)',
        'gd' => 'gaèlic escocès',
        'gd_GB' => 'gaèlic escocès (Regne Unit)',
        'gl' => 'gallec',
        'gl_ES' => 'gallec (Espanya)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (Índia)',
        'gv' => 'manx',
        'gv_IM' => 'manx (Illa de Man)',
        'ha' => 'haussa',
        'ha_GH' => 'haussa (Ghana)',
        'ha_NE' => 'haussa (Níger)',
        'ha_NG' => 'haussa (Nigèria)',
        'he' => 'hebreu',
        'he_IL' => 'hebreu (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Índia)',
        'hi_Latn' => 'hindi (llatí)',
        'hi_Latn_IN' => 'hindi (llatí, Índia)',
        'hr' => 'croat',
        'hr_BA' => 'croat (Bòsnia i Hercegovina)',
        'hr_HR' => 'croat (Croàcia)',
        'hu' => 'hongarès',
        'hu_HU' => 'hongarès (Hongria)',
        'hy' => 'armeni',
        'hy_AM' => 'armeni (Armènia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Món)',
        'id' => 'indonesi',
        'id_ID' => 'indonesi (Indonèsia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigèria)',
        'ii' => 'yi sichuan',
        'ii_CN' => 'yi sichuan (Xina)',
        'is' => 'islandès',
        'is_IS' => 'islandès (Islàndia)',
        'it' => 'italià',
        'it_CH' => 'italià (Suïssa)',
        'it_IT' => 'italià (Itàlia)',
        'it_SM' => 'italià (San Marino)',
        'it_VA' => 'italià (Ciutat del Vaticà)',
        'ja' => 'japonès',
        'ja_JP' => 'japonès (Japó)',
        'jv' => 'javanès',
        'jv_ID' => 'javanès (Indonèsia)',
        'ka' => 'georgià',
        'ka_GE' => 'georgià (Geòrgia)',
        'ki' => 'kikuiu',
        'ki_KE' => 'kikuiu (Kenya)',
        'kk' => 'kazakh',
        'kk_KZ' => 'kazakh (Kazakhstan)',
        'kl' => 'groenlandès',
        'kl_GL' => 'groenlandès (Groenlàndia)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Cambodja)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Índia)',
        'ko' => 'coreà',
        'ko_KP' => 'coreà (Corea del Nord)',
        'ko_KR' => 'coreà (Corea del Sud)',
        'ks' => 'caixmiri',
        'ks_Arab' => 'caixmiri (àrab)',
        'ks_Arab_IN' => 'caixmiri (àrab, Índia)',
        'ks_Deva' => 'caixmiri (devanagari)',
        'ks_Deva_IN' => 'caixmiri (devanagari, Índia)',
        'ks_IN' => 'caixmiri (Índia)',
        'ku' => 'kurd',
        'ku_TR' => 'kurd (Turquia)',
        'kw' => 'còrnic',
        'kw_GB' => 'còrnic (Regne Unit)',
        'ky' => 'kirguís',
        'ky_KG' => 'kirguís (Kirguizstan)',
        'lb' => 'luxemburguès',
        'lb_LU' => 'luxemburguès (Luxemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo - Kinshasa)',
        'ln_CF' => 'lingala (República Centreafricana)',
        'ln_CG' => 'lingala (Congo - Brazzaville)',
        'lo' => 'laosià',
        'lo_LA' => 'laosià (Laos)',
        'lt' => 'lituà',
        'lt_LT' => 'lituà (Lituània)',
        'lu' => 'luba katanga',
        'lu_CD' => 'luba katanga (Congo - Kinshasa)',
        'lv' => 'letó',
        'lv_LV' => 'letó (Letònia)',
        'mg' => 'malgaix',
        'mg_MG' => 'malgaix (Madagascar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nova Zelanda)',
        'mk' => 'macedoni',
        'mk_MK' => 'macedoni (Macedònia del Nord)',
        'ml' => 'malaiàlam',
        'ml_IN' => 'malaiàlam (Índia)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongòlia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (Índia)',
        'ms' => 'malai',
        'ms_BN' => 'malai (Brunei)',
        'ms_ID' => 'malai (Indonèsia)',
        'ms_MY' => 'malai (Malàisia)',
        'ms_SG' => 'malai (Singapur)',
        'mt' => 'maltès',
        'mt_MT' => 'maltès (Malta)',
        'my' => 'birmà',
        'my_MM' => 'birmà (Myanmar [Birmània])',
        'nb' => 'noruec bokmål',
        'nb_NO' => 'noruec bokmål (Noruega)',
        'nb_SJ' => 'noruec bokmål (Svalbard i Jan Mayen)',
        'nd' => 'ndebele septentrional',
        'nd_ZW' => 'ndebele septentrional (Zimbàbue)',
        'ne' => 'nepalès',
        'ne_IN' => 'nepalès (Índia)',
        'ne_NP' => 'nepalès (Nepal)',
        'nl' => 'neerlandès',
        'nl_AW' => 'neerlandès (Aruba)',
        'nl_BE' => 'neerlandès (Bèlgica)',
        'nl_BQ' => 'neerlandès (Carib Neerlandès)',
        'nl_CW' => 'neerlandès (Curaçao)',
        'nl_NL' => 'neerlandès (Països Baixos)',
        'nl_SR' => 'neerlandès (Surinam)',
        'nl_SX' => 'neerlandès (Sint Maarten)',
        'nn' => 'noruec nynorsk',
        'nn_NO' => 'noruec nynorsk (Noruega)',
        'no' => 'noruec',
        'no_NO' => 'noruec (Noruega)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiòpia)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'oriya',
        'or_IN' => 'oriya (Índia)',
        'os' => 'osseta',
        'os_GE' => 'osseta (Geòrgia)',
        'os_RU' => 'osseta (Rússia)',
        'pa' => 'panjabi',
        'pa_Arab' => 'panjabi (àrab)',
        'pa_Arab_PK' => 'panjabi (àrab, Pakistan)',
        'pa_Guru' => 'panjabi (gurmukhi)',
        'pa_Guru_IN' => 'panjabi (gurmukhi, Índia)',
        'pa_IN' => 'panjabi (Índia)',
        'pa_PK' => 'panjabi (Pakistan)',
        'pl' => 'polonès',
        'pl_PL' => 'polonès (Polònia)',
        'ps' => 'paixtu',
        'ps_AF' => 'paixtu (Afganistan)',
        'ps_PK' => 'paixtu (Pakistan)',
        'pt' => 'portuguès',
        'pt_AO' => 'portuguès (Angola)',
        'pt_BR' => 'portuguès (Brasil)',
        'pt_CH' => 'portuguès (Suïssa)',
        'pt_CV' => 'portuguès (Cap Verd)',
        'pt_GQ' => 'portuguès (Guinea Equatorial)',
        'pt_GW' => 'portuguès (Guinea Bissau)',
        'pt_LU' => 'portuguès (Luxemburg)',
        'pt_MO' => 'portuguès (Macau [RAE Xina])',
        'pt_MZ' => 'portuguès (Moçambic)',
        'pt_PT' => 'portuguès (Portugal)',
        'pt_ST' => 'portuguès (São Tomé i Príncipe)',
        'pt_TL' => 'portuguès (Timor-Leste)',
        'qu' => 'quítxua',
        'qu_BO' => 'quítxua (Bolívia)',
        'qu_EC' => 'quítxua (Equador)',
        'qu_PE' => 'quítxua (Perú)',
        'rm' => 'retoromànic',
        'rm_CH' => 'retoromànic (Suïssa)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'romanès',
        'ro_MD' => 'romanès (Moldàvia)',
        'ro_RO' => 'romanès (Romania)',
        'ru' => 'rus',
        'ru_BY' => 'rus (Belarús)',
        'ru_KG' => 'rus (Kirguizstan)',
        'ru_KZ' => 'rus (Kazakhstan)',
        'ru_MD' => 'rus (Moldàvia)',
        'ru_RU' => 'rus (Rússia)',
        'ru_UA' => 'rus (Ucraïna)',
        'rw' => 'ruandès',
        'rw_RW' => 'ruandès (Ruanda)',
        'sa' => 'sànscrit',
        'sa_IN' => 'sànscrit (Índia)',
        'sc' => 'sard',
        'sc_IT' => 'sard (Itàlia)',
        'sd' => 'sindi',
        'sd_Arab' => 'sindi (àrab)',
        'sd_Arab_PK' => 'sindi (àrab, Pakistan)',
        'sd_Deva' => 'sindi (devanagari)',
        'sd_Deva_IN' => 'sindi (devanagari, Índia)',
        'sd_IN' => 'sindi (Índia)',
        'sd_PK' => 'sindi (Pakistan)',
        'se' => 'sami septentrional',
        'se_FI' => 'sami septentrional (Finlàndia)',
        'se_NO' => 'sami septentrional (Noruega)',
        'se_SE' => 'sami septentrional (Suècia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (República Centreafricana)',
        'sh' => 'serbocroat',
        'sh_BA' => 'serbocroat (Bòsnia i Hercegovina)',
        'si' => 'singalès',
        'si_LK' => 'singalès (Sri Lanka)',
        'sk' => 'eslovac',
        'sk_SK' => 'eslovac (Eslovàquia)',
        'sl' => 'eslovè',
        'sl_SI' => 'eslovè (Eslovènia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbàbue)',
        'so' => 'somali',
        'so_DJ' => 'somali (Djibouti)',
        'so_ET' => 'somali (Etiòpia)',
        'so_KE' => 'somali (Kenya)',
        'so_SO' => 'somali (Somàlia)',
        'sq' => 'albanès',
        'sq_AL' => 'albanès (Albània)',
        'sq_MK' => 'albanès (Macedònia del Nord)',
        'sr' => 'serbi',
        'sr_BA' => 'serbi (Bòsnia i Hercegovina)',
        'sr_Cyrl' => 'serbi (ciríl·lic)',
        'sr_Cyrl_BA' => 'serbi (ciríl·lic, Bòsnia i Hercegovina)',
        'sr_Cyrl_ME' => 'serbi (ciríl·lic, Montenegro)',
        'sr_Cyrl_RS' => 'serbi (ciríl·lic, Sèrbia)',
        'sr_Latn' => 'serbi (llatí)',
        'sr_Latn_BA' => 'serbi (llatí, Bòsnia i Hercegovina)',
        'sr_Latn_ME' => 'serbi (llatí, Montenegro)',
        'sr_Latn_RS' => 'serbi (llatí, Sèrbia)',
        'sr_ME' => 'serbi (Montenegro)',
        'sr_RS' => 'serbi (Sèrbia)',
        'su' => 'sondanès',
        'su_ID' => 'sondanès (Indonèsia)',
        'su_Latn' => 'sondanès (llatí)',
        'su_Latn_ID' => 'sondanès (llatí, Indonèsia)',
        'sv' => 'suec',
        'sv_AX' => 'suec (Illes Åland)',
        'sv_FI' => 'suec (Finlàndia)',
        'sv_SE' => 'suec (Suècia)',
        'sw' => 'suahili',
        'sw_CD' => 'suahili (Congo - Kinshasa)',
        'sw_KE' => 'suahili (Kenya)',
        'sw_TZ' => 'suahili (Tanzània)',
        'sw_UG' => 'suahili (Uganda)',
        'ta' => 'tàmil',
        'ta_IN' => 'tàmil (Índia)',
        'ta_LK' => 'tàmil (Sri Lanka)',
        'ta_MY' => 'tàmil (Malàisia)',
        'ta_SG' => 'tàmil (Singapur)',
        'te' => 'telugu',
        'te_IN' => 'telugu (Índia)',
        'tg' => 'tadjik',
        'tg_TJ' => 'tadjik (Tadjikistan)',
        'th' => 'tai',
        'th_TH' => 'tai (Tailàndia)',
        'ti' => 'tigrinya',
        'ti_ER' => 'tigrinya (Eritrea)',
        'ti_ET' => 'tigrinya (Etiòpia)',
        'tk' => 'turcman',
        'tk_TM' => 'turcman (Turkmenistan)',
        'tl' => 'tagal',
        'tl_PH' => 'tagal (Filipines)',
        'to' => 'tongalès',
        'to_TO' => 'tongalès (Tonga)',
        'tr' => 'turc',
        'tr_CY' => 'turc (Xipre)',
        'tr_TR' => 'turc (Turquia)',
        'tt' => 'tàtar',
        'tt_RU' => 'tàtar (Rússia)',
        'ug' => 'uigur',
        'ug_CN' => 'uigur (Xina)',
        'uk' => 'ucraïnès',
        'uk_UA' => 'ucraïnès (Ucraïna)',
        'ur' => 'urdú',
        'ur_IN' => 'urdú (Índia)',
        'ur_PK' => 'urdú (Pakistan)',
        'uz' => 'uzbek',
        'uz_AF' => 'uzbek (Afganistan)',
        'uz_Arab' => 'uzbek (àrab)',
        'uz_Arab_AF' => 'uzbek (àrab, Afganistan)',
        'uz_Cyrl' => 'uzbek (ciríl·lic)',
        'uz_Cyrl_UZ' => 'uzbek (ciríl·lic, Uzbekistan)',
        'uz_Latn' => 'uzbek (llatí)',
        'uz_Latn_UZ' => 'uzbek (llatí, Uzbekistan)',
        'uz_UZ' => 'uzbek (Uzbekistan)',
        'vi' => 'vietnamita',
        'vi_VN' => 'vietnamita (Vietnam)',
        'wo' => 'wòlof',
        'wo_SN' => 'wòlof (Senegal)',
        'xh' => 'xosa',
        'xh_ZA' => 'xosa (República de Sud-àfrica)',
        'yi' => 'ídix',
        'yi_001' => 'ídix (Món)',
        'yo' => 'ioruba',
        'yo_BJ' => 'ioruba (Benín)',
        'yo_NG' => 'ioruba (Nigèria)',
        'zh' => 'xinès',
        'zh_CN' => 'xinès (Xina)',
        'zh_HK' => 'xinès (Hong Kong [RAE Xina])',
        'zh_Hans' => 'xinès (simplificat)',
        'zh_Hans_CN' => 'xinès (simplificat, Xina)',
        'zh_Hans_HK' => 'xinès (simplificat, Hong Kong [RAE Xina])',
        'zh_Hans_MO' => 'xinès (simplificat, Macau [RAE Xina])',
        'zh_Hans_SG' => 'xinès (simplificat, Singapur)',
        'zh_Hant' => 'xinès (tradicional)',
        'zh_Hant_HK' => 'xinès (tradicional, Hong Kong [RAE Xina])',
        'zh_Hant_MO' => 'xinès (tradicional, Macau [RAE Xina])',
        'zh_Hant_TW' => 'xinès (tradicional, Taiwan)',
        'zh_MO' => 'xinès (Macau [RAE Xina])',
        'zh_SG' => 'xinès (Singapur)',
        'zh_TW' => 'xinès (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (República de Sud-àfrica)',
    ],
];
