<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвичица юкъара хан (Абиджан)',
        'Africa/Accra' => 'Гринвичица юкъара хан (Аккра)',
        'Africa/Addis_Ababa' => 'Малхбален Африка (Аддис-Абеба)',
        'Africa/Algiers' => 'Юккъера Европа (Алжир)',
        'Africa/Asmera' => 'Малхбален Африка (Асмера)',
        'Africa/Bamako' => 'Гринвичица юкъара хан (Бамако)',
        'Africa/Bangui' => 'Малхбузен Африка (Банги)',
        'Africa/Banjul' => 'Гринвичица юкъара хан (Банжул)',
        'Africa/Bissau' => 'Гринвичица юкъара хан (Бисау)',
        'Africa/Blantyre' => 'Юккъера Африка (Блантайр)',
        'Africa/Brazzaville' => 'Малхбузен Африка (Браззавиль)',
        'Africa/Bujumbura' => 'Юккъера Африка (Бужумбура)',
        'Africa/Cairo' => 'Малхбален Европа (КъахӀира)',
        'Africa/Casablanca' => 'Малхбузен Европа (Касабланка)',
        'Africa/Ceuta' => 'Юккъера Европа (Сеута)',
        'Africa/Conakry' => 'Гринвичица юкъара хан (Конакри)',
        'Africa/Dakar' => 'Гринвичица юкъара хан (Дакар)',
        'Africa/Dar_es_Salaam' => 'Малхбален Африка (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Малхбален Африка (Джибути)',
        'Africa/Douala' => 'Малхбузен Африка (Дуала)',
        'Africa/El_Aaiun' => 'Малхбузен Европа (Эль-Аюн)',
        'Africa/Freetown' => 'Гринвичица юкъара хан (Фритаун)',
        'Africa/Gaborone' => 'Юккъера Африка (Габороне)',
        'Africa/Harare' => 'Юккъера Африка (Хараре)',
        'Africa/Johannesburg' => 'Къилба Африка (Йоханнесбург)',
        'Africa/Juba' => 'Юккъера Африка (Джуба)',
        'Africa/Kampala' => 'Малхбален Африка (Кампала)',
        'Africa/Khartoum' => 'Юккъера Африка (Хартум)',
        'Africa/Kigali' => 'Юккъера Африка (Кигали)',
        'Africa/Kinshasa' => 'Малхбузен Африка (Киншаса)',
        'Africa/Lagos' => 'Малхбузен Африка (Лагос)',
        'Africa/Libreville' => 'Малхбузен Африка (Либревиль)',
        'Africa/Lome' => 'Гринвичица юкъара хан (Ломе)',
        'Africa/Luanda' => 'Малхбузен Африка (Луанда)',
        'Africa/Lubumbashi' => 'Юккъера Африка (Лубумбаши)',
        'Africa/Lusaka' => 'Юккъера Африка (Лусака)',
        'Africa/Malabo' => 'Малхбузен Африка (Малабо)',
        'Africa/Maputo' => 'Юккъера Африка (Мапуту)',
        'Africa/Maseru' => 'Къилба Африка (Масеру)',
        'Africa/Mbabane' => 'Къилба Африка (Мбабане)',
        'Africa/Mogadishu' => 'Малхбален Африка (Могадишо)',
        'Africa/Monrovia' => 'Гринвичица юкъара хан (Монрови)',
        'Africa/Nairobi' => 'Малхбален Африка (Найроби)',
        'Africa/Ndjamena' => 'Малхбузен Африка (Нджамена)',
        'Africa/Niamey' => 'Малхбузен Африка (Ниамей)',
        'Africa/Nouakchott' => 'Гринвичица юкъара хан (Нуакшот)',
        'Africa/Ouagadougou' => 'Гринвичица юкъара хан (Уагадугу)',
        'Africa/Porto-Novo' => 'Малхбузен Африка (Порто-Ново)',
        'Africa/Sao_Tome' => 'Гринвичица юкъара хан (Сан-Томе)',
        'Africa/Tripoli' => 'Малхбален Европа (Триполи)',
        'Africa/Tunis' => 'Юккъера Европа (Тунис)',
        'Africa/Windhoek' => 'Юккъера Африка (Виндхук)',
        'America/Adak' => 'Гавайн-алеутийн хан (Адак)',
        'America/Anchorage' => 'Аляска (Анкоридж)',
        'America/Anguilla' => 'Атлантикан хан (Ангилья)',
        'America/Antigua' => 'Атлантикан хан (Антигуа)',
        'America/Araguaina' => 'Бразили (Арагуаина)',
        'America/Argentina/La_Rioja' => 'Аргентина (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина (Рио-Гальегос)',
        'America/Argentina/Salta' => 'Аргентина (Сальта)',
        'America/Argentina/San_Juan' => 'Аргентина (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина (Сан-Луис)',
        'America/Argentina/Tucuman' => 'Аргентина (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина (Ушуая)',
        'America/Aruba' => 'Атлантикан хан (Аруба)',
        'America/Asuncion' => 'Парагвай (Асунсьон)',
        'America/Bahia' => 'Бразили (Баи)',
        'America/Bahia_Banderas' => 'Юккъера Америка (Баия-де-Бандерас)',
        'America/Barbados' => 'Атлантикан хан (Барбадос)',
        'America/Belem' => 'Бразили (Белен)',
        'America/Belize' => 'Юккъера Америка (Белиз)',
        'America/Blanc-Sablon' => 'Атлантикан хан (Бланк-Саблон)',
        'America/Boa_Vista' => 'Амазонка (Боа-Виста)',
        'America/Bogota' => 'Колумби (Богота)',
        'America/Boise' => 'Лаьмнийн хан (АЦШ) (Бойсе)',
        'America/Buenos_Aires' => 'Аргентина (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Лаьмнийн хан (АЦШ) (Кеймбридж-Бей)',
        'America/Campo_Grande' => 'Амазонка (Кампу-Гранди)',
        'America/Cancun' => 'Малхбален Америка (Канкун)',
        'America/Caracas' => 'Венесуэла (Каракас)',
        'America/Catamarca' => 'Аргентина (Катамарка)',
        'America/Cayenne' => 'Французийн Гвиана (Кайенна)',
        'America/Cayman' => 'Малхбален Америка (Кайман)',
        'America/Chicago' => 'Юккъера Америка (Чикаго)',
        'America/Chihuahua' => 'Тийна океанан Мексикан хан (Чиуауа)',
        'America/Coral_Harbour' => 'Малхбален Америка (Корал-Харбор)',
        'America/Cordoba' => 'Аргентина (Кордова)',
        'America/Costa_Rica' => 'Юккъера Америка (Коста-Рика)',
        'America/Creston' => 'Лаьмнийн хан (АЦШ) (Крестон)',
        'America/Cuiaba' => 'Амазонка (Куяба)',
        'America/Curacao' => 'Атлантикан хан (Кюрасао)',
        'America/Danmarkshavn' => 'Гринвичица юкъара хан (Денмарксхавн)',
        'America/Dawson' => 'Канада (Доусон)',
        'America/Dawson_Creek' => 'Лаьмнийн хан (АЦШ) (Доусон-Крик)',
        'America/Denver' => 'Лаьмнийн хан (АЦШ) (Денвер)',
        'America/Detroit' => 'Малхбален Америка (Детройт)',
        'America/Dominica' => 'Атлантикан хан (Доминика)',
        'America/Edmonton' => 'Лаьмнийн хан (АЦШ) (Эдмонтон)',
        'America/Eirunepe' => 'Бразили (Эйрунепе)',
        'America/El_Salvador' => 'Юккъера Америка (Сальвадор)',
        'America/Fort_Nelson' => 'Лаьмнийн хан (АЦШ) (Форт Нельсон)',
        'America/Fortaleza' => 'Бразили (Форталеза)',
        'America/Glace_Bay' => 'Атлантикан хан (Глейс-Бей)',
        'America/Godthab' => 'Малхбузен Гренланди (Готхоб)',
        'America/Goose_Bay' => 'Атлантикан хан (Гус-Бей)',
        'America/Grand_Turk' => 'Малхбален Америка (Гранд Турк)',
        'America/Grenada' => 'Атлантикан хан (Гренада)',
        'America/Guadeloupe' => 'Атлантикан хан (Гваделупа)',
        'America/Guatemala' => 'Юккъера Америка (Гватемала)',
        'America/Guayaquil' => 'Эквадор (Гуаякиль)',
        'America/Guyana' => 'Гайана',
        'America/Halifax' => 'Атлантикан хан (Галифакс)',
        'America/Havana' => 'Куба (Гавана)',
        'America/Hermosillo' => 'Тийна океанан Мексикан хан (Эрмосильо)',
        'America/Indiana/Knox' => 'Юккъера Америка (Нокс)',
        'America/Indiana/Marengo' => 'Малхбален Америка (Маренго)',
        'America/Indiana/Petersburg' => 'Малхбален Америка (Петерсбург)',
        'America/Indiana/Tell_City' => 'Юккъера Америка (Телл-Сити)',
        'America/Indiana/Vevay' => 'Малхбален Америка (Вивэй)',
        'America/Indiana/Vincennes' => 'Малхбален Америка (Винсенс)',
        'America/Indiana/Winamac' => 'Малхбален Америка (Винамак)',
        'America/Indianapolis' => 'Малхбален Америка (Индианаполис)',
        'America/Inuvik' => 'Лаьмнийн хан (АЦШ) (Инувик)',
        'America/Iqaluit' => 'Малхбален Америка (Икалуит)',
        'America/Jamaica' => 'Малхбален Америка (Ямайка)',
        'America/Jujuy' => 'Аргентина (Жужуй)',
        'America/Juneau' => 'Аляска (Джуно)',
        'America/Kentucky/Monticello' => 'Малхбален Америка (Монтиселло)',
        'America/Kralendijk' => 'Атлантикан хан (Кралендейк)',
        'America/La_Paz' => 'Боливи (Ла-Пас)',
        'America/Lima' => 'Перу (Лима)',
        'America/Los_Angeles' => 'Тийна океанан хан (Лос-Анджелес)',
        'America/Louisville' => 'Малхбален Америка (Луисвилл)',
        'America/Lower_Princes' => 'Атлантикан хан (Лоуэр-Принсес-Куортер)',
        'America/Maceio' => 'Бразили (Масейо)',
        'America/Managua' => 'Юккъера Америка (Манагуа)',
        'America/Manaus' => 'Амазонка (Манаус)',
        'America/Marigot' => 'Атлантикан хан (Мариго)',
        'America/Martinique' => 'Атлантикан хан (Мартиника)',
        'America/Matamoros' => 'Юккъера Америка (Матаморос)',
        'America/Mazatlan' => 'Тийна океанан Мексикан хан (Масатлан)',
        'America/Mendoza' => 'Аргентина (Мендоса)',
        'America/Menominee' => 'Юккъера Америка (Меномини)',
        'America/Merida' => 'Юккъера Америка (Мерида)',
        'America/Metlakatla' => 'Аляска (Метлакатла)',
        'America/Mexico_City' => 'Юккъера Америка (Мехико)',
        'America/Miquelon' => 'Сен-Пьер а, Микелон а',
        'America/Moncton' => 'Атлантикан хан (Монктон)',
        'America/Monterrey' => 'Юккъера Америка (Монтеррей)',
        'America/Montevideo' => 'Уругвай (Монтевидео)',
        'America/Montreal' => 'Канада (Montreal)',
        'America/Montserrat' => 'Атлантикан хан (Монсеррат)',
        'America/Nassau' => 'Малхбален Америка (Нассау)',
        'America/New_York' => 'Малхбален Америка (Нью-Йорк)',
        'America/Nipigon' => 'Малхбален Америка (Нипигон)',
        'America/Nome' => 'Аляска (Ном)',
        'America/Noronha' => 'Фернанду-ди-Норонья (Норонха)',
        'America/North_Dakota/Beulah' => 'Юккъера Америка (Бойла, Къилбаседа Дакота)',
        'America/North_Dakota/Center' => 'Юккъера Америка (Юкъ, Къилбаседа Дакота)',
        'America/North_Dakota/New_Salem' => 'Юккъера Америка (Нью-Салем)',
        'America/Ojinaga' => 'Лаьмнийн хан (АЦШ) (Охинага)',
        'America/Panama' => 'Малхбален Америка (Панама)',
        'America/Pangnirtung' => 'Малхбален Америка (Пангниртанг)',
        'America/Paramaribo' => 'Суринам (Парамарибо)',
        'America/Phoenix' => 'Лаьмнийн хан (АЦШ) (Финикс)',
        'America/Port-au-Prince' => 'Малхбален Америка (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атлантикан хан (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'Амазонка (Порту-Велью)',
        'America/Puerto_Rico' => 'Атлантикан хан (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чили (Пунта-Аренас)',
        'America/Rainy_River' => 'Юккъера Америка (Рейни-Ривер)',
        'America/Rankin_Inlet' => 'Юккъера Америка (Ранкин-Инлет)',
        'America/Recife' => 'Бразили (Ресифи)',
        'America/Regina' => 'Юккъера Америка (Реджайна)',
        'America/Resolute' => 'Юккъера Америка (Резолют)',
        'America/Rio_Branco' => 'Бразили (Риу-Бранку)',
        'America/Santa_Isabel' => 'Къилбаседа Американ Мексикан хан (Санта-Изабел)',
        'America/Santarem' => 'Бразили (Сантарен)',
        'America/Santiago' => 'Чили (Сантьяго)',
        'America/Santo_Domingo' => 'Атлантикан хан (Санто-Доминго)',
        'America/Sao_Paulo' => 'Бразили (Сан-Паулу)',
        'America/Scoresbysund' => 'Малхбален Гренланди (Скорсбисунн)',
        'America/Sitka' => 'Аляска (Ситка)',
        'America/St_Barthelemy' => 'Атлантикан хан (Сен-Бартельми)',
        'America/St_Johns' => 'Ньюфаундленд (Сент-Джонс)',
        'America/St_Kitts' => 'Атлантикан хан (Сент-Китс)',
        'America/St_Lucia' => 'Атлантикан хан (Сент-Люси)',
        'America/St_Thomas' => 'Атлантикан хан (Сент-Томас)',
        'America/St_Vincent' => 'Атлантикан хан (Сент-Винсент)',
        'America/Swift_Current' => 'Юккъера Америка (Свифт-Карент)',
        'America/Tegucigalpa' => 'Юккъера Америка (Тегусигальпа)',
        'America/Thule' => 'Атлантикан хан (Туле)',
        'America/Thunder_Bay' => 'Малхбален Америка (Тандер-Бей)',
        'America/Tijuana' => 'Тийна океанан хан (Тихуана)',
        'America/Toronto' => 'Малхбален Америка (Торонто)',
        'America/Tortola' => 'Атлантикан хан (Тортола)',
        'America/Vancouver' => 'Тийна океанан хан (Ванкувер)',
        'America/Whitehorse' => 'Канада (Уайтхорс)',
        'America/Winnipeg' => 'Юккъера Америка (Виннипег)',
        'America/Yakutat' => 'Аляска (Якутат)',
        'America/Yellowknife' => 'Лаьмнийн хан (АЦШ) (Йеллоунайф)',
        'Antarctica/Casey' => 'Антарктида (Кейси)',
        'Antarctica/Davis' => 'Дейвис',
        'Antarctica/DumontDUrville' => 'Дюмон-д’Юрвиль',
        'Antarctica/Macquarie' => 'Малхбален Австрали (Маккуори)',
        'Antarctica/Mawson' => 'Моусон',
        'Antarctica/McMurdo' => 'Керла Зеланди (Мак-Мердо)',
        'Antarctica/Palmer' => 'Чили (Палмер)',
        'Antarctica/Rothera' => 'Ротера',
        'Antarctica/Syowa' => 'Сёва',
        'Antarctica/Troll' => 'Гринвичица юкъара хан (Тролль)',
        'Antarctica/Vostok' => 'Восток',
        'Arctic/Longyearbyen' => 'Юккъера Европа (Лонгйир)',
        'Asia/Aden' => 'СаӀудийн Ӏаьрбийчоь (Аден)',
        'Asia/Almaty' => 'Малхбален Казахстан (Алма-Ата)',
        'Asia/Amman' => 'Малхбален Европа (Ӏамман)',
        'Asia/Anadyr' => 'Росси (Анадырь)',
        'Asia/Aqtau' => 'Малхбузен Казахстан (Актау)',
        'Asia/Aqtobe' => 'Малхбузен Казахстан (Актобе)',
        'Asia/Ashgabat' => 'Туркмени (Ашхабад)',
        'Asia/Atyrau' => 'Малхбузен Казахстан (Атирау)',
        'Asia/Baghdad' => 'СаӀудийн Ӏаьрбийчоь (БагӀдад)',
        'Asia/Bahrain' => 'СаӀудийн Ӏаьрбийчоь (Бахрейн)',
        'Asia/Baku' => 'Азербайджан (Бакох)',
        'Asia/Bangkok' => 'Индокитай (Бангкок)',
        'Asia/Barnaul' => 'Росси (Барнаул)',
        'Asia/Beirut' => 'Малхбален Европа (Бейрут)',
        'Asia/Bishkek' => 'Киргизи (Бишкек)',
        'Asia/Brunei' => 'Бруней-Даруссалам',
        'Asia/Calcutta' => 'ХӀинди (Калькутта)',
        'Asia/Chita' => 'Якутск (Чита)',
        'Asia/Choibalsan' => 'Улан-Батор (Чойбалсан)',
        'Asia/Colombo' => 'ХӀинди (Коломбо)',
        'Asia/Damascus' => 'Малхбален Европа (Димашкъ)',
        'Asia/Dhaka' => 'Бангладеш (Дакка)',
        'Asia/Dili' => 'Малхбален Тимор (Дили)',
        'Asia/Dubai' => 'ГӀажарийн айма (Дубай)',
        'Asia/Dushanbe' => 'Таджикистан (Душанбе)',
        'Asia/Famagusta' => 'Малхбален Европа (Фамагуста)',
        'Asia/Gaza' => 'Малхбален Европа (Газа)',
        'Asia/Hebron' => 'Малхбален Европа (Хеврон)',
        'Asia/Hong_Kong' => 'Гонконг',
        'Asia/Hovd' => 'Ховд',
        'Asia/Irkutsk' => 'Иркутск',
        'Asia/Jakarta' => 'Малхбузен Индонези (Джакарта)',
        'Asia/Jayapura' => 'Малхбален Индонези (Джайпур)',
        'Asia/Jerusalem' => 'Израиль (Къудс-ГӀала)',
        'Asia/Kabul' => 'ОвхӀан (Кабул)',
        'Asia/Kamchatka' => 'Росси (Петропавловск-Камчатски)',
        'Asia/Karachi' => 'Пакистан (Карачи)',
        'Asia/Katmandu' => 'Непал (Катманду)',
        'Asia/Khandyga' => 'Якутск (Хандыга)',
        'Asia/Krasnoyarsk' => 'Красноярск',
        'Asia/Kuala_Lumpur' => 'Малайзи (Куала-Лумпур)',
        'Asia/Kuching' => 'Малайзи (Кучинг)',
        'Asia/Kuwait' => 'СаӀудийн Ӏаьрбийчоь (Кувейт)',
        'Asia/Macau' => 'Цийчоь (Макао)',
        'Asia/Magadan' => 'Магадан',
        'Asia/Makassar' => 'Юккъера Индонези (Макасар)',
        'Asia/Manila' => 'Филиппинаш (Манила)',
        'Asia/Muscat' => 'ГӀажарийн айма (Маскат)',
        'Asia/Nicosia' => 'Малхбален Европа (Никоси)',
        'Asia/Novokuznetsk' => 'Красноярск (Новокузнецк)',
        'Asia/Novosibirsk' => 'Новосибирск',
        'Asia/Omsk' => 'Омск',
        'Asia/Oral' => 'Малхбузен Казахстан (Орал)',
        'Asia/Phnom_Penh' => 'Индокитай (Пномпень)',
        'Asia/Pontianak' => 'Малхбузен Индонези (Понтианак)',
        'Asia/Pyongyang' => 'Корей (Пхеньян)',
        'Asia/Qatar' => 'СаӀудийн Ӏаьрбийчоь (Катар)',
        'Asia/Qostanay' => 'Малхбален Казахстан (Qostanay)',
        'Asia/Qyzylorda' => 'Малхбузен Казахстан (Кызылорда)',
        'Asia/Rangoon' => 'Мьянма (Рангун)',
        'Asia/Riyadh' => 'СаӀудийн Ӏаьрбийчоь (Эр-Рияд)',
        'Asia/Saigon' => 'Индокитай (Хошимин)',
        'Asia/Sakhalin' => 'Сахалин (Сахалин гӀ-е)',
        'Asia/Samarkand' => 'Узбекистан (Самарканд)',
        'Asia/Seoul' => 'Корей (Сеул)',
        'Asia/Shanghai' => 'Цийчоь (Шанхай)',
        'Asia/Singapore' => 'Сингапур',
        'Asia/Srednekolymsk' => 'Магадан (Среднеколымск)',
        'Asia/Taipei' => 'Тайвань (Тайбэй)',
        'Asia/Tashkent' => 'Узбекистан (Ташкент)',
        'Asia/Tbilisi' => 'Гуьржийчоь (Тбилиси)',
        'Asia/Tehran' => 'ГӀажарийчоь (ТехӀран)',
        'Asia/Thimphu' => 'Бутан (Тимпу)',
        'Asia/Tokyo' => 'Япон (Токио)',
        'Asia/Tomsk' => 'Росси (Томск)',
        'Asia/Ulaanbaatar' => 'Улан-Батор',
        'Asia/Urumqi' => 'Цийчоь (Урумчи)',
        'Asia/Ust-Nera' => 'Владивосток (Усть-Нера)',
        'Asia/Vientiane' => 'Индокитай (Вьентьян)',
        'Asia/Vladivostok' => 'Владивосток',
        'Asia/Yakutsk' => 'Якутск',
        'Asia/Yekaterinburg' => 'Екатеринбург',
        'Asia/Yerevan' => 'Эрмалойчоь (Ереван)',
        'Atlantic/Azores' => 'Азоран гӀайренаш',
        'Atlantic/Bermuda' => 'Атлантикан хан (Бермудаш)',
        'Atlantic/Canary' => 'Малхбузен Европа (Канаран гӀайренаш)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде',
        'Atlantic/Faeroe' => 'Малхбузен Европа (Фарерийн гӀайренаш)',
        'Atlantic/Madeira' => 'Малхбузен Европа (Мадейра, гӀ-е)',
        'Atlantic/Reykjavik' => 'Гринвичица юкъара хан (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Къилба Георги (Къилба Джорджи)',
        'Atlantic/St_Helena' => 'Гринвичица юкъара хан (Езачу Еленин гӀайре)',
        'Atlantic/Stanley' => 'Фолклендан гӀайренаш (Стэнли)',
        'Australia/Adelaide' => 'Юккъера Австрали (Аделаида)',
        'Australia/Brisbane' => 'Малхбален Австрали (Брисбен)',
        'Australia/Broken_Hill' => 'Юккъера Австрали (Брокен-Хилл)',
        'Australia/Currie' => 'Малхбален Австрали (Керри)',
        'Australia/Darwin' => 'Юккъера Австрали (Дарвин)',
        'Australia/Eucla' => 'Юккъера Австрали, малхбузен хан (Юкла)',
        'Australia/Hobart' => 'Малхбален Австрали (Хобарт)',
        'Australia/Lindeman' => 'Малхбален Австрали (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд-Хау (Лорд-Хау, гӀ-е)',
        'Australia/Melbourne' => 'Малхбален Австрали (Мельбурн)',
        'Australia/Perth' => 'Малхбузен Австрали (Перт)',
        'Australia/Sydney' => 'Малхбален Австрали (Сидней)',
        'CST6CDT' => 'Юккъера Америка',
        'EST5EDT' => 'Малхбален Америка',
        'Etc/GMT' => 'Гринвичица юкъара хан',
        'Europe/Amsterdam' => 'Юккъера Европа (Амстердам)',
        'Europe/Andorra' => 'Юккъера Европа (Андорра)',
        'Europe/Astrakhan' => 'Москва (Аштаркхне)',
        'Europe/Athens' => 'Малхбален Европа (Афина)',
        'Europe/Belgrade' => 'Юккъера Европа (Белград)',
        'Europe/Berlin' => 'Юккъера Европа (Берлин)',
        'Europe/Bratislava' => 'Юккъера Европа (Братислава)',
        'Europe/Brussels' => 'Юккъера Европа (Брюссель)',
        'Europe/Bucharest' => 'Малхбален Европа (Бухарест)',
        'Europe/Budapest' => 'Юккъера Европа (Будапешт)',
        'Europe/Busingen' => 'Юккъера Европа (Бюзинген-ам-Хохрайн)',
        'Europe/Chisinau' => 'Малхбален Европа (Кишинев)',
        'Europe/Copenhagen' => 'Юккъера Европа (Копенгаген)',
        'Europe/Dublin' => 'Гринвичица юкъара хан (Дублин)',
        'Europe/Gibraltar' => 'Юккъера Европа (Гибралтар)',
        'Europe/Guernsey' => 'Гринвичица юкъара хан (Гернси)',
        'Europe/Helsinki' => 'Малхбален Европа (Хельсинки)',
        'Europe/Isle_of_Man' => 'Гринвичица юкъара хан (Мэн, гӀ-е)',
        'Europe/Istanbul' => 'Туркойчоь (Стамбул)',
        'Europe/Jersey' => 'Гринвичица юкъара хан (Джерси)',
        'Europe/Kaliningrad' => 'Малхбален Европа (Калининград)',
        'Europe/Kiev' => 'Малхбален Европа (Киев)',
        'Europe/Kirov' => 'Росси (Киров)',
        'Europe/Lisbon' => 'Малхбузен Европа (Лиссабон)',
        'Europe/Ljubljana' => 'Юккъера Европа (Любляна)',
        'Europe/London' => 'Гринвичица юкъара хан (Лондон)',
        'Europe/Luxembourg' => 'Юккъера Европа (Люксембург)',
        'Europe/Madrid' => 'Юккъера Европа (Мадрид)',
        'Europe/Malta' => 'Юккъера Европа (Мальта)',
        'Europe/Mariehamn' => 'Малхбален Европа (Мариехамн)',
        'Europe/Minsk' => 'Москва (Минск)',
        'Europe/Monaco' => 'Юккъера Европа (Монако)',
        'Europe/Moscow' => 'Москва',
        'Europe/Oslo' => 'Юккъера Европа (Осло)',
        'Europe/Paris' => 'Юккъера Европа (Париж)',
        'Europe/Podgorica' => 'Юккъера Европа (Подгорица)',
        'Europe/Prague' => 'Юккъера Европа (Прага)',
        'Europe/Riga' => 'Малхбален Европа (Рига)',
        'Europe/Rome' => 'Юккъера Европа (Рим)',
        'Europe/Samara' => 'Росси (Самара)',
        'Europe/San_Marino' => 'Юккъера Европа (Сан-Марино)',
        'Europe/Sarajevo' => 'Юккъера Европа (Сараево)',
        'Europe/Saratov' => 'Москва (Саратов)',
        'Europe/Simferopol' => 'Москва (Симферополь)',
        'Europe/Skopje' => 'Юккъера Европа (Скопье)',
        'Europe/Sofia' => 'Малхбален Европа (Софи)',
        'Europe/Stockholm' => 'Юккъера Европа (Стокгольм)',
        'Europe/Tallinn' => 'Малхбален Европа (Таллин)',
        'Europe/Tirane' => 'Юккъера Европа (Тирана)',
        'Europe/Ulyanovsk' => 'Москва (Ульяновск)',
        'Europe/Uzhgorod' => 'Малхбален Европа (Ужгород)',
        'Europe/Vaduz' => 'Юккъера Европа (Вадуц)',
        'Europe/Vatican' => 'Юккъера Европа (Ватикан)',
        'Europe/Vienna' => 'Юккъера Европа (Вена)',
        'Europe/Vilnius' => 'Малхбален Европа (Вильнюс)',
        'Europe/Volgograd' => 'Волгоград',
        'Europe/Warsaw' => 'Юккъера Европа (Варшава)',
        'Europe/Zagreb' => 'Юккъера Европа (Загреб)',
        'Europe/Zaporozhye' => 'Малхбален Европа (Запорожье)',
        'Europe/Zurich' => 'Юккъера Европа (Цюрих)',
        'Indian/Antananarivo' => 'Малхбален Африка (Антананариву)',
        'Indian/Chagos' => 'Индин океан (Чагос)',
        'Indian/Christmas' => 'Ӏийса пайхамар винчу ден гӀайре',
        'Indian/Cocos' => 'Кокосийн, гӀ-наш',
        'Indian/Comoro' => 'Малхбален Африка (Коморийн гӀайренаш)',
        'Indian/Kerguelen' => 'Французийн къилба а, Антарктидан а хан (Кергелен)',
        'Indian/Mahe' => 'Сейшелан гӀайренаш (Маэ)',
        'Indian/Maldives' => 'Мальдиваш',
        'Indian/Mauritius' => 'Маврики',
        'Indian/Mayotte' => 'Малхбален Африка (Майорка)',
        'Indian/Reunion' => 'Реюньон',
        'MST7MDT' => 'Лаьмнийн хан (АЦШ)',
        'PST8PDT' => 'Тийна океанан хан',
        'Pacific/Apia' => 'хан Апиа, Самоа',
        'Pacific/Auckland' => 'Керла Зеланди (Окленд)',
        'Pacific/Bougainville' => 'Папуа – Керла Гвиней (Бугенвиль, гӀ-е)',
        'Pacific/Chatham' => 'Чатем (Чатем, гӀ-е)',
        'Pacific/Easter' => 'Мархин гӀайре (Мархин гӀайренаш)',
        'Pacific/Efate' => 'Вануату (Эфате)',
        'Pacific/Enderbury' => 'Феникс, гӀ-наш (Эндерберин, гӀ-е)',
        'Pacific/Fakaofo' => 'Токелау (Факаофо)',
        'Pacific/Fiji' => 'Фиджи',
        'Pacific/Funafuti' => 'Тувалу (Фунафути)',
        'Pacific/Galapagos' => 'Галапагосан гӀайренаш',
        'Pacific/Gambier' => 'Гамбье (Гамбьен, гӀ-наш)',
        'Pacific/Guadalcanal' => 'Соломонан, гӀ-наш (Гвадалканал)',
        'Pacific/Guam' => 'Чаморро (Гуам)',
        'Pacific/Honolulu' => 'Гавайн-алеутийн хан (Гонолулу)',
        'Pacific/Johnston' => 'Гавайн-алеутийн хан (Джонстон)',
        'Pacific/Kiritimati' => 'Лайн, гӀ-наш (Киритимати)',
        'Pacific/Kosrae' => 'Косраэ (Косрае)',
        'Pacific/Kwajalein' => 'Маршалан , гӀ-наш (Кваджалейн)',
        'Pacific/Majuro' => 'Маршалан , гӀ-наш (Маджуро)',
        'Pacific/Marquesas' => 'Маркизан, гӀ-наш',
        'Pacific/Midway' => 'Самоа (Мидуэй, гӀ-наш)',
        'Pacific/Nauru' => 'Науру',
        'Pacific/Niue' => 'Ниуэ',
        'Pacific/Norfolk' => 'Норфолк',
        'Pacific/Noumea' => 'Керла Каледони (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа (Паго-Паго)',
        'Pacific/Palau' => 'Палау',
        'Pacific/Pitcairn' => 'Питкэрн (Питкерн)',
        'Pacific/Ponape' => 'Понапе, гӀ-наш',
        'Pacific/Port_Moresby' => 'Папуа – Керла Гвиней (Порт-Морсби)',
        'Pacific/Rarotonga' => 'Кукан, гӀ-наш (Раротонга)',
        'Pacific/Saipan' => 'Чаморро (Сайпан)',
        'Pacific/Tahiti' => 'Таити, гӀ-наш',
        'Pacific/Tarawa' => 'Гилбертан, гӀ-наш (Тарава)',
        'Pacific/Tongatapu' => 'Тонга (Тонгатапу)',
        'Pacific/Truk' => 'Чуук (Трук, гӀ-наш)',
        'Pacific/Wake' => 'Уэйк, гӀ-е',
        'Pacific/Wallis' => 'Уоллис а, Футуна а',
    ],
    'Meta' => [
    ],
];
