<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Sør-Afrika)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amharisk',
        'am_ET' => 'amharisk (Etiopia)',
        'ar' => 'arabisk',
        'ar_001' => 'arabisk (verden)',
        'ar_AE' => 'arabisk (De forente arabiske emirater)',
        'ar_BH' => 'arabisk (Bahrain)',
        'ar_DJ' => 'arabisk (Djibouti)',
        'ar_DZ' => 'arabisk (Algerie)',
        'ar_EG' => 'arabisk (Egypt)',
        'ar_EH' => 'arabisk (Vest-Sahara)',
        'ar_ER' => 'arabisk (Eritrea)',
        'ar_IL' => 'arabisk (Israel)',
        'ar_IQ' => 'arabisk (Irak)',
        'ar_JO' => 'arabisk (Jordan)',
        'ar_KM' => 'arabisk (Komorene)',
        'ar_KW' => 'arabisk (Kuwait)',
        'ar_LB' => 'arabisk (Libanon)',
        'ar_LY' => 'arabisk (Libya)',
        'ar_MA' => 'arabisk (Marokko)',
        'ar_MR' => 'arabisk (Mauritania)',
        'ar_OM' => 'arabisk (Oman)',
        'ar_PS' => 'arabisk (Det palestinske området)',
        'ar_QA' => 'arabisk (Qatar)',
        'ar_SA' => 'arabisk (Saudi-Arabia)',
        'ar_SD' => 'arabisk (Sudan)',
        'ar_SO' => 'arabisk (Somalia)',
        'ar_SS' => 'arabisk (Sør-Sudan)',
        'ar_SY' => 'arabisk (Syria)',
        'ar_TD' => 'arabisk (Tsjad)',
        'ar_TN' => 'arabisk (Tunisia)',
        'ar_YE' => 'arabisk (Jemen)',
        'as' => 'assamesisk',
        'as_IN' => 'assamesisk (India)',
        'az' => 'aserbajdsjansk',
        'az_AZ' => 'aserbajdsjansk (Aserbajdsjan)',
        'az_Cyrl' => 'aserbajdsjansk (kyrillisk)',
        'az_Cyrl_AZ' => 'aserbajdsjansk (kyrillisk, Aserbajdsjan)',
        'az_Latn' => 'aserbajdsjansk (latinsk)',
        'az_Latn_AZ' => 'aserbajdsjansk (latinsk, Aserbajdsjan)',
        'be' => 'hviterussisk',
        'be_BY' => 'hviterussisk (Hviterussland)',
        'bg' => 'bulgarsk',
        'bg_BG' => 'bulgarsk (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengali',
        'bn_BD' => 'bengali (Bangladesh)',
        'bn_IN' => 'bengali (India)',
        'bo' => 'tibetansk',
        'bo_CN' => 'tibetansk (Kina)',
        'bo_IN' => 'tibetansk (India)',
        'br' => 'bretonsk',
        'br_FR' => 'bretonsk (Frankrike)',
        'bs' => 'bosnisk',
        'bs_BA' => 'bosnisk (Bosnia-Hercegovina)',
        'bs_Cyrl' => 'bosnisk (kyrillisk)',
        'bs_Cyrl_BA' => 'bosnisk (kyrillisk, Bosnia-Hercegovina)',
        'bs_Latn' => 'bosnisk (latinsk)',
        'bs_Latn_BA' => 'bosnisk (latinsk, Bosnia-Hercegovina)',
        'ca' => 'katalansk',
        'ca_AD' => 'katalansk (Andorra)',
        'ca_ES' => 'katalansk (Spania)',
        'ca_FR' => 'katalansk (Frankrike)',
        'ca_IT' => 'katalansk (Italia)',
        'ce' => 'tsjetsjensk',
        'ce_RU' => 'tsjetsjensk (Russland)',
        'cs' => 'tsjekkisk',
        'cs_CZ' => 'tsjekkisk (Tsjekkia)',
        'cv' => 'tsjuvasjisk',
        'cv_RU' => 'tsjuvasjisk (Russland)',
        'cy' => 'walisisk',
        'cy_GB' => 'walisisk (Storbritannia)',
        'da' => 'dansk',
        'da_DK' => 'dansk (Danmark)',
        'da_GL' => 'dansk (Grønland)',
        'de' => 'tysk',
        'de_AT' => 'tysk (Østerrike)',
        'de_BE' => 'tysk (Belgia)',
        'de_CH' => 'tysk (Sveits)',
        'de_DE' => 'tysk (Tyskland)',
        'de_IT' => 'tysk (Italia)',
        'de_LI' => 'tysk (Liechtenstein)',
        'de_LU' => 'tysk (Luxemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'gresk',
        'el_CY' => 'gresk (Kypros)',
        'el_GR' => 'gresk (Hellas)',
        'en' => 'engelsk',
        'en_001' => 'engelsk (verden)',
        'en_150' => 'engelsk (Europa)',
        'en_AE' => 'engelsk (De forente arabiske emirater)',
        'en_AG' => 'engelsk (Antigua og Barbuda)',
        'en_AI' => 'engelsk (Anguilla)',
        'en_AS' => 'engelsk (Amerikansk Samoa)',
        'en_AT' => 'engelsk (Østerrike)',
        'en_AU' => 'engelsk (Australia)',
        'en_BB' => 'engelsk (Barbados)',
        'en_BE' => 'engelsk (Belgia)',
        'en_BI' => 'engelsk (Burundi)',
        'en_BM' => 'engelsk (Bermuda)',
        'en_BS' => 'engelsk (Bahamas)',
        'en_BW' => 'engelsk (Botswana)',
        'en_BZ' => 'engelsk (Belize)',
        'en_CA' => 'engelsk (Canada)',
        'en_CC' => 'engelsk (Kokosøyene)',
        'en_CH' => 'engelsk (Sveits)',
        'en_CK' => 'engelsk (Cookøyene)',
        'en_CM' => 'engelsk (Kamerun)',
        'en_CX' => 'engelsk (Christmasøya)',
        'en_CY' => 'engelsk (Kypros)',
        'en_DE' => 'engelsk (Tyskland)',
        'en_DK' => 'engelsk (Danmark)',
        'en_DM' => 'engelsk (Dominica)',
        'en_ER' => 'engelsk (Eritrea)',
        'en_FI' => 'engelsk (Finland)',
        'en_FJ' => 'engelsk (Fiji)',
        'en_FK' => 'engelsk (Falklandsøyene)',
        'en_FM' => 'engelsk (Mikronesiaføderasjonen)',
        'en_GB' => 'engelsk (Storbritannia)',
        'en_GD' => 'engelsk (Grenada)',
        'en_GG' => 'engelsk (Guernsey)',
        'en_GH' => 'engelsk (Ghana)',
        'en_GI' => 'engelsk (Gibraltar)',
        'en_GM' => 'engelsk (Gambia)',
        'en_GU' => 'engelsk (Guam)',
        'en_GY' => 'engelsk (Guyana)',
        'en_HK' => 'engelsk (Hongkong SAR Kina)',
        'en_IE' => 'engelsk (Irland)',
        'en_IL' => 'engelsk (Israel)',
        'en_IM' => 'engelsk (Man)',
        'en_IN' => 'engelsk (India)',
        'en_IO' => 'engelsk (Det britiske territoriet i Indiahavet)',
        'en_JE' => 'engelsk (Jersey)',
        'en_JM' => 'engelsk (Jamaica)',
        'en_KE' => 'engelsk (Kenya)',
        'en_KI' => 'engelsk (Kiribati)',
        'en_KN' => 'engelsk (Saint Kitts og Nevis)',
        'en_KY' => 'engelsk (Caymanøyene)',
        'en_LC' => 'engelsk (St. Lucia)',
        'en_LR' => 'engelsk (Liberia)',
        'en_LS' => 'engelsk (Lesotho)',
        'en_MG' => 'engelsk (Madagaskar)',
        'en_MH' => 'engelsk (Marshalløyene)',
        'en_MO' => 'engelsk (Macao SAR Kina)',
        'en_MP' => 'engelsk (Nord-Marianene)',
        'en_MS' => 'engelsk (Montserrat)',
        'en_MT' => 'engelsk (Malta)',
        'en_MU' => 'engelsk (Mauritius)',
        'en_MV' => 'engelsk (Maldivene)',
        'en_MW' => 'engelsk (Malawi)',
        'en_MY' => 'engelsk (Malaysia)',
        'en_NA' => 'engelsk (Namibia)',
        'en_NF' => 'engelsk (Norfolkøya)',
        'en_NG' => 'engelsk (Nigeria)',
        'en_NL' => 'engelsk (Nederland)',
        'en_NR' => 'engelsk (Nauru)',
        'en_NU' => 'engelsk (Niue)',
        'en_NZ' => 'engelsk (New Zealand)',
        'en_PG' => 'engelsk (Papua Ny-Guinea)',
        'en_PH' => 'engelsk (Filippinene)',
        'en_PK' => 'engelsk (Pakistan)',
        'en_PN' => 'engelsk (Pitcairnøyene)',
        'en_PR' => 'engelsk (Puerto Rico)',
        'en_PW' => 'engelsk (Palau)',
        'en_RW' => 'engelsk (Rwanda)',
        'en_SB' => 'engelsk (Salomonøyene)',
        'en_SC' => 'engelsk (Seychellene)',
        'en_SD' => 'engelsk (Sudan)',
        'en_SE' => 'engelsk (Sverige)',
        'en_SG' => 'engelsk (Singapore)',
        'en_SH' => 'engelsk (St. Helena)',
        'en_SI' => 'engelsk (Slovenia)',
        'en_SL' => 'engelsk (Sierra Leone)',
        'en_SS' => 'engelsk (Sør-Sudan)',
        'en_SX' => 'engelsk (Sint Maarten)',
        'en_SZ' => 'engelsk (Eswatini)',
        'en_TC' => 'engelsk (Turks- og Caicosøyene)',
        'en_TK' => 'engelsk (Tokelau)',
        'en_TO' => 'engelsk (Tonga)',
        'en_TT' => 'engelsk (Trinidad og Tobago)',
        'en_TV' => 'engelsk (Tuvalu)',
        'en_TZ' => 'engelsk (Tanzania)',
        'en_UG' => 'engelsk (Uganda)',
        'en_UM' => 'engelsk (USAs ytre øyer)',
        'en_US' => 'engelsk (USA)',
        'en_VC' => 'engelsk (St. Vincent og Grenadinene)',
        'en_VG' => 'engelsk (De britiske jomfruøyene)',
        'en_VI' => 'engelsk (De amerikanske jomfruøyene)',
        'en_VU' => 'engelsk (Vanuatu)',
        'en_WS' => 'engelsk (Samoa)',
        'en_ZA' => 'engelsk (Sør-Afrika)',
        'en_ZM' => 'engelsk (Zambia)',
        'en_ZW' => 'engelsk (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (verden)',
        'es' => 'spansk',
        'es_419' => 'spansk (Latin-Amerika)',
        'es_AR' => 'spansk (Argentina)',
        'es_BO' => 'spansk (Bolivia)',
        'es_BR' => 'spansk (Brasil)',
        'es_BZ' => 'spansk (Belize)',
        'es_CL' => 'spansk (Chile)',
        'es_CO' => 'spansk (Colombia)',
        'es_CR' => 'spansk (Costa Rica)',
        'es_CU' => 'spansk (Cuba)',
        'es_DO' => 'spansk (Den dominikanske republikk)',
        'es_EC' => 'spansk (Ecuador)',
        'es_ES' => 'spansk (Spania)',
        'es_GQ' => 'spansk (Ekvatorial-Guinea)',
        'es_GT' => 'spansk (Guatemala)',
        'es_HN' => 'spansk (Honduras)',
        'es_MX' => 'spansk (Mexico)',
        'es_NI' => 'spansk (Nicaragua)',
        'es_PA' => 'spansk (Panama)',
        'es_PE' => 'spansk (Peru)',
        'es_PH' => 'spansk (Filippinene)',
        'es_PR' => 'spansk (Puerto Rico)',
        'es_PY' => 'spansk (Paraguay)',
        'es_SV' => 'spansk (El Salvador)',
        'es_US' => 'spansk (USA)',
        'es_UY' => 'spansk (Uruguay)',
        'es_VE' => 'spansk (Venezuela)',
        'et' => 'estisk',
        'et_EE' => 'estisk (Estland)',
        'eu' => 'baskisk',
        'eu_ES' => 'baskisk (Spania)',
        'fa' => 'persisk',
        'fa_AF' => 'persisk (Afghanistan)',
        'fa_IR' => 'persisk (Iran)',
        'ff' => 'fulfulde',
        'ff_Adlm' => 'fulfulde (adlam)',
        'ff_Adlm_BF' => 'fulfulde (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulfulde (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fulfulde (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulfulde (adlam, Gambia)',
        'ff_Adlm_GN' => 'fulfulde (adlam, Guinea)',
        'ff_Adlm_GW' => 'fulfulde (adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulfulde (adlam, Liberia)',
        'ff_Adlm_MR' => 'fulfulde (adlam, Mauritania)',
        'ff_Adlm_NE' => 'fulfulde (adlam, Niger)',
        'ff_Adlm_NG' => 'fulfulde (adlam, Nigeria)',
        'ff_Adlm_SL' => 'fulfulde (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulfulde (adlam, Senegal)',
        'ff_CM' => 'fulfulde (Kamerun)',
        'ff_GN' => 'fulfulde (Guinea)',
        'ff_Latn' => 'fulfulde (latinsk)',
        'ff_Latn_BF' => 'fulfulde (latinsk, Burkina Faso)',
        'ff_Latn_CM' => 'fulfulde (latinsk, Kamerun)',
        'ff_Latn_GH' => 'fulfulde (latinsk, Ghana)',
        'ff_Latn_GM' => 'fulfulde (latinsk, Gambia)',
        'ff_Latn_GN' => 'fulfulde (latinsk, Guinea)',
        'ff_Latn_GW' => 'fulfulde (latinsk, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulfulde (latinsk, Liberia)',
        'ff_Latn_MR' => 'fulfulde (latinsk, Mauritania)',
        'ff_Latn_NE' => 'fulfulde (latinsk, Niger)',
        'ff_Latn_NG' => 'fulfulde (latinsk, Nigeria)',
        'ff_Latn_SL' => 'fulfulde (latinsk, Sierra Leone)',
        'ff_Latn_SN' => 'fulfulde (latinsk, Senegal)',
        'ff_MR' => 'fulfulde (Mauritania)',
        'ff_SN' => 'fulfulde (Senegal)',
        'fi' => 'finsk',
        'fi_FI' => 'finsk (Finland)',
        'fo' => 'færøysk',
        'fo_DK' => 'færøysk (Danmark)',
        'fo_FO' => 'færøysk (Færøyene)',
        'fr' => 'fransk',
        'fr_BE' => 'fransk (Belgia)',
        'fr_BF' => 'fransk (Burkina Faso)',
        'fr_BI' => 'fransk (Burundi)',
        'fr_BJ' => 'fransk (Benin)',
        'fr_BL' => 'fransk (Saint-Barthélemy)',
        'fr_CA' => 'fransk (Canada)',
        'fr_CD' => 'fransk (Kongo)',
        'fr_CF' => 'fransk (Den sentralafrikanske republikk)',
        'fr_CG' => 'fransk (Kongo-Brazzaville)',
        'fr_CH' => 'fransk (Sveits)',
        'fr_CI' => 'fransk (Elfenbenskysten)',
        'fr_CM' => 'fransk (Kamerun)',
        'fr_DJ' => 'fransk (Djibouti)',
        'fr_DZ' => 'fransk (Algerie)',
        'fr_FR' => 'fransk (Frankrike)',
        'fr_GA' => 'fransk (Gabon)',
        'fr_GF' => 'fransk (Fransk Guyana)',
        'fr_GN' => 'fransk (Guinea)',
        'fr_GP' => 'fransk (Guadeloupe)',
        'fr_GQ' => 'fransk (Ekvatorial-Guinea)',
        'fr_HT' => 'fransk (Haiti)',
        'fr_KM' => 'fransk (Komorene)',
        'fr_LU' => 'fransk (Luxemburg)',
        'fr_MA' => 'fransk (Marokko)',
        'fr_MC' => 'fransk (Monaco)',
        'fr_MF' => 'fransk (Saint-Martin)',
        'fr_MG' => 'fransk (Madagaskar)',
        'fr_ML' => 'fransk (Mali)',
        'fr_MQ' => 'fransk (Martinique)',
        'fr_MR' => 'fransk (Mauritania)',
        'fr_MU' => 'fransk (Mauritius)',
        'fr_NC' => 'fransk (Ny-Caledonia)',
        'fr_NE' => 'fransk (Niger)',
        'fr_PF' => 'fransk (Fransk Polynesia)',
        'fr_PM' => 'fransk (Saint-Pierre-et-Miquelon)',
        'fr_RE' => 'fransk (Réunion)',
        'fr_RW' => 'fransk (Rwanda)',
        'fr_SC' => 'fransk (Seychellene)',
        'fr_SN' => 'fransk (Senegal)',
        'fr_SY' => 'fransk (Syria)',
        'fr_TD' => 'fransk (Tsjad)',
        'fr_TG' => 'fransk (Togo)',
        'fr_TN' => 'fransk (Tunisia)',
        'fr_VU' => 'fransk (Vanuatu)',
        'fr_WF' => 'fransk (Wallis og Futuna)',
        'fr_YT' => 'fransk (Mayotte)',
        'fy' => 'vestfrisisk',
        'fy_NL' => 'vestfrisisk (Nederland)',
        'ga' => 'irsk',
        'ga_GB' => 'irsk (Storbritannia)',
        'ga_IE' => 'irsk (Irland)',
        'gd' => 'skotsk-gælisk',
        'gd_GB' => 'skotsk-gælisk (Storbritannia)',
        'gl' => 'galisisk',
        'gl_ES' => 'galisisk (Spania)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'gv' => 'mansk',
        'gv_IM' => 'mansk (Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'hebraisk',
        'he_IL' => 'hebraisk (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latinsk)',
        'hi_Latn_IN' => 'hindi (latinsk, India)',
        'hr' => 'kroatisk',
        'hr_BA' => 'kroatisk (Bosnia-Hercegovina)',
        'hr_HR' => 'kroatisk (Kroatia)',
        'hu' => 'ungarsk',
        'hu_HU' => 'ungarsk (Ungarn)',
        'hy' => 'armensk',
        'hy_AM' => 'armensk (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (verden)',
        'id' => 'indonesisk',
        'id_ID' => 'indonesisk (Indonesia)',
        'ig' => 'ibo',
        'ig_NG' => 'ibo (Nigeria)',
        'ii' => 'sichuan-yi',
        'ii_CN' => 'sichuan-yi (Kina)',
        'is' => 'islandsk',
        'is_IS' => 'islandsk (Island)',
        'it' => 'italiensk',
        'it_CH' => 'italiensk (Sveits)',
        'it_IT' => 'italiensk (Italia)',
        'it_SM' => 'italiensk (San Marino)',
        'it_VA' => 'italiensk (Vatikanstaten)',
        'ja' => 'japansk',
        'ja_JP' => 'japansk (Japan)',
        'jv' => 'javanesisk',
        'jv_ID' => 'javanesisk (Indonesia)',
        'ka' => 'georgisk',
        'ka_GE' => 'georgisk (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kasakhisk',
        'kk_KZ' => 'kasakhisk (Kasakhstan)',
        'kl' => 'grønlandsk',
        'kl_GL' => 'grønlandsk (Grønland)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Kambodsja)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'koreansk',
        'ko_KP' => 'koreansk (Nord-Korea)',
        'ko_KR' => 'koreansk (Sør-Korea)',
        'ks' => 'kasjmiri',
        'ks_Arab' => 'kasjmiri (arabisk)',
        'ks_Arab_IN' => 'kasjmiri (arabisk, India)',
        'ks_Deva' => 'kasjmiri (devanagari)',
        'ks_Deva_IN' => 'kasjmiri (devanagari, India)',
        'ks_IN' => 'kasjmiri (India)',
        'ku' => 'kurdisk',
        'ku_TR' => 'kurdisk (Tyrkia)',
        'kw' => 'kornisk',
        'kw_GB' => 'kornisk (Storbritannia)',
        'ky' => 'kirgisisk',
        'ky_KG' => 'kirgisisk (Kirgisistan)',
        'lb' => 'luxemburgsk',
        'lb_LU' => 'luxemburgsk (Luxemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo)',
        'ln_CF' => 'lingala (Den sentralafrikanske republikk)',
        'ln_CG' => 'lingala (Kongo-Brazzaville)',
        'lo' => 'laotisk',
        'lo_LA' => 'laotisk (Laos)',
        'lt' => 'litauisk',
        'lt_LT' => 'litauisk (Litauen)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Kongo)',
        'lv' => 'latvisk',
        'lv_LV' => 'latvisk (Latvia)',
        'mg' => 'gassisk',
        'mg_MG' => 'gassisk (Madagaskar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (New Zealand)',
        'mk' => 'makedonsk',
        'mk_MK' => 'makedonsk (Nord-Makedonia)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (India)',
        'mn' => 'mongolsk',
        'mn_MN' => 'mongolsk (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malayisk',
        'ms_BN' => 'malayisk (Brunei)',
        'ms_ID' => 'malayisk (Indonesia)',
        'ms_MY' => 'malayisk (Malaysia)',
        'ms_SG' => 'malayisk (Singapore)',
        'mt' => 'maltesisk',
        'mt_MT' => 'maltesisk (Malta)',
        'my' => 'burmesisk',
        'my_MM' => 'burmesisk (Myanmar [Burma])',
        'nb' => 'norsk bokmål',
        'nb_NO' => 'norsk bokmål (Norge)',
        'nb_SJ' => 'norsk bokmål (Svalbard og Jan Mayen)',
        'nd' => 'nord-ndebele',
        'nd_ZW' => 'nord-ndebele (Zimbabwe)',
        'ne' => 'nepali',
        'ne_IN' => 'nepali (India)',
        'ne_NP' => 'nepali (Nepal)',
        'nl' => 'nederlandsk',
        'nl_AW' => 'nederlandsk (Aruba)',
        'nl_BE' => 'nederlandsk (Belgia)',
        'nl_BQ' => 'nederlandsk (Karibisk Nederland)',
        'nl_CW' => 'nederlandsk (Curaçao)',
        'nl_NL' => 'nederlandsk (Nederland)',
        'nl_SR' => 'nederlandsk (Surinam)',
        'nl_SX' => 'nederlandsk (Sint Maarten)',
        'nn' => 'norsk nynorsk',
        'nn_NO' => 'norsk nynorsk (Norge)',
        'no' => 'norsk',
        'no_NO' => 'norsk (Norge)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopia)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'odia',
        'or_IN' => 'odia (India)',
        'os' => 'ossetisk',
        'os_GE' => 'ossetisk (Georgia)',
        'os_RU' => 'ossetisk (Russland)',
        'pa' => 'panjabi',
        'pa_Arab' => 'panjabi (arabisk)',
        'pa_Arab_PK' => 'panjabi (arabisk, Pakistan)',
        'pa_Guru' => 'panjabi (gurmukhi)',
        'pa_Guru_IN' => 'panjabi (gurmukhi, India)',
        'pa_IN' => 'panjabi (India)',
        'pa_PK' => 'panjabi (Pakistan)',
        'pl' => 'polsk',
        'pl_PL' => 'polsk (Polen)',
        'ps' => 'pashto',
        'ps_AF' => 'pashto (Afghanistan)',
        'ps_PK' => 'pashto (Pakistan)',
        'pt' => 'portugisisk',
        'pt_AO' => 'portugisisk (Angola)',
        'pt_BR' => 'portugisisk (Brasil)',
        'pt_CH' => 'portugisisk (Sveits)',
        'pt_CV' => 'portugisisk (Kapp Verde)',
        'pt_GQ' => 'portugisisk (Ekvatorial-Guinea)',
        'pt_GW' => 'portugisisk (Guinea-Bissau)',
        'pt_LU' => 'portugisisk (Luxemburg)',
        'pt_MO' => 'portugisisk (Macao SAR Kina)',
        'pt_MZ' => 'portugisisk (Mosambik)',
        'pt_PT' => 'portugisisk (Portugal)',
        'pt_ST' => 'portugisisk (São Tomé og Príncipe)',
        'pt_TL' => 'portugisisk (Øst-Timor)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Peru)',
        'rm' => 'retoromansk',
        'rm_CH' => 'retoromansk (Sveits)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumensk',
        'ro_MD' => 'rumensk (Moldova)',
        'ro_RO' => 'rumensk (Romania)',
        'ru' => 'russisk',
        'ru_BY' => 'russisk (Hviterussland)',
        'ru_KG' => 'russisk (Kirgisistan)',
        'ru_KZ' => 'russisk (Kasakhstan)',
        'ru_MD' => 'russisk (Moldova)',
        'ru_RU' => 'russisk (Russland)',
        'ru_UA' => 'russisk (Ukraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Rwanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (India)',
        'sc' => 'sardisk',
        'sc_IT' => 'sardisk (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabisk)',
        'sd_Arab_PK' => 'sindhi (arabisk, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'nordsamisk',
        'se_FI' => 'nordsamisk (Finland)',
        'se_NO' => 'nordsamisk (Norge)',
        'se_SE' => 'nordsamisk (Sverige)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Den sentralafrikanske republikk)',
        'sh' => 'serbokroatisk',
        'sh_BA' => 'serbokroatisk (Bosnia-Hercegovina)',
        'si' => 'singalesisk',
        'si_LK' => 'singalesisk (Sri Lanka)',
        'sk' => 'slovakisk',
        'sk_SK' => 'slovakisk (Slovakia)',
        'sl' => 'slovensk',
        'sl_SI' => 'slovensk (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somali',
        'so_DJ' => 'somali (Djibouti)',
        'so_ET' => 'somali (Etiopia)',
        'so_KE' => 'somali (Kenya)',
        'so_SO' => 'somali (Somalia)',
        'sq' => 'albansk',
        'sq_AL' => 'albansk (Albania)',
        'sq_MK' => 'albansk (Nord-Makedonia)',
        'sr' => 'serbisk',
        'sr_BA' => 'serbisk (Bosnia-Hercegovina)',
        'sr_Cyrl' => 'serbisk (kyrillisk)',
        'sr_Cyrl_BA' => 'serbisk (kyrillisk, Bosnia-Hercegovina)',
        'sr_Cyrl_ME' => 'serbisk (kyrillisk, Montenegro)',
        'sr_Cyrl_RS' => 'serbisk (kyrillisk, Serbia)',
        'sr_Latn' => 'serbisk (latinsk)',
        'sr_Latn_BA' => 'serbisk (latinsk, Bosnia-Hercegovina)',
        'sr_Latn_ME' => 'serbisk (latinsk, Montenegro)',
        'sr_Latn_RS' => 'serbisk (latinsk, Serbia)',
        'sr_ME' => 'serbisk (Montenegro)',
        'sr_RS' => 'serbisk (Serbia)',
        'su' => 'sundanesisk',
        'su_ID' => 'sundanesisk (Indonesia)',
        'su_Latn' => 'sundanesisk (latinsk)',
        'su_Latn_ID' => 'sundanesisk (latinsk, Indonesia)',
        'sv' => 'svensk',
        'sv_AX' => 'svensk (Åland)',
        'sv_FI' => 'svensk (Finland)',
        'sv_SE' => 'svensk (Sverige)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Kongo)',
        'sw_KE' => 'swahili (Kenya)',
        'sw_TZ' => 'swahili (Tanzania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (India)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malaysia)',
        'ta_SG' => 'tamil (Singapore)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tadsjikisk',
        'tg_TJ' => 'tadsjikisk (Tadsjikistan)',
        'th' => 'thai',
        'th_TH' => 'thai (Thailand)',
        'ti' => 'tigrinja',
        'ti_ER' => 'tigrinja (Eritrea)',
        'ti_ET' => 'tigrinja (Etiopia)',
        'tk' => 'turkmensk',
        'tk_TM' => 'turkmensk (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filippinene)',
        'to' => 'tongansk',
        'to_TO' => 'tongansk (Tonga)',
        'tr' => 'tyrkisk',
        'tr_CY' => 'tyrkisk (Kypros)',
        'tr_TR' => 'tyrkisk (Tyrkia)',
        'tt' => 'tatarisk',
        'tt_RU' => 'tatarisk (Russland)',
        'ug' => 'uigurisk',
        'ug_CN' => 'uigurisk (Kina)',
        'uk' => 'ukrainsk',
        'uk_UA' => 'ukrainsk (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'usbekisk',
        'uz_AF' => 'usbekisk (Afghanistan)',
        'uz_Arab' => 'usbekisk (arabisk)',
        'uz_Arab_AF' => 'usbekisk (arabisk, Afghanistan)',
        'uz_Cyrl' => 'usbekisk (kyrillisk)',
        'uz_Cyrl_UZ' => 'usbekisk (kyrillisk, Usbekistan)',
        'uz_Latn' => 'usbekisk (latinsk)',
        'uz_Latn_UZ' => 'usbekisk (latinsk, Usbekistan)',
        'uz_UZ' => 'usbekisk (Usbekistan)',
        'vi' => 'vietnamesisk',
        'vi_VN' => 'vietnamesisk (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Sør-Afrika)',
        'yi' => 'jiddisk',
        'yi_001' => 'jiddisk (verden)',
        'yo' => 'joruba',
        'yo_BJ' => 'joruba (Benin)',
        'yo_NG' => 'joruba (Nigeria)',
        'zh' => 'kinesisk',
        'zh_CN' => 'kinesisk (Kina)',
        'zh_HK' => 'kinesisk (Hongkong SAR Kina)',
        'zh_Hans' => 'kinesisk (forenklet)',
        'zh_Hans_CN' => 'kinesisk (forenklet, Kina)',
        'zh_Hans_HK' => 'kinesisk (forenklet, Hongkong SAR Kina)',
        'zh_Hans_MO' => 'kinesisk (forenklet, Macao SAR Kina)',
        'zh_Hans_SG' => 'kinesisk (forenklet, Singapore)',
        'zh_Hant' => 'kinesisk (tradisjonell)',
        'zh_Hant_HK' => 'kinesisk (tradisjonell, Hongkong SAR Kina)',
        'zh_Hant_MO' => 'kinesisk (tradisjonell, Macao SAR Kina)',
        'zh_Hant_TW' => 'kinesisk (tradisjonell, Taiwan)',
        'zh_MO' => 'kinesisk (Macao SAR Kina)',
        'zh_SG' => 'kinesisk (Singapore)',
        'zh_TW' => 'kinesisk (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Sør-Afrika)',
    ],
];
