<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਅਬੀਦਜਾਨ)',
        'Africa/Accra' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਅੱਕਰਾ)',
        'Africa/Addis_Ababa' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਐਡਿਸ ਅਬਾਬਾ)',
        'Africa/Algiers' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਅਲਜੀਅਰਸ)',
        'Africa/Asmera' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਅਸਮਾਰਾ)',
        'Africa/Bamako' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਬਮੇਕੋ)',
        'Africa/Bangui' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਬਾਂਗੁਈ)',
        'Africa/Banjul' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਬਾਂਜੁਲ)',
        'Africa/Bissau' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਬਿਸਾਉ)',
        'Africa/Blantyre' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਬਲੰਟਾਇਰ)',
        'Africa/Brazzaville' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਬ੍ਰਾਜ਼ਾਵਿਲੇ)',
        'Africa/Bujumbura' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਬੁਜੁੰਬੁਰਾ)',
        'Africa/Cairo' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਕੈਰੋ)',
        'Africa/Casablanca' => 'ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ (ਕਾਸਾਬਲਾਂਕਾ)',
        'Africa/Ceuta' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਸੀਊਟਾ)',
        'Africa/Conakry' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਕੋਨੇਕਰੀ)',
        'Africa/Dakar' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਡਕਾਰ)',
        'Africa/Dar_es_Salaam' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਦਾਰ ਏਸ ਸਲਾਮ)',
        'Africa/Djibouti' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਜ਼ੀਬੂਤੀ)',
        'Africa/Douala' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਡੌਆਲਾ)',
        'Africa/El_Aaiun' => 'ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ (ਅਲ ਅਯੂਨ)',
        'Africa/Freetown' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਫਰੀਟਾਉਨ)',
        'Africa/Gaborone' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਗਾਬੋਰੋਨ)',
        'Africa/Harare' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਹਰਾਰੇ)',
        'Africa/Johannesburg' => 'ਦੱਖਣੀ ਅਫ਼ਰੀਕਾ ਮਿਆਰੀ ਵੇਲਾ (ਜੋਹਨਸਬਰਗ)',
        'Africa/Juba' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਜੂਬਾ)',
        'Africa/Kampala' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਕੰਪਾਲਾ)',
        'Africa/Khartoum' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਖਾਰਟੌਮ)',
        'Africa/Kigali' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਕਿਗਾਲੀ)',
        'Africa/Kinshasa' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਕਿੰਸ਼ਾਸਾ)',
        'Africa/Lagos' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਲਾਗੋਸ)',
        'Africa/Libreville' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਲਿਬਰਵਿਲੇ)',
        'Africa/Lome' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਲੋਮ)',
        'Africa/Luanda' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਲੁਆਂਡਾ)',
        'Africa/Lubumbashi' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਲੁਬੁਮਬਾਸ਼ੀ)',
        'Africa/Lusaka' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਲੁਸਾਕਾ)',
        'Africa/Malabo' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਮਾਲਾਬੋ)',
        'Africa/Maputo' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਮਾਪੁਟੋ)',
        'Africa/Maseru' => 'ਦੱਖਣੀ ਅਫ਼ਰੀਕਾ ਮਿਆਰੀ ਵੇਲਾ (ਮਸੇਰੂ)',
        'Africa/Mbabane' => 'ਦੱਖਣੀ ਅਫ਼ਰੀਕਾ ਮਿਆਰੀ ਵੇਲਾ (ਏਮਬਾਬਾਨੇ)',
        'Africa/Mogadishu' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਮੋਗਾਦਿਸ਼ੂ)',
        'Africa/Monrovia' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਮੋਨਰੋਵੀਆ)',
        'Africa/Nairobi' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਨੈਰੋਬੀ)',
        'Africa/Ndjamena' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਐਂਜਾਮੇਨਾ)',
        'Africa/Niamey' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਨਿਆਮੇ)',
        'Africa/Nouakchott' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਨੌਆਕਸ਼ਾਟ)',
        'Africa/Ouagadougou' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਉਆਗਾਡੂਗੂ)',
        'Africa/Porto-Novo' => 'ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਪੋਰਟੋ-ਨੋਵੋ)',
        'Africa/Sao_Tome' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਸਾਓ ਟੋਮ)',
        'Africa/Tripoli' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਤ੍ਰਿਪੋਲੀ)',
        'Africa/Tunis' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਟੁਨਿਸ)',
        'Africa/Windhoek' => 'ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਵਿੰਡਹੋਇਕ)',
        'America/Adak' => 'ਹਵਾਈ-ਅਲੇਯੂਸ਼ਿਅਨ ਵੇਲਾ (ਏਡਕ)',
        'America/Anchorage' => 'ਅਲਾਸਕਾ ਵੇਲਾ (ਐਂਕਰੇਜ)',
        'America/Anguilla' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਅੰਗੁਇਲਾ)',
        'America/Antigua' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਐਂਟੀਗੁਆ)',
        'America/Araguaina' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਆਰਗੁਆਇਨਾ)',
        'America/Argentina/La_Rioja' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਲਾ ਰਿਉਜਾ)',
        'America/Argentina/Rio_Gallegos' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਰਿਓ ਗੈਲੇਗੋਸ)',
        'America/Argentina/Salta' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਸਾਲਟਾ)',
        'America/Argentina/San_Juan' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਸੇਨ ਜੁਆਨ)',
        'America/Argentina/San_Luis' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਸੇਨ ਲੂਈਸ)',
        'America/Argentina/Tucuman' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਟੁਕੁਮਨ)',
        'America/Argentina/Ushuaia' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਉਸ਼ਵਾਇਆ)',
        'America/Aruba' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਅਰੂਬਾ)',
        'America/Asuncion' => 'ਪੈਰਾਗਵੇ ਵੇਲਾ (ਐਸੁੰਕੀਅਨ)',
        'America/Bahia' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਬਾਹੀਆ)',
        'America/Bahia_Banderas' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਬਾਹੀਆ ਬਾਂਦੇਰਸ)',
        'America/Barbados' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਬਾਰਬਾਡੋਸ)',
        'America/Belem' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਬੇਲੇਮ)',
        'America/Belize' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਬੇਲੀਜ਼)',
        'America/Blanc-Sablon' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਬਲੈਂਕ-ਸੈਬਲਾਨ)',
        'America/Boa_Vista' => 'ਅਮੇਜ਼ਨ ਵੇਲਾ (ਬੋਆ ਵਿਸਟਾ)',
        'America/Bogota' => 'ਕੋਲੰਬੀਆ ਵੇਲਾ (ਬੋਗੋਟਾ)',
        'America/Boise' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਬੋਇਸ)',
        'America/Buenos_Aires' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਬੂਈਨਸ ਆਇਰਸ)',
        'America/Cambridge_Bay' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਕੈਮਬ੍ਰਿਜ ਬੇ)',
        'America/Campo_Grande' => 'ਅਮੇਜ਼ਨ ਵੇਲਾ (ਕੈਂਪੋ ਗ੍ਰਾਂਡੇ)',
        'America/Cancun' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਕੈਨਕੁਨ)',
        'America/Caracas' => 'ਵੈਨੇਜ਼ੂਏਲਾ ਵੇਲਾ (ਕੈਰਾਕਾਸ)',
        'America/Catamarca' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਕੈਟਾਮਾਰਕਾ)',
        'America/Cayenne' => 'ਫ੍ਰੈਂਚ ਗੁਏਨਾ ਵੇਲਾ (ਕੇਯੇਨੇ)',
        'America/Cayman' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਕੇਮੈਨ)',
        'America/Chicago' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਸ਼ਿਕਾਗੋ)',
        'America/Chihuahua' => 'ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਚਿਹੁਆਹੁਆ)',
        'America/Coral_Harbour' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਐਟੀਕੋਕਨ)',
        'America/Cordoba' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਕੋਰਡੋਬਾ)',
        'America/Costa_Rica' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਕੋਸਟਾ ਰੀਕਾ)',
        'America/Creston' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਕ੍ਰੈਸਟਨ)',
        'America/Cuiaba' => 'ਅਮੇਜ਼ਨ ਵੇਲਾ (ਕਯੁਏਬਾ)',
        'America/Curacao' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਕੁਰਾਕਾਓ)',
        'America/Danmarkshavn' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਡੈਨਮਾਰਕਸ਼ੌਨ)',
        'America/Dawson' => 'ਯੂਕੋਨ ਸਮਾਂ (ਡੌਅਸਨ)',
        'America/Dawson_Creek' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਡੌਅਸਨ ਕ੍ਰੀਕ)',
        'America/Denver' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਡੇਨਵਰ)',
        'America/Detroit' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਡਿਟਰੋਇਟ)',
        'America/Dominica' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਡੋਮੀਨਿਕਾ)',
        'America/Edmonton' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਐਡਮੋਂਟਨ)',
        'America/Eirunepe' => 'ਬ੍ਰਾਜ਼ੀਲ ਵੇਲਾ (ਯੁਰੂਨੀਪੇ)',
        'America/El_Salvador' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਅਲ ਸਲਵਾਡੋਰ)',
        'America/Fort_Nelson' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਫੋਰਟ ਨੈਲਸਨ)',
        'America/Fortaleza' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਫੋਰਟਾਲੇਜ਼ਾ)',
        'America/Glace_Bay' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਗਲੇਸ ਬੇ)',
        'America/Godthab' => 'ਪੱਛਮੀ ਗ੍ਰੀਨਲੈਂਡ ਵੇਲਾ (ਨੂਕ)',
        'America/Goose_Bay' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਗੂਜ਼ ਬੇ)',
        'America/Grand_Turk' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਗਰਾਂਡ ਤੁਰਕ)',
        'America/Grenada' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਗ੍ਰੇਨਾਡਾ)',
        'America/Guadeloupe' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਗੁਆਡੇਲੋਪ)',
        'America/Guatemala' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਗੁਆਟੇਮਾਲਾ)',
        'America/Guayaquil' => 'ਇਕਵੇਡੋਰ ਵੇਲਾ (ਗੁਆਇਕਵਿਲ)',
        'America/Guyana' => 'ਗੁਯਾਨਾ ਵੇਲਾ (ਗੁਆਨਾ)',
        'America/Halifax' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਹੈਲੀਫੈਕਸ)',
        'America/Havana' => 'ਕਿਊਬਾ ਵੇਲਾ (ਹਵਾਨਾ)',
        'America/Hermosillo' => 'ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਹਰਮੋਸਿੱਲੋ)',
        'America/Indiana/Knox' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਨੋਕਸ, ਇੰਡੀਆਨਾ)',
        'America/Indiana/Marengo' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਮਾਰੇਂਗੋ, ਇੰਡੀਆਨਾ)',
        'America/Indiana/Petersburg' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਪੀਟਰਸਬਰਗ, ਇੰਡੀਆਨਾ)',
        'America/Indiana/Tell_City' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਟੈਲ ਸਿਟੀ, ਇੰਡੀਆਨਾ)',
        'America/Indiana/Vevay' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਵੇਵੇ, ਇੰਡੀਆਨਾ)',
        'America/Indiana/Vincennes' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਵਿੰਸੇਨੇਸ, ਇੰਡੀਆਨਾ)',
        'America/Indiana/Winamac' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਵਿਨਮੈਕ, ਇੰਡੀਆਨਾ)',
        'America/Indianapolis' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਇੰਡੀਆਨਾਪੋਲਿਸ)',
        'America/Inuvik' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਇਨੁਵਿਕ)',
        'America/Iqaluit' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਇਕਾਲੁਈਟ)',
        'America/Jamaica' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਜਮਾਇਕਾ)',
        'America/Jujuy' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਜੂਜੁਏ)',
        'America/Juneau' => 'ਅਲਾਸਕਾ ਵੇਲਾ (ਜਯੂਨੋ)',
        'America/Kentucky/Monticello' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਮੋਂਟੀਸੈਲੋ, ਕੈਂਟਕੀ)',
        'America/Kralendijk' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਕ੍ਰਾਲੇਂਦਿਜਕ)',
        'America/La_Paz' => 'ਬੋਲੀਵੀਆ ਵੇਲਾ (ਲਾ ਪਾਜ਼)',
        'America/Lima' => 'ਪੇਰੂ ਵੇਲਾ (ਲੀਮਾ)',
        'America/Los_Angeles' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਲਾਸ ਐਂਜਲਸ)',
        'America/Louisville' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਲੁਈਸਵਿਲੇ)',
        'America/Lower_Princes' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਲੋਅਰ ਪ੍ਰਿੰਸ’ਸ ਕਵਾਰਟਰ)',
        'America/Maceio' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਮੈਸੀਓ)',
        'America/Managua' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮਨਾਗੁਆ)',
        'America/Manaus' => 'ਅਮੇਜ਼ਨ ਵੇਲਾ (ਮਨੌਸ)',
        'America/Marigot' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਮੈਰੀਗੋਟ)',
        'America/Martinique' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਮਾਰਟੀਨਿਕ)',
        'America/Matamoros' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮਾਟਾਮੋਰਸ)',
        'America/Mazatlan' => 'ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਮਜ਼ੇਤਲਾਨ)',
        'America/Mendoza' => 'ਅਰਜਨਟੀਨਾ ਵੇਲਾ (ਮੈਂਡੋਜ਼ਾ)',
        'America/Menominee' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮੈਨੋਮਿਨੀ)',
        'America/Merida' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮੇਰਿਡਾ)',
        'America/Metlakatla' => 'ਅਲਾਸਕਾ ਵੇਲਾ (ਮੇਟਲਾਕਾਟਲਾ)',
        'America/Mexico_City' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮੈਕਸੀਕੋ ਸਿਟੀ)',
        'America/Miquelon' => 'ਸੈਂਟ ਪੀਅਰੇ ਅਤੇ ਮਿਕੇਲਨ ਵੇਲਾ',
        'America/Moncton' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਮੋਂਕਟਨ)',
        'America/Monterrey' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਮੋਨਟੇਰੀ)',
        'America/Montevideo' => 'ਉਰੂਗਵੇ ਵੇਲਾ (ਮੋਂਟੇਵੀਡੀਓ)',
        'America/Montreal' => 'ਕੈਨੇਡਾ ਵੇਲਾ (Montreal)',
        'America/Montserrat' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਮੋਂਟਸੇਰਾਤ)',
        'America/Nassau' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਨਾਸਾਓ)',
        'America/New_York' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਨਿਊ ਯਾਰਕ)',
        'America/Nipigon' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਨਿਪਿਗੌਨ)',
        'America/Nome' => 'ਅਲਾਸਕਾ ਵੇਲਾ (ਨੋਮ)',
        'America/Noronha' => 'ਫਰਨਾਂਡੋ ਡੇ ਨੋਰੋਨਹਾ ਵੇਲਾ (ਨੌਰੋਨਹਾ)',
        'America/North_Dakota/Beulah' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਬਿਉਲਾ, ਉੱਤਰੀ ਡਕੋਟਾ)',
        'America/North_Dakota/Center' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਸੇਂਟਰ, ਉੱਤਰੀ ਡਕੋਟਾ)',
        'America/North_Dakota/New_Salem' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਨਿਊ ਸਲੇਮ, ਉੱਤਰੀ ਡਕੋਟਾ)',
        'America/Ojinaga' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਓਜੀਨਾਗਾ)',
        'America/Panama' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਪਨਾਮਾ)',
        'America/Pangnirtung' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਪੈਂਗਨਿਰਟੰਗ)',
        'America/Paramaribo' => 'ਸੂਰੀਨਾਮ ਵੇਲਾ (ਪੈਰਾਮਰੀਬੋ)',
        'America/Phoenix' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਫਿਨਿਕਸ)',
        'America/Port-au-Prince' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਪੋਰਟ-ਔ-ਪ੍ਰਿੰਸ)',
        'America/Port_of_Spain' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਪੋਰਟ ਔਫ ਸਪੇਨ)',
        'America/Porto_Velho' => 'ਅਮੇਜ਼ਨ ਵੇਲਾ (ਪੋਰਟੋ ਵੇਲ੍ਹੋ)',
        'America/Puerto_Rico' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਪਿਊਰਟੋ ਰੀਕੋ)',
        'America/Punta_Arenas' => 'ਚਿਲੀ ਵੇਲਾ (ਪੰਟਾ ਅਰੇਨਸ)',
        'America/Rainy_River' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਰੇਨੀ ਰਿਵਰ)',
        'America/Rankin_Inlet' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਰੈਂਕਿਨ ਇਨਲੈਟ)',
        'America/Recife' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਰੇਸੀਫੇ)',
        'America/Regina' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਰੈਜੀਨਾ)',
        'America/Resolute' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਰੈਜ਼ੋਲਿਊਟ)',
        'America/Rio_Branco' => 'ਬ੍ਰਾਜ਼ੀਲ ਵੇਲਾ (ਰੀਓ ਬ੍ਰਾਂਕੋ)',
        'America/Santa_Isabel' => 'ਉੱਤਰ ਪੱਛਮੀ ਮੈਕਸੀਕੋ ਵੇਲਾ (ਸੈਂਟਾ ਇਸਾਬੇਲ)',
        'America/Santarem' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਸੇਂਟਾਰਮ)',
        'America/Santiago' => 'ਚਿਲੀ ਵੇਲਾ (ਸੇਂਟੀਆਗੋ)',
        'America/Santo_Domingo' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਸੇਂਟੋ ਡੋਮਿੰਗੋ)',
        'America/Sao_Paulo' => 'ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ (ਸਾਓ ਪੌਲੋ)',
        'America/Scoresbysund' => 'ਪੂਰਬੀ ਗ੍ਰੀਨਲੈਂਡ ਵੇਲਾ (ਇੱਟੋਕੋਰਟੂਰਮੀਟ)',
        'America/Sitka' => 'ਅਲਾਸਕਾ ਵੇਲਾ (ਸਿਟਕਾ)',
        'America/St_Barthelemy' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਸੇਂਟ ਬਾਰਥੇਲੇਮੀ)',
        'America/St_Johns' => 'ਨਿਊਫਾਉਂਡਲੈਂਡ ਵੇਲਾ (ਸੇਂਟ ਜੌਹਨਸ)',
        'America/St_Kitts' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਸੇਂਟ ਕਿਟਸ)',
        'America/St_Lucia' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਸੇਂਟ ਲੁਸੀਆ)',
        'America/St_Thomas' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਸੇਂਟ ਥੋਮਸ)',
        'America/St_Vincent' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਸੇਂਟ ਵਿਨਸੇਂਟ)',
        'America/Swift_Current' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਸਵਿਫਟ ਕਰੰਟ)',
        'America/Tegucigalpa' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਟੇਗੁਸੀਗਲਪਾ)',
        'America/Thule' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਥੁਲੇ)',
        'America/Thunder_Bay' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਥੰਡਰ ਬੇ)',
        'America/Tijuana' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਟਿਜੂਆਨਾ)',
        'America/Toronto' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ (ਟੋਰਾਂਟੋ)',
        'America/Tortola' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਟੋਰਟੋਲਾ)',
        'America/Vancouver' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਵੇਲਾ (ਵੈਨਕੂਵਰ)',
        'America/Whitehorse' => 'ਯੂਕੋਨ ਸਮਾਂ (ਵਾਈਟਹੌਰਸ)',
        'America/Winnipeg' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ (ਵਿਨੀਪੈਗ)',
        'America/Yakutat' => 'ਅਲਾਸਕਾ ਵੇਲਾ (ਯਕੁਤਤ)',
        'America/Yellowknife' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ (ਯੈਲੋਨਾਈਫ)',
        'Antarctica/Casey' => 'ਕੇਸੀ ਸਮਾਂ (ਕਾਸੇ)',
        'Antarctica/Davis' => 'ਡੇਵਿਸ ਵੇਲਾ',
        'Antarctica/DumontDUrville' => 'ਡਿਉਮੋਂਟ ਡਿਉਰਵਿਲੇ ਵੇਲਾ',
        'Antarctica/Macquarie' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਮੈਕਕਵੈਰੀ)',
        'Antarctica/Mawson' => 'ਮੌਸਨ ਵੇਲਾ',
        'Antarctica/McMurdo' => 'ਨਿਊਜ਼ੀਲੈਂਡ ਵੇਲਾ (ਮੈਕਮੁਰਡੋ)',
        'Antarctica/Palmer' => 'ਚਿਲੀ ਵੇਲਾ (ਪਾਮਰ)',
        'Antarctica/Rothera' => 'ਰੋਥੇਰਾ ਵੇਲਾ',
        'Antarctica/Syowa' => 'ਸਿਓਵਾ ਵੇਲਾ (ਸਵੋਯਾ)',
        'Antarctica/Troll' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਟਰੋਲ)',
        'Antarctica/Vostok' => 'ਵੋਸਟੋਕ ਵੇਲਾ',
        'Arctic/Longyearbyen' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਲੋਂਗਈਅਰਬਾਇਨ)',
        'Asia/Aden' => 'ਅਰਬੀ ਵੇਲਾ (ਅਡੇਨ)',
        'Asia/Almaty' => 'ਪੂਰਬੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਅਲਮੇਟੀ)',
        'Asia/Amman' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਅਮਾਨ)',
        'Asia/Anadyr' => 'ਰੂਸ ਵੇਲਾ (ਐਨਾਡਾਇਰ)',
        'Asia/Aqtau' => 'ਪੱਛਮੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਅਕਤੌ)',
        'Asia/Aqtobe' => 'ਪੱਛਮੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਅਕਤੋਬੇ)',
        'Asia/Ashgabat' => 'ਤੁਰਕਮੇਨਿਸਤਾਨ ਵੇਲਾ (ਅਸ਼ਗਾਬਾਟ)',
        'Asia/Atyrau' => 'ਪੱਛਮੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਏਤੇਰਾਓ)',
        'Asia/Baghdad' => 'ਅਰਬੀ ਵੇਲਾ (ਬਗਦਾਦ)',
        'Asia/Bahrain' => 'ਅਰਬੀ ਵੇਲਾ (ਬਹਿਰੀਨ)',
        'Asia/Baku' => 'ਅਜ਼ਰਬਾਈਜਾਨ ਵੇਲਾ (ਬਾਕੂ)',
        'Asia/Bangkok' => 'ਇੰਡੋਚਾਈਨਾ ਵੇਲਾ (ਬੈਂਕਾਕ)',
        'Asia/Barnaul' => 'ਰੂਸ ਵੇਲਾ (ਬਰਨੌਲ)',
        'Asia/Beirut' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਬੈਰੂਤ)',
        'Asia/Bishkek' => 'ਕਿਰਗਿਸਤਾਨ ਵੇਲਾ (ਬਿਸ਼ਕੇਕ)',
        'Asia/Brunei' => 'ਬਰੂਨੇਈ ਦਾਰੂਸਲਾਮ ਵੇਲਾ',
        'Asia/Calcutta' => 'ਭਾਰਤੀ ਮਿਆਰੀ ਵੇਲਾ (ਕੋਲਕਾਤਾ)',
        'Asia/Chita' => 'ਯਕੁਤਸਕ ਵੇਲਾ (ਚਿਤਾ)',
        'Asia/Choibalsan' => 'ਉਲਨ ਬਟੋਰ ਵੇਲਾ (ਚੋਇਲਬਾਲਸਨ)',
        'Asia/Colombo' => 'ਭਾਰਤੀ ਮਿਆਰੀ ਵੇਲਾ (ਕੋਲੰਬੋ)',
        'Asia/Damascus' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਡੈਮਸਕਸ)',
        'Asia/Dhaka' => 'ਬੰਗਲਾਦੇਸ਼ ਵੇਲਾ (ਢਾਕਾ)',
        'Asia/Dili' => 'ਪੂਰਬੀ ਤਿਮੂਰ ਵੇਲਾ (ਡਿਲੀ)',
        'Asia/Dubai' => 'ਖਾੜੀ ਮਿਆਰੀ ਵੇਲਾ (ਦੁਬਈ)',
        'Asia/Dushanbe' => 'ਤਾਜਿਕਿਸਤਾਨ ਵੇਲਾ (ਦੁਸ਼ਾਂਬੇ)',
        'Asia/Famagusta' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਫਾਮਾਗੁਸਟਾ)',
        'Asia/Gaza' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਗਾਜ਼ਾ)',
        'Asia/Hebron' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਹੇਬਰਾਨ)',
        'Asia/Hong_Kong' => 'ਹਾਂਗ ਕਾਂਗ ਵੇਲਾ',
        'Asia/Hovd' => 'ਹੋਵਡ ਵੇਲਾ',
        'Asia/Irkutsk' => 'ਇਰਕੁਤਸਕ ਵੇਲਾ',
        'Asia/Jakarta' => 'ਪੱਛਮੀ ਇੰਡੋਨੇਸ਼ੀਆ ਵੇਲਾ (ਜਕਾਰਤਾ)',
        'Asia/Jayapura' => 'ਪੂਰਬੀ ਇੰਡੋਨੇਸ਼ੀਆ ਵੇਲਾ (ਜਯਾਪੁਰਾ)',
        'Asia/Jerusalem' => 'ਇਜ਼ਰਾਈਲ ਵੇਲਾ (ਜੇਰੂਸਲਮ)',
        'Asia/Kabul' => 'ਅਫ਼ਗਾਨਿਸਤਾਨ ਵੇਲਾ (ਕਾਬੁਲ)',
        'Asia/Kamchatka' => 'ਰੂਸ ਵੇਲਾ (ਕਮਚਟਕਾ)',
        'Asia/Karachi' => 'ਪਾਕਿਸਤਾਨ ਵੇਲਾ (ਕਰਾਚੀ)',
        'Asia/Katmandu' => 'ਨੇਪਾਲ ਵੇਲਾ (ਕਾਠਮਾਂਡੂ)',
        'Asia/Khandyga' => 'ਯਕੁਤਸਕ ਵੇਲਾ (ਖਾਨਡਿਗਾ)',
        'Asia/Krasnoyarsk' => 'ਕ੍ਰਾਸਨੋਯਾਰਸਕ ਵੇਲਾ (ਕਰੈਸਨੇਜਰਸ)',
        'Asia/Kuala_Lumpur' => 'ਮਲੇਸ਼ੀਆ ਵੇਲਾ (ਕੁਆਲਾਲੰਪੁਰ)',
        'Asia/Kuching' => 'ਮਲੇਸ਼ੀਆ ਵੇਲਾ (ਕੁਚਿੰਗ)',
        'Asia/Kuwait' => 'ਅਰਬੀ ਵੇਲਾ (ਕੁਵੈਤ)',
        'Asia/Macau' => 'ਚੀਨ ਵੇਲਾ (ਮਕਾਉ)',
        'Asia/Magadan' => 'ਮੈਗੇਡਨ ਵੇਲਾ',
        'Asia/Makassar' => 'ਮੱਧ ਇੰਡੋਨੇਸ਼ੀਆਈ ਵੇਲਾ (ਮਕਸਾਰ)',
        'Asia/Manila' => 'ਫਿਲਿਪੀਨੀ ਵੇਲਾ (ਮਨੀਲਾ)',
        'Asia/Muscat' => 'ਖਾੜੀ ਮਿਆਰੀ ਵੇਲਾ (ਮਸਕਟ)',
        'Asia/Nicosia' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਨਿਕੋਸੀਆ)',
        'Asia/Novokuznetsk' => 'ਕ੍ਰਾਸਨੋਯਾਰਸਕ ਵੇਲਾ (ਨੋਵੋਕੁਜ਼ਨੇਟਸਕ)',
        'Asia/Novosibirsk' => 'ਨੌਵੋਸਿਬੀਰਸਕ ਵੇਲਾ (ਨੋਵੋਸਿਬੀਰਸਕ)',
        'Asia/Omsk' => 'ਓਮਸਕ ਵੇਲਾ',
        'Asia/Oral' => 'ਪੱਛਮੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਓਰਲ)',
        'Asia/Phnom_Penh' => 'ਇੰਡੋਚਾਈਨਾ ਵੇਲਾ (ਫਨੋਮ ਪੇਨਹ)',
        'Asia/Pontianak' => 'ਪੱਛਮੀ ਇੰਡੋਨੇਸ਼ੀਆ ਵੇਲਾ (ਪੌਂਟੀਆਨਾਕ)',
        'Asia/Pyongyang' => 'ਕੋਰੀਆਈ ਵੇਲਾ (ਪਯੋਂਗਯਾਂਗ)',
        'Asia/Qatar' => 'ਅਰਬੀ ਵੇਲਾ (ਕਤਰ)',
        'Asia/Qostanay' => 'ਪੂਰਬੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਕੋਸਤਾਨਾਏ)',
        'Asia/Qyzylorda' => 'ਪੱਛਮੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ (ਕਿਜ਼ੀਲੋਰਡਾ)',
        'Asia/Rangoon' => 'ਮਿਆਂਮਾਰ ਵੇਲਾ (ਰੰਗੂਨ)',
        'Asia/Riyadh' => 'ਅਰਬੀ ਵੇਲਾ (ਰਿਆਧ)',
        'Asia/Saigon' => 'ਇੰਡੋਚਾਈਨਾ ਵੇਲਾ (ਹੋ ਚੀ ਮਿਨ੍ਹ ਸਿਟੀ)',
        'Asia/Sakhalin' => 'ਸਖਲੀਨ ਵੇਲਾ',
        'Asia/Samarkand' => 'ਉਜ਼ਬੇਕਿਸਤਾਨ ਵੇਲਾ (ਸਮਰਕੰਦ)',
        'Asia/Seoul' => 'ਕੋਰੀਆਈ ਵੇਲਾ (ਸਿਉਲ)',
        'Asia/Shanghai' => 'ਚੀਨ ਵੇਲਾ (ਸ਼ੰਘਾਈ)',
        'Asia/Singapore' => 'ਸਿੰਗਾਪੁਰ ਮਿਆਰੀ ਵੇਲਾ',
        'Asia/Srednekolymsk' => 'ਮੈਗੇਡਨ ਵੇਲਾ (ਸਰਿਡਨੀਕੋਲਿਸਕ)',
        'Asia/Taipei' => 'ਤੈਪਈ ਵੇਲਾ',
        'Asia/Tashkent' => 'ਉਜ਼ਬੇਕਿਸਤਾਨ ਵੇਲਾ (ਤਾਸ਼ਕੰਦ)',
        'Asia/Tbilisi' => 'ਜਾਰਜੀਆ ਵੇਲਾ (ਟਬਿਲਿਸੀ)',
        'Asia/Tehran' => 'ਈਰਾਨ ਵੇਲਾ (ਤੇਹਰਾਨ)',
        'Asia/Thimphu' => 'ਭੂਟਾਨ ਵੇਲਾ (ਥਿੰਫੂ)',
        'Asia/Tokyo' => 'ਜਪਾਨ ਵੇਲਾ (ਟੋਕੀਓ)',
        'Asia/Tomsk' => 'ਰੂਸ ਵੇਲਾ (ਟੋਮਸਕ)',
        'Asia/Ulaanbaatar' => 'ਉਲਨ ਬਟੋਰ ਵੇਲਾ (ਉਲਾਨਬਾਤਰ)',
        'Asia/Urumqi' => 'ਚੀਨ ਵੇਲਾ (ਊਰੂਮਕੀ)',
        'Asia/Ust-Nera' => 'ਵਲਾਦੀਵੋਸਤਕ ਵੇਲਾ (ਉਸਤ-ਨੇਰਾ)',
        'Asia/Vientiane' => 'ਇੰਡੋਚਾਈਨਾ ਵੇਲਾ (ਵਾਏਨਟਿਆਨੇ)',
        'Asia/Vladivostok' => 'ਵਲਾਦੀਵੋਸਤਕ ਵੇਲਾ',
        'Asia/Yakutsk' => 'ਯਕੁਤਸਕ ਵੇਲਾ',
        'Asia/Yekaterinburg' => 'ਯਕੇਤਰਿਨਬਰਗ ਵੇਲਾ',
        'Asia/Yerevan' => 'ਅਰਮੀਨੀਆ ਵੇਲਾ (ਯੇਰੇਵਨ)',
        'Atlantic/Azores' => 'ਅਜੋਰੇਸ ਵੇਲਾ',
        'Atlantic/Bermuda' => 'ਅਟਲਾਂਟਿਕ ਵੇਲਾ (ਬਰਮੂਡਾ)',
        'Atlantic/Canary' => 'ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ (ਕੇਨੇਰੀ)',
        'Atlantic/Cape_Verde' => 'ਕੇਪ ਵਰਡ ਵੇਲਾ',
        'Atlantic/Faeroe' => 'ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ (ਫੈਰੋ)',
        'Atlantic/Madeira' => 'ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ (ਮਡੀਅਰਾ)',
        'Atlantic/Reykjavik' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਰੇਕਜਾਵਿਕ)',
        'Atlantic/South_Georgia' => 'ਦੱਖਣੀ ਜਾਰਜੀਆ ਵੇਲਾ',
        'Atlantic/St_Helena' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਸੇਂਟ ਹੇਲੇਨਾ)',
        'Atlantic/Stanley' => 'ਫ਼ਾਕਲੈਂਡ ਆਈਲੈਂਡਸ ਵੇਲਾ (ਸਟੇਨਲੀ)',
        'Australia/Adelaide' => 'ਕੇਂਦਰੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਐਡੀਲੇਡ)',
        'Australia/Brisbane' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਬ੍ਰਿਸਬੇਨ)',
        'Australia/Broken_Hill' => 'ਕੇਂਦਰੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਬ੍ਰੋਕਨ ਹਿਲ)',
        'Australia/Currie' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਕਰੀ)',
        'Australia/Darwin' => 'ਕੇਂਦਰੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਡਾਰਵਿਨ)',
        'Australia/Eucla' => 'ਆਸਟ੍ਰੇਲੀਆਈ ਕੇਂਦਰੀ ਪੱਛਮੀ ਵੇਲਾ (ਯੂਕਲਾ)',
        'Australia/Hobart' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਹੋਬਾਰਟ)',
        'Australia/Lindeman' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਲਿੰਡੇਮਨ)',
        'Australia/Lord_Howe' => 'ਲੌਰਡ ਹੋਵੇ ਵੇਲਾ',
        'Australia/Melbourne' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਮੈਲਬੋਰਨ)',
        'Australia/Perth' => 'ਪੱਛਮੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਪਰਥ)',
        'Australia/Sydney' => 'ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ (ਸਿਡਨੀ)',
        'CST6CDT' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ',
        'EST5EDT' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ',
        'Etc/GMT' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ',
        'Etc/UTC' => 'ਕੋਔਰਡੀਨੇਟੇਡ ਵਿਆਪਕ ਵੇਲਾ',
        'Europe/Amsterdam' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਐਮਸਟਰਡਮ)',
        'Europe/Andorra' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਅੰਡੋਰਾ)',
        'Europe/Astrakhan' => 'ਮਾਸਕੋ ਵੇਲਾ (ਆਸਟ੍ਰਾਖਾਨ)',
        'Europe/Athens' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਏਥਨਸ)',
        'Europe/Belgrade' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਬੈਲਗ੍ਰੇਡ)',
        'Europe/Berlin' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਬਰਲਿਨ)',
        'Europe/Bratislava' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਬ੍ਰਾਟਿਸਲਾਵਾ)',
        'Europe/Brussels' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਬਰੱਸਲਜ)',
        'Europe/Bucharest' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਬੂਕਾਰੈਸਟ)',
        'Europe/Budapest' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਬੁਡਾਪੈਸਟ)',
        'Europe/Busingen' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਬੁਸਿੰਜੇਨ)',
        'Europe/Chisinau' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਚਿਸਿਨੌ)',
        'Europe/Copenhagen' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਕੋਪਨਹੇਗਨ)',
        'Europe/Dublin' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਡਬਲਿਨ)',
        'Europe/Gibraltar' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਜਿਬਰਾਲਟਰ)',
        'Europe/Guernsey' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਗਰਨਜੀ)',
        'Europe/Helsinki' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਹੇਲਸਿੰਕੀ)',
        'Europe/Isle_of_Man' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਆਇਲ ਆਫ ਮੈਨ)',
        'Europe/Istanbul' => 'ਤੁਰਕੀ ਵੇਲਾ (ਇਸਤਾਂਬੁਲ)',
        'Europe/Jersey' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਜਰਸੀ)',
        'Europe/Kaliningrad' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਕਲੀਨਿੰਗ੍ਰੇਡ)',
        'Europe/Kiev' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਕੀਵ)',
        'Europe/Kirov' => 'ਰੂਸ ਵੇਲਾ (ਕੀਰੋਵ)',
        'Europe/Lisbon' => 'ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ (ਲਿਸਬਨ)',
        'Europe/Ljubljana' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਲਜੁਬਲਜਾਨਾ)',
        'Europe/London' => 'ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ (ਲੰਡਨ)',
        'Europe/Luxembourg' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਲਕਜ਼ਮਬਰਗ)',
        'Europe/Madrid' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਮੈਡ੍ਰਿਡ)',
        'Europe/Malta' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਮਾਲਟਾ)',
        'Europe/Mariehamn' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਮਾਰੀਏਹਾਮੇਨ)',
        'Europe/Minsk' => 'ਮਾਸਕੋ ਵੇਲਾ (ਮਿੰਸਕ)',
        'Europe/Monaco' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਮੋਨਾਕੋ)',
        'Europe/Moscow' => 'ਮਾਸਕੋ ਵੇਲਾ',
        'Europe/Oslo' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਓਸਲੋ)',
        'Europe/Paris' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਪੈਰਿਸ)',
        'Europe/Podgorica' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਪੋਡਗੋਰੀਕਾ)',
        'Europe/Prague' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਪ੍ਰਾਗ)',
        'Europe/Riga' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਰਿਗਾ)',
        'Europe/Rome' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਰੋਮ)',
        'Europe/Samara' => 'ਰੂਸ ਵੇਲਾ (ਸਮਾਰਾ)',
        'Europe/San_Marino' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਸੈਨ ਮਰੀਨੋ)',
        'Europe/Sarajevo' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਸਾਰਾਜੇਵੋ)',
        'Europe/Saratov' => 'ਮਾਸਕੋ ਵੇਲਾ (ਸੈਰਾਟੋਵ)',
        'Europe/Simferopol' => 'ਮਾਸਕੋ ਵੇਲਾ (ਸਿਮਫਰੋਪੋਲ)',
        'Europe/Skopje' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਸਕੋਪਜੇ)',
        'Europe/Sofia' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਸੋਫੀਆ)',
        'Europe/Stockholm' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਸਟਾਕਹੋਮ)',
        'Europe/Tallinn' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਟੱਲਿਨ)',
        'Europe/Tirane' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਤਿਰਾਨੇ)',
        'Europe/Ulyanovsk' => 'ਮਾਸਕੋ ਵੇਲਾ (ਯੁਲਿਆਨੋਸਕ)',
        'Europe/Uzhgorod' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਉਜ਼ਗੋਰੋਡ)',
        'Europe/Vaduz' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਵਾਡੁਜ਼)',
        'Europe/Vatican' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਵੈਟਿਕਨ)',
        'Europe/Vienna' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਵਿਆਨਾ)',
        'Europe/Vilnius' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਵਿਲਨਿਅਸ)',
        'Europe/Volgograd' => 'ਵੋਲਗੋਗ੍ਰੇਡ ਵੇਲਾ',
        'Europe/Warsaw' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਵਾਰਸਾਅ)',
        'Europe/Zagreb' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਜ਼ਗਰੇਬ)',
        'Europe/Zaporozhye' => 'ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ (ਜਪੋਰੋਜ਼ਾਏ)',
        'Europe/Zurich' => 'ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ (ਜਿਊਰਿਖ)',
        'Indian/Antananarivo' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਅੰਟਾਨਨੇਰਿਵੋ)',
        'Indian/Chagos' => 'ਹਿੰਦ ਮਹਾਂਸਾਗਰ ਵੇਲਾ (ਚਾਗੋਸ)',
        'Indian/Christmas' => 'ਕ੍ਰਿਸਮਸ ਆਈਲੈਂਡ ਵੇਲਾ',
        'Indian/Cocos' => 'ਕੋਕਸ ਆਈਲੈਂਡ ਵੇਲਾ (ਕੋਕੋਜ਼)',
        'Indian/Comoro' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਕੋਮੋਰੋ)',
        'Indian/Kerguelen' => 'ਫ੍ਰੈਂਚ ਦੱਖਣੀ ਅਤੇ ਐਂਟਾਰਟਿਕ ਵੇਲਾ (ਕਰਗਯੂਲੇਨ)',
        'Indian/Mahe' => 'ਸੇਸ਼ਲਸ ਵੇਲਾ (ਮਾਹੇ)',
        'Indian/Maldives' => 'ਮਾਲਦੀਵ ਵੇਲਾ',
        'Indian/Mauritius' => 'ਮੌਰਿਸ਼ਸ ਵੇਲਾ',
        'Indian/Mayotte' => 'ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ (ਮਾਯੋਟੀ)',
        'Indian/Reunion' => 'ਰਿਯੂਨੀਅਨ ਵੇਲਾ',
        'MST7MDT' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ',
        'PST8PDT' => 'ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਵੇਲਾ',
        'Pacific/Apia' => 'ਐਪੀਆ ਵੇਲਾ',
        'Pacific/Auckland' => 'ਨਿਊਜ਼ੀਲੈਂਡ ਵੇਲਾ (ਆਕਲੈਂਡ)',
        'Pacific/Bougainville' => 'ਪਾਪੂਆ ਨਿਊ ਗਿਨੀ ਵੇਲਾ (ਬੋਗਨਵਿਲੇ)',
        'Pacific/Chatham' => 'ਚੈਥਮ ਵੇਲਾ',
        'Pacific/Easter' => 'ਈਸਟਰ ਆਈਲੈਂਡ ਵੇਲਾ',
        'Pacific/Efate' => 'ਵਾਨੂਆਟੂ ਵੇਲਾ (ਇਫੇਟ)',
        'Pacific/Enderbury' => 'ਫਿਨਿਕਸ ਆਈਲੈਂਡ ਵੇਲਾ (ਏਂਡਰਬਰੀ)',
        'Pacific/Fakaofo' => 'ਟੋਕੇਲਾਉ ਵੇਲਾ (ਫਕਾਉਫੋ)',
        'Pacific/Fiji' => 'ਫ਼ਿਜ਼ੀ ਵੇਲਾ (ਫ਼ਿਜੀ)',
        'Pacific/Funafuti' => 'ਟੁਵਾਲੂ ਵੇਲਾ (ਫੁਨਾਫੁਟੀ)',
        'Pacific/Galapagos' => 'ਗਲਾਪਾਗੋਸ ਵੇਲਾ (ਗਲਪੇਗੋਸ)',
        'Pacific/Gambier' => 'ਗੈਂਬੀਅਰ ਵੇਲਾ',
        'Pacific/Guadalcanal' => 'ਸੋਲੋਮਨ ਆਈਲੈਂਡਸ ਵੇਲਾ (ਗੁਆਡਾਕੇਨਲ)',
        'Pacific/Guam' => 'ਚਾਮੋਰੋ ਮਿਆਰੀ ਵੇਲਾ (ਗੁਆਮ)',
        'Pacific/Honolulu' => 'ਹਵਾਈ-ਅਲੇਯੂਸ਼ਿਅਨ ਵੇਲਾ (ਹੋਨੋਲੁਲੂ)',
        'Pacific/Johnston' => 'ਹਵਾਈ-ਅਲੇਯੂਸ਼ਿਅਨ ਵੇਲਾ (ਜੋਨਸਟਨ)',
        'Pacific/Kiritimati' => 'ਲਾਈਨ ਆਈਲੈਂਡ ਵੇਲਾ (ਕਿਰਿਤਿਮਤੀ)',
        'Pacific/Kosrae' => 'ਕੋਸਰੇ ਵੇਲਾ (ਕੋਸ੍ਰਾਏ)',
        'Pacific/Kwajalein' => 'ਮਾਰਸ਼ਲ ਆਈਲੈਂਡ ਵੇਲਾ (ਕਵਾਜਾਲੀਨ)',
        'Pacific/Majuro' => 'ਮਾਰਸ਼ਲ ਆਈਲੈਂਡ ਵੇਲਾ (ਮੇਜੁਰੋ)',
        'Pacific/Marquesas' => 'ਮਾਰਕਿਸਾਸ ਵੇਲਾ',
        'Pacific/Midway' => 'ਸਾਮੋਆ ਵੇਲਾ (ਮਿਡਵੇ)',
        'Pacific/Nauru' => 'ਨਾਉਰੂ ਵੇਲਾ',
        'Pacific/Niue' => 'ਨੀਊ ਵੇਲਾ (ਨਿਯੂ)',
        'Pacific/Norfolk' => 'ਨੋਰਫੌਕ ਆਈਲੈਂਡ ਵੇਲਾ',
        'Pacific/Noumea' => 'ਨਿਊ ਕੈਲੇਡੋਨੀਆ ਵੇਲਾ (ਨੌਮਿਆ)',
        'Pacific/Pago_Pago' => 'ਸਾਮੋਆ ਵੇਲਾ (ਪਾਗੋ ਪਾਗੋ)',
        'Pacific/Palau' => 'ਪਲਾਉ ਵੇਲਾ',
        'Pacific/Pitcairn' => 'ਪਿਟਕੈਰਨ ਵੇਲਾ',
        'Pacific/Ponape' => 'ਪੋਨਾਪੇ ਵੇਲਾ (ਪੋਹਨਪੇਈ)',
        'Pacific/Port_Moresby' => 'ਪਾਪੂਆ ਨਿਊ ਗਿਨੀ ਵੇਲਾ (ਪੋਰਟ ਮੋਰੇਸਬੀ)',
        'Pacific/Rarotonga' => 'ਕੁੱਕ ਆਈਲੈਂਡ ਵੇਲਾ (ਰਾਰੋਟੋਂਗਾ)',
        'Pacific/Saipan' => 'ਚਾਮੋਰੋ ਮਿਆਰੀ ਵੇਲਾ (ਸੈਪਾਨ)',
        'Pacific/Tahiti' => 'ਤਾਹੀਤੀ ਵੇਲਾ (ਤਹਿਤੀ)',
        'Pacific/Tarawa' => 'ਗਿਲਬਰਟ ਆਈਲੈਂਡ ਵੇਲਾ (ਟਾਰਾਵਾ)',
        'Pacific/Tongatapu' => 'ਟੋਂਗਾ ਵੇਲਾ (ਟੋਂਗਾਟਾਪੂ)',
        'Pacific/Truk' => 'ਚੂਕ ਵੇਲਾ',
        'Pacific/Wake' => 'ਵੇਕ ਆਈਲੈਂਡ ਵੇਲਾ',
        'Pacific/Wallis' => 'ਵਾਲਿਸ ਅਤੇ ਫੁਟੂਨਾ ਵੇਲਾ',
    ],
    'Meta' => [
    ],
];
