<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorransk peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham fra de Forenede Arabiske Emirater',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afghansk afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afghansk afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albansk lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'armensk dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Nederlandske Antiller-gylden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angolansk kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolansk kwanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolansk nye kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolansk kwanza (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentinsk austral',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentinsk peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentinsk peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Østrigsk schilling',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'australsk dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arubansk florin',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Aserbajdsjansk manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'aserbajdsjansk manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosnien-Hercegovinsk dinar',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'bosnien-hercegovinsk konvertibel mark',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadisk dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladeshisk taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belgisk franc (konvertibel)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgisk franc',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belgisk franc (financial)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgarsk hard lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'bulgarsk lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahrainsk dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'burundisk franc',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'bermudansk dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'bruneisk dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviansk boliviano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Boliviansk peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Boliviansk mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Brasiliansk cruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Brasiliansk cruzado (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Brasiliansk cruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'brasiliansk real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Brasiliansk cruzado novo (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brasiliansk cruzeiro (1993–1994)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'bahamansk dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'bhutansk ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Burmesisk kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'botswansk pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Hviderussisk rubel (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'hviderussisk rubel',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'hviderussisk rubel (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'belizisk dollar',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'canadisk dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'congolesisk franc',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'schweizerfranc',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR franc',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'chilensk peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'kinesisk yuan (offshore)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'kinesisk yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'colombiansk peso',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'costaricansk colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Serbisk dinar (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Tjekkoslovakisk hard koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'cubansk konvertibel peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'cubansk peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'kapverdisk escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Cypriotisk pund',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'tjekkisk koruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Østtysk mark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Tysk mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'djiboutisk franc',
        ],
        'DKK' => [
            0 => 'kr.',
            1 => 'dansk krone',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dominikansk peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'algerisk dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ecuadoriansk sucre',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estisk kroon',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egyptisk pund',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'eritreisk nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Spansk peseta (A–konto)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Spansk peseta (konvertibel konto)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Spansk peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'etiopisk birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Finsk mark',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fijiansk dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'pund fra Falklandsøerne',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Fransk franc',
        ],
        'GBP' => [
            0 => '£',
            1 => 'britisk pund',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Georgisk kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'georgisk lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ghanesisk cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ghanesisk cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'gibraltarisk pund',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambisk dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'guineansk franc',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guineansk syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ækvatorialguineask ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Græsk drakme',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'guatemalansk quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugisisk guinea escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guineansk peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'guyansk dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'hongkongsk dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'honduransk lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Kroatisk dinar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kroatisk kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haitisk gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'ungarsk forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indonesisk rupiah',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Irsk pund',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Israelsk pund',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'ny israelsk shekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'indisk rupee',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'irakisk dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iransk rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'islandsk krone',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italiensk lire',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamaicansk dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jordansk dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'japansk yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenyansk shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgisisk som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'cambodjansk riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'comorisk franc',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'nordkoreansk won',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'sydkoreansk won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuwaitisk dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'caymansk dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kasakhisk tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laotisk kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'libanesisk pund',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'srilankansk rupee',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'liberisk dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesothisk loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litauisk litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litauisk talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Luxembourgsk konvertibel franc',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Luxembourgsk franc',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Luxembourgsk finansiel franc',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lettisk lat',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Lettisk rubel',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'libysk dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'marokkansk dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokkansk franc',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldovisk leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'madagaskisk ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madagaskisk franc',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'makedonsk denar',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malisk franc',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'myanmarsk kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongolsk tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'macaosk pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'mauritansk ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mauritansk ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltesisk lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltesisk pund',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'mauritisk rupee',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldivisk rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'malawisk kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'mexicansk peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Mexicansk silver peso (1861–1992)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malaysisk ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambiquisk escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mozambiquisk metical (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'mozambiquisk metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'namibisk dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nigeriansk naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nicaraguansk cordoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'nicaraguansk cordoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Hollandsk guilder',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'norsk krone',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepalesisk rupee',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'newzealandsk dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'omansk rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'panamansk balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'peruviansk inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'peruansk sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'peruviansk sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'papuansk kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'filippinsk peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistansk rupee',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'polsk zloty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Polsk zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugisisk escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paraguaysk guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'qatarsk rial',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rumænsk leu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'rumænsk leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'serbisk dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'russisk rubel',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Russisk rubel (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'rwandisk franc',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'saudiarabisk riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'salomonsk dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'seychellisk rupee',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Sudansk dinar (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sudansk pund',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Sudansk pund (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'svensk krone',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singaporeansk dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'pund fra Saint Helena',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slovensk tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovakisk koruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'sierraleonsk leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'somalisk shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'surinamsk dollar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinamsk guilder',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'sydsudansk pund',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra fra Sao Tome og Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra fra Sao Tome og Principe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovjetisk rubel',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Salvadoransk colon',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'syrisk pund',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'swazilandsk lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'thailandsk baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadsjikisk rubel',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tadsjikisk somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmensk manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'turkmensk manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tunesisk dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'tongansk paʻanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Escudo fra Timor',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Tyrkisk lire (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'tyrkisk lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'trinidadisk dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'ny taiwansk dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'tanzanisk shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ukrainsk grynia',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrainsk karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Ugandisk shilling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ugandisk shilling',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'amerikansk dollar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Amerikansk dollar (næste dag)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Amerikansk dollar (samme dag)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruguayansk peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'uruguayansk peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'usbekisk sum',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venezuelansk bolivar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venezuelansk bolivar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venezuelansk bolivar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'vietnamesisk dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuaisk vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'samoansk tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA-franc (BEAC)',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'østkaribisk dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'ECU',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Fransk guldfranc',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Fransk UIC-franc',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'CFA-franc BCEAO',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP-franc',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET-fond',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Yemenitisk dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'yemenitisk rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Jugoslavisk hard dinar (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Jugoslavisk noviy dinar (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Jugoslavisk konvertibel dinar (1990–1992)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Sydafrikansk rand (financial)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'sydafrikansk rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambisk kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'zambisk kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Ny zairisk zaire (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zairisk zaire (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabwisk dollar (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabwisk dollar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabwisk dollar (2008)',
        ],
    ],
];
