<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Πεσέτα Ανδόρας',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Ντιράμ Ηνωμένων Αραβικών Εμιράτων',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Αφγανί Αφγανιστάν (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Αφγάνι Αφγανιστάν',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Λεκ Αλβανίας',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Ντραμ Αρμενίας',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Γκίλντα Ολλανδικών Αντιλλών',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Κουάνζα Ανγκόλας',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Κουάνζα Ανγκόλας (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Νέα Κουάνζα Ανγκόλας (1990–2000)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Ωστράλ Αργετινής',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Πέσο Αργεντινής (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Πέσο Αργεντινής',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Σελίνι Αυστρίας',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Δολάριο Αυστραλίας',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Φλορίνι Αρούμπας',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Μανάτ Αζερμπαϊτζάν (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Μανάτ Αζερμπαϊτζάν',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Δηνάριο Βοσνίας-Ερζεγοβίνης',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Μετατρέψιμο Μάρκο Βοσνίας-Ερζεγοβίνης',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Δολάριο Μπαρμπέιντος',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Τάκα Μπαγκλαντές',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Φράγκο Βελγίου (μετατρέψιμο)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Φράγκο Βελγίου',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Φράγκο Βελγίου (οικονομικό)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Μεταλλικό Λεβ Βουλγαρίας',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Λεβ Βουλγαρίας',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Δηνάριο Μπαχρέιν',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Φράγκο Μπουρούντι',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Δολάριο Βερμούδων',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Δολάριο Μπρουνέι',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Μπολιβιάνο Βολιβίας',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Πέσο Βολιβίας',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Μβδολ Βολιβίας',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Νέο Κρουζιέρο Βραζιλίας (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Κρουζάντο Βραζιλίας',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Κρουζιέρο Βραζιλίας (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Ρεάλ Βραζιλίας',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Νέο Κρουζάντο Βραζιλίας',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Κρουζιέρο Βραζιλίας',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Δολάριο Μπαχαμών',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Νγκούλτρουμ Μπουτάν',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Κιατ Βιρμανίας',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Πούλα Μποτσουάνας',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Νέο Ρούβλι Λευκορωσίας (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Ρούβλι Λευκορωσίας',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Ρούβλι Λευκορωσίας (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Δολάριο Μπελίζ',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Δολάριο Καναδά',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Φράγκο Κονγκό',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'Ευρώ WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Φράγκο Ελβετίας',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'Φράγκο WIR',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Ουνιδάδες ντε φομέντο Χιλής',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Πέσο Χιλής',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Γουάν Κίνας (υπεράκτιο)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Γουάν Κίνας',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Πέσο Κολομβίας',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Κολόν Κόστα Ρίκα',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Παλαιό Δηνάριο Σερβίας',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Σκληρή Κορόνα Τσεχοσλοβακίας',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Μετατρέψιμο πέσο Κούβας',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Πέσο Κούβας',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Εσκούδο Πράσινου Ακρωτηρίου',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Λίρα Κύπρου',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Κορόνα Τσεχίας',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Οστμάρκ Ανατολικής Γερμανίας',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Μάρκο Γερμανίας',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Φράγκο Τζιμπουτί',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Κορόνα Δανίας',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Πέσο Δομινικανής Δημοκρατίας',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Δηνάριο Αλγερίας',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Σούκρε Εκουαδόρ',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Κορόνα Εσθονίας',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Λίρα Αιγύπτου',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Νάκφα Ερυθραίας',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'πεσέτα Ισπανίας (λογαριασμός Α)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'πεσέτα Ισπανίας (μετατρέψιμος λογαριασμός)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Πεσέτα Ισπανίας',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Μπιρ Αιθιοπίας',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Ευρώ',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Μάρκο Φινλανδίας',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Δολάριο Φίτζι',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Λίρα Νήσων Φόκλαντ',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Φράγκο Γαλλίας',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Λίρα Στερλίνα Βρετανίας',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Κούπον Λάρι Γεωργίας',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Λάρι Γεωργίας',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Σέντι Γκάνας (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Σέντι Γκάνας',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Λίρα Γιβραλτάρ',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Νταλάσι Γκάμπιας',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Φράγκο Γουινέας',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Συλί Γουινέας',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Εκγουέλε Ισημερινής Γουινέας',
        ],
        'GRD' => [
            0 => 'Δρχ',
            1 => 'Δραχμή Ελλάδας',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Κουετσάλ Γουατεμάλας',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Γκινέα Εσκούδο Πορτογαλίας',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Πέσο Γουινέας-Μπισάου',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Δολάριο Γουιάνας',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Δολάριο Χονγκ Κονγκ',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Λεμπίρα Ονδούρας',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Δηνάριο Κροατίας',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Κούνα Κροατίας',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Γκουρντ Αϊτής',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Φιορίνι Ουγγαρίας',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Ρουπία Ινδονησίας',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Λίρα Ιρλανδίας',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Λίρα Ισραήλ',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'παλιό σεκέλ Ισραήλ',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Νέο Σέκελ Ισραήλ',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Ρουπία Ινδίας',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Δηνάριο Ιράκ',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Ριάλ Ιράν',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'Παλιά κορόνα Ισλανδίας',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Κορόνα Ισλανδίας',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Λιρέτα Ιταλίας',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Δολάριο Τζαμάικας',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Δηνάριο Ιορδανίας',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Γιεν Ιαπωνίας',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Σελίνι Κένυας',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Σομ Κιργιζίας',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Ρίελ Καμπότζης',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Φράγκο Κομορών',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Γουόν Βόρειας Κορέας',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Γουόν Νότιας Κορέας',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Δηνάριο Κουβέιτ',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Δολάριο Νήσων Κέιμαν',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Τένγκε Καζακστάν',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Κιπ Λάος',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Λίρα Λιβάνου',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Ρουπία Σρι Λάνκα',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Δολάριο Λιβερίας',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Λότι Λεσότο',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Λίτα Λιθουανίας',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Ταλόνας Λιθουανίας',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Μετατρέψιμο Φράγκο Λουξεμβούργου',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Φράγκο Λουξεμβούργου',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Οικονομικό Φράγκο Λουξεμβούργου',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Λατς Λετονίας',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Ρούβλι Λετονίας',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Δηνάριο Λιβύης',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Ντιράμ Μαρόκου',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Φράγκο Μαρόκου',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Λέου Μολδαβίας',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Αριάρι Μαδαγασκάρης',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Φράγκο Μαδαγασκάρης',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Δηνάριο ΠΓΔΜ',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Φράγκο Μαλί',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Κιάτ Μιανμάρ',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Τουγκρίκ Μογγολίας',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Πατάκα Μακάο',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ουγκίγια Μαυριτανίας (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ουγκίγια Μαυριτανίας',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Λιρέτα Μάλτας',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Λίρα Μάλτας',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Ρουπία Μαυρικίου',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Ρουφίγια Μαλδίβων',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Κουάτσα Μαλάουι',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Πέσο Μεξικού',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Ασημένιο Πέσο Μεξικού (1861–1992)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ρινγκίτ Μαλαισίας',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Εσκούδο Μοζαμβίκης',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Παλαιό Μετικάλ Μοζαμβίκης',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Μετικάλ Μοζαμβίκης',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Δολάριο Ναμίμπιας',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Νάιρα Νιγηρίας',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Κόρδοβα Νικαράγουας',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Χρυσή Κόρδοβα Νικαράγουας',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Γκίλντα Ολλανδίας',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Κορόνα Νορβηγίας',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Ρουπία Νεπάλ',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Δολάριο Νέας Ζηλανδίας',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Ριάλ Ομάν',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Μπαλμπόα Παναμά',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Ίντι Περού',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Σολ Περού',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Σολ Περού (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Κίνα Παπούας Νέας Γουινέας',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Πέσο Φιλιππίνων',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Ρουπία Πακιστάν',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Ζλότι Πολωνίας',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Ζλότυ Πολωνίας (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Εσκούδο Πορτογαλίας',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Γκουαρανί Παραγουάης',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Ριάλ Κατάρ',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Δολάριο Ροδεσίας',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Λέι Ρουμανίας',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Λέου Ρουμανίας',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Δηνάριο Σερβίας',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Ρούβλι Ρωσίας',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Ρούβλι Ρωσίας (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Φράγκο Ρουάντας',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Ριάλ Σαουδικής Αραβίας',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Δολάριο Νήσων Σολομώντος',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Ρουπία Σεϋχελλών',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Δηνάριο Σουδάν',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Λίρα Σουδάν',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Παλαιά Λίρα Σουδάν',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Κορόνα Σουηδίας',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Δολάριο Σιγκαπούρης',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Λίρα Αγίας Ελένης',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Τόλαρ Σλοβενίας',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Κορόνα Σλοβενίας',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Λεόνε Σιέρα Λεόνε',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Σελίνι Σομαλίας',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Δολάριο Σουρινάμ',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Γκίλντα Σουρινάμ',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Λίρα Νότιου Σουδάν',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Ντόμπρα Σάο Τομέ και Πρίνσιπε (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Ντόμπρα Σάο Τομέ και Πρίνσιπε',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Σοβιετικό Ρούβλι',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Κολόν Ελ Σαλβαδόρ',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Λίρα Συρίας',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Λιλανγκένι Σουαζιλάνδης',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Μπατ Ταϊλάνδης',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Ρούβλι Τατζικιστάν',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Σομόνι Τατζικιστάν',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Μανάτ Τουρκμενιστάν',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Μάνατ Τουρκμενιστάν',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Δηνάριο Τυνησίας',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Παάγκα Τόνγκα',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Εσκούδο Τιμόρ',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Παλιά Λίρα Τουρκίας',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Λίρα Τουρκίας',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Δολάριο Τρινιντάντ και Τομπάγκο',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Νέο δολάριο Ταϊβάν',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Σελίνι Τανζανίας',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Γρίβνα Ουκρανίας',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Καρμποβανέτς Ουκρανίας',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Σελίνι Ουγκάντας (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Σελίνι Ουγκάντας',
        ],
        'USD' => [
            0 => '$',
            1 => 'Δολάριο ΗΠΑ',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Δολάριο ΗΠΑ (επόμενη ημέρα)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Δολάριο ΗΠΑ (ίδια ημέρα)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Πέσο Ουρουγουάης (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Πέσο Ουρουγουάης',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Σομ Ουζμπεκιστάν',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Μπολιβάρ Βενεζουέλας (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Μπολιβάρ Βενεζουέλας (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Μπολιβάρ Βενεζουέλας',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Ντονγκ Βιετνάμ',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Βατού Βανουάτου',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Τάλα Σαμόα',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Φράγκο CFA Κεντρικής Αφρικής',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Δολάριο Ανατολικής Καραϊβικής',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Ευρωπαϊκή Συναλλαγματική Μονάδα',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Χρυσό Φράγκο Γαλλίας',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'UIC-Φράγκο Γαλλίας',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Φράγκο CFA Δυτικής Αφρικής',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Φράγκο CFP',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Δηνάριο Υεμένης',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Ριάλ Υεμένης',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Μεταλλικό Δηνάριο Γιουγκοσλαβίας',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Νέο Δηνάριο Γιουγκοσλαβίας',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Μετατρέψιμο Δηνάριο Γιουγκοσλαβίας',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Ραντ Νότιας Αφρικής (οικονομικό)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Ραντ Νότιας Αφρικής',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Κουάνζα Ζαΐρ (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Κουάτσα Ζάμπιας',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Νέο Ζαΐρ Ζαΐρ',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Ζαΐρ Ζαΐρ',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Δολάριο Ζιμπάμπουε',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Δολάριο Ζιμπάμπουε (2009)',
        ],
    ],
];
