<?php

return [
    'Names' => [
        'Adlm' => 'isi-Adlam',
        'Aghb' => 'isi-Caucasian Albanian',
        'Ahom' => 'isi-Ahom',
        'Arab' => 'isi-Arabic',
        'Aran' => 'i-Nastaliq',
        'Armi' => 'isi-Imperial Aramaic',
        'Armn' => 'isi-Armenian',
        'Avst' => 'isi-Avestan',
        'Bali' => 'isi-Balinese',
        'Bamu' => 'isi-Bamum',
        'Bass' => 'isi-Bassa Vah',
        'Batk' => 'isi-Batak',
        'Beng' => 'isi-Bangla',
        'Bhks' => 'isi-Bhaiksuki',
        'Bopo' => 'isi-Bopomofo',
        'Brah' => 'isi-Brahmi',
        'Brai' => 'i-Braille',
        'Bugi' => 'isi-Buginese',
        'Buhd' => 'isi-Buhid',
        'Cakm' => 'isi-Chakma',
        'Cans' => 'i-Unified Canadian Aboriginal Syllabics',
        'Cari' => 'isi-Carian',
        'Cham' => 'isi-Cham',
        'Cher' => 'isi-Cherokee',
        'Chrs' => 'isi-Chorasmian',
        'Copt' => 'isi-Coptic',
        'Cprt' => 'isi-Cypriot',
        'Cyrl' => 'isi-Cyrillic',
        'Deva' => 'isi-Devanagari',
        'Diak' => 'isi-Dives Akuru',
        'Dogr' => 'isi-Dogra',
        'Dsrt' => 'isi-Deseret',
        'Dupl' => 'isi-Duployan shorthand',
        'Egyp' => 'i-Egyptian hieroglyphs',
        'Elba' => 'isi-Elbasan',
        'Elym' => 'isi-Elymaic',
        'Ethi' => 'isi-Ethiopic',
        'Geor' => 'isi-Georgian',
        'Glag' => 'isi-Glagolitic',
        'Gong' => 'isi-Gunjala Gondi',
        'Gonm' => 'isi-Masaram Gondi',
        'Goth' => 'isi-Gothic',
        'Gran' => 'isi-Grantha',
        'Grek' => 'isi-Greek',
        'Gujr' => 'isi-Gujarati',
        'Guru' => 'isi-Gurmukhi',
        'Hanb' => 'isi-Hanb',
        'Hang' => 'isi-Hangul',
        'Hani' => 'isi-Han',
        'Hano' => 'isi-Hanunoo',
        'Hans' => 'enziwe lula',
        'Hant' => 'okosiko',
        'Hatr' => 'isi-Hatran',
        'Hebr' => 'isi-Hebrew',
        'Hira' => 'isi-Hiragana',
        'Hluw' => 'isi-Anatolian Hieroglyphs',
        'Hmng' => 'isi-Pahawh Hmong',
        'Hmnp' => 'i-Nyiakeng Puachue Hmong',
        'Hrkt' => 'i-Japanese syllabaries',
        'Hung' => 'isi-Old Hungarian',
        'Ital' => 'i-Old Italic',
        'Jamo' => 'isi-Jamo',
        'Java' => 'isi-Javanese',
        'Jpan' => 'isi-Japanese',
        'Kali' => 'isi-Kayah Li',
        'Kana' => 'isi-Katakana',
        'Khar' => 'isi-Kharoshthi',
        'Khmr' => 'isi-Khmer',
        'Khoj' => 'isi-Khojki',
        'Kits' => 'i-Khitan small script',
        'Knda' => 'isi-Kannada',
        'Kore' => 'isi-Korean',
        'Kthi' => 'isi-Kaithi',
        'Lana' => 'isi-Lanna',
        'Laoo' => 'isi-Lao',
        'Latn' => 'isi-Latin',
        'Lepc' => 'isi-Lepcha',
        'Limb' => 'isi-Limbu',
        'Lina' => 'i-Linear A',
        'Linb' => 'i-Linear B',
        'Lisu' => 'isi-Fraser',
        'Lyci' => 'i-Lycian',
        'Lydi' => 'i-Lydian',
        'Mahj' => 'i-Mahajani',
        'Maka' => 'i-Makasar',
        'Mand' => 'isi-Mandaean',
        'Mani' => 'i-Manichaean',
        'Marc' => 'i-Marchen',
        'Medf' => 'i-Medefaidrin',
        'Mend' => 'i-Mende',
        'Merc' => 'i-Meroitic Cursive',
        'Mero' => 'i-Meroitic',
        'Mlym' => 'isi-Malayalam',
        'Modi' => 'i-Modi',
        'Mong' => 'isi-Mongolian',
        'Mroo' => 'i-Mro',
        'Mtei' => 'isi-Meitei Mayek',
        'Mult' => 'i-Multani',
        'Mymr' => 'isi-Myanmar',
        'Nand' => 'i-Nandinagari',
        'Narb' => 'i-Old North Arabian',
        'Nbat' => 'i-Nabataean',
        'Nkoo' => 'isi-N’Ko',
        'Nshu' => 'i-Nüshu',
        'Ogam' => 'i-Ogham',
        'Olck' => 'isi-Ol Chiki',
        'Orkh' => 'i-Orkhon',
        'Orya' => 'isi-Odia',
        'Osge' => 'isi-Osage',
        'Osma' => 'i-Osmanya',
        'Palm' => 'i-Palmyrene',
        'Pauc' => 'i-Pau Cin Hau',
        'Perm' => 'i-Old Permic',
        'Phag' => 'i-Phags-pa',
        'Phli' => 'i-Inscriptional Pahlavi',
        'Phlp' => 'i-Psalter Pahlavi',
        'Phnx' => 'i-Phoenician',
        'Plrd' => 'isi-Pollard Phonetic',
        'Prti' => 'i-Inscriptional Parthian',
        'Qaag' => 'i-Zawgyi',
        'Rjng' => 'i-Rejang',
        'Rohg' => 'isi-Hanifi Rohingya',
        'Runr' => 'i-Runic',
        'Samr' => 'i-Samaritan',
        'Sarb' => 'i-Old South Arabian',
        'Saur' => 'isi-Saurashtra',
        'Sgnw' => 'i-SignWriting',
        'Shaw' => 'i-Shavian',
        'Shrd' => 'i-Sharada',
        'Sidd' => 'i-Siddham',
        'Sind' => 'i-Khudawadi',
        'Sinh' => 'isi-Sinhala',
        'Sogd' => 'i-Sogdian',
        'Sogo' => 'i-Old Sogdian',
        'Sora' => 'i-Sora Sompeng',
        'Soyo' => 'i-Soyombo',
        'Sund' => 'isi-Sundanese',
        'Sylo' => 'isi-Syloti Nagri',
        'Syrc' => 'isi-Syriac',
        'Tagb' => 'i-Tagbanwa',
        'Takr' => 'i-Takri',
        'Tale' => 'isi-Tai Le',
        'Talu' => 'isi-New Tai Lue',
        'Taml' => 'isi-Tamil',
        'Tang' => 'i-Tangut',
        'Tavt' => 'isi-Tai Viet',
        'Telu' => 'isi-Telugu',
        'Tfng' => 'isi-Tifinagh',
        'Tglg' => 'i-Tagalog',
        'Thaa' => 'isi-Thaana',
        'Thai' => 'isi-Thai',
        'Tibt' => 'i-Tibetan',
        'Tirh' => 'i-Tirhuta',
        'Ugar' => 'i-Ugaritic',
        'Vaii' => 'isi-Vai',
        'Wara' => 'i-Varang Kshiti',
        'Wcho' => 'isi-Wancho',
        'Xpeo' => 'i-Old Persian',
        'Xsux' => 'i-Sumero-Akkadian Cuneiform',
        'Yezi' => 'i-Yezidi',
        'Yiii' => 'isi-Yi',
        'Zanb' => 'i-Zanabazar Square',
        'Zinh' => 'Okuthethwe',
        'Zmth' => 'i-Mathematical Notation',
        'Zsye' => 'i-Emoji',
        'Zsym' => 'amasimbuli',
        'Zxxx' => 'okungabhaliwe',
        'Zyyy' => 'jwayelekile',
    ],
];
