<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Андорска песета',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Дирхам на Обединените арабски емирства',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Афганистански афган (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Афганистански афган',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Албански лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Арменски драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Антилски гулден',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Анголска кванза',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Анголска кванца (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Анголска нова кванца (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Анголска нова кванца (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Аржентински австрал',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Аржентинско песо (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Аржентинско песо',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Австрийски шилинг',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'Австралийски долар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Арубски флорин',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Азербайджански манат (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Азербайджански манат',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Босна и Херцеговина-динар',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Босненска конвертируема марка',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Барбадоски долар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Бангладешка така',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Белгийски франк (конвертируем)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Белгийски франк',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Белгийски франк (финансов)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Български конвертируем лев (1962–1999)',
        ],
        'BGN' => [
            0 => 'лв.',
            1 => 'Български лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Бахрейнски динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Бурундийски франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Бермудски долар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Брунейски долар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Боливийско боливиано',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Боливийско песо',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Боливийски мвдол',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Бразилско ново крузейро (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Бразилско крозадо',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Бразилско крузейро (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Бразилски реал',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Бразилско ново крозадо',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Бразилско крузейро',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Бахамски долар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Бутански нгултрум',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Бирмански киат',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ботсванска пула',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Беларуска нова рубла (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Беларуска рубла',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Беларуска рубла (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Белизийски долар',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Канадски долар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Конгоански франк',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR евро',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Швейцарски франк',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR франк',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Условна разчетна единица на Чили',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Чилийско песо',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Китайски юан (офшорен)',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Китайски юан',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Колумбийско песо',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Колумбийска единица на реалната стойност',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Костарикански колон',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Стар сръбски динар',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Чехословашка конвертируема крона',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Кубинско конвертируемо песо',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Кубинско песо',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Ескудо на Кабо Верде',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Кипърска лира',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Чешка крона',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Източногерманска марка',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Германска марка',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Джибутски франк',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Датска крона',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Доминиканско песо',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Алжирски динар',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Еквадорско сукре',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Еквадорска банкова единица',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Естонска крона',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Египетска лира',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Еритрейска накфа',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Испанска песета',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Етиопски бир',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Евро',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Финландска марка',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Фиджийски долар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Фолкландска лира',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Френски франк',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'Британска лира',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Грузински купон',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Грузински лари',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ганайско седи (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ганайско седи',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Гибралтарска лира',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Гамбийско даласи',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Гвинейски франк',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Гвинейска сили',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Екваториално гвинейско еквеле',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Гръцка драхма',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Гватемалски кетцал',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Ескудо от Португалска Гвинея',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Гвинея-Бисау песо',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Гаянски долар',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Хонконгски долар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Хондураска лемпира',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Хърватски динар',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Хърватска куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Хаитски гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Унгарски форинт',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Индонезийска рупия',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Ирландска лира',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Израелска лира',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Израелски нов шекел',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Индийска рупия',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Иракски динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Ирански риал',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Исландска крона',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Италианска лира',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ямайски долар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Йордански динар',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'Японска йена',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Кенийски шилинг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Киргизстански сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Камбоджански риел',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Коморски франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Севернокорейски вон',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'Южнокорейски вон',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Кувейтски динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Кайманов долар',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Казахстанско тенге',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Лаоски кип',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Ливанска лира',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Шриланкска рупия',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Либерийски долар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Лесотско лоти',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Литовски литас',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Литовски талон',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Люксембургски франк',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Латвийски лат',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Латвийска рубла',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Либийски динар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Марокански дирхам',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Марокански франк',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Молдовска лея',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Малгашко ариари',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Малгашки франк - Мадагаскар',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Македонски денар',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Малийски франк',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Мианмарски киат',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Монголски тугрик',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Патака на Макао',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Мавританска угия (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Мавританска угия',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Малтийска лира',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Маврицийска рупия',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Малдивска руфия',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Малавийска куача',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Мексиканско песо',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Мексиканско сребърно песо (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Мексиканска конвертируема единица (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Малайзийски рингит',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Мозамбикско ескудо',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Мозамбикски метикал (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Мозамбикски метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Намибийски долар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Нигерийска найра',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Никарагуанска кордоба (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Никарагуанска кордоба',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Холандски гулден',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Норвежка крона',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Непалска рупия',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'Новозеландски долар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Омански риал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Панамска балбоа',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Перуанско инти',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Перуански сол',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Перуански сол (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Папуа-новогвинейска кина',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Филипинско песо',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Пакистанска рупия',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Полска злота',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Полска злота (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Португалско ескудо',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Парагвайско гуарани',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Катарски риал',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Родезийски долар',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Стара румънска лея',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Румънска лея',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Сръбски динар',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Руска рубла',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Руска рубла (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Руандски франк',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'саудитски риал',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Долар на Соломоновите острови',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Сейшелска рупия',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Судански динар',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Суданска лира',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Шведска крона',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Сингапурски долар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Лира на Света Елена',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Словенски толар',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Словашка крона',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Сиералеонско леоне',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Сомалийски шилинг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Суринамски долар',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Суринамски гилдер',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Южносуданска лира',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Добра на Сао Томе и Принсипи (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Добра на Сао Томе и Принсипи',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Съветска рубла',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Салвадорски колон',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Сирийска лира',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Свазилендски лилангени',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Тайландски бат',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Таджикистанска рубла',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Таджикистански сомони',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Туркменистански манат',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Туркменски манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Тунизийски динар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Тонганска паанга',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Тиморско ескудо',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Турска лира (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Турска лира',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Долар на Тринидад и Тобаго',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'Тайвански долар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Танзанийски шилинг',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Украинска гривня',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Украински карбованец',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Угандийски шилинг (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Угандски шилинг',
        ],
        'USD' => [
            0 => 'щ.д.',
            1 => 'Щатски долар',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'USN',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'USS',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Уругвайско песо (индекс на инфлацията)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Уругвайско песо (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Уругвайско песо',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Узбекски сум',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Венецуелски боливар (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Венецуелски боливар',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Венецуелски боливар (VES)',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'Виетнамски донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Вануатско вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Самоанска тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Централноафрикански франк',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'Източнокарибски долар',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Еку на ЕИО',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Френски златен франк',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Западноафрикански франк',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP франк',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Йеменски динар',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Йеменски риал',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Югославски твърд динар',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Югославски динар',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Югославски конвертируем динар',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Южноафрикански ранд (финансов)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Южноафрикански ранд',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Замбийска квача (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Замбийска куача',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Заирско ново зайре',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Заирско зайре',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Зимбабвийски долар',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Зимбабвийски долар (2009)',
        ],
    ],
];
