<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гриничко средње вријеме (Абиџан)',
        'Africa/Accra' => 'Гриничко средње вријеме (Акра)',
        'Africa/Addis_Ababa' => 'Источно-афричко вријеме (Адис Абеба)',
        'Africa/Algiers' => 'Средњеевропско вријеме (Алжир)',
        'Africa/Asmera' => 'Источно-афричко вријеме (Асмера)',
        'Africa/Bamako' => 'Гриничко средње вријеме (Бамако)',
        'Africa/Bangui' => 'Западно-афричко вријеме (Бангуи)',
        'Africa/Banjul' => 'Гриничко средње вријеме (Банжул)',
        'Africa/Bissau' => 'Гриничко средње вријеме (Бисао)',
        'Africa/Blantyre' => 'Централно-афричко вријеме (Блантир)',
        'Africa/Brazzaville' => 'Западно-афричко вријеме (Бразавил)',
        'Africa/Bujumbura' => 'Централно-афричко вријеме (Буџумбура)',
        'Africa/Cairo' => 'Источноевропско вријеме (Каиро)',
        'Africa/Casablanca' => 'Западноевропско вријеме (Казабланка)',
        'Africa/Ceuta' => 'Средњеевропско вријеме (Сеута)',
        'Africa/Conakry' => 'Гриничко средње вријеме (Конакри)',
        'Africa/Dakar' => 'Гриничко средње вријеме (Дакар)',
        'Africa/Dar_es_Salaam' => 'Источно-афричко вријеме (Дар-ес-Салам)',
        'Africa/Djibouti' => 'Источно-афричко вријеме (Џибути)',
        'Africa/Douala' => 'Западно-афричко вријеме (Дуала)',
        'Africa/El_Aaiun' => 'Западноевропско вријеме (Ел Ајун)',
        'Africa/Freetown' => 'Гриничко средње вријеме (Фритаун)',
        'Africa/Gaborone' => 'Централно-афричко вријеме (Габорон)',
        'Africa/Harare' => 'Централно-афричко вријеме (Хараре)',
        'Africa/Johannesburg' => 'Јужно-афричко вријеме (Јоханесбург)',
        'Africa/Juba' => 'Централно-афричко вријеме (Џуба)',
        'Africa/Kampala' => 'Источно-афричко вријеме (Кампала)',
        'Africa/Khartoum' => 'Централно-афричко вријеме (Картум)',
        'Africa/Kigali' => 'Централно-афричко вријеме (Кигали)',
        'Africa/Kinshasa' => 'Западно-афричко вријеме (Киншаса)',
        'Africa/Lagos' => 'Западно-афричко вријеме (Лагос)',
        'Africa/Libreville' => 'Западно-афричко вријеме (Либревил)',
        'Africa/Lome' => 'Гриничко средње вријеме (Ломе)',
        'Africa/Luanda' => 'Западно-афричко вријеме (Луанда)',
        'Africa/Lubumbashi' => 'Централно-афричко вријеме (Лумумбаши)',
        'Africa/Lusaka' => 'Централно-афричко вријеме (Лусака)',
        'Africa/Malabo' => 'Западно-афричко вријеме (Малабо)',
        'Africa/Maputo' => 'Централно-афричко вријеме (Мапуто)',
        'Africa/Maseru' => 'Јужно-афричко вријеме (Масеру)',
        'Africa/Mbabane' => 'Јужно-афричко вријеме (Мбабане)',
        'Africa/Mogadishu' => 'Источно-афричко вријеме (Могадиш)',
        'Africa/Monrovia' => 'Гриничко средње вријеме (Монровија)',
        'Africa/Nairobi' => 'Источно-афричко вријеме (Најроби)',
        'Africa/Ndjamena' => 'Западно-афричко вријеме (Нџамена)',
        'Africa/Niamey' => 'Западно-афричко вријеме (Нијамеј)',
        'Africa/Nouakchott' => 'Гриничко средње вријеме (Нуакшот)',
        'Africa/Ouagadougou' => 'Гриничко средње вријеме (Уагадугу)',
        'Africa/Porto-Novo' => 'Западно-афричко вријеме (Порто Ново)',
        'Africa/Sao_Tome' => 'Гриничко средње вријеме (Сао Томе)',
        'Africa/Tripoli' => 'Источноевропско вријеме (Триполи)',
        'Africa/Tunis' => 'Средњеевропско вријеме (Тунис)',
        'Africa/Windhoek' => 'Централно-афричко вријеме (Виндхук)',
        'America/Adak' => 'Хавајско-алеутско вријеме (Адак)',
        'America/Anchorage' => 'Аљаска вријеме (Енкориџ)',
        'America/Anguilla' => 'Атланско вријеме (Ангвила)',
        'America/Antigua' => 'Атланско вријеме (Антигва)',
        'America/Araguaina' => 'Бразилија вријеме (Арагвајана)',
        'America/Argentina/La_Rioja' => 'Аргентина вријеме (Ла Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина вријеме (Рио Гаљегос)',
        'America/Argentina/Salta' => 'Аргентина вријеме (Салта)',
        'America/Argentina/San_Juan' => 'Аргентина вријеме (Сан Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина вријеме (Сан Луи)',
        'America/Argentina/Tucuman' => 'Аргентина вријеме (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина вријеме (Ушуаија)',
        'America/Aruba' => 'Атланско вријеме (Аруба)',
        'America/Asuncion' => 'Парагвај вријеме (Асунсион)',
        'America/Bahia' => 'Бразилија вријеме (Баија)',
        'America/Bahia_Banderas' => 'Централно вријеме (Баија Бандерас)',
        'America/Barbados' => 'Атланско вријеме (Барбадос)',
        'America/Belem' => 'Бразилија вријеме (Белем)',
        'America/Belize' => 'Централно вријеме (Белизе)',
        'America/Blanc-Sablon' => 'Атланско вријеме (Бланк-Сејблон)',
        'America/Boa_Vista' => 'Амазон вријеме (Боа Виста)',
        'America/Bogota' => 'Колумбија вријеме (Богота)',
        'America/Boise' => 'Планинско вријеме (Бојзи)',
        'America/Buenos_Aires' => 'Аргентина вријеме (Буенос Аирес)',
        'America/Cambridge_Bay' => 'Планинско вријеме (Кембриџ Беј)',
        'America/Campo_Grande' => 'Амазон вријеме (Кампо Гранде)',
        'America/Cancun' => 'Источно вријеме (Канкун)',
        'America/Caracas' => 'Венецуела вријеме (Каракас)',
        'America/Catamarca' => 'Аргентина вријеме (Катамарка)',
        'America/Cayenne' => 'Француска Гвајана вријеме (Кајен)',
        'America/Cayman' => 'Источно вријеме (Кајманска острва)',
        'America/Chicago' => 'Централно вријеме (Чикаго)',
        'America/Chihuahua' => 'Мексичко пацифичко вријеме (Чивава)',
        'America/Coral_Harbour' => 'Источно вријеме (Атикокан)',
        'America/Cordoba' => 'Аргентина вријеме (Кордоба)',
        'America/Costa_Rica' => 'Централно вријеме (Костарика)',
        'America/Creston' => 'Планинско вријеме (Крестон)',
        'America/Cuiaba' => 'Амазон вријеме (Куиаба)',
        'America/Curacao' => 'Атланско вријеме (Курасао)',
        'America/Danmarkshavn' => 'Гриничко средње вријеме (Данмарксхаген)',
        'America/Dawson' => 'Jukonsko vrijeme (Досон)',
        'America/Dawson_Creek' => 'Планинско вријеме (Досон Крик)',
        'America/Denver' => 'Планинско вријеме (Денвер)',
        'America/Detroit' => 'Источно вријеме (Детроит)',
        'America/Dominica' => 'Атланско вријеме (Доминика)',
        'America/Edmonton' => 'Планинско вријеме (Едмонтон)',
        'America/Eirunepe' => 'Акре време (Еирунепе)',
        'America/El_Salvador' => 'Централно вријеме (Салвадор)',
        'America/Fort_Nelson' => 'Планинско вријеме (Форт Нелсон)',
        'America/Fortaleza' => 'Бразилија вријеме (Форталеза)',
        'America/Glace_Bay' => 'Атланско вријеме (Глејс Беј)',
        'America/Godthab' => 'Западни Гренланд вријеме (Нук)',
        'America/Goose_Bay' => 'Атланско вријеме (Гус Беј)',
        'America/Grand_Turk' => 'Источно вријеме (Гранд Турк)',
        'America/Grenada' => 'Атланско вријеме (Гренада)',
        'America/Guadeloupe' => 'Атланско вријеме (Гвадалупе)',
        'America/Guatemala' => 'Централно вријеме (Гватемала)',
        'America/Guayaquil' => 'Еквадор вријеме (Гвајакил)',
        'America/Guyana' => 'Гвајана вријеме (Гуана)',
        'America/Halifax' => 'Атланско вријеме (Халифакс)',
        'America/Havana' => 'Куба вријеме (Хавана)',
        'America/Hermosillo' => 'Мексичко пацифичко вријеме (Хермосиљо)',
        'America/Indiana/Knox' => 'Централно вријеме (Кнокс, Индијана)',
        'America/Indiana/Marengo' => 'Источно вријеме (Маренго, Индијана)',
        'America/Indiana/Petersburg' => 'Источно вријеме (Петерсбург, Индијана)',
        'America/Indiana/Tell_City' => 'Централно вријеме (Тел Сити, Индијана)',
        'America/Indiana/Vevay' => 'Источно вријеме (Вевај, Индијана)',
        'America/Indiana/Vincennes' => 'Источно вријеме (Винценес, Индијана)',
        'America/Indiana/Winamac' => 'Источно вријеме (Винамак, Индијана)',
        'America/Indianapolis' => 'Источно вријеме (Индианаполис)',
        'America/Inuvik' => 'Планинско вријеме (Инувик)',
        'America/Iqaluit' => 'Источно вријеме (Иквалуит)',
        'America/Jamaica' => 'Источно вријеме (Јамајка)',
        'America/Jujuy' => 'Аргентина вријеме (Хухуј)',
        'America/Juneau' => 'Аљаска вријеме (Жуно)',
        'America/Kentucky/Monticello' => 'Источно вријеме (Монтичело, Кентаки)',
        'America/Kralendijk' => 'Атланско вријеме (Крелендијк)',
        'America/La_Paz' => 'Боливија вријеме (Ла Паз)',
        'America/Lima' => 'Перу вријеме (Лима)',
        'America/Los_Angeles' => 'Пацифичко вријеме (Лос Анђелес)',
        'America/Louisville' => 'Источно вријеме (Луисвил)',
        'America/Lower_Princes' => 'Атланско вријеме (Лоуер Принс Квортер)',
        'America/Maceio' => 'Бразилија вријеме (Масејо)',
        'America/Managua' => 'Централно вријеме (Манагва)',
        'America/Manaus' => 'Амазон вријеме (Манаус)',
        'America/Marigot' => 'Атланско вријеме (Мариго)',
        'America/Martinique' => 'Атланско вријеме (Мартиник)',
        'America/Matamoros' => 'Централно вријеме (Матаморос)',
        'America/Mazatlan' => 'Мексичко пацифичко вријеме (Мазатлан)',
        'America/Mendoza' => 'Аргентина вријеме (Мендоза)',
        'America/Menominee' => 'Централно вријеме (Меномини)',
        'America/Merida' => 'Централно вријеме (Мерида)',
        'America/Metlakatla' => 'Аљаска вријеме (Метлакатла)',
        'America/Mexico_City' => 'Централно вријеме (Мексико Сити)',
        'America/Miquelon' => 'Сен Пјер и Микелон вријеме',
        'America/Moncton' => 'Атланско вријеме (Монктон)',
        'America/Monterrey' => 'Централно вријеме (Монтереј)',
        'America/Montevideo' => 'Уругвај вријеме (Монтевидео)',
        'America/Montreal' => 'Време: Канада (Montreal)',
        'America/Montserrat' => 'Атланско вријеме (Монтсерат)',
        'America/Nassau' => 'Источно вријеме (Насау)',
        'America/New_York' => 'Источно вријеме (Њујорк)',
        'America/Nipigon' => 'Источно вријеме (Нипигон)',
        'America/Nome' => 'Аљаска вријеме (Ном)',
        'America/Noronha' => 'Фернандо де Нороња вријеме',
        'America/North_Dakota/Beulah' => 'Централно вријеме (Бијула, Северна Дакота)',
        'America/North_Dakota/Center' => 'Централно вријеме (Центар, Северна Дакота)',
        'America/North_Dakota/New_Salem' => 'Централно вријеме (Нови Салем, Северна Дакота)',
        'America/Ojinaga' => 'Планинско вријеме (Охинага)',
        'America/Panama' => 'Источно вријеме (Панама)',
        'America/Pangnirtung' => 'Источно вријеме (Пангниртунг)',
        'America/Paramaribo' => 'Суринам вријеме (Парамарибо)',
        'America/Phoenix' => 'Планинско вријеме (Феникс)',
        'America/Port-au-Prince' => 'Источно вријеме (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атланско вријеме (Порт оф Спејн)',
        'America/Porto_Velho' => 'Амазон вријеме (Порто Вељо)',
        'America/Puerto_Rico' => 'Атланско вријеме (Порторико)',
        'America/Punta_Arenas' => 'Чиле вријеме (Пунта Аренас)',
        'America/Rainy_River' => 'Централно вријеме (Рејни Ривер)',
        'America/Rankin_Inlet' => 'Централно вријеме (Ранкин Инлет)',
        'America/Recife' => 'Бразилија вријеме (Ресифе)',
        'America/Regina' => 'Централно вријеме (Регина)',
        'America/Resolute' => 'Централно вријеме (Ресолут)',
        'America/Rio_Branco' => 'Акре време (Рио Бранко)',
        'America/Santa_Isabel' => 'Сјеверномексичко вријеме (Santa Isabel)',
        'America/Santarem' => 'Бразилија вријеме (Сантарем)',
        'America/Santiago' => 'Чиле вријеме (Сантијаго)',
        'America/Santo_Domingo' => 'Атланско вријеме (Санто Доминго)',
        'America/Sao_Paulo' => 'Бразилија вријеме (Сао Паоло)',
        'America/Scoresbysund' => 'Источни Гренланд вријеме (Итокортормит)',
        'America/Sitka' => 'Аљаска вријеме (Ситка)',
        'America/St_Barthelemy' => 'Атланско вријеме (Св. Бартоломeј)',
        'America/St_Johns' => 'Њуфаундленд вријеме (Св. Џон)',
        'America/St_Kitts' => 'Атланско вријеме (Сент Китс)',
        'America/St_Lucia' => 'Атланско вријеме (Св. Луција)',
        'America/St_Thomas' => 'Атланско вријеме (Св. Тома)',
        'America/St_Vincent' => 'Атланско вријеме (Сент Винсент)',
        'America/Swift_Current' => 'Централно вријеме (Свифт Курент)',
        'America/Tegucigalpa' => 'Централно вријеме (Тегусигалпа)',
        'America/Thule' => 'Атланско вријеме (Туле)',
        'America/Thunder_Bay' => 'Источно вријеме (Тандер Беј)',
        'America/Tijuana' => 'Пацифичко вријеме (Тихуана)',
        'America/Toronto' => 'Источно вријеме (Торонто)',
        'America/Tortola' => 'Атланско вријеме (Тортола)',
        'America/Vancouver' => 'Пацифичко вријеме (Ванкувер)',
        'America/Whitehorse' => 'Jukonsko vrijeme (Вајтхорс)',
        'America/Winnipeg' => 'Централно вријеме (Винипег)',
        'America/Yakutat' => 'Аљаска вријеме (Јакутат)',
        'America/Yellowknife' => 'Планинско вријеме (Јелоунајф)',
        'Antarctica/Casey' => 'Време: Антарктик (Касеј)',
        'Antarctica/Davis' => 'Дејвис вријеме',
        'Antarctica/DumontDUrville' => 'Димон д’Урвил вријеме',
        'Antarctica/Macquarie' => 'Аустралијско источно вријеме (Меквори)',
        'Antarctica/Mawson' => 'Мосон вријеме',
        'Antarctica/McMurdo' => 'Нови Зеланд вријеме (Макмурдо)',
        'Antarctica/Palmer' => 'Чиле вријеме (Палмер)',
        'Antarctica/Rothera' => 'Ротера вријеме',
        'Antarctica/Syowa' => 'Шова вријеме',
        'Antarctica/Troll' => 'Гриничко средње вријеме (Трол)',
        'Antarctica/Vostok' => 'Восток вријеме',
        'Arctic/Longyearbyen' => 'Средњеевропско вријеме (Лонгјербјен)',
        'Asia/Aden' => 'Арабијско вријеме (Аден)',
        'Asia/Almaty' => 'Источно-казахстанско вријеме (Алмати)',
        'Asia/Amman' => 'Источноевропско вријеме (Аман)',
        'Asia/Anadyr' => 'Анадир време',
        'Asia/Aqtau' => 'Западно-казахстанско вријеме (Актау)',
        'Asia/Aqtobe' => 'Западно-казахстанско вријеме (Акутобе)',
        'Asia/Ashgabat' => 'Туркменистан вријеме (Ашхабад)',
        'Asia/Atyrau' => 'Западно-казахстанско вријеме (Атирај)',
        'Asia/Baghdad' => 'Арабијско вријеме (Багдад)',
        'Asia/Bahrain' => 'Арабијско вријеме (Бахреин)',
        'Asia/Baku' => 'Азербејџан вријеме (Баку)',
        'Asia/Bangkok' => 'Индокина вријеме (Банкок)',
        'Asia/Barnaul' => 'Време: Русија (Барнаул)',
        'Asia/Beirut' => 'Источноевропско вријеме (Бејрут)',
        'Asia/Bishkek' => 'Киргистан вријеме (Бишкек)',
        'Asia/Brunei' => 'Брунеј Дарусалам вријеме (Брунеји)',
        'Asia/Calcutta' => 'Индијско стандардно вријеме (Калкута)',
        'Asia/Chita' => 'Јакутск вријеме (Чита)',
        'Asia/Choibalsan' => 'Улан Батор вријеме (Чојбалсан)',
        'Asia/Colombo' => 'Индијско стандардно вријеме (Коломбо)',
        'Asia/Damascus' => 'Источноевропско вријеме (Дамаск)',
        'Asia/Dhaka' => 'Бангладеш вријеме (Дака)',
        'Asia/Dili' => 'Тимор-Лесте вријеме (Дили)',
        'Asia/Dubai' => 'Заливско вријеме (Дубаи)',
        'Asia/Dushanbe' => 'Таџикистан вријеме (Душанбе)',
        'Asia/Famagusta' => 'Источноевропско вријеме (Фамагуста)',
        'Asia/Gaza' => 'Источноевропско вријеме (Газа)',
        'Asia/Hebron' => 'Источноевропско вријеме (Хеброн)',
        'Asia/Hong_Kong' => 'Хонг Конг вријеме',
        'Asia/Hovd' => 'Ховд вријеме',
        'Asia/Irkutsk' => 'Иркуцк вријеме',
        'Asia/Jakarta' => 'Западно-индонезијско вријеме (Џакарта)',
        'Asia/Jayapura' => 'Источно-индонезијско вријеме (Џајапура)',
        'Asia/Jerusalem' => 'Израелско вријеме (Јерусалим)',
        'Asia/Kabul' => 'Авганистан вријеме (Кабул)',
        'Asia/Kamchatka' => 'Петропавловско-камчатско време (Камчатка)',
        'Asia/Karachi' => 'Пакистан вријеме (Карачи)',
        'Asia/Katmandu' => 'Непал вријеме (Катманду)',
        'Asia/Khandyga' => 'Јакутск вријеме (Хандига)',
        'Asia/Krasnoyarsk' => 'Краснојарско вријеме',
        'Asia/Kuala_Lumpur' => 'Малезија вријеме (Куала Лумпур)',
        'Asia/Kuching' => 'Малезија вријеме (Кучинг)',
        'Asia/Kuwait' => 'Арабијско вријеме (Кувајт)',
        'Asia/Macau' => 'Кина вријеме (Макау)',
        'Asia/Magadan' => 'Магадан вријеме',
        'Asia/Makassar' => 'Централно-индонезијско вријеме (Макасар)',
        'Asia/Manila' => 'Филипини вријеме (Манила)',
        'Asia/Muscat' => 'Заливско вријеме (Мускат)',
        'Asia/Nicosia' => 'Источноевропско вријеме (Никозија)',
        'Asia/Novokuznetsk' => 'Краснојарско вријеме (Новокузњецк)',
        'Asia/Novosibirsk' => 'Новосибирско вријеме',
        'Asia/Omsk' => 'Омск вријеме',
        'Asia/Oral' => 'Западно-казахстанско вријеме (Орал)',
        'Asia/Phnom_Penh' => 'Индокина вријеме (Пном Пен)',
        'Asia/Pontianak' => 'Западно-индонезијско вријеме (Понтианак)',
        'Asia/Pyongyang' => 'Корејско вријеме (Пјонгјанг)',
        'Asia/Qatar' => 'Арабијско вријеме (Катар)',
        'Asia/Qostanay' => 'Источно-казахстанско вријеме (Костанај)',
        'Asia/Qyzylorda' => 'Западно-казахстанско вријеме (Кизилорда)',
        'Asia/Rangoon' => 'Мијанмар вријеме (Рангун)',
        'Asia/Riyadh' => 'Арабијско вријеме (Ријад)',
        'Asia/Saigon' => 'Индокина вријеме (Хо Ши Мин)',
        'Asia/Sakhalin' => 'Сахалин вријеме',
        'Asia/Samarkand' => 'Узбекистан вријеме (Самарканд)',
        'Asia/Seoul' => 'Корејско вријеме (Сеул)',
        'Asia/Shanghai' => 'Кина вријеме (Шангај)',
        'Asia/Singapore' => 'Сингапур стандардно вријеме',
        'Asia/Srednekolymsk' => 'Магадан вријеме (Средњеколимск)',
        'Asia/Taipei' => 'Тајпеј вријеме',
        'Asia/Tashkent' => 'Узбекистан вријеме (Ташкент)',
        'Asia/Tbilisi' => 'Грузија вријеме (Тбилиси)',
        'Asia/Tehran' => 'Иран вријеме (Техеран)',
        'Asia/Thimphu' => 'Бутан вријеме (Тимпу)',
        'Asia/Tokyo' => 'Јапанско вријеме (Токио)',
        'Asia/Tomsk' => 'Време: Русија (Томск)',
        'Asia/Ulaanbaatar' => 'Улан Батор вријеме',
        'Asia/Urumqi' => 'Време: Кина (Урумкви)',
        'Asia/Ust-Nera' => 'Владивосток вријеме (Уст-Нера)',
        'Asia/Vientiane' => 'Индокина вријеме (Вијентијан)',
        'Asia/Vladivostok' => 'Владивосток вријеме',
        'Asia/Yakutsk' => 'Јакутск вријеме',
        'Asia/Yekaterinburg' => 'Јекатеринбург вријеме',
        'Asia/Yerevan' => 'Арменија вријеме (Јереван)',
        'Atlantic/Azores' => 'Азори вријеме',
        'Atlantic/Bermuda' => 'Атланско вријеме (Бермуда)',
        'Atlantic/Canary' => 'Западноевропско вријеме (Канарска острва)',
        'Atlantic/Cape_Verde' => 'Зеленортско вријеме (Зеленортска Острва)',
        'Atlantic/Faeroe' => 'Западноевропско вријеме (Фарска острва)',
        'Atlantic/Madeira' => 'Западноевропско вријеме (Мадеира)',
        'Atlantic/Reykjavik' => 'Гриничко средње вријеме (Рејкјавик)',
        'Atlantic/South_Georgia' => 'Јужна Џорџија вријеме',
        'Atlantic/St_Helena' => 'Гриничко средње вријеме (Св. Јелена)',
        'Atlantic/Stanley' => 'Фолкландска Острва вријеме (Стенли)',
        'Australia/Adelaide' => 'Аустралијско централно вријеме (Аделаида)',
        'Australia/Brisbane' => 'Аустралијско источно вријеме (Бризбејн)',
        'Australia/Broken_Hill' => 'Аустралијско централно вријеме (Брокен Хил)',
        'Australia/Currie' => 'Аустралијско источно вријеме (Курие)',
        'Australia/Darwin' => 'Аустралијско централно вријеме (Дарвин)',
        'Australia/Eucla' => 'Аустралијско централно западно вријеме (Иукла)',
        'Australia/Hobart' => 'Аустралијско источно вријеме (Хобарт)',
        'Australia/Lindeman' => 'Аустралијско источно вријеме (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд Хов вријеме',
        'Australia/Melbourne' => 'Аустралијско источно вријеме (Мелбурн)',
        'Australia/Perth' => 'Аустралијско западно вријеме (Перт)',
        'Australia/Sydney' => 'Аустралијско источно вријеме (Сиднеј)',
        'CST6CDT' => 'Централно вријеме',
        'EST5EDT' => 'Источно вријеме',
        'Etc/GMT' => 'Гриничко средње вријеме',
        'Etc/UTC' => 'Координисано универзално вријеме',
        'Europe/Amsterdam' => 'Средњеевропско вријеме (Амстердам)',
        'Europe/Andorra' => 'Средњеевропско вријеме (Андора)',
        'Europe/Astrakhan' => 'Москва вријеме (Астрахан)',
        'Europe/Athens' => 'Источноевропско вријеме (Атина)',
        'Europe/Belgrade' => 'Средњеевропско вријеме (Београд)',
        'Europe/Berlin' => 'Средњеевропско вријеме (Берлин)',
        'Europe/Bratislava' => 'Средњеевропско вријеме (Братислава)',
        'Europe/Brussels' => 'Средњеевропско вријеме (Брисел)',
        'Europe/Bucharest' => 'Источноевропско вријеме (Букурешт)',
        'Europe/Budapest' => 'Средњеевропско вријеме (Будимпешта)',
        'Europe/Busingen' => 'Средњеевропско вријеме (Бусинген)',
        'Europe/Chisinau' => 'Источноевропско вријеме (Кишињев)',
        'Europe/Copenhagen' => 'Средњеевропско вријеме (Копенхаген)',
        'Europe/Dublin' => 'Гриничко средње вријеме (Даблин)',
        'Europe/Gibraltar' => 'Средњеевропско вријеме (Гибралтар)',
        'Europe/Guernsey' => 'Гриничко средње вријеме (Гернзи)',
        'Europe/Helsinki' => 'Источноевропско вријеме (Хелсинки)',
        'Europe/Isle_of_Man' => 'Гриничко средње вријеме (Острво Мен)',
        'Europe/Istanbul' => 'Време: Турска (Истанбул)',
        'Europe/Jersey' => 'Гриничко средње вријеме (Џерси)',
        'Europe/Kaliningrad' => 'Источноевропско вријеме (Калињинград)',
        'Europe/Kiev' => 'Источноевропско вријеме (Кијев)',
        'Europe/Kirov' => 'Време: Русија (Киров)',
        'Europe/Lisbon' => 'Западноевропско вријеме (Лисабон)',
        'Europe/Ljubljana' => 'Средњеевропско вријеме (Љубљана)',
        'Europe/London' => 'Гриничко средње вријеме (Лондон)',
        'Europe/Luxembourg' => 'Средњеевропско вријеме (Луксембург)',
        'Europe/Madrid' => 'Средњеевропско вријеме (Мадрид)',
        'Europe/Malta' => 'Средњеевропско вријеме (Малта)',
        'Europe/Mariehamn' => 'Источноевропско вријеме (Марихамн)',
        'Europe/Minsk' => 'Москва вријеме (Минск)',
        'Europe/Monaco' => 'Средњеевропско вријеме (Монако)',
        'Europe/Moscow' => 'Москва вријеме',
        'Europe/Oslo' => 'Средњеевропско вријеме (Осло)',
        'Europe/Paris' => 'Средњеевропско вријеме (Париз)',
        'Europe/Podgorica' => 'Средњеевропско вријеме (Подгорица)',
        'Europe/Prague' => 'Средњеевропско вријеме (Праг)',
        'Europe/Riga' => 'Источноевропско вријеме (Рига)',
        'Europe/Rome' => 'Средњеевропско вријеме (Рим)',
        'Europe/Samara' => 'Самара време',
        'Europe/San_Marino' => 'Средњеевропско вријеме (Сан Марино)',
        'Europe/Sarajevo' => 'Средњеевропско вријеме (Сарајево)',
        'Europe/Saratov' => 'Москва вријеме (Саратов)',
        'Europe/Simferopol' => 'Москва вријеме (Симферопољ)',
        'Europe/Skopje' => 'Средњеевропско вријеме (Скопље)',
        'Europe/Sofia' => 'Источноевропско вријеме (Софија)',
        'Europe/Stockholm' => 'Средњеевропско вријеме (Стокхолм)',
        'Europe/Tallinn' => 'Источноевропско вријеме (Талин)',
        'Europe/Tirane' => 'Средњеевропско вријеме (Тирана)',
        'Europe/Ulyanovsk' => 'Москва вријеме (Уљановск)',
        'Europe/Uzhgorod' => 'Источноевропско вријеме (Ужгород)',
        'Europe/Vaduz' => 'Средњеевропско вријеме (Вадуз)',
        'Europe/Vatican' => 'Средњеевропско вријеме (Ватикан)',
        'Europe/Vienna' => 'Средњеевропско вријеме (Беч)',
        'Europe/Vilnius' => 'Источноевропско вријеме (Виљнус)',
        'Europe/Volgograd' => 'Волгоград вријеме',
        'Europe/Warsaw' => 'Средњеевропско вријеме (Варшава)',
        'Europe/Zagreb' => 'Средњеевропско вријеме (Загреб)',
        'Europe/Zaporozhye' => 'Источноевропско вријеме (Запорожје)',
        'Europe/Zurich' => 'Средњеевропско вријеме (Цирих)',
        'Indian/Antananarivo' => 'Источно-афричко вријеме (Антананариво)',
        'Indian/Chagos' => 'Индијско океанско вријеме (Чагос)',
        'Indian/Christmas' => 'Божићна острва вријеме',
        'Indian/Cocos' => 'Кокос (Келинг) Острва вријеме',
        'Indian/Comoro' => 'Источно-афричко вријеме (Коморо)',
        'Indian/Kerguelen' => 'Француско јужно и антарктичко вријеме (Кергелен)',
        'Indian/Mahe' => 'Сејшели вријеме (Махе)',
        'Indian/Maldives' => 'Малдиви вријеме',
        'Indian/Mauritius' => 'Маурицијус вријеме',
        'Indian/Mayotte' => 'Источно-афричко вријеме (Мајот)',
        'Indian/Reunion' => 'Реинион вријеме (Реунион)',
        'MST7MDT' => 'Планинско вријеме',
        'PST8PDT' => 'Пацифичко вријеме',
        'Pacific/Apia' => 'Апија вријеме',
        'Pacific/Auckland' => 'Нови Зеланд вријеме (Окланд)',
        'Pacific/Bougainville' => 'Папуа Нова Гвинеја вријеме (Бугенвил)',
        'Pacific/Chatham' => 'Чатам вријеме (Катхам)',
        'Pacific/Easter' => 'Ускршња острва вријеме (Ускршње острво)',
        'Pacific/Efate' => 'Вануату вријеме (Ефат)',
        'Pacific/Enderbury' => 'Феникс острва вријеме (Ендербери)',
        'Pacific/Fakaofo' => 'Токелау вријеме (Факаофо)',
        'Pacific/Fiji' => 'Фиџи вријеме',
        'Pacific/Funafuti' => 'Тувалу вријеме (Фунафути)',
        'Pacific/Galapagos' => 'Галапагос вријеме',
        'Pacific/Gambier' => 'Гамбијер вријеме',
        'Pacific/Guadalcanal' => 'Соломонска Острва вријеме (Гвадалканал)',
        'Pacific/Guam' => 'Чаморо вријеме (Гуам)',
        'Pacific/Honolulu' => 'Хавајско-алеутско вријеме (Хонолулу)',
        'Pacific/Johnston' => 'Хавајско-алеутско вријеме (Џонстон)',
        'Pacific/Kiritimati' => 'Лине Острва вријеме (Киритимати)',
        'Pacific/Kosrae' => 'Кошре вријеме',
        'Pacific/Kwajalein' => 'Маршалска Острва вријеме (Кваџалејин)',
        'Pacific/Majuro' => 'Маршалска Острва вријеме (Мајуро)',
        'Pacific/Marquesas' => 'Маркиз вријеме',
        'Pacific/Midway' => 'Самоа вријеме (Мидвеј)',
        'Pacific/Nauru' => 'Науру вријеме',
        'Pacific/Niue' => 'Ниуе вријеме',
        'Pacific/Norfolk' => 'Норфолк Острво вријеме',
        'Pacific/Noumea' => 'Нова Каледонија вријеме (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа вријеме (Паго Паго)',
        'Pacific/Palau' => 'Палау вријеме',
        'Pacific/Pitcairn' => 'Питкерн вријеме',
        'Pacific/Ponape' => 'Понапе вријеме',
        'Pacific/Port_Moresby' => 'Папуа Нова Гвинеја вријеме (Порт Морзби)',
        'Pacific/Rarotonga' => 'Кукова острва вријеме (Раротонга)',
        'Pacific/Saipan' => 'Чаморо вријеме (Сајпан)',
        'Pacific/Tahiti' => 'Тахити вријеме',
        'Pacific/Tarawa' => 'Гилберт острва вријеме (Тарава)',
        'Pacific/Tongatapu' => 'Тонга вријеме (Тонгатапу)',
        'Pacific/Truk' => 'Трук вријеме',
        'Pacific/Wake' => 'Вејк острво вријеме',
        'Pacific/Wallis' => 'Валис и Футуна Острва вријеме',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT%s',
    ],
];
