<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Средно гринуичко време (Абиджан)',
        'Africa/Accra' => 'Средно гринуичко време (Акра)',
        'Africa/Addis_Ababa' => 'Източноафриканско време (Адис Абеба)',
        'Africa/Algiers' => 'Централноевропейско време (Алжир)',
        'Africa/Asmera' => 'Източноафриканско време (Асмара)',
        'Africa/Bamako' => 'Средно гринуичко време (Бамако)',
        'Africa/Bangui' => 'Западноафриканско време (Бангуи)',
        'Africa/Banjul' => 'Средно гринуичко време (Банджул)',
        'Africa/Bissau' => 'Средно гринуичко време (Бисау)',
        'Africa/Blantyre' => 'Централноафриканско време (Блантайър)',
        'Africa/Brazzaville' => 'Западноафриканско време (Бразавил)',
        'Africa/Bujumbura' => 'Централноафриканско време (Бужумбура)',
        'Africa/Cairo' => 'Източноевропейско време (Кайро)',
        'Africa/Casablanca' => 'Западноевропейско време (Казабланка)',
        'Africa/Ceuta' => 'Централноевропейско време (Сеута)',
        'Africa/Conakry' => 'Средно гринуичко време (Конакри)',
        'Africa/Dakar' => 'Средно гринуичко време (Дакар)',
        'Africa/Dar_es_Salaam' => 'Източноафриканско време (Дар ес Салам)',
        'Africa/Djibouti' => 'Източноафриканско време (Джибути)',
        'Africa/Douala' => 'Западноафриканско време (Дуала)',
        'Africa/El_Aaiun' => 'Западноевропейско време (Ел Аюн)',
        'Africa/Freetown' => 'Средно гринуичко време (Фрийтаун)',
        'Africa/Gaborone' => 'Централноафриканско време (Габороне)',
        'Africa/Harare' => 'Централноафриканско време (Хараре)',
        'Africa/Johannesburg' => 'Южноафриканско време (Йоханесбург)',
        'Africa/Juba' => 'Централноафриканско време (Джуба)',
        'Africa/Kampala' => 'Източноафриканско време (Кампала)',
        'Africa/Khartoum' => 'Централноафриканско време (Хартум)',
        'Africa/Kigali' => 'Централноафриканско време (Кигали)',
        'Africa/Kinshasa' => 'Западноафриканско време (Киншаса)',
        'Africa/Lagos' => 'Западноафриканско време (Лагос)',
        'Africa/Libreville' => 'Западноафриканско време (Либревил)',
        'Africa/Lome' => 'Средно гринуичко време (Ломе)',
        'Africa/Luanda' => 'Западноафриканско време (Луанда)',
        'Africa/Lubumbashi' => 'Централноафриканско време (Лубумбаши)',
        'Africa/Lusaka' => 'Централноафриканско време (Лусака)',
        'Africa/Malabo' => 'Западноафриканско време (Малабо)',
        'Africa/Maputo' => 'Централноафриканско време (Мапуто)',
        'Africa/Maseru' => 'Южноафриканско време (Масеру)',
        'Africa/Mbabane' => 'Южноафриканско време (Мбабане)',
        'Africa/Mogadishu' => 'Източноафриканско време (Могадишу)',
        'Africa/Monrovia' => 'Средно гринуичко време (Монровия)',
        'Africa/Nairobi' => 'Източноафриканско време (Найроби)',
        'Africa/Ndjamena' => 'Западноафриканско време (Нджамена)',
        'Africa/Niamey' => 'Западноафриканско време (Ниамей)',
        'Africa/Nouakchott' => 'Средно гринуичко време (Нуакшот)',
        'Africa/Ouagadougou' => 'Средно гринуичко време (Уагадугу)',
        'Africa/Porto-Novo' => 'Западноафриканско време (Порто Ново)',
        'Africa/Sao_Tome' => 'Средно гринуичко време (Сао Томе)',
        'Africa/Tripoli' => 'Източноевропейско време (Триполи)',
        'Africa/Tunis' => 'Централноевропейско време (Тунис)',
        'Africa/Windhoek' => 'Централноафриканско време (Виндхук)',
        'America/Adak' => 'Хавайско-алеутско време (Адак)',
        'America/Anchorage' => 'Аляска (Анкъридж)',
        'America/Anguilla' => 'Северноамериканско атлантическо време (Ангуила)',
        'America/Antigua' => 'Северноамериканско атлантическо време (Антигуа)',
        'America/Araguaina' => 'Бразилско време (Арагуайна)',
        'America/Argentina/La_Rioja' => 'Аржентинско време (Ла Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аржентинско време (Рио Галегос)',
        'America/Argentina/Salta' => 'Аржентинско време (Салта)',
        'America/Argentina/San_Juan' => 'Аржентинско време (Сан Хуан)',
        'America/Argentina/San_Luis' => 'Аржентинско време (Сан Луис)',
        'America/Argentina/Tucuman' => 'Аржентинско време (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аржентинско време (Ушуая)',
        'America/Aruba' => 'Северноамериканско атлантическо време (Аруба)',
        'America/Asuncion' => 'Парагвайско време (Асунсион)',
        'America/Bahia' => 'Бразилско време (Баия)',
        'America/Bahia_Banderas' => 'Северноамериканско централно време (Баия де Бандерас)',
        'America/Barbados' => 'Северноамериканско атлантическо време (Барбадос)',
        'America/Belem' => 'Бразилско време (Белем)',
        'America/Belize' => 'Северноамериканско централно време (Белиз)',
        'America/Blanc-Sablon' => 'Северноамериканско атлантическо време (Блан-Саблон)',
        'America/Boa_Vista' => 'Амазонско време (Боа Виста)',
        'America/Bogota' => 'Колумбийско време (Богота)',
        'America/Boise' => 'Северноамериканско планинско време (Бойси)',
        'America/Buenos_Aires' => 'Аржентинско време (Буенос Айрес)',
        'America/Cambridge_Bay' => 'Северноамериканско планинско време (Кеймбридж Бей)',
        'America/Campo_Grande' => 'Амазонско време (Кампо Гранде)',
        'America/Cancun' => 'Северноамериканско източно време (Канкун)',
        'America/Caracas' => 'Венецуелско време (Каракас)',
        'America/Catamarca' => 'Аржентинско време (Катамарка)',
        'America/Cayenne' => 'Френска Гвиана (Кайен)',
        'America/Cayman' => 'Северноамериканско източно време (Кайманови острови)',
        'America/Chicago' => 'Северноамериканско централно време (Чикаго)',
        'America/Chihuahua' => 'Мексиканско тихоокеанско време (Чиуауа)',
        'America/Coral_Harbour' => 'Северноамериканско източно време (Атикокан)',
        'America/Cordoba' => 'Аржентинско време (Кордоба)',
        'America/Costa_Rica' => 'Северноамериканско централно време (Коста Рика)',
        'America/Creston' => 'Северноамериканско планинско време (Крестън)',
        'America/Cuiaba' => 'Амазонско време (Чуяба)',
        'America/Curacao' => 'Северноамериканско атлантическо време (Кюрасао)',
        'America/Danmarkshavn' => 'Средно гринуичко време (Данмарксхавн)',
        'America/Dawson' => 'Юкон (Доусън)',
        'America/Dawson_Creek' => 'Северноамериканско планинско време (Доусън Крийк)',
        'America/Denver' => 'Северноамериканско планинско време (Денвър)',
        'America/Detroit' => 'Северноамериканско източно време (Детройт)',
        'America/Dominica' => 'Северноамериканско атлантическо време (Доминика)',
        'America/Edmonton' => 'Северноамериканско планинско време (Едмънтън)',
        'America/Eirunepe' => 'Бразилия (Ейрунепе)',
        'America/El_Salvador' => 'Северноамериканско централно време (Салвадор)',
        'America/Fort_Nelson' => 'Северноамериканско планинско време (Форт Нелсън)',
        'America/Fortaleza' => 'Бразилско време (Форталеза)',
        'America/Glace_Bay' => 'Северноамериканско атлантическо време (Глейс Бей)',
        'America/Godthab' => 'Западногренландско време (Нуук)',
        'America/Goose_Bay' => 'Северноамериканско атлантическо време (Гус Бей)',
        'America/Grand_Turk' => 'Северноамериканско източно време (Гранд Търк)',
        'America/Grenada' => 'Северноамериканско атлантическо време (Гренада)',
        'America/Guadeloupe' => 'Северноамериканско атлантическо време (Гваделупа)',
        'America/Guatemala' => 'Северноамериканско централно време (Гватемала)',
        'America/Guayaquil' => 'Еквадорско време (Гуаякил)',
        'America/Guyana' => 'Гаяна',
        'America/Halifax' => 'Северноамериканско атлантическо време (Халифакс)',
        'America/Havana' => 'Кубинско време (Хавана)',
        'America/Hermosillo' => 'Мексиканско тихоокеанско време (Ермосильо)',
        'America/Indiana/Knox' => 'Северноамериканско централно време (Нокс)',
        'America/Indiana/Marengo' => 'Северноамериканско източно време (Маренго)',
        'America/Indiana/Petersburg' => 'Северноамериканско източно време (Питърсбърг)',
        'America/Indiana/Tell_City' => 'Северноамериканско централно време (Тел Сити)',
        'America/Indiana/Vevay' => 'Северноамериканско източно време (Виви)',
        'America/Indiana/Vincennes' => 'Северноамериканско източно време (Винсенс)',
        'America/Indiana/Winamac' => 'Северноамериканско източно време (Уинамак)',
        'America/Indianapolis' => 'Северноамериканско източно време (Индианаполис)',
        'America/Inuvik' => 'Северноамериканско планинско време (Инувик)',
        'America/Iqaluit' => 'Северноамериканско източно време (Иквалуит)',
        'America/Jamaica' => 'Северноамериканско източно време (Ямайка)',
        'America/Jujuy' => 'Аржентинско време (Хухуй)',
        'America/Juneau' => 'Аляска (Джуно)',
        'America/Kentucky/Monticello' => 'Северноамериканско източно време (Монтичело)',
        'America/Kralendijk' => 'Северноамериканско атлантическо време (Кралендейк)',
        'America/La_Paz' => 'Боливийско време (Ла Пас)',
        'America/Lima' => 'Перуанско време (Лима)',
        'America/Los_Angeles' => 'Северноамериканско тихоокеанско време (Лос Анджелис)',
        'America/Louisville' => 'Северноамериканско източно време (Луисвил)',
        'America/Lower_Princes' => 'Северноамериканско атлантическо време (Лоуър принсес куотър)',
        'America/Maceio' => 'Бразилско време (Масейо)',
        'America/Managua' => 'Северноамериканско централно време (Манагуа)',
        'America/Manaus' => 'Амазонско време (Манаус)',
        'America/Marigot' => 'Северноамериканско атлантическо време (Мариго)',
        'America/Martinique' => 'Северноамериканско атлантическо време (Мартиника)',
        'America/Matamoros' => 'Северноамериканско централно време (Матаморос)',
        'America/Mazatlan' => 'Мексиканско тихоокеанско време (Масатлан)',
        'America/Mendoza' => 'Аржентинско време (Мендоса)',
        'America/Menominee' => 'Северноамериканско централно време (Меномини)',
        'America/Merida' => 'Северноамериканско централно време (Мерида)',
        'America/Metlakatla' => 'Аляска (Метлакатла)',
        'America/Mexico_City' => 'Северноамериканско централно време (Мексико Сити)',
        'America/Miquelon' => 'Сен Пиер и Микелон',
        'America/Moncton' => 'Северноамериканско атлантическо време (Монктон)',
        'America/Monterrey' => 'Северноамериканско централно време (Монтерей)',
        'America/Montevideo' => 'Уругвайско време (Монтевидео)',
        'America/Montreal' => 'Канада (Montreal)',
        'America/Montserrat' => 'Северноамериканско атлантическо време (Монтсерат)',
        'America/Nassau' => 'Северноамериканско източно време (Насау)',
        'America/New_York' => 'Северноамериканско източно време (Ню Йорк)',
        'America/Nipigon' => 'Северноамериканско източно време (Нипигон)',
        'America/Nome' => 'Аляска (Ноум)',
        'America/Noronha' => 'Фернандо де Нороня',
        'America/North_Dakota/Beulah' => 'Северноамериканско централно време (Бюла)',
        'America/North_Dakota/Center' => 'Северноамериканско централно време (Сентър)',
        'America/North_Dakota/New_Salem' => 'Северноамериканско централно време (Ню Сейлъм)',
        'America/Ojinaga' => 'Северноамериканско планинско време (Охинага)',
        'America/Panama' => 'Северноамериканско източно време (Панама)',
        'America/Pangnirtung' => 'Северноамериканско източно време (Пангниртунг)',
        'America/Paramaribo' => 'Суринамско време (Парамарибо)',
        'America/Phoenix' => 'Северноамериканско планинско време (Финикс)',
        'America/Port-au-Prince' => 'Северноамериканско източно време (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Северноамериканско атлантическо време (Порт ъф Спейн)',
        'America/Porto_Velho' => 'Амазонско време (Порто Вельо)',
        'America/Puerto_Rico' => 'Северноамериканско атлантическо време (Пуерто Рико)',
        'America/Punta_Arenas' => 'Чилийско време (Пунта Аренас)',
        'America/Rainy_River' => 'Северноамериканско централно време (Рейни Ривър)',
        'America/Rankin_Inlet' => 'Северноамериканско централно време (Ранкин Инлет)',
        'America/Recife' => 'Бразилско време (Ресифе)',
        'America/Regina' => 'Северноамериканско централно време (Риджайна)',
        'America/Resolute' => 'Северноамериканско централно време (Резолют)',
        'America/Rio_Branco' => 'Бразилия (Рио Бранко)',
        'America/Santa_Isabel' => 'Северозападно мексиканско време (Санта Исабел)',
        'America/Santarem' => 'Бразилско време (Сантарем)',
        'America/Santiago' => 'Чилийско време (Сантяго)',
        'America/Santo_Domingo' => 'Северноамериканско атлантическо време (Санто Доминго)',
        'America/Sao_Paulo' => 'Бразилско време (Сао Пауло)',
        'America/Scoresbysund' => 'Източногренландско време (Сгорсбисон)',
        'America/Sitka' => 'Аляска (Ситка)',
        'America/St_Barthelemy' => 'Северноамериканско атлантическо време (Сен Бартелеми)',
        'America/St_Johns' => 'Нюфаундлендско време (Сейнт Джонс)',
        'America/St_Kitts' => 'Северноамериканско атлантическо време (Сейнт Китс)',
        'America/St_Lucia' => 'Северноамериканско атлантическо време (Сейнт Лусия)',
        'America/St_Thomas' => 'Северноамериканско атлантическо време (Сейнт Томас)',
        'America/St_Vincent' => 'Северноамериканско атлантическо време (Сейнт Винсънт)',
        'America/Swift_Current' => 'Северноамериканско централно време (Суифт Кърент)',
        'America/Tegucigalpa' => 'Северноамериканско централно време (Тегусигалпа)',
        'America/Thule' => 'Северноамериканско атлантическо време (Туле)',
        'America/Thunder_Bay' => 'Северноамериканско източно време (Тъндър Бей)',
        'America/Tijuana' => 'Северноамериканско тихоокеанско време (Тихуана)',
        'America/Toronto' => 'Северноамериканско източно време (Торонто)',
        'America/Tortola' => 'Северноамериканско атлантическо време (Тортола)',
        'America/Vancouver' => 'Северноамериканско тихоокеанско време (Ванкувър)',
        'America/Whitehorse' => 'Юкон (Уайтхорс)',
        'America/Winnipeg' => 'Северноамериканско централно време (Уинипег)',
        'America/Yakutat' => 'Аляска (Якутат)',
        'America/Yellowknife' => 'Северноамериканско планинско време (Йелоунайф)',
        'Antarctica/Casey' => 'Антарктика (Кейси)',
        'Antarctica/Davis' => 'Дейвис',
        'Antarctica/DumontDUrville' => 'Дюмон Дюрвил',
        'Antarctica/Macquarie' => 'Източноавстралийско време (Маккуори)',
        'Antarctica/Mawson' => 'Моусън',
        'Antarctica/McMurdo' => 'Новозеландско време (Макмърдо)',
        'Antarctica/Palmer' => 'Чилийско време (Палмър)',
        'Antarctica/Rothera' => 'Ротера',
        'Antarctica/Syowa' => 'Шова',
        'Antarctica/Troll' => 'Средно гринуичко време (Трол)',
        'Antarctica/Vostok' => 'Восток',
        'Arctic/Longyearbyen' => 'Централноевропейско време (Лонгирбюен)',
        'Asia/Aden' => 'Арабско време (Аден)',
        'Asia/Almaty' => 'Източноказахстанско време (Алмати)',
        'Asia/Amman' => 'Източноевропейско време (Аман)',
        'Asia/Anadyr' => 'Анадир време',
        'Asia/Aqtau' => 'Западноказахстанско време (Актау)',
        'Asia/Aqtobe' => 'Западноказахстанско време (Актобе)',
        'Asia/Ashgabat' => 'Туркменистанско време (Ашхабад)',
        'Asia/Atyrau' => 'Западноказахстанско време (Атърау)',
        'Asia/Baghdad' => 'Арабско време (Багдад)',
        'Asia/Bahrain' => 'Арабско време (Бахрейн)',
        'Asia/Baku' => 'Азербайджанско време (Баку)',
        'Asia/Bangkok' => 'Индокитайско време (Банкок)',
        'Asia/Barnaul' => 'Русия (Барнаул)',
        'Asia/Beirut' => 'Източноевропейско време (Бейрут)',
        'Asia/Bishkek' => 'Киргизстанско време (Бишкек)',
        'Asia/Brunei' => 'Бруней Даруссалам',
        'Asia/Calcutta' => 'Индийско време (Колката)',
        'Asia/Chita' => 'Якутско време (Чита)',
        'Asia/Choibalsan' => 'Уланбаторско време (Чойбалсан)',
        'Asia/Colombo' => 'Индийско време (Коломбо)',
        'Asia/Damascus' => 'Източноевропейско време (Дамаск)',
        'Asia/Dhaka' => 'Бангладешко време (Дака)',
        'Asia/Dili' => 'Източнотиморско време (Дили)',
        'Asia/Dubai' => 'Персийски залив (Дубай)',
        'Asia/Dushanbe' => 'Таджикистанско време (Душанбе)',
        'Asia/Famagusta' => 'Източноевропейско време (Фамагуста)',
        'Asia/Gaza' => 'Източноевропейско време (Газа)',
        'Asia/Hebron' => 'Източноевропейско време (Хеброн)',
        'Asia/Hong_Kong' => 'Хонконгско време',
        'Asia/Hovd' => 'Ховдско време',
        'Asia/Irkutsk' => 'Иркутско време',
        'Asia/Jakarta' => 'Западноиндонезийско време (Джакарта)',
        'Asia/Jayapura' => 'Източноиндонезийско време (Джаяпура)',
        'Asia/Jerusalem' => 'Израелско време (Йерусалим)',
        'Asia/Kabul' => 'Афганистанско време (Кабул)',
        'Asia/Kamchatka' => 'Петропавловск-Камчатски време (Камчатка)',
        'Asia/Karachi' => 'Пакистанско време (Карачи)',
        'Asia/Katmandu' => 'Непалско време (Катманду)',
        'Asia/Khandyga' => 'Якутско време (Хандига)',
        'Asia/Krasnoyarsk' => 'Красноярско време',
        'Asia/Kuala_Lumpur' => 'Малайзийско време (Куала Лумпур)',
        'Asia/Kuching' => 'Малайзийско време (Кучин)',
        'Asia/Kuwait' => 'Арабско време (Кувейт)',
        'Asia/Macau' => 'Китайско време (Макао)',
        'Asia/Magadan' => 'Магаданско време',
        'Asia/Makassar' => 'Централноиндонезийско време (Макасар)',
        'Asia/Manila' => 'Филипинско време (Манила)',
        'Asia/Muscat' => 'Персийски залив (Мускат)',
        'Asia/Nicosia' => 'Източноевропейско време (Никозия)',
        'Asia/Novokuznetsk' => 'Красноярско време (Новокузнецк)',
        'Asia/Novosibirsk' => 'Новосибирско време',
        'Asia/Omsk' => 'Омско време',
        'Asia/Oral' => 'Западноказахстанско време (Арал)',
        'Asia/Phnom_Penh' => 'Индокитайско време (Пном Пен)',
        'Asia/Pontianak' => 'Западноиндонезийско време (Понтианак)',
        'Asia/Pyongyang' => 'Корейско време (Пхенян)',
        'Asia/Qatar' => 'Арабско време (Катар)',
        'Asia/Qostanay' => 'Източноказахстанско време (Костанай)',
        'Asia/Qyzylorda' => 'Западноказахстанско време (Къзълорда)',
        'Asia/Rangoon' => 'Мианмарско време (Рангун)',
        'Asia/Riyadh' => 'Арабско време (Рияд)',
        'Asia/Saigon' => 'Индокитайско време (Хошимин)',
        'Asia/Sakhalin' => 'Сахалинско време',
        'Asia/Samarkand' => 'Узбекистанско време (Самарканд)',
        'Asia/Seoul' => 'Корейско време (Сеул)',
        'Asia/Shanghai' => 'Китайско време (Шанхай)',
        'Asia/Singapore' => 'Сингапурско време',
        'Asia/Srednekolymsk' => 'Магаданско време (Среднеколимск)',
        'Asia/Taipei' => 'Тайпе',
        'Asia/Tashkent' => 'Узбекистанско време (Ташкент)',
        'Asia/Tbilisi' => 'Грузинско време (Тбилиси)',
        'Asia/Tehran' => 'Иранско време (Техеран)',
        'Asia/Thimphu' => 'Бутанско време (Тхимпху)',
        'Asia/Tokyo' => 'Японско време (Токио)',
        'Asia/Tomsk' => 'Русия (Томск)',
        'Asia/Ulaanbaatar' => 'Уланбаторско време (Улан Батор)',
        'Asia/Urumqi' => 'Китай (Урумчи)',
        'Asia/Ust-Nera' => 'Владивостокско време (Уст-Нера)',
        'Asia/Vientiane' => 'Индокитайско време (Виентян)',
        'Asia/Vladivostok' => 'Владивостокско време',
        'Asia/Yakutsk' => 'Якутско време',
        'Asia/Yekaterinburg' => 'Екатеринбургско време',
        'Asia/Yerevan' => 'Арменско време (Ереван)',
        'Atlantic/Azores' => 'Азорски острови',
        'Atlantic/Bermuda' => 'Северноамериканско атлантическо време (Бермудски острови)',
        'Atlantic/Canary' => 'Западноевропейско време (Канарски острови)',
        'Atlantic/Cape_Verde' => 'Кабо Верде',
        'Atlantic/Faeroe' => 'Западноевропейско време (Фарьорски острови)',
        'Atlantic/Madeira' => 'Западноевропейско време (Мадейра)',
        'Atlantic/Reykjavik' => 'Средно гринуичко време (Рейкявик)',
        'Atlantic/South_Georgia' => 'Южна Джорджия',
        'Atlantic/St_Helena' => 'Средно гринуичко време (Света Елена)',
        'Atlantic/Stanley' => 'Фолклендски острови (Стенли)',
        'Australia/Adelaide' => 'Централноавстралийско време (Аделаида)',
        'Australia/Brisbane' => 'Източноавстралийско време (Бризбейн)',
        'Australia/Broken_Hill' => 'Централноавстралийско време (Броукън Хил)',
        'Australia/Currie' => 'Източноавстралийско време (Къри)',
        'Australia/Darwin' => 'Централноавстралийско време (Дарвин)',
        'Australia/Eucla' => 'Австралия – западно централно време (Юкла)',
        'Australia/Hobart' => 'Източноавстралийско време (Хобарт)',
        'Australia/Lindeman' => 'Източноавстралийско време (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд Хау',
        'Australia/Melbourne' => 'Източноавстралийско време (Мелбърн)',
        'Australia/Perth' => 'Западноавстралийско време (Пърт)',
        'Australia/Sydney' => 'Източноавстралийско време (Сидни)',
        'CST6CDT' => 'Северноамериканско централно време',
        'EST5EDT' => 'Северноамериканско източно време',
        'Etc/GMT' => 'Средно гринуичко време',
        'Etc/UTC' => 'Координирано универсално време',
        'Europe/Amsterdam' => 'Централноевропейско време (Амстердам)',
        'Europe/Andorra' => 'Централноевропейско време (Андора)',
        'Europe/Astrakhan' => 'Московско време (Астрахан)',
        'Europe/Athens' => 'Източноевропейско време (Атина)',
        'Europe/Belgrade' => 'Централноевропейско време (Белград)',
        'Europe/Berlin' => 'Централноевропейско време (Берлин)',
        'Europe/Bratislava' => 'Централноевропейско време (Братислава)',
        'Europe/Brussels' => 'Централноевропейско време (Брюксел)',
        'Europe/Bucharest' => 'Източноевропейско време (Букурещ)',
        'Europe/Budapest' => 'Централноевропейско време (Будапеща)',
        'Europe/Busingen' => 'Централноевропейско време (Бюзинген)',
        'Europe/Chisinau' => 'Източноевропейско време (Кишинев)',
        'Europe/Copenhagen' => 'Централноевропейско време (Копенхаген)',
        'Europe/Dublin' => 'Средно гринуичко време (Дъблин)',
        'Europe/Gibraltar' => 'Централноевропейско време (Гибралтар)',
        'Europe/Guernsey' => 'Средно гринуичко време (Гърнзи)',
        'Europe/Helsinki' => 'Източноевропейско време (Хелзинки)',
        'Europe/Isle_of_Man' => 'Средно гринуичко време (остров Ман)',
        'Europe/Istanbul' => 'Турция (Истанбул)',
        'Europe/Jersey' => 'Средно гринуичко време (Джърси)',
        'Europe/Kaliningrad' => 'Източноевропейско време (Калининград)',
        'Europe/Kiev' => 'Източноевропейско време (Киев)',
        'Europe/Kirov' => 'Русия (Киров)',
        'Europe/Lisbon' => 'Западноевропейско време (Лисабон)',
        'Europe/Ljubljana' => 'Централноевропейско време (Любляна)',
        'Europe/London' => 'Средно гринуичко време (Лондон)',
        'Europe/Luxembourg' => 'Централноевропейско време (Люксембург)',
        'Europe/Madrid' => 'Централноевропейско време (Мадрид)',
        'Europe/Malta' => 'Централноевропейско време (Малта)',
        'Europe/Mariehamn' => 'Източноевропейско време (Мариехамн)',
        'Europe/Minsk' => 'Московско време (Минск)',
        'Europe/Monaco' => 'Централноевропейско време (Монако)',
        'Europe/Moscow' => 'Московско време (Москва)',
        'Europe/Oslo' => 'Централноевропейско време (Осло)',
        'Europe/Paris' => 'Централноевропейско време (Париж)',
        'Europe/Podgorica' => 'Централноевропейско време (Подгорица)',
        'Europe/Prague' => 'Централноевропейско време (Прага)',
        'Europe/Riga' => 'Източноевропейско време (Рига)',
        'Europe/Rome' => 'Централноевропейско време (Рим)',
        'Europe/Samara' => 'Самара време',
        'Europe/San_Marino' => 'Централноевропейско време (Сан Марино)',
        'Europe/Sarajevo' => 'Централноевропейско време (Сараево)',
        'Europe/Saratov' => 'Московско време (Саратов)',
        'Europe/Simferopol' => 'Московско време (Симферопол)',
        'Europe/Skopje' => 'Централноевропейско време (Скопие)',
        'Europe/Sofia' => 'Източноевропейско време (София)',
        'Europe/Stockholm' => 'Централноевропейско време (Стокхолм)',
        'Europe/Tallinn' => 'Източноевропейско време (Талин)',
        'Europe/Tirane' => 'Централноевропейско време (Тирана)',
        'Europe/Ulyanovsk' => 'Московско време (Уляновск)',
        'Europe/Uzhgorod' => 'Източноевропейско време (Ужгород)',
        'Europe/Vaduz' => 'Централноевропейско време (Вадуц)',
        'Europe/Vatican' => 'Централноевропейско време (Ватикан)',
        'Europe/Vienna' => 'Централноевропейско време (Виена)',
        'Europe/Vilnius' => 'Източноевропейско време (Вилнюс)',
        'Europe/Volgograd' => 'Волгоградско време',
        'Europe/Warsaw' => 'Централноевропейско време (Варшава)',
        'Europe/Zagreb' => 'Централноевропейско време (Загреб)',
        'Europe/Zaporozhye' => 'Източноевропейско време (Запорожие)',
        'Europe/Zurich' => 'Централноевропейско време (Цюрих)',
        'Indian/Antananarivo' => 'Източноафриканско време (Антананариво)',
        'Indian/Chagos' => 'Индийски океан (Чагос)',
        'Indian/Christmas' => 'Остров Рождество',
        'Indian/Cocos' => 'Кокосови острови',
        'Indian/Comoro' => 'Източноафриканско време (Коморски острови)',
        'Indian/Kerguelen' => 'Френски южни и антарктически територии (Кергелен)',
        'Indian/Mahe' => 'Сейшели (Мае)',
        'Indian/Maldives' => 'Малдивско време (Малдиви)',
        'Indian/Mauritius' => 'Мавриций',
        'Indian/Mayotte' => 'Източноафриканско време (Майот)',
        'Indian/Reunion' => 'Реюнион',
        'MST7MDT' => 'Северноамериканско планинско време',
        'PST8PDT' => 'Северноамериканско тихоокеанско време',
        'Pacific/Apia' => 'Апия',
        'Pacific/Auckland' => 'Новозеландско време (Окланд)',
        'Pacific/Bougainville' => 'Папуа Нова Гвинея (Бугенвил)',
        'Pacific/Chatham' => 'Чатъмско време (Чатам)',
        'Pacific/Easter' => 'Великденски остров',
        'Pacific/Efate' => 'Вануату (Ефате)',
        'Pacific/Enderbury' => 'Острови Феникс (Ендърбъри)',
        'Pacific/Fakaofo' => 'Токелау (Факаофо)',
        'Pacific/Fiji' => 'Фиджийско време',
        'Pacific/Funafuti' => 'Тувалу (Фунафути)',
        'Pacific/Galapagos' => 'Галапагоско време',
        'Pacific/Gambier' => 'Гамбие',
        'Pacific/Guadalcanal' => 'Соломонови острови (Гуадалканал)',
        'Pacific/Guam' => 'Чаморско време (Гуам)',
        'Pacific/Honolulu' => 'Хавайско-алеутско време (Хонолулу)',
        'Pacific/Johnston' => 'Хавайско-алеутско време (Джонстън)',
        'Pacific/Kiritimati' => 'Екваториални острови (Киритимати)',
        'Pacific/Kosrae' => 'Кошрай',
        'Pacific/Kwajalein' => 'Маршалови острови (Куаджалин)',
        'Pacific/Majuro' => 'Маршалови острови (Маджуро)',
        'Pacific/Marquesas' => 'Маркизки острови',
        'Pacific/Midway' => 'Самоанско време (Мидуей)',
        'Pacific/Nauru' => 'Науру',
        'Pacific/Niue' => 'Ниуе',
        'Pacific/Norfolk' => 'Норфолкско време',
        'Pacific/Noumea' => 'Новокаледонско време (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоанско време (Паго Паго)',
        'Pacific/Palau' => 'Палау',
        'Pacific/Pitcairn' => 'Питкерн',
        'Pacific/Ponape' => 'Понапе (Понпей)',
        'Pacific/Port_Moresby' => 'Папуа Нова Гвинея (Порт Морсби)',
        'Pacific/Rarotonga' => 'Острови Кук (Раротонга)',
        'Pacific/Saipan' => 'Чаморско време (Сайпан)',
        'Pacific/Tahiti' => 'Таитянско време (Таити)',
        'Pacific/Tarawa' => 'Острови Гилбърт (Тарауа)',
        'Pacific/Tongatapu' => 'Тонга (Тонгатапу)',
        'Pacific/Truk' => 'Чуюк',
        'Pacific/Wake' => 'Остров Уейк',
        'Pacific/Wallis' => 'Уолис и Футуна',
    ],
    'Meta' => [
        'GmtFormat' => 'Гринуич%s',
    ],
];
