<?php

return [
    'Names' => [
        'ak' => 'chiAkani',
        'am' => 'chiAmaric',
        'ar' => 'chiArabu',
        'be' => 'chiBelarusi',
        'bg' => 'chiBulgarian',
        'bn' => 'chiBengali',
        'cs' => 'chiCzech',
        'de' => 'chiJerimani',
        'el' => 'chiGreek',
        'en' => 'Chirungu',
        'es' => 'chiSpanish',
        'fa' => 'chiPeshiya',
        'fr' => 'chiFurenchi',
        'ha' => 'chiHausa',
        'hi' => 'chiHindi',
        'hu' => 'chiHungari',
        'id' => 'chiIndonesia',
        'ig' => 'chiIgbo',
        'it' => 'chiTariana',
        'ja' => 'chiJapani',
        'jv' => 'chiJava',
        'km' => 'chiKhema',
        'ko' => 'chiKoria',
        'ms' => 'chiMalay',
        'my' => 'chiBurma',
        'ne' => 'chiNepali',
        'nl' => 'chiDutch',
        'pa' => 'chiPunjabi',
        'pl' => 'chiPolish',
        'pt' => 'chiPutukezi',
        'ro' => 'chiRomanian',
        'ru' => 'chiRashiya',
        'rw' => 'chiRwanda',
        'sn' => 'chiShona',
        'so' => 'chiSomali',
        'sv' => 'chiSwedish',
        'ta' => 'chiTamil',
        'th' => 'chiThai',
        'tr' => 'chiTurkish',
        'uk' => 'chiUkrenia',
        'ur' => 'chiUrdu',
        'vi' => 'chiVietnam',
        'yo' => 'chiYoruba',
        'zh' => 'chiChinese',
        'zu' => 'chiZulu',
    ],
    'LocalizedNames' => [
    ],
];
