<?php

return [
    'Names' => [
        'aa' => 'Affareg',
        'ab' => 'Abchaseg',
        'ace' => 'Acehneg',
        'ach' => 'Acoli',
        'ada' => 'Adangmeg',
        'ady' => 'Circaseg Gorllewinol',
        'ae' => 'Afestaneg',
        'aeb' => 'Arabeg Tunisia',
        'af' => 'Affricâneg',
        'afh' => 'Affrihili',
        'agq' => 'Aghemeg',
        'ain' => 'Ainŵeg',
        'ak' => 'Acaneg',
        'akk' => 'Acadeg',
        'akz' => 'Alabamäeg',
        'ale' => 'Alewteg',
        'aln' => 'Ghegeg Albania',
        'alt' => 'Altäeg Deheuol',
        'am' => 'Amhareg',
        'an' => 'Aragoneg',
        'ang' => 'Hen Saesneg',
        'ann' => 'Obolo',
        'anp' => 'Angika',
        'ar' => 'Arabeg',
        'arc' => 'Aramaeg',
        'arn' => 'Arawcaneg',
        'aro' => 'Araonaeg',
        'arp' => 'Arapaho',
        'arq' => 'Arabeg Algeria',
        'ars' => 'Arabeg Najdi',
        'arw' => 'Arawaceg',
        'ary' => 'Arabeg Moroco',
        'arz' => 'Arabeg yr Aifft',
        'as' => 'Asameg',
        'asa' => 'Asw',
        'ase' => 'Iaith Arwyddion America',
        'ast' => 'Astwrianeg',
        'atj' => 'Atikamekw',
        'av' => 'Afareg',
        'awa' => 'Awadhi',
        'ay' => 'Aymareg',
        'az' => 'Aserbaijaneg',
        'ba' => 'Bashcorteg',
        'bal' => 'Balwtsi',
        'ban' => 'Balïeg',
        'bas' => 'Basâeg',
        'bax' => 'Bamwmeg',
        'be' => 'Belarwseg',
        'bej' => 'Bejäeg',
        'bem' => 'Bembeg',
        'bez' => 'Bena',
        'bfd' => 'Baffwteg',
        'bfq' => 'Badaga',
        'bg' => 'Bwlgareg',
        'bgn' => 'Balochi Gorllewinol',
        'bho' => 'Bhojpuri',
        'bi' => 'Bislama',
        'bin' => 'Bini',
        'bkm' => 'Comeg',
        'bla' => 'Siksika',
        'bm' => 'Bambareg',
        'bn' => 'Bengaleg',
        'bo' => 'Tibeteg',
        'br' => 'Llydaweg',
        'brh' => 'Brahui',
        'brx' => 'Bodo',
        'bs' => 'Bosnieg',
        'bss' => 'Acwseg',
        'bua' => 'Bwriateg',
        'bug' => 'Bwginaeg',
        'bum' => 'Bwlw',
        'byn' => 'Blin',
        'ca' => 'Catalaneg',
        'cad' => 'Cado',
        'car' => 'Caribeg',
        'cay' => 'Cayuga',
        'cch' => 'Atsameg',
        'ccp' => 'Tsiacma',
        'ce' => 'Tsietsieneg',
        'ceb' => 'Cebuano',
        'cgg' => 'Tsiga',
        'ch' => 'Tsiamorro',
        'chk' => 'Chuukaeg',
        'chm' => 'Marieg',
        'cho' => 'Siocto',
        'chp' => 'Chipewyan',
        'chr' => 'Tsierocî',
        'chy' => 'Cheyenne',
        'ckb' => 'Cwrdeg Sorani',
        'clc' => 'Chilcotin',
        'co' => 'Corseg',
        'cop' => 'Copteg',
        'cr' => 'Cri',
        'crg' => 'Michif',
        'crh' => 'Tyrceg y Crimea',
        'crj' => 'Cree De Ddwyrain',
        'crk' => 'Plains Cree',
        'crl' => 'Gogledd Dwyrain Cree',
        'crm' => 'Moose Cree',
        'crr' => 'Carolina Algonquian',
        'crs' => 'Ffrangeg Seselwa Creole',
        'cs' => 'Tsieceg',
        'csw' => 'Swampy Cree',
        'cu' => 'Hen Slafoneg',
        'cv' => 'Tshwfasheg',
        'cy' => 'Cymraeg',
        'da' => 'Daneg',
        'dak' => 'Dacotaeg',
        'dar' => 'Dargwa',
        'dav' => 'Taita',
        'de' => 'Almaeneg',
        'dgr' => 'Dogrib',
        'din' => 'Dinca',
        'dje' => 'Sarmaeg',
        'doi' => 'Dogri',
        'dsb' => 'Sorbeg Isaf',
        'dua' => 'Diwaleg',
        'dum' => 'Iseldireg Canol',
        'dv' => 'Difehi',
        'dyo' => 'Jola-Fonyi',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embw',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'egy' => 'Hen Eiffteg',
        'eka' => 'Ekajuk',
        'el' => 'Groeg',
        'elx' => 'Elameg',
        'en' => 'Saesneg',
        'enm' => 'Saesneg Canol',
        'eo' => 'Esperanto',
        'es' => 'Sbaeneg',
        'et' => 'Estoneg',
        'eu' => 'Basgeg',
        'ewo' => 'Ewondo',
        'ext' => 'Extremadureg',
        'fa' => 'Perseg',
        'fat' => 'Ffanti',
        'ff' => 'Ffwla',
        'fi' => 'Ffinneg',
        'fil' => 'Ffilipineg',
        'fit' => 'Ffinneg Tornedal',
        'fj' => 'Ffijïeg',
        'fo' => 'Ffaröeg',
        'fon' => 'Fon',
        'fr' => 'Ffrangeg',
        'frc' => 'Ffrangeg Cajwn',
        'frm' => 'Ffrangeg Canol',
        'fro' => 'Hen Ffrangeg',
        'frp' => 'Arpitaneg',
        'frr' => 'Ffriseg Gogleddol',
        'frs' => 'Ffriseg y Dwyrain',
        'fur' => 'Ffriwleg',
        'fy' => 'Ffriseg y Gorllewin',
        'ga' => 'Gwyddeleg',
        'gaa' => 'Ga',
        'gag' => 'Gagauz',
        'gay' => 'Gaio',
        'gba' => 'Gbaia',
        'gbz' => 'Dareg y Zoroastriaid',
        'gd' => 'Gaeleg yr Alban',
        'gez' => 'Geez',
        'gil' => 'Gilberteg',
        'gl' => 'Galisieg',
        'gmh' => 'Almaeneg Uchel Canol',
        'gn' => 'Guaraní',
        'goh' => 'Hen Almaeneg Uchel',
        'gor' => 'Gorontalo',
        'got' => 'Gotheg',
        'grc' => 'Hen Roeg',
        'gsw' => 'Almaeneg y Swistir',
        'gu' => 'Gwjarati',
        'guz' => 'Gusii',
        'gv' => 'Manaweg',
        'gwi' => 'Gwichʼin',
        'ha' => 'Hawsa',
        'hai' => 'Haida',
        'haw' => 'Hawäieg',
        'hax' => 'Haida Deheuol',
        'he' => 'Hebraeg',
        'hi' => 'Hindi',
        'hil' => 'Hiligaynon',
        'hit' => 'Hetheg',
        'hmn' => 'Hmongeg',
        'hr' => 'Croateg',
        'hsb' => 'Sorbeg Uchaf',
        'ht' => 'Creol Haiti',
        'hu' => 'Hwngareg',
        'hup' => 'Hupa',
        'hur' => 'Halkomelem',
        'hy' => 'Armeneg',
        'hz' => 'Herero',
        'ia' => 'Interlingua',
        'iba' => 'Ibaneg',
        'ibb' => 'Ibibio',
        'id' => 'Indoneseg',
        'ie' => 'Interlingue',
        'ig' => 'Igbo',
        'ii' => 'Nwosw',
        'ik' => 'Inwpiaceg',
        'ikt' => 'Inuktitut Canadaidd Gorllewinol',
        'ilo' => 'Ilocaneg',
        'inh' => 'Ingwsieg',
        'io' => 'Ido',
        'is' => 'Islandeg',
        'it' => 'Eidaleg',
        'iu' => 'Inwctitwt',
        'ja' => 'Japaneeg',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Matsiame',
        'jpr' => 'Iddew-Bersieg',
        'jrb' => 'Iddew-Arabeg',
        'jv' => 'Jafanaeg',
        'ka' => 'Georgeg',
        'kaa' => 'Cara-Calpaceg',
        'kab' => 'Cabileg',
        'kac' => 'Kachin',
        'kaj' => 'Jju',
        'kam' => 'Camba',
        'kbd' => 'Cabardieg',
        'kcg' => 'Tyapeg',
        'kde' => 'Macondeg',
        'kea' => 'Caboferdianeg',
        'kfo' => 'Koro',
        'kg' => 'Congo',
        'kgp' => 'Kaingang',
        'kha' => 'Càseg',
        'khq' => 'Koyra Chiini',
        'khw' => 'Chowareg',
        'ki' => 'Kikuyu',
        'kj' => 'Kuanyama',
        'kk' => 'Casacheg',
        'kkj' => 'Kako',
        'kl' => 'Kalaallisut',
        'kln' => 'Kalenjin',
        'km' => 'Chmereg',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada',
        'ko' => 'Coreeg',
        'koi' => 'Komi-Permyak',
        'kok' => 'Concani',
        'kpe' => 'Kpelle',
        'kr' => 'Canwri',
        'krc' => 'Karachay-Balkar',
        'krl' => 'Careleg',
        'kru' => 'Kurukh',
        'ks' => 'Cashmireg',
        'ksb' => 'Shambala',
        'ksf' => 'Baffia',
        'ksh' => 'Cwleneg',
        'ku' => 'Cwrdeg',
        'kum' => 'Cwmiceg',
        'kv' => 'Comi',
        'kw' => 'Cernyweg',
        'kwk' => 'Kwakʼwala',
        'ky' => 'Cirgiseg',
        'la' => 'Lladin',
        'lad' => 'Iddew-Sbaeneg',
        'lag' => 'Langi',
        'lah' => 'Lahnda',
        'lam' => 'Lamba',
        'lb' => 'Lwcsembwrgeg',
        'lez' => 'Lezgheg',
        'lg' => 'Ganda',
        'li' => 'Limbwrgeg',
        'lil' => 'Lillooet',
        'lkt' => 'Lakota',
        'lmo' => 'Lombardeg',
        'ln' => 'Lingala',
        'lo' => 'Laoeg',
        'lol' => 'Mongo',
        'lou' => 'Louisiana Creole',
        'loz' => 'Lozi',
        'lrc' => 'Luri Gogleddol',
        'lsm' => 'Saamia',
        'lt' => 'Lithwaneg',
        'ltg' => 'Latgaleg',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lun' => 'Lwnda',
        'luo' => 'Lŵo',
        'lus' => 'Lwshaieg',
        'luy' => 'Lwyia',
        'lv' => 'Latfieg',
        'mad' => 'Madwreg',
        'mag' => 'Magahi',
        'mai' => 'Maithili',
        'mak' => 'Macasareg',
        'man' => 'Mandingo',
        'mas' => 'Masai',
        'mdf' => 'Mocsia',
        'mdr' => 'Mandareg',
        'men' => 'Mendeg',
        'mer' => 'Mêrw',
        'mfe' => 'Morisyen',
        'mg' => 'Malagaseg',
        'mga' => 'Gwyddeleg Canol',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta',
        'mh' => 'Marsialeg',
        'mi' => 'Māori',
        'mic' => 'Micmaceg',
        'min' => 'Minangkabau',
        'mk' => 'Macedoneg',
        'ml' => 'Malayalam',
        'mn' => 'Mongoleg',
        'mnc' => 'Manshw',
        'mni' => 'Manipwri',
        'moe' => 'Innu-aimun',
        'moh' => 'Mohoceg',
        'mos' => 'Mosi',
        'mr' => 'Marathi',
        'mrj' => 'Mari Gorllewinol',
        'ms' => 'Maleieg',
        'mt' => 'Malteg',
        'mua' => 'Mundang',
        'mus' => 'Creek',
        'mwl' => 'Mirandeg',
        'mwr' => 'Marwari',
        'my' => 'Byrmaneg',
        'myv' => 'Erzya',
        'mzn' => 'Masanderani',
        'na' => 'Nawrŵeg',
        'nap' => 'Naplieg',
        'naq' => 'Nama',
        'nb' => 'Norwyeg Bokmål',
        'nd' => 'Ndebele Gogleddol',
        'nds' => 'Almaeneg Isel',
        'ne' => 'Nepaleg',
        'new' => 'Newaeg',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niuean',
        'njo' => 'Ao Naga',
        'nl' => 'Iseldireg',
        'nmg' => 'Kwasio',
        'nn' => 'Norwyeg Nynorsk',
        'nnh' => 'Ngiemboon',
        'no' => 'Norwyeg',
        'nog' => 'Nogai',
        'non' => 'Hen Norseg',
        'nqo' => 'N’Ko',
        'nr' => 'Ndebele Deheuol',
        'nso' => 'Sotho Gogleddol',
        'nus' => 'Nŵereg',
        'nv' => 'Nafaho',
        'nwc' => 'Hen Newari',
        'ny' => 'Nianja',
        'nym' => 'Niamwezi',
        'nyn' => 'Niancole',
        'nyo' => 'Nioro',
        'nzi' => 'Nzimeg',
        'oc' => 'Ocsitaneg',
        'oj' => 'Ojibwa',
        'ojb' => 'Ojibwa gogledd-orllewin',
        'ojc' => 'Ojibwa Canolog',
        'ojs' => 'Oji-Cree',
        'ojw' => 'Ojibwa Gorllewinol',
        'oka' => 'Okanagan',
        'om' => 'Oromo',
        'or' => 'Odia',
        'os' => 'Oseteg',
        'osa' => 'Osageg',
        'ota' => 'Tyrceg Otoman',
        'pa' => 'Pwnjabeg',
        'pag' => 'Pangasineg',
        'pal' => 'Pahlafi',
        'pam' => 'Pampanga',
        'pap' => 'Papiamento',
        'pau' => 'Palawan',
        'pcd' => 'Picardeg',
        'pcm' => 'Pidgin Nigeria',
        'pdc' => 'Almaeneg Pensylfania',
        'peo' => 'Hen Bersieg',
        'pfl' => 'Almaeneg Palatin',
        'phn' => 'Phoeniceg',
        'pi' => 'Pali',
        'pis' => 'Pijin',
        'pl' => 'Pwyleg',
        'pms' => 'Piedmonteg',
        'pnt' => 'Ponteg',
        'pon' => 'Pohnpeianeg',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'Prwseg',
        'pro' => 'Hen Brofensaleg',
        'ps' => 'Pashto',
        'pt' => 'Portiwgaleg',
        'qu' => 'Quechua',
        'quc' => 'K’iche’',
        'raj' => 'Rajasthaneg',
        'rap' => 'Rapanŵi',
        'rar' => 'Raratongeg',
        'rhg' => 'Rohingya',
        'rm' => 'Románsh',
        'rn' => 'Rwndi',
        'ro' => 'Rwmaneg',
        'rof' => 'Rombo',
        'rom' => 'Romani',
        'rtm' => 'Rotumaneg',
        'ru' => 'Rwseg',
        'rup' => 'Aromaneg',
        'rw' => 'Ciniarŵandeg',
        'rwk' => 'Rwa',
        'sa' => 'Sansgrit',
        'sad' => 'Sandäweg',
        'sah' => 'Sakha',
        'sam' => 'Aramaeg Samaria',
        'saq' => 'Sambŵrw',
        'sas' => 'Sasaceg',
        'sat' => 'Santali',
        'sba' => 'Ngambeieg',
        'sbp' => 'Sangw',
        'sc' => 'Sardeg',
        'scn' => 'Sisileg',
        'sco' => 'Sgoteg',
        'sd' => 'Sindhi',
        'sdc' => 'Sasareseg Sardinia',
        'sdh' => 'Cwrdeg Deheuol',
        'se' => 'Sami Gogleddol',
        'see' => 'Seneca',
        'seh' => 'Sena',
        'sei' => 'Seri',
        'sel' => 'Selcypeg',
        'ses' => 'Koyraboro Senni',
        'sg' => 'Sango',
        'sga' => 'Hen Wyddeleg',
        'sgs' => 'Samogiteg',
        'sh' => 'Serbo-Croateg',
        'shi' => 'Tachelhit',
        'shn' => 'Shan',
        'shu' => 'Arabeg Chad',
        'si' => 'Sinhaleg',
        'sid' => 'Sidamo',
        'sk' => 'Slofaceg',
        'sl' => 'Slofeneg',
        'slh' => 'Lushootseed Deheuol',
        'sli' => 'Is-silesieg',
        'sm' => 'Samöeg',
        'sma' => 'Sami Deheuol',
        'smj' => 'Sami Lwle',
        'smn' => 'Inari Sami',
        'sms' => 'Sami Scolt',
        'sn' => 'Shona',
        'snk' => 'Soninceg',
        'so' => 'Somaleg',
        'sog' => 'Sogdeg',
        'sq' => 'Albaneg',
        'sr' => 'Serbeg',
        'srn' => 'Sranan Tongo',
        'srr' => 'Serereg',
        'ss' => 'Swati',
        'ssy' => 'Saho',
        'st' => 'Sesotheg Deheuol',
        'stq' => 'Ffriseg Saterland',
        'str' => 'Straits Salish',
        'su' => 'Swndaneg',
        'suk' => 'Swcwma',
        'sus' => 'Swsŵeg',
        'sux' => 'Swmereg',
        'sv' => 'Swedeg',
        'sw' => 'Swahili',
        'swb' => 'Comoreg',
        'syc' => 'Hen Syrieg',
        'syr' => 'Syrieg',
        'szl' => 'Silesieg',
        'ta' => 'Tamileg',
        'tce' => 'Tutchone Deheuol',
        'tcy' => 'Tulu',
        'te' => 'Telugu',
        'tem' => 'Timneg',
        'teo' => 'Teso',
        'ter' => 'Terena',
        'tet' => 'Tetumeg',
        'tg' => 'Tajiceg',
        'tgx' => 'Tagish',
        'th' => 'Thai',
        'tht' => 'Tahltan',
        'ti' => 'Tigrinya',
        'tig' => 'Tigreg',
        'tiv' => 'Tifeg',
        'tk' => 'Tyrcmeneg',
        'tkl' => 'Tocelaweg',
        'tkr' => 'Tsakhureg',
        'tl' => 'Tagalog',
        'tlh' => 'Klingon',
        'tli' => 'Tlingit',
        'tly' => 'Talysheg',
        'tmh' => 'Tamasheceg',
        'tn' => 'Tswana',
        'to' => 'Tongeg',
        'tok' => 'Toki Pona',
        'tpi' => 'Tok Pisin',
        'tr' => 'Tyrceg',
        'trv' => 'Taroko',
        'ts' => 'Tsongaeg',
        'tsd' => 'Tsaconeg',
        'tt' => 'Tatareg',
        'ttm' => 'Tutchone gogleddol',
        'tum' => 'Twmbwca',
        'tvl' => 'Twfalweg',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahitïeg',
        'tyv' => 'Twfwnieg',
        'tzm' => 'Tamazight Canol yr Atlas',
        'udm' => 'Fotiaceg',
        'ug' => 'Uighur',
        'uga' => 'Wgariteg',
        'uk' => 'Wcreineg',
        'umb' => 'Umbundu',
        'ur' => 'Wrdw',
        'uz' => 'Wsbeceg',
        'vai' => 'Faieg',
        've' => 'Fendeg',
        'vec' => 'Feniseg',
        'vep' => 'Feps',
        'vi' => 'Fietnameg',
        'vls' => 'Fflemeg Gorllewinol',
        'vo' => 'Folapük',
        'vot' => 'Foteg',
        'vun' => 'Funjo',
        'wa' => 'Walwneg',
        'wae' => 'Walsereg',
        'wal' => 'Walamo',
        'war' => 'Winarayeg',
        'was' => 'Washo',
        'wbp' => 'Warlpiri',
        'wo' => 'Woloff',
        'wuu' => 'Wu Tsieineaidd',
        'xal' => 'Calmyceg',
        'xh' => 'Xhosa',
        'xog' => 'Soga',
        'yav' => 'Iangben',
        'ybb' => 'Iembaeg',
        'yi' => 'Iddew-Almaeneg',
        'yo' => 'Iorwba',
        'yrl' => 'Nheengatu',
        'yue' => 'Cantoneeg',
        'zap' => 'Zapoteceg',
        'zbl' => 'Blisssymbols',
        'zea' => 'Zêlandeg',
        'zgh' => 'Tamaseit Moroco Safonol',
        'zh' => 'Tsieinëeg',
        'zu' => 'Swlw',
        'zun' => 'Swni',
        'zza' => 'Sasäeg',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Arabeg Modern Safonol',
        'az_Arab' => 'Aserbaijaneg Deheuol',
        'de_AT' => 'Almaeneg Awstria',
        'de_CH' => 'Almaeneg Safonol y Swistir',
        'en_AU' => 'Saesneg Awstralia',
        'en_CA' => 'Saesneg Canada',
        'en_GB' => 'Saesneg Prydain',
        'en_US' => 'Saesneg America',
        'es_419' => 'Sbaeneg America Ladin',
        'es_ES' => 'Sbaeneg Ewrop',
        'es_MX' => 'Sbaeneg Mecsico',
        'fa_AF' => 'Dari',
        'fr_CA' => 'Ffrangeg Canada',
        'fr_CH' => 'Ffrangeg y Swistir',
        'nds_NL' => 'Sacsoneg Isel',
        'nl_BE' => 'Fflemeg',
        'pt_BR' => 'Portiwgaleg Brasil',
        'pt_PT' => 'Portiwgaleg Ewrop',
        'ro_MD' => 'Moldofeg',
        'sw_CD' => 'Swahili’r Congo',
        'zh_Hans' => 'Tsieinëeg Symledig',
        'zh_Hant' => 'Tsieinëeg Traddodiadol',
    ],
];
