<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'గ్రీన్‌విచ్ సగటు సమయం (అబిడ్జాన్)',
        'Africa/Accra' => 'గ్రీన్‌విచ్ సగటు సమయం (అక్రా)',
        'Africa/Addis_Ababa' => 'తూర్పు ఆఫ్రికా సమయం (యాడిస్ అబాబా)',
        'Africa/Algiers' => 'సెంట్రల్ యూరోపియన్ సమయం (అల్జియర్స్)',
        'Africa/Asmera' => 'తూర్పు ఆఫ్రికా సమయం (అస్మారా)',
        'Africa/Bamako' => 'గ్రీన్‌విచ్ సగటు సమయం (బామాకో)',
        'Africa/Bangui' => 'పశ్చిమ ఆఫ్రికా సమయం (బాంగుయ్)',
        'Africa/Banjul' => 'గ్రీన్‌విచ్ సగటు సమయం (బంజూల్)',
        'Africa/Bissau' => 'గ్రీన్‌విచ్ సగటు సమయం (బిస్సావ్)',
        'Africa/Blantyre' => 'సెంట్రల్ ఆఫ్రికా సమయం (బ్లాన్టైర్)',
        'Africa/Brazzaville' => 'పశ్చిమ ఆఫ్రికా సమయం (బ్రాజావిల్లే)',
        'Africa/Bujumbura' => 'సెంట్రల్ ఆఫ్రికా సమయం (బుజమ్బురా)',
        'Africa/Cairo' => 'తూర్పు యూరోపియన్ సమయం (కైరో)',
        'Africa/Casablanca' => 'పశ్చిమ యూరోపియన్ సమయం (కాసాబ్లాంకా)',
        'Africa/Ceuta' => 'సెంట్రల్ యూరోపియన్ సమయం (స్యూటా)',
        'Africa/Conakry' => 'గ్రీన్‌విచ్ సగటు సమయం (కోనాక్రీ)',
        'Africa/Dakar' => 'గ్రీన్‌విచ్ సగటు సమయం (డకార్)',
        'Africa/Dar_es_Salaam' => 'తూర్పు ఆఫ్రికా సమయం (దార్ ఎస్ సలామ్)',
        'Africa/Djibouti' => 'తూర్పు ఆఫ్రికా సమయం (డిజ్బౌటి)',
        'Africa/Douala' => 'పశ్చిమ ఆఫ్రికా సమయం (డౌలా)',
        'Africa/El_Aaiun' => 'పశ్చిమ యూరోపియన్ సమయం (ఎల్ ఎయున్)',
        'Africa/Freetown' => 'గ్రీన్‌విచ్ సగటు సమయం (ఫ్రీటౌన్)',
        'Africa/Gaborone' => 'సెంట్రల్ ఆఫ్రికా సమయం (గబోరోన్)',
        'Africa/Harare' => 'సెంట్రల్ ఆఫ్రికా సమయం (హరారే)',
        'Africa/Johannesburg' => 'దక్షిణ ఆఫ్రికా ప్రామాణిక సమయం (జొహెన్స్‌బర్గ్)',
        'Africa/Juba' => 'సెంట్రల్ ఆఫ్రికా సమయం (జుబా)',
        'Africa/Kampala' => 'తూర్పు ఆఫ్రికా సమయం (కంపాలా)',
        'Africa/Khartoum' => 'సెంట్రల్ ఆఫ్రికా సమయం (ఖార్టోమ్)',
        'Africa/Kigali' => 'సెంట్రల్ ఆఫ్రికా సమయం (కీగలి)',
        'Africa/Kinshasa' => 'పశ్చిమ ఆఫ్రికా సమయం (కిన్షాసా)',
        'Africa/Lagos' => 'పశ్చిమ ఆఫ్రికా సమయం (లాగోస్)',
        'Africa/Libreville' => 'పశ్చిమ ఆఫ్రికా సమయం (లెబర్విల్లే)',
        'Africa/Lome' => 'గ్రీన్‌విచ్ సగటు సమయం (లోమ్)',
        'Africa/Luanda' => 'పశ్చిమ ఆఫ్రికా సమయం (లువాండా)',
        'Africa/Lubumbashi' => 'సెంట్రల్ ఆఫ్రికా సమయం (లుబంబాషి)',
        'Africa/Lusaka' => 'సెంట్రల్ ఆఫ్రికా సమయం (లుసాకా)',
        'Africa/Malabo' => 'పశ్చిమ ఆఫ్రికా సమయం (మలాబో)',
        'Africa/Maputo' => 'సెంట్రల్ ఆఫ్రికా సమయం (మాపుటో)',
        'Africa/Maseru' => 'దక్షిణ ఆఫ్రికా ప్రామాణిక సమయం (మసేరు)',
        'Africa/Mbabane' => 'దక్షిణ ఆఫ్రికా ప్రామాణిక సమయం (బాబెన్)',
        'Africa/Mogadishu' => 'తూర్పు ఆఫ్రికా సమయం (మోగాదిషు)',
        'Africa/Monrovia' => 'గ్రీన్‌విచ్ సగటు సమయం (మోన్రోవియా)',
        'Africa/Nairobi' => 'తూర్పు ఆఫ్రికా సమయం (నైరోబీ)',
        'Africa/Ndjamena' => 'పశ్చిమ ఆఫ్రికా సమయం (డ్జామెనా)',
        'Africa/Niamey' => 'పశ్చిమ ఆఫ్రికా సమయం (నియామే)',
        'Africa/Nouakchott' => 'గ్రీన్‌విచ్ సగటు సమయం (న్వాక్షోట్)',
        'Africa/Ouagadougou' => 'గ్రీన్‌విచ్ సగటు సమయం (ఔగాడౌగోవ్)',
        'Africa/Porto-Novo' => 'పశ్చిమ ఆఫ్రికా సమయం (పోర్టో-నోవో)',
        'Africa/Sao_Tome' => 'గ్రీన్‌విచ్ సగటు సమయం (సావో టోమ్)',
        'Africa/Tripoli' => 'తూర్పు యూరోపియన్ సమయం (ట్రిపోలి)',
        'Africa/Tunis' => 'సెంట్రల్ యూరోపియన్ సమయం (ట్యునిస్)',
        'Africa/Windhoek' => 'సెంట్రల్ ఆఫ్రికా సమయం (విండ్హోక్)',
        'America/Adak' => 'హవాయ్-అల్యూషియన్ సమయం (అడాక్)',
        'America/Anchorage' => 'అలాస్కా సమయం (యాంకరేజ్)',
        'America/Anguilla' => 'అట్లాంటిక్ సమయం (ఆంగ్విల్లా)',
        'America/Antigua' => 'అట్లాంటిక్ సమయం (ఆంటిగ్వా)',
        'America/Araguaina' => 'బ్రెజిలియా సమయం (అరాగ్వేయీనా)',
        'America/Argentina/La_Rioja' => 'అర్జెంటీనా సమయం (లా రియోజ)',
        'America/Argentina/Rio_Gallegos' => 'అర్జెంటీనా సమయం (రియో గల్లేగోస్)',
        'America/Argentina/Salta' => 'అర్జెంటీనా సమయం (సాల్టా)',
        'America/Argentina/San_Juan' => 'అర్జెంటీనా సమయం (శాన్ జ్యూన్)',
        'America/Argentina/San_Luis' => 'అర్జెంటీనా సమయం (శాన్ లూయిస్)',
        'America/Argentina/Tucuman' => 'అర్జెంటీనా సమయం (టుకుమన్)',
        'America/Argentina/Ushuaia' => 'అర్జెంటీనా సమయం (ఉష్యూయ)',
        'America/Aruba' => 'అట్లాంటిక్ సమయం (అరుబా)',
        'America/Asuncion' => 'పరాగ్వే సమయం (అసున్సియోన్)',
        'America/Bahia' => 'బ్రెజిలియా సమయం (బహియ)',
        'America/Bahia_Banderas' => 'మధ్యమ సమయం (బహియా బండరాస్)',
        'America/Barbados' => 'అట్లాంటిక్ సమయం (బార్బడోస్)',
        'America/Belem' => 'బ్రెజిలియా సమయం (బెలెమ్)',
        'America/Belize' => 'మధ్యమ సమయం (బెలీజ్)',
        'America/Blanc-Sablon' => 'అట్లాంటిక్ సమయం (బ్లాంక్-సబ్లోన్)',
        'America/Boa_Vista' => 'అమెజాన్ సమయం (బోవా విస్టా)',
        'America/Bogota' => 'కొలంబియా సమయం (బగోటా)',
        'America/Boise' => 'మౌంటెయిన్ సమయం (బొయిసీ)',
        'America/Buenos_Aires' => 'అర్జెంటీనా సమయం (బ్యూనోస్ ఎయిర్స్)',
        'America/Cambridge_Bay' => 'మౌంటెయిన్ సమయం (కేంబ్రిడ్జ్ బే)',
        'America/Campo_Grande' => 'అమెజాన్ సమయం (కాంపో గ్రాండ్)',
        'America/Cancun' => 'తూర్పు సమయం (కన్‌కూన్)',
        'America/Caracas' => 'వెనిజులా సమయం (కారాకస్)',
        'America/Catamarca' => 'అర్జెంటీనా సమయం (కటమార్కా)',
        'America/Cayenne' => 'ఫ్రెంచ్ గయానా సమయం (కయేన్)',
        'America/Cayman' => 'తూర్పు సమయం (కేమాన్)',
        'America/Chicago' => 'మధ్యమ సమయం (చికాగో)',
        'America/Chihuahua' => 'మెక్సికన్ పసిఫిక్ సమయం (చువావా)',
        'America/Coral_Harbour' => 'తూర్పు సమయం (అటికోకన్)',
        'America/Cordoba' => 'అర్జెంటీనా సమయం (కోర్డోబా)',
        'America/Costa_Rica' => 'మధ్యమ సమయం (కోస్టా రికా)',
        'America/Creston' => 'మౌంటెయిన్ సమయం (క్రెస్టన్)',
        'America/Cuiaba' => 'అమెజాన్ సమయం (కుయబా)',
        'America/Curacao' => 'అట్లాంటిక్ సమయం (కురాకవో)',
        'America/Danmarkshavn' => 'గ్రీన్‌విచ్ సగటు సమయం (డెన్మార్క్‌షాన్)',
        'America/Dawson' => 'యుకోన్ సమయం (డాసన్)',
        'America/Dawson_Creek' => 'మౌంటెయిన్ సమయం (డాసన్ క్రీక్)',
        'America/Denver' => 'మౌంటెయిన్ సమయం (డెన్వెర్)',
        'America/Detroit' => 'తూర్పు సమయం (డిట్రోయిట్)',
        'America/Dominica' => 'అట్లాంటిక్ సమయం (డొమినికా)',
        'America/Edmonton' => 'మౌంటెయిన్ సమయం (ఎడ్మోంటన్)',
        'America/Eirunepe' => 'ఏకర్ సమయం (ఇరునెప్)',
        'America/El_Salvador' => 'మధ్యమ సమయం (ఎల్ సాల్వడోర్)',
        'America/Fort_Nelson' => 'మౌంటెయిన్ సమయం (ఫోర్ట్ నెల్సన్)',
        'America/Fortaleza' => 'బ్రెజిలియా సమయం (ఫోర్టలేజా)',
        'America/Glace_Bay' => 'అట్లాంటిక్ సమయం (గ్లేస్ బే)',
        'America/Godthab' => 'పశ్చిమ గ్రీన్‌ల్యాండ్ సమయం (నూక్)',
        'America/Goose_Bay' => 'అట్లాంటిక్ సమయం (గూస్ బే)',
        'America/Grand_Turk' => 'తూర్పు సమయం (గ్రాండ్ టర్క్)',
        'America/Grenada' => 'అట్లాంటిక్ సమయం (గ్రెనడా)',
        'America/Guadeloupe' => 'అట్లాంటిక్ సమయం (గ్వాడెలోప్)',
        'America/Guatemala' => 'మధ్యమ సమయం (గ్వాటిమాలా)',
        'America/Guayaquil' => 'ఈక్వడార్ సమయం (గయాక్విల్)',
        'America/Guyana' => 'గయానా సమయం',
        'America/Halifax' => 'అట్లాంటిక్ సమయం (హాలిఫాక్స్)',
        'America/Havana' => 'క్యూబా సమయం (హవానా)',
        'America/Hermosillo' => 'మెక్సికన్ పసిఫిక్ సమయం (హెర్మోసిల్లో)',
        'America/Indiana/Knox' => 'మధ్యమ సమయం (నోక్స్, ఇండియాన)',
        'America/Indiana/Marengo' => 'తూర్పు సమయం (మరెంగో, ఇండియాన)',
        'America/Indiana/Petersburg' => 'తూర్పు సమయం (పీటర్స్‌బర్గ్, ఇండియాన)',
        'America/Indiana/Tell_City' => 'మధ్యమ సమయం (టెల్ నగరం, ఇండియాన)',
        'America/Indiana/Vevay' => 'తూర్పు సమయం (వెవయ్, ఇండియాన)',
        'America/Indiana/Vincennes' => 'తూర్పు సమయం (విన్‌సెన్నెస్, ఇండియాన)',
        'America/Indiana/Winamac' => 'తూర్పు సమయం (వినామాక్, ఇండియాన)',
        'America/Indianapolis' => 'తూర్పు సమయం (ఇండియానపోలిస్)',
        'America/Inuvik' => 'మౌంటెయిన్ సమయం (ఇనువిక్)',
        'America/Iqaluit' => 'తూర్పు సమయం (ఇక్వాలిట్)',
        'America/Jamaica' => 'తూర్పు సమయం (జమైకా)',
        'America/Jujuy' => 'అర్జెంటీనా సమయం (జుజుయ్)',
        'America/Juneau' => 'అలాస్కా సమయం (జూనో)',
        'America/Kentucky/Monticello' => 'తూర్పు సమయం (మోంటిసెల్లో, కెన్‌టుక్కీ)',
        'America/Kralendijk' => 'అట్లాంటిక్ సమయం (క్రలెండ్జిక్)',
        'America/La_Paz' => 'బొలీవియా సమయం (లా పాజ్)',
        'America/Lima' => 'పెరూ సమయం (లిమా)',
        'America/Los_Angeles' => 'పసిఫిక్ సమయం (లాస్ ఏంజల్స్)',
        'America/Louisville' => 'తూర్పు సమయం (లూయివిల్)',
        'America/Lower_Princes' => 'అట్లాంటిక్ సమయం (లోయర్ ప్రిన్స్ క్వార్టర్)',
        'America/Maceio' => 'బ్రెజిలియా సమయం (మాసియో)',
        'America/Managua' => 'మధ్యమ సమయం (మనాగువా)',
        'America/Manaus' => 'అమెజాన్ సమయం (మనాస్)',
        'America/Marigot' => 'అట్లాంటిక్ సమయం (మారిగోట్)',
        'America/Martinique' => 'అట్లాంటిక్ సమయం (మార్టినీక్)',
        'America/Matamoros' => 'మధ్యమ సమయం (మాటమొరోస్)',
        'America/Mazatlan' => 'మెక్సికన్ పసిఫిక్ సమయం (మాసట్‌లాన్)',
        'America/Mendoza' => 'అర్జెంటీనా సమయం (మెండోజా)',
        'America/Menominee' => 'మధ్యమ సమయం (మెనోమినీ)',
        'America/Merida' => 'మధ్యమ సమయం (మెరిడా)',
        'America/Metlakatla' => 'అలాస్కా సమయం (మెట్లకట్ల)',
        'America/Mexico_City' => 'మధ్యమ సమయం (మెక్సికో నగరం)',
        'America/Miquelon' => 'సెయింట్ పియెర్ మరియు మిక్వెలాన్ సమయం (మికెలాన్)',
        'America/Moncton' => 'అట్లాంటిక్ సమయం (మోన్‌క్టోన్)',
        'America/Monterrey' => 'మధ్యమ సమయం (మోంటెర్రే)',
        'America/Montevideo' => 'ఉరుగ్వే సమయం (మోంటెవీడియో)',
        'America/Montreal' => 'కెనడా సమయం (Montreal)',
        'America/Montserrat' => 'అట్లాంటిక్ సమయం (మాంట్సెరాట్)',
        'America/Nassau' => 'తూర్పు సమయం (నాస్సావ్)',
        'America/New_York' => 'తూర్పు సమయం (న్యూయార్క్)',
        'America/Nipigon' => 'తూర్పు సమయం (నిపిగోన్)',
        'America/Nome' => 'అలాస్కా సమయం (నోమ్)',
        'America/Noronha' => 'ఫెర్నాండో డి నొరోన్హా సమయం (నరోన్హా)',
        'America/North_Dakota/Beulah' => 'మధ్యమ సమయం (బ్యులా, ఉత్తర డకోట)',
        'America/North_Dakota/Center' => 'మధ్యమ సమయం (సెంటర్, ఉత్తర డకోటా)',
        'America/North_Dakota/New_Salem' => 'మధ్యమ సమయం (న్యూ సలేమ్, ఉత్తర డకోట)',
        'America/Ojinaga' => 'మౌంటెయిన్ సమయం (ఒజినగ)',
        'America/Panama' => 'తూర్పు సమయం (పనామా)',
        'America/Pangnirtung' => 'తూర్పు సమయం (పాంగ్‌నీర్‌టుంగ్)',
        'America/Paramaribo' => 'సూరినామ్ సమయం (పరామారిబో)',
        'America/Phoenix' => 'మౌంటెయిన్ సమయం (ఫినిక్స్)',
        'America/Port-au-Prince' => 'తూర్పు సమయం (పోర్ట్-అవ్-ప్రిన్స్)',
        'America/Port_of_Spain' => 'అట్లాంటిక్ సమయం (పోర్ట్ ఆఫ్ స్పెయిన్)',
        'America/Porto_Velho' => 'అమెజాన్ సమయం (పోర్టో వెల్హో)',
        'America/Puerto_Rico' => 'అట్లాంటిక్ సమయం (ప్యూర్టో రికో)',
        'America/Punta_Arenas' => 'చిలీ సమయం (పుంటా అరీనస్)',
        'America/Rainy_River' => 'మధ్యమ సమయం (రెయినీ రివర్)',
        'America/Rankin_Inlet' => 'మధ్యమ సమయం (రన్‌కిన్ ఇన్‌లెట్)',
        'America/Recife' => 'బ్రెజిలియా సమయం (రెసిఫీ)',
        'America/Regina' => 'మధ్యమ సమయం (రెజీనా)',
        'America/Resolute' => 'మధ్యమ సమయం (రిజల్యూట్)',
        'America/Rio_Branco' => 'ఏకర్ సమయం (రియో బ్రాంకో)',
        'America/Santa_Isabel' => 'వాయువ్య మెక్సికో సమయం (శాంటా ఇసబెల్)',
        'America/Santarem' => 'బ్రెజిలియా సమయం (సాంటరెమ్)',
        'America/Santiago' => 'చిలీ సమయం (శాంటియాగో)',
        'America/Santo_Domingo' => 'అట్లాంటిక్ సమయం (శాంటో డోమింగో)',
        'America/Sao_Paulo' => 'బ్రెజిలియా సమయం (సావో పాలో)',
        'America/Scoresbysund' => 'తూర్పు గ్రీన్‌ల్యాండ్ సమయం (ఇటోక్కోర్టూర్మిట్)',
        'America/Sitka' => 'అలాస్కా సమయం (సిట్కా)',
        'America/St_Barthelemy' => 'అట్లాంటిక్ సమయం (సెయింట్ బర్తెలెమీ)',
        'America/St_Johns' => 'న్యూఫౌండ్‌ల్యాండ్ సమయం (సెయింట్ జాన్స్)',
        'America/St_Kitts' => 'అట్లాంటిక్ సమయం (సెయింట్ కిట్స్)',
        'America/St_Lucia' => 'అట్లాంటిక్ సమయం (సెయింట్ లూసియా)',
        'America/St_Thomas' => 'అట్లాంటిక్ సమయం (సెయింట్ థామస్)',
        'America/St_Vincent' => 'అట్లాంటిక్ సమయం (సెయింట్ విన్సెంట్)',
        'America/Swift_Current' => 'మధ్యమ సమయం (స్విఫ్ట్ కరెంట్)',
        'America/Tegucigalpa' => 'మధ్యమ సమయం (తెగుసిగల్పా)',
        'America/Thule' => 'అట్లాంటిక్ సమయం (థులే)',
        'America/Thunder_Bay' => 'తూర్పు సమయం (థండర్ బే)',
        'America/Tijuana' => 'పసిఫిక్ సమయం (టిజువానా)',
        'America/Toronto' => 'తూర్పు సమయం (టొరంటో)',
        'America/Tortola' => 'అట్లాంటిక్ సమయం (టోర్టోలా)',
        'America/Vancouver' => 'పసిఫిక్ సమయం (వాన్కూవర్)',
        'America/Whitehorse' => 'యుకోన్ సమయం (వైట్‌హార్స్)',
        'America/Winnipeg' => 'మధ్యమ సమయం (విన్నిపెగ్)',
        'America/Yakutat' => 'అలాస్కా సమయం (యకుటాట్)',
        'America/Yellowknife' => 'మౌంటెయిన్ సమయం (ఎల్లోనైఫ్)',
        'Antarctica/Casey' => 'అంటార్కిటికా సమయం (కేసీ)',
        'Antarctica/Davis' => 'డేవిస్ సమయం (డెవిస్)',
        'Antarctica/DumontDUrville' => 'డ్యూమాంట్-డి’ఉర్విల్లే సమయం',
        'Antarctica/Macquarie' => 'తూర్పు ఆస్ట్రేలియా సమయం (మకారీ)',
        'Antarctica/Mawson' => 'మాసన్ సమయం',
        'Antarctica/McMurdo' => 'న్యూజిల్యాండ్ సమయం (మెక్‌ముర్డో)',
        'Antarctica/Palmer' => 'చిలీ సమయం (పాల్మర్)',
        'Antarctica/Rothera' => 'రొతేరా సమయం',
        'Antarctica/Syowa' => 'స్యోవా సమయం',
        'Antarctica/Troll' => 'గ్రీన్‌విచ్ సగటు సమయం (ట్రోల్)',
        'Antarctica/Vostok' => 'వోస్టోక్ సమయం',
        'Arctic/Longyearbyen' => 'సెంట్రల్ యూరోపియన్ సమయం (లాంగ్‌యియర్‌బైయన్)',
        'Asia/Aden' => 'అరేబియన్ సమయం (ఎడెన్)',
        'Asia/Almaty' => 'తూర్పు కజకి‌స్తాన్ సమయం (ఆల్మాటి)',
        'Asia/Amman' => 'తూర్పు యూరోపియన్ సమయం (అమ్మన్)',
        'Asia/Anadyr' => 'అనడైర్ సమయం',
        'Asia/Aqtau' => 'పశ్చిమ కజకిస్తాన్ సమయం (అక్టావ్)',
        'Asia/Aqtobe' => 'పశ్చిమ కజకిస్తాన్ సమయం (అక్టోబ్)',
        'Asia/Ashgabat' => 'తుర్క్‌మెనిస్తాన్ సమయం (యాష్గాబాట్)',
        'Asia/Atyrau' => 'పశ్చిమ కజకిస్తాన్ సమయం (ఆటిరా)',
        'Asia/Baghdad' => 'అరేబియన్ సమయం (బాగ్దాద్)',
        'Asia/Bahrain' => 'అరేబియన్ సమయం (బహ్రెయిన్)',
        'Asia/Baku' => 'అజర్బైజాన్ సమయం (బాకు)',
        'Asia/Bangkok' => 'ఇండోచైనా సమయం (బ్యాంకాక్)',
        'Asia/Barnaul' => 'రష్యా సమయం (బార్నాల్)',
        'Asia/Beirut' => 'తూర్పు యూరోపియన్ సమయం (బీరట్)',
        'Asia/Bishkek' => 'కిర్గిస్తాన్ సమయం (బిష్కెక్)',
        'Asia/Brunei' => 'బ్రూనే దరుసలామ్ సమయం (బ్రూనై)',
        'Asia/Calcutta' => 'భారతదేశ ప్రామాణిక సమయం (కోల్‌కతా)',
        'Asia/Chita' => 'యాకుట్స్క్ సమయం (చితా)',
        'Asia/Choibalsan' => 'ఉలన్ బతోర్ సమయం (చోయిబాల్సన్)',
        'Asia/Colombo' => 'భారతదేశ ప్రామాణిక సమయం (కొలంబో)',
        'Asia/Damascus' => 'తూర్పు యూరోపియన్ సమయం (డమాస్కస్)',
        'Asia/Dhaka' => 'బంగ్లాదేశ్ సమయం (ఢాకా)',
        'Asia/Dili' => 'తూర్పు తైమూర్ సమయం (డిలి)',
        'Asia/Dubai' => 'గల్ఫ్ ప్రామాణిక సమయం (దుబాయి)',
        'Asia/Dushanbe' => 'తజికిస్తాన్ సమయం (డుషన్బీ)',
        'Asia/Famagusta' => 'తూర్పు యూరోపియన్ సమయం (ఫామగుస్టా)',
        'Asia/Gaza' => 'తూర్పు యూరోపియన్ సమయం (గాజా)',
        'Asia/Hebron' => 'తూర్పు యూరోపియన్ సమయం (హెబ్రాన్)',
        'Asia/Hong_Kong' => 'హాంకాంగ్ సమయం',
        'Asia/Hovd' => 'హోవ్డ్ సమయం',
        'Asia/Irkutsk' => 'ఇర్కుట్స్క్ సమయం',
        'Asia/Jakarta' => 'పశ్చిమ ఇండోనేషియా సమయం (జకార్తా)',
        'Asia/Jayapura' => 'తూర్పు ఇండోనేషియా సమయం (జయపుర)',
        'Asia/Jerusalem' => 'ఇజ్రాయిల్ సమయం (జరూసలేం)',
        'Asia/Kabul' => 'ఆఫ్ఘనిస్తాన్ సమయం (కాబుల్)',
        'Asia/Kamchatka' => 'పెట్రోపావ్లోవ్స్క్-కామ్ఛాట్స్కి సమయం (కమ్‌చత్కా)',
        'Asia/Karachi' => 'పాకిస్తాన్ సమయం (కరాచీ)',
        'Asia/Katmandu' => 'నేపాల్ సమయం (ఖాట్మండు)',
        'Asia/Khandyga' => 'యాకుట్స్క్ సమయం (కంద్యాగ)',
        'Asia/Krasnoyarsk' => 'క్రాస్నోయార్స్క్ సమయం (క్రసనోయార్స్క్)',
        'Asia/Kuala_Lumpur' => 'మలేషియా సమయం (కౌలాలంపూర్)',
        'Asia/Kuching' => 'మలేషియా సమయం (కుచింగ్)',
        'Asia/Kuwait' => 'అరేబియన్ సమయం (కువైట్)',
        'Asia/Macau' => 'చైనా సమయం (మకావ్)',
        'Asia/Magadan' => 'మగడాన్ సమయం',
        'Asia/Makassar' => 'సెంట్రల్ ఇండోనేషియా సమయం (మకాస్సర్)',
        'Asia/Manila' => 'ఫిలిప్పైన్ సమయం (మనీలా)',
        'Asia/Muscat' => 'గల్ఫ్ ప్రామాణిక సమయం (మస్కట్)',
        'Asia/Nicosia' => 'తూర్పు యూరోపియన్ సమయం (నికోసియా)',
        'Asia/Novokuznetsk' => 'క్రాస్నోయార్స్క్ సమయం (నొవొకుజ్‌నెట్‌స్క్)',
        'Asia/Novosibirsk' => 'నోవోసిబిర్స్క్ సమయం (నవోసిబిర్స్క్)',
        'Asia/Omsk' => 'ఓమ్స్క్ సమయం',
        'Asia/Oral' => 'పశ్చిమ కజకిస్తాన్ సమయం (ఓరల్)',
        'Asia/Phnom_Penh' => 'ఇండోచైనా సమయం (నోమ్‌పెన్హ్)',
        'Asia/Pontianak' => 'పశ్చిమ ఇండోనేషియా సమయం (పొన్టియనాక్)',
        'Asia/Pyongyang' => 'కొరియన్ సమయం (ప్యోంగాంగ్)',
        'Asia/Qatar' => 'అరేబియన్ సమయం (ఖతార్)',
        'Asia/Qostanay' => 'తూర్పు కజకి‌స్తాన్ సమయం (కోస్తానే)',
        'Asia/Qyzylorda' => 'పశ్చిమ కజకిస్తాన్ సమయం (క్విజిలోర్డా)',
        'Asia/Rangoon' => 'మయన్మార్ సమయం (యాంగన్)',
        'Asia/Riyadh' => 'అరేబియన్ సమయం (రియాధ్)',
        'Asia/Saigon' => 'ఇండోచైనా సమయం (హో చి మిన్హ్ నగరం)',
        'Asia/Sakhalin' => 'సఖాలిన్ సమయం',
        'Asia/Samarkand' => 'ఉజ్బెకిస్తాన్ సమయం (సమర్కాండ్)',
        'Asia/Seoul' => 'కొరియన్ సమయం (సియోల్)',
        'Asia/Shanghai' => 'చైనా సమయం (షాంఘై)',
        'Asia/Singapore' => 'సింగపూర్ ప్రామాణిక సమయం',
        'Asia/Srednekolymsk' => 'మగడాన్ సమయం (స్రెడ్నెకొలిమ్స్క్)',
        'Asia/Taipei' => 'తైపీ సమయం',
        'Asia/Tashkent' => 'ఉజ్బెకిస్తాన్ సమయం (తాష్కెంట్)',
        'Asia/Tbilisi' => 'జార్జియా సమయం (టిబిలిసి)',
        'Asia/Tehran' => 'ఇరాన్ సమయం (టెహ్రాన్)',
        'Asia/Thimphu' => 'భూటాన్ సమయం (థింఫు)',
        'Asia/Tokyo' => 'జపాన్ సమయం (టోక్యో)',
        'Asia/Tomsk' => 'రష్యా సమయం (టామ్స్క్)',
        'Asia/Ulaanbaatar' => 'ఉలన్ బతోర్ సమయం (ఉలాన్బాటర్)',
        'Asia/Urumqi' => 'చైనా సమయం (ఉరుమ్‌కీ)',
        'Asia/Ust-Nera' => 'వ్లాడివోస్టోక్ సమయం (అస్ట్-నెరా)',
        'Asia/Vientiane' => 'ఇండోచైనా సమయం (వియన్టైన్)',
        'Asia/Vladivostok' => 'వ్లాడివోస్టోక్ సమయం',
        'Asia/Yakutsk' => 'యాకుట్స్క్ సమయం (యకుట్స్క్)',
        'Asia/Yekaterinburg' => 'యెకటెరిన్‌బర్గ్ సమయం (యెకటెరింబర్గ్)',
        'Asia/Yerevan' => 'ఆర్మేనియా సమయం (యెరెవన్)',
        'Atlantic/Azores' => 'అజోర్స్ సమయం',
        'Atlantic/Bermuda' => 'అట్లాంటిక్ సమయం (బెర్ముడా)',
        'Atlantic/Canary' => 'పశ్చిమ యూరోపియన్ సమయం (కెనరీ)',
        'Atlantic/Cape_Verde' => 'కేప్ వెర్డె సమయం',
        'Atlantic/Faeroe' => 'పశ్చిమ యూరోపియన్ సమయం (ఫారో)',
        'Atlantic/Madeira' => 'పశ్చిమ యూరోపియన్ సమయం (మదైరా)',
        'Atlantic/Reykjavik' => 'గ్రీన్‌విచ్ సగటు సమయం (రెక్జావిక్)',
        'Atlantic/South_Georgia' => 'దక్షిణ జార్జియా సమయం',
        'Atlantic/St_Helena' => 'గ్రీన్‌విచ్ సగటు సమయం (సెయింట్ హెలెనా)',
        'Atlantic/Stanley' => 'ఫాక్‌ల్యాండ్ దీవుల సమయం (స్టాన్లీ)',
        'Australia/Adelaide' => 'ఆస్ట్రేలియా మధ్యమ సమయం (అడెలైడ్)',
        'Australia/Brisbane' => 'తూర్పు ఆస్ట్రేలియా సమయం (బ్రిస్‌బెయిన్)',
        'Australia/Broken_Hill' => 'ఆస్ట్రేలియా మధ్యమ సమయం (బ్రోకెన్ హిల్)',
        'Australia/Currie' => 'తూర్పు ఆస్ట్రేలియా సమయం (కర్రీ)',
        'Australia/Darwin' => 'ఆస్ట్రేలియా మధ్యమ సమయం (డార్విన్)',
        'Australia/Eucla' => 'ఆస్ట్రేలియా మధ్యమ పశ్చిమ సమయం (యుక్లా)',
        'Australia/Hobart' => 'తూర్పు ఆస్ట్రేలియా సమయం (హోబర్ట్)',
        'Australia/Lindeman' => 'తూర్పు ఆస్ట్రేలియా సమయం (లిండెమాన్)',
        'Australia/Lord_Howe' => 'లార్డ్ హోవ్ సమయం (లార్డ్ హౌ)',
        'Australia/Melbourne' => 'తూర్పు ఆస్ట్రేలియా సమయం (మెల్బోర్న్)',
        'Australia/Perth' => 'పశ్చిమ ఆస్ట్రేలియా సమయం (పెర్త్)',
        'Australia/Sydney' => 'తూర్పు ఆస్ట్రేలియా సమయం (సిడ్నీ)',
        'CST6CDT' => 'మధ్యమ సమయం',
        'EST5EDT' => 'తూర్పు సమయం',
        'Etc/GMT' => 'గ్రీన్‌విచ్ సగటు సమయం',
        'Etc/UTC' => 'సమన్వయ సార్వజనీన సమయం',
        'Europe/Amsterdam' => 'సెంట్రల్ యూరోపియన్ సమయం (ఆమ్‌స్టర్‌డామ్)',
        'Europe/Andorra' => 'సెంట్రల్ యూరోపియన్ సమయం (అండోరా)',
        'Europe/Astrakhan' => 'మాస్కో సమయం (అస్ట్రఖాన్)',
        'Europe/Athens' => 'తూర్పు యూరోపియన్ సమయం (ఏథెన్స్)',
        'Europe/Belgrade' => 'సెంట్రల్ యూరోపియన్ సమయం (బెల్‌గ్రేడ్)',
        'Europe/Berlin' => 'సెంట్రల్ యూరోపియన్ సమయం (బెర్లిన్)',
        'Europe/Bratislava' => 'సెంట్రల్ యూరోపియన్ సమయం (బ్రాటిస్లావా)',
        'Europe/Brussels' => 'సెంట్రల్ యూరోపియన్ సమయం (బ్రస్సెల్స్)',
        'Europe/Bucharest' => 'తూర్పు యూరోపియన్ సమయం (బుకారెస్ట్)',
        'Europe/Budapest' => 'సెంట్రల్ యూరోపియన్ సమయం (బుడాపెస్ట్)',
        'Europe/Busingen' => 'సెంట్రల్ యూరోపియన్ సమయం (బసింజన్)',
        'Europe/Chisinau' => 'తూర్పు యూరోపియన్ సమయం (చిసినావ్)',
        'Europe/Copenhagen' => 'సెంట్రల్ యూరోపియన్ సమయం (కోపెన్హాగన్)',
        'Europe/Dublin' => 'గ్రీన్‌విచ్ సగటు సమయం (డబ్లిన్)',
        'Europe/Gibraltar' => 'సెంట్రల్ యూరోపియన్ సమయం (జిబ్రాల్టర్)',
        'Europe/Guernsey' => 'గ్రీన్‌విచ్ సగటు సమయం (గ్వెర్న్సే)',
        'Europe/Helsinki' => 'తూర్పు యూరోపియన్ సమయం (హెల్సింకి)',
        'Europe/Isle_of_Man' => 'గ్రీన్‌విచ్ సగటు సమయం (ఐల్ ఆఫ్ మేన్)',
        'Europe/Istanbul' => 'టర్కీ సమయం (ఇస్తాంబుల్)',
        'Europe/Jersey' => 'గ్రీన్‌విచ్ సగటు సమయం (జెర్సీ)',
        'Europe/Kaliningrad' => 'తూర్పు యూరోపియన్ సమయం (కలినిన్‌గ్రద్)',
        'Europe/Kiev' => 'తూర్పు యూరోపియన్ సమయం (కీవ్)',
        'Europe/Kirov' => 'రష్యా సమయం (కిరోవ్)',
        'Europe/Lisbon' => 'పశ్చిమ యూరోపియన్ సమయం (లిస్బన్)',
        'Europe/Ljubljana' => 'సెంట్రల్ యూరోపియన్ సమయం (ల్యూబ్ల్యానా)',
        'Europe/London' => 'గ్రీన్‌విచ్ సగటు సమయం (లండన్)',
        'Europe/Luxembourg' => 'సెంట్రల్ యూరోపియన్ సమయం (లక్సెంబర్గ్)',
        'Europe/Madrid' => 'సెంట్రల్ యూరోపియన్ సమయం (మాడ్రిడ్)',
        'Europe/Malta' => 'సెంట్రల్ యూరోపియన్ సమయం (మాల్టా)',
        'Europe/Mariehamn' => 'తూర్పు యూరోపియన్ సమయం (మారీయుహమ్)',
        'Europe/Minsk' => 'మాస్కో సమయం (మిన్స్క్)',
        'Europe/Monaco' => 'సెంట్రల్ యూరోపియన్ సమయం (మొనాకో)',
        'Europe/Moscow' => 'మాస్కో సమయం',
        'Europe/Oslo' => 'సెంట్రల్ యూరోపియన్ సమయం (ఓస్లో)',
        'Europe/Paris' => 'సెంట్రల్ యూరోపియన్ సమయం (ప్యారిస్)',
        'Europe/Podgorica' => 'సెంట్రల్ యూరోపియన్ సమయం (పోడ్గోరికా)',
        'Europe/Prague' => 'సెంట్రల్ యూరోపియన్ సమయం (ప్రాగ్)',
        'Europe/Riga' => 'తూర్పు యూరోపియన్ సమయం (రీగా)',
        'Europe/Rome' => 'సెంట్రల్ యూరోపియన్ సమయం (రోమ్)',
        'Europe/Samara' => 'సమారా సమయం',
        'Europe/San_Marino' => 'సెంట్రల్ యూరోపియన్ సమయం (శాన్ మారినో)',
        'Europe/Sarajevo' => 'సెంట్రల్ యూరోపియన్ సమయం (సరాజోవో)',
        'Europe/Saratov' => 'మాస్కో సమయం (సరాటవ్)',
        'Europe/Simferopol' => 'మాస్కో సమయం (సిమ్‌ఫెరోపోల్)',
        'Europe/Skopje' => 'సెంట్రల్ యూరోపియన్ సమయం (స్కోప్‌యే)',
        'Europe/Sofia' => 'తూర్పు యూరోపియన్ సమయం (సోఫియా)',
        'Europe/Stockholm' => 'సెంట్రల్ యూరోపియన్ సమయం (స్టాక్హోమ్)',
        'Europe/Tallinn' => 'తూర్పు యూరోపియన్ సమయం (తాల్లిన్)',
        'Europe/Tirane' => 'సెంట్రల్ యూరోపియన్ సమయం (టిరేన్)',
        'Europe/Ulyanovsk' => 'మాస్కో సమయం (ఉల్యనోవ్స్క్)',
        'Europe/Uzhgorod' => 'తూర్పు యూరోపియన్ సమయం (ఉజ్‌హోరోడ్)',
        'Europe/Vaduz' => 'సెంట్రల్ యూరోపియన్ సమయం (వాడుజ్)',
        'Europe/Vatican' => 'సెంట్రల్ యూరోపియన్ సమయం (వాటికన్)',
        'Europe/Vienna' => 'సెంట్రల్ యూరోపియన్ సమయం (వియన్నా)',
        'Europe/Vilnius' => 'తూర్పు యూరోపియన్ సమయం (విల్నియస్)',
        'Europe/Volgograd' => 'వోల్గోగ్రాడ్ సమయం',
        'Europe/Warsaw' => 'సెంట్రల్ యూరోపియన్ సమయం (వార్షా)',
        'Europe/Zagreb' => 'సెంట్రల్ యూరోపియన్ సమయం (జాగ్రెబ్)',
        'Europe/Zaporozhye' => 'తూర్పు యూరోపియన్ సమయం (జపరోజై)',
        'Europe/Zurich' => 'సెంట్రల్ యూరోపియన్ సమయం (జ్యూరిచ్)',
        'Indian/Antananarivo' => 'తూర్పు ఆఫ్రికా సమయం (అంటానానారివో)',
        'Indian/Chagos' => 'హిందూ మహా సముద్ర సమయం (చాగోస్)',
        'Indian/Christmas' => 'క్రిస్మస్ దీవి సమయం',
        'Indian/Cocos' => 'కోకోస్ దీవుల సమయం',
        'Indian/Comoro' => 'తూర్పు ఆఫ్రికా సమయం (కొమోరో)',
        'Indian/Kerguelen' => 'ఫ్రెంచ్ దక్షిణ మరియు అంటార్కిటిక్ సమయం (కెర్గ్యూలెన్)',
        'Indian/Mahe' => 'సీషెల్స్ సమయం (మాహె)',
        'Indian/Maldives' => 'మాల్దీవుల సమయం (మాల్దీవులు)',
        'Indian/Mauritius' => 'మారిషస్ సమయం',
        'Indian/Mayotte' => 'తూర్పు ఆఫ్రికా సమయం (మయోట్)',
        'Indian/Reunion' => 'రీయూనియన్ సమయం',
        'MST7MDT' => 'మౌంటెయిన్ సమయం',
        'PST8PDT' => 'పసిఫిక్ సమయం',
        'Pacific/Apia' => 'ఏపియా సమయం',
        'Pacific/Auckland' => 'న్యూజిల్యాండ్ సమయం (ఆక్లాండ్)',
        'Pacific/Bougainville' => 'పాపువా న్యూ గినియా సమయం (బొగెయిన్‌విల్లే)',
        'Pacific/Chatham' => 'చాథమ్ సమయం',
        'Pacific/Easter' => 'ఈస్టర్ దీవి సమయం',
        'Pacific/Efate' => 'వనౌటు సమయం (ఇఫేట్)',
        'Pacific/Enderbury' => 'ఫినిక్స్ దీవుల సమయం (ఎండర్బెరీ)',
        'Pacific/Fakaofo' => 'టోకెలావ్ సమయం (ఫాకోఫో)',
        'Pacific/Fiji' => 'ఫిజీ సమయం (ఫీజీ)',
        'Pacific/Funafuti' => 'తువాలు సమయం (ఫునాఫుటి)',
        'Pacific/Galapagos' => 'గాలాపాగోస్ సమయం',
        'Pacific/Gambier' => 'గాంబియర్ సమయం (గాంబియేర్)',
        'Pacific/Guadalcanal' => 'సోలమన్ దీవుల సమయం (గ్వాడల్కెనాల్)',
        'Pacific/Guam' => 'చామర్రో ప్రామాణిక సమయం (గ్వామ్)',
        'Pacific/Honolulu' => 'హవాయ్-అల్యూషియన్ సమయం (హోనోలులు)',
        'Pacific/Johnston' => 'హవాయ్-అల్యూషియన్ సమయం (జాన్సటన్)',
        'Pacific/Kiritimati' => 'లైన్ దీవుల సమయం (కిరీటిమాటి)',
        'Pacific/Kosrae' => 'కోస్రాయి సమయం (కోస్రే)',
        'Pacific/Kwajalein' => 'మార్షల్ దీవుల సమయం (క్వాజాలైన్)',
        'Pacific/Majuro' => 'మార్షల్ దీవుల సమయం (మజురో)',
        'Pacific/Marquesas' => 'మార్క్వేసాస్ సమయం',
        'Pacific/Midway' => 'సమోవా సమయం (మిడ్వే)',
        'Pacific/Nauru' => 'నౌరు సమయం',
        'Pacific/Niue' => 'నియూ సమయం',
        'Pacific/Norfolk' => 'నార్ఫోక్ దీవి సమయం (నోర్ఫోక్)',
        'Pacific/Noumea' => 'న్యూ కాలెడోనియా సమయం (నౌమియా)',
        'Pacific/Pago_Pago' => 'సమోవా సమయం (పాగో పాగో)',
        'Pacific/Palau' => 'పాలావ్ సమయం',
        'Pacific/Pitcairn' => 'పిట్‌కైర్న్ సమయం',
        'Pacific/Ponape' => 'పొనేప్ సమయం (పోన్‌పై)',
        'Pacific/Port_Moresby' => 'పాపువా న్యూ గినియా సమయం (పోర్ట్ మోరెస్బే)',
        'Pacific/Rarotonga' => 'కుక్ దీవుల సమయం (రరోటోంగా)',
        'Pacific/Saipan' => 'చామర్రో ప్రామాణిక సమయం (సాయ్పాన్)',
        'Pacific/Tahiti' => 'తహితి సమయం',
        'Pacific/Tarawa' => 'గిల్బర్ట్ దీవుల సమయం (టరావా)',
        'Pacific/Tongatapu' => 'టాంగా సమయం (టోంగాటాపు)',
        'Pacific/Truk' => 'చక్ సమయం (చుక్)',
        'Pacific/Wake' => 'వేక్ దీవి సమయం',
        'Pacific/Wallis' => 'వాలీస్ మరియు ఫుటునా సమయం (వాల్లిస్)',
    ],
    'Meta' => [
    ],
];
