<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'peseta andorrana',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham degli Emirati Arabi Uniti',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afgani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albanese',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'dram armeno',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'fiorino delle Antille olandesi',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolano',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'kwanza angolano (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'nuovo kwanza angolano (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'kwanza reajustado angolano (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'austral argentino',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'peso argentino (vecchio Cod.)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'peso argentino',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'scellino austriaco',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'dollaro australiano',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'fiorino di Aruba',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'manat azero (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat azero',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'dinar Bosnia-Herzegovina',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'marco convertibile della Bosnia-Herzegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dollaro di Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'taka bangladese',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'franco belga (convertibile)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'franco belga',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'franco belga (finanziario)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'lev bulgaro (1962–1999)',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lev bulgaro',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinaro del Bahrein',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'franco del Burundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dollaro delle Bermuda',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'dollaro del Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'peso boliviano',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'mvdol boliviano',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'cruzeiro novo brasiliano (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'cruzado brasiliano',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'cruzeiro brasiliano (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'real brasiliano',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'cruzado novo brasiliano',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'cruzeiro brasiliano',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dollaro delle Bahamas',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ngultrum bhutanese',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'kyat birmano',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula del Botswana',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'nuovo rublo bielorusso (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rublo bielorusso',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'rublo bielorusso (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dollaro del Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'dollaro canadese',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'franco congolese',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'franco svizzero',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'unidades de fomento chilene',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso cileno',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'renmimbi cinese offshore',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'renminbi cinese',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso colombiano',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colón costaricano',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'antico dinaro serbo',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'corona forte cecoslovacca',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso cubano convertibile',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso cubano',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo capoverdiano',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'sterlina cipriota',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'corona ceca',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'ostmark della Germania Orientale',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'marco tedesco',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'franco di Gibuti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'corona danese',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominicano',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinaro algerino',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'sucre dell’Ecuador',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'unidad de valor constante (UVC) dell’Ecuador',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'corona dell’Estonia',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'sterlina egiziana',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nakfa eritreo',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'peseta spagnola account',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'peseta spagnola account convertibile',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'peseta spagnola',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr etiope',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'markka finlandese',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dollaro delle Figi',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'sterlina delle Falkland',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'franco francese',
        ],
        'GBP' => [
            0 => '£',
            1 => 'sterlina britannica',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'kupon larit georgiano',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'lari georgiano',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'cedi del Ghana',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cedi ghanese',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'sterlina di Gibilterra',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambiano',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'franco della Guinea',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'syli della Guinea',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekwele della Guinea Equatoriale',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'dracma greca',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal guatemalteco',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'escudo della Guinea portoghese',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'peso della Guinea-Bissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dollaro della Guyana',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'dollaro di Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira honduregna',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'dinaro croato',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna croata',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haitiano',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'fiorino ungherese',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'rupia indonesiana',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'sterlina irlandese',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'sterlina israeliana',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'nuovo siclo israeliano',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'rupia indiana',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'dinaro iracheno',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'rial iraniano',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'corona islandese',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'lira italiana',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dollaro giamaicano',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'dinaro giordano',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'yen giapponese',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'scellino keniota',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'som kirghiso',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'riel cambogiano',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'franco comoriano',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'won nordcoreano',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'won sudcoreano',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'dinaro kuwaitiano',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dollaro delle Isole Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'tenge kazako',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip laotiano',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'lira libanese',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'rupia di Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dollaro liberiano',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti del Lesotho',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litas lituano',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'talonas lituani',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'franco convertibile del Lussemburgo',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'franco del Lussemburgo',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'franco finanziario del Lussemburgo',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'lats lettone',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'rublo lettone',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinaro libico',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marocchino',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'franco marocchino',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'leu moldavo',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary malgascio',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'franco malgascio',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'dinaro macedone',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'dinaro macedone (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'franco di Mali',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'kyat di Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'tugrik mongolo',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'pataca di Macao',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ouguiya della Mauritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ouguiya della Mauritania',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'lira maltese',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'sterlina maltese',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupia mauriziana',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'rufiyaa delle Maldive',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha malawiano',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'peso messicano',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'peso messicano d’argento (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'unidad de inversion (UDI) messicana',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'ringgit malese',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'escudo del Mozambico',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical mozambicano',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dollaro namibiano',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nigeriana',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'cordoba nicaraguense',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'córdoba nicaraguense',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'fiorino olandese',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'corona norvegese',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'rupia nepalese',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'dollaro neozelandese',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'rial omanita',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa panamense',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'inti peruviano',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol peruviano',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'sol peruviano (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina papuana',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'peso filippino',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'rupia pakistana',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'zloty polacco',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'złoty Polacco (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'escudo portoghese',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guaraní paraguayano',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'rial qatariano',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'dollaro della Rhodesia',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'leu della Romania',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'leu rumeno',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinaro serbo',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rublo russo',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'rublo della CSI',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'franco ruandese',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'riyal saudita',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dollaro delle Isole Salomone',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupia delle Seychelles',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'dinaro sudanese',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sterlina sudanese',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'corona svedese',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'dollaro di Singapore',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'sterlina di Sant’Elena',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'tallero sloveno',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'corona slovacca',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone della Sierra Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'scellino somalo',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dollaro del Suriname',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'fiorino del Suriname',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'sterlina sud-sudanese',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra di Sao Tomé e Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra di Sao Tomé e Príncipe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'rublo sovietico',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'colón salvadoregno',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'lira siriana',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni dello Swaziland',
        ],
        'THB' => [
            0 => '฿',
            1 => 'baht thailandese',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'rublo del Tajikistan',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'somoni tagiko',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'manat turkmeno (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'manat turkmeno',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinaro tunisino',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'paʻanga tongano',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'escudo di Timor',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'lira turca (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'lira turca',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dollaro di Trinidad e Tobago',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'nuovo dollaro taiwanese',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'scellino della Tanzania',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'grivnia ucraina',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'karbovanetz ucraino',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'scellino ugandese (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'scellino ugandese',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'dollaro statunitense',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'dollaro statunitense (next day)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'dollaro statunitense (same day)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'peso uruguaiano in unità indicizzate',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'peso uruguaiano (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso uruguayano',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'sum uzbeco',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'bolivar venezuelano (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'bolívar venezuelano (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'bolívar venezuelano',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'dong vietnamita',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu di Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala samoano',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'franco CFA BEAC',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'dollaro dei Caraibi orientali',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'franco oro francese',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'franco UIC francese',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'franco CFA BCEAO',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'franco CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'fondi RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'dinaro dello Yemen',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'riyal yemenita',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'dinaro forte yugoslavo',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'dinaro noviy yugoslavo',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'dinaro convertibile yugoslavo',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'rand sudafricano (finanziario)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand sudafricano',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'kwacha dello Zambia (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha zambiano',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'nuovo zaire dello Zaire',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zaire dello Zaire',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'dollaro dello Zimbabwe',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'dollaro zimbabwiano (2009)',
        ],
    ],
];
