<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arabískt',
        'Aran' => 'nastaliq',
        'Armn' => 'armenskt',
        'Bali' => 'balinesíska',
        'Batk' => 'batakíska',
        'Beng' => 'bengalskt',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmíska',
        'Brai' => 'blindraletur',
        'Cakm' => 'chakma',
        'Cans' => 'samræmt kanadískt samstöfuletur frumbyggja',
        'Cher' => 'cherokí',
        'Copt' => 'koptíska',
        'Cyrl' => 'kyrillískt',
        'Deva' => 'devanagari',
        'Ethi' => 'eþíópískt',
        'Geor' => 'georgískt',
        'Grek' => 'grískt',
        'Gujr' => 'gújaratí',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'kínverskt',
        'Hans' => 'einfaldað',
        'Hant' => 'hefðbundið',
        'Hebr' => 'hebreskt',
        'Hira' => 'hiragana',
        'Hrkt' => 'japönsk samstöfuletur',
        'Jamo' => 'jamo',
        'Java' => 'javanesíska',
        'Jpan' => 'japanskt',
        'Kana' => 'katakana',
        'Khmr' => 'kmer',
        'Knda' => 'kannada',
        'Kore' => 'kóreskt',
        'Laoo' => 'lao',
        'Latn' => 'latneskt',
        'Mand' => 'mandaíska',
        'Mlym' => 'malalajam',
        'Mong' => 'mongólskt',
        'Mtei' => 'meitei mayek',
        'Mymr' => 'mjanmarskt',
        'Nkoo' => 'n-kó',
        'Olck' => 'ol chiki',
        'Orya' => 'oriya',
        'Rohg' => 'hanifi',
        'Sinh' => 'sinhala',
        'Sund' => 'sundanesíska',
        'Syrc' => 'syriakíska',
        'Taml' => 'tamílskt',
        'Telu' => 'telúgú',
        'Tfng' => 'tifinagh',
        'Thaa' => 'thaana',
        'Thai' => 'taílenskt',
        'Tibt' => 'tíbeskt',
        'Vaii' => 'vai',
        'Yiii' => 'yí',
        'Zmth' => 'stærðfræðitákn',
        'Zsye' => 'emoji-tákn',
        'Zsym' => 'tákn',
        'Zxxx' => 'óskrifað',
        'Zyyy' => 'almennt',
    ],
];
