<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirham',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angoley',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dolara aostralianina',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinar bahreïni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Farantsa Borondi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pola botsoaney',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dôlara Kanadianina',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Farantsa kôngôley',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Farantsa soisa',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yoan sinoa Renminbi',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Farantsa Djibotianina',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinara alzerianina',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'vola venty ejipsiana',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfà Eritreanina',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Bir etiopianina',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Eoro',
        ],
        'GBP' => [
            0 => '£',
            1 => 'livre sterling',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'cédi',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi gambianina',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Farantsa Gineanina',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Ropia Indianina',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yen Japoney',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shilling kenianina',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Farantsa Komorianina',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dôlara Liberianina',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinara Libyanina',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham marokianina',
        ],
        'MGA' => [
            0 => 'Ar',
            1 => 'Ariary',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya moritanianina (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya moritanianina',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Ropia maorisianina',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha malawite',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikaly',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dolara namibianina',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira nigerianina',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Farantsa Roande',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Rial saodianina',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Ropia Seysheloà',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Dinara Sodaney',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'livre soudanaise (1956–2007)',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'livre de Sainte-Hélène',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shilling somalianina',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinar tonizianina',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shilling tanzanianina',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilling ogandianina',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dolara amerikanina',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Farantsa CFA (BEAC)',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Farantsa CFA (BCEAO)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rand afrikanina tatsimo',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha zambianina (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha zambianina',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dôlara Zimbaboeanina',
        ],
    ],
];
