<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'am' => 'амхар',
        'ar' => 'гарәп',
        'arn' => 'мапуче',
        'as' => 'ассам',
        'az' => 'әзәрбайҗан',
        'ba' => 'башкорт',
        'ban' => 'бали',
        'be' => 'белорус',
        'bem' => 'бемба',
        'bg' => 'болгар',
        'bn' => 'бенгали',
        'bo' => 'тибет',
        'br' => 'бретон',
        'bs' => 'босния',
        'ca' => 'каталан',
        'ceb' => 'себуано',
        'chm' => 'мари',
        'chr' => 'чероки',
        'ckb' => 'үзәк көрд',
        'co' => 'корсика',
        'cs' => 'чех',
        'cy' => 'уэльс',
        'da' => 'дания',
        'de' => 'алман',
        'dsb' => 'түбән сорб',
        'dv' => 'мальдив',
        'dz' => 'дзонг-кха',
        'el' => 'грек',
        'en' => 'инглиз',
        'eo' => 'эсперанто',
        'es' => 'испан',
        'et' => 'эстон',
        'eu' => 'баск',
        'fa' => 'фарсы',
        'ff' => 'фула',
        'fi' => 'фин',
        'fil' => 'филиппин',
        'fo' => 'фарер',
        'fr' => 'француз',
        'ga' => 'ирланд',
        'gd' => 'шотланд гэль',
        'gl' => 'галисия',
        'gn' => 'гуарани',
        'gu' => 'гуҗарати',
        'ha' => 'хауса',
        'haw' => 'гавайи',
        'he' => 'яһүд',
        'hi' => 'һинд',
        'hil' => 'хилигайнон',
        'hr' => 'хорват',
        'hsb' => 'югары сорб',
        'ht' => 'гаити креол',
        'hu' => 'венгр',
        'hy' => 'әрмән',
        'hz' => 'гереро',
        'ibb' => 'ибибио',
        'id' => 'индонезия',
        'ig' => 'игбо',
        'is' => 'исланд',
        'it' => 'итальян',
        'iu' => 'инуктикут',
        'ja' => 'япон',
        'ka' => 'грузин',
        'kk' => 'казакъ',
        'km' => 'кхмер',
        'kn' => 'каннада',
        'ko' => 'корея',
        'kok' => 'конкани',
        'kr' => 'канури',
        'kru' => 'курух',
        'ks' => 'кашмири',
        'ku' => 'көрд',
        'ky' => 'кыргыз',
        'la' => 'латин',
        'lb' => 'люксембург',
        'lo' => 'лаос',
        'lt' => 'литва',
        'lv' => 'латыш',
        'men' => 'менде',
        'mg' => 'малагаси',
        'mi' => 'маори',
        'mk' => 'македон',
        'ml' => 'малаялам',
        'mn' => 'монгол',
        'mni' => 'манипури',
        'moh' => 'могаук',
        'mr' => 'маратхи',
        'ms' => 'малай',
        'mt' => 'мальта',
        'my' => 'бирма',
        'ne' => 'непали',
        'niu' => 'ниуэ',
        'nl' => 'голланд',
        'ny' => 'ньянҗа',
        'oc' => 'окситан',
        'om' => 'оромо',
        'or' => 'ория',
        'pa' => 'пәнҗаби',
        'pap' => 'папьяменто',
        'pl' => 'поляк',
        'ps' => 'пушту',
        'pt' => 'португал',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'rm' => 'ретороман',
        'ro' => 'румын',
        'ru' => 'рус',
        'rw' => 'руанда',
        'sa' => 'санскрит',
        'sah' => 'саха',
        'sat' => 'сантали',
        'sd' => 'синдһи',
        'se' => 'төньяк саам',
        'si' => 'сингал',
        'sk' => 'словак',
        'sl' => 'словен',
        'sma' => 'көньяк саам',
        'smj' => 'луле-саам',
        'smn' => 'инари-саам',
        'sms' => 'колтта-саам',
        'so' => 'сомали',
        'sq' => 'албан',
        'sr' => 'серб',
        'sv' => 'швед',
        'syr' => 'сүрия',
        'ta' => 'тамил',
        'te' => 'телугу',
        'tg' => 'таҗик',
        'th' => 'тай',
        'ti' => 'тигринья',
        'tk' => 'төрекмән',
        'to' => 'тонга',
        'tr' => 'төрек',
        'tt' => 'татар',
        'tzm' => 'үзәк атлас тамазигт',
        'ug' => 'уйгыр',
        'uk' => 'украин',
        'ur' => 'урду',
        'uz' => 'үзбәк',
        've' => 'венда',
        'vi' => 'вьетнам',
        'wo' => 'волоф',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'zh' => 'кытай',
    ],
    'LocalizedNames' => [
        'de_CH' => 'югары алман (Швейцария)',
        'en_GB' => 'Британия инглизчәсе',
        'en_US' => 'Америка инглизчәсе',
        'es_419' => 'испан (Латин Америкасы)',
        'es_ES' => 'испан (Европа)',
        'pt_PT' => 'португал (Европа)',
        'zh_Hans' => 'гадиләштерелгән кытай',
        'zh_Hant' => 'традицион кытай',
    ],
];
