<?php

return [
    'Names' => [
        'af' => '아프리칸스어',
        'af_NA' => '아프리칸스어(나미비아)',
        'af_ZA' => '아프리칸스어(남아프리카)',
        'ak' => '아칸어',
        'ak_GH' => '아칸어(가나)',
        'am' => '암하라어',
        'am_ET' => '암하라어(에티오피아)',
        'ar' => '아랍어',
        'ar_001' => '아랍어(세계)',
        'ar_AE' => '아랍어(아랍에미리트)',
        'ar_BH' => '아랍어(바레인)',
        'ar_DJ' => '아랍어(지부티)',
        'ar_DZ' => '아랍어(알제리)',
        'ar_EG' => '아랍어(이집트)',
        'ar_EH' => '아랍어(서사하라)',
        'ar_ER' => '아랍어(에리트리아)',
        'ar_IL' => '아랍어(이스라엘)',
        'ar_IQ' => '아랍어(이라크)',
        'ar_JO' => '아랍어(요르단)',
        'ar_KM' => '아랍어(코모로)',
        'ar_KW' => '아랍어(쿠웨이트)',
        'ar_LB' => '아랍어(레바논)',
        'ar_LY' => '아랍어(리비아)',
        'ar_MA' => '아랍어(모로코)',
        'ar_MR' => '아랍어(모리타니)',
        'ar_OM' => '아랍어(오만)',
        'ar_PS' => '아랍어(팔레스타인 지구)',
        'ar_QA' => '아랍어(카타르)',
        'ar_SA' => '아랍어(사우디아라비아)',
        'ar_SD' => '아랍어(수단)',
        'ar_SO' => '아랍어(소말리아)',
        'ar_SS' => '아랍어(남수단)',
        'ar_SY' => '아랍어(시리아)',
        'ar_TD' => '아랍어(차드)',
        'ar_TN' => '아랍어(튀니지)',
        'ar_YE' => '아랍어(예멘)',
        'as' => '아삼어',
        'as_IN' => '아삼어(인도)',
        'az' => '아제르바이잔어',
        'az_AZ' => '아제르바이잔어(아제르바이잔)',
        'az_Cyrl' => '아제르바이잔어(키릴 문자)',
        'az_Cyrl_AZ' => '아제르바이잔어(키릴 문자, 아제르바이잔)',
        'az_Latn' => '아제르바이잔어(로마자)',
        'az_Latn_AZ' => '아제르바이잔어(로마자, 아제르바이잔)',
        'be' => '벨라루스어',
        'be_BY' => '벨라루스어(벨라루스)',
        'bg' => '불가리아어',
        'bg_BG' => '불가리아어(불가리아)',
        'bm' => '밤바라어',
        'bm_ML' => '밤바라어(말리)',
        'bn' => '벵골어',
        'bn_BD' => '벵골어(방글라데시)',
        'bn_IN' => '벵골어(인도)',
        'bo' => '티베트어',
        'bo_CN' => '티베트어(중국)',
        'bo_IN' => '티베트어(인도)',
        'br' => '브르타뉴어',
        'br_FR' => '브르타뉴어(프랑스)',
        'bs' => '보스니아어',
        'bs_BA' => '보스니아어(보스니아 헤르체고비나)',
        'bs_Cyrl' => '보스니아어(키릴 문자)',
        'bs_Cyrl_BA' => '보스니아어(키릴 문자, 보스니아 헤르체고비나)',
        'bs_Latn' => '보스니아어(로마자)',
        'bs_Latn_BA' => '보스니아어(로마자, 보스니아 헤르체고비나)',
        'ca' => '카탈로니아어',
        'ca_AD' => '카탈로니아어(안도라)',
        'ca_ES' => '카탈로니아어(스페인)',
        'ca_FR' => '카탈로니아어(프랑스)',
        'ca_IT' => '카탈로니아어(이탈리아)',
        'ce' => '체첸어',
        'ce_RU' => '체첸어(러시아)',
        'cs' => '체코어',
        'cs_CZ' => '체코어(체코)',
        'cv' => '추바시어',
        'cv_RU' => '추바시어(러시아)',
        'cy' => '웨일스어',
        'cy_GB' => '웨일스어(영국)',
        'da' => '덴마크어',
        'da_DK' => '덴마크어(덴마크)',
        'da_GL' => '덴마크어(그린란드)',
        'de' => '독일어',
        'de_AT' => '독일어(오스트리아)',
        'de_BE' => '독일어(벨기에)',
        'de_CH' => '독일어(스위스)',
        'de_DE' => '독일어(독일)',
        'de_IT' => '독일어(이탈리아)',
        'de_LI' => '독일어(리히텐슈타인)',
        'de_LU' => '독일어(룩셈부르크)',
        'dz' => '종카어',
        'dz_BT' => '종카어(부탄)',
        'ee' => '에웨어',
        'ee_GH' => '에웨어(가나)',
        'ee_TG' => '에웨어(토고)',
        'el' => '그리스어',
        'el_CY' => '그리스어(키프로스)',
        'el_GR' => '그리스어(그리스)',
        'en' => '영어',
        'en_001' => '영어(세계)',
        'en_150' => '영어(유럽)',
        'en_AE' => '영어(아랍에미리트)',
        'en_AG' => '영어(앤티가 바부다)',
        'en_AI' => '영어(앵귈라)',
        'en_AS' => '영어(아메리칸 사모아)',
        'en_AT' => '영어(오스트리아)',
        'en_AU' => '영어(오스트레일리아)',
        'en_BB' => '영어(바베이도스)',
        'en_BE' => '영어(벨기에)',
        'en_BI' => '영어(부룬디)',
        'en_BM' => '영어(버뮤다)',
        'en_BS' => '영어(바하마)',
        'en_BW' => '영어(보츠와나)',
        'en_BZ' => '영어(벨리즈)',
        'en_CA' => '영어(캐나다)',
        'en_CC' => '영어(코코스 제도)',
        'en_CH' => '영어(스위스)',
        'en_CK' => '영어(쿡 제도)',
        'en_CM' => '영어(카메룬)',
        'en_CX' => '영어(크리스마스섬)',
        'en_CY' => '영어(키프로스)',
        'en_DE' => '영어(독일)',
        'en_DK' => '영어(덴마크)',
        'en_DM' => '영어(도미니카)',
        'en_ER' => '영어(에리트리아)',
        'en_FI' => '영어(핀란드)',
        'en_FJ' => '영어(피지)',
        'en_FK' => '영어(포클랜드 제도)',
        'en_FM' => '영어(미크로네시아)',
        'en_GB' => '영어(영국)',
        'en_GD' => '영어(그레나다)',
        'en_GG' => '영어(건지)',
        'en_GH' => '영어(가나)',
        'en_GI' => '영어(지브롤터)',
        'en_GM' => '영어(감비아)',
        'en_GU' => '영어(괌)',
        'en_GY' => '영어(가이아나)',
        'en_HK' => '영어(홍콩[중국 특별행정구])',
        'en_IE' => '영어(아일랜드)',
        'en_IL' => '영어(이스라엘)',
        'en_IM' => '영어(맨섬)',
        'en_IN' => '영어(인도)',
        'en_IO' => '영어(영국령 인도양 식민지)',
        'en_JE' => '영어(저지)',
        'en_JM' => '영어(자메이카)',
        'en_KE' => '영어(케냐)',
        'en_KI' => '영어(키리바시)',
        'en_KN' => '영어(세인트키츠 네비스)',
        'en_KY' => '영어(케이맨 제도)',
        'en_LC' => '영어(세인트루시아)',
        'en_LR' => '영어(라이베리아)',
        'en_LS' => '영어(레소토)',
        'en_MG' => '영어(마다가스카르)',
        'en_MH' => '영어(마셜 제도)',
        'en_MO' => '영어(마카오[중국 특별행정구])',
        'en_MP' => '영어(북마리아나제도)',
        'en_MS' => '영어(몬트세라트)',
        'en_MT' => '영어(몰타)',
        'en_MU' => '영어(모리셔스)',
        'en_MV' => '영어(몰디브)',
        'en_MW' => '영어(말라위)',
        'en_MY' => '영어(말레이시아)',
        'en_NA' => '영어(나미비아)',
        'en_NF' => '영어(노퍽섬)',
        'en_NG' => '영어(나이지리아)',
        'en_NL' => '영어(네덜란드)',
        'en_NR' => '영어(나우루)',
        'en_NU' => '영어(니우에)',
        'en_NZ' => '영어(뉴질랜드)',
        'en_PG' => '영어(파푸아뉴기니)',
        'en_PH' => '영어(필리핀)',
        'en_PK' => '영어(파키스탄)',
        'en_PN' => '영어(핏케언 제도)',
        'en_PR' => '영어(푸에르토리코)',
        'en_PW' => '영어(팔라우)',
        'en_RW' => '영어(르완다)',
        'en_SB' => '영어(솔로몬 제도)',
        'en_SC' => '영어(세이셸)',
        'en_SD' => '영어(수단)',
        'en_SE' => '영어(스웨덴)',
        'en_SG' => '영어(싱가포르)',
        'en_SH' => '영어(세인트헬레나)',
        'en_SI' => '영어(슬로베니아)',
        'en_SL' => '영어(시에라리온)',
        'en_SS' => '영어(남수단)',
        'en_SX' => '영어(신트마르턴)',
        'en_SZ' => '영어(에스와티니)',
        'en_TC' => '영어(터크스 케이커스 제도)',
        'en_TK' => '영어(토켈라우)',
        'en_TO' => '영어(통가)',
        'en_TT' => '영어(트리니다드 토바고)',
        'en_TV' => '영어(투발루)',
        'en_TZ' => '영어(탄자니아)',
        'en_UG' => '영어(우간다)',
        'en_UM' => '영어(미국령 해외 제도)',
        'en_US' => '영어(미국)',
        'en_VC' => '영어(세인트빈센트그레나딘)',
        'en_VG' => '영어(영국령 버진아일랜드)',
        'en_VI' => '영어(미국령 버진아일랜드)',
        'en_VU' => '영어(바누아투)',
        'en_WS' => '영어(사모아)',
        'en_ZA' => '영어(남아프리카)',
        'en_ZM' => '영어(잠비아)',
        'en_ZW' => '영어(짐바브웨)',
        'eo' => '에스페란토어',
        'eo_001' => '에스페란토어(세계)',
        'es' => '스페인어',
        'es_419' => '스페인어(라틴 아메리카)',
        'es_AR' => '스페인어(아르헨티나)',
        'es_BO' => '스페인어(볼리비아)',
        'es_BR' => '스페인어(브라질)',
        'es_BZ' => '스페인어(벨리즈)',
        'es_CL' => '스페인어(칠레)',
        'es_CO' => '스페인어(콜롬비아)',
        'es_CR' => '스페인어(코스타리카)',
        'es_CU' => '스페인어(쿠바)',
        'es_DO' => '스페인어(도미니카 공화국)',
        'es_EC' => '스페인어(에콰도르)',
        'es_ES' => '스페인어(스페인)',
        'es_GQ' => '스페인어(적도 기니)',
        'es_GT' => '스페인어(과테말라)',
        'es_HN' => '스페인어(온두라스)',
        'es_MX' => '스페인어(멕시코)',
        'es_NI' => '스페인어(니카라과)',
        'es_PA' => '스페인어(파나마)',
        'es_PE' => '스페인어(페루)',
        'es_PH' => '스페인어(필리핀)',
        'es_PR' => '스페인어(푸에르토리코)',
        'es_PY' => '스페인어(파라과이)',
        'es_SV' => '스페인어(엘살바도르)',
        'es_US' => '스페인어(미국)',
        'es_UY' => '스페인어(우루과이)',
        'es_VE' => '스페인어(베네수엘라)',
        'et' => '에스토니아어',
        'et_EE' => '에스토니아어(에스토니아)',
        'eu' => '바스크어',
        'eu_ES' => '바스크어(스페인)',
        'fa' => '페르시아어',
        'fa_AF' => '페르시아어(아프가니스탄)',
        'fa_IR' => '페르시아어(이란)',
        'ff' => '풀라어',
        'ff_Adlm' => '풀라어(아들람 문자)',
        'ff_Adlm_BF' => '풀라어(아들람 문자, 부르키나파소)',
        'ff_Adlm_CM' => '풀라어(아들람 문자, 카메룬)',
        'ff_Adlm_GH' => '풀라어(아들람 문자, 가나)',
        'ff_Adlm_GM' => '풀라어(아들람 문자, 감비아)',
        'ff_Adlm_GN' => '풀라어(아들람 문자, 기니)',
        'ff_Adlm_GW' => '풀라어(아들람 문자, 기니비사우)',
        'ff_Adlm_LR' => '풀라어(아들람 문자, 라이베리아)',
        'ff_Adlm_MR' => '풀라어(아들람 문자, 모리타니)',
        'ff_Adlm_NE' => '풀라어(아들람 문자, 니제르)',
        'ff_Adlm_NG' => '풀라어(아들람 문자, 나이지리아)',
        'ff_Adlm_SL' => '풀라어(아들람 문자, 시에라리온)',
        'ff_Adlm_SN' => '풀라어(아들람 문자, 세네갈)',
        'ff_CM' => '풀라어(카메룬)',
        'ff_GN' => '풀라어(기니)',
        'ff_Latn' => '풀라어(로마자)',
        'ff_Latn_BF' => '풀라어(로마자, 부르키나파소)',
        'ff_Latn_CM' => '풀라어(로마자, 카메룬)',
        'ff_Latn_GH' => '풀라어(로마자, 가나)',
        'ff_Latn_GM' => '풀라어(로마자, 감비아)',
        'ff_Latn_GN' => '풀라어(로마자, 기니)',
        'ff_Latn_GW' => '풀라어(로마자, 기니비사우)',
        'ff_Latn_LR' => '풀라어(로마자, 라이베리아)',
        'ff_Latn_MR' => '풀라어(로마자, 모리타니)',
        'ff_Latn_NE' => '풀라어(로마자, 니제르)',
        'ff_Latn_NG' => '풀라어(로마자, 나이지리아)',
        'ff_Latn_SL' => '풀라어(로마자, 시에라리온)',
        'ff_Latn_SN' => '풀라어(로마자, 세네갈)',
        'ff_MR' => '풀라어(모리타니)',
        'ff_SN' => '풀라어(세네갈)',
        'fi' => '핀란드어',
        'fi_FI' => '핀란드어(핀란드)',
        'fo' => '페로어',
        'fo_DK' => '페로어(덴마크)',
        'fo_FO' => '페로어(페로 제도)',
        'fr' => '프랑스어',
        'fr_BE' => '프랑스어(벨기에)',
        'fr_BF' => '프랑스어(부르키나파소)',
        'fr_BI' => '프랑스어(부룬디)',
        'fr_BJ' => '프랑스어(베냉)',
        'fr_BL' => '프랑스어(생바르텔레미)',
        'fr_CA' => '프랑스어(캐나다)',
        'fr_CD' => '프랑스어(콩고-킨샤사)',
        'fr_CF' => '프랑스어(중앙 아프리카 공화국)',
        'fr_CG' => '프랑스어(콩고-브라자빌)',
        'fr_CH' => '프랑스어(스위스)',
        'fr_CI' => '프랑스어(코트디부아르)',
        'fr_CM' => '프랑스어(카메룬)',
        'fr_DJ' => '프랑스어(지부티)',
        'fr_DZ' => '프랑스어(알제리)',
        'fr_FR' => '프랑스어(프랑스)',
        'fr_GA' => '프랑스어(가봉)',
        'fr_GF' => '프랑스어(프랑스령 기아나)',
        'fr_GN' => '프랑스어(기니)',
        'fr_GP' => '프랑스어(과들루프)',
        'fr_GQ' => '프랑스어(적도 기니)',
        'fr_HT' => '프랑스어(아이티)',
        'fr_KM' => '프랑스어(코모로)',
        'fr_LU' => '프랑스어(룩셈부르크)',
        'fr_MA' => '프랑스어(모로코)',
        'fr_MC' => '프랑스어(모나코)',
        'fr_MF' => '프랑스어(생마르탱)',
        'fr_MG' => '프랑스어(마다가스카르)',
        'fr_ML' => '프랑스어(말리)',
        'fr_MQ' => '프랑스어(마르티니크)',
        'fr_MR' => '프랑스어(모리타니)',
        'fr_MU' => '프랑스어(모리셔스)',
        'fr_NC' => '프랑스어(뉴칼레도니아)',
        'fr_NE' => '프랑스어(니제르)',
        'fr_PF' => '프랑스어(프랑스령 폴리네시아)',
        'fr_PM' => '프랑스어(생피에르 미클롱)',
        'fr_RE' => '프랑스어(레위니옹)',
        'fr_RW' => '프랑스어(르완다)',
        'fr_SC' => '프랑스어(세이셸)',
        'fr_SN' => '프랑스어(세네갈)',
        'fr_SY' => '프랑스어(시리아)',
        'fr_TD' => '프랑스어(차드)',
        'fr_TG' => '프랑스어(토고)',
        'fr_TN' => '프랑스어(튀니지)',
        'fr_VU' => '프랑스어(바누아투)',
        'fr_WF' => '프랑스어(왈리스-푸투나 제도)',
        'fr_YT' => '프랑스어(마요트)',
        'fy' => '서부 프리지아어',
        'fy_NL' => '서부 프리지아어(네덜란드)',
        'ga' => '아일랜드어',
        'ga_GB' => '아일랜드어(영국)',
        'ga_IE' => '아일랜드어(아일랜드)',
        'gd' => '스코틀랜드 게일어',
        'gd_GB' => '스코틀랜드 게일어(영국)',
        'gl' => '갈리시아어',
        'gl_ES' => '갈리시아어(스페인)',
        'gu' => '구자라트어',
        'gu_IN' => '구자라트어(인도)',
        'gv' => '맹크스어',
        'gv_IM' => '맹크스어(맨섬)',
        'ha' => '하우사어',
        'ha_GH' => '하우사어(가나)',
        'ha_NE' => '하우사어(니제르)',
        'ha_NG' => '하우사어(나이지리아)',
        'he' => '히브리어',
        'he_IL' => '히브리어(이스라엘)',
        'hi' => '힌디어',
        'hi_IN' => '힌디어(인도)',
        'hi_Latn' => '힌디어(로마자)',
        'hi_Latn_IN' => '힌디어(로마자, 인도)',
        'hr' => '크로아티아어',
        'hr_BA' => '크로아티아어(보스니아 헤르체고비나)',
        'hr_HR' => '크로아티아어(크로아티아)',
        'hu' => '헝가리어',
        'hu_HU' => '헝가리어(헝가리)',
        'hy' => '아르메니아어',
        'hy_AM' => '아르메니아어(아르메니아)',
        'ia' => '인터링구아',
        'ia_001' => '인터링구아(세계)',
        'id' => '인도네시아어',
        'id_ID' => '인도네시아어(인도네시아)',
        'ig' => '이그보어',
        'ig_NG' => '이그보어(나이지리아)',
        'ii' => '쓰촨 이어',
        'ii_CN' => '쓰촨 이어(중국)',
        'is' => '아이슬란드어',
        'is_IS' => '아이슬란드어(아이슬란드)',
        'it' => '이탈리아어',
        'it_CH' => '이탈리아어(스위스)',
        'it_IT' => '이탈리아어(이탈리아)',
        'it_SM' => '이탈리아어(산마리노)',
        'it_VA' => '이탈리아어(바티칸 시국)',
        'ja' => '일본어',
        'ja_JP' => '일본어(일본)',
        'jv' => '자바어',
        'jv_ID' => '자바어(인도네시아)',
        'ka' => '조지아어',
        'ka_GE' => '조지아어(조지아)',
        'ki' => '키쿠유어',
        'ki_KE' => '키쿠유어(케냐)',
        'kk' => '카자흐어',
        'kk_KZ' => '카자흐어(카자흐스탄)',
        'kl' => '그린란드어',
        'kl_GL' => '그린란드어(그린란드)',
        'km' => '크메르어',
        'km_KH' => '크메르어(캄보디아)',
        'kn' => '칸나다어',
        'kn_IN' => '칸나다어(인도)',
        'ko' => '한국어',
        'ko_KP' => '한국어(북한)',
        'ko_KR' => '한국어(대한민국)',
        'ks' => '카슈미르어',
        'ks_Arab' => '카슈미르어(아랍 문자)',
        'ks_Arab_IN' => '카슈미르어(아랍 문자, 인도)',
        'ks_Deva' => '카슈미르어(데바나가리 문자)',
        'ks_Deva_IN' => '카슈미르어(데바나가리 문자, 인도)',
        'ks_IN' => '카슈미르어(인도)',
        'ku' => '쿠르드어',
        'ku_TR' => '쿠르드어(터키)',
        'kw' => '콘월어',
        'kw_GB' => '콘월어(영국)',
        'ky' => '키르기스어',
        'ky_KG' => '키르기스어(키르기스스탄)',
        'lb' => '룩셈부르크어',
        'lb_LU' => '룩셈부르크어(룩셈부르크)',
        'lg' => '간다어',
        'lg_UG' => '간다어(우간다)',
        'ln' => '링갈라어',
        'ln_AO' => '링갈라어(앙골라)',
        'ln_CD' => '링갈라어(콩고-킨샤사)',
        'ln_CF' => '링갈라어(중앙 아프리카 공화국)',
        'ln_CG' => '링갈라어(콩고-브라자빌)',
        'lo' => '라오어',
        'lo_LA' => '라오어(라오스)',
        'lt' => '리투아니아어',
        'lt_LT' => '리투아니아어(리투아니아)',
        'lu' => '루바-카탄가어',
        'lu_CD' => '루바-카탄가어(콩고-킨샤사)',
        'lv' => '라트비아어',
        'lv_LV' => '라트비아어(라트비아)',
        'mg' => '말라가시어',
        'mg_MG' => '말라가시어(마다가스카르)',
        'mi' => '마오리어',
        'mi_NZ' => '마오리어(뉴질랜드)',
        'mk' => '마케도니아어',
        'mk_MK' => '마케도니아어(북마케도니아)',
        'ml' => '말라얄람어',
        'ml_IN' => '말라얄람어(인도)',
        'mn' => '몽골어',
        'mn_MN' => '몽골어(몽골)',
        'mr' => '마라티어',
        'mr_IN' => '마라티어(인도)',
        'ms' => '말레이어',
        'ms_BN' => '말레이어(브루나이)',
        'ms_ID' => '말레이어(인도네시아)',
        'ms_MY' => '말레이어(말레이시아)',
        'ms_SG' => '말레이어(싱가포르)',
        'mt' => '몰타어',
        'mt_MT' => '몰타어(몰타)',
        'my' => '버마어',
        'my_MM' => '버마어(미얀마)',
        'nb' => '노르웨이어[보크말]',
        'nb_NO' => '노르웨이어[보크말](노르웨이)',
        'nb_SJ' => '노르웨이어[보크말](스발바르제도-얀마웬섬)',
        'nd' => '북부 은데벨레어',
        'nd_ZW' => '북부 은데벨레어(짐바브웨)',
        'ne' => '네팔어',
        'ne_IN' => '네팔어(인도)',
        'ne_NP' => '네팔어(네팔)',
        'nl' => '네덜란드어',
        'nl_AW' => '네덜란드어(아루바)',
        'nl_BE' => '네덜란드어(벨기에)',
        'nl_BQ' => '네덜란드어(네덜란드령 카리브)',
        'nl_CW' => '네덜란드어(퀴라소)',
        'nl_NL' => '네덜란드어(네덜란드)',
        'nl_SR' => '네덜란드어(수리남)',
        'nl_SX' => '네덜란드어(신트마르턴)',
        'nn' => '노르웨이어[니노르스크]',
        'nn_NO' => '노르웨이어[니노르스크](노르웨이)',
        'no' => '노르웨이어',
        'no_NO' => '노르웨이어(노르웨이)',
        'om' => '오로모어',
        'om_ET' => '오로모어(에티오피아)',
        'om_KE' => '오로모어(케냐)',
        'or' => '오리야어',
        'or_IN' => '오리야어(인도)',
        'os' => '오세트어',
        'os_GE' => '오세트어(조지아)',
        'os_RU' => '오세트어(러시아)',
        'pa' => '펀잡어',
        'pa_Arab' => '펀잡어(아랍 문자)',
        'pa_Arab_PK' => '펀잡어(아랍 문자, 파키스탄)',
        'pa_Guru' => '펀잡어(구르무키 문자)',
        'pa_Guru_IN' => '펀잡어(구르무키 문자, 인도)',
        'pa_IN' => '펀잡어(인도)',
        'pa_PK' => '펀잡어(파키스탄)',
        'pl' => '폴란드어',
        'pl_PL' => '폴란드어(폴란드)',
        'ps' => '파슈토어',
        'ps_AF' => '파슈토어(아프가니스탄)',
        'ps_PK' => '파슈토어(파키스탄)',
        'pt' => '포르투갈어',
        'pt_AO' => '포르투갈어(앙골라)',
        'pt_BR' => '포르투갈어(브라질)',
        'pt_CH' => '포르투갈어(스위스)',
        'pt_CV' => '포르투갈어(카보베르데)',
        'pt_GQ' => '포르투갈어(적도 기니)',
        'pt_GW' => '포르투갈어(기니비사우)',
        'pt_LU' => '포르투갈어(룩셈부르크)',
        'pt_MO' => '포르투갈어(마카오[중국 특별행정구])',
        'pt_MZ' => '포르투갈어(모잠비크)',
        'pt_PT' => '포르투갈어(포르투갈)',
        'pt_ST' => '포르투갈어(상투메 프린시페)',
        'pt_TL' => '포르투갈어(동티모르)',
        'qu' => '케추아어',
        'qu_BO' => '케추아어(볼리비아)',
        'qu_EC' => '케추아어(에콰도르)',
        'qu_PE' => '케추아어(페루)',
        'rm' => '로만시어',
        'rm_CH' => '로만시어(스위스)',
        'rn' => '룬디어',
        'rn_BI' => '룬디어(부룬디)',
        'ro' => '루마니아어',
        'ro_MD' => '루마니아어(몰도바)',
        'ro_RO' => '루마니아어(루마니아)',
        'ru' => '러시아어',
        'ru_BY' => '러시아어(벨라루스)',
        'ru_KG' => '러시아어(키르기스스탄)',
        'ru_KZ' => '러시아어(카자흐스탄)',
        'ru_MD' => '러시아어(몰도바)',
        'ru_RU' => '러시아어(러시아)',
        'ru_UA' => '러시아어(우크라이나)',
        'rw' => '르완다어',
        'rw_RW' => '르완다어(르완다)',
        'sa' => '산스크리트어',
        'sa_IN' => '산스크리트어(인도)',
        'sc' => '사르디니아어',
        'sc_IT' => '사르디니아어(이탈리아)',
        'sd' => '신디어',
        'sd_Arab' => '신디어(아랍 문자)',
        'sd_Arab_PK' => '신디어(아랍 문자, 파키스탄)',
        'sd_Deva' => '신디어(데바나가리 문자)',
        'sd_Deva_IN' => '신디어(데바나가리 문자, 인도)',
        'sd_IN' => '신디어(인도)',
        'sd_PK' => '신디어(파키스탄)',
        'se' => '북부 사미어',
        'se_FI' => '북부 사미어(핀란드)',
        'se_NO' => '북부 사미어(노르웨이)',
        'se_SE' => '북부 사미어(스웨덴)',
        'sg' => '산고어',
        'sg_CF' => '산고어(중앙 아프리카 공화국)',
        'sh' => '세르비아-크로아티아어',
        'sh_BA' => '세르비아-크로아티아어(보스니아 헤르체고비나)',
        'si' => '싱할라어',
        'si_LK' => '싱할라어(스리랑카)',
        'sk' => '슬로바키아어',
        'sk_SK' => '슬로바키아어(슬로바키아)',
        'sl' => '슬로베니아어',
        'sl_SI' => '슬로베니아어(슬로베니아)',
        'sn' => '쇼나어',
        'sn_ZW' => '쇼나어(짐바브웨)',
        'so' => '소말리아어',
        'so_DJ' => '소말리아어(지부티)',
        'so_ET' => '소말리아어(에티오피아)',
        'so_KE' => '소말리아어(케냐)',
        'so_SO' => '소말리아어(소말리아)',
        'sq' => '알바니아어',
        'sq_AL' => '알바니아어(알바니아)',
        'sq_MK' => '알바니아어(북마케도니아)',
        'sr' => '세르비아어',
        'sr_BA' => '세르비아어(보스니아 헤르체고비나)',
        'sr_Cyrl' => '세르비아어(키릴 문자)',
        'sr_Cyrl_BA' => '세르비아어(키릴 문자, 보스니아 헤르체고비나)',
        'sr_Cyrl_ME' => '세르비아어(키릴 문자, 몬테네그로)',
        'sr_Cyrl_RS' => '세르비아어(키릴 문자, 세르비아)',
        'sr_Latn' => '세르비아어(로마자)',
        'sr_Latn_BA' => '세르비아어(로마자, 보스니아 헤르체고비나)',
        'sr_Latn_ME' => '세르비아어(로마자, 몬테네그로)',
        'sr_Latn_RS' => '세르비아어(로마자, 세르비아)',
        'sr_ME' => '세르비아어(몬테네그로)',
        'sr_RS' => '세르비아어(세르비아)',
        'su' => '순다어',
        'su_ID' => '순다어(인도네시아)',
        'su_Latn' => '순다어(로마자)',
        'su_Latn_ID' => '순다어(로마자, 인도네시아)',
        'sv' => '스웨덴어',
        'sv_AX' => '스웨덴어(올란드 제도)',
        'sv_FI' => '스웨덴어(핀란드)',
        'sv_SE' => '스웨덴어(스웨덴)',
        'sw' => '스와힐리어',
        'sw_CD' => '스와힐리어(콩고-킨샤사)',
        'sw_KE' => '스와힐리어(케냐)',
        'sw_TZ' => '스와힐리어(탄자니아)',
        'sw_UG' => '스와힐리어(우간다)',
        'ta' => '타밀어',
        'ta_IN' => '타밀어(인도)',
        'ta_LK' => '타밀어(스리랑카)',
        'ta_MY' => '타밀어(말레이시아)',
        'ta_SG' => '타밀어(싱가포르)',
        'te' => '텔루구어',
        'te_IN' => '텔루구어(인도)',
        'tg' => '타지크어',
        'tg_TJ' => '타지크어(타지키스탄)',
        'th' => '태국어',
        'th_TH' => '태국어(태국)',
        'ti' => '티그리냐어',
        'ti_ER' => '티그리냐어(에리트리아)',
        'ti_ET' => '티그리냐어(에티오피아)',
        'tk' => '투르크멘어',
        'tk_TM' => '투르크멘어(투르크메니스탄)',
        'tl' => '타갈로그어',
        'tl_PH' => '타갈로그어(필리핀)',
        'to' => '통가어',
        'to_TO' => '통가어(통가)',
        'tr' => '터키어',
        'tr_CY' => '터키어(키프로스)',
        'tr_TR' => '터키어(터키)',
        'tt' => '타타르어',
        'tt_RU' => '타타르어(러시아)',
        'ug' => '위구르어',
        'ug_CN' => '위구르어(중국)',
        'uk' => '우크라이나어',
        'uk_UA' => '우크라이나어(우크라이나)',
        'ur' => '우르두어',
        'ur_IN' => '우르두어(인도)',
        'ur_PK' => '우르두어(파키스탄)',
        'uz' => '우즈베크어',
        'uz_AF' => '우즈베크어(아프가니스탄)',
        'uz_Arab' => '우즈베크어(아랍 문자)',
        'uz_Arab_AF' => '우즈베크어(아랍 문자, 아프가니스탄)',
        'uz_Cyrl' => '우즈베크어(키릴 문자)',
        'uz_Cyrl_UZ' => '우즈베크어(키릴 문자, 우즈베키스탄)',
        'uz_Latn' => '우즈베크어(로마자)',
        'uz_Latn_UZ' => '우즈베크어(로마자, 우즈베키스탄)',
        'uz_UZ' => '우즈베크어(우즈베키스탄)',
        'vi' => '베트남어',
        'vi_VN' => '베트남어(베트남)',
        'wo' => '월로프어',
        'wo_SN' => '월로프어(세네갈)',
        'xh' => '코사어',
        'xh_ZA' => '코사어(남아프리카)',
        'yi' => '이디시어',
        'yi_001' => '이디시어(세계)',
        'yo' => '요루바어',
        'yo_BJ' => '요루바어(베냉)',
        'yo_NG' => '요루바어(나이지리아)',
        'zh' => '중국어',
        'zh_CN' => '중국어(중국)',
        'zh_HK' => '중국어(홍콩[중국 특별행정구])',
        'zh_Hans' => '중국어(간체)',
        'zh_Hans_CN' => '중국어(간체, 중국)',
        'zh_Hans_HK' => '중국어(간체, 홍콩[중국 특별행정구])',
        'zh_Hans_MO' => '중국어(간체, 마카오[중국 특별행정구])',
        'zh_Hans_SG' => '중국어(간체, 싱가포르)',
        'zh_Hant' => '중국어(번체)',
        'zh_Hant_HK' => '중국어(번체, 홍콩[중국 특별행정구])',
        'zh_Hant_MO' => '중국어(번체, 마카오[중국 특별행정구])',
        'zh_Hant_TW' => '중국어(번체, 대만)',
        'zh_MO' => '중국어(마카오[중국 특별행정구])',
        'zh_SG' => '중국어(싱가포르)',
        'zh_TW' => '중국어(대만)',
        'zu' => '줄루어',
        'zu_ZA' => '줄루어(남아프리카)',
    ],
];
