<?php

return [
    'Names' => [
        'CDF' => [
            0 => 'FC',
            1 => 'Faranga ya Kongo',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan Renminbi ya China',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Bir ya Uhabeshi',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Sarafu ya Kijapani',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariary ya Bukini',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya ya Moritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya ya Moritania',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupia ya Shelisheli',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Faranga CFA BEAC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faranga CFA BCEAO',
        ],
    ],
];
