<?php

return [
    'Names' => [
        'arn' => 'المابودونجونية',
        'gn' => 'الغورانية',
        'hsb' => 'صوربيا العليا',
        'lo' => 'اللاوو',
        'sh' => 'الكرواتية الصربية',
        'sma' => 'سامي الجنوبية',
        'sw' => 'السواحيلية',
        'te' => 'التيلوجو',
        'ti' => 'التيغرينية',
    ],
    'LocalizedNames' => [
        'ar_001' => 'العربية الرسمية الحديثة',
        'sw_CD' => 'السواحيلية الكونغولية',
    ],
];
