<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Afak' => 'afaka',
        'Aghb' => 'kavkazskoalbánské',
        'Arab' => 'arabské',
        'Aran' => 'nastalik',
        'Armi' => 'aramejské (imperiální)',
        'Armn' => 'arménské',
        'Avst' => 'avestánské',
        'Bali' => 'balijské',
        'Bamu' => 'bamumské',
        'Bass' => 'bassa vah',
        'Batk' => 'batacké',
        'Beng' => 'bengálské',
        'Blis' => 'Blissovo písmo',
        'Bopo' => 'bopomofo',
        'Brah' => 'bráhmí',
        'Brai' => 'Braillovo písmo',
        'Bugi' => 'buginské',
        'Buhd' => 'buhidské',
        'Cakm' => 'čakma',
        'Cans' => 'slabičné písmo kanadských domorodců',
        'Cari' => 'karijské',
        'Cham' => 'čam',
        'Cher' => 'čerokí',
        'Cirt' => 'kirt',
        'Copt' => 'koptské',
        'Cprt' => 'kyperské',
        'Cyrl' => 'cyrilice',
        'Cyrs' => 'cyrilce - staroslověnská',
        'Deva' => 'dévanágarí',
        'Dsrt' => 'deseret',
        'Dupl' => 'Duployého těsnopis',
        'Egyd' => 'egyptské démotické',
        'Egyh' => 'egyptské hieratické',
        'Egyp' => 'egyptské hieroglyfy',
        'Elba' => 'elbasanské',
        'Ethi' => 'etiopské',
        'Geok' => 'gruzínské chutsuri',
        'Geor' => 'gruzínské',
        'Glag' => 'hlaholice',
        'Goth' => 'gotické',
        'Gran' => 'grantha',
        'Grek' => 'řecké',
        'Gujr' => 'gudžarátí',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunóo',
        'Hans' => 'zjednodušené',
        'Hant' => 'tradiční',
        'Hebr' => 'hebrejské',
        'Hira' => 'hiragana',
        'Hluw' => 'anatolské hieroglyfy',
        'Hmng' => 'hmongské',
        'Hrkt' => 'japonské slabičné',
        'Hung' => 'staromaďarské',
        'Inds' => 'harappské',
        'Ital' => 'etruské',
        'Jamo' => 'jamo',
        'Java' => 'javánské',
        'Jpan' => 'japonské',
        'Jurc' => 'džürčenské',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kháróšthí',
        'Khmr' => 'khmerské',
        'Khoj' => 'chodžiki',
        'Knda' => 'kannadské',
        'Kore' => 'korejské',
        'Kpel' => 'kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laoské',
        'Latf' => 'latinka - lomená',
        'Latg' => 'latinka - galská',
        'Latn' => 'latinka',
        'Lepc' => 'lepčské',
        'Limb' => 'limbu',
        'Lina' => 'lineární A',
        'Linb' => 'lineární B',
        'Lisu' => 'Fraserovo',
        'Loma' => 'loma',
        'Lyci' => 'lýkijské',
        'Lydi' => 'lýdské',
        'Mahj' => 'mahádžaní',
        'Mand' => 'mandejské',
        'Mani' => 'manichejské',
        'Maya' => 'mayské hieroglyfy',
        'Mend' => 'mendské',
        'Merc' => 'meroitické psací',
        'Mero' => 'meroitické',
        'Mlym' => 'malajlámské',
        'Modi' => 'modí',
        'Mong' => 'mongolské',
        'Moon' => 'Moonovo písmo',
        'Mroo' => 'mro',
        'Mtei' => 'mejtej majek (manipurské)',
        'Mymr' => 'myanmarské',
        'Narb' => 'staroseveroarabské',
        'Nbat' => 'nabatejské',
        'Nkgb' => 'naxi geba',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nü-šu',
        'Ogam' => 'ogamské',
        'Olck' => 'santálské (ol chiki)',
        'Orkh' => 'orchonské',
        'Orya' => 'urijské',
        'Osma' => 'osmanské',
        'Palm' => 'palmýrské',
        'Pauc' => 'pau cin hau',
        'Perm' => 'staropermské',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavské klínové',
        'Phlp' => 'pahlavské žalmové',
        'Phlv' => 'pahlavské knižní',
        'Phnx' => 'fénické',
        'Plrd' => 'Pollardova fonetická abeceda',
        'Prti' => 'parthské klínové',
        'Qaag' => 'zawgyi',
        'Rjng' => 'redžanské',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'runové',
        'Samr' => 'samařské',
        'Sara' => 'sarati',
        'Sarb' => 'starojihoarabské',
        'Saur' => 'saurášterské',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'Shawova abeceda',
        'Shrd' => 'šáradá',
        'Sidd' => 'siddham',
        'Sind' => 'chudábádí',
        'Sinh' => 'sinhálské',
        'Sora' => 'sora sompeng',
        'Sund' => 'sundské',
        'Sylo' => 'sylhetské',
        'Syrc' => 'syrské',
        'Syre' => 'syrské - estrangelo',
        'Syrj' => 'syrské - západní',
        'Syrn' => 'syrské - východní',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takrí',
        'Tale' => 'tai le',
        'Talu' => 'tai lü nové',
        'Taml' => 'tamilské',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugské',
        'Teng' => 'tengwar',
        'Tfng' => 'berberské',
        'Tglg' => 'tagalské',
        'Thaa' => 'thaana',
        'Thai' => 'thajské',
        'Tibt' => 'tibetské',
        'Tirh' => 'tirhuta',
        'Ugar' => 'ugaritské klínové',
        'Vaii' => 'vai',
        'Visp' => 'viditelná řeč',
        'Wara' => 'varang kšiti',
        'Wole' => 'karolínské (woleai)',
        'Xpeo' => 'staroperské klínové písmo',
        'Xsux' => 'sumero-akkadské klínové písmo',
        'Yiii' => 'yi',
        'Zmth' => 'matematický zápis',
        'Zsye' => 'emodži',
        'Zsym' => 'symboly',
        'Zxxx' => 'bez zápisu',
        'Zyyy' => 'obecné',
    ],
];
