<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Дирхам ӀЦЭ',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'ОвхӀан-пачхьалкхан афгани',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Албанин лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Эрмалойчоьнан драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Нидерландин Антилин гульден',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Анголан кванза',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Аргентинан песо',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Австралин доллар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Арубан флорин',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Азербайджанан манат',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Боснин а, Герцеговинан а хийцалун марка',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Барбадосан доллар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Бангладешан така',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Болгарин лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Бахрейнан динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Бурундин франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Бермудан доллар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Брунейн доллар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Боливин боливиано',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Бразилин реал',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Багаман доллар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Бутанан нгултрум',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ботсванан пула',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Белоруссин сом',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Белоруссин сом (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Белизин доллар',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Канадан доллар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Конголезин франк',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Швейцарин франк',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Чилин песо',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Китайн юань',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Колумбин песо',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Костарикан колон',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Кубан хийцалун песо',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Кубан песо',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Кабо-Верден эскудо',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Чехин крона',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Джибутин франк',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Данин крона',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Доминикан песо',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Алжиран динар',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Мисаран фунт',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Эритрейн накфа',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Эфиопин быр',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Евро',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Фиджин доллар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Фолклендан гӀайренийн фунт',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Англин фунт',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Гуьржийчоьнан лари',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ганан седи',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Гибралтаран фунт',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Гамбин даласи',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Гвинейн франк',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Гватемалан кетсаль',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Гайанан доллар',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Гонконган доллар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Гондурасан лемпира',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Хорватин куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Гаитин гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Венгрин форинт',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Индонезин рупи',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Израилан керла шекель',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Индин рупи',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Ӏиракъан динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'ГӀажарийчоьнан риал',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Исландин крона',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ямайн доллар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Урданан динар',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Японин иена',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Кенин шиллинг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Киргизин сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Камбоджан риель',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Коморийн гӀайренийн франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Къилбаседа Корейн вона',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Къилба Корейн вона',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Кувейтан динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Кайманийн гӀайренийн доллар',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Кхазакхстанан тенге',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Лаосан кип',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Ливанан фунт',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Шри-Ланкан рупи',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Либерин доллар',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Ливин динар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Мароккон дирхам',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Молдавин лей',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Малагасийн ариари',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Македонин динар',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Мьянман кьят',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Монголин тугрик',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Макаон патака',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Мавританин уги (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Мавританин уги',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Маврикин рупи',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Мальдивийн руфи',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Малавин квача',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Мексикан песо',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Малайзин ринггит',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Мозамбикан метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Намибин доллар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Нигерин найра',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Никарагуан кордоба',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Норвегин крона',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Непалан рупи',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Керла Зеландин доллар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Оманан риал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Панаман бальбоа',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Перун соль',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Папуа — Керла Гвинейн кина',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Филиппинийн песо',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Пакистанан рупи',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Польшан злотый',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Парагвайн гуарани',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Катаран риал',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Румынин лей',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Сербин динар',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'Российн сом',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Руандан франк',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'СаӀудийн Ӏаьрбийчоьнан риал',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Соломонан гӀайренийн доллар',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Сейшелан рупи',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Суданан фунт',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Швецин крона',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Сингапуран доллар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Сийлахьчу Еленин гӀайрен фунт',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Леоне',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Сомалин шиллинг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Суринаман доллар',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Къилба Суданан фунт',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Сан-Томен а, Принсипин а добра (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Сан-Томен а, Принсипин а добра',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Шеман фунт',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Свазилендан лилангени',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Таиландан бат',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Таджикистанан сомони',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Туркменин керла манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Тунисан динар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Тонганан паанга',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Туркойчоьнан лира',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Тринидадан а, Тобагон а доллар',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Тайванан керла доллар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Танзанин шиллинг',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Украинан гривна',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Угандан шиллинг',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'АЦШн доллар',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Уругвайн песо',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Узбекистанан сом',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Венесуэлан боливар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Венесуэлан боливар',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Вьетнаман донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Вануатун вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Самоанан тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Юккъерчу Африкан КФА франк',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Малхбален Карибийн доллар',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Малхбузен Африкан КФА франк',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Французийн Тийна океанан франк',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Йеменан риал',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Къилба-Африкин рэнд',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Замбин квача',
        ],
    ],
];
