<?php

return [
    'Names' => [
        'af' => 'ኣፍሪካንስ',
        'af_NA' => 'ኣፍሪካንስ (ናሚብያ)',
        'af_ZA' => 'ኣፍሪካንስ (ደቡብ ኣፍሪቃ)',
        'ak' => 'ኣካን',
        'ak_GH' => 'ኣካን (ጋና)',
        'am' => 'ኣምሓርኛ',
        'am_ET' => 'ኣምሓርኛ (ኢትዮጵያ)',
        'ar' => 'ዓረብ',
        'ar_001' => 'ዓረብ (ዓለም)',
        'ar_AE' => 'ዓረብ (ሕቡራት ኢማራት ዓረብ)',
        'ar_BH' => 'ዓረብ (ባሕሬን)',
        'ar_DJ' => 'ዓረብ (ጅቡቲ)',
        'ar_DZ' => 'ዓረብ (ኣልጀርያ)',
        'ar_EG' => 'ዓረብ (ግብጺ)',
        'ar_EH' => 'ዓረብ (ምዕራባዊ ሰሃራ)',
        'ar_ER' => 'ዓረብ (ኤርትራ)',
        'ar_IL' => 'ዓረብ (እስራኤል)',
        'ar_IQ' => 'ዓረብ (ዒራቕ)',
        'ar_JO' => 'ዓረብ (ዮርዳኖስ)',
        'ar_KM' => 'ዓረብ (ኮሞሮስ)',
        'ar_KW' => 'ዓረብ (ኩዌት)',
        'ar_LB' => 'ዓረብ (ሊባኖስ)',
        'ar_LY' => 'ዓረብ (ሊብያ)',
        'ar_MA' => 'ዓረብ (ሞሮኮ)',
        'ar_MR' => 'ዓረብ (ማውሪታንያ)',
        'ar_OM' => 'ዓረብ (ዖማን)',
        'ar_PS' => 'ዓረብ (ግዝኣታት ፍልስጤም)',
        'ar_QA' => 'ዓረብ (ቐጠር)',
        'ar_SA' => 'ዓረብ (ስዑዲ ዓረብ)',
        'ar_SD' => 'ዓረብ (ሱዳን)',
        'ar_SO' => 'ዓረብ (ሶማልያ)',
        'ar_SS' => 'ዓረብ (ደቡብ ሱዳን)',
        'ar_SY' => 'ዓረብ (ሶርያ)',
        'ar_TD' => 'ዓረብ (ጫድ)',
        'ar_TN' => 'ዓረብ (ቱኒዝያ)',
        'ar_YE' => 'ዓረብ (የመን)',
        'as' => 'ኣሳሜዝኛ',
        'as_IN' => 'ኣሳሜዝኛ (ህንዲ)',
        'az' => 'ኣዘርባጃንኛ',
        'az_AZ' => 'ኣዘርባጃንኛ (ኣዘርባጃን)',
        'az_Latn' => 'ኣዘርባጃንኛ (ላቲን)',
        'az_Latn_AZ' => 'ኣዘርባጃንኛ (ላቲን፣ ኣዘርባጃን)',
        'be' => 'ቤላሩስኛ',
        'be_BY' => 'ቤላሩስኛ (ቤላሩስ)',
        'bg' => 'ቡልጋርኛ',
        'bg_BG' => 'ቡልጋርኛ (ቡልጋርያ)',
        'bm' => 'ባምባራ',
        'bm_ML' => 'ባምባራ (ማሊ)',
        'bn' => 'በንጋሊ',
        'bn_BD' => 'በንጋሊ (ባንግላደሽ)',
        'bn_IN' => 'በንጋሊ (ህንዲ)',
        'bo' => 'ቲበታንኛ',
        'bo_CN' => 'ቲበታንኛ (ቻይና)',
        'bo_IN' => 'ቲበታንኛ (ህንዲ)',
        'br' => 'ብረቶንኛ',
        'br_FR' => 'ብረቶንኛ (ፈረንሳ)',
        'bs' => 'ቦዝንኛ',
        'bs_BA' => 'ቦዝንኛ (ቦዝንያን ሄርዘጎቪናን)',
        'bs_Latn' => 'ቦዝንኛ (ላቲን)',
        'bs_Latn_BA' => 'ቦዝንኛ (ላቲን፣ ቦዝንያን ሄርዘጎቪናን)',
        'ca' => 'ካታላን',
        'ca_AD' => 'ካታላን (ኣንዶራ)',
        'ca_ES' => 'ካታላን (ስጳኛ)',
        'ca_FR' => 'ካታላን (ፈረንሳ)',
        'ca_IT' => 'ካታላን (ኢጣልያ)',
        'ce' => 'ቸቸንይና',
        'ce_RU' => 'ቸቸንይና (ሩስያ)',
        'cs' => 'ቸክኛ',
        'cs_CZ' => 'ቸክኛ (ቸክያ)',
        'cv' => 'ቹቫሽኛ',
        'cv_RU' => 'ቹቫሽኛ (ሩስያ)',
        'cy' => 'ዌልስኛ',
        'cy_GB' => 'ዌልስኛ (ብሪጣንያ)',
        'da' => 'ዳኒሽ',
        'da_DK' => 'ዳኒሽ (ደንማርክ)',
        'da_GL' => 'ዳኒሽ (ግሪንላንድ)',
        'de' => 'ጀርመን',
        'de_AT' => 'ጀርመን (ኦስትርያ)',
        'de_BE' => 'ጀርመን (ቤልጅዩም)',
        'de_CH' => 'ጀርመን (ስዊዘርላንድ)',
        'de_DE' => 'ጀርመን (ጀርመን)',
        'de_IT' => 'ጀርመን (ኢጣልያ)',
        'de_LI' => 'ጀርመን (ሊኽተንሽታይን)',
        'de_LU' => 'ጀርመን (ሉክሰምበርግ)',
        'dz' => 'ድዞንግካ',
        'dz_BT' => 'ድዞንግካ (ቡታን)',
        'ee' => 'ኢው',
        'ee_GH' => 'ኢው (ጋና)',
        'ee_TG' => 'ኢው (ቶጎ)',
        'el' => 'ግሪኽኛ',
        'el_CY' => 'ግሪኽኛ (ቆጵሮስ)',
        'el_GR' => 'ግሪኽኛ (ግሪኽ)',
        'en' => 'እንግሊዝኛ',
        'en_001' => 'እንግሊዝኛ (ዓለም)',
        'en_150' => 'እንግሊዝኛ (ኤውሮጳ)',
        'en_AE' => 'እንግሊዝኛ (ሕቡራት ኢማራት ዓረብ)',
        'en_AG' => 'እንግሊዝኛ (ኣንቲጓን ባርቡዳን)',
        'en_AI' => 'እንግሊዝኛ (ኣንጒላ)',
        'en_AS' => 'እንግሊዝኛ (ኣመሪካዊት ሳሞኣ)',
        'en_AT' => 'እንግሊዝኛ (ኦስትርያ)',
        'en_AU' => 'እንግሊዝኛ (ኣውስትራልያ)',
        'en_BB' => 'እንግሊዝኛ (ባርባዶስ)',
        'en_BE' => 'እንግሊዝኛ (ቤልጅዩም)',
        'en_BI' => 'እንግሊዝኛ (ብሩንዲ)',
        'en_BM' => 'እንግሊዝኛ (በርሙዳ)',
        'en_BS' => 'እንግሊዝኛ (ባሃማስ)',
        'en_BW' => 'እንግሊዝኛ (ቦትስዋና)',
        'en_BZ' => 'እንግሊዝኛ (በሊዝ)',
        'en_CA' => 'እንግሊዝኛ (ካናዳ)',
        'en_CC' => 'እንግሊዝኛ (ደሴታት ኮኮስ)',
        'en_CH' => 'እንግሊዝኛ (ስዊዘርላንድ)',
        'en_CK' => 'እንግሊዝኛ (ደሴታት ኩክ)',
        'en_CM' => 'እንግሊዝኛ (ካሜሩን)',
        'en_CX' => 'እንግሊዝኛ (ደሴት ክሪስማስ)',
        'en_CY' => 'እንግሊዝኛ (ቆጵሮስ)',
        'en_DE' => 'እንግሊዝኛ (ጀርመን)',
        'en_DK' => 'እንግሊዝኛ (ደንማርክ)',
        'en_DM' => 'እንግሊዝኛ (ዶሚኒካ)',
        'en_ER' => 'እንግሊዝኛ (ኤርትራ)',
        'en_FI' => 'እንግሊዝኛ (ፊንላንድ)',
        'en_FJ' => 'እንግሊዝኛ (ፊጂ)',
        'en_FK' => 'እንግሊዝኛ (ደሴታት ፎክላንድ)',
        'en_FM' => 'እንግሊዝኛ (ማይክሮነዥያ)',
        'en_GB' => 'እንግሊዝኛ (ብሪጣንያ)',
        'en_GD' => 'እንግሊዝኛ (ግረናዳ)',
        'en_GG' => 'እንግሊዝኛ (ገርንዚ)',
        'en_GH' => 'እንግሊዝኛ (ጋና)',
        'en_GI' => 'እንግሊዝኛ (ጂብራልታር)',
        'en_GM' => 'እንግሊዝኛ (ጋምብያ)',
        'en_GU' => 'እንግሊዝኛ (ጓም)',
        'en_GY' => 'እንግሊዝኛ (ጉያና)',
        'en_HK' => 'እንግሊዝኛ (ፍሉይ ምምሕዳራዊ ዞባ ሆንግ ኮንግ [ቻይና])',
        'en_IE' => 'እንግሊዝኛ (ኣየርላንድ)',
        'en_IL' => 'እንግሊዝኛ (እስራኤል)',
        'en_IM' => 'እንግሊዝኛ (ኣይል ኦፍ ማን)',
        'en_IN' => 'እንግሊዝኛ (ህንዲ)',
        'en_IO' => 'እንግሊዝኛ (ብሪጣንያዊ ህንዳዊ ውቅያኖስ ግዝኣት)',
        'en_JE' => 'እንግሊዝኛ (ጀርዚ)',
        'en_JM' => 'እንግሊዝኛ (ጃማይካ)',
        'en_KE' => 'እንግሊዝኛ (ኬንያ)',
        'en_KI' => 'እንግሊዝኛ (ኪሪባቲ)',
        'en_KN' => 'እንግሊዝኛ (ቅዱስ ኪትስን ኔቪስን)',
        'en_KY' => 'እንግሊዝኛ (ደሴታት ካይማን)',
        'en_LC' => 'እንግሊዝኛ (ቅድስቲ ሉስያ)',
        'en_LR' => 'እንግሊዝኛ (ላይበርያ)',
        'en_LS' => 'እንግሊዝኛ (ሌሶቶ)',
        'en_MG' => 'እንግሊዝኛ (ማዳጋስካር)',
        'en_MH' => 'እንግሊዝኛ (ደሴታት ማርሻል)',
        'en_MO' => 'እንግሊዝኛ (ፍሉይ ምምሕዳራዊ ዞባ ማካው [ቻይና])',
        'en_MP' => 'እንግሊዝኛ (ሰሜናዊ ደሴታት ማርያና)',
        'en_MS' => 'እንግሊዝኛ (ሞንትሰራት)',
        'en_MT' => 'እንግሊዝኛ (ማልታ)',
        'en_MU' => 'እንግሊዝኛ (ማውሪሸስ)',
        'en_MV' => 'እንግሊዝኛ (ማልዲቭስ)',
        'en_MW' => 'እንግሊዝኛ (ማላዊ)',
        'en_MY' => 'እንግሊዝኛ (ማለዥያ)',
        'en_NA' => 'እንግሊዝኛ (ናሚብያ)',
        'en_NF' => 'እንግሊዝኛ (ደሴት ኖርፎልክ)',
        'en_NG' => 'እንግሊዝኛ (ናይጀርያ)',
        'en_NL' => 'እንግሊዝኛ (ኔዘርላንድ)',
        'en_NR' => 'እንግሊዝኛ (ናውሩ)',
        'en_NU' => 'እንግሊዝኛ (ኒዩ)',
        'en_NZ' => 'እንግሊዝኛ (ኒው ዚላንድ)',
        'en_PG' => 'እንግሊዝኛ (ፓፕዋ ኒው ጊኒ)',
        'en_PH' => 'እንግሊዝኛ (ፊሊፒንስ)',
        'en_PK' => 'እንግሊዝኛ (ፓኪስታን)',
        'en_PN' => 'እንግሊዝኛ (ደሴታት ፒትካርን)',
        'en_PR' => 'እንግሊዝኛ (ፖርቶ ሪኮ)',
        'en_PW' => 'እንግሊዝኛ (ፓላው)',
        'en_RW' => 'እንግሊዝኛ (ርዋንዳ)',
        'en_SB' => 'እንግሊዝኛ (ደሴታት ሰሎሞን)',
        'en_SC' => 'እንግሊዝኛ (ሲሸልስ)',
        'en_SD' => 'እንግሊዝኛ (ሱዳን)',
        'en_SE' => 'እንግሊዝኛ (ሽወደን)',
        'en_SG' => 'እንግሊዝኛ (ሲንጋፖር)',
        'en_SH' => 'እንግሊዝኛ (ቅድስቲ ሄለና)',
        'en_SI' => 'እንግሊዝኛ (ስሎቬንያ)',
        'en_SL' => 'እንግሊዝኛ (ሴራ ልዮን)',
        'en_SS' => 'እንግሊዝኛ (ደቡብ ሱዳን)',
        'en_SX' => 'እንግሊዝኛ (ሲንት ማርተን)',
        'en_SZ' => 'እንግሊዝኛ (ኤስዋቲኒ)',
        'en_TC' => 'እንግሊዝኛ (ደሴታት ቱርካትን ካይኮስን)',
        'en_TK' => 'እንግሊዝኛ (ቶከላው)',
        'en_TO' => 'እንግሊዝኛ (ቶንጋ)',
        'en_TT' => 'እንግሊዝኛ (ትሪኒዳድን ቶባጎን)',
        'en_TV' => 'እንግሊዝኛ (ቱቫሉ)',
        'en_TZ' => 'እንግሊዝኛ (ታንዛንያ)',
        'en_UG' => 'እንግሊዝኛ (ኡጋንዳ)',
        'en_UM' => 'እንግሊዝኛ (ካብ ኣመሪካ ርሒቐን ንኣሽቱ ደሴታት)',
        'en_US' => 'እንግሊዝኛ (ኣመሪካ)',
        'en_VC' => 'እንግሊዝኛ (ቅዱስ ቪንሰንትን ግረነዲነዝን)',
        'en_VG' => 'እንግሊዝኛ (ደሴታት ደናግል ብሪጣንያ)',
        'en_VI' => 'እንግሊዝኛ (ደሴታት ደናግል ኣመሪካ)',
        'en_VU' => 'እንግሊዝኛ (ቫንዋቱ)',
        'en_WS' => 'እንግሊዝኛ (ሳሞኣ)',
        'en_ZA' => 'እንግሊዝኛ (ደቡብ ኣፍሪቃ)',
        'en_ZM' => 'እንግሊዝኛ (ዛምብያ)',
        'en_ZW' => 'እንግሊዝኛ (ዚምባብዌ)',
        'eo' => 'ኤስፐራንቶ',
        'eo_001' => 'ኤስፐራንቶ (ዓለም)',
        'es' => 'ስጳንኛ',
        'es_419' => 'ስጳንኛ (ላቲን ኣመሪካ)',
        'es_AR' => 'ስጳንኛ (ኣርጀንቲና)',
        'es_BO' => 'ስጳንኛ (ቦሊቭያ)',
        'es_BR' => 'ስጳንኛ (ብራዚል)',
        'es_BZ' => 'ስጳንኛ (በሊዝ)',
        'es_CL' => 'ስጳንኛ (ቺሌ)',
        'es_CO' => 'ስጳንኛ (ኮሎምብያ)',
        'es_CR' => 'ስጳንኛ (ኮስታ ሪካ)',
        'es_CU' => 'ስጳንኛ (ኩባ)',
        'es_DO' => 'ስጳንኛ (ዶሚኒካዊት ሪፓብሊክ)',
        'es_EC' => 'ስጳንኛ (ኤኳዶር)',
        'es_ES' => 'ስጳንኛ (ስጳኛ)',
        'es_GQ' => 'ስጳንኛ (ኢኳቶርያል ጊኒ)',
        'es_GT' => 'ስጳንኛ (ጓቲማላ)',
        'es_HN' => 'ስጳንኛ (ሆንዱራስ)',
        'es_MX' => 'ስጳንኛ (ሜክሲኮ)',
        'es_NI' => 'ስጳንኛ (ኒካራጓ)',
        'es_PA' => 'ስጳንኛ (ፓናማ)',
        'es_PE' => 'ስጳንኛ (ፔሩ)',
        'es_PH' => 'ስጳንኛ (ፊሊፒንስ)',
        'es_PR' => 'ስጳንኛ (ፖርቶ ሪኮ)',
        'es_PY' => 'ስጳንኛ (ፓራጓይ)',
        'es_SV' => 'ስጳንኛ (ኤል ሳልቫዶር)',
        'es_US' => 'ስጳንኛ (ኣመሪካ)',
        'es_UY' => 'ስጳንኛ (ኡራጓይ)',
        'es_VE' => 'ስጳንኛ (ቬኔዝዌላ)',
        'et' => 'ኤስቶንኛ',
        'et_EE' => 'ኤስቶንኛ (ኤስቶንያ)',
        'eu' => 'ባስክኛ',
        'eu_ES' => 'ባስክኛ (ስጳኛ)',
        'fa' => 'ፋርስኛ',
        'fa_AF' => 'ፋርስኛ (ኣፍጋኒስታን)',
        'fa_IR' => 'ፋርስኛ (ኢራን)',
        'ff' => 'ፉላ',
        'ff_CM' => 'ፉላ (ካሜሩን)',
        'ff_GN' => 'ፉላ (ጊኒ)',
        'ff_Latn' => 'ፉላ (ላቲን)',
        'ff_Latn_BF' => 'ፉላ (ላቲን፣ ቡርኪና ፋሶ)',
        'ff_Latn_CM' => 'ፉላ (ላቲን፣ ካሜሩን)',
        'ff_Latn_GH' => 'ፉላ (ላቲን፣ ጋና)',
        'ff_Latn_GM' => 'ፉላ (ላቲን፣ ጋምብያ)',
        'ff_Latn_GN' => 'ፉላ (ላቲን፣ ጊኒ)',
        'ff_Latn_GW' => 'ፉላ (ላቲን፣ ጊኒ-ቢሳው)',
        'ff_Latn_LR' => 'ፉላ (ላቲን፣ ላይበርያ)',
        'ff_Latn_MR' => 'ፉላ (ላቲን፣ ማውሪታንያ)',
        'ff_Latn_NE' => 'ፉላ (ላቲን፣ ኒጀር)',
        'ff_Latn_NG' => 'ፉላ (ላቲን፣ ናይጀርያ)',
        'ff_Latn_SL' => 'ፉላ (ላቲን፣ ሴራ ልዮን)',
        'ff_Latn_SN' => 'ፉላ (ላቲን፣ ሰነጋል)',
        'ff_MR' => 'ፉላ (ማውሪታንያ)',
        'ff_SN' => 'ፉላ (ሰነጋል)',
        'fi' => 'ፊንላንድኛ',
        'fi_FI' => 'ፊንላንድኛ (ፊንላንድ)',
        'fo' => 'ፋሮእይና',
        'fo_DK' => 'ፋሮእይና (ደንማርክ)',
        'fo_FO' => 'ፋሮእይና (ደሴታት ፋሮ)',
        'fr' => 'ፈረንሳይኛ',
        'fr_BE' => 'ፈረንሳይኛ (ቤልጅዩም)',
        'fr_BF' => 'ፈረንሳይኛ (ቡርኪና ፋሶ)',
        'fr_BI' => 'ፈረንሳይኛ (ብሩንዲ)',
        'fr_BJ' => 'ፈረንሳይኛ (ቤኒን)',
        'fr_BL' => 'ፈረንሳይኛ (ቅዱስ ባርተለሚ)',
        'fr_CA' => 'ፈረንሳይኛ (ካናዳ)',
        'fr_CD' => 'ፈረንሳይኛ (ደሞክራስያዊት ሪፓብሊክ ኮንጎ)',
        'fr_CF' => 'ፈረንሳይኛ (ሪፓብሊክ ማእከላይ ኣፍሪቃ)',
        'fr_CG' => 'ፈረንሳይኛ (ኮንጎ)',
        'fr_CH' => 'ፈረንሳይኛ (ስዊዘርላንድ)',
        'fr_CI' => 'ፈረንሳይኛ (ኮት ዲቭዋር)',
        'fr_CM' => 'ፈረንሳይኛ (ካሜሩን)',
        'fr_DJ' => 'ፈረንሳይኛ (ጅቡቲ)',
        'fr_DZ' => 'ፈረንሳይኛ (ኣልጀርያ)',
        'fr_FR' => 'ፈረንሳይኛ (ፈረንሳ)',
        'fr_GA' => 'ፈረንሳይኛ (ጋቦን)',
        'fr_GF' => 'ፈረንሳይኛ (ፈረንሳዊት ጊያና)',
        'fr_GN' => 'ፈረንሳይኛ (ጊኒ)',
        'fr_GP' => 'ፈረንሳይኛ (ጓደሉፕ)',
        'fr_GQ' => 'ፈረንሳይኛ (ኢኳቶርያል ጊኒ)',
        'fr_HT' => 'ፈረንሳይኛ (ሃይቲ)',
        'fr_KM' => 'ፈረንሳይኛ (ኮሞሮስ)',
        'fr_LU' => 'ፈረንሳይኛ (ሉክሰምበርግ)',
        'fr_MA' => 'ፈረንሳይኛ (ሞሮኮ)',
        'fr_MC' => 'ፈረንሳይኛ (ሞናኮ)',
        'fr_MF' => 'ፈረንሳይኛ (ቅዱስ ማርቲን)',
        'fr_MG' => 'ፈረንሳይኛ (ማዳጋስካር)',
        'fr_ML' => 'ፈረንሳይኛ (ማሊ)',
        'fr_MQ' => 'ፈረንሳይኛ (ማርቲኒክ)',
        'fr_MR' => 'ፈረንሳይኛ (ማውሪታንያ)',
        'fr_MU' => 'ፈረንሳይኛ (ማውሪሸስ)',
        'fr_NC' => 'ፈረንሳይኛ (ኒው ካለዶንያ)',
        'fr_NE' => 'ፈረንሳይኛ (ኒጀር)',
        'fr_PF' => 'ፈረንሳይኛ (ፈረንሳዊት ፖሊነዥያ)',
        'fr_PM' => 'ፈረንሳይኛ (ቅዱስ ፕየርን ሚከሎንን)',
        'fr_RE' => 'ፈረንሳይኛ (ርዩንየን)',
        'fr_RW' => 'ፈረንሳይኛ (ርዋንዳ)',
        'fr_SC' => 'ፈረንሳይኛ (ሲሸልስ)',
        'fr_SN' => 'ፈረንሳይኛ (ሰነጋል)',
        'fr_SY' => 'ፈረንሳይኛ (ሶርያ)',
        'fr_TD' => 'ፈረንሳይኛ (ጫድ)',
        'fr_TG' => 'ፈረንሳይኛ (ቶጎ)',
        'fr_TN' => 'ፈረንሳይኛ (ቱኒዝያ)',
        'fr_VU' => 'ፈረንሳይኛ (ቫንዋቱ)',
        'fr_WF' => 'ፈረንሳይኛ (ዋሊስን ፉቱናን)',
        'fr_YT' => 'ፈረንሳይኛ (ማዮት)',
        'fy' => 'ምዕራባዊ ፍሪስኛ',
        'fy_NL' => 'ምዕራባዊ ፍሪስኛ (ኔዘርላንድ)',
        'ga' => 'ኣየርላንድኛ',
        'ga_GB' => 'ኣየርላንድኛ (ብሪጣንያ)',
        'ga_IE' => 'ኣየርላንድኛ (ኣየርላንድ)',
        'gd' => 'ስኮትላንዳዊ ጋኤሊክኛ',
        'gd_GB' => 'ስኮትላንዳዊ ጋኤሊክኛ (ብሪጣንያ)',
        'gl' => 'ጋሊሽያን',
        'gl_ES' => 'ጋሊሽያን (ስጳኛ)',
        'gu' => 'ጉጃራቲ',
        'gu_IN' => 'ጉጃራቲ (ህንዲ)',
        'gv' => 'ማንክስ',
        'gv_IM' => 'ማንክስ (ኣይል ኦፍ ማን)',
        'ha' => 'ሃውሳ',
        'ha_GH' => 'ሃውሳ (ጋና)',
        'ha_NE' => 'ሃውሳ (ኒጀር)',
        'ha_NG' => 'ሃውሳ (ናይጀርያ)',
        'he' => 'እብራይስጢ',
        'he_IL' => 'እብራይስጢ (እስራኤል)',
        'hi' => 'ሂንዲ',
        'hi_IN' => 'ሂንዲ (ህንዲ)',
        'hi_Latn' => 'ሂንዲ (ላቲን)',
        'hi_Latn_IN' => 'ሂንዲ (ላቲን፣ ህንዲ)',
        'hr' => 'ክሮኤሽያን',
        'hr_BA' => 'ክሮኤሽያን (ቦዝንያን ሄርዘጎቪናን)',
        'hr_HR' => 'ክሮኤሽያን (ክሮኤሽያ)',
        'hu' => 'ሃንጋርኛ',
        'hu_HU' => 'ሃንጋርኛ (ሃንጋሪ)',
        'hy' => 'ኣርሜንኛ',
        'hy_AM' => 'ኣርሜንኛ (ኣርሜንያ)',
        'ia' => 'ኢንተርሊንጓ',
        'ia_001' => 'ኢንተርሊንጓ (ዓለም)',
        'id' => 'ኢንዶነዥኛ',
        'id_ID' => 'ኢንዶነዥኛ (ኢንዶነዥያ)',
        'ig' => 'ኢግቦ',
        'ig_NG' => 'ኢግቦ (ናይጀርያ)',
        'ii' => 'ሲችዋን ዪ',
        'ii_CN' => 'ሲችዋን ዪ (ቻይና)',
        'is' => 'ኣይስላንድኛ',
        'is_IS' => 'ኣይስላንድኛ (ኣይስላንድ)',
        'it' => 'ጥልያን',
        'it_CH' => 'ጥልያን (ስዊዘርላንድ)',
        'it_IT' => 'ጥልያን (ኢጣልያ)',
        'it_SM' => 'ጥልያን (ሳን ማሪኖ)',
        'it_VA' => 'ጥልያን (ከተማ ቫቲካን)',
        'ja' => 'ጃፓንኛ',
        'ja_JP' => 'ጃፓንኛ (ጃፓን)',
        'jv' => 'ጃቫንኛ',
        'jv_ID' => 'ጃቫንኛ (ኢንዶነዥያ)',
        'ka' => 'ጆርጅያንኛ',
        'ka_GE' => 'ጆርጅያንኛ (ጆርጅያ)',
        'ki' => 'ኪኩዩ',
        'ki_KE' => 'ኪኩዩ (ኬንያ)',
        'kk' => 'ካዛክ',
        'kk_KZ' => 'ካዛክ (ካዛኪስታን)',
        'kl' => 'ግሪንላንድኛ',
        'kl_GL' => 'ግሪንላንድኛ (ግሪንላንድ)',
        'km' => 'ክመር',
        'km_KH' => 'ክመር (ካምቦድያ)',
        'kn' => 'ካንናዳ',
        'kn_IN' => 'ካንናዳ (ህንዲ)',
        'ko' => 'ኮርይኛ',
        'ko_KP' => 'ኮርይኛ (ሰሜን ኮርያ)',
        'ko_KR' => 'ኮርይኛ (ደቡብ ኮርያ)',
        'ks' => 'ካሽሚሪ',
        'ks_IN' => 'ካሽሚሪ (ህንዲ)',
        'ku' => 'ኩርዲሽ',
        'ku_TR' => 'ኩርዲሽ (ቱርኪ)',
        'kw' => 'ኮርንኛ',
        'kw_GB' => 'ኮርንኛ (ብሪጣንያ)',
        'ky' => 'ኪርጊዝኛ',
        'ky_KG' => 'ኪርጊዝኛ (ኪርጊዝስታን)',
        'lb' => 'ሉክሰምበርግኛ',
        'lb_LU' => 'ሉክሰምበርግኛ (ሉክሰምበርግ)',
        'lg' => 'ጋንዳ',
        'lg_UG' => 'ጋንዳ (ኡጋንዳ)',
        'ln' => 'ሊንጋላ',
        'ln_AO' => 'ሊንጋላ (ኣንጎላ)',
        'ln_CD' => 'ሊንጋላ (ደሞክራስያዊት ሪፓብሊክ ኮንጎ)',
        'ln_CF' => 'ሊንጋላ (ሪፓብሊክ ማእከላይ ኣፍሪቃ)',
        'ln_CG' => 'ሊንጋላ (ኮንጎ)',
        'lo' => 'ላኦ',
        'lo_LA' => 'ላኦ (ላኦስ)',
        'lt' => 'ሊትዌንኛ',
        'lt_LT' => 'ሊትዌንኛ (ሊትዌንያ)',
        'lu' => 'ሉባ-ካታንጋ',
        'lu_CD' => 'ሉባ-ካታንጋ (ደሞክራስያዊት ሪፓብሊክ ኮንጎ)',
        'lv' => 'ላትቭኛ',
        'lv_LV' => 'ላትቭኛ (ላትቭያ)',
        'mg' => 'ማላጋሲ',
        'mg_MG' => 'ማላጋሲ (ማዳጋስካር)',
        'mi' => 'ማኦሪ',
        'mi_NZ' => 'ማኦሪ (ኒው ዚላንድ)',
        'mk' => 'መቄዶንኛ',
        'mk_MK' => 'መቄዶንኛ (ሰሜን መቄዶንያ)',
        'ml' => 'ማላያላም',
        'ml_IN' => 'ማላያላም (ህንዲ)',
        'mn' => 'ሞንጎልኛ',
        'mn_MN' => 'ሞንጎልኛ (ሞንጎልያ)',
        'mr' => 'ማራቲ',
        'mr_IN' => 'ማራቲ (ህንዲ)',
        'ms' => 'ማላይኛ',
        'ms_BN' => 'ማላይኛ (ብሩነይ)',
        'ms_ID' => 'ማላይኛ (ኢንዶነዥያ)',
        'ms_MY' => 'ማላይኛ (ማለዥያ)',
        'ms_SG' => 'ማላይኛ (ሲንጋፖር)',
        'mt' => 'ማልትኛ',
        'mt_MT' => 'ማልትኛ (ማልታ)',
        'my' => 'በርምኛ',
        'my_MM' => 'በርምኛ (ሚያንማር [በርማ])',
        'nb' => 'ኖርወያዊ ቦክማል',
        'nb_NO' => 'ኖርወያዊ ቦክማል (ኖርወይ)',
        'nb_SJ' => 'ኖርወያዊ ቦክማል (ስቫልባርድን ጃን ማየንን)',
        'nd' => 'ሰሜን ኤንደበለ',
        'nd_ZW' => 'ሰሜን ኤንደበለ (ዚምባብዌ)',
        'ne' => 'ኔፓሊ',
        'ne_IN' => 'ኔፓሊ (ህንዲ)',
        'ne_NP' => 'ኔፓሊ (ኔፓል)',
        'nl' => 'ዳች',
        'nl_AW' => 'ዳች (ኣሩባ)',
        'nl_BE' => 'ዳች (ቤልጅዩም)',
        'nl_BQ' => 'ዳች (ካሪብያን ኔዘርላንድ)',
        'nl_CW' => 'ዳች (ኩራሳው)',
        'nl_NL' => 'ዳች (ኔዘርላንድ)',
        'nl_SR' => 'ዳች (ሱሪናም)',
        'nl_SX' => 'ዳች (ሲንት ማርተን)',
        'nn' => 'ኖርወያዊ ናይኖርስክ',
        'nn_NO' => 'ኖርወያዊ ናይኖርስክ (ኖርወይ)',
        'no' => 'ኖርወይኛ',
        'no_NO' => 'ኖርወይኛ (ኖርወይ)',
        'om' => 'ኦሮሞ',
        'om_ET' => 'ኦሮሞ (ኢትዮጵያ)',
        'om_KE' => 'ኦሮሞ (ኬንያ)',
        'or' => 'ኦድያ',
        'or_IN' => 'ኦድያ (ህንዲ)',
        'os' => 'ኦሰትኛ',
        'os_GE' => 'ኦሰትኛ (ጆርጅያ)',
        'os_RU' => 'ኦሰትኛ (ሩስያ)',
        'pa' => 'ፑንጃቢ',
        'pa_IN' => 'ፑንጃቢ (ህንዲ)',
        'pa_PK' => 'ፑንጃቢ (ፓኪስታን)',
        'pl' => 'ፖሊሽ',
        'pl_PL' => 'ፖሊሽ (ፖላንድ)',
        'ps' => 'ፓሽቶ',
        'ps_AF' => 'ፓሽቶ (ኣፍጋኒስታን)',
        'ps_PK' => 'ፓሽቶ (ፓኪስታን)',
        'pt' => 'ፖርቱጊዝኛ',
        'pt_AO' => 'ፖርቱጊዝኛ (ኣንጎላ)',
        'pt_BR' => 'ፖርቱጊዝኛ (ብራዚል)',
        'pt_CH' => 'ፖርቱጊዝኛ (ስዊዘርላንድ)',
        'pt_CV' => 'ፖርቱጊዝኛ (ኬፕ ቨርደ)',
        'pt_GQ' => 'ፖርቱጊዝኛ (ኢኳቶርያል ጊኒ)',
        'pt_GW' => 'ፖርቱጊዝኛ (ጊኒ-ቢሳው)',
        'pt_LU' => 'ፖርቱጊዝኛ (ሉክሰምበርግ)',
        'pt_MO' => 'ፖርቱጊዝኛ (ፍሉይ ምምሕዳራዊ ዞባ ማካው [ቻይና])',
        'pt_MZ' => 'ፖርቱጊዝኛ (ሞዛምቢክ)',
        'pt_PT' => 'ፖርቱጊዝኛ (ፖርቱጋል)',
        'pt_ST' => 'ፖርቱጊዝኛ (ሳኦ ቶመን ፕሪንሲፐን)',
        'pt_TL' => 'ፖርቱጊዝኛ (ቲሞር-ለስተ)',
        'qu' => 'ቀችዋ',
        'qu_BO' => 'ቀችዋ (ቦሊቭያ)',
        'qu_EC' => 'ቀችዋ (ኤኳዶር)',
        'qu_PE' => 'ቀችዋ (ፔሩ)',
        'rm' => 'ሮማንሽ',
        'rm_CH' => 'ሮማንሽ (ስዊዘርላንድ)',
        'rn' => 'ኪሩንዲ',
        'rn_BI' => 'ኪሩንዲ (ብሩንዲ)',
        'ro' => 'ሩማንኛ',
        'ro_MD' => 'ሩማንኛ (ሞልዶቫ)',
        'ro_RO' => 'ሩማንኛ (ሩማንያ)',
        'ru' => 'ሩስኛ',
        'ru_BY' => 'ሩስኛ (ቤላሩስ)',
        'ru_KG' => 'ሩስኛ (ኪርጊዝስታን)',
        'ru_KZ' => 'ሩስኛ (ካዛኪስታን)',
        'ru_MD' => 'ሩስኛ (ሞልዶቫ)',
        'ru_RU' => 'ሩስኛ (ሩስያ)',
        'ru_UA' => 'ሩስኛ (ዩክሬን)',
        'rw' => 'ኪንያርዋንዳ',
        'rw_RW' => 'ኪንያርዋንዳ (ርዋንዳ)',
        'sa' => 'ሳንስክሪት',
        'sa_IN' => 'ሳንስክሪት (ህንዲ)',
        'sc' => 'ሳርዲንኛ',
        'sc_IT' => 'ሳርዲንኛ (ኢጣልያ)',
        'sd' => 'ሲንድሂ',
        'sd_IN' => 'ሲንድሂ (ህንዲ)',
        'sd_PK' => 'ሲንድሂ (ፓኪስታን)',
        'se' => 'ሰሜናዊ ሳሚ',
        'se_FI' => 'ሰሜናዊ ሳሚ (ፊንላንድ)',
        'se_NO' => 'ሰሜናዊ ሳሚ (ኖርወይ)',
        'se_SE' => 'ሰሜናዊ ሳሚ (ሽወደን)',
        'sg' => 'ሳንጎ',
        'sg_CF' => 'ሳንጎ (ሪፓብሊክ ማእከላይ ኣፍሪቃ)',
        'sh' => 'ሰርቦ-ክሮኤሽያን',
        'sh_BA' => 'ሰርቦ-ክሮኤሽያን (ቦዝንያን ሄርዘጎቪናን)',
        'si' => 'ሲንሃላ',
        'si_LK' => 'ሲንሃላ (ስሪ ላንካ)',
        'sk' => 'ስሎቫክኛ',
        'sk_SK' => 'ስሎቫክኛ (ስሎቫክያ)',
        'sl' => 'ስሎቬንኛ',
        'sl_SI' => 'ስሎቬንኛ (ስሎቬንያ)',
        'sn' => 'ሾና',
        'sn_ZW' => 'ሾና (ዚምባብዌ)',
        'so' => 'ሶማሊ',
        'so_DJ' => 'ሶማሊ (ጅቡቲ)',
        'so_ET' => 'ሶማሊ (ኢትዮጵያ)',
        'so_KE' => 'ሶማሊ (ኬንያ)',
        'so_SO' => 'ሶማሊ (ሶማልያ)',
        'sq' => 'ኣልባንኛ',
        'sq_AL' => 'ኣልባንኛ (ኣልባንያ)',
        'sq_MK' => 'ኣልባንኛ (ሰሜን መቄዶንያ)',
        'sr' => 'ቃንቃ ሰርቢያ',
        'sr_BA' => 'ቃንቃ ሰርቢያ (ቦዝንያን ሄርዘጎቪናን)',
        'sr_Latn' => 'ቃንቃ ሰርቢያ (ላቲን)',
        'sr_Latn_BA' => 'ቃንቃ ሰርቢያ (ላቲን፣ ቦዝንያን ሄርዘጎቪናን)',
        'sr_Latn_ME' => 'ቃንቃ ሰርቢያ (ላቲን፣ ሞንተኔግሮ)',
        'sr_Latn_RS' => 'ቃንቃ ሰርቢያ (ላቲን፣ ሰርብያ)',
        'sr_ME' => 'ቃንቃ ሰርቢያ (ሞንተኔግሮ)',
        'sr_RS' => 'ቃንቃ ሰርቢያ (ሰርብያ)',
        'su' => 'ሱንዳንኛ',
        'su_ID' => 'ሱንዳንኛ (ኢንዶነዥያ)',
        'su_Latn' => 'ሱንዳንኛ (ላቲን)',
        'su_Latn_ID' => 'ሱንዳንኛ (ላቲን፣ ኢንዶነዥያ)',
        'sv' => 'ስዊድንኛ',
        'sv_AX' => 'ስዊድንኛ (ደሴታት ኣላንድ)',
        'sv_FI' => 'ስዊድንኛ (ፊንላንድ)',
        'sv_SE' => 'ስዊድንኛ (ሽወደን)',
        'sw' => 'ስዋሂሊ',
        'sw_CD' => 'ስዋሂሊ (ደሞክራስያዊት ሪፓብሊክ ኮንጎ)',
        'sw_KE' => 'ስዋሂሊ (ኬንያ)',
        'sw_TZ' => 'ስዋሂሊ (ታንዛንያ)',
        'sw_UG' => 'ስዋሂሊ (ኡጋንዳ)',
        'ta' => 'ታሚል',
        'ta_IN' => 'ታሚል (ህንዲ)',
        'ta_LK' => 'ታሚል (ስሪ ላንካ)',
        'ta_MY' => 'ታሚል (ማለዥያ)',
        'ta_SG' => 'ታሚል (ሲንጋፖር)',
        'te' => 'ተሉጉ',
        'te_IN' => 'ተሉጉ (ህንዲ)',
        'tg' => 'ታጂክኛ',
        'tg_TJ' => 'ታጂክኛ (ታጂኪስታን)',
        'th' => 'ታይኛ',
        'th_TH' => 'ታይኛ (ታይላንድ)',
        'ti' => 'ትግርኛ',
        'ti_ER' => 'ትግርኛ (ኤርትራ)',
        'ti_ET' => 'ትግርኛ (ኢትዮጵያ)',
        'tk' => 'ቱርክመንኛ',
        'tk_TM' => 'ቱርክመንኛ (ቱርክመኒስታን)',
        'to' => 'ቶንጋንኛ',
        'to_TO' => 'ቶንጋንኛ (ቶንጋ)',
        'tr' => 'ቱርክኛ',
        'tr_CY' => 'ቱርክኛ (ቆጵሮስ)',
        'tr_TR' => 'ቱርክኛ (ቱርኪ)',
        'tt' => 'ታታር',
        'tt_RU' => 'ታታር (ሩስያ)',
        'ug' => 'ኡይጉር',
        'ug_CN' => 'ኡይጉር (ቻይና)',
        'uk' => 'ዩክረይንኛ',
        'uk_UA' => 'ዩክረይንኛ (ዩክሬን)',
        'ur' => 'ኡርዱ',
        'ur_IN' => 'ኡርዱ (ህንዲ)',
        'ur_PK' => 'ኡርዱ (ፓኪስታን)',
        'uz' => 'ኡዝበክኛ',
        'uz_AF' => 'ኡዝበክኛ (ኣፍጋኒስታን)',
        'uz_Latn' => 'ኡዝበክኛ (ላቲን)',
        'uz_Latn_UZ' => 'ኡዝበክኛ (ላቲን፣ ኡዝበኪስታን)',
        'uz_UZ' => 'ኡዝበክኛ (ኡዝበኪስታን)',
        'vi' => 'ቬትናምኛ',
        'vi_VN' => 'ቬትናምኛ (ቬትናም)',
        'wo' => 'ዎሎፍ',
        'wo_SN' => 'ዎሎፍ (ሰነጋል)',
        'xh' => 'ኮሳ',
        'xh_ZA' => 'ኮሳ (ደቡብ ኣፍሪቃ)',
        'yi' => 'ይሁድኛ',
        'yi_001' => 'ይሁድኛ (ዓለም)',
        'yo' => 'ዮሩባ',
        'yo_BJ' => 'ዮሩባ (ቤኒን)',
        'yo_NG' => 'ዮሩባ (ናይጀርያ)',
        'zh' => 'ቻይንኛ',
        'zh_CN' => 'ቻይንኛ (ቻይና)',
        'zh_HK' => 'ቻይንኛ (ፍሉይ ምምሕዳራዊ ዞባ ሆንግ ኮንግ [ቻይና])',
        'zh_MO' => 'ቻይንኛ (ፍሉይ ምምሕዳራዊ ዞባ ማካው [ቻይና])',
        'zh_SG' => 'ቻይንኛ (ሲንጋፖር)',
        'zh_TW' => 'ቻይንኛ (ታይዋን)',
        'zu' => 'ዙሉ',
        'zu_ZA' => 'ዙሉ (ደቡብ ኣፍሪቃ)',
    ],
];
