<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'peseta andorrana',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham de sos Emirados Àrabos Unidos',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afgani afganu (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afgani afganu',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'lek albanesu (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albanesu',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'dram armenu',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'fiorinu de sas Antillas Olandesas',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolanu',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'kwanza angolanu (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'kwanza nou angolanu (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'kwanza ri-acontzadu angolanu (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'austral argentinu',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'peso ley argentinu (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'peso argentinu (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'peso argentinu (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'peso argentinu',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'iscellinu austrìacu',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'dòllaru australianu',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'fiorinu arubanu',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'manat azeru (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat azeru',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'dinar de sa Bòsnia-Erzegòvina (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'marcu cunvertìbile de sa Bòsnia-Erzegòvina',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'dinar de sa Bòsnia-Erzegòvina (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dòllaru barbadianu',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'taka bangladesu',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'francu belga (cunvertìbile)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'francu belga',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'francu belga (finantziàriu)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'lev bùlgaru (1962–1999)',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'lev sotzialista bùlgaru',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lev bùlgaru',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'lev bùlgaru (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinar bahreinu',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'francu burundianu',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dòllaru de sas Bermudas',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'dòllaru de su Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'bolivianu',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'bolivianu (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'peso bolivianu',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'mvdol bolivianu',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'cruzèiru nou brasilianu (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'cruzadu brasilianu (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'cruzèiru brasilianu (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'real brasilianu',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'cruzadu nou brasilianu (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'cruzèiru brasilianu (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'cruzèiru brasilianu (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dòllaru bahamesu',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ngultrum bhutanesu',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'kyat birmanu',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula botswanesa',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'rublu bielorussu (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rublu bielorussu',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'rublu bielorussu (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dòllaru de su Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'dòllaru canadesu',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'francu congolesu',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'euro WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'francu isvìtzeru',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'francu WIR',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'iscudu tzilenu',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'unidade de acontu tzilena (UF)',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso tzilenu',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'renminbi tzinesu (extracontinentale)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'dòllaru de sa Banca Popolare Tzinesa',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'renminbi tzinesu',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso colombianu',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'unidade de valore reale colombiana',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colón costaricanu',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'dinar serbu (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'corona forte tzecoslovaca',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso cubanu cunvertìbile',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso cubanu',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'iscudu cabubirdianu',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'isterlina tzipriota',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'corona tzeca',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'marcu de sa Germània orientale',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'marcu tedescu',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'francu gibutianu',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'corona danesa',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominicanu',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinar algerinu',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'sucre ecuadorenu',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'unidade de valore costante ecuadorena',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'corona estonesa',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'isterlina egitziana',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nafka eritreu',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'peseta ispagnola (contu A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'peseta ispagnola (contu cunvertìbile)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'peseta ispagnola',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr etìope',
        ],
        'EUR' => [
            0 => '€',
            1 => 'èuro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'marcu finlandesu',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dòllaru fijianu',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'isterlina de sas ìsulas Falklands',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'francu frantzesu',
        ],
        'GBP' => [
            0 => '£',
            1 => 'isterlina britànnica',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'kupon larit georgianu',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'lari georgianu',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'cedi ganesu (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cedi ganesu',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'isterlina de Gibilterra',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambianu',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'francu guineanu',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'syli guineanu',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekwele de sa Guinea Ecuadoriana',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'dracma greca',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal guatemaltecu',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'iscudu de sa Guinea portoghesa',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'peso de sa Guinea-Bissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dòllaru guyanesu',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'dòllaru de Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira hondurenu',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'dinar croatu',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna croata',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haitianu',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'fiorinu ungheresu',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'rupia indonesiana',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'isterlina irlandesa',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'isterlina israeliana',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'siclu israelianu (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'siclu nou israelianu',
        ],
        'INR' => [
            0 => '₹',
            1 => 'rupia indiana',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'dinar irachenu',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'rial iranianu',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'corona islandesa (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'corona islandesa',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'lira italiana',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dòllaru giamaicanu',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'dinar giordanu',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'yen giaponesu',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'iscellinu kenianu',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'som kirghisu',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'riel cambogianu',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'francu comorianu',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'won nordcoreanu',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'hwan sudcoreanu (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'won sudcoreanu (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'won sudcoreanu',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'dinar kuwaitianu',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dòllaru de sas Ìsulas Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'tenge kazaku',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip laotianu',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'isterlina lebanesa',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'rupia de su Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dòllaru liberianu',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti lesothianu',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litas lituanu',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'talonas lituanu',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'francu cunvertìbile lussemburghesu',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'francu lussemburghesu',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'francu finantziàriu lussemburghesu',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'lats lètone',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'rublu lètone',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinar lìbicu',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marochinu',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'francu marochinu',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'francu monegascu',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'cupon moldavu',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'leu moldavu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary malgàsciu',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'francu malgàsciu',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'denar matzèdone',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'denar matzèdone (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'francu malianu',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'kyat de su Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'tugrik mòngolu',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'pataca macanesa',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ouguiya mauritiana (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ouguiya mauritiana',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'lira maltesa',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'isterlina maltesa',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupia mauritziana',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'rupia maldiviana (1947–1981)',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'rufiyaa maldiviana',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha malawiana',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'peso messicanu',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'peso de prata messicanu (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'unidade de investimentu messicana',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'ringgit malesu',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'iscudu mozambicanu',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'metical mozambicanu (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical mozambicanu',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dòllaru namibianu',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nigeriana',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'córdoba nicaraguesu (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'córdoba nicaraguesu',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'fiorinu olandesu',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'corona norvegesa',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'rupia nepalesa',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'dòllaru neozelandesu',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'rial omanesu',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa panamesu',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'inti peruvianu',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol peruvianu',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'sol peruvianu (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina papuana',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'peso filipinu',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'rupia pakistana',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'zloty polacu',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'złoty polacu (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'iscudu portoghesu',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guaraní paraguayanu',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'rial catarianu',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'dòllaru rhodesianu',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'leu rumenu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'leu rumenu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinar serbu',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rublu russu',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'rublu russu (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'francu ruandesu',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'riyal saudita',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dòllaru de sas Ìsulas Salomone',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupia seychellesa',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'dinar sudanesu (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'isterlina sudanesa',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'isterlina sudanesa (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'corona isvedesa',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'dòllaru de Singapore',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'isterlina de Sant’Elene',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'tolar islovenu',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'corona islovaca',
        ],
        'SLE' => [
            0 => 'SLE',
            1 => 'leone nou de sa Sierra Leone',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone de sa Sierra Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'iscellinu sòmalu',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dòllaru surinamesu',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'fiorinu surinamesu',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'isterlina sud-sudanesa',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra de São Tomé e Príncipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra de São Tomé e Príncipe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'rublu sovièticu',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'colón salvadorenu',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'isterlina siriana',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni de s’Eswatini',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'baht tailandesu',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'rublu tagiku',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'somoni tagiku',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'manat turkmenu (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'manat turkmenu',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinar tunisinu',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'paʻanga tongana',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'iscudu timoresu',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'lira turca (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'lira turca',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dòllaru de Trinidad e Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'dòllaru nou taiwanesu',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'iscellinu tanzanianu',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'hryvnia ucraina',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'karbovanets ucrainu',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'iscellinu ugandesu (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'iscellinu ugandesu',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'dòllaru americanu',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'dòllaru americanu (die imbeniente)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'dòllaru americanu (die matessi)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'peso uruguayanu (unidades inditzizadas)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'peso uruguayanu (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso uruguayanu',
        ],
        'UYW' => [
            0 => 'UYW',
            1 => 'unidade ìnditze de sos salàrios nominales uruguayanos',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'som uzbeku',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'bolivar venezuelanu (1871–2008)',
        ],
        'VED' => [
            0 => 'VED',
            1 => 'bolivar soberanu',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'bolivar venezuelanu (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'bolivar venezuelanu',
        ],
        'VND' => [
            0 => '₫',
            1 => 'dong vietnamesu',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'dong vietnamesu (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu de Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala samoana',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'francu CFA BEAC',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'dòllaru de sos Caràibes orientales',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'unidade de contu europea',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'francu oro frantzesu',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'francu UIC frantzesu',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'francu CFA BCEAO',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'francu CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'fundos RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'dinar yemenita',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'rial yemenita',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'dinar forte yugoslavu (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'dinar nou yugoslavu (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'dinar cunvertìbile yugoslavu (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'dinar riformadu yugoslavu (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'rand sudafricanu (finantziàriu)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand sudafricanu',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'kwacha zambiana (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha zambiana',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zaire nou zaireanu (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zaire zaireanu (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'dòllaru zimbabweanu (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'dòllaru zimbabweanu (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'dòllaru zimbabweanu (2008)',
        ],
    ],
];
