<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andoros peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Jungtinių Arabų Emyratų dirhamas',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afganistano afganis (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afganistano afganis',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Albanijos lekas (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanijos lekas',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armėnijos dramas',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Olandijos Antilų guldenas',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolos kvanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolos kvanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolos naujoji kvanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolos patikslinta kvanza (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentinos australs',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Argentinos pesos ley (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Argentinos pesai (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentinos pesas (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentinos pesas',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Austrijos šilingas',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'Australijos doleris',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Arubos guldenas',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbaidžano manatas (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaidžano manatas',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosnijos ir Hercegovinos dinaras (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnijos ir Hercegovinos konvertuojamoji markė',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Bosnijos ir Hercegovinos naujasis dinaras (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadoso doleris',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladešo taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belgijos frankas (konvertuojamas)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgijos frankas',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belgijos frankas (finansinis)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgarijos levas (1962–1999)',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Bulgarų socialistų leva',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgarijos levas',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Bulgarijos levas (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreino dinaras',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundžio frankas',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermudos doleris',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunėjaus doleris',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivijos bolivijanas',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Bolivijos bolivijanas (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Bolivijos pesas',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Bolivijos mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Brazilijos naujieji kruzeirai (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Brazilijos kruzadai (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Brazilijos kruzeiras (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Brazilijos realas',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Brazilijos naujiejis kruzadai (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brazilijos kruzeiras (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Brazilijos kruzeirai (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamų doleris',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butano ngultrumas',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Birmos kijatas',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botsvanos pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Baltarusijos naujasis rublis (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Baltarusijos rublis',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Baltarusijos rublis (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belizo doleris',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Kanados doleris',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongo frankas',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR eurai',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Šveicarijos frankas',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR frankas',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Čilės eskudai',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Čiliečių unidades de fomentos',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Čilės pesas',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Kinijos Užsienio juanis',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Kinijos "People" banko doleris',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Kinijos ženminbi juanis',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbijos pesas',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'unidad de valor realai',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kosta Rikos kolonas',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Serbijos dinaras (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Čekoslovakų sunkusis korunas',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kubos konvertuojamasis pesas',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kubos pesas',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Žaliojo Kyšulio eskudas',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Kipro svaras',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Čekijos krona',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Rytų Vokietijos markė',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Vokietijos markė',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Džibučio frankas',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Danijos krona',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikos pesas',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Alžyro dinaras',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ekvadoro sukrė',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Ekvadoro constante (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estijos krona',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egipto svaras',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrėjos nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Ispanų pesetai (A sąskaita)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Ispanų pesetai (konvertuojama sąskaita)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Ispanijos peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiopijos biras',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euras',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Suomijos markė',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fidžio doleris',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falklando salų svaras',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Prancūzijos frankas',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'Didžiosios Britanijos svaras',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Gruzinų kupon larits',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gruzijos laris',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ganos sedis (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ganos sedis',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltaro svaras',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambijos dalasis',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gvinėjos frankas',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guinean sylis',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Pusiaujo Guinean ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Graikijos drachma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Gvatemalos ketcalis',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugalų Gvinėjos eskudas',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Gvinėjos-Bisau pesas',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Gajanos doleris',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Honkongo doleris',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Hondūro lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Kroatijos dinaras',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatijos kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haičio gurdas',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Vengrijos forintas',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonezijos rupija',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Airijos svaras',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Izraelio svaras',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'Izraelio šekelis (1980–1985)',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Izraelio naujasis šekelis',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Indijos rupija',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irako dinaras',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Irano rialas',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'Islandijos krona (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islandijos krona',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italijos lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaikos doleris',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordanijos dinaras',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'Japonijos jena',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenijos šilingas',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgizijos somas',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodžos rielis',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komoro frankas',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Šiaurės Korėjos vonas',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Pietų Korėjos hwanas (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Pietų Korėjos vonas (1945–1953)',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'Pietų Korėjos vonas',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuveito dinaras',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kaimanų salų doleris',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazachstano tengė',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laoso kipas',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libano svaras',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Šri Lankos rupija',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberijos doleris',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesoto lotis',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Lietuvos litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Lietuvos talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Liuksemburgo konvertuojamas frankas',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Liuksemburgo frankas',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Liuksemburgo finansinis frankas',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Latvijos latas',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Latvijos rublis',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libijos dinaras',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Maroko dirhamas',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Maroko frankas',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Monegasque frankas',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Moldovų cupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovos lėja',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskaro ariaris',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madagaskaro frankas',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedonijos denaras',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Makedonijos denaras (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malio frankas',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Mianmaro kijatas',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolijos tugrikas',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao pataka',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritanijos ugija (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritanijos ugija',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltos lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltos svaras',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauricijaus rupija',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'Maldyvų rupija',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldyvų rufija',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malavio kvača',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Meksikos pesas',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Meksikos sidabrinis pesas (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Meksikos United de Inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malaizijos ringitas',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambiko eskudas',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mozambiko metikalis (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambiko metikalis',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibijos doleris',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigerijos naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nikaragvos kardoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragvos kordoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Nyderlandų guldenas',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norvegijos krona',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalo rupija',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'Naujosios Zelandijos doleris',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omano rialas',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamos balboja',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peru intis',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru solis',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peru solis (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua Naujosios Gvinėjos kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filipinų pesas',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistano rupija',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Lenkijos zlotas',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Lenkijos zlotas (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugalijos eskudas',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paragvajaus guaranis',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Kataro rialas',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rodezijos doleris',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rumunijos lėja (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumunijos lėja',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbijos dinaras',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rusijos rublis',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rusijos rublis (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruandos frankas',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudo Arabijos rijalas',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Saliamono salų doleris',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seišelių rupija',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Sudano dinaras (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudano svaras',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Sudano svaras (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Švedijos krona',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapūro doleris',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Šv. Elenos salų svaras',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slovėnijos tolaras',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovakijos krona',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Siera Leonės leonė',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalio šilingas',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surimano doleris',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surimano guldenas',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Pietų Sudano svaras',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'San Tomės ir Principės dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'San Tomės ir Principės dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovietų rublis',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Salvadoro kolonas',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Sirijos svaras',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svazilando lilangenis',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Tailando batas',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadžikistano rublis',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadžikistano somonis',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmėnistano manatas (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmėnistano manatas',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tuniso dinaras',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongo paanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timoro eskudas',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turkijos lira (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkijos lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidado ir Tobago doleris',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'Taivano naujasis doleris',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzanijos šilingas',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrainos grivina',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrainos karbovanecas',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Ugandos šilingas (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandos šilingas',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'JAV doleris',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'JAV doleris (kitos dienos)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'JAV doleris (šios dienos)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Urugvajaus pesai en unidades indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Urugvajaus pesas (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Urugvajaus pesas',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Uzbekistano sumas',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venesuelos bolivaras (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venesuelos bolivaras (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venesuelos bolivaras',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'Vietnamo dongas',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Vietnamo dongas (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu vatas',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa tala',
        ],
        'XAF' => [
            0 => 'XAF',
            1 => 'CFA BEAC frankas',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'Rytų Karibų doleris',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Europos piniginis vienetas (1993–1999)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Aukso frankas',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Prancūzijos UIC - frankas',
        ],
        'XOF' => [
            0 => 'XOF',
            1 => 'CFA BCEAO frankas',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'CFP frankas',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET fondai',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemeno dinaras',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemeno rialas',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Jugoslavijos kietasis dinaras (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Jugoslavijos naujasis dinaras (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Jugoslavijos konvertuojamas dinaras (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Jugoslavijos reformuotas dinaras (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Pietų Afrikos finansinis randas',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Pietų Afrikos Respublikos randas',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambijos kvača (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambijos kvača',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zairo naujasis zairas (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zairo zairas (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabvės doleris (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabvės doleris (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabvės doleris (2008)',
        ],
    ],
];
