<?php

return [
    'Names' => [
        'ar_001' => 'arábagiella (Máilbmi)',
        'ar_SD' => 'arábagiella (Sudan)',
        'ar_TD' => 'arábagiella (Chad)',
        'be' => 'vilgesruoššagiella',
        'be_BY' => 'vilgesruoššagiella (Vilges-Ruošša)',
        'bn' => 'bengalagiella',
        'bn_BD' => 'bengalagiella (Bangladesh)',
        'bn_IN' => 'bengalagiella (India)',
        'bs_BA' => 'bosniagiella (Bosnia ja Hercegovina)',
        'bs_Cyrl_BA' => 'bosniagiella (kyrillalaš, Bosnia ja Hercegovina)',
        'bs_Latn_BA' => 'bosniagiella (láhtenaš, Bosnia ja Hercegovina)',
        'en_001' => 'eaŋgalsgiella (Máilbmi)',
        'en_SD' => 'eaŋgalsgiella (Sudan)',
        'es_419' => 'spánskkagiella (Latiinnalaš Amerihká)',
        'fr_TD' => 'fránskkagiella (Chad)',
        'hr_BA' => 'kroátiagiella (Bosnia ja Hercegovina)',
        'hy' => 'armenagiella',
        'hy_AM' => 'armenagiella (Armenia)',
        'kk' => 'kazakhgiella',
        'kk_KZ' => 'kazakhgiella (Kasakstan)',
        'km' => 'kambožagiella',
        'km_KH' => 'kambožagiella (Kamboža)',
        'ne' => 'nepalagiella',
        'ne_IN' => 'nepalagiella (India)',
        'ne_NP' => 'nepalagiella (Nepal)',
        'pa' => 'panjabagiella',
        'pa_Arab' => 'panjabagiella (arábalaš)',
        'pa_Arab_PK' => 'panjabagiella (arábalaš, Pakistan)',
        'pa_IN' => 'panjabagiella (India)',
        'pa_PK' => 'panjabagiella (Pakistan)',
        'sh_BA' => 'serbokroatiagiella (Bosnia ja Hercegovina)',
        'sr_BA' => 'serbiagiella (Bosnia ja Hercegovina)',
        'sr_Cyrl_BA' => 'serbiagiella (kyrillalaš, Bosnia ja Hercegovina)',
        'sr_Latn_BA' => 'serbiagiella (láhtenaš, Bosnia ja Hercegovina)',
        'th' => 'thaigiella',
        'th_TH' => 'thaigiella (Thaieana)',
        'vi' => 'vietnamagiella',
        'vi_VN' => 'vietnamagiella (Vietnam)',
        'zh_Hans' => 'kiinnágiella (álkes kiinnálaš)',
        'zh_Hans_CN' => 'kiinnágiella (álkes kiinnálaš, Kiinná)',
        'zh_Hans_HK' => 'kiinnágiella (álkes kiinnálaš, Hongkong)',
        'zh_Hans_MO' => 'kiinnágiella (álkes kiinnálaš, Makáo)',
        'zh_Hans_SG' => 'kiinnágiella (álkes kiinnálaš, Singapore)',
        'zh_Hant' => 'kiinnágiella (árbevirolaš kiinnálaš)',
        'zh_Hant_HK' => 'kiinnágiella (árbevirolaš kiinnálaš, Hongkong)',
        'zh_Hant_MO' => 'kiinnágiella (árbevirolaš kiinnálaš, Makáo)',
        'zh_Hant_TW' => 'kiinnágiella (árbevirolaš kiinnálaš, Taiwan)',
    ],
];
