<?php

return [
    'Names' => [
        'America/Adak' => 'ꂰꇩ (Adak)',
        'America/Anchorage' => 'ꂰꇩ (Anchorage)',
        'America/Araguaina' => 'ꀠꑭ (Araguaina)',
        'America/Bahia' => 'ꀠꑭ (Bahia)',
        'America/Belem' => 'ꀠꑭ (Belem)',
        'America/Boa_Vista' => 'ꀠꑭ (Boa Vista)',
        'America/Boise' => 'ꂰꇩ (Boise)',
        'America/Campo_Grande' => 'ꀠꑭ (Campo Grande)',
        'America/Chicago' => 'ꂰꇩ (Chicago)',
        'America/Cuiaba' => 'ꀠꑭ (Cuiaba)',
        'America/Denver' => 'ꂰꇩ (Denver)',
        'America/Detroit' => 'ꂰꇩ (Detroit)',
        'America/Eirunepe' => 'ꀠꑭ (Eirunepe)',
        'America/Fortaleza' => 'ꀠꑭ (Fortaleza)',
        'America/Indiana/Knox' => 'ꂰꇩ (Knox, Indiana)',
        'America/Indiana/Marengo' => 'ꂰꇩ (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'ꂰꇩ (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'ꂰꇩ (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'ꂰꇩ (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'ꂰꇩ (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'ꂰꇩ (Winamac, Indiana)',
        'America/Indianapolis' => 'ꂰꇩ (Indianapolis)',
        'America/Juneau' => 'ꂰꇩ (Juneau)',
        'America/Kentucky/Monticello' => 'ꂰꇩ (Monticello, Kentucky)',
        'America/Los_Angeles' => 'ꂰꇩ (Los Angeles)',
        'America/Louisville' => 'ꂰꇩ (Louisville)',
        'America/Maceio' => 'ꀠꑭ (Maceio)',
        'America/Manaus' => 'ꀠꑭ (Manaus)',
        'America/Menominee' => 'ꂰꇩ (Menominee)',
        'America/Metlakatla' => 'ꂰꇩ (Metlakatla)',
        'America/New_York' => 'ꂰꇩ (New York)',
        'America/Nome' => 'ꂰꇩ (Nome)',
        'America/Noronha' => 'ꀠꑭ (Noronha)',
        'America/North_Dakota/Beulah' => 'ꂰꇩ (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'ꂰꇩ (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'ꂰꇩ (New Salem, North Dakota)',
        'America/Phoenix' => 'ꂰꇩ (Phoenix)',
        'America/Porto_Velho' => 'ꀠꑭ (Porto Velho)',
        'America/Recife' => 'ꀠꑭ (Recife)',
        'America/Rio_Branco' => 'ꀠꑭ (Rio Branco)',
        'America/Santarem' => 'ꀠꑭ (Santarem)',
        'America/Sao_Paulo' => 'ꀠꑭ (Sao Paulo)',
        'America/Sitka' => 'ꂰꇩ (Sitka)',
        'America/Yakutat' => 'ꂰꇩ (Yakutat)',
        'Antarctica/Troll' => 'Troll',
        'Asia/Anadyr' => 'ꊉꇆꌦ (Anadyr)',
        'Asia/Barnaul' => 'ꊉꇆꌦ (Barnaul)',
        'Asia/Calcutta' => 'ꑴꄗ (Kolkata)',
        'Asia/Chita' => 'ꊉꇆꌦ (Chita)',
        'Asia/Irkutsk' => 'ꊉꇆꌦ (Irkutsk)',
        'Asia/Kamchatka' => 'ꊉꇆꌦ (Kamchatka)',
        'Asia/Khandyga' => 'ꊉꇆꌦ (Khandyga)',
        'Asia/Krasnoyarsk' => 'ꊉꇆꌦ (Krasnoyarsk)',
        'Asia/Magadan' => 'ꊉꇆꌦ (Magadan)',
        'Asia/Novokuznetsk' => 'ꊉꇆꌦ (Novokuznetsk)',
        'Asia/Novosibirsk' => 'ꊉꇆꌦ (Novosibirsk)',
        'Asia/Omsk' => 'ꊉꇆꌦ (Omsk)',
        'Asia/Sakhalin' => 'ꊉꇆꌦ (Sakhalin)',
        'Asia/Shanghai' => 'ꍏꇩ (Shanghai)',
        'Asia/Srednekolymsk' => 'ꊉꇆꌦ (Srednekolymsk)',
        'Asia/Tokyo' => 'ꏝꀪ (Tokyo)',
        'Asia/Tomsk' => 'ꊉꇆꌦ (Tomsk)',
        'Asia/Urumqi' => 'ꍏꇩ (Urumqi)',
        'Asia/Ust-Nera' => 'ꊉꇆꌦ (Ust-Nera)',
        'Asia/Vladivostok' => 'ꊉꇆꌦ (Vladivostok)',
        'Asia/Yakutsk' => 'ꊉꇆꌦ (Yakutsk)',
        'Asia/Yekaterinburg' => 'ꊉꇆꌦ (Yekaterinburg)',
        'Europe/Astrakhan' => 'ꊉꇆꌦ (Astrakhan)',
        'Europe/Berlin' => 'ꄓꇩ (Berlin)',
        'Europe/Busingen' => 'ꄓꇩ (Busingen)',
        'Europe/Kaliningrad' => 'ꊉꇆꌦ (Kaliningrad)',
        'Europe/Kirov' => 'ꊉꇆꌦ (Kirov)',
        'Europe/London' => 'ꑱꇩ (London)',
        'Europe/Moscow' => 'ꊉꇆꌦ (Moscow)',
        'Europe/Paris' => 'ꃔꇩ (Paris)',
        'Europe/Rome' => 'ꑴꄊꆺ (Rome)',
        'Europe/Samara' => 'ꊉꇆꌦ (Samara)',
        'Europe/Saratov' => 'ꊉꇆꌦ (Saratov)',
        'Europe/Ulyanovsk' => 'ꊉꇆꌦ (Ulyanovsk)',
        'Europe/Volgograd' => 'ꊉꇆꌦ (Volgograd)',
        'Pacific/Honolulu' => 'ꂰꇩ (Honolulu)',
    ],
    'Meta' => [
    ],
];
