<?php

return [
    'Names' => [
        'en_CC' => 'انگریزی (جزائر [کیلنگ] کوکوس)',
        'en_CK' => 'انگریزی (جزائر کک)',
        'en_FK' => 'انگریزی (جزائر فاکلینڈ)',
        'en_IO' => 'انگریزی (برطانوی بحرہند خطہ)',
        'en_MH' => 'انگریزی (جزائر مارشل)',
        'en_MP' => 'انگریزی (جزائر شمالی ماریانا)',
        'en_NF' => 'انگریزی (جزیرہ نارفوک)',
        'en_PN' => 'انگریزی (جزائر پٹکیرن)',
        'en_SB' => 'انگریزی (جزائر سلیمان)',
        'en_TC' => 'انگریزی (جزائر کیکس و ترکیہ)',
        'en_UM' => 'انگریزی (امریکی بیرونی جزائر)',
        'en_VG' => 'انگریزی (برطانوی جزائر ورجن)',
        'en_VI' => 'انگریزی (امریکی جزائر ورجن)',
        'fo_FO' => 'فیروئیز (جزائر فیرو)',
        'fr_GF' => 'فرانسیسی (فرانسیسی گیانا)',
        'hr' => 'کروشین',
        'hr_BA' => 'کروشین (بوسنیا اور ہرزیگووینا)',
        'hr_HR' => 'کروشین (کروشیا)',
        'jv' => 'جاوانیز',
        'jv_ID' => 'جاوانیز (انڈونیشیا)',
        'ka' => 'جارجيائى',
        'ka_GE' => 'جارجيائى (جارجیا)',
        'kl' => 'کلالیسٹ',
        'kl_GL' => 'کلالیسٹ (گرین لینڈ)',
        'kn' => 'کنڑ',
        'kn_IN' => 'کنڑ (بھارت)',
        'ku' => 'کرد',
        'ku_TR' => 'کرد (ترکی)',
        'sv_AX' => 'سویڈش (جزائر آلینڈ)',
    ],
];
