<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorrskur peseti',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'arabískt dírham',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afgani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albanskt lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'armenskt dramm',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'hollenskt Antillugyllini',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angólsk kvansa',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentine Austral',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentískur pesi (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentínskur pesi',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Austurrískur skildingur',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'ástralskur dalur',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arúbönsk flórína',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'aserskt manat',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'skiptanlegt Bosníu og Hersegóvínu-mark',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadoskur dalur',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladessk taka',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgískur franki',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Lef',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'búlgarskt lef',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bareinskur denari',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'búrúndískur franki',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermúdadalur',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'brúneiskur dalur',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'bólivíani',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Bólivískur pesi',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Bolivian Mvdol',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'brasilískt ríal',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamadalur',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'bútanskt núltrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Búrmverskt kjat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'botsvönsk púla',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'hvítrússnesk rúbla',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'hvítrússnesk rúbla (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'belískur dalur',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Kanadadalur',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'kongóskur franki',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'svissneskur franki',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Chilean Unidades de Fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'síleskur pesi',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'kínverskt júan (utan heimalands)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'kínverskt júan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'kólumbískur pesi',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'kostarískt kólon',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Tékknesk króna, eldri',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'kúbverskur skiptanlegur pesi',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'kúbverskur pesi',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'grænhöfðeyskur skúti',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Kýpverskt pund',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'tékknesk króna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Austurþýskt mark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Þýskt mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'djíbútískur franki',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'dönsk króna',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dóminískur pesi',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'alsírskur denari',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ecuador Sucre',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Eistnesk króna',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egypskt pund',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'erítresk nakfa',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Spænskur peseti',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'eþíópískt birr',
        ],
        'EUR' => [
            0 => 'EUR',
            1 => 'evra',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Finnskt mark',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fídjískur dalur',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'falklenskt pund',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franskur franki',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'sterlingspund',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'georgískur lari',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ganverskur sedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gíbraltarspund',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambískur dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gíneufranki',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Drakma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'gvatemalskt kvesal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portúgalskur, gíneskur skúti',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'gvæjanskur dalur',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hong Kong-dalur',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'hondúrsk lempíra',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'króatísk kúna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haítískur gúrdi',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'ungversk fórinta',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indónesísk rúpía',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Írskt pund',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Ísraelskt pund',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'nýr ísraelskur sikill',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'indversk rúpía',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'írakskur denari',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'íranskt ríal',
        ],
        'ISK' => [
            0 => 'kr.',
            1 => 'íslensk króna',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Ítölsk líra',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamaískur dalur',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jórdanskur denari',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'japanskt jen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenískur skildingur',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgiskt som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'kambódískt ríal',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'kómoreyskur franki',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'norðurkóreskt vonn',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'suðurkóreskt vonn',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kúveiskur denari',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'caymaneyskur dalur',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kasakst tengi',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laoskt kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'líbanskt pund',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'srílönsk rúpía',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'líberískur dalur',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesótóskur lóti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litháískt lít',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Lithuanian Talonas',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Lúxemborgarfranki',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lettneskt lat',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Lettnesk rúbla',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'líbískur denari',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'marokkóskt dírham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokkóskur franki',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldavískt lei',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskararjari',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madagaskur franki',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'makedónskur denari',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malískur franki',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'mjanmarskt kjat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongólskur túríkur',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'makaósk pataka',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'márítönsk úgía (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'márítönsk úgía',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Meltnesk líra',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltneskt pund',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'máritísk rúpía',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldíveysk rúpía',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'malavísk kvaka',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'mexíkóskur pesi',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Mexíkóskur silfurpesi (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Mexíkóskur pesi, UDI',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malasískt ringit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mósambískur skúti',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'mósambískt metikal',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'namibískur dalur',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nígerísk næra',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Níkarögsk kordóva (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'níkarögsk kordóva',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Hollenskt gyllini',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'norsk króna',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepölsk rúpía',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'nýsjálenskur dalur',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'ómanskt ríal',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balbói',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'perúskt sól',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'papúsk kína',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'filippseyskur pesi',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistönsk rúpía',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'pólskt slot',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Slot',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portúgalskur skúti',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paragvæskt gvaraní',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'katarskt ríal',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rúmenskt lei (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'rúmenskt lei',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'serbneskur denari',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rússnesk rúbla',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rússnesk rúbla (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'rúandskur franki',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'sádíarabískt ríal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'salómonseyskur dalur',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seychellesrúpía',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Súdanskur denari',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'súdanskt pund',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Súdanskt pund (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'sænsk króna',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singapúrskur dalur',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'helenskt pund',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slóvenskur dalur',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slóvakísk króna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'síerraleónsk ljóna',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'sómalískur skildingur',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Súrínamdalur',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Suriname Guilder',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'suðursúdanskt pund',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Saó Tóme og Prinsípe-dóbra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Saó Tóme og Prinsípe-dóbra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Soviet Rouble',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'El Salvador Colon',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'sýrlenskt pund',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'svasílenskur lílangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'taílenskt bat',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadsjiksk rúbla',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tadsjikskur sómóni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Túrkmenskt manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'túrkmenskt manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'túniskur denari',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongapanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Tímorskur skúti',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Tyrknesk líra (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'tyrknesk líra',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trínidad og Tóbagó-dalur',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'taívanskur dalur',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'tansanískur skildingur',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'úkraínsk hrinja',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrainian Karbovanetz',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'úgandskur skildingur',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'Bandaríkjadalur',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Bandaríkjadalur (næsta dag)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Bandaríkjadalur (sama dag)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'úrúgvæskur pesi',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'úsbekskt súm',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Bolívar í Venesúela (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venesúelskur bólívari (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venesúelskur bólívari',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'víetnamskt dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanúatúskt vatú',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samóatala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'miðafrískur franki',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'austurkarabískur dalur',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franskur gullfranki',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Franskur franki, UIC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'vesturafrískur franki',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'pólinesískur franki',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemenskur denari',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'jemenskt ríal',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Júgóslavneskur denari',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Rand (viðskipta)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'suðurafrískt rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambian Kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'sambísk kvaka',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Simbabveskur dalur',
        ],
    ],
];
