<?php

/**
 * Belarusian PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Aleksander Maksymiuk <info@setpro.pl>
 */

$PHPMAILER_LANG['authenticate']         = 'Памылка SMTP: памылка ідэнтыфікацыі.';
$PHPMAILER_LANG['connect_host']         = 'Памылка SMTP: нельга ўстанавіць сувязь з SMTP-серверам.';
$PHPMAILER_LANG['data_not_accepted']    = 'Памылка SMTP: звесткі непрынятыя.';
$PHPMAILER_LANG['empty_message']        = 'Пустое паведамленне.';
$PHPMAILER_LANG['encoding']             = 'Невядомая кадыроўка тэксту: ';
$PHPMAILER_LANG['execute']              = 'Нельга выканаць каманду: ';
$PHPMAILER_LANG['file_access']          = 'Няма доступу да файла: ';
$PHPMAILER_LANG['file_open']            = 'Нельга адкрыць файл: ';
$PHPMAILER_LANG['from_failed']          = 'Няправільны адрас адпраўніка: ';
$PHPMAILER_LANG['instantiate']          = 'Нельга прымяніць функцыю mail().';
$PHPMAILER_LANG['invalid_address']      = 'Нельга даслаць паведамленне, няправільны email атрымальніка: ';
$PHPMAILER_LANG['provide_address']      = 'Запоўніце, калі ласка, правільны email атрымальніка.';
$PHPMAILER_LANG['mailer_not_supported'] = ' - паштовы сервер не падтрымліваецца.';
$PHPMAILER_LANG['recipients_failed']    = 'Памылка SMTP: няправільныя атрымальнікі: ';
$PHPMAILER_LANG['signing']              = 'Памылка подпісу паведамлення: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'Памылка сувязі з SMTP-серверам.';
$PHPMAILER_LANG['smtp_error']           = 'Памылка SMTP: ';
$PHPMAILER_LANG['variable_set']         = 'Нельга ўстанавіць або перамяніць значэнне пераменнай: ';
//$PHPMAILER_LANG['extension_missing']    = 'Extension missing: ';
