<?php

return [
    'Names' => [
        'sr' => 'ሰርብኛ',
        'sr_BA' => 'ሰርብኛ (ቦዝንያን ሄርዘጎቪናን)',
        'sr_Latn' => 'ሰርብኛ (ላቲን)',
        'sr_Latn_BA' => 'ሰርብኛ (ላቲን፣ ቦዝንያን ሄርዘጎቪናን)',
        'sr_Latn_ME' => 'ሰርብኛ (ላቲን፣ ሞንተኔግሮ)',
        'sr_Latn_RS' => 'ሰርብኛ (ላቲን፣ ሰርብያ)',
        'sr_ME' => 'ሰርብኛ (ሞንተኔግሮ)',
        'sr_RS' => 'ሰርብኛ (ሰርብያ)',
    ],
];
