<?php

return [
    'Names' => [
        'ak' => 'Akâan',
        'am' => 'Amarîki',
        'ar' => 'Arâbo',
        'be' => 'Bielörûsi',
        'bg' => 'Bulugäri',
        'bn' => 'Bengäli',
        'cs' => 'Tyêki',
        'de' => 'Zâmani',
        'el' => 'Gerêki',
        'en' => 'Anglëe',
        'es' => 'Espanyöl',
        'fa' => 'Farsî',
        'fr' => 'Farânzi',
        'ha' => 'Haüsä',
        'hi' => 'Hîndi',
        'hu' => 'Hongruäa',
        'id' => 'Enndonezïi',
        'ig' => 'Ïgbö',
        'it' => 'Ênnde',
        'ja' => 'Zaponëe',
        'jv' => 'Zavanëe',
        'km' => 'Kmêre',
        'ko' => 'Koreyëen',
        'ms' => 'Malëe',
        'my' => 'Miamära, Birimäni',
        'ne' => 'Nepalëe',
        'nl' => 'Holandëe',
        'pa' => 'Penzäbï',
        'pl' => 'Polonëe',
        'pt' => 'Portugëe, Pûra',
        'ro' => 'Rumëen',
        'ru' => 'Rûsi',
        'rw' => 'Ruandäa',
        'sg' => 'Sängö',
        'so' => 'Somalïi',
        'sv' => 'Sueduäa',
        'ta' => 'Tämûli',
        'th' => 'Thâi',
        'tr' => 'Tûrûku',
        'uk' => 'Ukrêni',
        'ur' => 'Ûrdu',
        'vi' => 'Vietnäm',
        'yo' => 'Yoruba',
        'zh' => 'Shinuäa',
        'zu' => 'Zûlu',
    ],
    'LocalizedNames' => [
    ],
];
