<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (Afrika Selatan)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amharic',
        'am_ET' => 'Amharic (Ethiopia)',
        'ar' => 'Arab',
        'ar_001' => 'Arab (Dunia)',
        'ar_AE' => 'Arab (Emiriah Arab Bersatu)',
        'ar_BH' => 'Arab (Bahrain)',
        'ar_DJ' => 'Arab (Djibouti)',
        'ar_DZ' => 'Arab (Algeria)',
        'ar_EG' => 'Arab (Mesir)',
        'ar_EH' => 'Arab (Sahara Barat)',
        'ar_ER' => 'Arab (Eritrea)',
        'ar_IL' => 'Arab (Israel)',
        'ar_IQ' => 'Arab (Iraq)',
        'ar_JO' => 'Arab (Jordan)',
        'ar_KM' => 'Arab (Comoros)',
        'ar_KW' => 'Arab (Kuwait)',
        'ar_LB' => 'Arab (Lubnan)',
        'ar_LY' => 'Arab (Libya)',
        'ar_MA' => 'Arab (Maghribi)',
        'ar_MR' => 'Arab (Mauritania)',
        'ar_OM' => 'Arab (Oman)',
        'ar_PS' => 'Arab (Wilayah Palestin)',
        'ar_QA' => 'Arab (Qatar)',
        'ar_SA' => 'Arab (Arab Saudi)',
        'ar_SD' => 'Arab (Sudan)',
        'ar_SO' => 'Arab (Somalia)',
        'ar_SS' => 'Arab (Sudan Selatan)',
        'ar_SY' => 'Arab (Syria)',
        'ar_TD' => 'Arab (Chad)',
        'ar_TN' => 'Arab (Tunisia)',
        'ar_YE' => 'Arab (Yaman)',
        'as' => 'Assam',
        'as_IN' => 'Assam (India)',
        'az' => 'Azerbaijan',
        'az_AZ' => 'Azerbaijan (Azerbaijan)',
        'az_Cyrl' => 'Azerbaijan (Cyril)',
        'az_Cyrl_AZ' => 'Azerbaijan (Cyril, Azerbaijan)',
        'az_Latn' => 'Azerbaijan (Latin)',
        'az_Latn_AZ' => 'Azerbaijan (Latin, Azerbaijan)',
        'be' => 'Belarus',
        'be_BY' => 'Belarus (Belarus)',
        'bg' => 'Bulgaria',
        'bg_BG' => 'Bulgaria (Bulgaria)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Benggali',
        'bn_BD' => 'Benggali (Bangladesh)',
        'bn_IN' => 'Benggali (India)',
        'bo' => 'Tibet',
        'bo_CN' => 'Tibet (China)',
        'bo_IN' => 'Tibet (India)',
        'br' => 'Breton',
        'br_FR' => 'Breton (Perancis)',
        'bs' => 'Bosnia',
        'bs_BA' => 'Bosnia (Bosnia dan Herzegovina)',
        'bs_Cyrl' => 'Bosnia (Cyril)',
        'bs_Cyrl_BA' => 'Bosnia (Cyril, Bosnia dan Herzegovina)',
        'bs_Latn' => 'Bosnia (Latin)',
        'bs_Latn_BA' => 'Bosnia (Latin, Bosnia dan Herzegovina)',
        'ca' => 'Catalonia',
        'ca_AD' => 'Catalonia (Andorra)',
        'ca_ES' => 'Catalonia (Sepanyol)',
        'ca_FR' => 'Catalonia (Perancis)',
        'ca_IT' => 'Catalonia (Itali)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (Rusia)',
        'cs' => 'Czech',
        'cs_CZ' => 'Czech (Czechia)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Rusia)',
        'cy' => 'Wales',
        'cy_GB' => 'Wales (United Kingdom)',
        'da' => 'Denmark',
        'da_DK' => 'Denmark (Denmark)',
        'da_GL' => 'Denmark (Greenland)',
        'de' => 'Jerman',
        'de_AT' => 'Jerman (Austria)',
        'de_BE' => 'Jerman (Belgium)',
        'de_CH' => 'Jerman (Switzerland)',
        'de_DE' => 'Jerman (Jerman)',
        'de_IT' => 'Jerman (Itali)',
        'de_LI' => 'Jerman (Liechtenstein)',
        'de_LU' => 'Jerman (Luxembourg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Greek',
        'el_CY' => 'Greek (Cyprus)',
        'el_GR' => 'Greek (Greece)',
        'en' => 'Inggeris',
        'en_001' => 'Inggeris (Dunia)',
        'en_150' => 'Inggeris (Eropah)',
        'en_AE' => 'Inggeris (Emiriah Arab Bersatu)',
        'en_AG' => 'Inggeris (Antigua dan Barbuda)',
        'en_AI' => 'Inggeris (Anguilla)',
        'en_AS' => 'Inggeris (Samoa Amerika)',
        'en_AT' => 'Inggeris (Austria)',
        'en_AU' => 'Inggeris (Australia)',
        'en_BB' => 'Inggeris (Barbados)',
        'en_BE' => 'Inggeris (Belgium)',
        'en_BI' => 'Inggeris (Burundi)',
        'en_BM' => 'Inggeris (Bermuda)',
        'en_BS' => 'Inggeris (Bahamas)',
        'en_BW' => 'Inggeris (Botswana)',
        'en_BZ' => 'Inggeris (Belize)',
        'en_CA' => 'Inggeris (Kanada)',
        'en_CC' => 'Inggeris (Kepulauan Cocos [Keeling])',
        'en_CH' => 'Inggeris (Switzerland)',
        'en_CK' => 'Inggeris (Kepulauan Cook)',
        'en_CM' => 'Inggeris (Cameroon)',
        'en_CX' => 'Inggeris (Pulau Krismas)',
        'en_CY' => 'Inggeris (Cyprus)',
        'en_DE' => 'Inggeris (Jerman)',
        'en_DK' => 'Inggeris (Denmark)',
        'en_DM' => 'Inggeris (Dominica)',
        'en_ER' => 'Inggeris (Eritrea)',
        'en_FI' => 'Inggeris (Finland)',
        'en_FJ' => 'Inggeris (Fiji)',
        'en_FK' => 'Inggeris (Kepulauan Falkland)',
        'en_FM' => 'Inggeris (Micronesia)',
        'en_GB' => 'Inggeris (United Kingdom)',
        'en_GD' => 'Inggeris (Grenada)',
        'en_GG' => 'Inggeris (Guernsey)',
        'en_GH' => 'Inggeris (Ghana)',
        'en_GI' => 'Inggeris (Gibraltar)',
        'en_GM' => 'Inggeris (Gambia)',
        'en_GU' => 'Inggeris (Guam)',
        'en_GY' => 'Inggeris (Guyana)',
        'en_HK' => 'Inggeris (Hong Kong SAR China)',
        'en_IE' => 'Inggeris (Ireland)',
        'en_IL' => 'Inggeris (Israel)',
        'en_IM' => 'Inggeris (Isle of Man)',
        'en_IN' => 'Inggeris (India)',
        'en_IO' => 'Inggeris (Wilayah Lautan Hindi British)',
        'en_JE' => 'Inggeris (Jersey)',
        'en_JM' => 'Inggeris (Jamaica)',
        'en_KE' => 'Inggeris (Kenya)',
        'en_KI' => 'Inggeris (Kiribati)',
        'en_KN' => 'Inggeris (Saint Kitts dan Nevis)',
        'en_KY' => 'Inggeris (Kepulauan Cayman)',
        'en_LC' => 'Inggeris (Saint Lucia)',
        'en_LR' => 'Inggeris (Liberia)',
        'en_LS' => 'Inggeris (Lesotho)',
        'en_MG' => 'Inggeris (Madagaskar)',
        'en_MH' => 'Inggeris (Kepulauan Marshall)',
        'en_MO' => 'Inggeris (Macau SAR China)',
        'en_MP' => 'Inggeris (Kepulauan Mariana Utara)',
        'en_MS' => 'Inggeris (Montserrat)',
        'en_MT' => 'Inggeris (Malta)',
        'en_MU' => 'Inggeris (Mauritius)',
        'en_MV' => 'Inggeris (Maldives)',
        'en_MW' => 'Inggeris (Malawi)',
        'en_MY' => 'Inggeris (Malaysia)',
        'en_NA' => 'Inggeris (Namibia)',
        'en_NF' => 'Inggeris (Pulau Norfolk)',
        'en_NG' => 'Inggeris (Nigeria)',
        'en_NL' => 'Inggeris (Belanda)',
        'en_NR' => 'Inggeris (Nauru)',
        'en_NU' => 'Inggeris (Niue)',
        'en_NZ' => 'Inggeris (New Zealand)',
        'en_PG' => 'Inggeris (Papua New Guinea)',
        'en_PH' => 'Inggeris (Filipina)',
        'en_PK' => 'Inggeris (Pakistan)',
        'en_PN' => 'Inggeris (Kepulauan Pitcairn)',
        'en_PR' => 'Inggeris (Puerto Rico)',
        'en_PW' => 'Inggeris (Palau)',
        'en_RW' => 'Inggeris (Rwanda)',
        'en_SB' => 'Inggeris (Kepulauan Solomon)',
        'en_SC' => 'Inggeris (Seychelles)',
        'en_SD' => 'Inggeris (Sudan)',
        'en_SE' => 'Inggeris (Sweden)',
        'en_SG' => 'Inggeris (Singapura)',
        'en_SH' => 'Inggeris (Saint Helena)',
        'en_SI' => 'Inggeris (Slovenia)',
        'en_SL' => 'Inggeris (Sierra Leone)',
        'en_SS' => 'Inggeris (Sudan Selatan)',
        'en_SX' => 'Inggeris (Sint Maarten)',
        'en_SZ' => 'Inggeris (Eswatini)',
        'en_TC' => 'Inggeris (Kepulauan Turks dan Caicos)',
        'en_TK' => 'Inggeris (Tokelau)',
        'en_TO' => 'Inggeris (Tonga)',
        'en_TT' => 'Inggeris (Trinidad dan Tobago)',
        'en_TV' => 'Inggeris (Tuvalu)',
        'en_TZ' => 'Inggeris (Tanzania)',
        'en_UG' => 'Inggeris (Uganda)',
        'en_UM' => 'Inggeris (Kepulauan Terpencil A.S.)',
        'en_US' => 'Inggeris (Amerika Syarikat)',
        'en_VC' => 'Inggeris (Saint Vincent dan Grenadines)',
        'en_VG' => 'Inggeris (Kepulauan Virgin British)',
        'en_VI' => 'Inggeris (Kepulauan Virgin A.S.)',
        'en_VU' => 'Inggeris (Vanuatu)',
        'en_WS' => 'Inggeris (Samoa)',
        'en_ZA' => 'Inggeris (Afrika Selatan)',
        'en_ZM' => 'Inggeris (Zambia)',
        'en_ZW' => 'Inggeris (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Dunia)',
        'es' => 'Sepanyol',
        'es_419' => 'Sepanyol (Amerika Latin)',
        'es_AR' => 'Sepanyol (Argentina)',
        'es_BO' => 'Sepanyol (Bolivia)',
        'es_BR' => 'Sepanyol (Brazil)',
        'es_BZ' => 'Sepanyol (Belize)',
        'es_CL' => 'Sepanyol (Chile)',
        'es_CO' => 'Sepanyol (Colombia)',
        'es_CR' => 'Sepanyol (Costa Rica)',
        'es_CU' => 'Sepanyol (Cuba)',
        'es_DO' => 'Sepanyol (Republik Dominica)',
        'es_EC' => 'Sepanyol (Ecuador)',
        'es_ES' => 'Sepanyol (Sepanyol)',
        'es_GQ' => 'Sepanyol (Guinea Khatulistiwa)',
        'es_GT' => 'Sepanyol (Guatemala)',
        'es_HN' => 'Sepanyol (Honduras)',
        'es_MX' => 'Sepanyol (Mexico)',
        'es_NI' => 'Sepanyol (Nicaragua)',
        'es_PA' => 'Sepanyol (Panama)',
        'es_PE' => 'Sepanyol (Peru)',
        'es_PH' => 'Sepanyol (Filipina)',
        'es_PR' => 'Sepanyol (Puerto Rico)',
        'es_PY' => 'Sepanyol (Paraguay)',
        'es_SV' => 'Sepanyol (El Salvador)',
        'es_US' => 'Sepanyol (Amerika Syarikat)',
        'es_UY' => 'Sepanyol (Uruguay)',
        'es_VE' => 'Sepanyol (Venezuela)',
        'et' => 'Estonia',
        'et_EE' => 'Estonia (Estonia)',
        'eu' => 'Basque',
        'eu_ES' => 'Basque (Sepanyol)',
        'fa' => 'Parsi',
        'fa_AF' => 'Parsi (Afghanistan)',
        'fa_IR' => 'Parsi (Iran)',
        'ff' => 'Fulah',
        'ff_Adlm' => 'Fulah (Adlam)',
        'ff_Adlm_BF' => 'Fulah (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fulah (Adlam, Cameroon)',
        'ff_Adlm_GH' => 'Fulah (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Fulah (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Fulah (Adlam, Guinea)',
        'ff_Adlm_GW' => 'Fulah (Adlam, Guinea Bissau)',
        'ff_Adlm_LR' => 'Fulah (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Fulah (Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Fulah (Adlam, Niger)',
        'ff_Adlm_NG' => 'Fulah (Adlam, Nigeria)',
        'ff_Adlm_SL' => 'Fulah (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fulah (Adlam, Senegal)',
        'ff_CM' => 'Fulah (Cameroon)',
        'ff_GN' => 'Fulah (Guinea)',
        'ff_Latn' => 'Fulah (Latin)',
        'ff_Latn_BF' => 'Fulah (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fulah (Latin, Cameroon)',
        'ff_Latn_GH' => 'Fulah (Latin, Ghana)',
        'ff_Latn_GM' => 'Fulah (Latin, Gambia)',
        'ff_Latn_GN' => 'Fulah (Latin, Guinea)',
        'ff_Latn_GW' => 'Fulah (Latin, Guinea Bissau)',
        'ff_Latn_LR' => 'Fulah (Latin, Liberia)',
        'ff_Latn_MR' => 'Fulah (Latin, Mauritania)',
        'ff_Latn_NE' => 'Fulah (Latin, Niger)',
        'ff_Latn_NG' => 'Fulah (Latin, Nigeria)',
        'ff_Latn_SL' => 'Fulah (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fulah (Latin, Senegal)',
        'ff_MR' => 'Fulah (Mauritania)',
        'ff_SN' => 'Fulah (Senegal)',
        'fi' => 'Finland',
        'fi_FI' => 'Finland (Finland)',
        'fo' => 'Faroe',
        'fo_DK' => 'Faroe (Denmark)',
        'fo_FO' => 'Faroe (Kepulauan Faroe)',
        'fr' => 'Perancis',
        'fr_BE' => 'Perancis (Belgium)',
        'fr_BF' => 'Perancis (Burkina Faso)',
        'fr_BI' => 'Perancis (Burundi)',
        'fr_BJ' => 'Perancis (Benin)',
        'fr_BL' => 'Perancis (St. Barthelemy)',
        'fr_CA' => 'Perancis (Kanada)',
        'fr_CD' => 'Perancis (Congo - Kinshasa)',
        'fr_CF' => 'Perancis (Republik Afrika Tengah)',
        'fr_CG' => 'Perancis (Congo - Brazzaville)',
        'fr_CH' => 'Perancis (Switzerland)',
        'fr_CI' => 'Perancis (Cote d’Ivoire)',
        'fr_CM' => 'Perancis (Cameroon)',
        'fr_DJ' => 'Perancis (Djibouti)',
        'fr_DZ' => 'Perancis (Algeria)',
        'fr_FR' => 'Perancis (Perancis)',
        'fr_GA' => 'Perancis (Gabon)',
        'fr_GF' => 'Perancis (Guiana Perancis)',
        'fr_GN' => 'Perancis (Guinea)',
        'fr_GP' => 'Perancis (Guadeloupe)',
        'fr_GQ' => 'Perancis (Guinea Khatulistiwa)',
        'fr_HT' => 'Perancis (Haiti)',
        'fr_KM' => 'Perancis (Comoros)',
        'fr_LU' => 'Perancis (Luxembourg)',
        'fr_MA' => 'Perancis (Maghribi)',
        'fr_MC' => 'Perancis (Monaco)',
        'fr_MF' => 'Perancis (Saint Martin)',
        'fr_MG' => 'Perancis (Madagaskar)',
        'fr_ML' => 'Perancis (Mali)',
        'fr_MQ' => 'Perancis (Martinique)',
        'fr_MR' => 'Perancis (Mauritania)',
        'fr_MU' => 'Perancis (Mauritius)',
        'fr_NC' => 'Perancis (New Caledonia)',
        'fr_NE' => 'Perancis (Niger)',
        'fr_PF' => 'Perancis (Polinesia Perancis)',
        'fr_PM' => 'Perancis (Saint Pierre dan Miquelon)',
        'fr_RE' => 'Perancis (Reunion)',
        'fr_RW' => 'Perancis (Rwanda)',
        'fr_SC' => 'Perancis (Seychelles)',
        'fr_SN' => 'Perancis (Senegal)',
        'fr_SY' => 'Perancis (Syria)',
        'fr_TD' => 'Perancis (Chad)',
        'fr_TG' => 'Perancis (Togo)',
        'fr_TN' => 'Perancis (Tunisia)',
        'fr_VU' => 'Perancis (Vanuatu)',
        'fr_WF' => 'Perancis (Wallis dan Futuna)',
        'fr_YT' => 'Perancis (Mayotte)',
        'fy' => 'Frisian Barat',
        'fy_NL' => 'Frisian Barat (Belanda)',
        'ga' => 'Ireland',
        'ga_GB' => 'Ireland (United Kingdom)',
        'ga_IE' => 'Ireland (Ireland)',
        'gd' => 'Scots Gaelic',
        'gd_GB' => 'Scots Gaelic (United Kingdom)',
        'gl' => 'Galicia',
        'gl_ES' => 'Galicia (Sepanyol)',
        'gu' => 'Gujerat',
        'gu_IN' => 'Gujerat (India)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Isle of Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Nigeria)',
        'he' => 'Ibrani',
        'he_IL' => 'Ibrani (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Latin)',
        'hi_Latn_IN' => 'Hindi (Latin, India)',
        'hr' => 'Croatia',
        'hr_BA' => 'Croatia (Bosnia dan Herzegovina)',
        'hr_HR' => 'Croatia (Croatia)',
        'hu' => 'Hungary',
        'hu_HU' => 'Hungary (Hungary)',
        'hy' => 'Armenia',
        'hy_AM' => 'Armenia (Armenia)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Dunia)',
        'id' => 'Indonesia',
        'id_ID' => 'Indonesia (Indonesia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigeria)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (China)',
        'is' => 'Iceland',
        'is_IS' => 'Iceland (Iceland)',
        'it' => 'Itali',
        'it_CH' => 'Itali (Switzerland)',
        'it_IT' => 'Itali (Itali)',
        'it_SM' => 'Itali (San Marino)',
        'it_VA' => 'Itali (Kota Vatican)',
        'ja' => 'Jepun',
        'ja_JP' => 'Jepun (Jepun)',
        'jv' => 'Jawa',
        'jv_ID' => 'Jawa (Indonesia)',
        'ka' => 'Georgia',
        'ka_GE' => 'Georgia (Georgia)',
        'ki' => 'Kikuya',
        'ki_KE' => 'Kikuya (Kenya)',
        'kk' => 'Kazakhstan',
        'kk_KZ' => 'Kazakhstan (Kazakhstan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Greenland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Kemboja)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (India)',
        'ko' => 'Korea',
        'ko_KP' => 'Korea (Korea Utara)',
        'ko_KR' => 'Korea (Korea Selatan)',
        'ks' => 'Kashmir',
        'ks_Arab' => 'Kashmir (Arab)',
        'ks_Arab_IN' => 'Kashmir (Arab, India)',
        'ks_Deva' => 'Kashmir (Devanagari)',
        'ks_Deva_IN' => 'Kashmir (Devanagari, India)',
        'ks_IN' => 'Kashmir (India)',
        'ku' => 'Kurdish',
        'ku_TR' => 'Kurdish (Turki)',
        'kw' => 'Cornish',
        'kw_GB' => 'Cornish (United Kingdom)',
        'ky' => 'Kirghiz',
        'ky_KG' => 'Kirghiz (Kyrgyzstan)',
        'lb' => 'Luxembourg',
        'lb_LU' => 'Luxembourg (Luxembourg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Congo - Kinshasa)',
        'ln_CF' => 'Lingala (Republik Afrika Tengah)',
        'ln_CG' => 'Lingala (Congo - Brazzaville)',
        'lo' => 'Laos',
        'lo_LA' => 'Laos (Laos)',
        'lt' => 'Lithuania',
        'lt_LT' => 'Lithuania (Lithuania)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Congo - Kinshasa)',
        'lv' => 'Latvia',
        'lv_LV' => 'Latvia (Latvia)',
        'mg' => 'Malagasy',
        'mg_MG' => 'Malagasy (Madagaskar)',
        'mi' => 'Maori',
        'mi_NZ' => 'Maori (New Zealand)',
        'mk' => 'Macedonia',
        'mk_MK' => 'Macedonia (Macedonia Utara)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mongolia',
        'mn_MN' => 'Mongolia (Mongolia)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (India)',
        'ms' => 'Melayu',
        'ms_BN' => 'Melayu (Brunei)',
        'ms_ID' => 'Melayu (Indonesia)',
        'ms_MY' => 'Melayu (Malaysia)',
        'ms_SG' => 'Melayu (Singapura)',
        'mt' => 'Malta',
        'mt_MT' => 'Malta (Malta)',
        'my' => 'Burma',
        'my_MM' => 'Burma (Myanmar [Burma])',
        'nb' => 'Bokmal Norway',
        'nb_NO' => 'Bokmal Norway (Norway)',
        'nb_SJ' => 'Bokmal Norway (Svalbard dan Jan Mayen)',
        'nd' => 'Ndebele Utara',
        'nd_ZW' => 'Ndebele Utara (Zimbabwe)',
        'ne' => 'Nepal',
        'ne_IN' => 'Nepal (India)',
        'ne_NP' => 'Nepal (Nepal)',
        'nl' => 'Belanda',
        'nl_AW' => 'Belanda (Aruba)',
        'nl_BE' => 'Belanda (Belgium)',
        'nl_BQ' => 'Belanda (Belanda Caribbean)',
        'nl_CW' => 'Belanda (Curacao)',
        'nl_NL' => 'Belanda (Belanda)',
        'nl_SR' => 'Belanda (Surinam)',
        'nl_SX' => 'Belanda (Sint Maarten)',
        'nn' => 'Nynorsk Norway',
        'nn_NO' => 'Nynorsk Norway (Norway)',
        'no' => 'Norway',
        'no_NO' => 'Norway (Norway)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Ethiopia)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Odia',
        'or_IN' => 'Odia (India)',
        'os' => 'Ossete',
        'os_GE' => 'Ossete (Georgia)',
        'os_RU' => 'Ossete (Rusia)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Arab)',
        'pa_Arab_PK' => 'Punjabi (Arab, Pakistan)',
        'pa_Guru' => 'Punjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Punjabi (Gurmukhi, India)',
        'pa_IN' => 'Punjabi (India)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Poland',
        'pl_PL' => 'Poland (Poland)',
        'ps' => 'Pashto',
        'ps_AF' => 'Pashto (Afghanistan)',
        'ps_PK' => 'Pashto (Pakistan)',
        'pt' => 'Portugis',
        'pt_AO' => 'Portugis (Angola)',
        'pt_BR' => 'Portugis (Brazil)',
        'pt_CH' => 'Portugis (Switzerland)',
        'pt_CV' => 'Portugis (Cape Verde)',
        'pt_GQ' => 'Portugis (Guinea Khatulistiwa)',
        'pt_GW' => 'Portugis (Guinea Bissau)',
        'pt_LU' => 'Portugis (Luxembourg)',
        'pt_MO' => 'Portugis (Macau SAR China)',
        'pt_MZ' => 'Portugis (Mozambique)',
        'pt_PT' => 'Portugis (Portugal)',
        'pt_ST' => 'Portugis (Sao Tome dan Principe)',
        'pt_TL' => 'Portugis (Timor-Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolivia)',
        'qu_EC' => 'Quechua (Ecuador)',
        'qu_PE' => 'Quechua (Peru)',
        'rm' => 'Romansh',
        'rm_CH' => 'Romansh (Switzerland)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Romania',
        'ro_MD' => 'Romania (Moldova)',
        'ro_RO' => 'Romania (Romania)',
        'ru' => 'Rusia',
        'ru_BY' => 'Rusia (Belarus)',
        'ru_KG' => 'Rusia (Kyrgyzstan)',
        'ru_KZ' => 'Rusia (Kazakhstan)',
        'ru_MD' => 'Rusia (Moldova)',
        'ru_RU' => 'Rusia (Rusia)',
        'ru_UA' => 'Rusia (Ukraine)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (India)',
        'sc' => 'Sardinia',
        'sc_IT' => 'Sardinia (Itali)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arab)',
        'sd_Arab_PK' => 'Sindhi (Arab, Pakistan)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
        'sd_IN' => 'Sindhi (India)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Sami Utara',
        'se_FI' => 'Sami Utara (Finland)',
        'se_NO' => 'Sami Utara (Norway)',
        'se_SE' => 'Sami Utara (Sweden)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Republik Afrika Tengah)',
        'sh' => 'SerboCroatia',
        'sh_BA' => 'SerboCroatia (Bosnia dan Herzegovina)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Slovak',
        'sk_SK' => 'Slovak (Slovakia)',
        'sl' => 'Slovenia',
        'sl_SI' => 'Slovenia (Slovenia)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somali',
        'so_DJ' => 'Somali (Djibouti)',
        'so_ET' => 'Somali (Ethiopia)',
        'so_KE' => 'Somali (Kenya)',
        'so_SO' => 'Somali (Somalia)',
        'sq' => 'Albania',
        'sq_AL' => 'Albania (Albania)',
        'sq_MK' => 'Albania (Macedonia Utara)',
        'sr' => 'Serbia',
        'sr_BA' => 'Serbia (Bosnia dan Herzegovina)',
        'sr_Cyrl' => 'Serbia (Cyril)',
        'sr_Cyrl_BA' => 'Serbia (Cyril, Bosnia dan Herzegovina)',
        'sr_Cyrl_ME' => 'Serbia (Cyril, Montenegro)',
        'sr_Cyrl_RS' => 'Serbia (Cyril, Serbia)',
        'sr_Latn' => 'Serbia (Latin)',
        'sr_Latn_BA' => 'Serbia (Latin, Bosnia dan Herzegovina)',
        'sr_Latn_ME' => 'Serbia (Latin, Montenegro)',
        'sr_Latn_RS' => 'Serbia (Latin, Serbia)',
        'sr_ME' => 'Serbia (Montenegro)',
        'sr_RS' => 'Serbia (Serbia)',
        'su' => 'Sunda',
        'su_ID' => 'Sunda (Indonesia)',
        'su_Latn' => 'Sunda (Latin)',
        'su_Latn_ID' => 'Sunda (Latin, Indonesia)',
        'sv' => 'Sweden',
        'sv_AX' => 'Sweden (Kepulauan Aland)',
        'sv_FI' => 'Sweden (Finland)',
        'sv_SE' => 'Sweden (Sweden)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Congo - Kinshasa)',
        'sw_KE' => 'Swahili (Kenya)',
        'sw_TZ' => 'Swahili (Tanzania)',
        'sw_UG' => 'Swahili (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (India)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Malaysia)',
        'ta_SG' => 'Tamil (Singapura)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tajik',
        'tg_TJ' => 'Tajik (Tajikistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Thailand)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Ethiopia)',
        'tk' => 'Turkmen',
        'tk_TM' => 'Turkmen (Turkmenistan)',
        'to' => 'Tonga',
        'to_TO' => 'Tonga (Tonga)',
        'tr' => 'Turki',
        'tr_CY' => 'Turki (Cyprus)',
        'tr_TR' => 'Turki (Turki)',
        'tt' => 'Tatar',
        'tt_RU' => 'Tatar (Rusia)',
        'ug' => 'Uyghur',
        'ug_CN' => 'Uyghur (China)',
        'uk' => 'Ukraine',
        'uk_UA' => 'Ukraine (Ukraine)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (India)',
        'ur_PK' => 'Urdu (Pakistan)',
        'uz' => 'Uzbekistan',
        'uz_AF' => 'Uzbekistan (Afghanistan)',
        'uz_Arab' => 'Uzbekistan (Arab)',
        'uz_Arab_AF' => 'Uzbekistan (Arab, Afghanistan)',
        'uz_Cyrl' => 'Uzbekistan (Cyril)',
        'uz_Cyrl_UZ' => 'Uzbekistan (Cyril, Uzbekistan)',
        'uz_Latn' => 'Uzbekistan (Latin)',
        'uz_Latn_UZ' => 'Uzbekistan (Latin, Uzbekistan)',
        'uz_UZ' => 'Uzbekistan (Uzbekistan)',
        'vi' => 'Vietnam',
        'vi_VN' => 'Vietnam (Vietnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Afrika Selatan)',
        'yi' => 'Yiddish',
        'yi_001' => 'Yiddish (Dunia)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benin)',
        'yo_NG' => 'Yoruba (Nigeria)',
        'zh' => 'Cina',
        'zh_CN' => 'Cina (China)',
        'zh_HK' => 'Cina (Hong Kong SAR China)',
        'zh_Hans' => 'Cina (Ringkas)',
        'zh_Hans_CN' => 'Cina (Ringkas, China)',
        'zh_Hans_HK' => 'Cina (Ringkas, Hong Kong SAR China)',
        'zh_Hans_MO' => 'Cina (Ringkas, Macau SAR China)',
        'zh_Hans_SG' => 'Cina (Ringkas, Singapura)',
        'zh_Hant' => 'Cina (Tradisional)',
        'zh_Hant_HK' => 'Cina (Tradisional, Hong Kong SAR China)',
        'zh_Hant_MO' => 'Cina (Tradisional, Macau SAR China)',
        'zh_Hant_TW' => 'Cina (Tradisional, Taiwan)',
        'zh_MO' => 'Cina (Macau SAR China)',
        'zh_SG' => 'Cina (Singapura)',
        'zh_TW' => 'Cina (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Afrika Selatan)',
    ],
];
