<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'ანდორული პესეტა',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'არაბთა გაერთიანებული საამიროების დირჰამი',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'ავღანი (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'ავღანური ავღანი',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'ალბანური ლეკი',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'სომხური დრამი',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'ნიდერლანდების ანტილების გულდენი',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'ანგოლური კვანზა',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'ანგოლური კვანზა (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'ანგოლური ახალი კვანზა (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'ანგოლური მიტოლებული კვანზა (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'არგენტინული აუსტრალი',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'არგენტინული პესო (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'არგენტინული პესო',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'ავსტრიული შილინგი',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'ავსტრალიური დოლარი',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'არუბანული გულდენი',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'აზერბაიჯანული მანათი (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'აზერბაიჯანული მანათი',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'ბოსნია-ჰერცოგოვინას დინარი',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'ბოსნია და ჰერცოგოვინას კონვერტირებადი მარკა',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'ბარბადოსული დოლარი',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'ბანგლადეშური ტაკა',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'ბელგიური ფრანკი (კოვერტირებადი)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'ბელგიური ფრანკი',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'ბელგიური ფრანკი (ფინანსური)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'ბულგარული მყარი ლევი',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'ბულგარული ლევი',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'ბაჰრეინული დინარი',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'ბურუნდიული ფრანკი',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'ბერმუდული დოლარი',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'ბრუნეული დოლარი',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'ბოლივიური ბოლივიანო',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'ბოლივიური პესო',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'ბრაზილიური კრუზეირო ნოვო (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'ბრაზილიური კრუზადო',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'ბრაზილიური კრუზეირო (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'ბრაზილიური რეალი',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'ბრაზილიური კრუზადო ნოვო',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'ბრაზილიური კრუზეირო',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'ბაჰამური დოლარი',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ბუტანური ნგულტრუმი',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'ბოცვანური პულა',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'ახალი ბელარუსიული რუბლი (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'ბელორუსული რუბლი',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'ბელორუსული რუბლი (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'ბელიზის დოლარი',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'კანადური დოლარი',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'კონგოს ფრანკი',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'შვეიცარიული ფრანკი',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'ჩილეს პესო',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'ჩინური იუანი (ოფშორი)',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'ჩინური იუანი',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'კოლუმბიური პესო',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'კოსტა-რიკული კოლონი',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'ძველი სერბიული დინარი',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'ჩეხოსლოვაკიის მყარი კრონა',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'კუბური კონვერტირებადი პესო',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'კუბური პესო',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'კაბო-ვერდეს ესკუდო',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'კვიპროსის გირვანქა',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'ჩეხური კრონა',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'აღმოსავლეთ გერმანული მარკა',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'გერმანული მარკა',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'ჯიბუტის ფრანკი',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'დანიური კრონა',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'დომინიკური პესო',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'ალჟირული დინარი',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'ესტონური კრუნა',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'ეგვიპტური გირვანქა',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'ერიტრეის ნაკფა',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'ესპანური პესეტა',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'ეთიოპიური ბირი',
        ],
        'EUR' => [
            0 => '€',
            1 => 'ევრო',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'ფინური მარკა',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'ფიჯის დოლარი',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'ფოლკლენდის კუნძულების ფუნტი',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'ფრანგული ფრანკი',
        ],
        'GBP' => [
            0 => '£',
            1 => 'ბრიტანული გირვანქა სტერლინგი',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'ქართული კუპონი ლარით',
        ],
        'GEL' => [
            0 => '₾',
            1 => 'ქართული ლარი',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'განური სედი',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'გიბრალტარული ფუნტი',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'გამბიური დალასი',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'გვინეური ფრანკი',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'ბერძნული დრაჰმა',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'გვატემალური კეტსალი',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'პორტუგალიური გინეა ესკუდო',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'გაიანური დოლარი',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'ჰონკონგის დოლარი',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'ჰონდურასული ლემპირა',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'ხორვატიული დინარი',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'ხორვატული კუნა',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'ჰაიტური გურდი',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'უნგრული ფორინტი',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'ინდონეზიური რუპია',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'ირლანდიური გირვანქა',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'ისრაელის ახალი შეკელი',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'ინდური რუპია',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'ერაყული დინარი',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'ირანული რიალი',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'ისლანდიური კრონა',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'იტალიური ლირა',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'იამაიკური დოლარი',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'იორდანიული დოლარი',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'იაპონური იენი',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'კენიური შილინგი',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'ყირგიზული სომი',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'კამბოჯური რიელი',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'კომორული ფრანკი',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'ჩრდილოეთ კორეული ვონი',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'სამხრეთ კორეული ვონი',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'ქუვეითური დინარი',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'კაიმანის კუნძულების დოლარი',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'ყაზახური ტენგე',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'ლაოსური კიპი',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'ლიბანური ფუნტი',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'შრი-ლანკური რუპია',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'ლიბერიული დოლარი',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'ლესოთოს ლოტი',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'ლიტვური ლიტა',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'ლიტვური ტალონი',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'ლუქსემბურგის კონვერტირებადი ფრანკი',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'ლუქსემბურგის ფრანკი',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'ლუქსემბურგის ფინანსური ფრანკი',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'ლატვიური ლატი',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'ლატვიური რუბლი',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'ლიბიური დინარი',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'მაროკოს დირჰამი',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'მაროკოს ფრანკი',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'მოლდოვური ლეუ',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'მადაგასკარის არიარი',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'მადაგასკარის ფრანკი',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'მაკედონიური დინარი',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'მალის ფრანკი',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'მიანმარის კიატი',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'მონღოლური ტუგრიკი',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'მაკაუს პატაკა',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'მავრიტანული უგია (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'მავრიტანული უგია',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'მალტის ლირა',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'მალტის გირვანქა',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'მავრიტანული რუპია',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'მალდივური რუფია',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'მალავიური კვაჩა',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'მექსიკური პესო',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'მექსიკური ვერცხლის პესო (1861–1992)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'მალაიზიური რინგიტი',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'მოზამბიკური ესკუდო',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'ძველი მოზამბიკური მეტიკალი',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'მოზამბიკური მეტიკალი',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'ნამიბიური დოლარი',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'ნიგერიული ნაირა',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'ნიკარაგუას კორდობა',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'ნიკარაგუას ოქროს კორდობა',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'ჰოლანდიური გულდენი',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'ნორვეგიული კრონა',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'ნეპალური რუპია',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'ახალი ზელანდიის დოლარი',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'ომანის რიალი',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'პანამური ბალბოა',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'პერუს ინტი',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'პერუს სოლი',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'პერუს სოლი (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'პაპუა-ახალი გვინეის კინა',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'ფილიპინური პესო',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'პაკისტანური რუპია',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'პოლონური ზლოტი',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'პოლონური ზლოტი (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'პორტუგალიური ესკუდო',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'პარაგვაული გუარანი',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'კატარის რიალი',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'როდეზიული დოლარი',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'ძველი რუმინული ლეუ',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'რუმინული ლეუ',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'სერბული დინარი',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'რუსული რუბლი',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'რუსული რუბლი (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'რუანდული ფრანკი',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'საუდის არაბეთის რიალი',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'სოლომონის კუნძულების დოლარი',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'სეიშელური რუპია',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'სუდანის დინარი',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'სუდანური ფუნტი',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'სუდანის გირვანქა',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'შვედური კრონა',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'სინგაპურის დოლარი',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'წმ. ელენეს კუნძულის ფუნტი',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'სიერა-ლეონეს ლეონე',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'სომალური შილინგი',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'სურინამული დოლარი',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'სურინამის გულდენი',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'სამხრეთ სუდანური ფუნტი',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'სან-ტომე და პრინსიპის დობრა (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'სან-ტომე და პრინსიპის დობრა',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'საბჭოთა რუბლი',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'სირიული ფუნტი',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'სვაზილენდის ლილანგენი',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'ტაილანდური ბატი',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'ტაჯიკური რუბლი',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'ტაჯიკური სომონი',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'თურქმენული მანათი',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'თურქმენეთის მანათი',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'ტუნისური დინარი',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'ტონგანური პაანგა',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'თურქული ლირა',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'ახალი თურქული ლირა',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'ტრინიდად და ტობაგოს დოლარი',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'ტაივანური ახალი დოლარი',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'ტანზანიური შილინგი',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'უკრაინული გრივნა',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'უკრაინული კარბოვანეცი',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'უგანდური შილინგი (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'უგანდური შილინგი',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'აშშ დოლარი',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'აშშ დოლარი (შემდეგი დღე)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'აშშ დოლარი (იგივე დღე)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'ურუგვაის პესო (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'ურუგვაის პესო',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'უზბეკური სუმი',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'ვენესუელის ბოლივარი (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'ვენესუელის ბოლივარი (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'ვენესუელის ბოლივარი',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'ვიეტნამური დონგი',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'ვანუატუს ვატუ',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'სამოური ტალა',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'ცენტრალურ აფრიკული CFA ფრანკი',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'აღმოსავლეთ კარიბიული დოლარი',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'ევროპული სავალუტო ერთეული',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'ფრანგული ოქროს ფრანკი',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'დასავლეთ აფრიკული CFA ფრანკი',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP ფრანკი',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'იემენის დინარი',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'იემენის რეალი',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'იუგოსლავიური მყარი დინარი',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'იუგოსლავიური ახალი დინარი',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'იუგოსლავიური კონვერტირებადი დინარი',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'სამხრეთ აფრიკული რანდი',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'ზამბიური კვაჭა (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'ზამბიური კვაჭა',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'ზაირის ახალი ზაირი',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'ზაირის ზაირი',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'ზიმბაბვეს დოლარი',
        ],
    ],
];
