<?php

return [
    'Names' => [
        'Deva' => 'devanagari',
        'Gujr' => 'gujarati',
        'Hanb' => 'hanb',
        'Hans' => 'idéogrammes han simplifiés',
        'Hant' => 'idéogrammes han traditionnels',
        'Hrkt' => 'syllabaires japonais',
        'Olck' => 'ol chiki',
        'Zsye' => 'émoji',
    ],
];
