<?php

return [
    'Names' => [
        'AM' => 'Arménia',
        'AX' => 'Alanda',
        'BD' => 'Bangladeche',
        'BH' => 'Barém',
        'BJ' => 'Benim',
        'BS' => 'Baamas',
        'CC' => 'Ilhas dos Cocos (Keeling)',
        'CD' => 'Congo-Kinshasa',
        'CG' => 'Congo-Brazzaville',
        'CI' => 'Côte d’Ivoire (Costa do Marfim)',
        'CW' => 'Curaçau',
        'CX' => 'Ilha do Natal',
        'CZ' => 'Chéquia',
        'DJ' => 'Jibuti',
        'DM' => 'Domínica',
        'EE' => 'Estónia',
        'EH' => 'Sara Ocidental',
        'FK' => 'Ilhas Falkland',
        'GG' => 'Guernesey',
        'GL' => 'Gronelândia',
        'GU' => 'Guame',
        'IR' => 'Irão',
        'KE' => 'Quénia',
        'KI' => 'Quiribáti',
        'KN' => 'São Cristóvão e Neves',
        'KW' => 'Koweit',
        'KY' => 'Ilhas Caimão',
        'LI' => 'Listenstaine',
        'LK' => 'Sri Lanca',
        'LV' => 'Letónia',
        'MC' => 'Mónaco',
        'MF' => 'São Martinho (Saint-Martin)',
        'MG' => 'Madagáscar',
        'MK' => 'Macedónia do Norte',
        'MS' => 'Monserrate',
        'MU' => 'Maurícia',
        'MW' => 'Maláui',
        'NC' => 'Nova Caledónia',
        'NU' => 'Niuê',
        'PL' => 'Polónia',
        'PS' => 'Territórios palestinianos',
        'RO' => 'Roménia',
        'SI' => 'Eslovénia',
        'SM' => 'São Marinho',
        'SV' => 'Salvador',
        'SX' => 'São Martinho (Sint Maarten)',
        'TF' => 'Territórios Austrais Franceses',
        'TJ' => 'Tajiquistão',
        'TK' => 'Toquelau',
        'TM' => 'Turquemenistão',
        'TT' => 'Trindade e Tobago',
        'UM' => 'Ilhas Menores Afastadas dos EUA',
        'UZ' => 'Usbequistão',
        'VI' => 'Ilhas Virgens dos EUA',
        'VN' => 'Vietname',
        'YE' => 'Iémen',
        'YT' => 'Maiote',
        'ZW' => 'Zimbabué',
    ],
];
