<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ગ્રીનવિચ મધ્યમ સમય (આબિદ્જાન)',
        'Africa/Accra' => 'ગ્રીનવિચ મધ્યમ સમય (ઍકરા)',
        'Africa/Addis_Ababa' => 'પૂર્વ આફ્રિકા સમય (એડિસ અબાબા)',
        'Africa/Algiers' => 'મધ્ય યુરોપિયન સમય (અલ્જીયર્સ)',
        'Africa/Asmera' => 'પૂર્વ આફ્રિકા સમય (અસ્મારા)',
        'Africa/Bamako' => 'ગ્રીનવિચ મધ્યમ સમય (બમેકો)',
        'Africa/Bangui' => 'પશ્ચિમ આફ્રિકા સમય (બાંગુઈ)',
        'Africa/Banjul' => 'ગ્રીનવિચ મધ્યમ સમય (બાંજુલ)',
        'Africa/Bissau' => 'ગ્રીનવિચ મધ્યમ સમય (બિસાઉ)',
        'Africa/Blantyre' => 'મધ્ય આફ્રિકા સમય (બ્લેંટીર)',
        'Africa/Brazzaville' => 'પશ્ચિમ આફ્રિકા સમય (બ્રાઝાવિલે)',
        'Africa/Bujumbura' => 'મધ્ય આફ્રિકા સમય (બુજમ્બુરા)',
        'Africa/Cairo' => 'પૂર્વી યુરોપિયન સમય (કૈરો)',
        'Africa/Casablanca' => 'પશ્ચિમી યુરોપિયન સમય (કાસાબ્લાંકા)',
        'Africa/Ceuta' => 'મધ્ય યુરોપિયન સમય (ક્વેટા)',
        'Africa/Conakry' => 'ગ્રીનવિચ મધ્યમ સમય (કોનૅક્રી)',
        'Africa/Dakar' => 'ગ્રીનવિચ મધ્યમ સમય (ડકાર)',
        'Africa/Dar_es_Salaam' => 'પૂર્વ આફ્રિકા સમય (દાર એસ સલામ)',
        'Africa/Djibouti' => 'પૂર્વ આફ્રિકા સમય (જીબુટી)',
        'Africa/Douala' => 'પશ્ચિમ આફ્રિકા સમય (ડૌઆલા)',
        'Africa/El_Aaiun' => 'પશ્ચિમી યુરોપિયન સમય (એલ ઐઉન)',
        'Africa/Freetown' => 'ગ્રીનવિચ મધ્યમ સમય (ફ્રીટાઉન)',
        'Africa/Gaborone' => 'મધ્ય આફ્રિકા સમય (ગૅબોરોન)',
        'Africa/Harare' => 'મધ્ય આફ્રિકા સમય (હરારે)',
        'Africa/Johannesburg' => 'દક્ષિણ આફ્રિકા માનક સમય (જોહાન્સબર્ગ)',
        'Africa/Juba' => 'મધ્ય આફ્રિકા સમય (જુબા)',
        'Africa/Kampala' => 'પૂર્વ આફ્રિકા સમય (કમ્પાલા)',
        'Africa/Khartoum' => 'મધ્ય આફ્રિકા સમય (ખાર્ટૂમ)',
        'Africa/Kigali' => 'મધ્ય આફ્રિકા સમય (કિગાલી)',
        'Africa/Kinshasa' => 'પશ્ચિમ આફ્રિકા સમય (કિંશાસા)',
        'Africa/Lagos' => 'પશ્ચિમ આફ્રિકા સમય (લાગોસ)',
        'Africa/Libreville' => 'પશ્ચિમ આફ્રિકા સમય (લિબ્રેવિલે)',
        'Africa/Lome' => 'ગ્રીનવિચ મધ્યમ સમય (લોમ)',
        'Africa/Luanda' => 'પશ્ચિમ આફ્રિકા સમય (લ્યુએન્ડા)',
        'Africa/Lubumbashi' => 'મધ્ય આફ્રિકા સમય (લુબુમ્બાશી)',
        'Africa/Lusaka' => 'મધ્ય આફ્રિકા સમય (લુસાકા)',
        'Africa/Malabo' => 'પશ્ચિમ આફ્રિકા સમય (મલાબો)',
        'Africa/Maputo' => 'મધ્ય આફ્રિકા સમય (માપુટો)',
        'Africa/Maseru' => 'દક્ષિણ આફ્રિકા માનક સમય (મસેરુ)',
        'Africa/Mbabane' => 'દક્ષિણ આફ્રિકા માનક સમય (અમ્બબાન)',
        'Africa/Mogadishu' => 'પૂર્વ આફ્રિકા સમય (મોગાડીશુ)',
        'Africa/Monrovia' => 'ગ્રીનવિચ મધ્યમ સમય (મોંરોવિયા)',
        'Africa/Nairobi' => 'પૂર્વ આફ્રિકા સમય (નૈરોબી)',
        'Africa/Ndjamena' => 'પશ્ચિમ આફ્રિકા સમય (અન્જમેન)',
        'Africa/Niamey' => 'પશ્ચિમ આફ્રિકા સમય (નિયામી)',
        'Africa/Nouakchott' => 'ગ્રીનવિચ મધ્યમ સમય (નૌકચોટ)',
        'Africa/Ouagadougou' => 'ગ્રીનવિચ મધ્યમ સમય (ઔઆગાદૌગૌ)',
        'Africa/Porto-Novo' => 'પશ્ચિમ આફ્રિકા સમય (પોર્ટો-નોવો)',
        'Africa/Sao_Tome' => 'ગ્રીનવિચ મધ્યમ સમય (સાઓ ટૉમ)',
        'Africa/Tripoli' => 'પૂર્વી યુરોપિયન સમય (ટ્રીપોલી)',
        'Africa/Tunis' => 'મધ્ય યુરોપિયન સમય (ટ્યુનિસ)',
        'Africa/Windhoek' => 'મધ્ય આફ્રિકા સમય (વિંડહૉક)',
        'America/Adak' => 'હવાઈ-એલ્યુશિઅન સમય (અદક)',
        'America/Anchorage' => 'અલાસ્કા સમય (એન્કોરેજ)',
        'America/Anguilla' => 'એટલાન્ટિક સમય (ઍંગ્વિલા)',
        'America/Antigua' => 'એટલાન્ટિક સમય (ઍન્ટિગુઆ)',
        'America/Araguaina' => 'બ્રાઝિલિયા સમય (અરાગુઇના)',
        'America/Argentina/La_Rioja' => 'આર્જેન્ટીના સમય (લા રિઓહા)',
        'America/Argentina/Rio_Gallegos' => 'આર્જેન્ટીના સમય (રિઓ ગેલેગોસ)',
        'America/Argentina/Salta' => 'આર્જેન્ટીના સમય (સાલ્ટા)',
        'America/Argentina/San_Juan' => 'આર્જેન્ટીના સમય (સેન જુએન)',
        'America/Argentina/San_Luis' => 'આર્જેન્ટીના સમય (સેન લુઇસ)',
        'America/Argentina/Tucuman' => 'આર્જેન્ટીના સમય (તુકુમાન)',
        'America/Argentina/Ushuaia' => 'આર્જેન્ટીના સમય (ઉશાયા)',
        'America/Aruba' => 'એટલાન્ટિક સમય (અરુબા)',
        'America/Asuncion' => 'પેરાગ્વે સમય (એસન્શિયન)',
        'America/Bahia' => 'બ્રાઝિલિયા સમય (બાહિયા)',
        'America/Bahia_Banderas' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (બહિયા બાંદ્રાસ)',
        'America/Barbados' => 'એટલાન્ટિક સમય (બારબાડોસ)',
        'America/Belem' => 'બ્રાઝિલિયા સમય (બેલેમ)',
        'America/Belize' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (બેલીઝ)',
        'America/Blanc-Sablon' => 'એટલાન્ટિક સમય (બ્લાંક-સેબલોન)',
        'America/Boa_Vista' => 'એમેઝોન સમય (બોઆ વિસ્ટા)',
        'America/Bogota' => 'કોલમ્બિયા સમય (બોગોટા)',
        'America/Boise' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (બોઇઝ)',
        'America/Buenos_Aires' => 'આર્જેન્ટીના સમય (બ્યુનસ એયર્સ)',
        'America/Cambridge_Bay' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (કેમ્બ્રિજ બે)',
        'America/Campo_Grande' => 'એમેઝોન સમય (કામ્પો ગ્રાંડ)',
        'America/Cancun' => 'ઉત્તર અમેરિકન પૂર્વી સમય (કાન્કુન)',
        'America/Caracas' => 'વેનેઝુએલા સમય (કૅરાકસ)',
        'America/Catamarca' => 'આર્જેન્ટીના સમય (કાતામાર્કા)',
        'America/Cayenne' => 'ફ્રેંચ ગયાના સમય (કાયેને)',
        'America/Cayman' => 'ઉત્તર અમેરિકન પૂર્વી સમય (કેમેન)',
        'America/Chicago' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (શિકાગો)',
        'America/Chihuahua' => 'મેક્સિકન પેસિફિક સમય (ચિહુઆહુઆ)',
        'America/Coral_Harbour' => 'ઉત્તર અમેરિકન પૂર્વી સમય (એટિકોકેન)',
        'America/Cordoba' => 'આર્જેન્ટીના સમય (કોર્ડોબા)',
        'America/Costa_Rica' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (કોસ્ટા રિકા)',
        'America/Creston' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ક્રેસ્ટન)',
        'America/Cuiaba' => 'એમેઝોન સમય (ક્યુએબા)',
        'America/Curacao' => 'એટલાન્ટિક સમય (કુરાકાઓ)',
        'America/Danmarkshavn' => 'ગ્રીનવિચ મધ્યમ સમય (ડેનમાર્કશૉન)',
        'America/Dawson' => 'યુકોન સમય (ડૌસન)',
        'America/Dawson_Creek' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ડૌસન ક્રિક)',
        'America/Denver' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (દેન્વર)',
        'America/Detroit' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ડેટ્રોઇટ)',
        'America/Dominica' => 'એટલાન્ટિક સમય (ડોમિનિકા)',
        'America/Edmonton' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (એડમેન્ટન)',
        'America/Eirunepe' => 'એકર સમય (ઇરુનેપ)',
        'America/El_Salvador' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (એલ સેલ્વાડોર)',
        'America/Fort_Nelson' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ફોર્ટ નેલ્સન)',
        'America/Fortaleza' => 'બ્રાઝિલિયા સમય (ફોર્ટાલેઝા)',
        'America/Glace_Bay' => 'એટલાન્ટિક સમય (ગ્લેસ બે)',
        'America/Godthab' => 'પશ્ચિમ ગ્રીનલેન્ડ સમય (નૂક)',
        'America/Goose_Bay' => 'એટલાન્ટિક સમય (ગૂસ બે)',
        'America/Grand_Turk' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ગ્રાન્ડ ટર્ક)',
        'America/Grenada' => 'એટલાન્ટિક સમય (ગ્રેનેડા)',
        'America/Guadeloupe' => 'એટલાન્ટિક સમય (ગ્વાડેલોપ)',
        'America/Guatemala' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (ગ્વાટેમાલા)',
        'America/Guayaquil' => 'એક્વાડોર સમય (ગુયાક્વિલ)',
        'America/Guyana' => 'ગયાના સમય',
        'America/Halifax' => 'એટલાન્ટિક સમય (હેલિફેક્સ)',
        'America/Havana' => 'ક્યુબા સમય (હવાના)',
        'America/Hermosillo' => 'મેક્સિકન પેસિફિક સમય (એરમોસિયો)',
        'America/Indiana/Knox' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (નોક્સ, ઇન્ડિયાના)',
        'America/Indiana/Marengo' => 'ઉત્તર અમેરિકન પૂર્વી સમય (મેરેંગો, ઇન્ડિયાના)',
        'America/Indiana/Petersburg' => 'ઉત્તર અમેરિકન પૂર્વી સમય (પિટર્સબર્ગ, ઇન્ડિયાના)',
        'America/Indiana/Tell_City' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (ટેલ સિટી, ઇન્ડિયાના)',
        'America/Indiana/Vevay' => 'ઉત્તર અમેરિકન પૂર્વી સમય (વેવૈ, ઇન્ડિયાના)',
        'America/Indiana/Vincennes' => 'ઉત્તર અમેરિકન પૂર્વી સમય (વિન્સેન્સ, ઇન્ડિયાના)',
        'America/Indiana/Winamac' => 'ઉત્તર અમેરિકન પૂર્વી સમય (વિનામેક, ઇન્ડિયાના)',
        'America/Indianapolis' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ઇન્ડિયાનાપોલિસ)',
        'America/Inuvik' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ઇનુવિક)',
        'America/Iqaluit' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ઇકાલુઇત)',
        'America/Jamaica' => 'ઉત્તર અમેરિકન પૂર્વી સમય (જમૈકા)',
        'America/Jujuy' => 'આર્જેન્ટીના સમય (હુહુઇ)',
        'America/Juneau' => 'અલાસ્કા સમય (જુનેઇ)',
        'America/Kentucky/Monticello' => 'ઉત્તર અમેરિકન પૂર્વી સમય (મોન્ટીસેલો, કેન્ટુકી)',
        'America/Kralendijk' => 'એટલાન્ટિક સમય (ક્રાલેન્ડિક)',
        'America/La_Paz' => 'બોલિવિયા સમય (લા પેઝ)',
        'America/Lima' => 'પેરુ સમય (લિમા)',
        'America/Los_Angeles' => 'ઉત્તર અમેરિકન પેસિફિક સમય (લોસ એંજેલેસ)',
        'America/Louisville' => 'ઉત્તર અમેરિકન પૂર્વી સમય (લૂઇવિલ)',
        'America/Lower_Princes' => 'એટલાન્ટિક સમય (લોઅર પ્રિન્સનું ક્વાર્ટર)',
        'America/Maceio' => 'બ્રાઝિલિયા સમય (મેસિઓ)',
        'America/Managua' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (માનાગુઆ)',
        'America/Manaus' => 'એમેઝોન સમય (મનૌસ)',
        'America/Marigot' => 'એટલાન્ટિક સમય (મેરીગોટ)',
        'America/Martinique' => 'એટલાન્ટિક સમય (માર્ટીનીક)',
        'America/Matamoros' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (માતામોરોસ)',
        'America/Mazatlan' => 'મેક્સિકન પેસિફિક સમય (મઝત્લાન)',
        'America/Mendoza' => 'આર્જેન્ટીના સમય (મેન્ડોઝા)',
        'America/Menominee' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (મેનોમિની)',
        'America/Merida' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (મેરિદા)',
        'America/Metlakatla' => 'અલાસ્કા સમય (મેટ્લાકાટ્લા)',
        'America/Mexico_City' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (મેક્સિકો સિટી)',
        'America/Miquelon' => 'સેંટ પીએરી અને મિક્યુલોન સમય',
        'America/Moncton' => 'એટલાન્ટિક સમય (મોન્કટન)',
        'America/Monterrey' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (મોન્તોરે)',
        'America/Montevideo' => 'ઉરુગ્વે સમય (મૉંટેવિડિઓ)',
        'America/Montreal' => 'કેનેડા સમય (Montreal)',
        'America/Montserrat' => 'એટલાન્ટિક સમય (મોંટસેરાત)',
        'America/Nassau' => 'ઉત્તર અમેરિકન પૂર્વી સમય (નાસાઉ)',
        'America/New_York' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ન્યૂયોર્ક)',
        'America/Nipigon' => 'ઉત્તર અમેરિકન પૂર્વી સમય (નિપિગોન)',
        'America/Nome' => 'અલાસ્કા સમય (નોમ)',
        'America/Noronha' => 'ફર્નાન્ડો ડી નોરોન્હા સમય',
        'America/North_Dakota/Beulah' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (બિયુલાહ, ઉત્તર ડેકોટા)',
        'America/North_Dakota/Center' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (સેન્ટર, ઉત્તર ડેકોટા)',
        'America/North_Dakota/New_Salem' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (ન્યુ સેલમ, ઉત્તર ડેકોટા)',
        'America/Ojinaga' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ઓજિનાગા)',
        'America/Panama' => 'ઉત્તર અમેરિકન પૂર્વી સમય (પનામા)',
        'America/Pangnirtung' => 'ઉત્તર અમેરિકન પૂર્વી સમય (પેંગનિરતુંગ)',
        'America/Paramaribo' => 'સુરીનામ સમય (પેરામેરિબો)',
        'America/Phoenix' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (ફોનિક્સ)',
        'America/Port-au-Prince' => 'ઉત્તર અમેરિકન પૂર્વી સમય (પોર્ટ-ઓ-પ્રિન્સ)',
        'America/Port_of_Spain' => 'એટલાન્ટિક સમય (પોર્ટ ઑફ સ્પેન)',
        'America/Porto_Velho' => 'એમેઝોન સમય (પોર્ટો વેલ્હો)',
        'America/Puerto_Rico' => 'એટલાન્ટિક સમય (પ્યુઅર્ટો રિકો)',
        'America/Punta_Arenas' => 'ચિલી સમય (પુન્ટા એરીનાઝ)',
        'America/Rainy_River' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (રેઇની નદી)',
        'America/Rankin_Inlet' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (રેંકિન ઇન્લેટ)',
        'America/Recife' => 'બ્રાઝિલિયા સમય (રેસીફ)',
        'America/Regina' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (રેજીના)',
        'America/Resolute' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (રેઝોલૂટ)',
        'America/Rio_Branco' => 'એકર સમય (રિયો બ્રાંકો)',
        'America/Santa_Isabel' => 'ઉત્તરપશ્ચિમ મેક્સિકો સમય (સાંતા ઇસાબેલ)',
        'America/Santarem' => 'બ્રાઝિલિયા સમય (સેન્તારેમ)',
        'America/Santiago' => 'ચિલી સમય (સાંટિયાગો)',
        'America/Santo_Domingo' => 'એટલાન્ટિક સમય (સેંટો ડોમિંગો)',
        'America/Sao_Paulo' => 'બ્રાઝિલિયા સમય (સાઓ પાઉલો)',
        'America/Scoresbysund' => 'પૂર્વ ગ્રીનલેન્ડ સમય (ઇતોકોર્ટોરોમિટ)',
        'America/Sitka' => 'અલાસ્કા સમય (સિટ્કા)',
        'America/St_Barthelemy' => 'એટલાન્ટિક સમય (સેંટ બાર્થેલેમી)',
        'America/St_Johns' => 'ન્યૂફાઉન્ડલેન્ડ સમય (સેંટ જ્હોન્સ)',
        'America/St_Kitts' => 'એટલાન્ટિક સમય (સેંટ કીટ્સ)',
        'America/St_Lucia' => 'એટલાન્ટિક સમય (સેંટ લુસિયા)',
        'America/St_Thomas' => 'એટલાન્ટિક સમય (સેંટ થોમસ)',
        'America/St_Vincent' => 'એટલાન્ટિક સમય (સેંટ વિન્સેન્ટ)',
        'America/Swift_Current' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (સ્વિફ્ટ કરંટ)',
        'America/Tegucigalpa' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (તેગુસિગલ્પા)',
        'America/Thule' => 'એટલાન્ટિક સમય (થુલે)',
        'America/Thunder_Bay' => 'ઉત્તર અમેરિકન પૂર્વી સમય (થંડર બે)',
        'America/Tijuana' => 'ઉત્તર અમેરિકન પેસિફિક સમય (તિજુઆના)',
        'America/Toronto' => 'ઉત્તર અમેરિકન પૂર્વી સમય (ટોરન્ટો)',
        'America/Tortola' => 'એટલાન્ટિક સમય (ટોર્ટોલા)',
        'America/Vancouver' => 'ઉત્તર અમેરિકન પેસિફિક સમય (વેન્કુવર)',
        'America/Whitehorse' => 'યુકોન સમય (વ્હાઇટહોર્સ)',
        'America/Winnipeg' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય (વિન્નિપેગ)',
        'America/Yakutat' => 'અલાસ્કા સમય (યકુતત)',
        'America/Yellowknife' => 'ઉત્તર અમેરિકન માઉન્ટન સમય (યેલોનાઇફ)',
        'Antarctica/Casey' => 'એન્ટાર્કટિકા સમય (કૅસી)',
        'Antarctica/Davis' => 'ડેવિસ સમય',
        'Antarctica/DumontDUrville' => 'ડ્યુમોન્ટ-ડી‘ઉર્વિલ સમય (દુમોન્ત દી‘ઉર્વિલ)',
        'Antarctica/Macquarie' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (મેક્વેરી)',
        'Antarctica/Mawson' => 'મોસન સમય',
        'Antarctica/McMurdo' => 'ન્યુઝીલેન્ડ સમય (મૅકમર્ડો)',
        'Antarctica/Palmer' => 'ચિલી સમય (પાલ્મર)',
        'Antarctica/Rothera' => 'રોથેરા સમય',
        'Antarctica/Syowa' => 'સ્યોવા સમય',
        'Antarctica/Troll' => 'ગ્રીનવિચ મધ્યમ સમય (ટ્રોલ)',
        'Antarctica/Vostok' => 'વોસ્ટોક સમય (વોસ્ટૉક)',
        'Arctic/Longyearbyen' => 'મધ્ય યુરોપિયન સમય (લોંગઇયરબિયેન)',
        'Asia/Aden' => 'અરેબિયન સમય (એદેન)',
        'Asia/Almaty' => 'પૂર્વ કઝાકિસ્તાન સમય (અલ્માટી)',
        'Asia/Amman' => 'પૂર્વી યુરોપિયન સમય (અમ્માન)',
        'Asia/Anadyr' => 'અનાદિર સમય (અનદિર)',
        'Asia/Aqtau' => 'પશ્ચિમ કઝાકિસ્તાન સમય (અકટાઉ)',
        'Asia/Aqtobe' => 'પશ્ચિમ કઝાકિસ્તાન સમય (ઍક્ટોબ)',
        'Asia/Ashgabat' => 'તુર્કમેનિસ્તાન સમય (અશગાબટ)',
        'Asia/Atyrau' => 'પશ્ચિમ કઝાકિસ્તાન સમય (અત્યારુ)',
        'Asia/Baghdad' => 'અરેબિયન સમય (બગદાદ)',
        'Asia/Bahrain' => 'અરેબિયન સમય (બેહરીન)',
        'Asia/Baku' => 'અઝરબૈજાન સમય (બાકુ)',
        'Asia/Bangkok' => 'ઇન્ડોચાઇના સમય (બેંગકોક)',
        'Asia/Barnaul' => 'રશિયા સમય (બારનૌલ)',
        'Asia/Beirut' => 'પૂર્વી યુરોપિયન સમય (બૈરુત)',
        'Asia/Bishkek' => 'કિર્ગિઝ્સ્તાન સમય (બિશકેક)',
        'Asia/Brunei' => 'બ્રુનેઇ દરુસલામ સમય',
        'Asia/Calcutta' => 'ભારતીય માનક સમય (કોલકાતા)',
        'Asia/Chita' => 'યાકુત્સ્ક સમય (ચિતા)',
        'Asia/Choibalsan' => 'ઉલાન બાટોર સમય (ચોઇબાલ્સન)',
        'Asia/Colombo' => 'ભારતીય માનક સમય (કોલંબો)',
        'Asia/Damascus' => 'પૂર્વી યુરોપિયન સમય (દમાસ્કસ)',
        'Asia/Dhaka' => 'બાંગ્લાદેશ સમય (ઢાકા)',
        'Asia/Dili' => 'પૂર્વ તિમોર સમય (દિલિ)',
        'Asia/Dubai' => 'ગલ્ફ માનક સમય (દુબઈ)',
        'Asia/Dushanbe' => 'તાજીકિસ્તાન સમય (દુશામ્બે)',
        'Asia/Famagusta' => 'પૂર્વી યુરોપિયન સમય (ફામાગુસ્તા)',
        'Asia/Gaza' => 'પૂર્વી યુરોપિયન સમય (ગાઝા)',
        'Asia/Hebron' => 'પૂર્વી યુરોપિયન સમય (હેબ્રોન)',
        'Asia/Hong_Kong' => 'હોંગ કોંગ સમય (હોંગકોંગ)',
        'Asia/Hovd' => 'હોવ્ડ સમય',
        'Asia/Irkutsk' => 'ઇર્કુત્સ્ક સમય',
        'Asia/Jakarta' => 'પશ્ચિમી ઇન્ડોનેશિયા સમય (જકાર્તા)',
        'Asia/Jayapura' => 'પૂર્વીય ઇન્ડોનેશિયા સમય (જયાપુરા)',
        'Asia/Jerusalem' => 'ઇઝરાઇલ સમય (જેરુસલેમ)',
        'Asia/Kabul' => 'અફઘાનિસ્તાન સમય (કાબુલ)',
        'Asia/Kamchatka' => 'પેટ્રોપેવલોવ્સ્ક-કામચતસ્કી સમય (કામચટ્કા)',
        'Asia/Karachi' => 'પાકિસ્તાન સમય (કરાચી)',
        'Asia/Katmandu' => 'નેપાળ સમય (કાઠમંડુ)',
        'Asia/Khandyga' => 'યાકુત્સ્ક સમય (ખંડિગા)',
        'Asia/Krasnoyarsk' => 'ક્રેસ્નોયાર્સ્ક સમય (ક્રિસ્નોયાર્સ્ક)',
        'Asia/Kuala_Lumpur' => 'મલેશિયા સમય (કુઆલા લુમ્પુર)',
        'Asia/Kuching' => 'મલેશિયા સમય (કુચિંગ)',
        'Asia/Kuwait' => 'અરેબિયન સમય (કુવૈત)',
        'Asia/Macau' => 'ચીન સમય (મકાઉ)',
        'Asia/Magadan' => 'મગાડન સમય (મેગાડન)',
        'Asia/Makassar' => 'મધ્ય ઇન્ડોનેશિયા સમય (માકસ્સર)',
        'Asia/Manila' => 'ફિલિપાઇન સમય (મનિલા)',
        'Asia/Muscat' => 'ગલ્ફ માનક સમય (મસ્કત)',
        'Asia/Nicosia' => 'પૂર્વી યુરોપિયન સમય (નિકોસિયા)',
        'Asia/Novokuznetsk' => 'ક્રેસ્નોયાર્સ્ક સમય (નોવોકુઝ્નેત્સ્ક)',
        'Asia/Novosibirsk' => 'નોવસિબિર્સ્ક સમય (નોવોસીર્બિર્સ્ક)',
        'Asia/Omsk' => 'ઓમ્સ્ક સમય',
        'Asia/Oral' => 'પશ્ચિમ કઝાકિસ્તાન સમય (ઓરલ)',
        'Asia/Phnom_Penh' => 'ઇન્ડોચાઇના સમય (ફ્નોમ પેન્હ)',
        'Asia/Pontianak' => 'પશ્ચિમી ઇન્ડોનેશિયા સમય (પોન્ટિયનેક)',
        'Asia/Pyongyang' => 'કોરિયન સમય (પ્યોંગયાંગ)',
        'Asia/Qatar' => 'અરેબિયન સમય (કતાર)',
        'Asia/Qostanay' => 'પૂર્વ કઝાકિસ્તાન સમય (કોસ્ટાને)',
        'Asia/Qyzylorda' => 'પશ્ચિમ કઝાકિસ્તાન સમય (કિઝિલોર્ડા)',
        'Asia/Rangoon' => 'મ્યાનમાર સમય (રંગૂન)',
        'Asia/Riyadh' => 'અરેબિયન સમય (રિયાધ)',
        'Asia/Saigon' => 'ઇન્ડોચાઇના સમય (હો ચી મીન સિટી)',
        'Asia/Sakhalin' => 'સખાલિન સમય',
        'Asia/Samarkand' => 'ઉઝ્બેકિસ્તાન સમય (સમરકન્ડ)',
        'Asia/Seoul' => 'કોરિયન સમય (સીઓલ)',
        'Asia/Shanghai' => 'ચીન સમય (શાંઘાઈ)',
        'Asia/Singapore' => 'સિંગાપુર માનક સમય',
        'Asia/Srednekolymsk' => 'મગાડન સમય (સ્રેડ્નેકોલીમ્સ્ક)',
        'Asia/Taipei' => 'તાઇપેઇ સમય',
        'Asia/Tashkent' => 'ઉઝ્બેકિસ્તાન સમય (તાશકેન્ટ)',
        'Asia/Tbilisi' => 'જ્યોર્જિયા સમય (બિલિસિ)',
        'Asia/Tehran' => 'ઈરાન સમય (તેહરાન)',
        'Asia/Thimphu' => 'ભૂટાન સમય (થીમ્ફુ)',
        'Asia/Tokyo' => 'જાપાન સમય (ટોક્યો)',
        'Asia/Tomsk' => 'રશિયા સમય (તોમસ્ક)',
        'Asia/Ulaanbaatar' => 'ઉલાન બાટોર સમય (ઉલાંબાતર)',
        'Asia/Urumqi' => 'ચીન સમય (ઉરુમ્કી)',
        'Asia/Ust-Nera' => 'વ્લાડિવોસ્ટોક સમય (ઉસ્ત-નેરા)',
        'Asia/Vientiane' => 'ઇન્ડોચાઇના સમય (વિયેનટિયેન)',
        'Asia/Vladivostok' => 'વ્લાડિવોસ્ટોક સમય (વ્લેડિવોસ્ટોક)',
        'Asia/Yakutsk' => 'યાકુત્સ્ક સમય (યકુત્સક)',
        'Asia/Yekaterinburg' => 'યેકાટેરિનબર્ગ સમય (યેકાતેરિનબર્ગ)',
        'Asia/Yerevan' => 'આર્મેનિયા સમય (યેરેવાન)',
        'Atlantic/Azores' => 'એઝોર્સ સમય (એઝોરેઝ)',
        'Atlantic/Bermuda' => 'એટલાન્ટિક સમય (બર્મુડા)',
        'Atlantic/Canary' => 'પશ્ચિમી યુરોપિયન સમય (કૅનેરી)',
        'Atlantic/Cape_Verde' => 'કૅપ વર્ડે સમય',
        'Atlantic/Faeroe' => 'પશ્ચિમી યુરોપિયન સમય (ફેરો)',
        'Atlantic/Madeira' => 'પશ્ચિમી યુરોપિયન સમય (મડિરા)',
        'Atlantic/Reykjavik' => 'ગ્રીનવિચ મધ્યમ સમય (રૅકયાવિક)',
        'Atlantic/South_Georgia' => 'દક્ષિણ જ્યોર્જિયા સમય',
        'Atlantic/St_Helena' => 'ગ્રીનવિચ મધ્યમ સમય (સેંટ હેલેના)',
        'Atlantic/Stanley' => 'ફૉકલેન્ડ આઇલેન્ડ્સ સમય (સ્ટેનલી)',
        'Australia/Adelaide' => 'કેન્દ્રીય ઑસ્ટ્રેલિયન સમય (એડિલેઇડ)',
        'Australia/Brisbane' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (બ્રિસબેન)',
        'Australia/Broken_Hill' => 'કેન્દ્રીય ઑસ્ટ્રેલિયન સમય (બ્રોકન હિલ)',
        'Australia/Currie' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (ક્યુરી)',
        'Australia/Darwin' => 'કેન્દ્રીય ઑસ્ટ્રેલિયન સમય (ડાર્વિન)',
        'Australia/Eucla' => 'ઑસ્ટ્રેલિયન કેન્દ્રીય પશ્ચિમી સમય (ઉક્લા)',
        'Australia/Hobart' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (હોબાર્ટ)',
        'Australia/Lindeman' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (લિન્ડેમેન)',
        'Australia/Lord_Howe' => 'લોર્ડ હોવ સમય',
        'Australia/Melbourne' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (મેલબોર્ન)',
        'Australia/Perth' => 'પશ્ચિમી ઑસ્ટ્રેલિયા સમય (પર્થ)',
        'Australia/Sydney' => 'પૂર્વીય ઑસ્ટ્રેલિયા સમય (સિડની)',
        'CST6CDT' => 'ઉત્તર અમેરિકન કેન્દ્રીય સમય',
        'EST5EDT' => 'ઉત્તર અમેરિકન પૂર્વી સમય',
        'Etc/GMT' => 'ગ્રીનવિચ મધ્યમ સમય',
        'Etc/UTC' => 'સંકલિત યુનિવર્સલ સમય',
        'Europe/Amsterdam' => 'મધ્ય યુરોપિયન સમય (ઍમ્સ્ટરડૅમ)',
        'Europe/Andorra' => 'મધ્ય યુરોપિયન સમય (ઍંડોરા)',
        'Europe/Astrakhan' => 'મોસ્કો સમય (આસ્ટ્રખન)',
        'Europe/Athens' => 'પૂર્વી યુરોપિયન સમય (એથેંસ)',
        'Europe/Belgrade' => 'મધ્ય યુરોપિયન સમય (બેલગ્રેડ)',
        'Europe/Berlin' => 'મધ્ય યુરોપિયન સમય (બર્લિન)',
        'Europe/Bratislava' => 'મધ્ય યુરોપિયન સમય (બ્રેટિસલાવા)',
        'Europe/Brussels' => 'મધ્ય યુરોપિયન સમય (બ્રસેલ્સ)',
        'Europe/Bucharest' => 'પૂર્વી યુરોપિયન સમય (બુકરેસ્ટ)',
        'Europe/Budapest' => 'મધ્ય યુરોપિયન સમય (બુડાપેસ્ટ)',
        'Europe/Busingen' => 'મધ્ય યુરોપિયન સમય (બિઝેન્ગન)',
        'Europe/Chisinau' => 'પૂર્વી યુરોપિયન સમય (ચિસીનાઉ)',
        'Europe/Copenhagen' => 'મધ્ય યુરોપિયન સમય (કોપનહેગન)',
        'Europe/Dublin' => 'ગ્રીનવિચ મધ્યમ સમય (ડબલિન)',
        'Europe/Gibraltar' => 'મધ્ય યુરોપિયન સમય (જિબ્રાલ્ટર)',
        'Europe/Guernsey' => 'ગ્રીનવિચ મધ્યમ સમય (ગર્નઝી)',
        'Europe/Helsinki' => 'પૂર્વી યુરોપિયન સમય (હેલસિંકી)',
        'Europe/Isle_of_Man' => 'ગ્રીનવિચ મધ્યમ સમય (આઇલ ઑફ મેન)',
        'Europe/Istanbul' => 'તુર્કી સમય (ઇસ્તાંબુલ)',
        'Europe/Jersey' => 'ગ્રીનવિચ મધ્યમ સમય (જર્સી)',
        'Europe/Kaliningrad' => 'પૂર્વી યુરોપિયન સમય (કલિનિન્ગ્રેડ)',
        'Europe/Kiev' => 'પૂર્વી યુરોપિયન સમય (કૈવ)',
        'Europe/Kirov' => 'રશિયા સમય (કીરોવ)',
        'Europe/Lisbon' => 'પશ્ચિમી યુરોપિયન સમય (લિસ્બન)',
        'Europe/Ljubljana' => 'મધ્ય યુરોપિયન સમય (લુબ્લિયાના)',
        'Europe/London' => 'ગ્રીનવિચ મધ્યમ સમય (લંડન)',
        'Europe/Luxembourg' => 'મધ્ય યુરોપિયન સમય (લક્ઝમબર્ગ)',
        'Europe/Madrid' => 'મધ્ય યુરોપિયન સમય (મેડ્રિડ)',
        'Europe/Malta' => 'મધ્ય યુરોપિયન સમય (માલ્ટા)',
        'Europe/Mariehamn' => 'પૂર્વી યુરોપિયન સમય (મેરિહેમ)',
        'Europe/Minsk' => 'મોસ્કો સમય (મિંસ્ક)',
        'Europe/Monaco' => 'મધ્ય યુરોપિયન સમય (મોનાકો)',
        'Europe/Moscow' => 'મોસ્કો સમય',
        'Europe/Oslo' => 'મધ્ય યુરોપિયન સમય (ઑસ્લો)',
        'Europe/Paris' => 'મધ્ય યુરોપિયન સમય (પેરિસ)',
        'Europe/Podgorica' => 'મધ્ય યુરોપિયન સમય (પોડગોરિકા)',
        'Europe/Prague' => 'મધ્ય યુરોપિયન સમય (પ્રાગ)',
        'Europe/Riga' => 'પૂર્વી યુરોપિયન સમય (રિગા)',
        'Europe/Rome' => 'મધ્ય યુરોપિયન સમય (રોમ)',
        'Europe/Samara' => 'સમારા સમય',
        'Europe/San_Marino' => 'મધ્ય યુરોપિયન સમય (સૅન મેરિનો)',
        'Europe/Sarajevo' => 'મધ્ય યુરોપિયન સમય (સારાજેવો)',
        'Europe/Saratov' => 'મોસ્કો સમય (સારાટોવ)',
        'Europe/Simferopol' => 'મોસ્કો સમય (સિમ્ફેરોપોલ)',
        'Europe/Skopje' => 'મધ્ય યુરોપિયન સમય (સ્કોપયે)',
        'Europe/Sofia' => 'પૂર્વી યુરોપિયન સમય (સોફિયા)',
        'Europe/Stockholm' => 'મધ્ય યુરોપિયન સમય (સ્ટોકહૉમ)',
        'Europe/Tallinn' => 'પૂર્વી યુરોપિયન સમય (તલ્લીન)',
        'Europe/Tirane' => 'મધ્ય યુરોપિયન સમય (તિરાને)',
        'Europe/Ulyanovsk' => 'મોસ્કો સમય (ઉલેનોવ્સ્ક)',
        'Europe/Uzhgorod' => 'પૂર્વી યુરોપિયન સમય (ઉઝ્ગોરોદ)',
        'Europe/Vaduz' => 'મધ્ય યુરોપિયન સમય (વૅદુઝ)',
        'Europe/Vatican' => 'મધ્ય યુરોપિયન સમય (વેટિકન)',
        'Europe/Vienna' => 'મધ્ય યુરોપિયન સમય (વિયેના)',
        'Europe/Vilnius' => 'પૂર્વી યુરોપિયન સમય (વિલ્નિઅસ)',
        'Europe/Volgograd' => 'વોલ્ગોગ્રેડ સમય',
        'Europe/Warsaw' => 'મધ્ય યુરોપિયન સમય (વોરસૉ)',
        'Europe/Zagreb' => 'મધ્ય યુરોપિયન સમય (ઝેગરેબ)',
        'Europe/Zaporozhye' => 'પૂર્વી યુરોપિયન સમય (જેપોરોઝિયે)',
        'Europe/Zurich' => 'મધ્ય યુરોપિયન સમય (ઝુરીક)',
        'Indian/Antananarivo' => 'પૂર્વ આફ્રિકા સમય (અંતાનાનારિવો)',
        'Indian/Chagos' => 'ભારતીય મહાસાગર સમય (ચાગોસ)',
        'Indian/Christmas' => 'ક્રિસમસ આઇલેન્ડ સમય',
        'Indian/Cocos' => 'કોકોઝ આઇલેન્ડ્સ સમય',
        'Indian/Comoro' => 'પૂર્વ આફ્રિકા સમય (કોમોરો)',
        'Indian/Kerguelen' => 'ફ્રેંચ સધર્ન અને એન્ટાર્કટિક સમય (કેરગ્વેલિન)',
        'Indian/Mahe' => 'સેશલ્સ સમય (માહે)',
        'Indian/Maldives' => 'માલદીવ સમય (માલદિવ્સ)',
        'Indian/Mauritius' => 'મોરિશિયસ સમય',
        'Indian/Mayotte' => 'પૂર્વ આફ્રિકા સમય (મેયોટ)',
        'Indian/Reunion' => 'રીયુનિયન સમય',
        'MST7MDT' => 'ઉત્તર અમેરિકન માઉન્ટન સમય',
        'PST8PDT' => 'ઉત્તર અમેરિકન પેસિફિક સમય',
        'Pacific/Apia' => 'એપિયા સમય',
        'Pacific/Auckland' => 'ન્યુઝીલેન્ડ સમય (ઑકલેન્ડ)',
        'Pacific/Bougainville' => 'પાપુઆ ન્યુ ગિની સમય (બૌગેઈનવિલે)',
        'Pacific/Chatham' => 'ચેતહામ સમય (ચથમ)',
        'Pacific/Easter' => 'ઇસ્ટર આઇલેન્ડ સમય',
        'Pacific/Efate' => 'વનાતૂ સમય (એફેટ)',
        'Pacific/Enderbury' => 'ફોનિક્સ આઇલેન્ડ્સ સમય (એંડર્બરી)',
        'Pacific/Fakaofo' => 'ટોકલાઉ સમય (ફાકાઓફો)',
        'Pacific/Fiji' => 'ફીજી સમય',
        'Pacific/Funafuti' => 'ટવાલૂ સમય (ફુનાફુટી)',
        'Pacific/Galapagos' => 'ગાલાપાગોસ સમય (ગાલાપેગોસ)',
        'Pacific/Gambier' => 'ગેમ્બિયર સમય',
        'Pacific/Guadalcanal' => 'સોલોમન આઇલેન્ડ્સ સમય (ગૌડલકૅનલ)',
        'Pacific/Guam' => 'કેમોરો માનક સમય (ગ્વામ)',
        'Pacific/Honolulu' => 'હવાઈ-એલ્યુશિઅન સમય (હોનોલુલુ)',
        'Pacific/Johnston' => 'હવાઈ-એલ્યુશિઅન સમય (જોહ્નસ્ટોન)',
        'Pacific/Kiritimati' => 'લાઇન આઇલેન્ડ્સ સમય (કિરિતિમાતી)',
        'Pacific/Kosrae' => 'કોસરે સમય',
        'Pacific/Kwajalein' => 'માર્શલ આઇલેન્ડ્સ સમય (ક્વાજાલીન)',
        'Pacific/Majuro' => 'માર્શલ આઇલેન્ડ્સ સમય (માજુરો)',
        'Pacific/Marquesas' => 'માર્ક્યૂસસ સમય (માર્કીસાસ)',
        'Pacific/Midway' => 'સમોઆ સમય (મીડવે)',
        'Pacific/Nauru' => 'નૌરુ સમય',
        'Pacific/Niue' => 'નીયુ સમય',
        'Pacific/Norfolk' => 'નોરફૉક આઇલેન્ડ સમય (નૉરફૉક)',
        'Pacific/Noumea' => 'ન્યુ સેલેડોનિયા સમય (નૌમીઆ)',
        'Pacific/Pago_Pago' => 'સમોઆ સમય (પેગો પેગો)',
        'Pacific/Palau' => 'પલાઉ સમય',
        'Pacific/Pitcairn' => 'પિટકેયર્ન સમય (પીટકૈર્ન)',
        'Pacific/Ponape' => 'પોનપે સમય (પોન્પે)',
        'Pacific/Port_Moresby' => 'પાપુઆ ન્યુ ગિની સમય (પોર્ટ મોર્સ્બી)',
        'Pacific/Rarotonga' => 'કુક આઇલેન્ડ્સ સમય (રેરોટોંગા)',
        'Pacific/Saipan' => 'કેમોરો માનક સમય (સાઇપન)',
        'Pacific/Tahiti' => 'તાહિતી સમય (તાહીતી)',
        'Pacific/Tarawa' => 'ગિલબર્ટ આઇલેન્ડ્સ સમય (તારાવા)',
        'Pacific/Tongatapu' => 'ટોંગા સમય (ટૉંગાટાપુ)',
        'Pacific/Truk' => 'ચુઉક સમય (ચુક)',
        'Pacific/Wake' => 'વૅક આઇલેન્ડ સમય (વેક)',
        'Pacific/Wallis' => 'વૉલિસ અને ફ્યુચુના સમય (વાલિસ)',
    ],
    'Meta' => [
    ],
];
