<?php

return [
    'Names' => [
        'aa' => 'Kiafar',
        'ab' => 'Kiabkhazi',
        'ace' => 'Kiacheni',
        'ach' => 'Kiakoli',
        'ada' => 'Kiadangme',
        'ady' => 'Kiadyghe',
        'af' => 'Kiafrikana',
        'agq' => 'Kiaghem',
        'ain' => 'Kiainu',
        'ak' => 'Kiakani',
        'ale' => 'Kialeut',
        'alt' => 'Kialtai',
        'am' => 'Kiamhari',
        'an' => 'Kiaragoni',
        'ang' => 'Kiingereza cha Kale',
        'ann' => 'Kiobolo',
        'anp' => 'Kiangika',
        'ar' => 'Kiarabu',
        'arc' => 'Kiaramu',
        'arn' => 'Kimapuche',
        'arp' => 'Kiarapaho',
        'arq' => 'Kiarabu cha Algeria',
        'ars' => 'Kiarabu cha Najdi',
        'arz' => 'Kiarabu cha Misri',
        'as' => 'Kiassam',
        'asa' => 'Kiasu',
        'ast' => 'Kiasturia',
        'atj' => 'Kiatikamekw',
        'av' => 'Kiavari',
        'awa' => 'Kiawadhi',
        'ay' => 'Kiaymara',
        'az' => 'Kiazerbaijani',
        'ba' => 'Kibashkiri',
        'ban' => 'Kibali',
        'bas' => 'Kibasaa',
        'bax' => 'Kibamun',
        'bbj' => 'Kighomala',
        'be' => 'Kibelarusi',
        'bej' => 'Kibeja',
        'bem' => 'Kibemba',
        'bez' => 'Kibena',
        'bfd' => 'Kibafut',
        'bg' => 'Kibulgaria',
        'bgn' => 'Kibalochi cha Magharibi',
        'bho' => 'Kibhojpuri',
        'bi' => 'Kibislama',
        'bin' => 'Kibini',
        'bkm' => 'Kikom',
        'bla' => 'Kisiksika',
        'bm' => 'Kibambara',
        'bn' => 'Kibengali',
        'bo' => 'Kitibeti',
        'br' => 'Kibretoni',
        'brx' => 'Kibodo',
        'bs' => 'Kibosnia',
        'bug' => 'Kibugini',
        'bum' => 'Kibulu',
        'byn' => 'Kiblin',
        'byv' => 'Kimedumba',
        'ca' => 'Kikatalani',
        'cay' => 'Kikayuga',
        'ccp' => 'Kichakma',
        'ce' => 'Kichechenia',
        'ceb' => 'Kichebuano',
        'cgg' => 'Kichiga',
        'ch' => 'Kichamorro',
        'chk' => 'Kichukisi',
        'chm' => 'Kimari',
        'cho' => 'Kichoktao',
        'chp' => 'Kichipewyani',
        'chr' => 'Kicherokee',
        'chy' => 'Kicheyeni',
        'ckb' => 'Kikurdi cha Sorani',
        'clc' => 'Kichikotini',
        'co' => 'Kikosikani',
        'cop' => 'Kikhufti',
        'crg' => 'Kimichifu',
        'crj' => 'Kikrii cha Kusini Mashariki',
        'crk' => 'Kikri (Maeneo Tambarare)',
        'crl' => 'Kikrii cha Kaskazini Mashariki',
        'crm' => 'Kikrii cha Moose',
        'crr' => 'Kipamliko cha Carolina',
        'crs' => 'Krioli ya Shelisheli',
        'cs' => 'Kicheki',
        'csw' => 'Kiomushkego',
        'cu' => 'Kislovakia cha Kanisa',
        'cv' => 'Kichuvash',
        'cy' => 'Kiwelisi',
        'da' => 'Kidenmaki',
        'dak' => 'Kidakota',
        'dar' => 'Kidaragwa',
        'dav' => 'Kitaita',
        'de' => 'Kijerumani',
        'dgr' => 'Kidogrib',
        'dje' => 'Kizarma',
        'doi' => 'Kidogri',
        'dsb' => 'Kisobia cha Chini',
        'dua' => 'Kiduala',
        'dv' => 'Kidivehi',
        'dyo' => 'Kijola-Fonyi',
        'dyu' => 'Kijula',
        'dz' => 'Kizongkha',
        'dzg' => 'Kidazaga',
        'ebu' => 'Kiembu',
        'ee' => 'Kiewe',
        'efi' => 'Kiefik',
        'egy' => 'Kimisri',
        'eka' => 'Kiekajuk',
        'el' => 'Kigiriki',
        'en' => 'Kiingereza',
        'eo' => 'Kiesperanto',
        'es' => 'Kihispania',
        'et' => 'Kiestonia',
        'eu' => 'Kibaski',
        'ewo' => 'Kiewondo',
        'fa' => 'Kiajemi',
        'ff' => 'Kifulani',
        'fi' => 'Kifini',
        'fil' => 'Kifilipino',
        'fj' => 'Kifiji',
        'fo' => 'Kifaroe',
        'fon' => 'Kifon',
        'fr' => 'Kifaransa',
        'frc' => 'Kifaransa cha Kajuni',
        'fro' => 'Kifaransa cha Kale',
        'frr' => 'Kifrisia cha Kaskazini',
        'frs' => 'Kifrisia cha Mashariki',
        'fur' => 'Kifriulian',
        'fy' => 'Kifrisia cha Magharibi',
        'ga' => 'Kiayalandi',
        'gaa' => 'Ga',
        'gag' => 'Kigagauz',
        'gba' => 'Kigbaya',
        'gd' => 'Kigaeli cha Uskoti',
        'gez' => 'Kige’ez',
        'gil' => 'Kikiribati',
        'gl' => 'Kigalisi',
        'gn' => 'Kiguarani',
        'gor' => 'Kigorontalo',
        'grc' => 'Kiyunani',
        'gsw' => 'Kijerumani cha Uswisi',
        'gu' => 'Kigujarati',
        'guz' => 'Kikisii',
        'gv' => 'Kimanx',
        'gwi' => 'Gwichʼin',
        'ha' => 'Kihausa',
        'hai' => 'Kihaida',
        'haw' => 'Kihawai',
        'hax' => 'Kihaida cha Kusini',
        'he' => 'Kiebrania',
        'hi' => 'Kihindi',
        'hil' => 'Kihiligaynon',
        'hit' => 'Kihiti',
        'hmn' => 'Kihmong',
        'hr' => 'Kikorasia',
        'hsb' => 'Kisobia cha Ukanda wa Juu',
        'ht' => 'Kihaiti',
        'hu' => 'Kihungaria',
        'hup' => 'Hupa',
        'hur' => 'Kihalkomelemi',
        'hy' => 'Kiarmenia',
        'hz' => 'Kiherero',
        'ia' => 'Kiintalingua',
        'iba' => 'Kiiban',
        'ibb' => 'Kiibibio',
        'id' => 'Kiindonesia',
        'ie' => 'lugha ya kisayansi',
        'ig' => 'Kiigbo',
        'ii' => 'Kiyi cha Sichuan',
        'ikt' => 'Kiinuktituti cha Kanada Magharibi',
        'ilo' => 'Kiilocano',
        'inh' => 'Kiingush',
        'io' => 'Kiido',
        'is' => 'Kiisilandi',
        'it' => 'Kiitaliano',
        'iu' => 'Kiinuktituti',
        'ja' => 'Kijapani',
        'jbo' => 'Lojban',
        'jgo' => 'Kingomba',
        'jmc' => 'Kimachame',
        'jv' => 'Kijava',
        'ka' => 'Kijojia',
        'kab' => 'Kikabylia',
        'kac' => 'Kachin',
        'kaj' => 'Kijju',
        'kam' => 'Kikamba',
        'kbd' => 'Kikabardian',
        'kbl' => 'Kikanembu',
        'kcg' => 'Kityap',
        'kde' => 'Kimakonde',
        'kea' => 'Kikabuverdianu',
        'kfo' => 'Kikoro',
        'kg' => 'Kikongo',
        'kgp' => 'Kikaingang',
        'kha' => 'Kikhasi',
        'khq' => 'Kikoyra Chiini',
        'ki' => 'Kikikuyu',
        'kj' => 'Kikwanyama',
        'kk' => 'Kikazakh',
        'kkj' => 'Lugha ya Kako',
        'kl' => 'Kikalaallisut',
        'kln' => 'Kikalenjin',
        'km' => 'Kikambodia',
        'kmb' => 'Kimbundu',
        'kn' => 'Kikannada',
        'ko' => 'Kikorea',
        'koi' => 'Kikomi-Permyak',
        'kok' => 'Kikonkani',
        'kpe' => 'Kikpelle',
        'kr' => 'Kikanuri',
        'krc' => 'Kikarachay-Balkar',
        'krl' => 'Karjala',
        'kru' => 'Kurukh',
        'ks' => 'Kikashmiri',
        'ksb' => 'Kisambaa',
        'ksf' => 'Kibafia',
        'ksh' => 'Kicologne',
        'ku' => 'Kikurdi',
        'kum' => 'Kumyk',
        'kv' => 'Kikomi',
        'kw' => 'Kikorni',
        'kwk' => 'Kikwakʼwala',
        'ky' => 'Kikyrgyz',
        'la' => 'Kilatini',
        'lad' => 'Kiladino',
        'lag' => 'Kirangi',
        'lam' => 'Lamba',
        'lb' => 'Kilasembagi',
        'lez' => 'Kilezighian',
        'lg' => 'Kiganda',
        'li' => 'Limburgish',
        'lil' => 'Kilillooet',
        'lkt' => 'Kilakota',
        'ln' => 'Kilingala',
        'lo' => 'Kilaosi',
        'lol' => 'Kimongo',
        'lou' => 'Kikrioli cha Louisiana',
        'loz' => 'Kilozi',
        'lrc' => 'Kiluri cha Kaskazini',
        'lsm' => 'Kisaamia',
        'lt' => 'Kilithuania',
        'lu' => 'Kiluba-Katanga',
        'lua' => 'Kiluba-Lulua',
        'lun' => 'Kilunda',
        'luo' => 'Kijaluo',
        'lus' => 'Kimizo',
        'luy' => 'Kiluhya',
        'lv' => 'Kilatvia',
        'mad' => 'Kimadura',
        'maf' => 'Kimafa',
        'mag' => 'Kimagahi',
        'mai' => 'Kimaithili',
        'mak' => 'Kimakasar',
        'mas' => 'Kimaasai',
        'mde' => 'Kimaba',
        'mdf' => 'Lugha ya Moksha',
        'men' => 'Kimende',
        'mer' => 'Kimeru',
        'mfe' => 'Kimoriseni',
        'mg' => 'Kimalagasi',
        'mgh' => 'Kimakhuwa-Meetto',
        'mgo' => 'Kimeta',
        'mh' => 'Kimashale',
        'mi' => 'Kimaori',
        'mic' => 'Mi’kmaq',
        'min' => 'Kiminangkabau',
        'mk' => 'Kimacedonia',
        'ml' => 'Kimalayalamu',
        'mn' => 'Kimongolia',
        'mni' => 'Kimanipuri',
        'moe' => 'Kiinnu-aimun',
        'moh' => 'Lugha ya Mohawk',
        'mos' => 'Kimoore',
        'mr' => 'Kimarathi',
        'ms' => 'Kimalei',
        'mt' => 'Kimalta',
        'mua' => 'Kimundang',
        'mus' => 'Kikriki',
        'mwl' => 'Kimirandi',
        'my' => 'Kiburma',
        'myv' => 'Kierzya',
        'mzn' => 'Kimazanderani',
        'na' => 'Kinauru',
        'nap' => 'Kinapoli',
        'naq' => 'Kinama',
        'nb' => 'Kinorwe cha Bokmal',
        'nd' => 'Kindebele cha Kaskazini',
        'nds' => 'Kisaksoni',
        'ne' => 'Kinepali',
        'new' => 'Kinewari',
        'ng' => 'Kindonga',
        'nia' => 'Kiniasi',
        'niu' => 'Kiniuea',
        'nl' => 'Kiholanzi',
        'nmg' => 'Kikwasio',
        'nn' => 'Kinorwe cha Nynorsk',
        'nnh' => 'Lugha ya Ngiemboon',
        'no' => 'Kinorwe',
        'nog' => 'Kinogai',
        'nqo' => 'N’Ko',
        'nr' => 'Kindebele',
        'nso' => 'Kisotho cha Kaskazini',
        'nus' => 'Kinuer',
        'nv' => 'Kinavajo',
        'nwc' => 'Kinewari cha kale',
        'ny' => 'Kinyanja',
        'nym' => 'Kinyamwezi',
        'nyn' => 'Kinyankole',
        'nyo' => 'Kinyoro',
        'nzi' => 'Kinzema',
        'oc' => 'Kiokitani',
        'ojb' => 'Kiojibwa cha Kaskazini Magharibi',
        'ojc' => 'Kiojibwa cha kati',
        'ojs' => 'Kikrii cha Oji',
        'ojw' => 'Kiojibwa cha Magharibi',
        'oka' => 'Kiokanagani',
        'om' => 'Kioromo',
        'or' => 'Kioriya',
        'os' => 'Kiosetia',
        'pa' => 'Kipunjabi',
        'pag' => 'Kipangasinan',
        'pam' => 'Kipampanga',
        'pap' => 'Kipapiamento',
        'pau' => 'Kipalau',
        'pcm' => 'Pijini ya Nigeria',
        'peo' => 'Kiajemi cha Kale',
        'pis' => 'Kipijini',
        'pl' => 'Kipolandi',
        'pqm' => 'Kimaliseet-Passamaquoddy',
        'prg' => 'Kiprussia',
        'ps' => 'Kipashto',
        'pt' => 'Kireno',
        'qu' => 'Kikechua',
        'quc' => 'Kʼicheʼ',
        'rap' => 'Kirapanui',
        'rar' => 'Kirarotonga',
        'rhg' => 'Kirohingya',
        'rm' => 'Kiromanshi',
        'rn' => 'Kirundi',
        'ro' => 'Kiromania',
        'rof' => 'Kirombo',
        'ru' => 'Kirusi',
        'rup' => 'Kiaromania',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Lugha ya Rwa',
        'sa' => 'Kisanskriti',
        'sad' => 'Kisandawe',
        'sah' => 'Kisakha',
        'sam' => 'Kiaramu cha Wasamaria',
        'saq' => 'Kisamburu',
        'sat' => 'Kisantali',
        'sba' => 'Kingambay',
        'sbp' => 'Kisangu',
        'sc' => 'Kisardinia',
        'scn' => 'Kisicilia',
        'sco' => 'Kiskoti',
        'sd' => 'Kisindhi',
        'sdh' => 'Kikurdi cha Kusini',
        'se' => 'Kisami cha Kaskazini',
        'seh' => 'Kisena',
        'ses' => 'Kikoyraboro Senni',
        'sg' => 'Kisango',
        'sh' => 'Kiserbia-kroeshia',
        'shi' => 'Kitachelhit',
        'shn' => 'Kishan',
        'shu' => 'Kiarabu cha Chad',
        'si' => 'Kisinhala',
        'sk' => 'Kislovakia',
        'sl' => 'Kislovenia',
        'slh' => 'Lugha ya Lushootseed ya Kusini',
        'sm' => 'Kisamoa',
        'sma' => 'Kisami cha Kusini',
        'smj' => 'Kisami cha Lule',
        'smn' => 'Kisami cha Inari',
        'sms' => 'Kisami cha Skolt',
        'sn' => 'Kishona',
        'snk' => 'Kisoninke',
        'so' => 'Kisomali',
        'sq' => 'Kialbania',
        'sr' => 'Kiserbia',
        'srn' => 'Lugha ya Sranan Tongo',
        'ss' => 'Kiswati',
        'ssy' => 'Kisaho',
        'st' => 'Kisotho',
        'str' => 'Kisalishi cha Straiti',
        'su' => 'Kisunda',
        'suk' => 'Kisukuma',
        'sus' => 'Kisusu',
        'sv' => 'Kiswidi',
        'sw' => 'Kiswahili',
        'swb' => 'Shikomor',
        'syr' => 'Lugha ya Syriac',
        'ta' => 'Kitamili',
        'tce' => 'Kitutchone cha Kusini',
        'te' => 'Kitelugu',
        'tem' => 'Kitemne',
        'teo' => 'Kiteso',
        'tet' => 'Kitetum',
        'tg' => 'Kitajiki',
        'tgx' => 'Kitagishi',
        'th' => 'Kithai',
        'tht' => 'Kitahltani',
        'ti' => 'Kitigrinya',
        'tig' => 'Kitigre',
        'tk' => 'Kiturukimeni',
        'tlh' => 'Kiklingoni',
        'tli' => 'Kitlingiti',
        'tn' => 'Kitswana',
        'to' => 'Kitonga',
        'tok' => 'Kitoki Pona',
        'tpi' => 'Kitokpisin',
        'tr' => 'Kituruki',
        'trv' => 'Kitaroko',
        'ts' => 'Kitsonga',
        'tt' => 'Kitatari',
        'ttm' => 'Kitutchone cha Kaskazini',
        'tum' => 'Kitumbuka',
        'tvl' => 'Kituvalu',
        'tw' => 'Twi',
        'twq' => 'Kitasawak',
        'ty' => 'Kitahiti',
        'tyv' => 'Kituva',
        'tzm' => 'Kitamazighati cha Atlasi ya Kati',
        'udm' => 'Kiudmurt',
        'ug' => 'Kiuyghur',
        'uk' => 'Kiukraini',
        'umb' => 'Umbundu',
        'ur' => 'Kiurdu',
        'uz' => 'Kiuzbeki',
        'vai' => 'Kivai',
        've' => 'Kivenda',
        'vi' => 'Kivietinamu',
        'vo' => 'Kivolapuk',
        'vun' => 'Kivunjo',
        'wa' => 'Kiwaloon',
        'wae' => 'Kiwalser',
        'wal' => 'Kiwolaytta',
        'war' => 'Kiwaray',
        'wbp' => 'Kiwarlpiri',
        'wo' => 'Kiwolofu',
        'wuu' => 'Kichina cha Wu',
        'xal' => 'Kikalmyk',
        'xh' => 'Kixhosa',
        'xog' => 'Kisoga',
        'yao' => 'Kiyao',
        'yav' => 'Kiyangben',
        'ybb' => 'Kiyemba',
        'yi' => 'Kiyiddi',
        'yo' => 'Kiyoruba',
        'yrl' => 'Kinheengatu',
        'yue' => 'Kikantoni',
        'zgh' => 'Kiberber Sanifu cha Moroko',
        'zh' => 'Kichina',
        'zu' => 'Kizulu',
        'zun' => 'Kizuni',
        'zza' => 'Kizaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Kiarabu sanifu',
        'en_CA' => 'Kiingereza (Canada)',
        'en_GB' => 'Kiingereza (Uingereza)',
        'es_419' => 'Kihispania (Amerika ya Latini)',
        'es_ES' => 'Kihispania (Ulaya)',
        'fa_AF' => 'Kiajemi (Afganistani)',
        'fr_CA' => 'Kifaransa (Canada)',
        'nl_BE' => 'Kiflemi',
        'pt_BR' => 'Kireno (Brazili)',
        'pt_PT' => 'Kireno (Ulaya)',
        'ro_MD' => 'Kimoldova cha Romania',
        'zh_Hans' => 'Kichina (Kilichorahisishwa)',
        'zh_Hant' => 'Kichina cha Jadi',
    ],
];
