<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abcaso',
        'ace' => 'accinese',
        'ach' => 'acioli',
        'ada' => 'adangme',
        'ady' => 'adyghe',
        'ae' => 'avestan',
        'aeb' => 'arabo tunisino',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'accado',
        'akz' => 'alabama',
        'ale' => 'aleuto',
        'aln' => 'albanese ghego',
        'alt' => 'altai meridionale',
        'am' => 'amarico',
        'an' => 'aragonese',
        'ang' => 'inglese antico',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabo',
        'arc' => 'aramaico',
        'arn' => 'mapudungun',
        'aro' => 'araona',
        'arp' => 'arapaho',
        'arq' => 'arabo algerino',
        'ars' => 'arabo najd',
        'arw' => 'aruaco',
        'ary' => 'arabo marocchino',
        'arz' => 'arabo egiziano',
        'as' => 'assamese',
        'asa' => 'asu',
        'ase' => 'lingua dei segni americana',
        'ast' => 'asturiano',
        'atj' => 'atikamekw',
        'av' => 'avaro',
        'avk' => 'kotava',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'azerbaigiano',
        'ba' => 'baschiro',
        'bal' => 'beluci',
        'ban' => 'balinese',
        'bar' => 'bavarese',
        'bas' => 'basa',
        'bax' => 'bamun',
        'bbc' => 'batak toba',
        'bbj' => 'ghomala',
        'be' => 'bielorusso',
        'bej' => 'begia',
        'bem' => 'wemba',
        'bew' => 'betawi',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bfq' => 'badaga',
        'bg' => 'bulgaro',
        'bgn' => 'beluci occidentale',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bik' => 'bicol',
        'bin' => 'bini',
        'bjn' => 'banjar',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bengalese',
        'bo' => 'tibetano',
        'bpy' => 'bishnupriya',
        'bqi' => 'bakhtiari',
        'br' => 'bretone',
        'bra' => 'braj',
        'brh' => 'brahui',
        'brx' => 'bodo',
        'bs' => 'bosniaco',
        'bss' => 'akoose',
        'bua' => 'buriat',
        'bug' => 'bugi',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumba',
        'ca' => 'catalano',
        'cad' => 'caddo',
        'car' => 'caribico',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'ceceno',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'chibcha',
        'chg' => 'ciagataico',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'chn' => 'gergo chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'curdo sorani',
        'clc' => 'chilcotin',
        'co' => 'corso',
        'cop' => 'copto',
        'cps' => 'capiznon',
        'cr' => 'cree',
        'crg' => 'métchif',
        'crh' => 'turco crimeo',
        'crj' => 'cree sud-orientale',
        'crk' => 'cree delle pianure',
        'crl' => 'cree nord-orientale',
        'crm' => 'cree moose',
        'crr' => 'algonchino della Carolina',
        'crs' => 'creolo delle Seychelles',
        'cs' => 'ceco',
        'csb' => 'kashubian',
        'csw' => 'cree delle paludi',
        'cu' => 'slavo ecclesiastico',
        'cv' => 'ciuvascio',
        'cy' => 'gallese',
        'da' => 'danese',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'tedesco',
        'del' => 'delaware',
        'den' => 'slave',
        'dgr' => 'dogrib',
        'din' => 'dinca',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'basso sorabo',
        'dtp' => 'dusun centrale',
        'dua' => 'duala',
        'dum' => 'olandese medio',
        'dv' => 'divehi',
        'dyo' => 'jola-fony',
        'dyu' => 'diula',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egl' => 'emiliano',
        'egy' => 'egiziano antico',
        'eka' => 'ekajuka',
        'el' => 'greco',
        'elx' => 'elamitico',
        'en' => 'inglese',
        'enm' => 'inglese medio',
        'eo' => 'esperanto',
        'es' => 'spagnolo',
        'esu' => 'yupik centrale',
        'et' => 'estone',
        'eu' => 'basco',
        'ewo' => 'ewondo',
        'ext' => 'estremegno',
        'fa' => 'persiano',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulah',
        'fi' => 'finlandese',
        'fil' => 'filippino',
        'fit' => 'finlandese del Tornedalen',
        'fj' => 'figiano',
        'fo' => 'faroese',
        'fon' => 'fon',
        'fr' => 'francese',
        'frc' => 'francese cajun',
        'frm' => 'francese medio',
        'fro' => 'francese antico',
        'frp' => 'francoprovenzale',
        'frr' => 'frisone settentrionale',
        'frs' => 'frisone orientale',
        'fur' => 'friulano',
        'fy' => 'frisone occidentale',
        'ga' => 'irlandese',
        'gaa' => 'ga',
        'gag' => 'gagauzo',
        'gan' => 'gan',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gbz' => 'dari zoroastriano',
        'gd' => 'gaelico scozzese',
        'gez' => 'geez',
        'gil' => 'gilbertese',
        'gl' => 'galiziano',
        'glk' => 'gilaki',
        'gmh' => 'tedesco medio alto',
        'gn' => 'guaraní',
        'goh' => 'tedesco antico alto',
        'gom' => 'konkani goano',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gotico',
        'grb' => 'grebo',
        'grc' => 'greco antico',
        'gsw' => 'tedesco svizzero',
        'gu' => 'gujarati',
        'guc' => 'wayuu',
        'guz' => 'gusii',
        'gv' => 'mannese',
        'gwi' => 'gwichʼin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'hak' => 'hakka',
        'haw' => 'hawaiano',
        'hax' => 'haida meridionale',
        'he' => 'ebraico',
        'hi' => 'hindi',
        'hif' => 'hindi figiano',
        'hil' => 'ilongo',
        'hit' => 'hittite',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'croato',
        'hsb' => 'alto sorabo',
        'hsn' => 'xiang',
        'ht' => 'creolo haitiano',
        'hu' => 'ungherese',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armeno',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesiano',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ik' => 'inupiak',
        'ikt' => 'inuktitut canadese occidentale',
        'ilo' => 'ilocano',
        'inh' => 'ingush',
        'io' => 'ido',
        'is' => 'islandese',
        'it' => 'italiano',
        'iu' => 'inuktitut',
        'izh' => 'ingrico',
        'ja' => 'giapponese',
        'jam' => 'creolo giamaicano',
        'jbo' => 'lojban',
        'jgo' => 'ngamambo',
        'jmc' => 'machame',
        'jpr' => 'giudeo persiano',
        'jrb' => 'giudeo arabo',
        'jut' => 'jutlandico',
        'jv' => 'giavanese',
        'ka' => 'georgiano',
        'kaa' => 'kara-kalpak',
        'kab' => 'cabilo',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'cabardino',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'capoverdiano',
        'kfo' => 'koro',
        'kg' => 'kongo',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'kho' => 'khotanese',
        'khq' => 'koyra chiini',
        'khw' => 'khowar',
        'ki' => 'kikuyu',
        'kiu' => 'kirmanjki',
        'kj' => 'kuanyama',
        'kk' => 'kazako',
        'kkj' => 'kako',
        'kl' => 'groenlandese',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'coreano',
        'koi' => 'permiaco',
        'kok' => 'konkani',
        'kos' => 'kosraean',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karachay-Balkar',
        'krl' => 'careliano',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'coloniese',
        'ku' => 'curdo',
        'kum' => 'kumyk',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'cornico',
        'kwk' => 'kwakʼwala',
        'ky' => 'kirghiso',
        'la' => 'latino',
        'lad' => 'giudeo-spagnolo',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'lussemburghese',
        'lez' => 'lesgo',
        'lfn' => 'Lingua Franca Nova',
        'lg' => 'ganda',
        'li' => 'limburghese',
        'lij' => 'ligure',
        'lil' => 'lillooet',
        'liv' => 'livone',
        'lkt' => 'lakota',
        'lmo' => 'lombardo',
        'ln' => 'lingala',
        'lo' => 'lao',
        'lol' => 'lolo bantu',
        'lou' => 'creolo della Louisiana',
        'loz' => 'lozi',
        'lrc' => 'luri settentrionale',
        'lsm' => 'samia',
        'lt' => 'lituano',
        'ltg' => 'letgallo',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'lushai',
        'luy' => 'luyia',
        'lv' => 'lettone',
        'lzh' => 'cinese classico',
        'lzz' => 'laz',
        'mad' => 'madurese',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'man' => 'mandingo',
        'mas' => 'masai',
        'mde' => 'maba',
        'mdf' => 'moksha',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'creolo mauriziano',
        'mg' => 'malgascio',
        'mga' => 'irlandese medio',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshallese',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'menangkabau',
        'mk' => 'macedone',
        'ml' => 'malayalam',
        'mn' => 'mongolo',
        'mnc' => 'manchu',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'mrj' => 'mari occidentale',
        'ms' => 'malese',
        'mt' => 'maltese',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandese',
        'mwr' => 'marwari',
        'mwv' => 'mentawai',
        'my' => 'birmano',
        'mye' => 'myene',
        'myv' => 'erzya',
        'mzn' => 'mazandarani',
        'na' => 'nauru',
        'nan' => 'min nan',
        'nap' => 'napoletano',
        'naq' => 'nama',
        'nb' => 'norvegese bokmål',
        'nd' => 'ndebele del nord',
        'nds' => 'basso tedesco',
        'ne' => 'nepalese',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niue',
        'njo' => 'ao',
        'nl' => 'olandese',
        'nmg' => 'kwasio',
        'nn' => 'norvegese nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norvegese',
        'nog' => 'nogai',
        'non' => 'norse antico',
        'nov' => 'novial',
        'nqo' => 'n’ko',
        'nr' => 'ndebele del sud',
        'nso' => 'sotho del nord',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'nwc' => 'newari classico',
        'ny' => 'nyanja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'occitano',
        'oj' => 'ojibwa',
        'ojb' => 'ojibwe nord-occidentale',
        'ojc' => 'ojibwe centrale',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwe occidentale',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'odia',
        'os' => 'ossetico',
        'osa' => 'osage',
        'ota' => 'turco ottomano',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palau',
        'pcd' => 'piccardo',
        'pcm' => 'pidgin nigeriano',
        'pdc' => 'tedesco della Pennsylvania',
        'peo' => 'persiano antico',
        'pfl' => 'tedesco palatino',
        'phn' => 'fenicio',
        'pi' => 'pali',
        'pis' => 'pijin',
        'pl' => 'polacco',
        'pms' => 'piemontese',
        'pnt' => 'pontico',
        'pon' => 'ponape',
        'pqm' => 'malecite-passamaquoddy',
        'prg' => 'prussiano',
        'pro' => 'provenzale antico',
        'ps' => 'pashto',
        'pt' => 'portoghese',
        'qu' => 'quechua',
        'quc' => 'k’iche’',
        'qug' => 'quechua dell’altopiano del Chimborazo',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotonga',
        'rgn' => 'romagnolo',
        'rhg' => 'rohingya',
        'rif' => 'tarifit',
        'rm' => 'romancio',
        'rn' => 'rundi',
        'ro' => 'rumeno',
        'rof' => 'rombo',
        'rom' => 'romani',
        'rtm' => 'rotumano',
        'ru' => 'russo',
        'rue' => 'ruteno',
        'rug' => 'roviana',
        'rup' => 'arumeno',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanscrito',
        'sad' => 'sandawe',
        'sah' => 'sacha',
        'sam' => 'aramaico samaritano',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'saz' => 'saurashtra',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardo',
        'scn' => 'siciliano',
        'sco' => 'scozzese',
        'sd' => 'sindhi',
        'sdc' => 'sassarese',
        'sdh' => 'curdo meridionale',
        'se' => 'sami del nord',
        'see' => 'seneca',
        'seh' => 'sena',
        'sei' => 'seri',
        'sel' => 'selkup',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'irlandese antico',
        'sgs' => 'samogitico',
        'sh' => 'serbo-croato',
        'shi' => 'tashelhit',
        'shn' => 'shan',
        'shu' => 'arabo ciadiano',
        'si' => 'singalese',
        'sid' => 'sidamo',
        'sk' => 'slovacco',
        'sl' => 'sloveno',
        'slh' => 'lushootseed meridionale',
        'sli' => 'tedesco slesiano',
        'sly' => 'selayar',
        'sm' => 'samoano',
        'sma' => 'sami del sud',
        'smj' => 'sami di Lule',
        'smn' => 'sami di Inari',
        'sms' => 'sami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somalo',
        'sog' => 'sogdiano',
        'sq' => 'albanese',
        'sr' => 'serbo',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'swati',
        'ssy' => 'saho',
        'st' => 'sotho del sud',
        'stq' => 'saterfriesisch',
        'str' => 'salish straits',
        'su' => 'sundanese',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumero',
        'sv' => 'svedese',
        'sw' => 'swahili',
        'swb' => 'comoriano',
        'syc' => 'siriaco classico',
        'syr' => 'siriaco',
        'szl' => 'slesiano',
        'ta' => 'tamil',
        'tce' => 'tutchone meridionale',
        'tcy' => 'tulu',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tagico',
        'tgx' => 'tagish',
        'th' => 'thailandese',
        'tht' => 'tahltan',
        'ti' => 'tigrino',
        'tig' => 'tigre',
        'tiv' => 'tiv',
        'tk' => 'turcomanno',
        'tkl' => 'tokelau',
        'tkr' => 'tsakhur',
        'tl' => 'tagalog',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tly' => 'taliscio',
        'tmh' => 'tamashek',
        'tn' => 'tswana',
        'to' => 'tongano',
        'tog' => 'nyasa del Tonga',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turco',
        'tru' => 'turoyo',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsd' => 'zaconico',
        'tsi' => 'tsimshian',
        'tt' => 'tataro',
        'ttm' => 'tutchone settentrionale',
        'ttt' => 'tat islamico',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'ci',
        'twq' => 'tasawaq',
        'ty' => 'taitiano',
        'tyv' => 'tuvinian',
        'tzm' => 'tamazight',
        'udm' => 'udmurt',
        'ug' => 'uiguro',
        'uga' => 'ugaritico',
        'uk' => 'ucraino',
        'umb' => 'mbundu',
        'ur' => 'urdu',
        'uz' => 'uzbeco',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'veneto',
        'vep' => 'vepso',
        'vi' => 'vietnamita',
        'vls' => 'fiammingo occidentale',
        'vo' => 'volapük',
        'vot' => 'voto',
        'vro' => 'võro',
        'vun' => 'vunjo',
        'wa' => 'vallone',
        'wae' => 'walser',
        'wal' => 'walamo',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'wolof',
        'wuu' => 'wu',
        'xal' => 'kalmyk',
        'xh' => 'xhosa',
        'xmf' => 'mengrelio',
        'xog' => 'soga',
        'yao' => 'yao (bantu)',
        'yap' => 'yapese',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'yiddish',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'cantonese',
        'za' => 'zhuang',
        'zap' => 'zapotec',
        'zbl' => 'blissymbol',
        'zea' => 'zelandese',
        'zen' => 'zenaga',
        'zgh' => 'tamazight del Marocco standard',
        'zh' => 'cinese',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabo moderno standard',
        'de_AT' => 'tedesco austriaco',
        'de_CH' => 'alto tedesco svizzero',
        'en_AU' => 'inglese australiano',
        'en_CA' => 'inglese canadese',
        'en_GB' => 'inglese britannico',
        'en_US' => 'inglese americano',
        'es_419' => 'spagnolo latinoamericano',
        'es_ES' => 'spagnolo europeo',
        'es_MX' => 'spagnolo messicano',
        'fa_AF' => 'dari',
        'fr_CA' => 'francese canadese',
        'fr_CH' => 'francese svizzero',
        'nds_NL' => 'basso tedesco olandese',
        'nl_BE' => 'fiammingo',
        'pt_BR' => 'portoghese brasiliano',
        'pt_PT' => 'portoghese europeo',
        'ro_MD' => 'moldavo',
        'sw_CD' => 'swahili del Congo',
        'zh_Hans' => 'cinese semplificato',
        'zh_Hant' => 'cinese tradizionale',
    ],
];
