<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Idiramu ryo muri Leta Zunze Ubumwe z’Abarabu',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Ikwanza ryo muri Angola',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Idolari ryo muri Ositaraliya',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Idinari ry’iribahireyini',
        ],
        'BIF' => [
            0 => 'FBu',
            1 => 'Ifaranga ry’Uburundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ipula ryo muri Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Idolari rya Kanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Ifaranga rya Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Ifaranga ry’Ubusuwisi',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Iyuwani ryo mu Bushinwa',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Irikaboveridiyano ryo muri Esikudo',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Ifaranga ryo muri Jibuti',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Idinari ryo muri Alijeriya',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Ipawundi rya Misiri',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Irinakufa ryo muri Eritereya',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ibiri ryo muri Etiyopiya',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Iyero',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Ipawundi ryo mu Bwongereza',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Icedi ryo muri Gana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Idalasi ryo muri Gambiya',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Ifaranga ryo muri Gineya',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Irupiya ryo mu Buhindi',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Iyeni ry’Ubuyapani',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Ishilingi rya Kenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Ifaranga rya Komore',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Idolari rya Liberiya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Iloti ryo muro Lesoto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Idinari rya Libiya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Idiramu ryo muri Maroke',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Iriyari ryo muri Madagasikari',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya ryo muri Moritaniya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya ryo muri Moritaniya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Irupiya ryo mu birwa bya Morise',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Ikwaca ryo muri Malawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Irimetikali ryo muri Mozambike',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Idolari rya Namibiya',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Inayira ryo muri Nijeriya',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ifaranga ry’u Rwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Iriyari ryo muri Arabiya Sawudite',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Irupiya ryo mu birwa bya Sayisheli',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Ipawundi rya Sudani',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Ipawundi rya Sente Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Ilewone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Ishilingi ryo muri Somaliya',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Idobura ryo muri Sawotome na Perensipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Idobura ryo muri Sawotome na Perensipe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Ililangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Idinari ryo muri Tuniziya',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Ishilingi rya Tanzaniya',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ishilingi ry’Ubugande',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Idolari ry’abanyamerika',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Irandi ryo muri Afurika y’Epfo',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Ikwaca ryo muri Zambiya (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Ikwaca ryo muri Zambiya',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Idolari ryo muri Zimbabwe',
        ],
    ],
];
