<?php

return [
    'Names' => [
        'AE' => 'Dei sameinte arabiske emirata',
        'AT' => 'Austerrike',
        'BY' => 'Kviterussland',
        'CC' => 'Kokosøyane',
        'CD' => 'Kongo-Kinshasa',
        'CF' => 'Den sentralafrikanske republikken',
        'CI' => 'Elfenbeinskysten',
        'CK' => 'Cookøyane',
        'DO' => 'Den dominikanske republikken',
        'FK' => 'Falklandsøyane',
        'FO' => 'Færøyane',
        'GS' => 'Sør-Georgia og Sør-Sandwichøyane',
        'HM' => 'Heardøya og McDonaldøyane',
        'KM' => 'Komorane',
        'KY' => 'Caymanøyane',
        'LU' => 'Luxembourg',
        'MH' => 'Marshalløyane',
        'MP' => 'Nord-Marianane',
        'MV' => 'Maldivane',
        'NO' => 'Noreg',
        'PH' => 'Filippinane',
        'PN' => 'Pitcairn',
        'SB' => 'Salomonøyane',
        'SC' => 'Seychellane',
        'SH' => 'Saint Helena',
        'TC' => 'Turks- og Caicosøyane',
        'TF' => 'Dei franske sørterritoria',
        'TL' => 'Aust-Timor',
        'UM' => 'USAs ytre småøyar',
        'VC' => 'St. Vincent og Grenadinane',
        'VG' => 'Dei britiske Jomfruøyane',
        'VI' => 'Dei amerikanske Jomfruøyane',
    ],
];
