<?php

return [
    'Names' => [
        'af' => 'afrikansa',
        'af_NA' => 'afrikansa (Namibio)',
        'af_ZA' => 'afrikansa (Sud-Afriko)',
        'am' => 'amhara',
        'am_ET' => 'amhara (Etiopujo)',
        'ar' => 'araba',
        'ar_001' => 'araba (Mondo)',
        'ar_AE' => 'araba (Unuiĝintaj Arabaj Emirlandoj)',
        'ar_BH' => 'araba (Barejno)',
        'ar_DJ' => 'araba (Ĝibutio)',
        'ar_DZ' => 'araba (Alĝerio)',
        'ar_EG' => 'araba (Egipto)',
        'ar_EH' => 'araba (Okcidenta Saharo)',
        'ar_ER' => 'araba (Eritreo)',
        'ar_IL' => 'araba (Israelo)',
        'ar_IQ' => 'araba (Irako)',
        'ar_JO' => 'araba (Jordanio)',
        'ar_KM' => 'araba (Komoroj)',
        'ar_KW' => 'araba (Kuvajto)',
        'ar_LB' => 'araba (Libano)',
        'ar_LY' => 'araba (Libio)',
        'ar_MA' => 'araba (Maroko)',
        'ar_MR' => 'araba (Maŭritanujo)',
        'ar_OM' => 'araba (Omano)',
        'ar_QA' => 'araba (Kataro)',
        'ar_SA' => 'araba (Saŭda Arabujo)',
        'ar_SD' => 'araba (Sudano)',
        'ar_SO' => 'araba (Somalujo)',
        'ar_SY' => 'araba (Sirio)',
        'ar_TD' => 'araba (Ĉado)',
        'ar_TN' => 'araba (Tunizio)',
        'ar_YE' => 'araba (Jemeno)',
        'as' => 'asama',
        'as_IN' => 'asama (Hindujo)',
        'az' => 'azerbajĝana',
        'az_AZ' => 'azerbajĝana (Azerbajĝano)',
        'be' => 'belorusa',
        'be_BY' => 'belorusa (Belorusujo)',
        'bg' => 'bulgara',
        'bg_BG' => 'bulgara (Bulgarujo)',
        'bn' => 'bengala',
        'bn_BD' => 'bengala (Bangladeŝo)',
        'bn_IN' => 'bengala (Hindujo)',
        'bo' => 'tibeta',
        'bo_CN' => 'tibeta (Ĉinujo)',
        'bo_IN' => 'tibeta (Hindujo)',
        'br' => 'bretona',
        'br_FR' => 'bretona (Francujo)',
        'bs' => 'bosnia',
        'bs_BA' => 'bosnia (Bosnio-Hercegovino)',
        'ca' => 'kataluna',
        'ca_AD' => 'kataluna (Andoro)',
        'ca_ES' => 'kataluna (Hispanujo)',
        'ca_FR' => 'kataluna (Francujo)',
        'ca_IT' => 'kataluna (Italujo)',
        'cs' => 'ĉeĥa',
        'cs_CZ' => 'ĉeĥa (Ĉeĥujo)',
        'cy' => 'kimra',
        'cy_GB' => 'kimra (Unuiĝinta Reĝlando)',
        'da' => 'dana',
        'da_DK' => 'dana (Danujo)',
        'da_GL' => 'dana (Gronlando)',
        'de' => 'germana',
        'de_AT' => 'germana (Aŭstrujo)',
        'de_BE' => 'germana (Belgujo)',
        'de_CH' => 'germana (Svisujo)',
        'de_DE' => 'germana (Germanujo)',
        'de_IT' => 'germana (Italujo)',
        'de_LI' => 'germana (Liĥtenŝtejno)',
        'de_LU' => 'germana (Luksemburgo)',
        'dz' => 'dzonko',
        'dz_BT' => 'dzonko (Butano)',
        'el' => 'greka',
        'el_CY' => 'greka (Kipro)',
        'el_GR' => 'greka (Grekujo)',
        'en' => 'angla',
        'en_001' => 'angla (Mondo)',
        'en_AE' => 'angla (Unuiĝintaj Arabaj Emirlandoj)',
        'en_AG' => 'angla (Antigvo-Barbudo)',
        'en_AI' => 'angla (Angvilo)',
        'en_AT' => 'angla (Aŭstrujo)',
        'en_AU' => 'angla (Aŭstralio)',
        'en_BB' => 'angla (Barbado)',
        'en_BE' => 'angla (Belgujo)',
        'en_BI' => 'angla (Burundo)',
        'en_BM' => 'angla (Bermudoj)',
        'en_BS' => 'angla (Bahamoj)',
        'en_BW' => 'angla (Bocvano)',
        'en_BZ' => 'angla (Belizo)',
        'en_CA' => 'angla (Kanado)',
        'en_CH' => 'angla (Svisujo)',
        'en_CK' => 'angla (Kukinsuloj)',
        'en_CM' => 'angla (Kameruno)',
        'en_CY' => 'angla (Kipro)',
        'en_DE' => 'angla (Germanujo)',
        'en_DK' => 'angla (Danujo)',
        'en_DM' => 'angla (Dominiko)',
        'en_ER' => 'angla (Eritreo)',
        'en_FI' => 'angla (Finnlando)',
        'en_FJ' => 'angla (Fiĝoj)',
        'en_FM' => 'angla (Mikronezio)',
        'en_GB' => 'angla (Unuiĝinta Reĝlando)',
        'en_GD' => 'angla (Grenado)',
        'en_GH' => 'angla (Ganao)',
        'en_GI' => 'angla (Ĝibraltaro)',
        'en_GM' => 'angla (Gambio)',
        'en_GU' => 'angla (Gvamo)',
        'en_GY' => 'angla (Gujano)',
        'en_IE' => 'angla (Irlando)',
        'en_IL' => 'angla (Israelo)',
        'en_IN' => 'angla (Hindujo)',
        'en_IO' => 'angla (Brita Hindoceana Teritorio)',
        'en_JM' => 'angla (Jamajko)',
        'en_KE' => 'angla (Kenjo)',
        'en_KI' => 'angla (Kiribato)',
        'en_KN' => 'angla (Sent-Kristofo kaj Neviso)',
        'en_KY' => 'angla (Kejmanoj)',
        'en_LC' => 'angla (Sent-Lucio)',
        'en_LR' => 'angla (Liberio)',
        'en_LS' => 'angla (Lesoto)',
        'en_MG' => 'angla (Madagaskaro)',
        'en_MH' => 'angla (Marŝaloj)',
        'en_MP' => 'angla (Nord-Marianoj)',
        'en_MT' => 'angla (Malto)',
        'en_MU' => 'angla (Maŭricio)',
        'en_MV' => 'angla (Maldivoj)',
        'en_MW' => 'angla (Malavio)',
        'en_MY' => 'angla (Malajzio)',
        'en_NA' => 'angla (Namibio)',
        'en_NF' => 'angla (Norfolkinsulo)',
        'en_NG' => 'angla (Niĝerio)',
        'en_NL' => 'angla (Nederlando)',
        'en_NR' => 'angla (Nauro)',
        'en_NU' => 'angla (Niuo)',
        'en_NZ' => 'angla (Nov-Zelando)',
        'en_PG' => 'angla (Papuo-Nov-Gvineo)',
        'en_PH' => 'angla (Filipinoj)',
        'en_PK' => 'angla (Pakistano)',
        'en_PN' => 'angla (Pitkarna Insulo)',
        'en_PR' => 'angla (Puerto-Riko)',
        'en_PW' => 'angla (Belaŭo)',
        'en_RW' => 'angla (Ruando)',
        'en_SB' => 'angla (Salomonoj)',
        'en_SC' => 'angla (Sejŝeloj)',
        'en_SD' => 'angla (Sudano)',
        'en_SE' => 'angla (Svedujo)',
        'en_SG' => 'angla (Singapuro)',
        'en_SH' => 'angla (Sent-Heleno)',
        'en_SI' => 'angla (Slovenujo)',
        'en_SL' => 'angla (Siera-Leono)',
        'en_SZ' => 'angla (Svazilando)',
        'en_TO' => 'angla (Tongo)',
        'en_TT' => 'angla (Trinidado kaj Tobago)',
        'en_TV' => 'angla (Tuvalo)',
        'en_TZ' => 'angla (Tanzanio)',
        'en_UG' => 'angla (Ugando)',
        'en_UM' => 'angla (Usonaj malgrandaj insuloj)',
        'en_US' => 'angla (Usono)',
        'en_VC' => 'angla (Sent-Vincento kaj la Grenadinoj)',
        'en_VG' => 'angla (Britaj Virgulininsuloj)',
        'en_VI' => 'angla (Usonaj Virgulininsuloj)',
        'en_VU' => 'angla (Vanuatuo)',
        'en_WS' => 'angla (Samoo)',
        'en_ZA' => 'angla (Sud-Afriko)',
        'en_ZM' => 'angla (Zambio)',
        'en_ZW' => 'angla (Zimbabvo)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Mondo)',
        'es' => 'hispana',
        'es_AR' => 'hispana (Argentino)',
        'es_BO' => 'hispana (Bolivio)',
        'es_BR' => 'hispana (Brazilo)',
        'es_BZ' => 'hispana (Belizo)',
        'es_CL' => 'hispana (Ĉilio)',
        'es_CO' => 'hispana (Kolombio)',
        'es_CR' => 'hispana (Kostariko)',
        'es_CU' => 'hispana (Kubo)',
        'es_DO' => 'hispana (Domingo)',
        'es_EC' => 'hispana (Ekvadoro)',
        'es_ES' => 'hispana (Hispanujo)',
        'es_GQ' => 'hispana (Ekvatora Gvineo)',
        'es_GT' => 'hispana (Gvatemalo)',
        'es_HN' => 'hispana (Honduro)',
        'es_MX' => 'hispana (Meksiko)',
        'es_NI' => 'hispana (Nikaragvo)',
        'es_PA' => 'hispana (Panamo)',
        'es_PE' => 'hispana (Peruo)',
        'es_PH' => 'hispana (Filipinoj)',
        'es_PR' => 'hispana (Puerto-Riko)',
        'es_PY' => 'hispana (Paragvajo)',
        'es_SV' => 'hispana (Salvadoro)',
        'es_US' => 'hispana (Usono)',
        'es_UY' => 'hispana (Urugvajo)',
        'es_VE' => 'hispana (Venezuelo)',
        'et' => 'estona',
        'et_EE' => 'estona (Estonujo)',
        'eu' => 'eŭska',
        'eu_ES' => 'eŭska (Hispanujo)',
        'fa' => 'persa',
        'fa_AF' => 'persa (Afganujo)',
        'fa_IR' => 'persa (Irano)',
        'fi' => 'finna',
        'fi_FI' => 'finna (Finnlando)',
        'fo' => 'feroa',
        'fo_DK' => 'feroa (Danujo)',
        'fo_FO' => 'feroa (Ferooj)',
        'fr' => 'franca',
        'fr_BE' => 'franca (Belgujo)',
        'fr_BF' => 'franca (Burkino)',
        'fr_BI' => 'franca (Burundo)',
        'fr_BJ' => 'franca (Benino)',
        'fr_CA' => 'franca (Kanado)',
        'fr_CF' => 'franca (Centr-Afrika Respubliko)',
        'fr_CG' => 'franca (Kongolo)',
        'fr_CH' => 'franca (Svisujo)',
        'fr_CI' => 'franca (Ebur-Bordo)',
        'fr_CM' => 'franca (Kameruno)',
        'fr_DJ' => 'franca (Ĝibutio)',
        'fr_DZ' => 'franca (Alĝerio)',
        'fr_FR' => 'franca (Francujo)',
        'fr_GA' => 'franca (Gabono)',
        'fr_GF' => 'franca (Franca Gviano)',
        'fr_GN' => 'franca (Gvineo)',
        'fr_GP' => 'franca (Gvadelupo)',
        'fr_GQ' => 'franca (Ekvatora Gvineo)',
        'fr_HT' => 'franca (Haitio)',
        'fr_KM' => 'franca (Komoroj)',
        'fr_LU' => 'franca (Luksemburgo)',
        'fr_MA' => 'franca (Maroko)',
        'fr_MC' => 'franca (Monako)',
        'fr_MG' => 'franca (Madagaskaro)',
        'fr_ML' => 'franca (Malio)',
        'fr_MQ' => 'franca (Martiniko)',
        'fr_MR' => 'franca (Maŭritanujo)',
        'fr_MU' => 'franca (Maŭricio)',
        'fr_NC' => 'franca (Nov-Kaledonio)',
        'fr_NE' => 'franca (Niĝero)',
        'fr_PF' => 'franca (Franca Polinezio)',
        'fr_PM' => 'franca (Sent-Piero kaj Mikelono)',
        'fr_RE' => 'franca (Reunio)',
        'fr_RW' => 'franca (Ruando)',
        'fr_SC' => 'franca (Sejŝeloj)',
        'fr_SN' => 'franca (Senegalo)',
        'fr_SY' => 'franca (Sirio)',
        'fr_TD' => 'franca (Ĉado)',
        'fr_TG' => 'franca (Togolo)',
        'fr_TN' => 'franca (Tunizio)',
        'fr_VU' => 'franca (Vanuatuo)',
        'fr_WF' => 'franca (Valiso kaj Futuno)',
        'fr_YT' => 'franca (Majoto)',
        'fy' => 'frisa',
        'fy_NL' => 'frisa (Nederlando)',
        'ga' => 'irlanda',
        'ga_GB' => 'irlanda (Unuiĝinta Reĝlando)',
        'ga_IE' => 'irlanda (Irlando)',
        'gd' => 'gaela',
        'gd_GB' => 'gaela (Unuiĝinta Reĝlando)',
        'gl' => 'galega',
        'gl_ES' => 'galega (Hispanujo)',
        'gu' => 'guĝarata',
        'gu_IN' => 'guĝarata (Hindujo)',
        'ha' => 'haŭsa',
        'ha_GH' => 'haŭsa (Ganao)',
        'ha_NE' => 'haŭsa (Niĝero)',
        'ha_NG' => 'haŭsa (Niĝerio)',
        'he' => 'hebrea',
        'he_IL' => 'hebrea (Israelo)',
        'hi' => 'hinda',
        'hi_IN' => 'hinda (Hindujo)',
        'hr' => 'kroata',
        'hr_BA' => 'kroata (Bosnio-Hercegovino)',
        'hr_HR' => 'kroata (Kroatujo)',
        'hu' => 'hungara',
        'hu_HU' => 'hungara (Hungarujo)',
        'hy' => 'armena',
        'hy_AM' => 'armena (Armenujo)',
        'ia' => 'interlingvao',
        'ia_001' => 'interlingvao (Mondo)',
        'id' => 'indonezia',
        'id_ID' => 'indonezia (Indonezio)',
        'is' => 'islanda',
        'is_IS' => 'islanda (Islando)',
        'it' => 'itala',
        'it_CH' => 'itala (Svisujo)',
        'it_IT' => 'itala (Italujo)',
        'it_SM' => 'itala (San-Marino)',
        'it_VA' => 'itala (Vatikano)',
        'ja' => 'japana',
        'ja_JP' => 'japana (Japanujo)',
        'jv' => 'java',
        'jv_ID' => 'java (Indonezio)',
        'ka' => 'kartvela',
        'ka_GE' => 'kartvela (Kartvelujo)',
        'kk' => 'kazaĥa',
        'kk_KZ' => 'kazaĥa (Kazaĥstano)',
        'kl' => 'gronlanda',
        'kl_GL' => 'gronlanda (Gronlando)',
        'km' => 'kmera',
        'km_KH' => 'kmera (Kamboĝo)',
        'kn' => 'kanara',
        'kn_IN' => 'kanara (Hindujo)',
        'ko' => 'korea',
        'ko_KP' => 'korea (Nord-Koreo)',
        'ko_KR' => 'korea (Sud-Koreo)',
        'ks' => 'kaŝmira',
        'ks_IN' => 'kaŝmira (Hindujo)',
        'ku' => 'kurda',
        'ku_TR' => 'kurda (Turkujo)',
        'ky' => 'kirgiza',
        'ky_KG' => 'kirgiza (Kirgizistano)',
        'lb' => 'luksemburga',
        'lb_LU' => 'luksemburga (Luksemburgo)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angolo)',
        'ln_CF' => 'lingala (Centr-Afrika Respubliko)',
        'ln_CG' => 'lingala (Kongolo)',
        'lo' => 'laŭa',
        'lo_LA' => 'laŭa (Laoso)',
        'lt' => 'litova',
        'lt_LT' => 'litova (Litovujo)',
        'lv' => 'latva',
        'lv_LV' => 'latva (Latvujo)',
        'mg' => 'malagasa',
        'mg_MG' => 'malagasa (Madagaskaro)',
        'mi' => 'maoria',
        'mi_NZ' => 'maoria (Nov-Zelando)',
        'mk' => 'makedona',
        'ml' => 'malajalama',
        'ml_IN' => 'malajalama (Hindujo)',
        'mn' => 'mongola',
        'mn_MN' => 'mongola (Mongolujo)',
        'mr' => 'marata',
        'mr_IN' => 'marata (Hindujo)',
        'ms' => 'malaja',
        'ms_BN' => 'malaja (Brunejo)',
        'ms_ID' => 'malaja (Indonezio)',
        'ms_MY' => 'malaja (Malajzio)',
        'ms_SG' => 'malaja (Singapuro)',
        'mt' => 'malta',
        'mt_MT' => 'malta (Malto)',
        'my' => 'birma',
        'my_MM' => 'birma (Mjanmao)',
        'nb' => 'dannorvega',
        'nb_NO' => 'dannorvega (Norvegujo)',
        'nb_SJ' => 'dannorvega (Svalbardo kaj Jan-Majen-insulo)',
        'ne' => 'nepala',
        'ne_IN' => 'nepala (Hindujo)',
        'ne_NP' => 'nepala (Nepalo)',
        'nl' => 'nederlanda',
        'nl_AW' => 'nederlanda (Arubo)',
        'nl_BE' => 'nederlanda (Belgujo)',
        'nl_NL' => 'nederlanda (Nederlando)',
        'nl_SR' => 'nederlanda (Surinamo)',
        'nn' => 'novnorvega',
        'nn_NO' => 'novnorvega (Norvegujo)',
        'no' => 'norvega',
        'no_NO' => 'norvega (Norvegujo)',
        'om' => 'oroma',
        'om_ET' => 'oroma (Etiopujo)',
        'om_KE' => 'oroma (Kenjo)',
        'or' => 'orijo',
        'or_IN' => 'orijo (Hindujo)',
        'pa' => 'panĝaba',
        'pa_IN' => 'panĝaba (Hindujo)',
        'pa_PK' => 'panĝaba (Pakistano)',
        'pl' => 'pola',
        'pl_PL' => 'pola (Pollando)',
        'ps' => 'paŝtoa',
        'ps_AF' => 'paŝtoa (Afganujo)',
        'ps_PK' => 'paŝtoa (Pakistano)',
        'pt' => 'portugala',
        'pt_AO' => 'portugala (Angolo)',
        'pt_BR' => 'portugala (Brazilo)',
        'pt_CH' => 'portugala (Svisujo)',
        'pt_CV' => 'portugala (Kabo-Verdo)',
        'pt_GQ' => 'portugala (Ekvatora Gvineo)',
        'pt_GW' => 'portugala (Gvineo-Bisaŭo)',
        'pt_LU' => 'portugala (Luksemburgo)',
        'pt_MZ' => 'portugala (Mozambiko)',
        'pt_PT' => 'portugala (Portugalujo)',
        'pt_ST' => 'portugala (Sao-Tomeo kaj Principeo)',
        'qu' => 'keĉua',
        'qu_BO' => 'keĉua (Bolivio)',
        'qu_EC' => 'keĉua (Ekvadoro)',
        'qu_PE' => 'keĉua (Peruo)',
        'rm' => 'romanĉa',
        'rm_CH' => 'romanĉa (Svisujo)',
        'rn' => 'burunda',
        'rn_BI' => 'burunda (Burundo)',
        'ro' => 'rumana',
        'ro_MD' => 'rumana (Moldavujo)',
        'ro_RO' => 'rumana (Rumanujo)',
        'ru' => 'rusa',
        'ru_BY' => 'rusa (Belorusujo)',
        'ru_KG' => 'rusa (Kirgizistano)',
        'ru_KZ' => 'rusa (Kazaĥstano)',
        'ru_MD' => 'rusa (Moldavujo)',
        'ru_RU' => 'rusa (Rusujo)',
        'ru_UA' => 'rusa (Ukrajno)',
        'rw' => 'ruanda',
        'rw_RW' => 'ruanda (Ruando)',
        'sa' => 'sanskrito',
        'sa_IN' => 'sanskrito (Hindujo)',
        'sd' => 'sinda',
        'sd_IN' => 'sinda (Hindujo)',
        'sd_PK' => 'sinda (Pakistano)',
        'sg' => 'sangoa',
        'sg_CF' => 'sangoa (Centr-Afrika Respubliko)',
        'sh' => 'serbo-Kroata',
        'sh_BA' => 'serbo-Kroata (Bosnio-Hercegovino)',
        'si' => 'sinhala',
        'si_LK' => 'sinhala (Sri-Lanko)',
        'sk' => 'slovaka',
        'sk_SK' => 'slovaka (Slovakujo)',
        'sl' => 'slovena',
        'sl_SI' => 'slovena (Slovenujo)',
        'sn' => 'ŝona',
        'sn_ZW' => 'ŝona (Zimbabvo)',
        'so' => 'somala',
        'so_DJ' => 'somala (Ĝibutio)',
        'so_ET' => 'somala (Etiopujo)',
        'so_KE' => 'somala (Kenjo)',
        'so_SO' => 'somala (Somalujo)',
        'sq' => 'albana',
        'sq_AL' => 'albana (Albanujo)',
        'sr' => 'serba',
        'sr_BA' => 'serba (Bosnio-Hercegovino)',
        'su' => 'sunda',
        'su_ID' => 'sunda (Indonezio)',
        'sv' => 'sveda',
        'sv_FI' => 'sveda (Finnlando)',
        'sv_SE' => 'sveda (Svedujo)',
        'sw' => 'svahila',
        'sw_KE' => 'svahila (Kenjo)',
        'sw_TZ' => 'svahila (Tanzanio)',
        'sw_UG' => 'svahila (Ugando)',
        'ta' => 'tamila',
        'ta_IN' => 'tamila (Hindujo)',
        'ta_LK' => 'tamila (Sri-Lanko)',
        'ta_MY' => 'tamila (Malajzio)',
        'ta_SG' => 'tamila (Singapuro)',
        'te' => 'telugua',
        'te_IN' => 'telugua (Hindujo)',
        'tg' => 'taĝika',
        'tg_TJ' => 'taĝika (Taĝikujo)',
        'th' => 'taja',
        'th_TH' => 'taja (Tajlando)',
        'ti' => 'tigraja',
        'ti_ER' => 'tigraja (Eritreo)',
        'ti_ET' => 'tigraja (Etiopujo)',
        'tk' => 'turkmena',
        'tk_TM' => 'turkmena (Turkmenujo)',
        'tl' => 'tagaloga',
        'tl_PH' => 'tagaloga (Filipinoj)',
        'to' => 'tongaa',
        'to_TO' => 'tongaa (Tongo)',
        'tr' => 'turka',
        'tr_CY' => 'turka (Kipro)',
        'tr_TR' => 'turka (Turkujo)',
        'tt' => 'tatara',
        'tt_RU' => 'tatara (Rusujo)',
        'ug' => 'ujgura',
        'ug_CN' => 'ujgura (Ĉinujo)',
        'uk' => 'ukraina',
        'uk_UA' => 'ukraina (Ukrajno)',
        'ur' => 'urduo',
        'ur_IN' => 'urduo (Hindujo)',
        'ur_PK' => 'urduo (Pakistano)',
        'uz' => 'uzbeka',
        'uz_AF' => 'uzbeka (Afganujo)',
        'uz_UZ' => 'uzbeka (Uzbekujo)',
        'vi' => 'vjetnama',
        'vi_VN' => 'vjetnama (Vjetnamo)',
        'wo' => 'volofa',
        'wo_SN' => 'volofa (Senegalo)',
        'xh' => 'ksosa',
        'xh_ZA' => 'ksosa (Sud-Afriko)',
        'yi' => 'jida',
        'yi_001' => 'jida (Mondo)',
        'yo' => 'joruba',
        'yo_BJ' => 'joruba (Benino)',
        'yo_NG' => 'joruba (Niĝerio)',
        'zh' => 'ĉina',
        'zh_CN' => 'ĉina (Ĉinujo)',
        'zh_SG' => 'ĉina (Singapuro)',
        'zh_TW' => 'ĉina (Tajvano)',
        'zu' => 'zulua',
        'zu_ZA' => 'zulua (Sud-Afriko)',
    ],
];
