<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Aghb' => 'Qoraalka Luuqada Caucasian Albanian',
        'Ahom' => 'Dadka Ahom',
        'Arab' => 'Carabi',
        'Aran' => 'Farta Luuqada Faarsiga',
        'Armi' => 'Luuqada Imperial Aramaic',
        'Armn' => 'Armeeniyaan',
        'Avst' => 'Luuqada Avestan',
        'Bali' => 'Baliniis',
        'Bamu' => 'Bamum',
        'Bass' => 'Qoraalka Vah',
        'Batk' => 'Batak',
        'Beng' => 'Baangla',
        'Bhks' => 'Qoraalka Bhaiksuki',
        'Bopo' => 'Bobomofo',
        'Brah' => 'Dhirta Brahmi',
        'Brai' => 'Qoraalka Indhoolaha',
        'Bugi' => 'Luuqada Buginiiska',
        'Buhd' => 'Luuqada Buhid',
        'Cakm' => 'Jakma',
        'Cans' => 'Qoraalka Luuqada Aborajiinka ee Kanada',
        'Cari' => 'Luuqada kaariyaanka',
        'Cham' => 'Jam',
        'Cher' => 'Jerokee',
        'Chrs' => 'Luuqada Korasmiyaanka',
        'Copt' => 'Dadka Kotiga',
        'Cprt' => 'sibraas dhalad ah',
        'Cyrl' => 'Siriylik',
        'Deva' => 'Dhefangaari',
        'Diak' => 'Luuqadaha Dives Akuru',
        'Dogr' => 'Dadka Dogra',
        'Dsrt' => 'Gobalka Deseret',
        'Dupl' => 'Qoraalka Duployan shorthand',
        'Egyp' => 'Fartii hore ee Masaarida',
        'Elba' => 'Magaalada Elbasan',
        'Elym' => 'Qoraalka Elymaic',
        'Ethi' => 'Itoobiya',
        'Geor' => 'Joorjiya',
        'Glag' => 'Qoraalka Glagolitic',
        'Gong' => 'Gumjala Gondi',
        'Gonm' => 'Qoraalka Masaram Gondi',
        'Goth' => 'Dadka Gothic',
        'Gran' => 'Qoraalka Grantha',
        'Grek' => 'Giriik',
        'Gujr' => 'Gujaraati',
        'Guru' => 'Luuqada gujarati',
        'Hanb' => 'Han iyo Bobomofo',
        'Hang' => 'Hanguul',
        'Hani' => 'Han',
        'Hano' => 'Qoraalka Hanunoo',
        'Hans' => 'La fududeeyay',
        'Hant' => 'Hore',
        'Hatr' => 'Qoraalka Hatran',
        'Hebr' => 'Cibraani',
        'Hira' => 'Hiragana',
        'Hluw' => 'Qoraalka Anatolian Hieroglyphs',
        'Hmng' => 'Hmonga pahawh',
        'Hmnp' => 'Hmonga Nyiakeng Puachue',
        'Hrkt' => 'Qoraalka Xuruufta Jabaaniiska',
        'Hung' => 'Hangariyaankii Hore',
        'Ital' => 'Itaaliggii Hore',
        'Jamo' => 'Jaamo',
        'Java' => 'Jafaniis',
        'Jpan' => 'Jabaaniis',
        'Kali' => 'Kayah LI',
        'Kana' => 'Katakaana',
        'Khar' => 'Koraalka kharooshi',
        'Khmr' => 'Khamer',
        'Khoj' => 'Qoraalka Khojki',
        'Kits' => 'Qoraalka yar ee Khitan',
        'Knda' => 'Kanada',
        'Kore' => 'Kuuriyaan',
        'Kthi' => 'kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Dalka Lao',
        'Latn' => 'Laatiin',
        'Lepc' => 'Lebja',
        'Limb' => 'Limbu',
        'Lina' => 'Nidaamka qoraalka Linear A',
        'Linb' => 'Nidaamka qoraalka Linear B',
        'Lisu' => 'Wabiga Fraser',
        'Lyci' => 'Lyciantii Hore',
        'Lydi' => 'Lydian',
        'Mahj' => 'Mahajani',
        'Maka' => 'Makasar',
        'Mand' => 'Luuqada Mandaean',
        'Mani' => 'Manichaean',
        'Marc' => 'Marchen',
        'Medf' => 'Madefaidrin',
        'Mend' => 'Mende',
        'Merc' => 'Meroitic Curve',
        'Mero' => 'Meroitic',
        'Mlym' => 'Maalayalam',
        'Modi' => 'Moodi',
        'Mong' => 'Mongooliyaan',
        'Mroo' => 'Mro',
        'Mtei' => 'Qoraalka Luuqada Meitei',
        'Mult' => 'Multani',
        'Mymr' => 'Mayanmaar',
        'Nand' => 'Nandinagari',
        'Narb' => 'Carabiyadii Hore ee Wuqooye',
        'Nbat' => 'Nabataean',
        'Newa' => 'Newa',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Jiki',
        'Orkh' => 'Orkhon',
        'Orya' => 'Oodhiya',
        'Osge' => 'Osage',
        'Osma' => 'Osmanya',
        'Palm' => 'Palmyrene',
        'Pauc' => 'Baaw Sin Haaw',
        'Perm' => 'Permic gii hore',
        'Phag' => 'Qoraalka Phags-pa',
        'Phli' => 'Qoraaladii hore ee Pahlavi',
        'Phlp' => 'Qoraalka midig laga bilaabo ee faarsiyiintii',
        'Phnx' => 'Luuqada Phoenicianka',
        'Plrd' => 'Shibanaha',
        'Prti' => 'Qoraalka Parthian',
        'Qaag' => 'Qoraalka Sawgiga',
        'Rjng' => 'Dadka Rejan',
        'Rohg' => 'Hanifi Rohingya',
        'Runr' => 'Dadka Rejang',
        'Samr' => 'Dadka Samaritan',
        'Sarb' => 'Crabiyaankii Hore ee Wuqooyi',
        'Saur' => 'Sawrashtra',
        'Sgnw' => 'Qaabka dhagoolka loola hadlo',
        'Shaw' => 'calaamad qoris',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'khudwadi',
        'Sinh' => 'Sinhaala',
        'Sogd' => 'Sogdiyaan',
        'Sogo' => 'Sogdiyaankii Hore',
        'Sora' => 'Qoraalka Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Dadka Sundaniiska',
        'Sylo' => 'Qoraalka Luuqada Sylheti',
        'Syrc' => 'Lahjada Syriac',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'Tai Lue cusub',
        'Taml' => 'Taamiil',
        'Tang' => 'Luuqada Tangut',
        'Tavt' => 'Farta lagu Qoro Luuqadaha Tai',
        'Telu' => 'Teeluguu',
        'Tfng' => 'Farta Tifinagh',
        'Tglg' => 'Luuqada Tagalog',
        'Thaa' => 'Daana',
        'Thai' => 'Taay',
        'Tibt' => 'Tibetaan',
        'Tirh' => 'Qoraalka Luuqada Maithili',
        'Ugar' => 'Luuqada Ugaritic',
        'Vaii' => 'Dadka Vai',
        'Wara' => 'Nidaamka Qoraalka Luuqada Ho',
        'Wcho' => 'Dadka wanjo',
        'Xpeo' => 'Faarsigii Hore',
        'Xsux' => 'Qoraalkii Hore ee dadka Sumaariyiinta ee dhulka mesobataamiya',
        'Yezi' => 'Dadka Yesiidiga',
        'Yiii' => 'Tiknoolajiyada Yi',
        'Zanb' => 'Xarafka laba jibaaran ee kujira Xarfaha Zanabazar',
        'Zinh' => 'Dhaxlay',
        'Zmth' => 'Aqoonsiga Xisaabta',
        'Zsye' => 'Calaamad Dareen Muujin',
        'Zsym' => 'Calaamado',
        'Zxxx' => 'Aan la qorin',
        'Zyyy' => 'Caadi ahaan',
    ],
];
