<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorran peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Arabiemiirikuntien dirhami',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afganistanin afgaani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afganistanin afgaani',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Albanian lek (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanian lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armenian dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Alankomaiden Antillien guldeni',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolan kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolan kwanza (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolan uusi kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolan kwanza reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentiinan austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Argentiinan ley-peso (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Argentiinan peso (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentiinan peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentiinan peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Itävallan šillinki',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'Australian dollari',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruban floriini',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbaidžanin manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaidžanin manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosnia-Hertsegovinan dinaari (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnia-Hertsegovinan vaihdettava markka',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Bosnia-Hertsegovinan uusi dinaari (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadosin dollari',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladeshin taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belgian vaihdettava frangi',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgian frangi',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belgian rahoitusfrangi',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgarian kova lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Bulgarian sosialistinen lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgarian lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Bulgarian lev (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahrainin dinaari',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundin frangi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermudan dollari',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunein dollari',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivian boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Bolivian boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Bolivian peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Bolivian mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Brasilian uusi cruzeiro (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Brasilian cruzado (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Brasilian cruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Brasilian real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Brasilian uusi cruzado (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brasilian cruzeiro (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Brasilian cruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahaman dollari',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhutanin ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Burman kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswanan pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Valko-Venäjän uusi rupla (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Valko-Venäjän rupla',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Valko-Venäjän rupla (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belizen dollari',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Kanadan dollari',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongon frangi',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'Sveitsin WIR-euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Sveitsin frangi',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'Sveitsin WIR-frangi',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Chilen escudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Chilen unidades de fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chilen peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Kiinan juan (offshore)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Kiinan kansanpankin dollari',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Kiinan juan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbian peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Kolumbian unidad de valor real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Costa Rican colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Serbian dinaari (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Tšekkoslovakian kova koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kuuban vaihdettava peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kuuban peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kap Verden escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Kyproksen punta',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Tšekin koruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Itä-Saksan markka',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Saksan markka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djiboutin frangi',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Tanskan kruunu',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikaanisen tasavallan peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algerian dinaari',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ecuadorin sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Ecuadorin UVC',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Viron kruunu',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptin punta',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrean nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Espanjan peseta (A-tili)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Espanjan peseta (vaihdettava tili)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Espanjan peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiopian birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'mk',
            1 => 'Suomen markka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fidžin dollari',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falklandinsaarten punta',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Ranskan frangi',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Englannin punta',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Georgian kuponkilari',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgian lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ghanan cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanan cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltarin punta',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambian dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinean frangi',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guinean syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Päiväntasaajan Guinean ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Kreikan drakma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemalan quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugalin Guinean escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guinea-Bissaun peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyanan dollari',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Hongkongin dollari',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Hondurasin lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Kroatian dinaari',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatian kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haitin gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Unkarin forintti',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesian rupia',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Irlannin punta',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Israelin punta',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'Israelin sekeli (1980–1985)',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Israelin uusi sekeli',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Intian rupia',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irakin dinaari',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iranin rial',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'Islannin kruunu (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islannin kruunu',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italian liira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaikan dollari',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordanian dinaari',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Japanin jeni',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenian šillinki',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgisian som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodžan riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komorien frangi',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Pohjois-Korean won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Etelä-Korean hwan (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Etelä-Korean won (1945–1953)',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'Etelä-Korean won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuwaitin dinaari',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Caymansaarten dollari',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazakstanin tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laosin kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libanonin punta',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lankan rupia',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberian dollari',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesothon loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Liettuan liti',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Liettuan talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Luxemburgin vaihdettava frangi',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Luxemburgin frangi',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Luxemburgin rahoitusfrangi',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Latvian lati',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Latvian rupla',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libyan dinaari',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokon dirhami',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokon frangi',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Monacon frangi',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Moldovan kuponkileu',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovan leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskarin ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madagaskarin frangi',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedonian denaari',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Makedonian dinaari (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malin frangi',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmarin kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolian tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macaon pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritanian ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritanian ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltan liira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltan punta',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritiuksen rupia',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'Malediivien rupia (1947–1981)',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Malediivien rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawin kwacha',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Meksikon peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Meksikon hopeapeso (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Meksikon UDI',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malesian ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mosambikin escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mosambikin metical (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mosambikin metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibian dollari',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigerian naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nicaraguan córdoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nicaraguan córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Alankomaiden guldeni',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norjan kruunu',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalin rupia',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'Uuden-Seelannin dollari',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omanin rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panaman balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Perun inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Perun sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Perun sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua-Uuden-Guinean kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filippiinien peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistanin rupia',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Puolan złoty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Puolan złoty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugalin escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguayn guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Qatarin rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rhodesian dollari',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Romanian leu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Romanian leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbian dinaari',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Venäjän rupla',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Venäjän rupla (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruandan frangi',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudi-Arabian rial',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Salomonsaarten dollari',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seychellien rupia',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Sudanin dinaari (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudanin punta',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Sudanin punta (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Ruotsin kruunu',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singaporen dollari',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Saint Helenan punta',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slovenian tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovakian koruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra Leonen leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalian šillinki',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinamen dollari',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinamen guldeni',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Etelä-Sudanin punta',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'São Tomén ja Príncipen dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'São Tomén ja Príncipen dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Neuvostoliiton rupla',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'El Salvadorin colón',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Syyrian punta',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazimaan lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Thaimaan baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadžikistanin rupla',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadžikistanin somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmenistanin manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistanin manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunisian dinaari',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongan pa’anga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timorin escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turkin liira (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkin liira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidadin ja Tobagon dollari',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'Taiwanin uusi dollari',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tansanian šillinki',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrainan hryvnia',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrainan karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Ugandan šillinki (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandan šillinki',
        ],
        'USD' => [
            0 => '$',
            1 => 'Yhdysvaltain dollari',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Yhdysvaltain dollari (seuraava päivä)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Yhdysvaltain dollari (sama päivä)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Uruguayn peso en unidades indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruguayn peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguayn peso',
        ],
        'UYW' => [
            0 => 'UYW',
            1 => 'Uruguayn nimellinen palkkaindeksiyksikkö',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Uzbekistanin som',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venezuelan bolívar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezuelan bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venezuelan suvereeni bolívar',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'Vietnamin dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Vietnamin dong (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatun vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoan tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA-frangi BEAC',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'Itä-Karibian dollari',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Euroopan valuuttayksikkö (ECU)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Ranskan kultafrangi',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Ranskan UIC-frangi',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'CFA-frangi BCEAO',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'CFP-frangi',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET-rahastot',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemenin dinaari',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemenin rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Jugoslavian kova dinaari (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Jugoslavian uusi dinaari (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Jugoslavian vaihdettava dinaari (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Jugoslavian uudistettu dinaari (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Etelä-Afrikan rahoitusrandi',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Etelä-Afrikan randi',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Sambian kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Sambian kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zairen uusi zaire (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zairen zaire (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabwen dollari (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabwen dollari (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabwen dollari (2008)',
        ],
    ],
];
