<?php

return [
    'Names' => [
        'America/Araguaina' => 'Saa za Brazili (Araguaina)',
        'America/Argentina/La_Rioja' => 'Saa za Ajentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Saa za Ajentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Saa za Ajentina (Salta)',
        'America/Argentina/San_Juan' => 'Saa za Ajentina (San Juan)',
        'America/Argentina/San_Luis' => 'Saa za Ajentina (San Luis)',
        'America/Argentina/Tucuman' => 'Saa za Ajentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'Saa za Ajentina (Ushuaia)',
        'America/Bahia' => 'Saa za Brazili (Bahia)',
        'America/Barbados' => 'Saa za Atlantiki (Babados)',
        'America/Belem' => 'Saa za Brazili (Belem)',
        'America/Buenos_Aires' => 'Saa za Ajentina (Buenos Aires)',
        'America/Catamarca' => 'Saa za Ajentina (Catamarca)',
        'America/Cayenne' => 'Saa za Guiana (Cayenne)',
        'America/Cordoba' => 'Saa za Ajentina (Cordoba)',
        'America/Costa_Rica' => 'Saa za Kati (Kostarika)',
        'America/Curacao' => 'Saa za Atlantiki (kurakao)',
        'America/Dominica' => 'Saa za Atlantiki (Dominika)',
        'America/El_Salvador' => 'Saa za Kati (Elsalvado)',
        'America/Fortaleza' => 'Saa za Brazili (Fortaleza)',
        'America/Guadeloupe' => 'Saa za Atlantiki (Guadalupe)',
        'America/Jamaica' => 'Saa za Mashariki (Jamaika)',
        'America/Jujuy' => 'Saa za Ajentina (Jujuy)',
        'America/Maceio' => 'Saa za Brazili (Maceio)',
        'America/Mendoza' => 'Saa za Ajentina (Mendoza)',
        'America/North_Dakota/Beulah' => 'Saa za Kati (Beulah, Dakota Kaskazini)',
        'America/North_Dakota/Center' => 'Saa za Kati (Center, Dakota Kaskazini)',
        'America/North_Dakota/New_Salem' => 'Saa za Kati (New Salem, Dakota Kaskazini)',
        'America/Port_of_Spain' => 'Saa za Atlantiki (Bandari ya Uhispania)',
        'America/Puerto_Rico' => 'Saa za Atlantiki (Pwetoriko)',
        'America/Recife' => 'Saa za Brazili (Recife)',
        'America/Santa_Isabel' => 'Saa za Kaskazini Magharibi mwa Meksiko (Santa Isabel)',
        'America/Santarem' => 'Saa za Brazili (Santarem)',
        'America/Sao_Paulo' => 'Saa za Brazili (Sao Paulo)',
        'Antarctica/Casey' => 'Saa za Antaktika (Casey)',
        'Antarctica/McMurdo' => 'Saa za Nyuzilandi (McMurdo)',
        'Asia/Almaty' => 'Saa za Kazakistani Mashariki (Almaty)',
        'Asia/Aqtau' => 'Saa za Kazakistani Magharibi (Aqtau)',
        'Asia/Aqtobe' => 'Saa za Kazakistani Magharibi (Aqtobe)',
        'Asia/Ashgabat' => 'Saa za Turkmenistani (Ashgabat)',
        'Asia/Atyrau' => 'Saa za Kazakistani Magharibi (Atyrau)',
        'Asia/Baku' => 'Saa za Azabajani (Baku)',
        'Asia/Choibalsan' => 'Saa za Ulaanbataar (Choibalsan)',
        'Asia/Colombo' => 'Saa za Wastani za India (Kolombo)',
        'Asia/Dhaka' => 'Saa za Bangladeshi (Dhaka)',
        'Asia/Dubai' => 'Saa za Wastani za Ghuba (Dubai)',
        'Asia/Dushanbe' => 'Saaza Tajikistani (Dushanbe)',
        'Asia/Kabul' => 'Saa za Afghanistani (Kabul)',
        'Asia/Karachi' => 'Saa za Pakistani (Karachi)',
        'Asia/Katmandu' => 'Saa za Nepali (Kathmandu)',
        'Asia/Kuala_Lumpur' => 'Saa za Malesia (Kuala Lumpur)',
        'Asia/Kuching' => 'Saa za Malesia (Kuching)',
        'Asia/Macau' => 'Saa za Uchina (Makao)',
        'Asia/Muscat' => 'Saa za Wastani za Ghuba (Muscat)',
        'Asia/Oral' => 'Saa za Kazakistani Magharibi (Oral)',
        'Asia/Qostanay' => 'Saa za Kazakistani Mashariki (Kostanay)',
        'Asia/Qyzylorda' => 'Saa za Kazakistani Magharibi (Qyzylorda)',
        'Asia/Rangoon' => 'Saa za Myanma (Yangon)',
        'Asia/Saigon' => 'Saa za Indochina (Jiji la Ho Chi Minh)',
        'Asia/Samarkand' => 'Saa za Uzbekistani (Samarkand)',
        'Asia/Singapore' => 'Saa za Wastani za Singapoo',
        'Asia/Tashkent' => 'Saa za Uzbekistani (Tashkent)',
        'Asia/Tbilisi' => 'Saa za Jiojia (Tbilisi)',
        'Asia/Tehran' => 'Saa za Irani (Tehran)',
        'Asia/Thimphu' => 'Saa za Butani (Thimphu)',
        'Asia/Tokyo' => 'Saa za Japani (Tokyo)',
        'Asia/Ulaanbaatar' => 'Saa za Ulaanbataar (Ulaanbaatar)',
        'Atlantic/Canary' => 'Saa za Magharibi mwa Ulaya (Kanari)',
        'Atlantic/Cape_Verde' => 'Saa za Kepuvede (Cape Verde)',
        'Atlantic/South_Georgia' => 'Saa za Jojia Kusini (Georgia Kusini)',
        'Australia/Eucla' => 'Saa za Magharibi mwa Austrialia ya Kati (Eucla)',
        'Etc/UTC' => 'Saa ya Dunia',
        'Indian/Christmas' => 'Saa za Kisiwa cha Krismasi',
        'Indian/Maldives' => 'Saa za Maldivi',
        'Pacific/Auckland' => 'Saa za Nyuzilandi (Auckland)',
        'Pacific/Bougainville' => 'Saa za Papua (Bougainville)',
        'Pacific/Enderbury' => 'Saa za Visiwa vya Finiksi (Enderbury)',
        'Pacific/Noumea' => 'Saa za Kaledonia Mpya (Noumea)',
        'Pacific/Port_Moresby' => 'Saa za Papua (Port Moresby)',
    ],
    'Meta' => [
    ],
];
