<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich middeltid (Abidjan)',
        'Africa/Accra' => 'Greenwich middeltid (Accra)',
        'Africa/Addis_Ababa' => 'østafrikansk tid (Addis Abeba)',
        'Africa/Algiers' => 'sentraleuropeisk tid (Alger)',
        'Africa/Asmera' => 'østafrikansk tid (Asmara)',
        'Africa/Bamako' => 'Greenwich middeltid (Bamako)',
        'Africa/Bangui' => 'vestafrikansk tid (Bangui)',
        'Africa/Banjul' => 'Greenwich middeltid (Banjul)',
        'Africa/Bissau' => 'Greenwich middeltid (Bissau)',
        'Africa/Blantyre' => 'sentralafrikansk tid (Blantyre)',
        'Africa/Brazzaville' => 'vestafrikansk tid (Brazzaville)',
        'Africa/Bujumbura' => 'sentralafrikansk tid (Bujumbura)',
        'Africa/Cairo' => 'østeuropeisk tid (Kairo)',
        'Africa/Casablanca' => 'vesteuropeisk tid (Casablanca)',
        'Africa/Ceuta' => 'sentraleuropeisk tid (Ceuta)',
        'Africa/Conakry' => 'Greenwich middeltid (Conakry)',
        'Africa/Dakar' => 'Greenwich middeltid (Dakar)',
        'Africa/Dar_es_Salaam' => 'østafrikansk tid (Dar-es-Salaam)',
        'Africa/Djibouti' => 'østafrikansk tid (Djibouti)',
        'Africa/Douala' => 'vestafrikansk tid (Douala)',
        'Africa/El_Aaiun' => 'vesteuropeisk tid (El Aaiún)',
        'Africa/Freetown' => 'Greenwich middeltid (Freetown)',
        'Africa/Gaborone' => 'sentralafrikansk tid (Gaborone)',
        'Africa/Harare' => 'sentralafrikansk tid (Harare)',
        'Africa/Johannesburg' => 'sørafrikansk tid (Johannesburg)',
        'Africa/Juba' => 'sentralafrikansk tid (Juba)',
        'Africa/Kampala' => 'østafrikansk tid (Kampala)',
        'Africa/Khartoum' => 'sentralafrikansk tid (Khartoum)',
        'Africa/Kigali' => 'sentralafrikansk tid (Kigali)',
        'Africa/Kinshasa' => 'vestafrikansk tid (Kinshasa)',
        'Africa/Lagos' => 'vestafrikansk tid (Lagos)',
        'Africa/Libreville' => 'vestafrikansk tid (Libreville)',
        'Africa/Lome' => 'Greenwich middeltid (Lomé)',
        'Africa/Luanda' => 'vestafrikansk tid (Luanda)',
        'Africa/Lubumbashi' => 'sentralafrikansk tid (Lubumbashi)',
        'Africa/Lusaka' => 'sentralafrikansk tid (Lusaka)',
        'Africa/Malabo' => 'vestafrikansk tid (Malabo)',
        'Africa/Maputo' => 'sentralafrikansk tid (Maputo)',
        'Africa/Maseru' => 'sørafrikansk tid (Maseru)',
        'Africa/Mbabane' => 'sørafrikansk tid (Mbabane)',
        'Africa/Mogadishu' => 'østafrikansk tid (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich middeltid (Monrovia)',
        'Africa/Nairobi' => 'østafrikansk tid (Nairobi)',
        'Africa/Ndjamena' => 'vestafrikansk tid (Ndjamena)',
        'Africa/Niamey' => 'vestafrikansk tid (Niamey)',
        'Africa/Nouakchott' => 'Greenwich middeltid (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich middeltid (Ouagadougou)',
        'Africa/Porto-Novo' => 'vestafrikansk tid (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich middeltid (São Tomé)',
        'Africa/Tripoli' => 'østeuropeisk tid (Tripoli)',
        'Africa/Tunis' => 'sentraleuropeisk tid (Tunis)',
        'Africa/Windhoek' => 'sentralafrikansk tid (Windhoek)',
        'America/Adak' => 'tidssone for Hawaii og Aleutene (Adak)',
        'America/Anchorage' => 'alaskisk tid (Anchorage)',
        'America/Anguilla' => 'tidssone for den nordamerikanske atlanterhavskysten (Anguilla)',
        'America/Antigua' => 'tidssone for den nordamerikanske atlanterhavskysten (Antigua)',
        'America/Araguaina' => 'tidssone for Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'argentinsk tid (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'argentinsk tid (Rio Gallegos)',
        'America/Argentina/Salta' => 'argentinsk tid (Salta)',
        'America/Argentina/San_Juan' => 'argentinsk tid (San Juan)',
        'America/Argentina/San_Luis' => 'argentinsk tid (San Luis)',
        'America/Argentina/Tucuman' => 'argentinsk tid (Tucumán)',
        'America/Argentina/Ushuaia' => 'argentinsk tid (Ushuaia)',
        'America/Aruba' => 'tidssone for den nordamerikanske atlanterhavskysten (Aruba)',
        'America/Asuncion' => 'paraguayansk tid (Asunción)',
        'America/Bahia' => 'tidssone for Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'tidssone for det sentrale Nord-Amerika (Bahía Banderas)',
        'America/Barbados' => 'tidssone for den nordamerikanske atlanterhavskysten (Barbados)',
        'America/Belem' => 'tidssone for Brasilia (Belém)',
        'America/Belize' => 'tidssone for det sentrale Nord-Amerika (Belize)',
        'America/Blanc-Sablon' => 'tidssone for den nordamerikanske atlanterhavskysten (Blanc-Sablon)',
        'America/Boa_Vista' => 'tidssone for Amazonas (Boa Vista)',
        'America/Bogota' => 'colombiansk tid (Bogotá)',
        'America/Boise' => 'tidssone for Rocky Mountains (USA) (Boise)',
        'America/Buenos_Aires' => 'argentinsk tid (Buenos Aires)',
        'America/Cambridge_Bay' => 'tidssone for Rocky Mountains (USA) (Cambridge Bay)',
        'America/Campo_Grande' => 'tidssone for Amazonas (Campo Grande)',
        'America/Cancun' => 'tidssone for den nordamerikanske østkysten (Cancún)',
        'America/Caracas' => 'venezuelansk tid (Caracas)',
        'America/Catamarca' => 'argentinsk tid (Catamarca)',
        'America/Cayenne' => 'tidssone for Fransk Guyana (Cayenne)',
        'America/Cayman' => 'tidssone for den nordamerikanske østkysten (Caymanøyene)',
        'America/Chicago' => 'tidssone for det sentrale Nord-Amerika (Chicago)',
        'America/Chihuahua' => 'tidssone for den meksikanske Stillehavskysten (Chihuahua)',
        'America/Coral_Harbour' => 'tidssone for den nordamerikanske østkysten (Atikokan)',
        'America/Cordoba' => 'argentinsk tid (Córdoba)',
        'America/Costa_Rica' => 'tidssone for det sentrale Nord-Amerika (Costa Rica)',
        'America/Creston' => 'tidssone for Rocky Mountains (USA) (Creston)',
        'America/Cuiaba' => 'tidssone for Amazonas (Cuiabá)',
        'America/Curacao' => 'tidssone for den nordamerikanske atlanterhavskysten (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich middeltid (Danmarkshavn)',
        'America/Dawson' => 'tidssone for Yukon (Dawson)',
        'America/Dawson_Creek' => 'tidssone for Rocky Mountains (USA) (Dawson Creek)',
        'America/Denver' => 'tidssone for Rocky Mountains (USA) (Denver)',
        'America/Detroit' => 'tidssone for den nordamerikanske østkysten (Detroit)',
        'America/Dominica' => 'tidssone for den nordamerikanske atlanterhavskysten (Dominica)',
        'America/Edmonton' => 'tidssone for Rocky Mountains (USA) (Edmonton)',
        'America/Eirunepe' => 'Acre-tid (Eirunepe)',
        'America/El_Salvador' => 'tidssone for det sentrale Nord-Amerika (El Salvador)',
        'America/Fort_Nelson' => 'tidssone for Rocky Mountains (USA) (Fort Nelson)',
        'America/Fortaleza' => 'tidssone for Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'tidssone for den nordamerikanske atlanterhavskysten (Glace Bay)',
        'America/Godthab' => 'vestgrønlandsk tid (Nuuk)',
        'America/Goose_Bay' => 'tidssone for den nordamerikanske atlanterhavskysten (Goose Bay)',
        'America/Grand_Turk' => 'tidssone for den nordamerikanske østkysten (Grand Turk)',
        'America/Grenada' => 'tidssone for den nordamerikanske atlanterhavskysten (Grenada)',
        'America/Guadeloupe' => 'tidssone for den nordamerikanske atlanterhavskysten (Guadeloupe)',
        'America/Guatemala' => 'tidssone for det sentrale Nord-Amerika (Guatemala)',
        'America/Guayaquil' => 'ecuadoriansk tid (Guayaquil)',
        'America/Guyana' => 'guyansk tid (Guyana)',
        'America/Halifax' => 'tidssone for den nordamerikanske atlanterhavskysten (Halifax)',
        'America/Havana' => 'cubansk tid (Havana)',
        'America/Hermosillo' => 'tidssone for den meksikanske Stillehavskysten (Hermosillo)',
        'America/Indiana/Knox' => 'tidssone for det sentrale Nord-Amerika (Knox, Indiana)',
        'America/Indiana/Marengo' => 'tidssone for den nordamerikanske østkysten (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'tidssone for den nordamerikanske østkysten (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'tidssone for det sentrale Nord-Amerika (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'tidssone for den nordamerikanske østkysten (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'tidssone for den nordamerikanske østkysten (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'tidssone for den nordamerikanske østkysten (Winamac, Indiana)',
        'America/Indianapolis' => 'tidssone for den nordamerikanske østkysten (Indianapolis)',
        'America/Inuvik' => 'tidssone for Rocky Mountains (USA) (Inuvik)',
        'America/Iqaluit' => 'tidssone for den nordamerikanske østkysten (Iqaluit)',
        'America/Jamaica' => 'tidssone for den nordamerikanske østkysten (Jamaica)',
        'America/Jujuy' => 'argentinsk tid (Jujuy)',
        'America/Juneau' => 'alaskisk tid (Juneau)',
        'America/Kentucky/Monticello' => 'tidssone for den nordamerikanske østkysten (Monticello, Kentucky)',
        'America/Kralendijk' => 'tidssone for den nordamerikanske atlanterhavskysten (Kralendijk)',
        'America/La_Paz' => 'boliviansk tid (La Paz)',
        'America/Lima' => 'peruansk tid (Lima)',
        'America/Los_Angeles' => 'tidssone for den nordamerikanske Stillehavskysten (Los Angeles)',
        'America/Louisville' => 'tidssone for den nordamerikanske østkysten (Louisville)',
        'America/Lower_Princes' => 'tidssone for den nordamerikanske atlanterhavskysten (Lower Prince’s Quarter)',
        'America/Maceio' => 'tidssone for Brasilia (Maceió)',
        'America/Managua' => 'tidssone for det sentrale Nord-Amerika (Managua)',
        'America/Manaus' => 'tidssone for Amazonas (Manaus)',
        'America/Marigot' => 'tidssone for den nordamerikanske atlanterhavskysten (Marigot)',
        'America/Martinique' => 'tidssone for den nordamerikanske atlanterhavskysten (Martinique)',
        'America/Matamoros' => 'tidssone for det sentrale Nord-Amerika (Matamoros)',
        'America/Mazatlan' => 'tidssone for den meksikanske Stillehavskysten (Mazatlan)',
        'America/Mendoza' => 'argentinsk tid (Mendoza)',
        'America/Menominee' => 'tidssone for det sentrale Nord-Amerika (Menominee)',
        'America/Merida' => 'tidssone for det sentrale Nord-Amerika (Mérida)',
        'America/Metlakatla' => 'alaskisk tid (Metlakatla)',
        'America/Mexico_City' => 'tidssone for det sentrale Nord-Amerika (Mexico by)',
        'America/Miquelon' => 'tidssone for Saint-Pierre-et-Miquelon',
        'America/Moncton' => 'tidssone for den nordamerikanske atlanterhavskysten (Moncton)',
        'America/Monterrey' => 'tidssone for det sentrale Nord-Amerika (Monterrey)',
        'America/Montevideo' => 'uruguayansk tid (Montevideo)',
        'America/Montreal' => 'tidssone for Canada (Montreal)',
        'America/Montserrat' => 'tidssone for den nordamerikanske atlanterhavskysten (Montserrat)',
        'America/Nassau' => 'tidssone for den nordamerikanske østkysten (Nassau)',
        'America/New_York' => 'tidssone for den nordamerikanske østkysten (New York)',
        'America/Nipigon' => 'tidssone for den nordamerikanske østkysten (Nipigon)',
        'America/Nome' => 'alaskisk tid (Nome)',
        'America/Noronha' => 'tidssone for Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'tidssone for det sentrale Nord-Amerika (Beulah, Nord-Dakota)',
        'America/North_Dakota/Center' => 'tidssone for det sentrale Nord-Amerika (Center, Nord-Dakota)',
        'America/North_Dakota/New_Salem' => 'tidssone for det sentrale Nord-Amerika (New Salem, Nord-Dakota)',
        'America/Ojinaga' => 'tidssone for Rocky Mountains (USA) (Ojinaga)',
        'America/Panama' => 'tidssone for den nordamerikanske østkysten (Panama)',
        'America/Pangnirtung' => 'tidssone for den nordamerikanske østkysten (Pangnirtung)',
        'America/Paramaribo' => 'surinamsk tid (Paramaribo)',
        'America/Phoenix' => 'tidssone for Rocky Mountains (USA) (Phoenix)',
        'America/Port-au-Prince' => 'tidssone for den nordamerikanske østkysten (Port-au-Prince)',
        'America/Port_of_Spain' => 'tidssone for den nordamerikanske atlanterhavskysten (Port of Spain)',
        'America/Porto_Velho' => 'tidssone for Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'tidssone for den nordamerikanske atlanterhavskysten (Puerto Rico)',
        'America/Punta_Arenas' => 'chilensk tid (Punta Arenas)',
        'America/Rainy_River' => 'tidssone for det sentrale Nord-Amerika (Rainy River)',
        'America/Rankin_Inlet' => 'tidssone for det sentrale Nord-Amerika (Rankin Inlet)',
        'America/Recife' => 'tidssone for Brasilia (Recife)',
        'America/Regina' => 'tidssone for det sentrale Nord-Amerika (Regina)',
        'America/Resolute' => 'tidssone for det sentrale Nord-Amerika (Resolute)',
        'America/Rio_Branco' => 'Acre-tid (Rio Branco)',
        'America/Santa_Isabel' => 'tidssone for nordvestlige Mexico (Santa Isabel)',
        'America/Santarem' => 'tidssone for Brasilia (Santarém)',
        'America/Santiago' => 'chilensk tid (Santiago)',
        'America/Santo_Domingo' => 'tidssone for den nordamerikanske atlanterhavskysten (Santo Domingo)',
        'America/Sao_Paulo' => 'tidssone for Brasilia (São Paulo)',
        'America/Scoresbysund' => 'østgrønlandsk tid (Ittoqqortoormiit)',
        'America/Sitka' => 'alaskisk tid (Sitka)',
        'America/St_Barthelemy' => 'tidssone for den nordamerikanske atlanterhavskysten (Saint-Barthélemy)',
        'America/St_Johns' => 'tidssone for Newfoundland (St. John’s)',
        'America/St_Kitts' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Kitts)',
        'America/St_Lucia' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Lucia)',
        'America/St_Thomas' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Thomas)',
        'America/St_Vincent' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Vincent)',
        'America/Swift_Current' => 'tidssone for det sentrale Nord-Amerika (Swift Current)',
        'America/Tegucigalpa' => 'tidssone for det sentrale Nord-Amerika (Tegucigalpa)',
        'America/Thule' => 'tidssone for den nordamerikanske atlanterhavskysten (Thule)',
        'America/Thunder_Bay' => 'tidssone for den nordamerikanske østkysten (Thunder Bay)',
        'America/Tijuana' => 'tidssone for den nordamerikanske Stillehavskysten (Tijuana)',
        'America/Toronto' => 'tidssone for den nordamerikanske østkysten (Toronto)',
        'America/Tortola' => 'tidssone for den nordamerikanske atlanterhavskysten (Tortola)',
        'America/Vancouver' => 'tidssone for den nordamerikanske Stillehavskysten (Vancouver)',
        'America/Whitehorse' => 'tidssone for Yukon (Whitehorse)',
        'America/Winnipeg' => 'tidssone for det sentrale Nord-Amerika (Winnipeg)',
        'America/Yakutat' => 'alaskisk tid (Yakutat)',
        'America/Yellowknife' => 'tidssone for Rocky Mountains (USA) (Yellowknife)',
        'Antarctica/Casey' => 'Casey-tid',
        'Antarctica/Davis' => 'tidssone for Davis',
        'Antarctica/DumontDUrville' => 'tidssone for Dumont d’Urville',
        'Antarctica/Macquarie' => 'østaustralsk tid (Macquarie)',
        'Antarctica/Mawson' => 'tidssone for Mawson',
        'Antarctica/McMurdo' => 'newzealandsk tid (McMurdo)',
        'Antarctica/Palmer' => 'chilensk tid (Palmer)',
        'Antarctica/Rothera' => 'tidssone for Rothera',
        'Antarctica/Syowa' => 'tidssone for Syowa',
        'Antarctica/Troll' => 'Greenwich middeltid (Troll)',
        'Antarctica/Vostok' => 'tidssone for Vostok',
        'Arctic/Longyearbyen' => 'sentraleuropeisk tid (Longyearbyen)',
        'Asia/Aden' => 'arabisk tid (Aden)',
        'Asia/Almaty' => 'østkasakhstansk tid (Almaty)',
        'Asia/Amman' => 'østeuropeisk tid (Amman)',
        'Asia/Anadyr' => 'Russisk (Anadyr) tid',
        'Asia/Aqtau' => 'vestkasakhstansk tid (Aktau)',
        'Asia/Aqtobe' => 'vestkasakhstansk tid (Aqtöbe)',
        'Asia/Ashgabat' => 'turkmensk tid (Asjkhabad)',
        'Asia/Atyrau' => 'vestkasakhstansk tid (Atyrau)',
        'Asia/Baghdad' => 'arabisk tid (Bagdad)',
        'Asia/Bahrain' => 'arabisk tid (Bahrain)',
        'Asia/Baku' => 'aserbajdsjansk tid (Baku)',
        'Asia/Bangkok' => 'indokinesisk tid (Bangkok)',
        'Asia/Barnaul' => 'tidssone for Russland (Barnaul)',
        'Asia/Beirut' => 'østeuropeisk tid (Beirut)',
        'Asia/Bishkek' => 'kirgisisk tid (Bisjkek)',
        'Asia/Brunei' => 'tidssone for Brunei Darussalam',
        'Asia/Calcutta' => 'indisk tid (Kolkata)',
        'Asia/Chita' => 'tidssone for Jakutsk (Tsjita)',
        'Asia/Choibalsan' => 'tidssone for Ulan Bator (Choybalsan)',
        'Asia/Colombo' => 'indisk tid (Colombo)',
        'Asia/Damascus' => 'østeuropeisk tid (Damaskus)',
        'Asia/Dhaka' => 'bangladeshisk tid (Dhaka)',
        'Asia/Dili' => 'østtimoresisk tid (Dili)',
        'Asia/Dubai' => 'tidssone for Persiabukta (Dubai)',
        'Asia/Dushanbe' => 'tadsjikisk tid (Dusjanbe)',
        'Asia/Famagusta' => 'østeuropeisk tid (Famagusta)',
        'Asia/Gaza' => 'østeuropeisk tid (Gaza)',
        'Asia/Hebron' => 'østeuropeisk tid (Hebron)',
        'Asia/Hong_Kong' => 'tidssone for Hongkong',
        'Asia/Hovd' => 'tidssone for Khovd',
        'Asia/Irkutsk' => 'tidssone for Irkutsk',
        'Asia/Jakarta' => 'vestindonesisk tid (Jakarta)',
        'Asia/Jayapura' => 'østindonesisk tid (Jajapura)',
        'Asia/Jerusalem' => 'israelsk tid (Jerusalem)',
        'Asia/Kabul' => 'afghansk tid (Kabul)',
        'Asia/Kamchatka' => 'Russisk (Petropavlovsk-Kamtsjatskij) tid (Kamtsjatka)',
        'Asia/Karachi' => 'pakistansk tid (Karachi)',
        'Asia/Katmandu' => 'nepalsk tid (Katmandu)',
        'Asia/Khandyga' => 'tidssone for Jakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'tidssone for Krasnojarsk',
        'Asia/Kuala_Lumpur' => 'malaysisk tid (Kuala Lumpur)',
        'Asia/Kuching' => 'malaysisk tid (Kuching)',
        'Asia/Kuwait' => 'arabisk tid (Kuwait)',
        'Asia/Macau' => 'kinesisk tid (Macao)',
        'Asia/Magadan' => 'tidssone for Magadan',
        'Asia/Makassar' => 'sentralindonesisk tid (Makassar)',
        'Asia/Manila' => 'filippinsk tid (Manila)',
        'Asia/Muscat' => 'tidssone for Persiabukta (Muskat)',
        'Asia/Nicosia' => 'østeuropeisk tid (Nikosia)',
        'Asia/Novokuznetsk' => 'tidssone for Krasnojarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'tidssone for Novosibirsk',
        'Asia/Omsk' => 'tidssone for Omsk',
        'Asia/Oral' => 'vestkasakhstansk tid (Oral)',
        'Asia/Phnom_Penh' => 'indokinesisk tid (Phnom Penh)',
        'Asia/Pontianak' => 'vestindonesisk tid (Pontianak)',
        'Asia/Pyongyang' => 'koreansk tid (Pyongyang)',
        'Asia/Qatar' => 'arabisk tid (Qatar)',
        'Asia/Qostanay' => 'østkasakhstansk tid (Kostanaj)',
        'Asia/Qyzylorda' => 'vestkasakhstansk tid (Kyzylorda)',
        'Asia/Rangoon' => 'myanmarsk tid (Yangon)',
        'Asia/Riyadh' => 'arabisk tid (Riyadh)',
        'Asia/Saigon' => 'indokinesisk tid (Ho Chi Minh-byen)',
        'Asia/Sakhalin' => 'tidssone for Sakhalin',
        'Asia/Samarkand' => 'usbekisk tid (Samarkand)',
        'Asia/Seoul' => 'koreansk tid (Seoul)',
        'Asia/Shanghai' => 'kinesisk tid (Shanghai)',
        'Asia/Singapore' => 'singaporsk tid (Singapore)',
        'Asia/Srednekolymsk' => 'tidssone for Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'tidssone for Taipei',
        'Asia/Tashkent' => 'usbekisk tid (Tasjkent)',
        'Asia/Tbilisi' => 'georgisk tid (Tbilisi)',
        'Asia/Tehran' => 'iransk tid (Teheran)',
        'Asia/Thimphu' => 'bhutansk tid (Thimpu)',
        'Asia/Tokyo' => 'japansk tid (Tokyo)',
        'Asia/Tomsk' => 'tidssone for Russland (Tomsk)',
        'Asia/Ulaanbaatar' => 'tidssone for Ulan Bator',
        'Asia/Urumqi' => 'tidssone for Kina (Ürümqi)',
        'Asia/Ust-Nera' => 'tidssone for Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'indokinesisk tid (Vientiane)',
        'Asia/Vladivostok' => 'tidssone for Vladivostok',
        'Asia/Yakutsk' => 'tidssone for Jakutsk',
        'Asia/Yekaterinburg' => 'tidssone for Jekaterinburg',
        'Asia/Yerevan' => 'armensk tid (Jerevan)',
        'Atlantic/Azores' => 'asorisk tid (Asorene)',
        'Atlantic/Bermuda' => 'tidssone for den nordamerikanske atlanterhavskysten (Bermuda)',
        'Atlantic/Canary' => 'vesteuropeisk tid (Kanariøyene)',
        'Atlantic/Cape_Verde' => 'kappverdisk tid (Kapp Verde)',
        'Atlantic/Faeroe' => 'vesteuropeisk tid (Færøyene)',
        'Atlantic/Madeira' => 'vesteuropeisk tid (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich middeltid (Reykjavík)',
        'Atlantic/South_Georgia' => 'tidssone for Sør-Georgia',
        'Atlantic/St_Helena' => 'Greenwich middeltid (St. Helena)',
        'Atlantic/Stanley' => 'tidssone for Falklandsøyene (Stanley)',
        'Australia/Adelaide' => 'sentralaustralsk tid (Adelaide)',
        'Australia/Brisbane' => 'østaustralsk tid (Brisbane)',
        'Australia/Broken_Hill' => 'sentralaustralsk tid (Broken Hill)',
        'Australia/Currie' => 'østaustralsk tid (Currie)',
        'Australia/Darwin' => 'sentralaustralsk tid (Darwin)',
        'Australia/Eucla' => 'vest-sentralaustralsk tid (Eucla)',
        'Australia/Hobart' => 'østaustralsk tid (Hobart)',
        'Australia/Lindeman' => 'østaustralsk tid (Lindeman)',
        'Australia/Lord_Howe' => 'tidssone for Lord Howe-øya',
        'Australia/Melbourne' => 'østaustralsk tid (Melbourne)',
        'Australia/Perth' => 'vestaustralsk tid (Perth)',
        'Australia/Sydney' => 'østaustralsk tid (Sydney)',
        'CST6CDT' => 'tidssone for det sentrale Nord-Amerika',
        'EST5EDT' => 'tidssone for den nordamerikanske østkysten',
        'Etc/GMT' => 'Greenwich middeltid',
        'Etc/UTC' => 'koordinert universaltid',
        'Europe/Amsterdam' => 'sentraleuropeisk tid (Amsterdam)',
        'Europe/Andorra' => 'sentraleuropeisk tid (Andorra)',
        'Europe/Astrakhan' => 'tidssone for Moskva (Astrakhan)',
        'Europe/Athens' => 'østeuropeisk tid (Athen)',
        'Europe/Belgrade' => 'sentraleuropeisk tid (Beograd)',
        'Europe/Berlin' => 'sentraleuropeisk tid (Berlin)',
        'Europe/Bratislava' => 'sentraleuropeisk tid (Bratislava)',
        'Europe/Brussels' => 'sentraleuropeisk tid (Brussel)',
        'Europe/Bucharest' => 'østeuropeisk tid (București)',
        'Europe/Budapest' => 'sentraleuropeisk tid (Budapest)',
        'Europe/Busingen' => 'sentraleuropeisk tid (Büsingen)',
        'Europe/Chisinau' => 'østeuropeisk tid (Chișinău)',
        'Europe/Copenhagen' => 'sentraleuropeisk tid (København)',
        'Europe/Dublin' => 'Greenwich middeltid (Dublin)',
        'Europe/Gibraltar' => 'sentraleuropeisk tid (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich middeltid (Guernsey)',
        'Europe/Helsinki' => 'østeuropeisk tid (Helsingfors)',
        'Europe/Isle_of_Man' => 'Greenwich middeltid (Man)',
        'Europe/Istanbul' => 'tidssone for Tyrkia (Istanbul)',
        'Europe/Jersey' => 'Greenwich middeltid (Jersey)',
        'Europe/Kaliningrad' => 'østeuropeisk tid (Kaliningrad)',
        'Europe/Kiev' => 'østeuropeisk tid (Kyiv)',
        'Europe/Kirov' => 'tidssone for Russland (Kirov)',
        'Europe/Lisbon' => 'vesteuropeisk tid (Lisboa)',
        'Europe/Ljubljana' => 'sentraleuropeisk tid (Ljubljana)',
        'Europe/London' => 'Greenwich middeltid (London)',
        'Europe/Luxembourg' => 'sentraleuropeisk tid (Luxemburg)',
        'Europe/Madrid' => 'sentraleuropeisk tid (Madrid)',
        'Europe/Malta' => 'sentraleuropeisk tid (Malta)',
        'Europe/Mariehamn' => 'østeuropeisk tid (Mariehamn)',
        'Europe/Minsk' => 'tidssone for Moskva (Minsk)',
        'Europe/Monaco' => 'sentraleuropeisk tid (Monaco)',
        'Europe/Moscow' => 'tidssone for Moskva',
        'Europe/Oslo' => 'sentraleuropeisk tid (Oslo)',
        'Europe/Paris' => 'sentraleuropeisk tid (Paris)',
        'Europe/Podgorica' => 'sentraleuropeisk tid (Podgorica)',
        'Europe/Prague' => 'sentraleuropeisk tid (Praha)',
        'Europe/Riga' => 'østeuropeisk tid (Riga)',
        'Europe/Rome' => 'sentraleuropeisk tid (Roma)',
        'Europe/Samara' => 'Russisk (Samara) tid',
        'Europe/San_Marino' => 'sentraleuropeisk tid (San Marino)',
        'Europe/Sarajevo' => 'sentraleuropeisk tid (Sarajevo)',
        'Europe/Saratov' => 'tidssone for Moskva (Saratov)',
        'Europe/Simferopol' => 'tidssone for Moskva (Simferopol)',
        'Europe/Skopje' => 'sentraleuropeisk tid (Skopje)',
        'Europe/Sofia' => 'østeuropeisk tid (Sofia)',
        'Europe/Stockholm' => 'sentraleuropeisk tid (Stockholm)',
        'Europe/Tallinn' => 'østeuropeisk tid (Tallinn)',
        'Europe/Tirane' => 'sentraleuropeisk tid (Tirana)',
        'Europe/Ulyanovsk' => 'tidssone for Moskva (Uljanovsk)',
        'Europe/Uzhgorod' => 'østeuropeisk tid (Uzjhorod)',
        'Europe/Vaduz' => 'sentraleuropeisk tid (Vaduz)',
        'Europe/Vatican' => 'sentraleuropeisk tid (Vatikanstaten)',
        'Europe/Vienna' => 'sentraleuropeisk tid (Wien)',
        'Europe/Vilnius' => 'østeuropeisk tid (Vilnius)',
        'Europe/Volgograd' => 'tidssone for Volgograd',
        'Europe/Warsaw' => 'sentraleuropeisk tid (Warszawa)',
        'Europe/Zagreb' => 'sentraleuropeisk tid (Zagreb)',
        'Europe/Zaporozhye' => 'østeuropeisk tid (Zaporizjzja)',
        'Europe/Zurich' => 'sentraleuropeisk tid (Zürich)',
        'Indian/Antananarivo' => 'østafrikansk tid (Antananarivo)',
        'Indian/Chagos' => 'tidssone for Indiahavet (Chagos)',
        'Indian/Christmas' => 'tidssone for Christmasøya',
        'Indian/Cocos' => 'tidssone for Kokosøyene',
        'Indian/Comoro' => 'østafrikansk tid (Komorene)',
        'Indian/Kerguelen' => 'tidssone for De franske sørterritorier (Kerguelen)',
        'Indian/Mahe' => 'seychellisk tid (Mahé)',
        'Indian/Maldives' => 'maldivisk tid (Maldivene)',
        'Indian/Mauritius' => 'mauritisk tid (Mauritius)',
        'Indian/Mayotte' => 'østafrikansk tid (Mayotte)',
        'Indian/Reunion' => 'tidssone for Réunion',
        'MST7MDT' => 'tidssone for Rocky Mountains (USA)',
        'PST8PDT' => 'tidssone for den nordamerikanske Stillehavskysten',
        'Pacific/Apia' => 'tidssone for Apia',
        'Pacific/Auckland' => 'newzealandsk tid (Auckland)',
        'Pacific/Bougainville' => 'papuansk tid (Bougainville)',
        'Pacific/Chatham' => 'tidssone for Chatham',
        'Pacific/Easter' => 'tidssone for Påskeøya',
        'Pacific/Efate' => 'vanuatisk tid (Efate)',
        'Pacific/Enderbury' => 'tidssone for Phoenixøyene (Enderbury)',
        'Pacific/Fakaofo' => 'tidssone for Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'fijiansk tid',
        'Pacific/Funafuti' => 'tuvalsk tid (Funafuti)',
        'Pacific/Galapagos' => 'tidssone for Galápagosøyene',
        'Pacific/Gambier' => 'tidssone for Gambier',
        'Pacific/Guadalcanal' => 'salomonsk tid (Guadalcanal)',
        'Pacific/Guam' => 'tidssone for Chamorro (Guam)',
        'Pacific/Honolulu' => 'tidssone for Hawaii og Aleutene (Honolulu)',
        'Pacific/Johnston' => 'tidssone for Hawaii og Aleutene (Johnston)',
        'Pacific/Kiritimati' => 'tidssone for Linjeøyene (Kiritimati)',
        'Pacific/Kosrae' => 'tidssone for Kosrae',
        'Pacific/Kwajalein' => 'marshallesisk tid (Kwajalein)',
        'Pacific/Majuro' => 'marshallesisk tid (Majuro)',
        'Pacific/Marquesas' => 'tidssone for Marquesasøyene',
        'Pacific/Midway' => 'samoansk tid (Midway)',
        'Pacific/Nauru' => 'naurisk tid (Nauru)',
        'Pacific/Niue' => 'tidssone for Niue',
        'Pacific/Norfolk' => 'tidssone for Norfolkøya',
        'Pacific/Noumea' => 'kaledonsk tid (Nouméa)',
        'Pacific/Pago_Pago' => 'samoansk tid (Pago Pago)',
        'Pacific/Palau' => 'palauisk tid',
        'Pacific/Pitcairn' => 'tidssone for Pitcairn',
        'Pacific/Ponape' => 'tidssone for Pohnpei',
        'Pacific/Port_Moresby' => 'papuansk tid (Port Moresby)',
        'Pacific/Rarotonga' => 'tidssone for Cookøyene (Rarotonga)',
        'Pacific/Saipan' => 'tidssone for Chamorro (Saipan)',
        'Pacific/Tahiti' => 'tahitisk tid',
        'Pacific/Tarawa' => 'tidssone for Gilbertøyene (Tarawa)',
        'Pacific/Tongatapu' => 'tongansk tid (Tongatapu)',
        'Pacific/Truk' => 'tidssone for Chuukøyene',
        'Pacific/Wake' => 'tidssone for Wake Island',
        'Pacific/Wallis' => 'tidssone for Wallis- og Futunaøyene',
    ],
    'Meta' => [
    ],
];
