<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Afak' => 'Afaka',
        'Aghb' => 'Albàinis Chabhcasach',
        'Ahom' => 'Ahom',
        'Arab' => 'Arabais',
        'Aran' => 'Nastaliq',
        'Armi' => 'Aramais impireil',
        'Armn' => 'Airmeinis',
        'Avst' => 'Avestanais',
        'Bali' => 'Bali',
        'Bamu' => 'Bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batak',
        'Beng' => 'Beangailis',
        'Bhks' => 'Bhaiksuki',
        'Blis' => 'Comharran Bliss',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'Braille',
        'Bugi' => 'Lontara',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'Sgrìobhadh Lideach Aonaichte nan Tùsanach Canadach',
        'Cari' => 'Carian',
        'Cham' => 'Cham',
        'Cher' => 'Cherokee',
        'Chrs' => 'Khwarazm',
        'Cirt' => 'Cirth',
        'Copt' => 'Coptais',
        'Cpmn' => 'Mìneothais Chìopras',
        'Cprt' => 'Cìoprasais',
        'Cyrl' => 'Cirilis',
        'Cyrs' => 'Cirilis Seann-Slàbhais na h-Eaglaise',
        'Deva' => 'Devanagari',
        'Diak' => 'Dives Akuru',
        'Dogr' => 'Dogra',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Gearr-sgrìobhadh Duployé',
        'Egyp' => 'Sealbh-sgrìobhadh Èipheiteach',
        'Elba' => 'Elbasan',
        'Elym' => 'Elymaidheach',
        'Ethi' => 'Ge’ez',
        'Geor' => 'Cairtbheilis',
        'Glag' => 'Glagoliticeach',
        'Gong' => 'Gunjala Gondi',
        'Gonm' => 'Masaram Gondi',
        'Goth' => 'Gotais',
        'Gran' => 'Grantha',
        'Grek' => 'Greugais',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han le Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'Simplichte',
        'Hant' => 'Tradaiseanta',
        'Hatr' => 'Hatran',
        'Hebr' => 'Eabhra',
        'Hira' => 'Hiragana',
        'Hluw' => 'Dealbh-sgrìobhadh Anatolach',
        'Hmng' => 'Pahawh Hmong',
        'Hmnp' => 'Nyiakeng Puachue Hmong',
        'Hrkt' => 'Katakana no Hiragana',
        'Hung' => 'Seann-Ungarais',
        'Ital' => 'Seann-Eadailtis',
        'Jamo' => 'Jamo',
        'Java' => 'Deàbhanais',
        'Jpan' => 'Seapanais',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Kawi' => 'Kawi',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Cmèar',
        'Khoj' => 'Khojki',
        'Kits' => 'Litrichean beaga na Khitan',
        'Knda' => 'Kannada',
        'Kore' => 'Coirèanais',
        'Kpel' => 'Kpelle',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Làtho',
        'Latf' => 'Laideann fraktur',
        'Latg' => 'Laideann Ghàidhealach',
        'Latn' => 'Laideann',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Linear A',
        'Linb' => 'Linear B',
        'Lisu' => 'Lisu',
        'Loma' => 'Loma',
        'Lyci' => 'Lycian',
        'Lydi' => 'Lydian',
        'Mahj' => 'Mahajani',
        'Maka' => 'Makasar',
        'Mand' => 'Mandaean',
        'Mani' => 'Manichaean',
        'Marc' => 'Marchen',
        'Maya' => 'Dealbh-sgrìobhadh Mayach',
        'Medf' => 'Medefaidrin',
        'Mend' => 'Mende',
        'Merc' => 'Meroiticeach ceangailte',
        'Mero' => 'Meroiticeach',
        'Mlym' => 'Malayalam',
        'Modi' => 'Modi',
        'Mong' => 'Mongolais',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei Mayek',
        'Mult' => 'Multani',
        'Mymr' => 'Miànmar',
        'Nagm' => 'Nag Mundari',
        'Nand' => 'Nandinagari',
        'Narb' => 'Seann-Arabach Thuathach',
        'Nbat' => 'Nabataean',
        'Newa' => 'Newa',
        'Nkgb' => 'Naxi Geba',
        'Nkoo' => 'N’ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham-chraobh',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orkhon',
        'Orya' => 'Oriya',
        'Osge' => 'Osage',
        'Osma' => 'Osmanya',
        'Ougr' => 'Seann-Ùigiurais',
        'Palm' => 'Palmyrene',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Seann-Phermic',
        'Phag' => 'Phags-pa',
        'Phli' => 'Pahlavi nan snaidh-sgrìobhaidhean',
        'Phlp' => 'Pahlavi nan saltair',
        'Phnx' => 'Pheniceach',
        'Plrd' => 'Miao Phollard',
        'Prti' => 'Partais snaidh-sgrìobhte',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi Rohingya',
        'Roro' => 'Rongorongo',
        'Runr' => 'Rùn-sgrìobhadh',
        'Samr' => 'Samaritanais',
        'Sara' => 'Sarati',
        'Sarb' => 'Seann-Arabais Dheasach',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'Sgrìobhadh cainnte-sanais',
        'Shaw' => 'Sgrìobhadh an t-Seathaich',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Khudawadi',
        'Sinh' => 'Sinhala',
        'Sogd' => 'Sogdianais',
        'Sogo' => 'Seann-Sogdianais',
        'Sora' => 'Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Sunda',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Suraidheac',
        'Syrj' => 'Suraidheac Siarach',
        'Syrn' => 'Suraidheac Earach',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'Tai Lue Ùr',
        'Taml' => 'Taimil',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagalog',
        'Thaa' => 'Thaana',
        'Thai' => 'Tàidh',
        'Tibt' => 'Tibeitis',
        'Tirh' => 'Tirhuta',
        'Tnsa' => 'Tangsa',
        'Toto' => 'Toto',
        'Ugar' => 'Ugariticeach',
        'Vaii' => 'Vai',
        'Vith' => 'Vithkuqi',
        'Wara' => 'Varang Kshiti',
        'Wcho' => 'Wancho',
        'Wole' => 'Woleai',
        'Xpeo' => 'Seann-Pheirsis',
        'Xsux' => 'Gèinn-sgrìobhadh Sumer is Akkad',
        'Yezi' => 'Yezidis',
        'Yiii' => 'Yi',
        'Zanb' => 'Zanabazar ceàrnagach',
        'Zinh' => 'Dìleab',
        'Zmth' => 'Gnìomhairean matamataig',
        'Zsye' => 'Emoji',
        'Zsym' => 'Samhlaidhean',
        'Zxxx' => 'Gun sgrìobhadh',
        'Zyyy' => 'Coitcheann',
    ],
];
