<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'ar' => 'араббаг',
        'ar_001' => 'араббаг (Дуне)',
        'az' => 'тӕтӕйраг',
        'az_Cyrl' => 'тӕтӕйраг (Киррилицӕ)',
        'az_Latn' => 'тӕтӕйраг (Латинаг)',
        'bg' => 'болгайраг',
        'bs' => 'босниаг',
        'bs_Cyrl' => 'босниаг (Киррилицӕ)',
        'bs_Latn' => 'босниаг (Латинаг)',
        'ca' => 'каталайнаг',
        'ca_FR' => 'каталайнаг (Франц)',
        'ca_IT' => 'каталайнаг (Итали)',
        'ce' => 'цӕцӕйнаг',
        'ce_RU' => 'цӕцӕйнаг (Уӕрӕсе)',
        'cs' => 'чехаг',
        'cv' => 'чувашаг',
        'cv_RU' => 'чувашаг (Уӕрӕсе)',
        'da' => 'даниаг',
        'de' => 'немыцаг',
        'de_DE' => 'немыцаг (Герман)',
        'de_IT' => 'немыцаг (Итали)',
        'el' => 'бердзейнаг',
        'en' => 'англисаг',
        'en_001' => 'англисаг (Дуне)',
        'en_150' => 'англисаг (Европӕ)',
        'en_DE' => 'англисаг (Герман)',
        'en_GB' => 'англисаг (Стыр Британи)',
        'en_IN' => 'англисаг (Инди)',
        'en_US' => 'англисаг (АИШ)',
        'eo' => 'есперанто',
        'eo_001' => 'есперанто (Дуне)',
        'es' => 'испайнаг',
        'es_BR' => 'испайнаг (Бразили)',
        'es_US' => 'испайнаг (АИШ)',
        'et' => 'естойнаг',
        'eu' => 'баскаг',
        'fa' => 'персайнаг',
        'fi' => 'финнаг',
        'fo' => 'фарераг',
        'fr' => 'францаг',
        'fr_FR' => 'францаг (Франц)',
        'ga' => 'ирландиаг',
        'ga_GB' => 'ирландиаг (Стыр Британи)',
        'he' => 'уираг',
        'hr' => 'хорватаг',
        'hu' => 'венгериаг',
        'hy' => 'сомихаг',
        'it' => 'италиаг',
        'it_IT' => 'италиаг (Итали)',
        'ja' => 'япойнаг',
        'ja_JP' => 'япойнаг (Япон)',
        'ka' => 'гуырдзиаг',
        'ka_GE' => 'гуырдзиаг (Гуырдзыстон)',
        'ku' => 'курдаг',
        'mk' => 'мӕчъидон',
        'os' => 'ирон',
        'os_GE' => 'ирон (Гуырдзыстон)',
        'os_RU' => 'ирон (Уӕрӕсе)',
        'pt' => 'португалиаг',
        'pt_BR' => 'португалиаг (Бразили)',
        'ru' => 'уырыссаг',
        'ru_RU' => 'уырыссаг (Уӕрӕсе)',
        'zh' => 'китайаг',
        'zh_CN' => 'китайаг (Китай)',
        'zh_Hans' => 'китайаг (Ӕнцонгонд китайаг)',
        'zh_Hans_CN' => 'китайаг (Ӕнцонгонд китайаг, Китай)',
        'zh_Hant' => 'китайаг (Традицион китайаг)',
    ],
];
