<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Diramu re United Arab Emirates',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza ye Angola',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dora re Australia',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dhinari re Bhahareni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Furenki re Bhurundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pura re Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dora re Kanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Furenki re Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Furenki re Swisi',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan Renminbi ye China',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Dhora re Escudo',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Furenki re Jibhuti',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dhinari re Aljeria',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Paundi re Ijipita',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa re Eritrea',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Dhora re Etiopia',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuro',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Paundi ye Bhiriteni',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi ye Ghana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi ye Gambia',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Furenki re Gine',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupe re India',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni ye Japani',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shiringi ye Kenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Furenki re Komoro',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dora re Liberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ye Lesoto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinari re Libya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham ye Moroko',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Furenki re Malagasi',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya ye Moritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya ye Moritania',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupi ye Morishasi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha ye Malawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metika ye Mozambiki',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dora re Namibia',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira ye Nijeria',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Furenki re Ruwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyali re Saudi',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupi re Seyisheri',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Dinari re Sudani',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Paundi re Sudani',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Paundi re Senti Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leoni',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shiringi re Somalia',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra re Sao Tome ne Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra re Sao Tome ne Principe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinari re Tunisia',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shiringi re Tanzania',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shiringi re Uganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dora re Amerika',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Furenki CFA BEAC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Furenki CFA BCEAO',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randi',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha ye Zambia (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha ye Zambia',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dora re Zimbabwe',
        ],
    ],
];
