<?php

return [
    'Names' => [
        'az_Latn' => 'azerbaiyano (latín)',
        'az_Latn_AZ' => 'azerbaiyano (latín, Azerbaiyán)',
        'bs_BA' => 'bosnio (Bosnia-Herzegovina)',
        'bs_Cyrl_BA' => 'bosnio (cirílico, Bosnia-Herzegovina)',
        'bs_Latn' => 'bosnio (latín)',
        'bs_Latn_BA' => 'bosnio (latín, Bosnia-Herzegovina)',
        'en_UM' => 'inglés (Islas Ultramarinas de EE.UU.)',
        'eu' => 'vasco',
        'eu_ES' => 'vasco (España)',
        'ff_Latn' => 'fula (latín)',
        'ff_Latn_BF' => 'fula (latín, Burkina Faso)',
        'ff_Latn_CM' => 'fula (latín, Camerún)',
        'ff_Latn_GH' => 'fula (latín, Ghana)',
        'ff_Latn_GM' => 'fula (latín, Gambia)',
        'ff_Latn_GN' => 'fula (latín, Guinea)',
        'ff_Latn_GW' => 'fula (latín, Guinea-Bisáu)',
        'ff_Latn_LR' => 'fula (latín, Liberia)',
        'ff_Latn_MR' => 'fula (latín, Mauritania)',
        'ff_Latn_NE' => 'fula (latín, Níger)',
        'ff_Latn_NG' => 'fula (latín, Nigeria)',
        'ff_Latn_SL' => 'fula (latín, Sierra Leona)',
        'ff_Latn_SN' => 'fula (latín, Senegal)',
        'fr_CG' => 'francés (República del Congo)',
        'fr_CI' => 'francés (Costa de Marfil)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'hi_Latn' => 'hindi (latín)',
        'hi_Latn_IN' => 'hindi (latín, India)',
        'hr_BA' => 'croata (Bosnia-Herzegovina)',
        'ks' => 'cachemiro',
        'ks_Arab' => 'cachemiro (árabe)',
        'ks_Arab_IN' => 'cachemiro (árabe, India)',
        'ks_Deva' => 'cachemiro (devanagari)',
        'ks_Deva_IN' => 'cachemiro (devanagari, India)',
        'ks_IN' => 'cachemiro (India)',
        'ln_CG' => 'lingala (República del Congo)',
        'lo' => 'laosiano',
        'lo_LA' => 'laosiano (Laos)',
        'ml' => 'malabar',
        'ml_IN' => 'malabar (India)',
        'pa' => 'panyabí',
        'pa_Arab' => 'panyabí (árabe)',
        'pa_Arab_PK' => 'panyabí (árabe, Pakistán)',
        'pa_Guru' => 'panyabí (gurmuji)',
        'pa_Guru_IN' => 'panyabí (gurmuji, India)',
        'pa_IN' => 'panyabí (India)',
        'pa_PK' => 'panyabí (Pakistán)',
        'rm' => 'retorrománico',
        'rm_CH' => 'retorrománico (Suiza)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (árabe)',
        'sd_Arab_PK' => 'sindhi (árabe, Pakistán)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistán)',
        'sh_BA' => 'serbocroata (Bosnia-Herzegovina)',
        'sr_BA' => 'serbio (Bosnia-Herzegovina)',
        'sr_Cyrl_BA' => 'serbio (cirílico, Bosnia-Herzegovina)',
        'sr_Latn' => 'serbio (latín)',
        'sr_Latn_BA' => 'serbio (latín, Bosnia-Herzegovina)',
        'sr_Latn_ME' => 'serbio (latín, Montenegro)',
        'sr_Latn_RS' => 'serbio (latín, Serbia)',
        'su_Latn' => 'sundanés (latín)',
        'su_Latn_ID' => 'sundanés (latín, Indonesia)',
        'sv_AX' => 'sueco (Islas Åland)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (República Democrática del Congo)',
        'sw_KE' => 'swahili (Kenia)',
        'sw_TZ' => 'swahili (Tanzania)',
        'sw_UG' => 'swahili (Uganda)',
        'uz_Latn' => 'uzbeko (latín)',
        'uz_Latn_UZ' => 'uzbeko (latín, Uzbekistán)',
    ],
];
