<?php

return [
    'Names' => [
        'Africa/Bangui' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Bangui)',
        'Africa/Brazzaville' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Brazzaville)',
        'Africa/Casablanca' => 'Àkókò Ìwɔ Oòrùn Europe (Casablanca)',
        'Africa/Douala' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Douala)',
        'Africa/El_Aaiun' => 'Àkókò Ìwɔ Oòrùn Europe (El Aaiun)',
        'Africa/Kinshasa' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Kinshasa)',
        'Africa/Lagos' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Lagos)',
        'Africa/Libreville' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Libreville)',
        'Africa/Luanda' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Luanda)',
        'Africa/Malabo' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Malabo)',
        'Africa/Ndjamena' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Ndjamena)',
        'Africa/Niamey' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Niamey)',
        'Africa/Porto-Novo' => 'Àkókò Ìwɔ̀-Oòrùn Afírikà (Porto-Novo)',
        'America/Anchorage' => 'Àkókò Alásíkà (ìlú Ankɔ́réèjì)',
        'America/Argentina/La_Rioja' => 'Aago Ajɛntìnà (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Aago Ajɛntìnà (Rio Gallegos)',
        'America/Argentina/Salta' => 'Aago Ajɛntìnà (Salta)',
        'America/Argentina/San_Juan' => 'Aago Ajɛntìnà (San Juan)',
        'America/Argentina/San_Luis' => 'Aago Ajɛntìnà (San Luis)',
        'America/Argentina/Tucuman' => 'Aago Ajɛntìnà (Tucuman)',
        'America/Argentina/Ushuaia' => 'Aago Ajɛntìnà (Ushuaia)',
        'America/Bahia_Banderas' => 'àkókò àárín gbùngbùn (ìlú Báhì Bándɛ́rásì)',
        'America/Barbados' => 'Àkókò Àtìláńtíìkì (ìlú Bábádɔ́ɔ̀sì)',
        'America/Belize' => 'àkókò àárín gbùngbùn (ìlú Bɛ̀líìsì)',
        'America/Blanc-Sablon' => 'Àkókò Àtìláńtíìkì (ìlú Blank Sabulɔ́ɔ̀nì)',
        'America/Boa_Vista' => 'Àkókò Amásɔ́nì (Boa Vista)',
        'America/Boise' => 'Àkókò òkè (ìlú Bɔ́isè)',
        'America/Buenos_Aires' => 'Aago Ajɛntìnà (Buenos Aires)',
        'America/Campo_Grande' => 'Àkókò Amásɔ́nì (Campo Grande)',
        'America/Catamarca' => 'Aago Ajɛntìnà (Catamarca)',
        'America/Chihuahua' => 'Àkókò Pásífíìkì Mɛ́shíkò (ìlú Shihuahua)',
        'America/Coral_Harbour' => 'Àkókò ìhà ìlà oòrùn (ìlú àtikɔkàn)',
        'America/Cordoba' => 'Aago Ajɛntìnà (Cordoba)',
        'America/Creston' => 'Àkókò òkè (ìlú Kírɛstɔ́ɔ̀nù)',
        'America/Cuiaba' => 'Àkókò Amásɔ́nì (Cuiaba)',
        'America/Curacao' => 'Àkókò Àtìláńtíìkì (ìlú Kurashao)',
        'America/Dawson' => 'Àkókò Yúkɔ́nì (ìlú Dawson)',
        'America/Godthab' => 'Àkókò Ìwɔ̀ oorùn Greenland (ìlú Nuuk)',
        'America/Hermosillo' => 'Àkókò Pásífíìkì Mɛ́shíkò (ìlú Hermosilo)',
        'America/Indiana/Knox' => 'àkókò àárín gbùngbùn (ìlú nɔ́sì)',
        'America/Indiana/Marengo' => 'Àkókò ìhà ìlà oòrùn (ìlú Marɛ́ngo)',
        'America/Jujuy' => 'Aago Ajɛntìnà (Jujuy)',
        'America/Kentucky/Monticello' => 'Àkókò ìhà ìlà oòrùn (ìlú Montisɛ́lò)',
        'America/Kralendijk' => 'Àkókò Àtìláńtíìkì (ìlú Kíralɛ́ndáikì)',
        'America/Manaus' => 'Àkókò Amásɔ́nì (Manaus)',
        'America/Marigot' => 'Àkókò Àtìláńtíìkì (ìlú Marigɔ́ɔ̀tì)',
        'America/Mazatlan' => 'Àkókò Pásífíìkì Mɛ́shíkò (ìlú Masatiani)',
        'America/Mendoza' => 'Aago Ajɛntìnà (Mendoza)',
        'America/Mexico_City' => 'àkókò àárín gbùngbùn (ìlú Mɛ́síkò)',
        'America/Miquelon' => 'Àkókò Pierre & Miquelon (ìlú Mikulɔ́nì)',
        'America/Porto_Velho' => 'Àkókò Amásɔ́nì (Porto Velho)',
        'America/Punta_Arenas' => 'Àkókò Shílè (Punta Arenas)',
        'America/Santa_Isabel' => 'Àkókò Apá Ìwɔ̀ Oorùn Mɛ́shíkò (Santa Isabel)',
        'America/Santiago' => 'Àkókò Shílè (Santiago)',
        'America/St_Johns' => 'Àkókò Newfoundland (ìlú St Jɔ́ɔ̀nù)',
        'America/St_Thomas' => 'Àkókò Àtìláńtíìkì (ìlú St Tɔ́màsì)',
        'America/Swift_Current' => 'àkókò àárín gbùngbùn (ìlú Súfítù Kɔ̀rentì)',
        'America/Whitehorse' => 'Àkókò Yúkɔ́nì (ìlú Whitehosì)',
        'Antarctica/Palmer' => 'Àkókò Shílè (Palmer)',
        'Asia/Anadyr' => 'Ìgbà Rɔshia (Anadyr)',
        'Asia/Barnaul' => 'Ìgbà Rɔshia (Barnaul)',
        'Asia/Dubai' => 'Ìgbà Ɛmirate ti Awɔn Arabu (Dubai)',
        'Asia/Jakarta' => 'Àkókò Ìwɔ̀ oorùn Indonesia (Jakarta)',
        'Asia/Kamchatka' => 'Ìgbà Rɔshia (Kamchatka)',
        'Asia/Macau' => 'Àkókò Sháínà (Macao)',
        'Asia/Muscat' => 'Ìgbà Ɔɔma (Muscat)',
        'Asia/Pontianak' => 'Àkókò Ìwɔ̀ oorùn Indonesia (Pontianak)',
        'Asia/Shanghai' => 'Àkókò Sháínà (Shanghai)',
        'Asia/Tomsk' => 'Ìgbà Rɔshia (Tomsk)',
        'Asia/Urumqi' => 'Ìgbà Sháínà (Urumqi)',
        'Atlantic/Azores' => 'Àkókò Ásɔ́sì (Azores)',
        'Atlantic/Bermuda' => 'Àkókò Àtìláńtíìkì (ìlú Bɛ̀múdà)',
        'Atlantic/Canary' => 'Àkókò Ìwɔ Oòrùn Europe (Canary)',
        'Atlantic/Faeroe' => 'Àkókò Ìwɔ Oòrùn Europe (Faroe)',
        'Atlantic/Madeira' => 'Àkókò Ìwɔ Oòrùn Europe (Madeira)',
        'Atlantic/South_Georgia' => 'Àkókò Gúsù Jɔ́jíà (South Georgia)',
        'Etc/UTC' => 'Àpapɔ̀ Àkókò Àgbáyé',
        'Europe/Istanbul' => 'Ìgbà Tɔɔki (Istanbul)',
        'Europe/Kirov' => 'Ìgbà Rɔshia (Kirov)',
        'Europe/Lisbon' => 'Àkókò Ìwɔ Oòrùn Europe (Lisbon)',
        'Europe/Samara' => 'Ìgbà Rɔshia (Samara)',
        'Indian/Mahe' => 'Àkókò Sèshɛ́ɛ̀lì (Mahe)',
        'Indian/Mauritius' => 'Àkókò Máríshúshì (Mauritius)',
        'Indian/Reunion' => 'Àkókò Rɛ́yúníɔ́nì (Reunion)',
    ],
    'Meta' => [
    ],
];
