<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'andorranske pesetas',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'emiratarabiske dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afgansk afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afghanske afghani',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'albanske lek (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albanske lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'armenske dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'nederlandske antillegylden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angolanske kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'angolanske kwanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'angolanske nye kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'angolanske omjusterte kwanza (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'argentinske australer',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'argentinske peso ley',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'argentinsk pesos (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'argentinske pesos (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentinske pesos',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'østerrikske shilling',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'australske dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arubiske floriner',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'aserbajdsjanske manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'aserbajdsjanske manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'bosnisk-hercegovinske dinarer (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'bosnisk-hercegovinske konvertible mark',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'nye bosnisk-hercegovinske dinarer (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadiske dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladeshiske taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'belgiske franc (konvertible)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'belgiske franc',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'belgiske franc (finansielle)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'bulgarske lev (hard)',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'bulgarske lev (sosialist)',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'bulgarske lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'bulgarske lev (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahrainske dinarer',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'burundiske franc',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'bermudiske dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'bruneiske dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'bolivianske boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'bolivianske boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'bolivianske pesos',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'bolivianske mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'brasilianske cruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'brasilianske cruzados (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'brasilianske cruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'brasilianske real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'brasilianske cruzado novo (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'brasilianske cruzeiro (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'brasilianske cruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'bahamanske dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'bhutanske ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'burmesiske kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'botswanske pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'hviterussiske nye rubler (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'nye hviterussiske rubler',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'hviterussiske rubler (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'beliziske dollar',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'kanadiske dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'kongolesiske franc',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'sveitsiske franc',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR franc',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'chilenske escudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'chilenske unidades de fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'chilenske pesos',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'kinesiske yuan (offshore)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Kinas folkebank dollar',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'kinesiske yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'colombianske pesos',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'colombianske unidad de valor real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'costaricanske colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'serbiske dinarer (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'tsjekkoslovakiske koruna (hard)',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'kubanske konvertible pesos',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'kubanske pesos',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'kappverdiske escudos',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'kypriotiske pund',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'tsjekkiske koruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'østtyske mark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'tyske mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'djiboutiske franc',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'danske kroner',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dominikanske pesos',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'algeriske dinarer',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'ecuadorianske sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'ecuadorianske unidad de valor constante (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'estiske kroon',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egyptiske pund',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'eritreiske nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'spanske peseta (A–konto)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'spanske peseta (konvertibel konto)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'spanske peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'etiopiske birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'finske mark',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fijianske dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'falklandspund',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'franske franc',
        ],
        'GBP' => [
            0 => '£',
            1 => 'britiske pund',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'georgiske kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'georgiske lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ghanesisk cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ghanesiske cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'gibraltarske pund',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambiske dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'guineanske franc',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'guineanske syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekvatorialguineanske ekwele guineana',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'greske drakmer',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'guatemalanske quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'portugisiske guinea escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guinea-Bissau-pesos',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'guyanske dollar',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Hongkong-dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'honduranske lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'kroatiske dinarer',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kroatiske kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haitiske gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'ungarske forinter',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indonesiske rupier',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'irske pund',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'israelske pund',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'israelske shekler (1980–1985)',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'nye israelske shekler',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'indiske rupier',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'irakske dinarer',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iranske rialer',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'islandske kroner (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'islandske kroner',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'italienske lire',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamaikanske dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jordanske dinarer',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'japanske yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenyanske shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgisiske som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'kambodsjanske riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'komoriske franc',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'nordkoreanske won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'sørkoreanske hwan (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'sørkoreanske won (1945–1953)',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'sørkoreanske won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuwaitiske dinarer',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'caymanske dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kasakhstanske tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laotiske kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'libanesiske pund',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'srilankiske rupier',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'liberiske dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesothiske loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litauiske litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'litauiske talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'luxemburgske konvertible franc',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'luxemburgske franc',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'luxemburgske finansielle franc',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'latviske lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'latviske rubler',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'libyske dinarer',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'marokkanske dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'marokkanske franc',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'monegaskiske franc',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'moldovske cupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldovske leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'madagassiske ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'madagassiske franc',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'makedonske denarer',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'makedonske denarer (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'maliske franc',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'myanmarske kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongolske tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'makaoiske pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'mauritanske ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mauritanske ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'maltesiske lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'maltesiske pund',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'mauritiske rupier',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'maldiviske rupier',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldiviske rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'malawiske kwacha',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'meksikanske pesos',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'meksikanske sølvpesos (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'meksikanske unidad de inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malaysiske ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'mosambikiske escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'gamle mosambikiske metical',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'mosambikiske metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'namibiske dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nigerianske naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'nicaraguanske cordoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'nicaraguanske córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'nederlandske gylden',
        ],
        'NOK' => [
            0 => 'kr',
            1 => 'norske kroner',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepalske rupier',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'newzealandske dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'omanske rialer',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'panamanske balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'peruanske inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'peruanske sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'peruanske sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'papuanske kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'filippinske pesos',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistanske rupier',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'polske zloty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'polske zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'portugisiske escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paraguayanske guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'qatarske rialer',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'rhodesiske dollar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'rumenske leu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'rumenske leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'serbiske dinarer',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'russiske rubler',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'russiske rubler (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'rwandiske franc',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'saudiarabiske riyaler',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'salomonske dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'seychelliske rupier',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'sudanesiske dinarer (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sudanske pund',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'sudanesiske pund',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'svenske kroner',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singaporske dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'sankthelenske pund',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'slovenske tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'slovakiske koruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'sierraleonske leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'somaliske shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'surinamske dollar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'surinamske gylden',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'sørsudanske pund',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'saotomesiske dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'saotomesiske dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'sovjetiske rubler',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'salvadoranske colon',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'syriske pund',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'swazilandske lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'thailandske baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'tadsjikiske rubler',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tadsjikiske somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'turkmenske manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'turkmenske manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tunisiske dinarer',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'tonganske paʻanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'timoresiske escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'tyrkiske lire (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'tyrkiske lire',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'trinidadiske dollar',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'nye taiwanske dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'tanzanianske shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ukrainske hryvnia',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ukrainske karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'ugandiske shilling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ugandiske shilling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'amerikanske dollar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'amerikanske dollar (neste dag)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'amerikanske dollar (samme dag)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'uruguyanske pesos (indekserte enheter)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'uruguayanske pesos (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'uruguayanske pesos',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'usbekiske som',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'venezuelanske bolivar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venezuelanske bolivar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venezuelanske bolivar',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'vietnamesiske dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'vietnamesiske dong (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuatiske vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'samoanske tala',
        ],
        'XAF' => [
            0 => 'XAF',
            1 => 'sentralafrikanske CFA-franc',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'østkaribiske dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'europeisk valutaenhet',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'franske gullfranc',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'franske UIC-franc',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'vestafrikanske CFA-franc',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'CFP-franc',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET-fond',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'jemenittiske dinarer',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'jemenittiske rialer',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'jugoslaviske dinarer (hard)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'jugoslaviske noviy-dinarer',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'jugoslaviske konvertible dinarer',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'jugoslaviske reformerte dinarer (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'sørafrikanske rand (finansielle)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'sørafrikanske rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'zambiske kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'zambiske kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zairiske nye zaire',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zairiske zaire',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'zimbabwiske dollar (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'zimbabwisk dollar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'zimbabwisk dollar (2008)',
        ],
    ],
];
