<?php

return [
    'Names' => [
        'af' => 'Tiếng Afrikaans',
        'af_NA' => 'Tiếng Afrikaans (Namibia)',
        'af_ZA' => 'Tiếng Afrikaans (Nam Phi)',
        'ak' => 'Tiếng Akan',
        'ak_GH' => 'Tiếng Akan (Ghana)',
        'am' => 'Tiếng Amharic',
        'am_ET' => 'Tiếng Amharic (Ethiopia)',
        'ar' => 'Tiếng Ả Rập',
        'ar_001' => 'Tiếng Ả Rập (Thế giới)',
        'ar_AE' => 'Tiếng Ả Rập (Các Tiểu Vương quốc Ả Rập Thống nhất)',
        'ar_BH' => 'Tiếng Ả Rập (Bahrain)',
        'ar_DJ' => 'Tiếng Ả Rập (Djibouti)',
        'ar_DZ' => 'Tiếng Ả Rập (Algeria)',
        'ar_EG' => 'Tiếng Ả Rập (Ai Cập)',
        'ar_EH' => 'Tiếng Ả Rập (Tây Sahara)',
        'ar_ER' => 'Tiếng Ả Rập (Eritrea)',
        'ar_IL' => 'Tiếng Ả Rập (Israel)',
        'ar_IQ' => 'Tiếng Ả Rập (Iraq)',
        'ar_JO' => 'Tiếng Ả Rập (Jordan)',
        'ar_KM' => 'Tiếng Ả Rập (Comoros)',
        'ar_KW' => 'Tiếng Ả Rập (Kuwait)',
        'ar_LB' => 'Tiếng Ả Rập (Li-băng)',
        'ar_LY' => 'Tiếng Ả Rập (Libya)',
        'ar_MA' => 'Tiếng Ả Rập (Ma-rốc)',
        'ar_MR' => 'Tiếng Ả Rập (Mauritania)',
        'ar_OM' => 'Tiếng Ả Rập (Oman)',
        'ar_PS' => 'Tiếng Ả Rập (Lãnh thổ Palestine)',
        'ar_QA' => 'Tiếng Ả Rập (Qatar)',
        'ar_SA' => 'Tiếng Ả Rập (Ả Rập Xê-út)',
        'ar_SD' => 'Tiếng Ả Rập (Sudan)',
        'ar_SO' => 'Tiếng Ả Rập (Somalia)',
        'ar_SS' => 'Tiếng Ả Rập (Nam Sudan)',
        'ar_SY' => 'Tiếng Ả Rập (Syria)',
        'ar_TD' => 'Tiếng Ả Rập (Chad)',
        'ar_TN' => 'Tiếng Ả Rập (Tunisia)',
        'ar_YE' => 'Tiếng Ả Rập (Yemen)',
        'as' => 'Tiếng Assam',
        'as_IN' => 'Tiếng Assam (Ấn Độ)',
        'az' => 'Tiếng Azerbaijan',
        'az_AZ' => 'Tiếng Azerbaijan (Azerbaijan)',
        'az_Cyrl' => 'Tiếng Azerbaijan (Chữ Kirin)',
        'az_Cyrl_AZ' => 'Tiếng Azerbaijan (Chữ Kirin, Azerbaijan)',
        'az_Latn' => 'Tiếng Azerbaijan (Chữ La tinh)',
        'az_Latn_AZ' => 'Tiếng Azerbaijan (Chữ La tinh, Azerbaijan)',
        'be' => 'Tiếng Belarus',
        'be_BY' => 'Tiếng Belarus (Belarus)',
        'bg' => 'Tiếng Bulgaria',
        'bg_BG' => 'Tiếng Bulgaria (Bulgaria)',
        'bm' => 'Tiếng Bambara',
        'bm_ML' => 'Tiếng Bambara (Mali)',
        'bn' => 'Tiếng Bangla',
        'bn_BD' => 'Tiếng Bangla (Bangladesh)',
        'bn_IN' => 'Tiếng Bangla (Ấn Độ)',
        'bo' => 'Tiếng Tây Tạng',
        'bo_CN' => 'Tiếng Tây Tạng (Trung Quốc)',
        'bo_IN' => 'Tiếng Tây Tạng (Ấn Độ)',
        'br' => 'Tiếng Breton',
        'br_FR' => 'Tiếng Breton (Pháp)',
        'bs' => 'Tiếng Bosnia',
        'bs_BA' => 'Tiếng Bosnia (Bosnia và Herzegovina)',
        'bs_Cyrl' => 'Tiếng Bosnia (Chữ Kirin)',
        'bs_Cyrl_BA' => 'Tiếng Bosnia (Chữ Kirin, Bosnia và Herzegovina)',
        'bs_Latn' => 'Tiếng Bosnia (Chữ La tinh)',
        'bs_Latn_BA' => 'Tiếng Bosnia (Chữ La tinh, Bosnia và Herzegovina)',
        'ca' => 'Tiếng Catalan',
        'ca_AD' => 'Tiếng Catalan (Andorra)',
        'ca_ES' => 'Tiếng Catalan (Tây Ban Nha)',
        'ca_FR' => 'Tiếng Catalan (Pháp)',
        'ca_IT' => 'Tiếng Catalan (Italy)',
        'ce' => 'Tiếng Chechen',
        'ce_RU' => 'Tiếng Chechen (Nga)',
        'cs' => 'Tiếng Séc',
        'cs_CZ' => 'Tiếng Séc (Séc)',
        'cv' => 'Tiếng Chuvash',
        'cv_RU' => 'Tiếng Chuvash (Nga)',
        'cy' => 'Tiếng Wales',
        'cy_GB' => 'Tiếng Wales (Vương quốc Anh)',
        'da' => 'Tiếng Đan Mạch',
        'da_DK' => 'Tiếng Đan Mạch (Đan Mạch)',
        'da_GL' => 'Tiếng Đan Mạch (Greenland)',
        'de' => 'Tiếng Đức',
        'de_AT' => 'Tiếng Đức (Áo)',
        'de_BE' => 'Tiếng Đức (Bỉ)',
        'de_CH' => 'Tiếng Đức (Thụy Sĩ)',
        'de_DE' => 'Tiếng Đức (Đức)',
        'de_IT' => 'Tiếng Đức (Italy)',
        'de_LI' => 'Tiếng Đức (Liechtenstein)',
        'de_LU' => 'Tiếng Đức (Luxembourg)',
        'dz' => 'Tiếng Dzongkha',
        'dz_BT' => 'Tiếng Dzongkha (Bhutan)',
        'ee' => 'Tiếng Ewe',
        'ee_GH' => 'Tiếng Ewe (Ghana)',
        'ee_TG' => 'Tiếng Ewe (Togo)',
        'el' => 'Tiếng Hy Lạp',
        'el_CY' => 'Tiếng Hy Lạp (Síp)',
        'el_GR' => 'Tiếng Hy Lạp (Hy Lạp)',
        'en' => 'Tiếng Anh',
        'en_001' => 'Tiếng Anh (Thế giới)',
        'en_150' => 'Tiếng Anh (Châu Âu)',
        'en_AE' => 'Tiếng Anh (Các Tiểu Vương quốc Ả Rập Thống nhất)',
        'en_AG' => 'Tiếng Anh (Antigua và Barbuda)',
        'en_AI' => 'Tiếng Anh (Anguilla)',
        'en_AS' => 'Tiếng Anh (Samoa thuộc Mỹ)',
        'en_AT' => 'Tiếng Anh (Áo)',
        'en_AU' => 'Tiếng Anh (Australia)',
        'en_BB' => 'Tiếng Anh (Barbados)',
        'en_BE' => 'Tiếng Anh (Bỉ)',
        'en_BI' => 'Tiếng Anh (Burundi)',
        'en_BM' => 'Tiếng Anh (Bermuda)',
        'en_BS' => 'Tiếng Anh (Bahamas)',
        'en_BW' => 'Tiếng Anh (Botswana)',
        'en_BZ' => 'Tiếng Anh (Belize)',
        'en_CA' => 'Tiếng Anh (Canada)',
        'en_CC' => 'Tiếng Anh (Quần đảo Cocos [Keeling])',
        'en_CH' => 'Tiếng Anh (Thụy Sĩ)',
        'en_CK' => 'Tiếng Anh (Quần đảo Cook)',
        'en_CM' => 'Tiếng Anh (Cameroon)',
        'en_CX' => 'Tiếng Anh (Đảo Giáng Sinh)',
        'en_CY' => 'Tiếng Anh (Síp)',
        'en_DE' => 'Tiếng Anh (Đức)',
        'en_DK' => 'Tiếng Anh (Đan Mạch)',
        'en_DM' => 'Tiếng Anh (Dominica)',
        'en_ER' => 'Tiếng Anh (Eritrea)',
        'en_FI' => 'Tiếng Anh (Phần Lan)',
        'en_FJ' => 'Tiếng Anh (Fiji)',
        'en_FK' => 'Tiếng Anh (Quần đảo Falkland)',
        'en_FM' => 'Tiếng Anh (Micronesia)',
        'en_GB' => 'Tiếng Anh (Vương quốc Anh)',
        'en_GD' => 'Tiếng Anh (Grenada)',
        'en_GG' => 'Tiếng Anh (Guernsey)',
        'en_GH' => 'Tiếng Anh (Ghana)',
        'en_GI' => 'Tiếng Anh (Gibraltar)',
        'en_GM' => 'Tiếng Anh (Gambia)',
        'en_GU' => 'Tiếng Anh (Guam)',
        'en_GY' => 'Tiếng Anh (Guyana)',
        'en_HK' => 'Tiếng Anh (Đặc khu Hành chính Hồng Kông, Trung Quốc)',
        'en_IE' => 'Tiếng Anh (Ireland)',
        'en_IL' => 'Tiếng Anh (Israel)',
        'en_IM' => 'Tiếng Anh (Đảo Man)',
        'en_IN' => 'Tiếng Anh (Ấn Độ)',
        'en_IO' => 'Tiếng Anh (Lãnh thổ Ấn Độ Dương thuộc Anh)',
        'en_JE' => 'Tiếng Anh (Jersey)',
        'en_JM' => 'Tiếng Anh (Jamaica)',
        'en_KE' => 'Tiếng Anh (Kenya)',
        'en_KI' => 'Tiếng Anh (Kiribati)',
        'en_KN' => 'Tiếng Anh (St. Kitts và Nevis)',
        'en_KY' => 'Tiếng Anh (Quần đảo Cayman)',
        'en_LC' => 'Tiếng Anh (St. Lucia)',
        'en_LR' => 'Tiếng Anh (Liberia)',
        'en_LS' => 'Tiếng Anh (Lesotho)',
        'en_MG' => 'Tiếng Anh (Madagascar)',
        'en_MH' => 'Tiếng Anh (Quần đảo Marshall)',
        'en_MO' => 'Tiếng Anh (Đặc khu Hành chính Macao, Trung Quốc)',
        'en_MP' => 'Tiếng Anh (Quần đảo Bắc Mariana)',
        'en_MS' => 'Tiếng Anh (Montserrat)',
        'en_MT' => 'Tiếng Anh (Malta)',
        'en_MU' => 'Tiếng Anh (Mauritius)',
        'en_MV' => 'Tiếng Anh (Maldives)',
        'en_MW' => 'Tiếng Anh (Malawi)',
        'en_MY' => 'Tiếng Anh (Malaysia)',
        'en_NA' => 'Tiếng Anh (Namibia)',
        'en_NF' => 'Tiếng Anh (Đảo Norfolk)',
        'en_NG' => 'Tiếng Anh (Nigeria)',
        'en_NL' => 'Tiếng Anh (Hà Lan)',
        'en_NR' => 'Tiếng Anh (Nauru)',
        'en_NU' => 'Tiếng Anh (Niue)',
        'en_NZ' => 'Tiếng Anh (New Zealand)',
        'en_PG' => 'Tiếng Anh (Papua New Guinea)',
        'en_PH' => 'Tiếng Anh (Philippines)',
        'en_PK' => 'Tiếng Anh (Pakistan)',
        'en_PN' => 'Tiếng Anh (Quần đảo Pitcairn)',
        'en_PR' => 'Tiếng Anh (Puerto Rico)',
        'en_PW' => 'Tiếng Anh (Palau)',
        'en_RW' => 'Tiếng Anh (Rwanda)',
        'en_SB' => 'Tiếng Anh (Quần đảo Solomon)',
        'en_SC' => 'Tiếng Anh (Seychelles)',
        'en_SD' => 'Tiếng Anh (Sudan)',
        'en_SE' => 'Tiếng Anh (Thụy Điển)',
        'en_SG' => 'Tiếng Anh (Singapore)',
        'en_SH' => 'Tiếng Anh (St. Helena)',
        'en_SI' => 'Tiếng Anh (Slovenia)',
        'en_SL' => 'Tiếng Anh (Sierra Leone)',
        'en_SS' => 'Tiếng Anh (Nam Sudan)',
        'en_SX' => 'Tiếng Anh (Sint Maarten)',
        'en_SZ' => 'Tiếng Anh (Eswatini)',
        'en_TC' => 'Tiếng Anh (Quần đảo Turks và Caicos)',
        'en_TK' => 'Tiếng Anh (Tokelau)',
        'en_TO' => 'Tiếng Anh (Tonga)',
        'en_TT' => 'Tiếng Anh (Trinidad và Tobago)',
        'en_TV' => 'Tiếng Anh (Tuvalu)',
        'en_TZ' => 'Tiếng Anh (Tanzania)',
        'en_UG' => 'Tiếng Anh (Uganda)',
        'en_UM' => 'Tiếng Anh (Các tiểu đảo xa của Hoa Kỳ)',
        'en_US' => 'Tiếng Anh (Hoa Kỳ)',
        'en_VC' => 'Tiếng Anh (St. Vincent và Grenadines)',
        'en_VG' => 'Tiếng Anh (Quần đảo Virgin thuộc Anh)',
        'en_VI' => 'Tiếng Anh (Quần đảo Virgin thuộc Hoa Kỳ)',
        'en_VU' => 'Tiếng Anh (Vanuatu)',
        'en_WS' => 'Tiếng Anh (Samoa)',
        'en_ZA' => 'Tiếng Anh (Nam Phi)',
        'en_ZM' => 'Tiếng Anh (Zambia)',
        'en_ZW' => 'Tiếng Anh (Zimbabwe)',
        'eo' => 'Tiếng Quốc Tế Ngữ',
        'eo_001' => 'Tiếng Quốc Tế Ngữ (Thế giới)',
        'es' => 'Tiếng Tây Ban Nha',
        'es_419' => 'Tiếng Tây Ban Nha (Châu Mỹ La-tinh)',
        'es_AR' => 'Tiếng Tây Ban Nha (Argentina)',
        'es_BO' => 'Tiếng Tây Ban Nha (Bolivia)',
        'es_BR' => 'Tiếng Tây Ban Nha (Brazil)',
        'es_BZ' => 'Tiếng Tây Ban Nha (Belize)',
        'es_CL' => 'Tiếng Tây Ban Nha (Chile)',
        'es_CO' => 'Tiếng Tây Ban Nha (Colombia)',
        'es_CR' => 'Tiếng Tây Ban Nha (Costa Rica)',
        'es_CU' => 'Tiếng Tây Ban Nha (Cuba)',
        'es_DO' => 'Tiếng Tây Ban Nha (Cộng hòa Dominica)',
        'es_EC' => 'Tiếng Tây Ban Nha (Ecuador)',
        'es_ES' => 'Tiếng Tây Ban Nha (Tây Ban Nha)',
        'es_GQ' => 'Tiếng Tây Ban Nha (Guinea Xích Đạo)',
        'es_GT' => 'Tiếng Tây Ban Nha (Guatemala)',
        'es_HN' => 'Tiếng Tây Ban Nha (Honduras)',
        'es_MX' => 'Tiếng Tây Ban Nha (Mexico)',
        'es_NI' => 'Tiếng Tây Ban Nha (Nicaragua)',
        'es_PA' => 'Tiếng Tây Ban Nha (Panama)',
        'es_PE' => 'Tiếng Tây Ban Nha (Peru)',
        'es_PH' => 'Tiếng Tây Ban Nha (Philippines)',
        'es_PR' => 'Tiếng Tây Ban Nha (Puerto Rico)',
        'es_PY' => 'Tiếng Tây Ban Nha (Paraguay)',
        'es_SV' => 'Tiếng Tây Ban Nha (El Salvador)',
        'es_US' => 'Tiếng Tây Ban Nha (Hoa Kỳ)',
        'es_UY' => 'Tiếng Tây Ban Nha (Uruguay)',
        'es_VE' => 'Tiếng Tây Ban Nha (Venezuela)',
        'et' => 'Tiếng Estonia',
        'et_EE' => 'Tiếng Estonia (Estonia)',
        'eu' => 'Tiếng Basque',
        'eu_ES' => 'Tiếng Basque (Tây Ban Nha)',
        'fa' => 'Tiếng Ba Tư',
        'fa_AF' => 'Tiếng Ba Tư (Afghanistan)',
        'fa_IR' => 'Tiếng Ba Tư (Iran)',
        'ff' => 'Tiếng Fulah',
        'ff_Adlm' => 'Tiếng Fulah (Chữ Adlam)',
        'ff_Adlm_BF' => 'Tiếng Fulah (Chữ Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Tiếng Fulah (Chữ Adlam, Cameroon)',
        'ff_Adlm_GH' => 'Tiếng Fulah (Chữ Adlam, Ghana)',
        'ff_Adlm_GM' => 'Tiếng Fulah (Chữ Adlam, Gambia)',
        'ff_Adlm_GN' => 'Tiếng Fulah (Chữ Adlam, Guinea)',
        'ff_Adlm_GW' => 'Tiếng Fulah (Chữ Adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'Tiếng Fulah (Chữ Adlam, Liberia)',
        'ff_Adlm_MR' => 'Tiếng Fulah (Chữ Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Tiếng Fulah (Chữ Adlam, Niger)',
        'ff_Adlm_NG' => 'Tiếng Fulah (Chữ Adlam, Nigeria)',
        'ff_Adlm_SL' => 'Tiếng Fulah (Chữ Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Tiếng Fulah (Chữ Adlam, Senegal)',
        'ff_CM' => 'Tiếng Fulah (Cameroon)',
        'ff_GN' => 'Tiếng Fulah (Guinea)',
        'ff_Latn' => 'Tiếng Fulah (Chữ La tinh)',
        'ff_Latn_BF' => 'Tiếng Fulah (Chữ La tinh, Burkina Faso)',
        'ff_Latn_CM' => 'Tiếng Fulah (Chữ La tinh, Cameroon)',
        'ff_Latn_GH' => 'Tiếng Fulah (Chữ La tinh, Ghana)',
        'ff_Latn_GM' => 'Tiếng Fulah (Chữ La tinh, Gambia)',
        'ff_Latn_GN' => 'Tiếng Fulah (Chữ La tinh, Guinea)',
        'ff_Latn_GW' => 'Tiếng Fulah (Chữ La tinh, Guinea-Bissau)',
        'ff_Latn_LR' => 'Tiếng Fulah (Chữ La tinh, Liberia)',
        'ff_Latn_MR' => 'Tiếng Fulah (Chữ La tinh, Mauritania)',
        'ff_Latn_NE' => 'Tiếng Fulah (Chữ La tinh, Niger)',
        'ff_Latn_NG' => 'Tiếng Fulah (Chữ La tinh, Nigeria)',
        'ff_Latn_SL' => 'Tiếng Fulah (Chữ La tinh, Sierra Leone)',
        'ff_Latn_SN' => 'Tiếng Fulah (Chữ La tinh, Senegal)',
        'ff_MR' => 'Tiếng Fulah (Mauritania)',
        'ff_SN' => 'Tiếng Fulah (Senegal)',
        'fi' => 'Tiếng Phần Lan',
        'fi_FI' => 'Tiếng Phần Lan (Phần Lan)',
        'fo' => 'Tiếng Faroe',
        'fo_DK' => 'Tiếng Faroe (Đan Mạch)',
        'fo_FO' => 'Tiếng Faroe (Quần đảo Faroe)',
        'fr' => 'Tiếng Pháp',
        'fr_BE' => 'Tiếng Pháp (Bỉ)',
        'fr_BF' => 'Tiếng Pháp (Burkina Faso)',
        'fr_BI' => 'Tiếng Pháp (Burundi)',
        'fr_BJ' => 'Tiếng Pháp (Benin)',
        'fr_BL' => 'Tiếng Pháp (St. Barthélemy)',
        'fr_CA' => 'Tiếng Pháp (Canada)',
        'fr_CD' => 'Tiếng Pháp (Congo - Kinshasa)',
        'fr_CF' => 'Tiếng Pháp (Cộng hòa Trung Phi)',
        'fr_CG' => 'Tiếng Pháp (Congo - Brazzaville)',
        'fr_CH' => 'Tiếng Pháp (Thụy Sĩ)',
        'fr_CI' => 'Tiếng Pháp (Côte d’Ivoire)',
        'fr_CM' => 'Tiếng Pháp (Cameroon)',
        'fr_DJ' => 'Tiếng Pháp (Djibouti)',
        'fr_DZ' => 'Tiếng Pháp (Algeria)',
        'fr_FR' => 'Tiếng Pháp (Pháp)',
        'fr_GA' => 'Tiếng Pháp (Gabon)',
        'fr_GF' => 'Tiếng Pháp (Guiana thuộc Pháp)',
        'fr_GN' => 'Tiếng Pháp (Guinea)',
        'fr_GP' => 'Tiếng Pháp (Guadeloupe)',
        'fr_GQ' => 'Tiếng Pháp (Guinea Xích Đạo)',
        'fr_HT' => 'Tiếng Pháp (Haiti)',
        'fr_KM' => 'Tiếng Pháp (Comoros)',
        'fr_LU' => 'Tiếng Pháp (Luxembourg)',
        'fr_MA' => 'Tiếng Pháp (Ma-rốc)',
        'fr_MC' => 'Tiếng Pháp (Monaco)',
        'fr_MF' => 'Tiếng Pháp (St. Martin)',
        'fr_MG' => 'Tiếng Pháp (Madagascar)',
        'fr_ML' => 'Tiếng Pháp (Mali)',
        'fr_MQ' => 'Tiếng Pháp (Martinique)',
        'fr_MR' => 'Tiếng Pháp (Mauritania)',
        'fr_MU' => 'Tiếng Pháp (Mauritius)',
        'fr_NC' => 'Tiếng Pháp (New Caledonia)',
        'fr_NE' => 'Tiếng Pháp (Niger)',
        'fr_PF' => 'Tiếng Pháp (Polynesia thuộc Pháp)',
        'fr_PM' => 'Tiếng Pháp (Saint Pierre và Miquelon)',
        'fr_RE' => 'Tiếng Pháp (Réunion)',
        'fr_RW' => 'Tiếng Pháp (Rwanda)',
        'fr_SC' => 'Tiếng Pháp (Seychelles)',
        'fr_SN' => 'Tiếng Pháp (Senegal)',
        'fr_SY' => 'Tiếng Pháp (Syria)',
        'fr_TD' => 'Tiếng Pháp (Chad)',
        'fr_TG' => 'Tiếng Pháp (Togo)',
        'fr_TN' => 'Tiếng Pháp (Tunisia)',
        'fr_VU' => 'Tiếng Pháp (Vanuatu)',
        'fr_WF' => 'Tiếng Pháp (Wallis và Futuna)',
        'fr_YT' => 'Tiếng Pháp (Mayotte)',
        'fy' => 'Tiếng Frisia',
        'fy_NL' => 'Tiếng Frisia (Hà Lan)',
        'ga' => 'Tiếng Ireland',
        'ga_GB' => 'Tiếng Ireland (Vương quốc Anh)',
        'ga_IE' => 'Tiếng Ireland (Ireland)',
        'gd' => 'Tiếng Gael Scotland',
        'gd_GB' => 'Tiếng Gael Scotland (Vương quốc Anh)',
        'gl' => 'Tiếng Galician',
        'gl_ES' => 'Tiếng Galician (Tây Ban Nha)',
        'gu' => 'Tiếng Gujarati',
        'gu_IN' => 'Tiếng Gujarati (Ấn Độ)',
        'gv' => 'Tiếng Manx',
        'gv_IM' => 'Tiếng Manx (Đảo Man)',
        'ha' => 'Tiếng Hausa',
        'ha_GH' => 'Tiếng Hausa (Ghana)',
        'ha_NE' => 'Tiếng Hausa (Niger)',
        'ha_NG' => 'Tiếng Hausa (Nigeria)',
        'he' => 'Tiếng Do Thái',
        'he_IL' => 'Tiếng Do Thái (Israel)',
        'hi' => 'Tiếng Hindi',
        'hi_IN' => 'Tiếng Hindi (Ấn Độ)',
        'hi_Latn' => 'Tiếng Hindi (Chữ La tinh)',
        'hi_Latn_IN' => 'Tiếng Hindi (Chữ La tinh, Ấn Độ)',
        'hr' => 'Tiếng Croatia',
        'hr_BA' => 'Tiếng Croatia (Bosnia và Herzegovina)',
        'hr_HR' => 'Tiếng Croatia (Croatia)',
        'hu' => 'Tiếng Hungary',
        'hu_HU' => 'Tiếng Hungary (Hungary)',
        'hy' => 'Tiếng Armenia',
        'hy_AM' => 'Tiếng Armenia (Armenia)',
        'ia' => 'Tiếng Khoa Học Quốc Tế',
        'ia_001' => 'Tiếng Khoa Học Quốc Tế (Thế giới)',
        'id' => 'Tiếng Indonesia',
        'id_ID' => 'Tiếng Indonesia (Indonesia)',
        'ig' => 'Tiếng Igbo',
        'ig_NG' => 'Tiếng Igbo (Nigeria)',
        'ii' => 'Tiếng Di Tứ Xuyên',
        'ii_CN' => 'Tiếng Di Tứ Xuyên (Trung Quốc)',
        'is' => 'Tiếng Iceland',
        'is_IS' => 'Tiếng Iceland (Iceland)',
        'it' => 'Tiếng Italy',
        'it_CH' => 'Tiếng Italy (Thụy Sĩ)',
        'it_IT' => 'Tiếng Italy (Italy)',
        'it_SM' => 'Tiếng Italy (San Marino)',
        'it_VA' => 'Tiếng Italy (Thành Vatican)',
        'ja' => 'Tiếng Nhật',
        'ja_JP' => 'Tiếng Nhật (Nhật Bản)',
        'jv' => 'Tiếng Java',
        'jv_ID' => 'Tiếng Java (Indonesia)',
        'ka' => 'Tiếng Georgia',
        'ka_GE' => 'Tiếng Georgia (Georgia)',
        'ki' => 'Tiếng Kikuyu',
        'ki_KE' => 'Tiếng Kikuyu (Kenya)',
        'kk' => 'Tiếng Kazakh',
        'kk_KZ' => 'Tiếng Kazakh (Kazakhstan)',
        'kl' => 'Tiếng Kalaallisut',
        'kl_GL' => 'Tiếng Kalaallisut (Greenland)',
        'km' => 'Tiếng Khmer',
        'km_KH' => 'Tiếng Khmer (Campuchia)',
        'kn' => 'Tiếng Kannada',
        'kn_IN' => 'Tiếng Kannada (Ấn Độ)',
        'ko' => 'Tiếng Hàn',
        'ko_KP' => 'Tiếng Hàn (Triều Tiên)',
        'ko_KR' => 'Tiếng Hàn (Hàn Quốc)',
        'ks' => 'Tiếng Kashmir',
        'ks_Arab' => 'Tiếng Kashmir (Chữ Ả Rập)',
        'ks_Arab_IN' => 'Tiếng Kashmir (Chữ Ả Rập, Ấn Độ)',
        'ks_Deva' => 'Tiếng Kashmir (Chữ Devanagari)',
        'ks_Deva_IN' => 'Tiếng Kashmir (Chữ Devanagari, Ấn Độ)',
        'ks_IN' => 'Tiếng Kashmir (Ấn Độ)',
        'ku' => 'Tiếng Kurd',
        'ku_TR' => 'Tiếng Kurd (Thổ Nhĩ Kỳ)',
        'kw' => 'Tiếng Cornwall',
        'kw_GB' => 'Tiếng Cornwall (Vương quốc Anh)',
        'ky' => 'Tiếng Kyrgyz',
        'ky_KG' => 'Tiếng Kyrgyz (Kyrgyzstan)',
        'lb' => 'Tiếng Luxembourg',
        'lb_LU' => 'Tiếng Luxembourg (Luxembourg)',
        'lg' => 'Tiếng Ganda',
        'lg_UG' => 'Tiếng Ganda (Uganda)',
        'ln' => 'Tiếng Lingala',
        'ln_AO' => 'Tiếng Lingala (Angola)',
        'ln_CD' => 'Tiếng Lingala (Congo - Kinshasa)',
        'ln_CF' => 'Tiếng Lingala (Cộng hòa Trung Phi)',
        'ln_CG' => 'Tiếng Lingala (Congo - Brazzaville)',
        'lo' => 'Tiếng Lào',
        'lo_LA' => 'Tiếng Lào (Lào)',
        'lt' => 'Tiếng Litva',
        'lt_LT' => 'Tiếng Litva (Litva)',
        'lu' => 'Tiếng Luba-Katanga',
        'lu_CD' => 'Tiếng Luba-Katanga (Congo - Kinshasa)',
        'lv' => 'Tiếng Latvia',
        'lv_LV' => 'Tiếng Latvia (Latvia)',
        'mg' => 'Tiếng Malagasy',
        'mg_MG' => 'Tiếng Malagasy (Madagascar)',
        'mi' => 'Tiếng Māori',
        'mi_NZ' => 'Tiếng Māori (New Zealand)',
        'mk' => 'Tiếng Macedonia',
        'mk_MK' => 'Tiếng Macedonia (Bắc Macedonia)',
        'ml' => 'Tiếng Malayalam',
        'ml_IN' => 'Tiếng Malayalam (Ấn Độ)',
        'mn' => 'Tiếng Mông Cổ',
        'mn_MN' => 'Tiếng Mông Cổ (Mông Cổ)',
        'mr' => 'Tiếng Marathi',
        'mr_IN' => 'Tiếng Marathi (Ấn Độ)',
        'ms' => 'Tiếng Mã Lai',
        'ms_BN' => 'Tiếng Mã Lai (Brunei)',
        'ms_ID' => 'Tiếng Mã Lai (Indonesia)',
        'ms_MY' => 'Tiếng Mã Lai (Malaysia)',
        'ms_SG' => 'Tiếng Mã Lai (Singapore)',
        'mt' => 'Tiếng Malta',
        'mt_MT' => 'Tiếng Malta (Malta)',
        'my' => 'Tiếng Miến Điện',
        'my_MM' => 'Tiếng Miến Điện (Myanmar [Miến Điện])',
        'nb' => 'Tiếng Na Uy [Bokmål]',
        'nb_NO' => 'Tiếng Na Uy [Bokmål] (Na Uy)',
        'nb_SJ' => 'Tiếng Na Uy [Bokmål] (Svalbard và Jan Mayen)',
        'nd' => 'Tiếng Ndebele Miền Bắc',
        'nd_ZW' => 'Tiếng Ndebele Miền Bắc (Zimbabwe)',
        'ne' => 'Tiếng Nepal',
        'ne_IN' => 'Tiếng Nepal (Ấn Độ)',
        'ne_NP' => 'Tiếng Nepal (Nepal)',
        'nl' => 'Tiếng Hà Lan',
        'nl_AW' => 'Tiếng Hà Lan (Aruba)',
        'nl_BE' => 'Tiếng Hà Lan (Bỉ)',
        'nl_BQ' => 'Tiếng Hà Lan (Ca-ri-bê Hà Lan)',
        'nl_CW' => 'Tiếng Hà Lan (Curaçao)',
        'nl_NL' => 'Tiếng Hà Lan (Hà Lan)',
        'nl_SR' => 'Tiếng Hà Lan (Suriname)',
        'nl_SX' => 'Tiếng Hà Lan (Sint Maarten)',
        'nn' => 'Tiếng Na Uy [Nynorsk]',
        'nn_NO' => 'Tiếng Na Uy [Nynorsk] (Na Uy)',
        'no' => 'Tiếng Na Uy',
        'no_NO' => 'Tiếng Na Uy (Na Uy)',
        'om' => 'Tiếng Oromo',
        'om_ET' => 'Tiếng Oromo (Ethiopia)',
        'om_KE' => 'Tiếng Oromo (Kenya)',
        'or' => 'Tiếng Odia',
        'or_IN' => 'Tiếng Odia (Ấn Độ)',
        'os' => 'Tiếng Ossetic',
        'os_GE' => 'Tiếng Ossetic (Georgia)',
        'os_RU' => 'Tiếng Ossetic (Nga)',
        'pa' => 'Tiếng Punjab',
        'pa_Arab' => 'Tiếng Punjab (Chữ Ả Rập)',
        'pa_Arab_PK' => 'Tiếng Punjab (Chữ Ả Rập, Pakistan)',
        'pa_Guru' => 'Tiếng Punjab (Chữ Gurmukhi)',
        'pa_Guru_IN' => 'Tiếng Punjab (Chữ Gurmukhi, Ấn Độ)',
        'pa_IN' => 'Tiếng Punjab (Ấn Độ)',
        'pa_PK' => 'Tiếng Punjab (Pakistan)',
        'pl' => 'Tiếng Ba Lan',
        'pl_PL' => 'Tiếng Ba Lan (Ba Lan)',
        'ps' => 'Tiếng Pashto',
        'ps_AF' => 'Tiếng Pashto (Afghanistan)',
        'ps_PK' => 'Tiếng Pashto (Pakistan)',
        'pt' => 'Tiếng Bồ Đào Nha',
        'pt_AO' => 'Tiếng Bồ Đào Nha (Angola)',
        'pt_BR' => 'Tiếng Bồ Đào Nha (Brazil)',
        'pt_CH' => 'Tiếng Bồ Đào Nha (Thụy Sĩ)',
        'pt_CV' => 'Tiếng Bồ Đào Nha (Cape Verde)',
        'pt_GQ' => 'Tiếng Bồ Đào Nha (Guinea Xích Đạo)',
        'pt_GW' => 'Tiếng Bồ Đào Nha (Guinea-Bissau)',
        'pt_LU' => 'Tiếng Bồ Đào Nha (Luxembourg)',
        'pt_MO' => 'Tiếng Bồ Đào Nha (Đặc khu Hành chính Macao, Trung Quốc)',
        'pt_MZ' => 'Tiếng Bồ Đào Nha (Mozambique)',
        'pt_PT' => 'Tiếng Bồ Đào Nha (Bồ Đào Nha)',
        'pt_ST' => 'Tiếng Bồ Đào Nha (São Tomé và Príncipe)',
        'pt_TL' => 'Tiếng Bồ Đào Nha (Timor-Leste)',
        'qu' => 'Tiếng Quechua',
        'qu_BO' => 'Tiếng Quechua (Bolivia)',
        'qu_EC' => 'Tiếng Quechua (Ecuador)',
        'qu_PE' => 'Tiếng Quechua (Peru)',
        'rm' => 'Tiếng Romansh',
        'rm_CH' => 'Tiếng Romansh (Thụy Sĩ)',
        'rn' => 'Tiếng Rundi',
        'rn_BI' => 'Tiếng Rundi (Burundi)',
        'ro' => 'Tiếng Romania',
        'ro_MD' => 'Tiếng Romania (Moldova)',
        'ro_RO' => 'Tiếng Romania (Romania)',
        'ru' => 'Tiếng Nga',
        'ru_BY' => 'Tiếng Nga (Belarus)',
        'ru_KG' => 'Tiếng Nga (Kyrgyzstan)',
        'ru_KZ' => 'Tiếng Nga (Kazakhstan)',
        'ru_MD' => 'Tiếng Nga (Moldova)',
        'ru_RU' => 'Tiếng Nga (Nga)',
        'ru_UA' => 'Tiếng Nga (Ukraina)',
        'rw' => 'Tiếng Kinyarwanda',
        'rw_RW' => 'Tiếng Kinyarwanda (Rwanda)',
        'sa' => 'Tiếng Phạn',
        'sa_IN' => 'Tiếng Phạn (Ấn Độ)',
        'sc' => 'Tiếng Sardinia',
        'sc_IT' => 'Tiếng Sardinia (Italy)',
        'sd' => 'Tiếng Sindhi',
        'sd_Arab' => 'Tiếng Sindhi (Chữ Ả Rập)',
        'sd_Arab_PK' => 'Tiếng Sindhi (Chữ Ả Rập, Pakistan)',
        'sd_Deva' => 'Tiếng Sindhi (Chữ Devanagari)',
        'sd_Deva_IN' => 'Tiếng Sindhi (Chữ Devanagari, Ấn Độ)',
        'sd_IN' => 'Tiếng Sindhi (Ấn Độ)',
        'sd_PK' => 'Tiếng Sindhi (Pakistan)',
        'se' => 'Tiếng Sami Miền Bắc',
        'se_FI' => 'Tiếng Sami Miền Bắc (Phần Lan)',
        'se_NO' => 'Tiếng Sami Miền Bắc (Na Uy)',
        'se_SE' => 'Tiếng Sami Miền Bắc (Thụy Điển)',
        'sg' => 'Tiếng Sango',
        'sg_CF' => 'Tiếng Sango (Cộng hòa Trung Phi)',
        'sh' => 'Tiếng Serbo-Croatia',
        'sh_BA' => 'Tiếng Serbo-Croatia (Bosnia và Herzegovina)',
        'si' => 'Tiếng Sinhala',
        'si_LK' => 'Tiếng Sinhala (Sri Lanka)',
        'sk' => 'Tiếng Slovak',
        'sk_SK' => 'Tiếng Slovak (Slovakia)',
        'sl' => 'Tiếng Slovenia',
        'sl_SI' => 'Tiếng Slovenia (Slovenia)',
        'sn' => 'Tiếng Shona',
        'sn_ZW' => 'Tiếng Shona (Zimbabwe)',
        'so' => 'Tiếng Somali',
        'so_DJ' => 'Tiếng Somali (Djibouti)',
        'so_ET' => 'Tiếng Somali (Ethiopia)',
        'so_KE' => 'Tiếng Somali (Kenya)',
        'so_SO' => 'Tiếng Somali (Somalia)',
        'sq' => 'Tiếng Albania',
        'sq_AL' => 'Tiếng Albania (Albania)',
        'sq_MK' => 'Tiếng Albania (Bắc Macedonia)',
        'sr' => 'Tiếng Serbia',
        'sr_BA' => 'Tiếng Serbia (Bosnia và Herzegovina)',
        'sr_Cyrl' => 'Tiếng Serbia (Chữ Kirin)',
        'sr_Cyrl_BA' => 'Tiếng Serbia (Chữ Kirin, Bosnia và Herzegovina)',
        'sr_Cyrl_ME' => 'Tiếng Serbia (Chữ Kirin, Montenegro)',
        'sr_Cyrl_RS' => 'Tiếng Serbia (Chữ Kirin, Serbia)',
        'sr_Latn' => 'Tiếng Serbia (Chữ La tinh)',
        'sr_Latn_BA' => 'Tiếng Serbia (Chữ La tinh, Bosnia và Herzegovina)',
        'sr_Latn_ME' => 'Tiếng Serbia (Chữ La tinh, Montenegro)',
        'sr_Latn_RS' => 'Tiếng Serbia (Chữ La tinh, Serbia)',
        'sr_ME' => 'Tiếng Serbia (Montenegro)',
        'sr_RS' => 'Tiếng Serbia (Serbia)',
        'su' => 'Tiếng Sunda',
        'su_ID' => 'Tiếng Sunda (Indonesia)',
        'su_Latn' => 'Tiếng Sunda (Chữ La tinh)',
        'su_Latn_ID' => 'Tiếng Sunda (Chữ La tinh, Indonesia)',
        'sv' => 'Tiếng Thụy Điển',
        'sv_AX' => 'Tiếng Thụy Điển (Quần đảo Åland)',
        'sv_FI' => 'Tiếng Thụy Điển (Phần Lan)',
        'sv_SE' => 'Tiếng Thụy Điển (Thụy Điển)',
        'sw' => 'Tiếng Swahili',
        'sw_CD' => 'Tiếng Swahili (Congo - Kinshasa)',
        'sw_KE' => 'Tiếng Swahili (Kenya)',
        'sw_TZ' => 'Tiếng Swahili (Tanzania)',
        'sw_UG' => 'Tiếng Swahili (Uganda)',
        'ta' => 'Tiếng Tamil',
        'ta_IN' => 'Tiếng Tamil (Ấn Độ)',
        'ta_LK' => 'Tiếng Tamil (Sri Lanka)',
        'ta_MY' => 'Tiếng Tamil (Malaysia)',
        'ta_SG' => 'Tiếng Tamil (Singapore)',
        'te' => 'Tiếng Telugu',
        'te_IN' => 'Tiếng Telugu (Ấn Độ)',
        'tg' => 'Tiếng Tajik',
        'tg_TJ' => 'Tiếng Tajik (Tajikistan)',
        'th' => 'Tiếng Thái',
        'th_TH' => 'Tiếng Thái (Thái Lan)',
        'ti' => 'Tiếng Tigrinya',
        'ti_ER' => 'Tiếng Tigrinya (Eritrea)',
        'ti_ET' => 'Tiếng Tigrinya (Ethiopia)',
        'tk' => 'Tiếng Turkmen',
        'tk_TM' => 'Tiếng Turkmen (Turkmenistan)',
        'tl' => 'Tiếng Tagalog',
        'tl_PH' => 'Tiếng Tagalog (Philippines)',
        'to' => 'Tiếng Tonga',
        'to_TO' => 'Tiếng Tonga (Tonga)',
        'tr' => 'Tiếng Thổ Nhĩ Kỳ',
        'tr_CY' => 'Tiếng Thổ Nhĩ Kỳ (Síp)',
        'tr_TR' => 'Tiếng Thổ Nhĩ Kỳ (Thổ Nhĩ Kỳ)',
        'tt' => 'Tiếng Tatar',
        'tt_RU' => 'Tiếng Tatar (Nga)',
        'ug' => 'Tiếng Uyghur',
        'ug_CN' => 'Tiếng Uyghur (Trung Quốc)',
        'uk' => 'Tiếng Ukraina',
        'uk_UA' => 'Tiếng Ukraina (Ukraina)',
        'ur' => 'Tiếng Urdu',
        'ur_IN' => 'Tiếng Urdu (Ấn Độ)',
        'ur_PK' => 'Tiếng Urdu (Pakistan)',
        'uz' => 'Tiếng Uzbek',
        'uz_AF' => 'Tiếng Uzbek (Afghanistan)',
        'uz_Arab' => 'Tiếng Uzbek (Chữ Ả Rập)',
        'uz_Arab_AF' => 'Tiếng Uzbek (Chữ Ả Rập, Afghanistan)',
        'uz_Cyrl' => 'Tiếng Uzbek (Chữ Kirin)',
        'uz_Cyrl_UZ' => 'Tiếng Uzbek (Chữ Kirin, Uzbekistan)',
        'uz_Latn' => 'Tiếng Uzbek (Chữ La tinh)',
        'uz_Latn_UZ' => 'Tiếng Uzbek (Chữ La tinh, Uzbekistan)',
        'uz_UZ' => 'Tiếng Uzbek (Uzbekistan)',
        'vi' => 'Tiếng Việt',
        'vi_VN' => 'Tiếng Việt (Việt Nam)',
        'wo' => 'Tiếng Wolof',
        'wo_SN' => 'Tiếng Wolof (Senegal)',
        'xh' => 'Tiếng Xhosa',
        'xh_ZA' => 'Tiếng Xhosa (Nam Phi)',
        'yi' => 'Tiếng Yiddish',
        'yi_001' => 'Tiếng Yiddish (Thế giới)',
        'yo' => 'Tiếng Yoruba',
        'yo_BJ' => 'Tiếng Yoruba (Benin)',
        'yo_NG' => 'Tiếng Yoruba (Nigeria)',
        'zh' => 'Tiếng Trung',
        'zh_CN' => 'Tiếng Trung (Trung Quốc)',
        'zh_HK' => 'Tiếng Trung (Đặc khu Hành chính Hồng Kông, Trung Quốc)',
        'zh_Hans' => 'Tiếng Trung (Giản thể)',
        'zh_Hans_CN' => 'Tiếng Trung (Giản thể, Trung Quốc)',
        'zh_Hans_HK' => 'Tiếng Trung (Giản thể, Đặc khu Hành chính Hồng Kông, Trung Quốc)',
        'zh_Hans_MO' => 'Tiếng Trung (Giản thể, Đặc khu Hành chính Macao, Trung Quốc)',
        'zh_Hans_SG' => 'Tiếng Trung (Giản thể, Singapore)',
        'zh_Hant' => 'Tiếng Trung (Phồn thể)',
        'zh_Hant_HK' => 'Tiếng Trung (Phồn thể, Đặc khu Hành chính Hồng Kông, Trung Quốc)',
        'zh_Hant_MO' => 'Tiếng Trung (Phồn thể, Đặc khu Hành chính Macao, Trung Quốc)',
        'zh_Hant_TW' => 'Tiếng Trung (Phồn thể, Đài Loan)',
        'zh_MO' => 'Tiếng Trung (Đặc khu Hành chính Macao, Trung Quốc)',
        'zh_SG' => 'Tiếng Trung (Singapore)',
        'zh_TW' => 'Tiếng Trung (Đài Loan)',
        'zu' => 'Tiếng Zulu',
        'zu_ZA' => 'Tiếng Zulu (Nam Phi)',
    ],
];
