<?php

return [
    'Names' => [
        'ar' => 'арап',
        'ar_001' => 'арап (тӗнче)',
        'ar_AE' => 'арап (Арапсен Пӗрлешӳллӗ Эмирачӗ)',
        'ar_BH' => 'арап (Бахрейн)',
        'ar_DJ' => 'арап (Джибути)',
        'ar_DZ' => 'арап (Алжир)',
        'ar_EG' => 'арап (Египет)',
        'ar_EH' => 'арап (Анӑҫ Сахара)',
        'ar_ER' => 'арап (Эритрей)',
        'ar_IL' => 'арап (Израиль)',
        'ar_IQ' => 'арап (Ирак)',
        'ar_JO' => 'арап (Иордани)',
        'ar_KM' => 'арап (Комор утравӗсем)',
        'ar_KW' => 'арап (Кувейт)',
        'ar_LB' => 'арап (Ливан)',
        'ar_LY' => 'арап (Ливи)',
        'ar_MA' => 'арап (Марокко)',
        'ar_MR' => 'арап (Мавритани)',
        'ar_OM' => 'арап (Оман)',
        'ar_PS' => 'арап (Палестинӑн территорийӗсем)',
        'ar_QA' => 'арап (Катар)',
        'ar_SA' => 'арап (Сауд Аравийӗ)',
        'ar_SD' => 'арап (Судан)',
        'ar_SO' => 'арап (Сомали)',
        'ar_SS' => 'арап (Кӑнтӑр Судан)',
        'ar_SY' => 'арап (Сири)',
        'ar_TD' => 'арап (Чад)',
        'ar_TN' => 'арап (Тунис)',
        'ar_YE' => 'арап (Йемен)',
        'bn' => 'бенгал',
        'bn_BD' => 'бенгал (Бангладеш)',
        'bn_IN' => 'бенгал (Инди)',
        'cv' => 'чӑваш',
        'cv_RU' => 'чӑваш (Раҫҫей)',
        'de' => 'нимӗҫ',
        'de_AT' => 'нимӗҫ (Австри)',
        'de_BE' => 'нимӗҫ (Бельги)',
        'de_CH' => 'нимӗҫ (Швейцари)',
        'de_DE' => 'нимӗҫ (Германи)',
        'de_IT' => 'нимӗҫ (Итали)',
        'de_LI' => 'нимӗҫ (Лихтенштейн)',
        'de_LU' => 'нимӗҫ (Люксембург)',
        'en' => 'акӑлчан',
        'en_001' => 'акӑлчан (тӗнче)',
        'en_150' => 'акӑлчан (Европа)',
        'en_AE' => 'акӑлчан (Арапсен Пӗрлешӳллӗ Эмирачӗ)',
        'en_AG' => 'акӑлчан (Антигуа тата Барбуда)',
        'en_AI' => 'акӑлчан (Ангилья)',
        'en_AS' => 'акӑлчан (Америка Самоа)',
        'en_AT' => 'акӑлчан (Австри)',
        'en_AU' => 'акӑлчан (Австрали)',
        'en_BB' => 'акӑлчан (Барбадос)',
        'en_BE' => 'акӑлчан (Бельги)',
        'en_BI' => 'акӑлчан (Бурунди)',
        'en_BM' => 'акӑлчан (Бермуд утравӗсем)',
        'en_BS' => 'акӑлчан (Пахам утравӗсем)',
        'en_BW' => 'акӑлчан (Ботсвана)',
        'en_BZ' => 'акӑлчан (Белиз)',
        'en_CA' => 'акӑлчан (Канада)',
        'en_CC' => 'акӑлчан (Кокос утравӗсем)',
        'en_CH' => 'акӑлчан (Швейцари)',
        'en_CK' => 'акӑлчан (Кук утравӗсем)',
        'en_CM' => 'акӑлчан (Камерун)',
        'en_CX' => 'акӑлчан (Раштав утравӗ)',
        'en_CY' => 'акӑлчан (Кипр)',
        'en_DE' => 'акӑлчан (Германи)',
        'en_DK' => 'акӑлчан (Дани)',
        'en_DM' => 'акӑлчан (Доминика)',
        'en_ER' => 'акӑлчан (Эритрей)',
        'en_FI' => 'акӑлчан (Финлянди)',
        'en_FJ' => 'акӑлчан (Фиджи)',
        'en_FK' => 'акӑлчан (Фолкленд утравӗсем)',
        'en_FM' => 'акӑлчан (Микронези)',
        'en_GB' => 'акӑлчан (Аслӑ Британи)',
        'en_GD' => 'акӑлчан (Гренада)',
        'en_GG' => 'акӑлчан (Гернси)',
        'en_GH' => 'акӑлчан (Гана)',
        'en_GI' => 'акӑлчан (Гибралтар)',
        'en_GM' => 'акӑлчан (Гамби)',
        'en_GU' => 'акӑлчан (Гуам)',
        'en_GY' => 'акӑлчан (Гайана)',
        'en_HK' => 'акӑлчан (Гонконг [САР])',
        'en_IE' => 'акӑлчан (Ирланди)',
        'en_IL' => 'акӑлчан (Израиль)',
        'en_IM' => 'акӑлчан (Мэн утравӗ)',
        'en_IN' => 'акӑлчан (Инди)',
        'en_IO' => 'акӑлчан (Британин территори Инди океанӗре)',
        'en_JE' => 'акӑлчан (Джерси)',
        'en_JM' => 'акӑлчан (Ямайка)',
        'en_KE' => 'акӑлчан (Кени)',
        'en_KI' => 'акӑлчан (Кирибати)',
        'en_KN' => 'акӑлчан (Сент-Китс тата Невис)',
        'en_KY' => 'акӑлчан (Кайман утравӗсем)',
        'en_LC' => 'акӑлчан (Сент-Люсия)',
        'en_LR' => 'акӑлчан (Либери)',
        'en_LS' => 'акӑлчан (Лесото)',
        'en_MG' => 'акӑлчан (Мадагаскар)',
        'en_MH' => 'акӑлчан (Маршаллов утравӗсем)',
        'en_MO' => 'акӑлчан (Макао [САР])',
        'en_MP' => 'акӑлчан (Ҫурҫӗр Мариан утравӗсем)',
        'en_MS' => 'акӑлчан (Монтсеррат)',
        'en_MT' => 'акӑлчан (Мальта)',
        'en_MU' => 'акӑлчан (Маврики)',
        'en_MV' => 'акӑлчан (Мальдивсем)',
        'en_MW' => 'акӑлчан (Малави)',
        'en_MY' => 'акӑлчан (Малайзи)',
        'en_NA' => 'акӑлчан (Намиби)',
        'en_NF' => 'акӑлчан (Норфолк утравӗ)',
        'en_NG' => 'акӑлчан (Нигери)',
        'en_NL' => 'акӑлчан (Нидерланд)',
        'en_NR' => 'акӑлчан (Науру)',
        'en_NU' => 'акӑлчан (Ниуэ)',
        'en_NZ' => 'акӑлчан (Ҫӗнӗ Зеланди)',
        'en_PG' => 'акӑлчан (Папуа — Ҫӗнӗ Гвиней)',
        'en_PH' => 'акӑлчан (Филиппинсем)',
        'en_PK' => 'акӑлчан (Пакистан)',
        'en_PN' => 'акӑлчан (Питкэрн утравӗсем)',
        'en_PR' => 'акӑлчан (Пуэрто-Рико)',
        'en_PW' => 'акӑлчан (Палау)',
        'en_RW' => 'акӑлчан (Руанда)',
        'en_SB' => 'акӑлчан (Соломон утравӗсем)',
        'en_SC' => 'акӑлчан (Сейшел утравӗсем)',
        'en_SD' => 'акӑлчан (Судан)',
        'en_SE' => 'акӑлчан (Швеци)',
        'en_SG' => 'акӑлчан (Сингапур)',
        'en_SH' => 'акӑлчан (Сӑваплӑ Елена утравӗ)',
        'en_SI' => 'акӑлчан (Словени)',
        'en_SL' => 'акӑлчан (Сьерра-Леоне)',
        'en_SS' => 'акӑлчан (Кӑнтӑр Судан)',
        'en_SX' => 'акӑлчан (Синт-Мартен)',
        'en_SZ' => 'акӑлчан (Эсватини)',
        'en_TC' => 'акӑлчан (Тёркс тата Кайкос утравӗсем)',
        'en_TK' => 'акӑлчан (Токелау)',
        'en_TO' => 'акӑлчан (Тонга)',
        'en_TT' => 'акӑлчан (Тринидад тата Тобаго)',
        'en_TV' => 'акӑлчан (Тувалу)',
        'en_TZ' => 'акӑлчан (Танзани)',
        'en_UG' => 'акӑлчан (Уганда)',
        'en_UM' => 'акӑлчан (Тулашӗнчи утравӗсем [АПШ])',
        'en_US' => 'акӑлчан (Пӗрлешӗннӗ Штатсем)',
        'en_VC' => 'акӑлчан (Сент-Винсент тата Гренадины)',
        'en_VG' => 'акӑлчан (Британин Виргини утравӗсем)',
        'en_VI' => 'акӑлчан (Виргини утравӗсем [АПШ])',
        'en_VU' => 'акӑлчан (Вануату)',
        'en_WS' => 'акӑлчан (Самоа)',
        'en_ZA' => 'акӑлчан (Кӑнтӑр Африка Республики)',
        'en_ZM' => 'акӑлчан (Замби)',
        'en_ZW' => 'акӑлчан (Зимбабве)',
        'es' => 'испани',
        'es_419' => 'испани (Латинла Америка)',
        'es_AR' => 'испани (Аргентина)',
        'es_BO' => 'испани (Боливи)',
        'es_BR' => 'испани (Бразили)',
        'es_BZ' => 'испани (Белиз)',
        'es_CL' => 'испани (Чили)',
        'es_CO' => 'испани (Колумби)',
        'es_CR' => 'испани (Коста-Рика)',
        'es_CU' => 'испани (Куба)',
        'es_DO' => 'испани (Доминикан Республики)',
        'es_EC' => 'испани (Эквадор)',
        'es_ES' => 'испани (Испани)',
        'es_GQ' => 'испани (Экваториаллӑ Гвиней)',
        'es_GT' => 'испани (Гватемала)',
        'es_HN' => 'испани (Гондурас)',
        'es_MX' => 'испани (Мексика)',
        'es_NI' => 'испани (Никарагуа)',
        'es_PA' => 'испани (Панама)',
        'es_PE' => 'испани (Перу)',
        'es_PH' => 'испани (Филиппинсем)',
        'es_PR' => 'испани (Пуэрто-Рико)',
        'es_PY' => 'испани (Парагвай)',
        'es_SV' => 'испани (Сальвадор)',
        'es_US' => 'испани (Пӗрлешӗннӗ Штатсем)',
        'es_UY' => 'испани (Уругвай)',
        'es_VE' => 'испани (Венесуэла)',
        'fr' => 'франци',
        'fr_BE' => 'франци (Бельги)',
        'fr_BF' => 'франци (Буркина-Фасо)',
        'fr_BI' => 'франци (Бурунди)',
        'fr_BJ' => 'франци (Бенин)',
        'fr_BL' => 'франци (Сен-Бартелеми)',
        'fr_CA' => 'франци (Канада)',
        'fr_CD' => 'франци (Конго - Киншаса)',
        'fr_CF' => 'франци (Тӗп Африка Республики)',
        'fr_CG' => 'франци (Конго - Браззавиль)',
        'fr_CH' => 'франци (Швейцари)',
        'fr_CI' => 'франци (Кот-д’Ивуар)',
        'fr_CM' => 'франци (Камерун)',
        'fr_DJ' => 'франци (Джибути)',
        'fr_DZ' => 'франци (Алжир)',
        'fr_FR' => 'франци (Франци)',
        'fr_GA' => 'франци (Габон)',
        'fr_GF' => 'франци (Франци Гвиана)',
        'fr_GN' => 'франци (Гвиней)',
        'fr_GP' => 'франци (Гваделупа)',
        'fr_GQ' => 'франци (Экваториаллӑ Гвиней)',
        'fr_HT' => 'франци (Гаити)',
        'fr_KM' => 'франци (Комор утравӗсем)',
        'fr_LU' => 'франци (Люксембург)',
        'fr_MA' => 'франци (Марокко)',
        'fr_MC' => 'франци (Монако)',
        'fr_MF' => 'франци (Сен-Мартен)',
        'fr_MG' => 'франци (Мадагаскар)',
        'fr_ML' => 'франци (Мали)',
        'fr_MQ' => 'франци (Мартиника)',
        'fr_MR' => 'франци (Мавритани)',
        'fr_MU' => 'франци (Маврики)',
        'fr_NC' => 'франци (Ҫӗнӗ Каледони)',
        'fr_NE' => 'франци (Нигер)',
        'fr_PF' => 'франци (Франци Полинези)',
        'fr_PM' => 'франци (Сен-Пьер & Микелон)',
        'fr_RE' => 'франци (Реюньон)',
        'fr_RW' => 'франци (Руанда)',
        'fr_SC' => 'франци (Сейшел утравӗсем)',
        'fr_SN' => 'франци (Сенегал)',
        'fr_SY' => 'франци (Сири)',
        'fr_TD' => 'франци (Чад)',
        'fr_TG' => 'франци (Того)',
        'fr_TN' => 'франци (Тунис)',
        'fr_VU' => 'франци (Вануату)',
        'fr_WF' => 'франци (Уоллис тата Футуна)',
        'fr_YT' => 'франци (Майотта)',
        'hi' => 'хинди',
        'hi_IN' => 'хинди (Инди)',
        'hi_Latn' => 'хинди (латин)',
        'hi_Latn_IN' => 'хинди (латин, Инди)',
        'id' => 'индонези',
        'id_ID' => 'индонези (Индонези)',
        'it' => 'итали',
        'it_CH' => 'итали (Швейцари)',
        'it_IT' => 'итали (Итали)',
        'it_SM' => 'итали (Сан-Марино)',
        'it_VA' => 'итали (Ватикан)',
        'ja' => 'япони',
        'ja_JP' => 'япони (Япони)',
        'ko' => 'корей',
        'ko_KP' => 'корей (КХДР)',
        'ko_KR' => 'корей (Корей Республики)',
        'nl' => 'голланди',
        'nl_AW' => 'голланди (Аруба)',
        'nl_BE' => 'голланди (Бельги)',
        'nl_BQ' => 'голланди (Бонэйр, Синт-Эстатиус тата Саба)',
        'nl_CW' => 'голланди (Кюрасао)',
        'nl_NL' => 'голланди (Нидерланд)',
        'nl_SR' => 'голланди (Суринам)',
        'nl_SX' => 'голланди (Синт-Мартен)',
        'pl' => 'поляк',
        'pl_PL' => 'поляк (Польша)',
        'pt' => 'португали',
        'pt_AO' => 'португали (Ангола)',
        'pt_BR' => 'португали (Бразили)',
        'pt_CH' => 'португали (Швейцари)',
        'pt_CV' => 'португали (Кабо-Верде)',
        'pt_GQ' => 'португали (Экваториаллӑ Гвиней)',
        'pt_GW' => 'португали (Гвиней-Бисау)',
        'pt_LU' => 'португали (Люксембург)',
        'pt_MO' => 'португали (Макао [САР])',
        'pt_MZ' => 'португали (Мозамбик)',
        'pt_PT' => 'португали (Португали)',
        'pt_ST' => 'португали (Сан-Томе тата Принсипи)',
        'pt_TL' => 'португали (Хӗвелтухӑҫ Тимор)',
        'ru' => 'вырӑс',
        'ru_BY' => 'вырӑс (Беларуҫ)',
        'ru_KG' => 'вырӑс (Киргизи)',
        'ru_KZ' => 'вырӑс (Казахстан)',
        'ru_MD' => 'вырӑс (Молдова)',
        'ru_RU' => 'вырӑс (Раҫҫей)',
        'ru_UA' => 'вырӑс (Украина)',
        'th' => 'тай',
        'th_TH' => 'тай (Таиланд)',
        'tr' => 'турккӑ',
        'tr_CY' => 'турккӑ (Кипр)',
        'tr_TR' => 'турккӑ (Турци)',
        'zh' => 'китай',
        'zh_CN' => 'китай (Китай)',
        'zh_HK' => 'китай (Гонконг [САР])',
        'zh_Hans' => 'китай (ҫӑмӑллатнӑн китай)',
        'zh_Hans_CN' => 'китай (ҫӑмӑллатнӑн китай, Китай)',
        'zh_Hans_HK' => 'китай (ҫӑмӑллатнӑн китай, Гонконг [САР])',
        'zh_Hans_MO' => 'китай (ҫӑмӑллатнӑн китай, Макао [САР])',
        'zh_Hans_SG' => 'китай (ҫӑмӑллатнӑн китай, Сингапур)',
        'zh_Hant' => 'китай (традициллӗн китай)',
        'zh_Hant_HK' => 'китай (традициллӗн китай, Гонконг [САР])',
        'zh_Hant_MO' => 'китай (традициллӗн китай, Макао [САР])',
        'zh_Hant_TW' => 'китай (традициллӗн китай, Тайвань)',
        'zh_MO' => 'китай (Макао [САР])',
        'zh_SG' => 'китай (Сингапур)',
        'zh_TW' => 'китай (Тайвань)',
    ],
];
