<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Diraamu eya Emireeti',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza ey’Angola',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Doola ey’Awusiturelya',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinaali ey’eBaareeni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Faranga ey’eburundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula ey’eBotiswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Doola ey’eKanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Faranga ey’eKongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Faranga ey’eSwitizirandi',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuwani Reniminibi ey’eCayina',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Esikudo ey’Keepu Veredi',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Faranga ey’eJjibuti',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinaali ey’Aligerya',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Pawundi ey’eMisiri',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakifa ey’Eritureya',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Biiru ey’Esyopya',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuro',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Pawundi ey’eBungereza',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi ey’eGana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi ey’eGambya',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Faranga ey’eGini',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupiya ey’eBuyindi',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni ey’eJapani',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Silingi ey’eKenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Faranga ey’eKomoro',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Doola ey’eLiberya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ey’eLesoso',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinaali ey’eLibya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Diraamu ey’eMoroko',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Faranga ey’eMalagase',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Wugwiya ey’eMawritenya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Wugwiya ey’eMawritenya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupiya ey’eMawurisyasi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwaca ey’eMalawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikaali ey’eMozambiiki',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Doola ey’eNamibiya',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nayira ey’eNayijerya',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Faranga ey’eRwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyaali ey’eBuwarabu',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupiya ey’eSesere',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Dinaali ey’eSudaani',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Pawundi ey’eSudaani',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Pawundi ey’eSenti Herena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Lewone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Silingi ey’eSomaliya',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobura ey’eSantome ne Purincipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobura ey’eSantome ne Purincipe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinaali ey’eTunizya',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Silingi ey’eTanzaniya',
        ],
        'UGX' => [
            0 => 'USh',
            1 => 'Silingi eya Yuganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Doola ey’Amerika',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Faranga ey’omu Afirika eya wakati',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faranga ey’omu Afirika ey’ebugwanjuba',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randi ey’eSawusafirika',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwaca ey’eZambya (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwaca ey’eZambya',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Doola ey’eZimbabwe',
        ],
    ],
];
