<?php

return [
    'Names' => [
        'af' => 'afrikánština',
        'af_NA' => 'afrikánština (Namibie)',
        'af_ZA' => 'afrikánština (Jihoafrická republika)',
        'ak' => 'akanština',
        'ak_GH' => 'akanština (Ghana)',
        'am' => 'amharština',
        'am_ET' => 'amharština (Etiopie)',
        'ar' => 'arabština',
        'ar_001' => 'arabština (svět)',
        'ar_AE' => 'arabština (Spojené arabské emiráty)',
        'ar_BH' => 'arabština (Bahrajn)',
        'ar_DJ' => 'arabština (Džibutsko)',
        'ar_DZ' => 'arabština (Alžírsko)',
        'ar_EG' => 'arabština (Egypt)',
        'ar_EH' => 'arabština (Západní Sahara)',
        'ar_ER' => 'arabština (Eritrea)',
        'ar_IL' => 'arabština (Izrael)',
        'ar_IQ' => 'arabština (Irák)',
        'ar_JO' => 'arabština (Jordánsko)',
        'ar_KM' => 'arabština (Komory)',
        'ar_KW' => 'arabština (Kuvajt)',
        'ar_LB' => 'arabština (Libanon)',
        'ar_LY' => 'arabština (Libye)',
        'ar_MA' => 'arabština (Maroko)',
        'ar_MR' => 'arabština (Mauritánie)',
        'ar_OM' => 'arabština (Omán)',
        'ar_PS' => 'arabština (Palestinská území)',
        'ar_QA' => 'arabština (Katar)',
        'ar_SA' => 'arabština (Saúdská Arábie)',
        'ar_SD' => 'arabština (Súdán)',
        'ar_SO' => 'arabština (Somálsko)',
        'ar_SS' => 'arabština (Jižní Súdán)',
        'ar_SY' => 'arabština (Sýrie)',
        'ar_TD' => 'arabština (Čad)',
        'ar_TN' => 'arabština (Tunisko)',
        'ar_YE' => 'arabština (Jemen)',
        'as' => 'ásámština',
        'as_IN' => 'ásámština (Indie)',
        'az' => 'ázerbájdžánština',
        'az_AZ' => 'ázerbájdžánština (Ázerbájdžán)',
        'az_Cyrl' => 'ázerbájdžánština (cyrilice)',
        'az_Cyrl_AZ' => 'ázerbájdžánština (cyrilice, Ázerbájdžán)',
        'az_Latn' => 'ázerbájdžánština (latinka)',
        'az_Latn_AZ' => 'ázerbájdžánština (latinka, Ázerbájdžán)',
        'be' => 'běloruština',
        'be_BY' => 'běloruština (Bělorusko)',
        'bg' => 'bulharština',
        'bg_BG' => 'bulharština (Bulharsko)',
        'bm' => 'bambarština',
        'bm_ML' => 'bambarština (Mali)',
        'bn' => 'bengálština',
        'bn_BD' => 'bengálština (Bangladéš)',
        'bn_IN' => 'bengálština (Indie)',
        'bo' => 'tibetština',
        'bo_CN' => 'tibetština (Čína)',
        'bo_IN' => 'tibetština (Indie)',
        'br' => 'bretonština',
        'br_FR' => 'bretonština (Francie)',
        'bs' => 'bosenština',
        'bs_BA' => 'bosenština (Bosna a Hercegovina)',
        'bs_Cyrl' => 'bosenština (cyrilice)',
        'bs_Cyrl_BA' => 'bosenština (cyrilice, Bosna a Hercegovina)',
        'bs_Latn' => 'bosenština (latinka)',
        'bs_Latn_BA' => 'bosenština (latinka, Bosna a Hercegovina)',
        'ca' => 'katalánština',
        'ca_AD' => 'katalánština (Andorra)',
        'ca_ES' => 'katalánština (Španělsko)',
        'ca_FR' => 'katalánština (Francie)',
        'ca_IT' => 'katalánština (Itálie)',
        'ce' => 'čečenština',
        'ce_RU' => 'čečenština (Rusko)',
        'cs' => 'čeština',
        'cs_CZ' => 'čeština (Česko)',
        'cv' => 'čuvaština',
        'cv_RU' => 'čuvaština (Rusko)',
        'cy' => 'velština',
        'cy_GB' => 'velština (Spojené království)',
        'da' => 'dánština',
        'da_DK' => 'dánština (Dánsko)',
        'da_GL' => 'dánština (Grónsko)',
        'de' => 'němčina',
        'de_AT' => 'němčina (Rakousko)',
        'de_BE' => 'němčina (Belgie)',
        'de_CH' => 'němčina (Švýcarsko)',
        'de_DE' => 'němčina (Německo)',
        'de_IT' => 'němčina (Itálie)',
        'de_LI' => 'němčina (Lichtenštejnsko)',
        'de_LU' => 'němčina (Lucembursko)',
        'dz' => 'dzongkä',
        'dz_BT' => 'dzongkä (Bhútán)',
        'ee' => 'eweština',
        'ee_GH' => 'eweština (Ghana)',
        'ee_TG' => 'eweština (Togo)',
        'el' => 'řečtina',
        'el_CY' => 'řečtina (Kypr)',
        'el_GR' => 'řečtina (Řecko)',
        'en' => 'angličtina',
        'en_001' => 'angličtina (svět)',
        'en_150' => 'angličtina (Evropa)',
        'en_AE' => 'angličtina (Spojené arabské emiráty)',
        'en_AG' => 'angličtina (Antigua a Barbuda)',
        'en_AI' => 'angličtina (Anguilla)',
        'en_AS' => 'angličtina (Americká Samoa)',
        'en_AT' => 'angličtina (Rakousko)',
        'en_AU' => 'angličtina (Austrálie)',
        'en_BB' => 'angličtina (Barbados)',
        'en_BE' => 'angličtina (Belgie)',
        'en_BI' => 'angličtina (Burundi)',
        'en_BM' => 'angličtina (Bermudy)',
        'en_BS' => 'angličtina (Bahamy)',
        'en_BW' => 'angličtina (Botswana)',
        'en_BZ' => 'angličtina (Belize)',
        'en_CA' => 'angličtina (Kanada)',
        'en_CC' => 'angličtina (Kokosové ostrovy)',
        'en_CH' => 'angličtina (Švýcarsko)',
        'en_CK' => 'angličtina (Cookovy ostrovy)',
        'en_CM' => 'angličtina (Kamerun)',
        'en_CX' => 'angličtina (Vánoční ostrov)',
        'en_CY' => 'angličtina (Kypr)',
        'en_DE' => 'angličtina (Německo)',
        'en_DK' => 'angličtina (Dánsko)',
        'en_DM' => 'angličtina (Dominika)',
        'en_ER' => 'angličtina (Eritrea)',
        'en_FI' => 'angličtina (Finsko)',
        'en_FJ' => 'angličtina (Fidži)',
        'en_FK' => 'angličtina (Falklandské ostrovy)',
        'en_FM' => 'angličtina (Mikronésie)',
        'en_GB' => 'angličtina (Spojené království)',
        'en_GD' => 'angličtina (Grenada)',
        'en_GG' => 'angličtina (Guernsey)',
        'en_GH' => 'angličtina (Ghana)',
        'en_GI' => 'angličtina (Gibraltar)',
        'en_GM' => 'angličtina (Gambie)',
        'en_GU' => 'angličtina (Guam)',
        'en_GY' => 'angličtina (Guyana)',
        'en_HK' => 'angličtina (Hongkong – ZAO Číny)',
        'en_IE' => 'angličtina (Irsko)',
        'en_IL' => 'angličtina (Izrael)',
        'en_IM' => 'angličtina (Ostrov Man)',
        'en_IN' => 'angličtina (Indie)',
        'en_IO' => 'angličtina (Britské indickooceánské území)',
        'en_JE' => 'angličtina (Jersey)',
        'en_JM' => 'angličtina (Jamajka)',
        'en_KE' => 'angličtina (Keňa)',
        'en_KI' => 'angličtina (Kiribati)',
        'en_KN' => 'angličtina (Svatý Kryštof a Nevis)',
        'en_KY' => 'angličtina (Kajmanské ostrovy)',
        'en_LC' => 'angličtina (Svatá Lucie)',
        'en_LR' => 'angličtina (Libérie)',
        'en_LS' => 'angličtina (Lesotho)',
        'en_MG' => 'angličtina (Madagaskar)',
        'en_MH' => 'angličtina (Marshallovy ostrovy)',
        'en_MO' => 'angličtina (Macao – ZAO Číny)',
        'en_MP' => 'angličtina (Severní Mariany)',
        'en_MS' => 'angličtina (Montserrat)',
        'en_MT' => 'angličtina (Malta)',
        'en_MU' => 'angličtina (Mauricius)',
        'en_MV' => 'angličtina (Maledivy)',
        'en_MW' => 'angličtina (Malawi)',
        'en_MY' => 'angličtina (Malajsie)',
        'en_NA' => 'angličtina (Namibie)',
        'en_NF' => 'angličtina (Norfolk)',
        'en_NG' => 'angličtina (Nigérie)',
        'en_NL' => 'angličtina (Nizozemsko)',
        'en_NR' => 'angličtina (Nauru)',
        'en_NU' => 'angličtina (Niue)',
        'en_NZ' => 'angličtina (Nový Zéland)',
        'en_PG' => 'angličtina (Papua-Nová Guinea)',
        'en_PH' => 'angličtina (Filipíny)',
        'en_PK' => 'angličtina (Pákistán)',
        'en_PN' => 'angličtina (Pitcairnovy ostrovy)',
        'en_PR' => 'angličtina (Portoriko)',
        'en_PW' => 'angličtina (Palau)',
        'en_RW' => 'angličtina (Rwanda)',
        'en_SB' => 'angličtina (Šalamounovy ostrovy)',
        'en_SC' => 'angličtina (Seychely)',
        'en_SD' => 'angličtina (Súdán)',
        'en_SE' => 'angličtina (Švédsko)',
        'en_SG' => 'angličtina (Singapur)',
        'en_SH' => 'angličtina (Svatá Helena)',
        'en_SI' => 'angličtina (Slovinsko)',
        'en_SL' => 'angličtina (Sierra Leone)',
        'en_SS' => 'angličtina (Jižní Súdán)',
        'en_SX' => 'angličtina (Svatý Martin [Nizozemsko])',
        'en_SZ' => 'angličtina (Eswatini)',
        'en_TC' => 'angličtina (Turks a Caicos)',
        'en_TK' => 'angličtina (Tokelau)',
        'en_TO' => 'angličtina (Tonga)',
        'en_TT' => 'angličtina (Trinidad a Tobago)',
        'en_TV' => 'angličtina (Tuvalu)',
        'en_TZ' => 'angličtina (Tanzanie)',
        'en_UG' => 'angličtina (Uganda)',
        'en_UM' => 'angličtina (Menší odlehlé ostrovy USA)',
        'en_US' => 'angličtina (Spojené státy)',
        'en_VC' => 'angličtina (Svatý Vincenc a Grenadiny)',
        'en_VG' => 'angličtina (Britské Panenské ostrovy)',
        'en_VI' => 'angličtina (Americké Panenské ostrovy)',
        'en_VU' => 'angličtina (Vanuatu)',
        'en_WS' => 'angličtina (Samoa)',
        'en_ZA' => 'angličtina (Jihoafrická republika)',
        'en_ZM' => 'angličtina (Zambie)',
        'en_ZW' => 'angličtina (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (svět)',
        'es' => 'španělština',
        'es_419' => 'španělština (Latinská Amerika)',
        'es_AR' => 'španělština (Argentina)',
        'es_BO' => 'španělština (Bolívie)',
        'es_BR' => 'španělština (Brazílie)',
        'es_BZ' => 'španělština (Belize)',
        'es_CL' => 'španělština (Chile)',
        'es_CO' => 'španělština (Kolumbie)',
        'es_CR' => 'španělština (Kostarika)',
        'es_CU' => 'španělština (Kuba)',
        'es_DO' => 'španělština (Dominikánská republika)',
        'es_EC' => 'španělština (Ekvádor)',
        'es_ES' => 'španělština (Španělsko)',
        'es_GQ' => 'španělština (Rovníková Guinea)',
        'es_GT' => 'španělština (Guatemala)',
        'es_HN' => 'španělština (Honduras)',
        'es_MX' => 'španělština (Mexiko)',
        'es_NI' => 'španělština (Nikaragua)',
        'es_PA' => 'španělština (Panama)',
        'es_PE' => 'španělština (Peru)',
        'es_PH' => 'španělština (Filipíny)',
        'es_PR' => 'španělština (Portoriko)',
        'es_PY' => 'španělština (Paraguay)',
        'es_SV' => 'španělština (Salvador)',
        'es_US' => 'španělština (Spojené státy)',
        'es_UY' => 'španělština (Uruguay)',
        'es_VE' => 'španělština (Venezuela)',
        'et' => 'estonština',
        'et_EE' => 'estonština (Estonsko)',
        'eu' => 'baskičtina',
        'eu_ES' => 'baskičtina (Španělsko)',
        'fa' => 'perština',
        'fa_AF' => 'perština (Afghánistán)',
        'fa_IR' => 'perština (Írán)',
        'ff' => 'fulbština',
        'ff_Adlm' => 'fulbština (adlam)',
        'ff_Adlm_BF' => 'fulbština (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulbština (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fulbština (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulbština (adlam, Gambie)',
        'ff_Adlm_GN' => 'fulbština (adlam, Guinea)',
        'ff_Adlm_GW' => 'fulbština (adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulbština (adlam, Libérie)',
        'ff_Adlm_MR' => 'fulbština (adlam, Mauritánie)',
        'ff_Adlm_NE' => 'fulbština (adlam, Niger)',
        'ff_Adlm_NG' => 'fulbština (adlam, Nigérie)',
        'ff_Adlm_SL' => 'fulbština (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulbština (adlam, Senegal)',
        'ff_CM' => 'fulbština (Kamerun)',
        'ff_GN' => 'fulbština (Guinea)',
        'ff_Latn' => 'fulbština (latinka)',
        'ff_Latn_BF' => 'fulbština (latinka, Burkina Faso)',
        'ff_Latn_CM' => 'fulbština (latinka, Kamerun)',
        'ff_Latn_GH' => 'fulbština (latinka, Ghana)',
        'ff_Latn_GM' => 'fulbština (latinka, Gambie)',
        'ff_Latn_GN' => 'fulbština (latinka, Guinea)',
        'ff_Latn_GW' => 'fulbština (latinka, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulbština (latinka, Libérie)',
        'ff_Latn_MR' => 'fulbština (latinka, Mauritánie)',
        'ff_Latn_NE' => 'fulbština (latinka, Niger)',
        'ff_Latn_NG' => 'fulbština (latinka, Nigérie)',
        'ff_Latn_SL' => 'fulbština (latinka, Sierra Leone)',
        'ff_Latn_SN' => 'fulbština (latinka, Senegal)',
        'ff_MR' => 'fulbština (Mauritánie)',
        'ff_SN' => 'fulbština (Senegal)',
        'fi' => 'finština',
        'fi_FI' => 'finština (Finsko)',
        'fo' => 'faerština',
        'fo_DK' => 'faerština (Dánsko)',
        'fo_FO' => 'faerština (Faerské ostrovy)',
        'fr' => 'francouzština',
        'fr_BE' => 'francouzština (Belgie)',
        'fr_BF' => 'francouzština (Burkina Faso)',
        'fr_BI' => 'francouzština (Burundi)',
        'fr_BJ' => 'francouzština (Benin)',
        'fr_BL' => 'francouzština (Svatý Bartoloměj)',
        'fr_CA' => 'francouzština (Kanada)',
        'fr_CD' => 'francouzština (Kongo – Kinshasa)',
        'fr_CF' => 'francouzština (Středoafrická republika)',
        'fr_CG' => 'francouzština (Kongo – Brazzaville)',
        'fr_CH' => 'francouzština (Švýcarsko)',
        'fr_CI' => 'francouzština (Pobřeží slonoviny)',
        'fr_CM' => 'francouzština (Kamerun)',
        'fr_DJ' => 'francouzština (Džibutsko)',
        'fr_DZ' => 'francouzština (Alžírsko)',
        'fr_FR' => 'francouzština (Francie)',
        'fr_GA' => 'francouzština (Gabon)',
        'fr_GF' => 'francouzština (Francouzská Guyana)',
        'fr_GN' => 'francouzština (Guinea)',
        'fr_GP' => 'francouzština (Guadeloupe)',
        'fr_GQ' => 'francouzština (Rovníková Guinea)',
        'fr_HT' => 'francouzština (Haiti)',
        'fr_KM' => 'francouzština (Komory)',
        'fr_LU' => 'francouzština (Lucembursko)',
        'fr_MA' => 'francouzština (Maroko)',
        'fr_MC' => 'francouzština (Monako)',
        'fr_MF' => 'francouzština (Svatý Martin [Francie])',
        'fr_MG' => 'francouzština (Madagaskar)',
        'fr_ML' => 'francouzština (Mali)',
        'fr_MQ' => 'francouzština (Martinik)',
        'fr_MR' => 'francouzština (Mauritánie)',
        'fr_MU' => 'francouzština (Mauricius)',
        'fr_NC' => 'francouzština (Nová Kaledonie)',
        'fr_NE' => 'francouzština (Niger)',
        'fr_PF' => 'francouzština (Francouzská Polynésie)',
        'fr_PM' => 'francouzština (Saint-Pierre a Miquelon)',
        'fr_RE' => 'francouzština (Réunion)',
        'fr_RW' => 'francouzština (Rwanda)',
        'fr_SC' => 'francouzština (Seychely)',
        'fr_SN' => 'francouzština (Senegal)',
        'fr_SY' => 'francouzština (Sýrie)',
        'fr_TD' => 'francouzština (Čad)',
        'fr_TG' => 'francouzština (Togo)',
        'fr_TN' => 'francouzština (Tunisko)',
        'fr_VU' => 'francouzština (Vanuatu)',
        'fr_WF' => 'francouzština (Wallis a Futuna)',
        'fr_YT' => 'francouzština (Mayotte)',
        'fy' => 'fríština [západní]',
        'fy_NL' => 'fríština [západní] (Nizozemsko)',
        'ga' => 'irština',
        'ga_GB' => 'irština (Spojené království)',
        'ga_IE' => 'irština (Irsko)',
        'gd' => 'skotská gaelština',
        'gd_GB' => 'skotská gaelština (Spojené království)',
        'gl' => 'galicijština',
        'gl_ES' => 'galicijština (Španělsko)',
        'gu' => 'gudžarátština',
        'gu_IN' => 'gudžarátština (Indie)',
        'gv' => 'manština',
        'gv_IM' => 'manština (Ostrov Man)',
        'ha' => 'hauština',
        'ha_GH' => 'hauština (Ghana)',
        'ha_NE' => 'hauština (Niger)',
        'ha_NG' => 'hauština (Nigérie)',
        'he' => 'hebrejština',
        'he_IL' => 'hebrejština (Izrael)',
        'hi' => 'hindština',
        'hi_IN' => 'hindština (Indie)',
        'hi_Latn' => 'hindština (latinka)',
        'hi_Latn_IN' => 'hindština (latinka, Indie)',
        'hr' => 'chorvatština',
        'hr_BA' => 'chorvatština (Bosna a Hercegovina)',
        'hr_HR' => 'chorvatština (Chorvatsko)',
        'hu' => 'maďarština',
        'hu_HU' => 'maďarština (Maďarsko)',
        'hy' => 'arménština',
        'hy_AM' => 'arménština (Arménie)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (svět)',
        'id' => 'indonéština',
        'id_ID' => 'indonéština (Indonésie)',
        'ig' => 'igboština',
        'ig_NG' => 'igboština (Nigérie)',
        'ii' => 'iština [sečuánská]',
        'ii_CN' => 'iština [sečuánská] (Čína)',
        'is' => 'islandština',
        'is_IS' => 'islandština (Island)',
        'it' => 'italština',
        'it_CH' => 'italština (Švýcarsko)',
        'it_IT' => 'italština (Itálie)',
        'it_SM' => 'italština (San Marino)',
        'it_VA' => 'italština (Vatikán)',
        'ja' => 'japonština',
        'ja_JP' => 'japonština (Japonsko)',
        'jv' => 'javánština',
        'jv_ID' => 'javánština (Indonésie)',
        'ka' => 'gruzínština',
        'ka_GE' => 'gruzínština (Gruzie)',
        'ki' => 'kikujština',
        'ki_KE' => 'kikujština (Keňa)',
        'kk' => 'kazaština',
        'kk_KZ' => 'kazaština (Kazachstán)',
        'kl' => 'grónština',
        'kl_GL' => 'grónština (Grónsko)',
        'km' => 'khmérština',
        'km_KH' => 'khmérština (Kambodža)',
        'kn' => 'kannadština',
        'kn_IN' => 'kannadština (Indie)',
        'ko' => 'korejština',
        'ko_KP' => 'korejština (Severní Korea)',
        'ko_KR' => 'korejština (Jižní Korea)',
        'ks' => 'kašmírština',
        'ks_Arab' => 'kašmírština (arabské)',
        'ks_Arab_IN' => 'kašmírština (arabské, Indie)',
        'ks_Deva' => 'kašmírština (dévanágarí)',
        'ks_Deva_IN' => 'kašmírština (dévanágarí, Indie)',
        'ks_IN' => 'kašmírština (Indie)',
        'ku' => 'kurdština',
        'ku_TR' => 'kurdština (Turecko)',
        'kw' => 'kornština',
        'kw_GB' => 'kornština (Spojené království)',
        'ky' => 'kyrgyzština',
        'ky_KG' => 'kyrgyzština (Kyrgyzstán)',
        'lb' => 'lucemburština',
        'lb_LU' => 'lucemburština (Lucembursko)',
        'lg' => 'gandština',
        'lg_UG' => 'gandština (Uganda)',
        'ln' => 'lingalština',
        'ln_AO' => 'lingalština (Angola)',
        'ln_CD' => 'lingalština (Kongo – Kinshasa)',
        'ln_CF' => 'lingalština (Středoafrická republika)',
        'ln_CG' => 'lingalština (Kongo – Brazzaville)',
        'lo' => 'laoština',
        'lo_LA' => 'laoština (Laos)',
        'lt' => 'litevština',
        'lt_LT' => 'litevština (Litva)',
        'lu' => 'lubu-katanžština',
        'lu_CD' => 'lubu-katanžština (Kongo – Kinshasa)',
        'lv' => 'lotyština',
        'lv_LV' => 'lotyština (Lotyšsko)',
        'mg' => 'malgaština',
        'mg_MG' => 'malgaština (Madagaskar)',
        'mi' => 'maorština',
        'mi_NZ' => 'maorština (Nový Zéland)',
        'mk' => 'makedonština',
        'mk_MK' => 'makedonština (Severní Makedonie)',
        'ml' => 'malajálamština',
        'ml_IN' => 'malajálamština (Indie)',
        'mn' => 'mongolština',
        'mn_MN' => 'mongolština (Mongolsko)',
        'mr' => 'maráthština',
        'mr_IN' => 'maráthština (Indie)',
        'ms' => 'malajština',
        'ms_BN' => 'malajština (Brunej)',
        'ms_ID' => 'malajština (Indonésie)',
        'ms_MY' => 'malajština (Malajsie)',
        'ms_SG' => 'malajština (Singapur)',
        'mt' => 'maltština',
        'mt_MT' => 'maltština (Malta)',
        'my' => 'barmština',
        'my_MM' => 'barmština (Myanmar [Barma])',
        'nb' => 'norština [bokmål]',
        'nb_NO' => 'norština [bokmål] (Norsko)',
        'nb_SJ' => 'norština [bokmål] (Špicberky a Jan Mayen)',
        'nd' => 'ndebele [Zimbabwe]',
        'nd_ZW' => 'ndebele [Zimbabwe] (Zimbabwe)',
        'ne' => 'nepálština',
        'ne_IN' => 'nepálština (Indie)',
        'ne_NP' => 'nepálština (Nepál)',
        'nl' => 'nizozemština',
        'nl_AW' => 'nizozemština (Aruba)',
        'nl_BE' => 'nizozemština (Belgie)',
        'nl_BQ' => 'nizozemština (Karibské Nizozemsko)',
        'nl_CW' => 'nizozemština (Curaçao)',
        'nl_NL' => 'nizozemština (Nizozemsko)',
        'nl_SR' => 'nizozemština (Surinam)',
        'nl_SX' => 'nizozemština (Svatý Martin [Nizozemsko])',
        'nn' => 'norština [nynorsk]',
        'nn_NO' => 'norština [nynorsk] (Norsko)',
        'no' => 'norština',
        'no_NO' => 'norština (Norsko)',
        'om' => 'oromština',
        'om_ET' => 'oromština (Etiopie)',
        'om_KE' => 'oromština (Keňa)',
        'or' => 'urijština',
        'or_IN' => 'urijština (Indie)',
        'os' => 'osetština',
        'os_GE' => 'osetština (Gruzie)',
        'os_RU' => 'osetština (Rusko)',
        'pa' => 'paňdžábština',
        'pa_Arab' => 'paňdžábština (arabské)',
        'pa_Arab_PK' => 'paňdžábština (arabské, Pákistán)',
        'pa_Guru' => 'paňdžábština (gurmukhi)',
        'pa_Guru_IN' => 'paňdžábština (gurmukhi, Indie)',
        'pa_IN' => 'paňdžábština (Indie)',
        'pa_PK' => 'paňdžábština (Pákistán)',
        'pl' => 'polština',
        'pl_PL' => 'polština (Polsko)',
        'ps' => 'paštština',
        'ps_AF' => 'paštština (Afghánistán)',
        'ps_PK' => 'paštština (Pákistán)',
        'pt' => 'portugalština',
        'pt_AO' => 'portugalština (Angola)',
        'pt_BR' => 'portugalština (Brazílie)',
        'pt_CH' => 'portugalština (Švýcarsko)',
        'pt_CV' => 'portugalština (Kapverdy)',
        'pt_GQ' => 'portugalština (Rovníková Guinea)',
        'pt_GW' => 'portugalština (Guinea-Bissau)',
        'pt_LU' => 'portugalština (Lucembursko)',
        'pt_MO' => 'portugalština (Macao – ZAO Číny)',
        'pt_MZ' => 'portugalština (Mosambik)',
        'pt_PT' => 'portugalština (Portugalsko)',
        'pt_ST' => 'portugalština (Svatý Tomáš a Princův ostrov)',
        'pt_TL' => 'portugalština (Východní Timor)',
        'qu' => 'kečuánština',
        'qu_BO' => 'kečuánština (Bolívie)',
        'qu_EC' => 'kečuánština (Ekvádor)',
        'qu_PE' => 'kečuánština (Peru)',
        'rm' => 'rétorománština',
        'rm_CH' => 'rétorománština (Švýcarsko)',
        'rn' => 'kirundština',
        'rn_BI' => 'kirundština (Burundi)',
        'ro' => 'rumunština',
        'ro_MD' => 'rumunština (Moldavsko)',
        'ro_RO' => 'rumunština (Rumunsko)',
        'ru' => 'ruština',
        'ru_BY' => 'ruština (Bělorusko)',
        'ru_KG' => 'ruština (Kyrgyzstán)',
        'ru_KZ' => 'ruština (Kazachstán)',
        'ru_MD' => 'ruština (Moldavsko)',
        'ru_RU' => 'ruština (Rusko)',
        'ru_UA' => 'ruština (Ukrajina)',
        'rw' => 'kiňarwandština',
        'rw_RW' => 'kiňarwandština (Rwanda)',
        'sa' => 'sanskrt',
        'sa_IN' => 'sanskrt (Indie)',
        'sc' => 'sardština',
        'sc_IT' => 'sardština (Itálie)',
        'sd' => 'sindhština',
        'sd_Arab' => 'sindhština (arabské)',
        'sd_Arab_PK' => 'sindhština (arabské, Pákistán)',
        'sd_Deva' => 'sindhština (dévanágarí)',
        'sd_Deva_IN' => 'sindhština (dévanágarí, Indie)',
        'sd_IN' => 'sindhština (Indie)',
        'sd_PK' => 'sindhština (Pákistán)',
        'se' => 'sámština [severní]',
        'se_FI' => 'sámština [severní] (Finsko)',
        'se_NO' => 'sámština [severní] (Norsko)',
        'se_SE' => 'sámština [severní] (Švédsko)',
        'sg' => 'sangština',
        'sg_CF' => 'sangština (Středoafrická republika)',
        'sh' => 'srbochorvatština',
        'sh_BA' => 'srbochorvatština (Bosna a Hercegovina)',
        'si' => 'sinhálština',
        'si_LK' => 'sinhálština (Srí Lanka)',
        'sk' => 'slovenština',
        'sk_SK' => 'slovenština (Slovensko)',
        'sl' => 'slovinština',
        'sl_SI' => 'slovinština (Slovinsko)',
        'sn' => 'šonština',
        'sn_ZW' => 'šonština (Zimbabwe)',
        'so' => 'somálština',
        'so_DJ' => 'somálština (Džibutsko)',
        'so_ET' => 'somálština (Etiopie)',
        'so_KE' => 'somálština (Keňa)',
        'so_SO' => 'somálština (Somálsko)',
        'sq' => 'albánština',
        'sq_AL' => 'albánština (Albánie)',
        'sq_MK' => 'albánština (Severní Makedonie)',
        'sr' => 'srbština',
        'sr_BA' => 'srbština (Bosna a Hercegovina)',
        'sr_Cyrl' => 'srbština (cyrilice)',
        'sr_Cyrl_BA' => 'srbština (cyrilice, Bosna a Hercegovina)',
        'sr_Cyrl_ME' => 'srbština (cyrilice, Černá Hora)',
        'sr_Cyrl_RS' => 'srbština (cyrilice, Srbsko)',
        'sr_Latn' => 'srbština (latinka)',
        'sr_Latn_BA' => 'srbština (latinka, Bosna a Hercegovina)',
        'sr_Latn_ME' => 'srbština (latinka, Černá Hora)',
        'sr_Latn_RS' => 'srbština (latinka, Srbsko)',
        'sr_ME' => 'srbština (Černá Hora)',
        'sr_RS' => 'srbština (Srbsko)',
        'su' => 'sundština',
        'su_ID' => 'sundština (Indonésie)',
        'su_Latn' => 'sundština (latinka)',
        'su_Latn_ID' => 'sundština (latinka, Indonésie)',
        'sv' => 'švédština',
        'sv_AX' => 'švédština (Ålandy)',
        'sv_FI' => 'švédština (Finsko)',
        'sv_SE' => 'švédština (Švédsko)',
        'sw' => 'svahilština',
        'sw_CD' => 'svahilština (Kongo – Kinshasa)',
        'sw_KE' => 'svahilština (Keňa)',
        'sw_TZ' => 'svahilština (Tanzanie)',
        'sw_UG' => 'svahilština (Uganda)',
        'ta' => 'tamilština',
        'ta_IN' => 'tamilština (Indie)',
        'ta_LK' => 'tamilština (Srí Lanka)',
        'ta_MY' => 'tamilština (Malajsie)',
        'ta_SG' => 'tamilština (Singapur)',
        'te' => 'telugština',
        'te_IN' => 'telugština (Indie)',
        'tg' => 'tádžičtina',
        'tg_TJ' => 'tádžičtina (Tádžikistán)',
        'th' => 'thajština',
        'th_TH' => 'thajština (Thajsko)',
        'ti' => 'tigrinijština',
        'ti_ER' => 'tigrinijština (Eritrea)',
        'ti_ET' => 'tigrinijština (Etiopie)',
        'tk' => 'turkmenština',
        'tk_TM' => 'turkmenština (Turkmenistán)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filipíny)',
        'to' => 'tongánština',
        'to_TO' => 'tongánština (Tonga)',
        'tr' => 'turečtina',
        'tr_CY' => 'turečtina (Kypr)',
        'tr_TR' => 'turečtina (Turecko)',
        'tt' => 'tatarština',
        'tt_RU' => 'tatarština (Rusko)',
        'ug' => 'ujgurština',
        'ug_CN' => 'ujgurština (Čína)',
        'uk' => 'ukrajinština',
        'uk_UA' => 'ukrajinština (Ukrajina)',
        'ur' => 'urdština',
        'ur_IN' => 'urdština (Indie)',
        'ur_PK' => 'urdština (Pákistán)',
        'uz' => 'uzbečtina',
        'uz_AF' => 'uzbečtina (Afghánistán)',
        'uz_Arab' => 'uzbečtina (arabské)',
        'uz_Arab_AF' => 'uzbečtina (arabské, Afghánistán)',
        'uz_Cyrl' => 'uzbečtina (cyrilice)',
        'uz_Cyrl_UZ' => 'uzbečtina (cyrilice, Uzbekistán)',
        'uz_Latn' => 'uzbečtina (latinka)',
        'uz_Latn_UZ' => 'uzbečtina (latinka, Uzbekistán)',
        'uz_UZ' => 'uzbečtina (Uzbekistán)',
        'vi' => 'vietnamština',
        'vi_VN' => 'vietnamština (Vietnam)',
        'wo' => 'wolofština',
        'wo_SN' => 'wolofština (Senegal)',
        'xh' => 'xhoština',
        'xh_ZA' => 'xhoština (Jihoafrická republika)',
        'yi' => 'jidiš',
        'yi_001' => 'jidiš (svět)',
        'yo' => 'jorubština',
        'yo_BJ' => 'jorubština (Benin)',
        'yo_NG' => 'jorubština (Nigérie)',
        'zh' => 'čínština',
        'zh_CN' => 'čínština (Čína)',
        'zh_HK' => 'čínština (Hongkong – ZAO Číny)',
        'zh_Hans' => 'čínština (zjednodušené)',
        'zh_Hans_CN' => 'čínština (zjednodušené, Čína)',
        'zh_Hans_HK' => 'čínština (zjednodušené, Hongkong – ZAO Číny)',
        'zh_Hans_MO' => 'čínština (zjednodušené, Macao – ZAO Číny)',
        'zh_Hans_SG' => 'čínština (zjednodušené, Singapur)',
        'zh_Hant' => 'čínština (tradiční)',
        'zh_Hant_HK' => 'čínština (tradiční, Hongkong – ZAO Číny)',
        'zh_Hant_MO' => 'čínština (tradiční, Macao – ZAO Číny)',
        'zh_Hant_TW' => 'čínština (tradiční, Tchaj-wan)',
        'zh_MO' => 'čínština (Macao – ZAO Číny)',
        'zh_SG' => 'čínština (Singapur)',
        'zh_TW' => 'čínština (Tchaj-wan)',
        'zu' => 'zuluština',
        'zu_ZA' => 'zuluština (Jihoafrická republika)',
    ],
];
