<?php

return [
    'Names' => [
        'af' => 'африканс',
        'af_NA' => 'африканс (Намибија)',
        'af_ZA' => 'африканс (Јужноафричка Република)',
        'ak' => 'акански',
        'ak_GH' => 'акански (Гана)',
        'am' => 'амхарски',
        'am_ET' => 'амхарски (Етиопија)',
        'ar' => 'арапски',
        'ar_001' => 'арапски (свет)',
        'ar_AE' => 'арапски (Уједињени Арапски Емирати)',
        'ar_BH' => 'арапски (Бахреин)',
        'ar_DJ' => 'арапски (Џибути)',
        'ar_DZ' => 'арапски (Алжир)',
        'ar_EG' => 'арапски (Египат)',
        'ar_EH' => 'арапски (Западна Сахара)',
        'ar_ER' => 'арапски (Еритреја)',
        'ar_IL' => 'арапски (Израел)',
        'ar_IQ' => 'арапски (Ирак)',
        'ar_JO' => 'арапски (Јордан)',
        'ar_KM' => 'арапски (Коморска Острва)',
        'ar_KW' => 'арапски (Кувајт)',
        'ar_LB' => 'арапски (Либан)',
        'ar_LY' => 'арапски (Либија)',
        'ar_MA' => 'арапски (Мароко)',
        'ar_MR' => 'арапски (Мауританија)',
        'ar_OM' => 'арапски (Оман)',
        'ar_PS' => 'арапски (Палестинске територије)',
        'ar_QA' => 'арапски (Катар)',
        'ar_SA' => 'арапски (Саудијска Арабија)',
        'ar_SD' => 'арапски (Судан)',
        'ar_SO' => 'арапски (Сомалија)',
        'ar_SS' => 'арапски (Јужни Судан)',
        'ar_SY' => 'арапски (Сирија)',
        'ar_TD' => 'арапски (Чад)',
        'ar_TN' => 'арапски (Тунис)',
        'ar_YE' => 'арапски (Јемен)',
        'as' => 'асамски',
        'as_IN' => 'асамски (Индија)',
        'az' => 'азербејџански',
        'az_AZ' => 'азербејџански (Азербејџан)',
        'az_Cyrl' => 'азербејџански (ћирилица)',
        'az_Cyrl_AZ' => 'азербејџански (ћирилица, Азербејџан)',
        'az_Latn' => 'азербејџански (латиница)',
        'az_Latn_AZ' => 'азербејџански (латиница, Азербејџан)',
        'be' => 'белоруски',
        'be_BY' => 'белоруски (Белорусија)',
        'bg' => 'бугарски',
        'bg_BG' => 'бугарски (Бугарска)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Мали)',
        'bn' => 'бенгалски',
        'bn_BD' => 'бенгалски (Бангладеш)',
        'bn_IN' => 'бенгалски (Индија)',
        'bo' => 'тибетански',
        'bo_CN' => 'тибетански (Кина)',
        'bo_IN' => 'тибетански (Индија)',
        'br' => 'бретонски',
        'br_FR' => 'бретонски (Француска)',
        'bs' => 'босански',
        'bs_BA' => 'босански (Босна и Херцеговина)',
        'bs_Cyrl' => 'босански (ћирилица)',
        'bs_Cyrl_BA' => 'босански (ћирилица, Босна и Херцеговина)',
        'bs_Latn' => 'босански (латиница)',
        'bs_Latn_BA' => 'босански (латиница, Босна и Херцеговина)',
        'ca' => 'каталонски',
        'ca_AD' => 'каталонски (Андора)',
        'ca_ES' => 'каталонски (Шпанија)',
        'ca_FR' => 'каталонски (Француска)',
        'ca_IT' => 'каталонски (Италија)',
        'ce' => 'чеченски',
        'ce_RU' => 'чеченски (Русија)',
        'cs' => 'чешки',
        'cs_CZ' => 'чешки (Чешка)',
        'cv' => 'чувашки',
        'cv_RU' => 'чувашки (Русија)',
        'cy' => 'велшки',
        'cy_GB' => 'велшки (Уједињено Краљевство)',
        'da' => 'дански',
        'da_DK' => 'дански (Данска)',
        'da_GL' => 'дански (Гренланд)',
        'de' => 'немачки',
        'de_AT' => 'немачки (Аустрија)',
        'de_BE' => 'немачки (Белгија)',
        'de_CH' => 'немачки (Швајцарска)',
        'de_DE' => 'немачки (Немачка)',
        'de_IT' => 'немачки (Италија)',
        'de_LI' => 'немачки (Лихтенштајн)',
        'de_LU' => 'немачки (Луксембург)',
        'dz' => 'џонга',
        'dz_BT' => 'џонга (Бутан)',
        'ee' => 'еве',
        'ee_GH' => 'еве (Гана)',
        'ee_TG' => 'еве (Того)',
        'el' => 'грчки',
        'el_CY' => 'грчки (Кипар)',
        'el_GR' => 'грчки (Грчка)',
        'en' => 'енглески',
        'en_001' => 'енглески (свет)',
        'en_150' => 'енглески (Европа)',
        'en_AE' => 'енглески (Уједињени Арапски Емирати)',
        'en_AG' => 'енглески (Антигва и Барбуда)',
        'en_AI' => 'енглески (Ангвила)',
        'en_AS' => 'енглески (Америчка Самоа)',
        'en_AT' => 'енглески (Аустрија)',
        'en_AU' => 'енглески (Аустралија)',
        'en_BB' => 'енглески (Барбадос)',
        'en_BE' => 'енглески (Белгија)',
        'en_BI' => 'енглески (Бурунди)',
        'en_BM' => 'енглески (Бермуда)',
        'en_BS' => 'енглески (Бахами)',
        'en_BW' => 'енглески (Боцвана)',
        'en_BZ' => 'енглески (Белизе)',
        'en_CA' => 'енглески (Канада)',
        'en_CC' => 'енглески (Кокосова [Килингова] Острва)',
        'en_CH' => 'енглески (Швајцарска)',
        'en_CK' => 'енглески (Кукова Острва)',
        'en_CM' => 'енглески (Камерун)',
        'en_CX' => 'енглески (Божићно Острво)',
        'en_CY' => 'енглески (Кипар)',
        'en_DE' => 'енглески (Немачка)',
        'en_DK' => 'енглески (Данска)',
        'en_DM' => 'енглески (Доминика)',
        'en_ER' => 'енглески (Еритреја)',
        'en_FI' => 'енглески (Финска)',
        'en_FJ' => 'енглески (Фиџи)',
        'en_FK' => 'енглески (Фокландска Острва)',
        'en_FM' => 'енглески (Микронезија)',
        'en_GB' => 'енглески (Уједињено Краљевство)',
        'en_GD' => 'енглески (Гренада)',
        'en_GG' => 'енглески (Гернзи)',
        'en_GH' => 'енглески (Гана)',
        'en_GI' => 'енглески (Гибралтар)',
        'en_GM' => 'енглески (Гамбија)',
        'en_GU' => 'енглески (Гуам)',
        'en_GY' => 'енглески (Гвајана)',
        'en_HK' => 'енглески (САР Хонгконг [Кина])',
        'en_IE' => 'енглески (Ирска)',
        'en_IL' => 'енглески (Израел)',
        'en_IM' => 'енглески (Острво Ман)',
        'en_IN' => 'енглески (Индија)',
        'en_IO' => 'енглески (Британска територија Индијског океана)',
        'en_JE' => 'енглески (Џерзи)',
        'en_JM' => 'енглески (Јамајка)',
        'en_KE' => 'енглески (Кенија)',
        'en_KI' => 'енглески (Кирибати)',
        'en_KN' => 'енглески (Сент Китс и Невис)',
        'en_KY' => 'енглески (Кајманска Острва)',
        'en_LC' => 'енглески (Света Луција)',
        'en_LR' => 'енглески (Либерија)',
        'en_LS' => 'енглески (Лесото)',
        'en_MG' => 'енглески (Мадагаскар)',
        'en_MH' => 'енглески (Маршалска Острва)',
        'en_MO' => 'енглески (САР Макао [Кина])',
        'en_MP' => 'енглески (Северна Маријанска Острва)',
        'en_MS' => 'енглески (Монсерат)',
        'en_MT' => 'енглески (Малта)',
        'en_MU' => 'енглески (Маурицијус)',
        'en_MV' => 'енглески (Малдиви)',
        'en_MW' => 'енглески (Малави)',
        'en_MY' => 'енглески (Малезија)',
        'en_NA' => 'енглески (Намибија)',
        'en_NF' => 'енглески (Острво Норфок)',
        'en_NG' => 'енглески (Нигерија)',
        'en_NL' => 'енглески (Холандија)',
        'en_NR' => 'енглески (Науру)',
        'en_NU' => 'енглески (Ниуе)',
        'en_NZ' => 'енглески (Нови Зеланд)',
        'en_PG' => 'енглески (Папуа Нова Гвинеја)',
        'en_PH' => 'енглески (Филипини)',
        'en_PK' => 'енглески (Пакистан)',
        'en_PN' => 'енглески (Питкерн)',
        'en_PR' => 'енглески (Порторико)',
        'en_PW' => 'енглески (Палау)',
        'en_RW' => 'енглески (Руанда)',
        'en_SB' => 'енглески (Соломонска Острва)',
        'en_SC' => 'енглески (Сејшели)',
        'en_SD' => 'енглески (Судан)',
        'en_SE' => 'енглески (Шведска)',
        'en_SG' => 'енглески (Сингапур)',
        'en_SH' => 'енглески (Света Јелена)',
        'en_SI' => 'енглески (Словенија)',
        'en_SL' => 'енглески (Сијера Леоне)',
        'en_SS' => 'енглески (Јужни Судан)',
        'en_SX' => 'енглески (Свети Мартин [Холандија])',
        'en_SZ' => 'енглески (Свазиленд)',
        'en_TC' => 'енглески (Острва Туркс и Каикос)',
        'en_TK' => 'енглески (Токелау)',
        'en_TO' => 'енглески (Тонга)',
        'en_TT' => 'енглески (Тринидад и Тобаго)',
        'en_TV' => 'енглески (Тувалу)',
        'en_TZ' => 'енглески (Танзанија)',
        'en_UG' => 'енглески (Уганда)',
        'en_UM' => 'енглески (Удаљена острва САД)',
        'en_US' => 'енглески (Сједињене Државе)',
        'en_VC' => 'енглески (Сент Винсент и Гренадини)',
        'en_VG' => 'енглески (Британска Девичанска Острва)',
        'en_VI' => 'енглески (Америчка Девичанска Острва)',
        'en_VU' => 'енглески (Вануату)',
        'en_WS' => 'енглески (Самоа)',
        'en_ZA' => 'енглески (Јужноафричка Република)',
        'en_ZM' => 'енглески (Замбија)',
        'en_ZW' => 'енглески (Зимбабве)',
        'eo' => 'есперанто',
        'eo_001' => 'есперанто (свет)',
        'es' => 'шпански',
        'es_419' => 'шпански (Латинска Америка)',
        'es_AR' => 'шпански (Аргентина)',
        'es_BO' => 'шпански (Боливија)',
        'es_BR' => 'шпански (Бразил)',
        'es_BZ' => 'шпански (Белизе)',
        'es_CL' => 'шпански (Чиле)',
        'es_CO' => 'шпански (Колумбија)',
        'es_CR' => 'шпански (Костарика)',
        'es_CU' => 'шпански (Куба)',
        'es_DO' => 'шпански (Доминиканска Република)',
        'es_EC' => 'шпански (Еквадор)',
        'es_ES' => 'шпански (Шпанија)',
        'es_GQ' => 'шпански (Екваторијална Гвинеја)',
        'es_GT' => 'шпански (Гватемала)',
        'es_HN' => 'шпански (Хондурас)',
        'es_MX' => 'шпански (Мексико)',
        'es_NI' => 'шпански (Никарагва)',
        'es_PA' => 'шпански (Панама)',
        'es_PE' => 'шпански (Перу)',
        'es_PH' => 'шпански (Филипини)',
        'es_PR' => 'шпански (Порторико)',
        'es_PY' => 'шпански (Парагвај)',
        'es_SV' => 'шпански (Салвадор)',
        'es_US' => 'шпански (Сједињене Државе)',
        'es_UY' => 'шпански (Уругвај)',
        'es_VE' => 'шпански (Венецуела)',
        'et' => 'естонски',
        'et_EE' => 'естонски (Естонија)',
        'eu' => 'баскијски',
        'eu_ES' => 'баскијски (Шпанија)',
        'fa' => 'персијски',
        'fa_AF' => 'персијски (Авганистан)',
        'fa_IR' => 'персијски (Иран)',
        'ff' => 'фула',
        'ff_Adlm' => 'фула (адлам)',
        'ff_Adlm_BF' => 'фула (адлам, Буркина Фасо)',
        'ff_Adlm_CM' => 'фула (адлам, Камерун)',
        'ff_Adlm_GH' => 'фула (адлам, Гана)',
        'ff_Adlm_GM' => 'фула (адлам, Гамбија)',
        'ff_Adlm_GN' => 'фула (адлам, Гвинеја)',
        'ff_Adlm_GW' => 'фула (адлам, Гвинеја-Бисао)',
        'ff_Adlm_LR' => 'фула (адлам, Либерија)',
        'ff_Adlm_MR' => 'фула (адлам, Мауританија)',
        'ff_Adlm_NE' => 'фула (адлам, Нигер)',
        'ff_Adlm_NG' => 'фула (адлам, Нигерија)',
        'ff_Adlm_SL' => 'фула (адлам, Сијера Леоне)',
        'ff_Adlm_SN' => 'фула (адлам, Сенегал)',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвинеја)',
        'ff_Latn' => 'фула (латиница)',
        'ff_Latn_BF' => 'фула (латиница, Буркина Фасо)',
        'ff_Latn_CM' => 'фула (латиница, Камерун)',
        'ff_Latn_GH' => 'фула (латиница, Гана)',
        'ff_Latn_GM' => 'фула (латиница, Гамбија)',
        'ff_Latn_GN' => 'фула (латиница, Гвинеја)',
        'ff_Latn_GW' => 'фула (латиница, Гвинеја-Бисао)',
        'ff_Latn_LR' => 'фула (латиница, Либерија)',
        'ff_Latn_MR' => 'фула (латиница, Мауританија)',
        'ff_Latn_NE' => 'фула (латиница, Нигер)',
        'ff_Latn_NG' => 'фула (латиница, Нигерија)',
        'ff_Latn_SL' => 'фула (латиница, Сијера Леоне)',
        'ff_Latn_SN' => 'фула (латиница, Сенегал)',
        'ff_MR' => 'фула (Мауританија)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фински',
        'fi_FI' => 'фински (Финска)',
        'fo' => 'фарски',
        'fo_DK' => 'фарски (Данска)',
        'fo_FO' => 'фарски (Фарска Острва)',
        'fr' => 'француски',
        'fr_BE' => 'француски (Белгија)',
        'fr_BF' => 'француски (Буркина Фасо)',
        'fr_BI' => 'француски (Бурунди)',
        'fr_BJ' => 'француски (Бенин)',
        'fr_BL' => 'француски (Свети Бартоломеј)',
        'fr_CA' => 'француски (Канада)',
        'fr_CD' => 'француски (Конго - Киншаса)',
        'fr_CF' => 'француски (Централноафричка Република)',
        'fr_CG' => 'француски (Конго - Бразавил)',
        'fr_CH' => 'француски (Швајцарска)',
        'fr_CI' => 'француски (Обала Слоноваче [Кот д’Ивоар])',
        'fr_CM' => 'француски (Камерун)',
        'fr_DJ' => 'француски (Џибути)',
        'fr_DZ' => 'француски (Алжир)',
        'fr_FR' => 'француски (Француска)',
        'fr_GA' => 'француски (Габон)',
        'fr_GF' => 'француски (Француска Гвајана)',
        'fr_GN' => 'француски (Гвинеја)',
        'fr_GP' => 'француски (Гваделуп)',
        'fr_GQ' => 'француски (Екваторијална Гвинеја)',
        'fr_HT' => 'француски (Хаити)',
        'fr_KM' => 'француски (Коморска Острва)',
        'fr_LU' => 'француски (Луксембург)',
        'fr_MA' => 'француски (Мароко)',
        'fr_MC' => 'француски (Монако)',
        'fr_MF' => 'француски (Свети Мартин [Француска])',
        'fr_MG' => 'француски (Мадагаскар)',
        'fr_ML' => 'француски (Мали)',
        'fr_MQ' => 'француски (Мартиник)',
        'fr_MR' => 'француски (Мауританија)',
        'fr_MU' => 'француски (Маурицијус)',
        'fr_NC' => 'француски (Нова Каледонија)',
        'fr_NE' => 'француски (Нигер)',
        'fr_PF' => 'француски (Француска Полинезија)',
        'fr_PM' => 'француски (Сен Пјер и Микелон)',
        'fr_RE' => 'француски (Реинион)',
        'fr_RW' => 'француски (Руанда)',
        'fr_SC' => 'француски (Сејшели)',
        'fr_SN' => 'француски (Сенегал)',
        'fr_SY' => 'француски (Сирија)',
        'fr_TD' => 'француски (Чад)',
        'fr_TG' => 'француски (Того)',
        'fr_TN' => 'француски (Тунис)',
        'fr_VU' => 'француски (Вануату)',
        'fr_WF' => 'француски (Валис и Футуна)',
        'fr_YT' => 'француски (Мајот)',
        'fy' => 'западни фризијски',
        'fy_NL' => 'западни фризијски (Холандија)',
        'ga' => 'ирски',
        'ga_GB' => 'ирски (Уједињено Краљевство)',
        'ga_IE' => 'ирски (Ирска)',
        'gd' => 'шкотски гелски',
        'gd_GB' => 'шкотски гелски (Уједињено Краљевство)',
        'gl' => 'галицијски',
        'gl_ES' => 'галицијски (Шпанија)',
        'gu' => 'гуџарати',
        'gu_IN' => 'гуџарати (Индија)',
        'gv' => 'манкс',
        'gv_IM' => 'манкс (Острво Ман)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигерија)',
        'he' => 'хебрејски',
        'he_IL' => 'хебрејски (Израел)',
        'hi' => 'хинди',
        'hi_IN' => 'хинди (Индија)',
        'hi_Latn' => 'хинди (латиница)',
        'hi_Latn_IN' => 'хинди (латиница, Индија)',
        'hr' => 'хрватски',
        'hr_BA' => 'хрватски (Босна и Херцеговина)',
        'hr_HR' => 'хрватски (Хрватска)',
        'hu' => 'мађарски',
        'hu_HU' => 'мађарски (Мађарска)',
        'hy' => 'јерменски',
        'hy_AM' => 'јерменски (Јерменија)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (свет)',
        'id' => 'индонежански',
        'id_ID' => 'индонежански (Индонезија)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерија)',
        'ii' => 'сечуански ји',
        'ii_CN' => 'сечуански ји (Кина)',
        'is' => 'исландски',
        'is_IS' => 'исландски (Исланд)',
        'it' => 'италијански',
        'it_CH' => 'италијански (Швајцарска)',
        'it_IT' => 'италијански (Италија)',
        'it_SM' => 'италијански (Сан Марино)',
        'it_VA' => 'италијански (Ватикан)',
        'ja' => 'јапански',
        'ja_JP' => 'јапански (Јапан)',
        'jv' => 'јавански',
        'jv_ID' => 'јавански (Индонезија)',
        'ka' => 'грузијски',
        'ka_GE' => 'грузијски (Грузија)',
        'ki' => 'кикују',
        'ki_KE' => 'кикују (Кенија)',
        'kk' => 'казашки',
        'kk_KZ' => 'казашки (Казахстан)',
        'kl' => 'гренландски',
        'kl_GL' => 'гренландски (Гренланд)',
        'km' => 'кмерски',
        'km_KH' => 'кмерски (Камбоџа)',
        'kn' => 'канада',
        'kn_IN' => 'канада (Индија)',
        'ko' => 'корејски',
        'ko_KP' => 'корејски (Северна Кореја)',
        'ko_KR' => 'корејски (Јужна Кореја)',
        'ks' => 'кашмирски',
        'ks_Arab' => 'кашмирски (арапско писмо)',
        'ks_Arab_IN' => 'кашмирски (арапско писмо, Индија)',
        'ks_Deva' => 'кашмирски (деванагари)',
        'ks_Deva_IN' => 'кашмирски (деванагари, Индија)',
        'ks_IN' => 'кашмирски (Индија)',
        'ku' => 'курдски',
        'ku_TR' => 'курдски (Турска)',
        'kw' => 'корнволски',
        'kw_GB' => 'корнволски (Уједињено Краљевство)',
        'ky' => 'киргиски',
        'ky_KG' => 'киргиски (Киргистан)',
        'lb' => 'луксембуршки',
        'lb_LU' => 'луксембуршки (Луксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лингала',
        'ln_AO' => 'лингала (Ангола)',
        'ln_CD' => 'лингала (Конго - Киншаса)',
        'ln_CF' => 'лингала (Централноафричка Република)',
        'ln_CG' => 'лингала (Конго - Бразавил)',
        'lo' => 'лаоски',
        'lo_LA' => 'лаоски (Лаос)',
        'lt' => 'литвански',
        'lt_LT' => 'литвански (Литванија)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго - Киншаса)',
        'lv' => 'летонски',
        'lv_LV' => 'летонски (Летонија)',
        'mg' => 'малгашки',
        'mg_MG' => 'малгашки (Мадагаскар)',
        'mi' => 'маорски',
        'mi_NZ' => 'маорски (Нови Зеланд)',
        'mk' => 'македонски',
        'mk_MK' => 'македонски (Северна Македонија)',
        'ml' => 'малајалам',
        'ml_IN' => 'малајалам (Индија)',
        'mn' => 'монголски',
        'mn_MN' => 'монголски (Монголија)',
        'mr' => 'марати',
        'mr_IN' => 'марати (Индија)',
        'ms' => 'малајски',
        'ms_BN' => 'малајски (Брунеј)',
        'ms_ID' => 'малајски (Индонезија)',
        'ms_MY' => 'малајски (Малезија)',
        'ms_SG' => 'малајски (Сингапур)',
        'mt' => 'малтешки',
        'mt_MT' => 'малтешки (Малта)',
        'my' => 'бурмански',
        'my_MM' => 'бурмански (Мијанмар [Бурма])',
        'nb' => 'норвешки букмол',
        'nb_NO' => 'норвешки букмол (Норвешка)',
        'nb_SJ' => 'норвешки букмол (Свалбард и Јан Мајен)',
        'nd' => 'северни ндебеле',
        'nd_ZW' => 'северни ндебеле (Зимбабве)',
        'ne' => 'непалски',
        'ne_IN' => 'непалски (Индија)',
        'ne_NP' => 'непалски (Непал)',
        'nl' => 'холандски',
        'nl_AW' => 'холандски (Аруба)',
        'nl_BE' => 'холандски (Белгија)',
        'nl_BQ' => 'холандски (Карипска Холандија)',
        'nl_CW' => 'холандски (Курасао)',
        'nl_NL' => 'холандски (Холандија)',
        'nl_SR' => 'холандски (Суринам)',
        'nl_SX' => 'холандски (Свети Мартин [Холандија])',
        'nn' => 'норвешки нинорск',
        'nn_NO' => 'норвешки нинорск (Норвешка)',
        'no' => 'норвешки',
        'no_NO' => 'норвешки (Норвешка)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Етиопија)',
        'om_KE' => 'оромо (Кенија)',
        'or' => 'одија',
        'or_IN' => 'одија (Индија)',
        'os' => 'осетински',
        'os_GE' => 'осетински (Грузија)',
        'os_RU' => 'осетински (Русија)',
        'pa' => 'пенџапски',
        'pa_Arab' => 'пенџапски (арапско писмо)',
        'pa_Arab_PK' => 'пенџапски (арапско писмо, Пакистан)',
        'pa_Guru' => 'пенџапски (гурмуки писмо)',
        'pa_Guru_IN' => 'пенџапски (гурмуки писмо, Индија)',
        'pa_IN' => 'пенџапски (Индија)',
        'pa_PK' => 'пенџапски (Пакистан)',
        'pl' => 'пољски',
        'pl_PL' => 'пољски (Пољска)',
        'ps' => 'паштунски',
        'ps_AF' => 'паштунски (Авганистан)',
        'ps_PK' => 'паштунски (Пакистан)',
        'pt' => 'португалски',
        'pt_AO' => 'португалски (Ангола)',
        'pt_BR' => 'португалски (Бразил)',
        'pt_CH' => 'португалски (Швајцарска)',
        'pt_CV' => 'португалски (Зеленортска Острва)',
        'pt_GQ' => 'португалски (Екваторијална Гвинеја)',
        'pt_GW' => 'португалски (Гвинеја-Бисао)',
        'pt_LU' => 'португалски (Луксембург)',
        'pt_MO' => 'португалски (САР Макао [Кина])',
        'pt_MZ' => 'португалски (Мозамбик)',
        'pt_PT' => 'португалски (Португалија)',
        'pt_ST' => 'португалски (Сао Томе и Принципе)',
        'pt_TL' => 'португалски (Тимор-Лесте [Источни Тимор])',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливија)',
        'qu_EC' => 'кечуа (Еквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'романш',
        'rm_CH' => 'романш (Швајцарска)',
        'rn' => 'кирунди',
        'rn_BI' => 'кирунди (Бурунди)',
        'ro' => 'румунски',
        'ro_MD' => 'румунски (Молдавија)',
        'ro_RO' => 'румунски (Румунија)',
        'ru' => 'руски',
        'ru_BY' => 'руски (Белорусија)',
        'ru_KG' => 'руски (Киргистан)',
        'ru_KZ' => 'руски (Казахстан)',
        'ru_MD' => 'руски (Молдавија)',
        'ru_RU' => 'руски (Русија)',
        'ru_UA' => 'руски (Украјина)',
        'rw' => 'кињаруанда',
        'rw_RW' => 'кињаруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Индија)',
        'sc' => 'сардински',
        'sc_IT' => 'сардински (Италија)',
        'sd' => 'синди',
        'sd_Arab' => 'синди (арапско писмо)',
        'sd_Arab_PK' => 'синди (арапско писмо, Пакистан)',
        'sd_Deva' => 'синди (деванагари)',
        'sd_Deva_IN' => 'синди (деванагари, Индија)',
        'sd_IN' => 'синди (Индија)',
        'sd_PK' => 'синди (Пакистан)',
        'se' => 'северни сами',
        'se_FI' => 'северни сами (Финска)',
        'se_NO' => 'северни сами (Норвешка)',
        'se_SE' => 'северни сами (Шведска)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Централноафричка Република)',
        'sh' => 'српскохрватски',
        'sh_BA' => 'српскохрватски (Босна и Херцеговина)',
        'si' => 'синхалешки',
        'si_LK' => 'синхалешки (Шри Ланка)',
        'sk' => 'словачки',
        'sk_SK' => 'словачки (Словачка)',
        'sl' => 'словеначки',
        'sl_SI' => 'словеначки (Словенија)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомалски',
        'so_DJ' => 'сомалски (Џибути)',
        'so_ET' => 'сомалски (Етиопија)',
        'so_KE' => 'сомалски (Кенија)',
        'so_SO' => 'сомалски (Сомалија)',
        'sq' => 'албански',
        'sq_AL' => 'албански (Албанија)',
        'sq_MK' => 'албански (Северна Македонија)',
        'sr' => 'српски',
        'sr_BA' => 'српски (Босна и Херцеговина)',
        'sr_Cyrl' => 'српски (ћирилица)',
        'sr_Cyrl_BA' => 'српски (ћирилица, Босна и Херцеговина)',
        'sr_Cyrl_ME' => 'српски (ћирилица, Црна Гора)',
        'sr_Cyrl_RS' => 'српски (ћирилица, Србија)',
        'sr_Latn' => 'српски (латиница)',
        'sr_Latn_BA' => 'српски (латиница, Босна и Херцеговина)',
        'sr_Latn_ME' => 'српски (латиница, Црна Гора)',
        'sr_Latn_RS' => 'српски (латиница, Србија)',
        'sr_ME' => 'српски (Црна Гора)',
        'sr_RS' => 'српски (Србија)',
        'su' => 'сундански',
        'su_ID' => 'сундански (Индонезија)',
        'su_Latn' => 'сундански (латиница)',
        'su_Latn_ID' => 'сундански (латиница, Индонезија)',
        'sv' => 'шведски',
        'sv_AX' => 'шведски (Оландска Острва)',
        'sv_FI' => 'шведски (Финска)',
        'sv_SE' => 'шведски (Шведска)',
        'sw' => 'свахили',
        'sw_CD' => 'свахили (Конго - Киншаса)',
        'sw_KE' => 'свахили (Кенија)',
        'sw_TZ' => 'свахили (Танзанија)',
        'sw_UG' => 'свахили (Уганда)',
        'ta' => 'тамилски',
        'ta_IN' => 'тамилски (Индија)',
        'ta_LK' => 'тамилски (Шри Ланка)',
        'ta_MY' => 'тамилски (Малезија)',
        'ta_SG' => 'тамилски (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Индија)',
        'tg' => 'таџички',
        'tg_TJ' => 'таџички (Таџикистан)',
        'th' => 'тајски',
        'th_TH' => 'тајски (Тајланд)',
        'ti' => 'тигриња',
        'ti_ER' => 'тигриња (Еритреја)',
        'ti_ET' => 'тигриња (Етиопија)',
        'tk' => 'туркменски',
        'tk_TM' => 'туркменски (Туркменистан)',
        'tl' => 'тагалог',
        'tl_PH' => 'тагалог (Филипини)',
        'to' => 'тонгански',
        'to_TO' => 'тонгански (Тонга)',
        'tr' => 'турски',
        'tr_CY' => 'турски (Кипар)',
        'tr_TR' => 'турски (Турска)',
        'tt' => 'татарски',
        'tt_RU' => 'татарски (Русија)',
        'ug' => 'ујгурски',
        'ug_CN' => 'ујгурски (Кина)',
        'uk' => 'украјински',
        'uk_UA' => 'украјински (Украјина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Индија)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'узбечки',
        'uz_AF' => 'узбечки (Авганистан)',
        'uz_Arab' => 'узбечки (арапско писмо)',
        'uz_Arab_AF' => 'узбечки (арапско писмо, Авганистан)',
        'uz_Cyrl' => 'узбечки (ћирилица)',
        'uz_Cyrl_UZ' => 'узбечки (ћирилица, Узбекистан)',
        'uz_Latn' => 'узбечки (латиница)',
        'uz_Latn_UZ' => 'узбечки (латиница, Узбекистан)',
        'uz_UZ' => 'узбечки (Узбекистан)',
        'vi' => 'вијетнамски',
        'vi_VN' => 'вијетнамски (Вијетнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'xh' => 'коса',
        'xh_ZA' => 'коса (Јужноафричка Република)',
        'yi' => 'јидиш',
        'yi_001' => 'јидиш (свет)',
        'yo' => 'јоруба',
        'yo_BJ' => 'јоруба (Бенин)',
        'yo_NG' => 'јоруба (Нигерија)',
        'zh' => 'кинески',
        'zh_CN' => 'кинески (Кина)',
        'zh_HK' => 'кинески (САР Хонгконг [Кина])',
        'zh_Hans' => 'кинески (поједностављено кинеско писмо)',
        'zh_Hans_CN' => 'кинески (поједностављено кинеско писмо, Кина)',
        'zh_Hans_HK' => 'кинески (поједностављено кинеско писмо, САР Хонгконг [Кина])',
        'zh_Hans_MO' => 'кинески (поједностављено кинеско писмо, САР Макао [Кина])',
        'zh_Hans_SG' => 'кинески (поједностављено кинеско писмо, Сингапур)',
        'zh_Hant' => 'кинески (традиционално кинеско писмо)',
        'zh_Hant_HK' => 'кинески (традиционално кинеско писмо, САР Хонгконг [Кина])',
        'zh_Hant_MO' => 'кинески (традиционално кинеско писмо, САР Макао [Кина])',
        'zh_Hant_TW' => 'кинески (традиционално кинеско писмо, Тајван)',
        'zh_MO' => 'кинески (САР Макао [Кина])',
        'zh_SG' => 'кинески (Сингапур)',
        'zh_TW' => 'кинески (Тајван)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Јужноафричка Република)',
    ],
];
