<?php

return [
    'Names' => [
        'aa' => '𞤀𞤬𞤢𞥄𞤪𞤫',
        'ab' => '𞤀𞤦𞤳𞤢𞥄𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'ace' => '𞤀𞥄𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'ada' => '𞤀𞤣𞤢𞤲𞤺𞤥𞤫𞥅𞤪𞤫',
        'ady' => '𞤀𞤣𞤭𞤿𞤭𞥅𞤪𞤫',
        'af' => '𞤀𞤬𞤪𞤭𞤳𞤢𞤲𞤪𞤫',
        'agq' => '𞤀𞤺𞤸𞤫𞤥𞤪𞤫',
        'ain' => '𞤀𞤴𞤲𞤵𞥅𞤪𞤫',
        'ak' => '𞤀𞤳𞤢𞤲𞤪𞤫',
        'ale' => '𞤀𞤤𞤫𞤵𞤼𞤵𞥅𞤪𞤫',
        'alt' => '𞤀𞤤𞤼𞤢𞤴𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫𞤲𞤳𞤮𞥅𞤪𞤫',
        'am' => '𞤀𞤥𞤸𞤢𞤪𞤭𞥅𞤪𞤫',
        'an' => '𞤀𞤪𞤢𞤺𞤮𞤲𞤪𞤫',
        'ann' => '𞤌𞤦𞤮𞤤𞤮𞥅𞤪𞤫',
        'anp' => '𞤀𞤲𞤺𞤭𞤳𞤢𞥄𞤪𞤫',
        'ar' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫',
        'arn' => '𞤃𞤢𞤨𞤵𞤷𞤭𞥅𞤪𞤫',
        'arp' => '𞤀𞤪𞤢𞤨𞤢𞤸𞤮𞥅𞤪𞤫',
        'ars' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 𞤐𞤢𞤶𞤣𞤭',
        'as' => '𞤀𞤧𞤢𞤥𞤫𞥅𞤪𞤫',
        'asa' => '𞤀𞤧𞤵𞥅𞤪𞤫',
        'ast' => '𞤀𞤧𞤼𞤵𞤪𞤭𞥅𞤪𞤫',
        'atj' => '𞤀𞤼𞤭𞤥𞤫𞤳𞤵𞤱𞤪𞤫',
        'av' => '𞤀𞤬𞤱𞤢𞤪𞤭𞥅𞤪𞤫',
        'awa' => '𞤀𞤱𞤢𞤣𞤭𞥅𞤪𞤫',
        'ay' => '𞤀𞤴𞤥𞤢𞤪𞤢𞥄𞤪𞤫',
        'az' => '𞤀𞤶𞤢𞤪𞤦𞤢𞤴𞤭𞤶𞤢𞤲𞤭𞥅𞤪𞤫',
        'ba' => '𞤄𞤢𞤧𞤳𞤭𞥅𞤪𞤫',
        'ban' => '𞤄𞤢𞥄𞤤𞤭𞥅𞤪𞤫',
        'bas' => '𞤄𞤢𞤧𞤢𞥄𞤪𞤫',
        'be' => '𞤄𞤫𞤤𞤢𞤪𞤭𞥅𞤧𞤭𞥅𞤪𞤫',
        'bem' => '𞤄𞤫𞤥𞤦𞤢𞥄𞤪𞤫',
        'bez' => '𞤄𞤫𞤲𞤢𞥄𞤪𞤫',
        'bg' => '𞤄𞤭𞤤𞤺𞤢𞥄𞤪𞤫',
        'bho' => '𞤄𞤮𞤧𞤨𞤵𞤪𞤭𞥅𞤪𞤫',
        'bi' => '𞤄𞤭𞤧𞤤𞤢𞤥𞤢𞥄𞤪𞤫',
        'bin' => '𞤄𞤭𞤲𞤭𞥅𞤪𞤫',
        'bla' => '𞤅𞤭𞤳𞤧𞤭𞤳𞤢𞥄𞤪𞤫',
        'bm' => '𞤄𞤢𞤥𞤦𞤢𞤪𞤢𞥄𞤪𞤫',
        'bn' => '𞤄𞤫𞤲𞤺𞤢𞤤𞤭𞥅𞤪𞤫',
        'bo' => '𞤚𞤭𞤦𞤫𞤼𞤫𞤲𞤪𞤫',
        'br' => '𞤄𞤫𞤪𞤫𞤼𞤮𞤲𞤪𞤫',
        'brx' => '𞤄𞤮𞤣𞤮𞥅𞤪𞤫',
        'bs' => '𞤄𞤮𞤧𞤲𞤭𞤴𞤢𞥄𞤪𞤫',
        'bug' => '𞤄𞤵𞤺𞤭𞤧𞤢𞥄𞤪𞤫',
        'byn' => '𞤄𞤭𞤤𞤭𞤲𞤪𞤫',
        'ca' => '𞤑𞤢𞤼𞤢𞤤𞤢𞤲𞤪𞤫',
        'cay' => '𞤑𞤢𞤴𞤺𞤢𞥄𞤪𞤫',
        'ccp' => '𞤅𞤢𞤳𞤥𞤢𞥄𞤪𞤫',
        'ce' => '𞤕𞤫𞤷𞤫𞤲𞤪𞤫',
        'ceb' => '𞤅𞤫𞤦𞤱𞤢𞤲𞤮𞥅𞤪𞤫',
        'cgg' => '𞤕𞤭𞤺𞤢𞥄𞤪𞤫',
        'ch' => '𞤕𞤢𞤥𞤮𞤪𞤮𞥅𞤪𞤫',
        'chk' => '𞤕𞤵𞥅𞤳𞤵𞥅𞤪𞤫',
        'chm' => '𞤃𞤢𞤪𞤭𞥅𞤪𞤫',
        'cho' => '𞤕𞤢𞤸𞤼𞤢𞥄𞤪𞤫',
        'chp' => '𞤕𞤭𞤨𞤴𞤢𞤲𞤪𞤫',
        'chr' => '𞤕𞤫𞥅𞤪𞤮𞤳𞤭𞥅𞤪𞤫',
        'chy' => '𞤅𞤢𞥄𞤴𞤢𞤲𞤪𞤫',
        'ckb' => '𞤑𞤵𞤪𞤣𞤵𞥅𞤪𞤫',
        'clc' => '𞤕𞤭𞤤𞤳𞤮𞤼𞤭𞤲𞤪𞤫',
        'co' => '𞤑𞤮𞤪𞤧𞤭𞤳𞤢𞥄𞤪𞤫',
        'crg' => '𞤃𞤭𞤷𞤭𞤬𞤪𞤫',
        'crj' => '𞤑𞤪𞤭𞥅𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫𞤲𞤳𞤮',
        'crk' => '𞤆𞤤𞤫𞤭𞤲𞤧 𞤑𞤪𞤭𞥅𞤪𞤫',
        'crl' => 'Vote 𞤑𞤪𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞤬𞤵𞤯𞤲𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'crm' => '𞤃𞤮𞥅𞤧𞤫 𞤑𞤪𞤭𞥅𞤪𞤫',
        'crr' => '𞤀𞤤𞤺𞤮𞤲𞤳𞤭𞤲𞤪𞤫 𞤑𞤢𞥄𞤪𞤤𞤭𞤲𞤢',
        'cs' => '𞤕𞤫𞤳𞤧𞤭𞤲𞤢𞥄𞤪𞤫',
        'csw' => '𞤑𞤪𞤭𞥅𞤪𞤫 𞤅𞤢𞤱𞤨𞤭𞥅',
        'cu' => '𞤅𞤭𞤤𞤾𞤭𞤳𞤪𞤫 𞤕𞤮𞥅𞤷𞤭',
        'cv' => '𞤕𞤵𞥅𞤾𞤢𞤧𞤪𞤫',
        'cy' => '𞤘𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'da' => '𞤁𞤢𞥄𞤲𞤭𞤧𞤳𞤮𞥅𞤪𞤫',
        'dak' => '𞤁𞤢𞤳𞤮𞤼𞤢𞥄𞤪𞤫',
        'dar' => '𞤁𞤢𞤪𞤺𞤭𞤲𞤢𞥄𞤪𞤫',
        'dav' => '𞤚𞤢𞤭𞤼𞤢𞥄𞤪𞤫',
        'de' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'dgr' => '𞤁𞤮𞤺𞤪𞤭𞤦𞤪𞤫',
        'dje' => '𞤔𞤢𞤪𞤥𞤢𞥄𞤪𞤫',
        'doi' => '𞤁𞤮𞤺𞤪𞤭𞥅𞤪𞤫',
        'dsb' => '𞤂𞤫𞤧 𞤅𞤮𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫',
        'dua' => '𞤁𞤵𞤱𞤢𞤤𞤢𞥄𞤪𞤫',
        'dv' => '𞤁𞤭𞥅𞤬𞤫𞤸𞤭𞥅𞤪𞤫',
        'dyo' => '𞤔𞤮𞥅𞤤𞤢𞥄𞤪𞤫',
        'dz' => '𞤄𞤵𞥅𞤼𞤢𞤲𞤪𞤫',
        'dzg' => '𞤁𞤢𞤶𞤢𞤺𞤢𞥄𞤪𞤫',
        'ebu' => '𞤉𞤥𞤦𞤵𞥅𞤪𞤫',
        'ee' => '𞤉𞤱𞤫𞥅𞤪𞤫',
        'efi' => '𞤉𞤬𞤭𞤳𞤪𞤫',
        'eka' => '𞤉𞤳𞤢𞤶𞤵𞤳𞤪𞤫',
        'el' => '𞤘𞤭𞥅𞤪𞤧𞤢𞥄𞤪𞤫',
        'en' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫',
        'eo' => '𞤉𞤧𞤨𞤫𞤪𞤢𞤲𞤼𞤮𞥅𞤪𞤫',
        'es' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'et' => '𞤉𞤧𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'eu' => '𞤄𞤢𞤧𞤳𞤢𞤪𞤢𞥄𞤪𞤫',
        'ewo' => '𞤉𞤱𞤮𞤲𞤣𞤮𞥅𞤪𞤫',
        'fa' => '𞤊𞤢𞥄𞤪𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'ff' => '𞤆𞤵𞤤𞤢𞤪',
        'fi' => '𞤊𞤫𞤲𞤭𞤧𞤪𞤫',
        'fil' => '𞤊𞤭𞤤𞤭𞤨𞤭𞤲𞤮𞥅𞤪𞤫',
        'fj' => '𞤊𞤭𞥅𞤶𞤭𞤴𞤢𞤲𞤪𞤫',
        'fo' => '𞤊𞤫𞤪𞤮𞤱𞤫𞤧𞤪𞤫',
        'fon' => '𞤊𞤮𞤲𞤪𞤫',
        'fr' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫',
        'frc' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 𞤑𞤢𞤣𞤭𞤴𞤫𞤲𞤪𞤫',
        'fur' => '𞤊𞤭𞤪𞥇𞤵𞤤𞤭𞤴𞤢𞤲𞤪𞤫',
        'fy' => '𞤊𞤭𞤪𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤖𞤭𞤪𞤲𞤢',
        'ga' => '𞤋𞤪𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'gaa' => '𞤘𞤢𞥄𞤪𞤫',
        'gd' => '𞤅𞤭𞤳𞤮𞤼𞤭𞤧𞤪𞤫 𞤘𞤢𞤫𞤭𞤳',
        'gez' => '𞤘𞤫𞥅𞤶𞤪𞤫',
        'gil' => '𞤘𞤭𞤤𞤦𞤫𞤪𞤼𞤫𞥅𞤧𞤪𞤫',
        'gl' => '𞤘𞤢𞤤𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'gn' => '𞤘𞤵𞤢𞤪𞤢𞤲𞤭𞥅𞤪𞤫',
        'gor' => '𞤘𞤮𞤪𞤮𞤲𞤼𞤢𞤤𞤮𞥅𞤪𞤫',
        'gsw' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤪𞤫 𞤅𞤵𞤱𞤭𞤧',
        'gu' => '𞤘𞤵𞤶𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫',
        'guz' => '𞤘𞤵𞤧𞤭𞥅𞤪𞤫',
        'gv' => '𞤃𞤢𞤲𞤳𞤭𞤧𞤪𞤫',
        'gwi' => '𞤘𞤭𞤱𞤧𞤭𞤲𞤪𞤫',
        'ha' => '𞤖𞤢𞤱𞤧𞤢𞥄𞤪𞤫',
        'hai' => '𞤖𞤢𞤴𞤣𞤢𞥄𞤪𞤫',
        'haw' => '𞤖𞤢𞤱𞤢𞥄𞤭𞤴𞤫𞤲𞤪𞤫',
        'hax' => '𞤖𞤢𞤭𞤣𞤢𞥄𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫𞤲𞤳𞤮',
        'he' => '𞤖𞤭𞤦𞤵𞤪𞤵𞥅𞤪𞤫',
        'hi' => '𞤖𞤭𞤲𞤣𞤭𞥅𞤪𞤫',
        'hil' => '𞤖𞤭𞤤𞤭𞤺𞤢𞤴𞤲𞤮𞤲𞤪𞤫',
        'hmn' => '𞤖𞤵𞤥𞤺𞤵𞤲𞤪𞤫',
        'hr' => '𞤑𞤮𞤪𞤮𞤱𞤢𞤧𞤭𞥅𞤪𞤫',
        'hsb' => '𞤅𞤮𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫 𞤁𞤮𞤱𞤪𞤭',
        'ht' => '𞤀𞤳𞤵𞥅𞤪𞤫 𞤖𞤢𞤴𞤼𞤭𞥅',
        'hu' => '𞤖𞤵𞤲𞤺𞤢𞤪𞤭𞤴𞤢𞤲𞤪𞤫',
        'hup' => '𞤖𞤵𞤨𞤢𞥄𞤪𞤫',
        'hur' => '𞤖𞤢𞤤𞤳𞤮𞤥𞤫𞤤𞤫𞤥𞤪𞤫',
        'hy' => '𞤀𞤪𞤥𞤫𞤲𞤭𞥅𞤪𞤫',
        'hz' => '𞤖𞤫𞤪𞤫𞤪𞤮𞥅𞤪𞤫',
        'ia' => '𞤉𞤲𞤼𞤫𞤪𞤤𞤭𞤺𞤢𞥄𞤪𞤫',
        'iba' => '𞤋𞤦𞤢𞤲𞤪𞤫',
        'ibb' => '𞤋𞤦𞤭𞥅𞤦𞤭𞤴𞤮𞥅𞤪𞤫',
        'id' => '𞤋𞤲𞤣𞤮𞤲𞤭𞥅𞤧𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'ig' => '𞤋𞤦𞤮𞥅𞤪𞤫',
        'ii' => '𞤅𞤭𞤧𞤵𞤢𞤲𞤪𞤫 𞤒𞤭𞥅',
        'ikt' => '𞤋𞤲𞤵𞤳𞤼𞤵𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫 𞤑𞤢𞤲𞤢𞤣𞤢𞥄',
        'ilo' => '𞤋𞤤𞤮𞤳𞤮𞥅𞤪𞤫',
        'inh' => '𞤋𞤲𞤺𞤮𞤧𞤫𞥅𞤪𞤫',
        'io' => '𞤋𞤣𞤮𞥅𞤪𞤫',
        'is' => '𞤀𞤴𞤧𞤭𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'it' => '𞤋𞤼𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'iu' => '𞤋𞤲𞤵𞤳𞤼𞤫𞥅𞤪𞤫',
        'ja' => '𞤐𞤭𞤨𞤮𞤲𞤪𞤫',
        'jbo' => '𞤂𞤮𞤶𞤦𞤢𞤲𞤪𞤫',
        'jgo' => '𞤐𞤺𞤮𞤥𞤦𞤢𞥄𞤪𞤫',
        'jmc' => '𞤃𞤢𞤳𞤢𞤥𞤫𞥅𞤪𞤫',
        'jv' => '𞤔𞤢𞥄𞤱𞤢𞤫𞥅𞤪𞤫',
        'ka' => '𞤔𞤮𞥅𞤪𞥁𞤭𞤴𞤢𞤲𞤪𞤫',
        'kab' => '𞤑𞤢𞤦𞤭𞤤𞤭𞥅𞤪𞤫',
        'kac' => '𞤑𞤢𞤧𞤭𞤲𞤪𞤫',
        'kaj' => '𞤑𞤢𞤶𞤫𞥅𞤪𞤫',
        'kam' => '𞤑𞤢𞤥𞤦𞤢𞥄𞤪𞤫',
        'kbd' => '𞤑𞤢𞤦𞤢𞤪𞤣𞤭𞤴𞤢𞤲𞤪𞤫',
        'kcg' => '𞤚𞤵𞤴𞤢𞤨𞤵𞥅𞤪𞤫',
        'kde' => '𞤃𞤢𞤳𞤮𞤲𞤣𞤫𞥅𞤪𞤫',
        'kea' => '𞤑𞤢𞤦𞤵𞤾𞤫𞤪𞤣𞤭𞤴𞤢𞤲𞤪𞤫',
        'kfo' => '𞤑𞤮𞤪𞤮𞥅𞤪𞤫',
        'kgp' => '𞤑𞤢𞤭𞤲𞤺𞤢𞤲𞤺𞤪𞤫',
        'kha' => '𞤝𞤢𞤧𞤭𞥅𞤪𞤫',
        'khq' => '𞤑𞤮𞤴𞤪𞤢𞤷𞤭𞤲𞤪𞤫',
        'ki' => '𞤑𞤭𞤳𞤵𞤴𞤵𞥅𞤪𞤫',
        'kj' => '𞤑𞤵𞤢𞤻𞤢𞤥𞤢𞥄𞤪𞤫',
        'kk' => '𞤑𞤢𞥁𞤢𞤳𞤪𞤫',
        'kkj' => '𞤑𞤢𞤳𞤮𞥅𞤪𞤫',
        'kl' => '𞤑𞤢𞤤𞤢𞥄𞤤𞤧𞤵𞤼𞤪𞤫',
        'kln' => '𞤑𞤢𞤤𞤫𞤲𞤶𞤭𞤲𞤪𞤫',
        'km' => '𞤑𞤵𞤥𞤢𞤴𞤪𞤫',
        'kmb' => '𞤑𞤭𞤥𞤦𞤵𞤲𞤣𞤵𞥅𞤪𞤫',
        'kn' => '𞤑𞤢𞤲𞥆𞤢𞤣𞤢𞥄𞤪𞤫',
        'ko' => '𞤑𞤮𞥅𞤪𞤫𞤴𞤢𞤲𞤪𞤫',
        'kok' => '𞤑𞤮𞤲𞤳𞤢𞤲𞤭𞥅𞤪𞤫',
        'kpe' => '𞤘𞤫𞤪𞤧𞤫𞥅𞤪𞤫',
        'kr' => '𞤑𞤮𞥅𞤤𞤫𞥅𞤪𞤫',
        'krc' => '𞤑𞤢𞤪𞤢𞤧𞤢𞤴-𞤄𞤢𞤤𞤳𞤢𞥄𞤪𞤫',
        'krl' => '𞤑𞤢𞤪𞤫𞤤𞤭𞤢𞤲𞤪𞤫',
        'kru' => '𞤑𞤵𞤪𞤵𞤿𞤵𞥅𞤪𞤫',
        'ks' => '𞤑𞤢𞥃𞤥𞤭𞥅𞤪𞤫',
        'ksb' => '𞤅𞤢𞤥𞤦𞤢𞤤𞤢𞥄𞤪𞤫',
        'ksf' => '𞤄𞤢𞤬𞤭𞤴𞤢𞥄𞤪𞤫',
        'ksh' => '𞤑𞤮𞤤𞤮𞤺𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'ku' => '𞤑𞤵𞤪𞤣𞤭𞤧𞤭𞥅𞤪𞤫',
        'kum' => '𞤑𞤵𞤥𞤴𞤢𞤳𞤪𞤫',
        'kv' => '𞤑𞤮𞤥𞤭𞥅𞤪𞤫',
        'kw' => '𞤑𞤮𞤪𞤲𞤭𞥅𞤪𞤫',
        'kwk' => '𞤑𞤢𞤱𞤳𞥇𞤱𞤢𞤤𞤢𞥄𞤪𞤫',
        'ky' => '𞤑𞤭𞤪𞤺𞤵𞥅𞤪𞤫',
        'la' => '𞤂𞤢𞤼𞤫𞤲𞤪𞤫',
        'lad' => '𞤂𞤢𞤣𞤭𞤲𞤮𞥅𞤪𞤫',
        'lag' => '𞤂𞤢𞤲𞤺𞤭𞥅𞤪𞤫',
        'lb' => '𞤂𞤵𞥁𞤫𞤲𞤦𞤵𞥅𞤪𞤺𞤭𞤧𞤪𞤫',
        'lez' => '𞤂𞤫𞥁𞤺𞤭𞤴𞤢𞤲𞤪𞤫',
        'lg' => '𞤘𞤢𞤲𞤣𞤢𞥄𞤪𞤫',
        'li' => '𞤂𞤭𞤥𞤦𞤵𞤪𞤺𞤵𞤧𞤪𞤫',
        'lij' => '𞤂𞤳𞤭𞤺𞤵𞥅𞤪𞤫',
        'lil' => '𞤂𞤭𞤤𞥆𞤮𞥅𞤫𞤼𞤪𞤫',
        'lkt' => '𞤂𞤢𞤳𞤮𞤼𞤢𞥄𞤪𞤫',
        'ln' => '𞤂𞤭𞤲𞤺𞤢𞤤𞤢𞥄𞤪𞤫',
        'lo' => '𞤂𞤢𞤮𞥅𞤪𞤫',
        'lou' => '𞤀𞤳𞤵𞥅𞤪𞤫 𞤂𞤵𞥅𞥁𞤭𞤴𞤢𞥄𞤲𞤢',
        'loz' => '𞤂𞤮𞥁𞤭𞥅𞤪𞤫',
        'lrc' => '𞤂𞤵𞤪𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'lsm' => '𞤅𞤢𞥄𞤥𞤭𞤢𞥄𞤪𞤫',
        'lt' => '𞤂𞤭𞤼𞤮𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'lu' => '𞤂𞤵𞤦𞤢-𞤑𞤢𞤼𞤢𞤲𞤺𞤢𞥄𞤪𞤫',
        'lua' => '𞤂𞤵𞤦𞤢 𞤑𞤢𞤧𞤢𞤭𞤪𞤫',
        'lun' => '𞤂𞤵𞤲𞤣𞤢𞥄𞤪𞤫',
        'luo' => '𞤂𞤵𞤮𞥅𞤪𞤫',
        'lus' => '𞤃𞤭𞤧𞤮𞥅𞤪𞤫',
        'luy' => '𞤂𞤵𞤴𞤭𞤢𞥄𞤪𞤫',
        'lv' => '𞤂𞤢𞤼𞤾𞤭𞤴𞤢𞤲𞤪𞤫',
        'mad' => '𞤃𞤢𞤣𞤵𞤪𞤫𞥅𞤪𞤫',
        'mag' => '𞤃𞤢𞤺𞤢𞤸𞤭𞥅𞤪𞤫',
        'mai' => '𞤃𞤢𞤴𞤭𞤼𞤭𞤤𞤭𞥅𞤪𞤫',
        'mak' => '𞤃𞤢𞤳𞤢𞤧𞤢𞤪𞤢𞥄𞤪𞤫',
        'mas' => '𞤃𞤢𞤧𞤢𞤴𞤭𞥅𞤪𞤫',
        'mdf' => '𞤃𞤮𞤳𞤧𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'men' => '𞤃𞤫𞤲𞤣𞤫𞥅𞤪𞤫',
        'mer' => '𞤃𞤫𞤪𞤵𞥅𞤪𞤫',
        'mfe' => '𞤃𞤮𞤪𞤭𞥅𞤧𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'mg' => '𞤃𞤢𞤤𞤢𞤺𞤢𞤧𞤭𞥅𞤪𞤫',
        'mgh' => '𞤃𞤢𞤳𞤵𞤱𞤢𞥄𞤪𞤫',
        'mgo' => '𞤃𞤫𞤼𞤢𞥄𞤪𞤫',
        'mh' => '𞤃𞤢𞤪𞤧𞤢𞤤𞤫𞥅𞤪𞤫',
        'mi' => '𞤃𞤢𞥄𞤮𞤪𞤭𞥅𞤪𞤫',
        'mic' => '𞤃𞤭𞤳𞤥𞤢𞤹𞤵𞥅𞤪𞤫',
        'min' => '𞤃𞤭𞤲𞤢𞤲𞤺𞤳𞤢𞤦𞤢𞤵𞥅𞤪𞤫',
        'mk' => '𞤃𞤢𞤧𞤫𞤣𞤮𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'ml' => '𞤃𞤢𞤤𞤢𞤴𞤢𞤤𞤢𞤥𞤪𞤫',
        'mn' => '𞤃𞤮𞤲𞤺𞤮𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'mni' => '𞤃𞤢𞤲𞤭𞤨𞤵𞥅𞤪𞤫',
        'moe' => '𞤋𞤲𞥆𞤵-𞤢𞤴𞤥𞤵𞤲𞤪𞤫',
        'moh' => '𞤃𞤮𞥅𞤸𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'mos' => '𞤃𞤮𞥅𞤧𞤭𞥅𞤪𞤫',
        'mr' => '𞤃𞤢𞤪𞤢𞤼𞤭𞥅𞤪𞤫',
        'ms' => '𞤃𞤢𞤤𞤫𞥅𞤪𞤫',
        'mt' => '𞤃𞤢𞤤𞤼𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'mua' => '𞤃𞤵𞤲𞤣𞤢𞤲𞤪𞤫',
        'mus' => '𞤃𞤵𞤧𞤳𞤮𞤳𞤭𞥅𞤪𞤫',
        'mwl' => '𞤃𞤭𞤪𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'my' => '𞤄𞤵𞤪𞤥𞤢𞥄𞤪𞤫',
        'myv' => '𞤉𞤪𞤶𞤭𞤴𞤢𞤲𞤪𞤫',
        'mzn' => '𞤃𞤢𞥁𞤢𞤲𞤣𞤫𞤪𞤢𞤲𞤭𞥅𞤪𞤫',
        'na' => '𞤐𞤢𞤱𞤵𞤪𞤵𞤲𞤳𞤮𞥅𞤪𞤫',
        'nap' => '𞤐𞤢𞥄𞤨𞤮𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'naq' => '𞤐𞤢𞤥𞤢𞥄𞤪𞤫',
        'nb' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤄𞤮𞤳𞤥𞤢𞤤',
        'nd' => '𞤐𞤣𞤫𞤦𞤫𞤤𞤫𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤺𞤫',
        'nds' => '𞤂𞤫𞤧-𞤀𞤤𞤵𞤥𞤢𞤲𞤪𞤫',
        'ne' => '𞤐𞤫𞤨𞤢𞤤𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'new' => '𞤐𞤫𞤱𞤢𞤪𞤭𞥅𞤪𞤫',
        'ng' => '𞤐𞤣𞤮𞤲𞤺𞤢𞥄𞤪𞤫',
        'nia' => '𞤙𞤢𞤧𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'niu' => '𞤐𞤭𞤵𞤫𞤴𞤢𞤲𞤪𞤫',
        'nl' => '𞤁𞤮𞥅𞤷𞤵𞤪𞤫',
        'nmg' => '𞤐𞤺𞤵𞤥𞤦𞤢𞥄𞤪𞤫',
        'nn' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫 𞤙𞤮𞤪𞤧𞤳',
        'nnh' => '𞤐𞤶𞤢𞤥𞤦𞤵𞥅𞤪𞤫',
        'no' => '𞤐𞤮𞤪𞤱𞤫𞤶𞤭𞤴𞤢𞤲𞤪𞤫',
        'nog' => '𞤐𞤮𞤺𞤢𞤭𞥅𞤪𞤫',
        'nqo' => '𞤐𞤳𞤮𞥅𞤪𞤫',
        'nr' => '𞤐𞤣𞤫𞤦𞤫𞤤𞤫𞥅𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫',
        'nso' => '𞤅𞤮𞤼𞤮𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'nus' => '𞤐𞤵𞤫𞤪𞤭𞥅𞤪𞤫',
        'nv' => '𞤐𞤢𞤬𞤱𞤢𞤸𞤮𞥅𞤪𞤫',
        'ny' => '𞤙𞤢𞤲𞤶𞤢𞥄𞤪𞤫',
        'nyn' => '𞤙𞤢𞤲𞤳𞤮𞤤𞤫𞥅𞤪𞤫',
        'oc' => '𞤌𞤷𞥆𞤭𞤼𞤢𞤲𞤪𞤫',
        'ojb' => '𞤌𞤶𞤭𞤦𞤵𞤱𞤢𞥄𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'ojc' => '𞤌𞤶𞤭𞤦𞤵𞤱𞤪𞤫 𞤕𞤢𞤳𞤢',
        'ojs' => '𞤌𞤶𞤭-𞤑𞤪𞤭𞥅𞤪𞤫',
        'ojw' => '𞤌𞤶𞤭𞤦𞤱𞤢𞥄𞤪𞤫 𞤖𞤭𞥅𞤪𞤲𞤢𞥄𞤲𞤺𞤫',
        'oka' => '𞤌𞤳𞤢𞤲𞤢𞤺𞤢𞤲𞤪𞤫',
        'om' => '𞤌𞤪𞤮𞤥𞤮𞥅𞤪𞤫',
        'or' => '𞤌𞤣𞤭𞤢𞥄𞤪𞤫',
        'os' => '𞤌𞤧𞥆𞤫𞤼𞤭𞤳𞤪𞤫',
        'pa' => '𞤆𞤵𞤲𞤶𞤢𞥄𞤦𞤭𞥅𞤪𞤫',
        'pag' => '𞤆𞤢𞤲𞤺𞤢𞤧𞤭𞤲𞤢𞤲𞤪𞤫',
        'pam' => '𞤆𞤢𞤥𞤨𞤢𞤲𞤺𞤢𞥄𞤪𞤫',
        'pap' => '𞤆𞤢𞤨𞤭𞤢𞤥𞤫𞤲𞤼𞤮𞥅𞤪𞤫',
        'pau' => '𞤆𞤢𞤤𞤢𞤵𞤴𞤢𞤲𞤪𞤫',
        'pcm' => '𞤆𞤭𞤶𞤫𞤲𞤪𞤫 𞤐𞤢𞤶𞤭𞤪𞤭𞤴𞤢𞥄',
        'pis' => '𞤆𞤭𞤶𞤭𞤲𞤪𞤫',
        'pl' => '𞤆𞤮𞤤𞤢𞤲𞤣𞤭𞥅𞤪𞤫',
        'pqm' => '𞤃𞤢𞤤𞤭𞤧𞤫𞥅𞤼-𞤆𞤢𞤧𞤢𞤥𞤢𞤹𞤵𞤮𞤣𞥆𞤭',
        'prg' => '𞤆𞤵𞤪𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'ps' => '𞤆𞤢𞤧𞤼𞤵𞤲𞤪𞤫',
        'pt' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫',
        'qu' => '𞤗𞤵𞤷𞤵𞤢𞤲𞤪𞤫',
        'rap' => '𞤈𞤢𞤨𞤢𞤲𞤵𞤭𞥅𞤪𞤫',
        'rar' => '𞤈𞤢𞤪𞤮𞤼𞤮𞤲𞤺𞤢𞤲𞤪𞤫',
        'rhg' => '𞤈𞤮𞤸𞤭𞤲𞤺𞤢𞥄𞤪𞤫',
        'rm' => '𞤈𞤮𞤥𞤢𞤲𞤧𞤪𞤫',
        'rn' => '𞤈𞤵𞤲𞤣𞤭𞥅𞤪𞤫',
        'ro' => '𞤈𞤮𞤥𞤢𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'rof' => '𞤈𞤮𞤥𞤦𞤮𞥅𞤪𞤫',
        'ru' => '𞤈𞤮𞥅𞤧𞤭𞤴𞤢𞤲𞤪𞤫',
        'rup' => '𞤀𞤪𞤮𞤥𞤢𞤲𞤭𞥅𞤪𞤫',
        'rw' => '𞤑𞤭𞤻𞤭𞤪𞤵𞤱𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'rwk' => '𞤈𞤵𞤱𞤢𞥄𞤪𞤫',
        'sa' => '𞤅𞤢𞤲𞤧𞤳𞤪𞤭𞤼𞤪𞤫',
        'sad' => '𞤅𞤢𞤲𞤣𞤢𞤱𞤫𞥅𞤪𞤫',
        'sah' => '𞤅𞤢𞤿𞤢𞥄𞤪𞤫',
        'saq' => '𞤅𞤢𞤥𞤦𞤵𞤪𞤵𞥅𞤪𞤫',
        'sat' => '𞤅𞤢𞤲𞤼𞤢𞤤𞤭𞥅𞤪𞤫',
        'sba' => '𞤐𞤺𞤢𞤥𞤦𞤢𞤴𞤪𞤫',
        'sbp' => '𞤅𞤢𞤲𞤺𞤵𞥅𞤪𞤫',
        'sc' => '𞤅𞤢𞤪𞤣𞤭𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'scn' => '𞤅𞤭𞤧𞤭𞤤𞤭𞤴𞤢𞤲𞤪𞤫',
        'sco' => '𞤅𞤭𞤳𞤮𞤼𞤧𞤪𞤫',
        'sd' => '𞤅𞤭𞤲𞤣𞤢𞥄𞤪𞤫',
        'se' => '𞤅𞤢𞤥𞤭𞥅𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'seh' => '𞤅𞤫𞤲𞤢𞥄𞤪𞤫',
        'ses' => '𞤑𞤮𞤪𞤮𞤦𞤮𞤪𞤮𞥅𞤪𞤫 𞤅𞤫𞤲𞥆𞤭',
        'sg' => '𞤅𞤢𞤲𞤺𞤮𞥅𞤪𞤫',
        'shi' => '𞤚𞤢𞤧𞤭𞤤𞤸𞤭𞤼𞤪𞤫',
        'shn' => '𞤅𞤢𞤲𞤪𞤫',
        'si' => '𞤅𞤭𞤲𞤸𞤢𞤤𞤢𞥄𞤪𞤫',
        'sk' => '𞤅𞤤𞤮𞤾𞤢𞥄𞤳𞤪𞤫',
        'sl' => '𞤅𞤤𞤮𞤾𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'slh' => '𞤂𞤵𞥃𞤵𞤼𞤧𞤭𞤣𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫𞤲𞤳𞤮',
        'sm' => '𞤅𞤢𞤥𞤮𞤢𞤲𞤪𞤫',
        'smn' => '𞤋𞤲𞤢𞤪𞤭𞤧𞤳𞤢𞤤𞤭𞥅𞤪𞤫',
        'sms' => '𞤅𞤭𞤳𞤮𞤤𞤼 𞤅𞤢𞤥𞤭𞥅𞤪𞤫',
        'sn' => '𞤅𞤮𞤲𞤢𞥄𞤪𞤫',
        'snk' => '𞤅𞤢𞤪𞤢𞤲𞤳𞤵𞤤𞥆𞤪𞤫',
        'so' => '𞤅𞤮𞤥𞤢𞤤𞤭𞥅𞤪𞤫',
        'sq' => '𞤀𞤤𞤦𞤢𞤲𞤭𞥅𞤪𞤫',
        'sr' => '𞤅𞤫𞤪𞤦𞤭𞤴𞤢𞤲𞤪𞤫',
        'srn' => '𞤅𞤢𞤪𞤲𞤢𞤲-𞤚𞤮𞤲𞤺𞤮𞥅𞤪𞤫',
        'ss' => '𞤅𞤵𞤱𞤢𞤼𞤭𞥅𞤪𞤫',
        'st' => '𞤅𞤮𞤼𞤮𞥅𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫𞤲𞤳𞤮',
        'str' => '𞤅𞤭𞤼𞤪𞤭𞤼 𞤅𞤢𞤤𞤭𞤧𞤪𞤫',
        'su' => '𞤅𞤵𞤲𞤣𞤢𞤲𞤭𞥅𞤪𞤫',
        'suk' => '𞤅𞤵𞤳𞤵𞤥𞤢𞥄𞤪𞤫',
        'sv' => '𞤅𞤱𞤫𞤣𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'sw' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫',
        'swb' => '𞤑𞤮𞤥𞤮𞤪𞤭𞥅𞤪𞤫',
        'syr' => '𞤅𞤭𞥅𞤪𞤭𞤴𞤢𞤳𞤪𞤫',
        'ta' => '𞤚𞤢𞤥𞤵𞤤𞤪𞤫',
        'tce' => '𞤚𞤵𞤼𞤳𞤮𞤲𞤭𞥅𞤪𞤫 𞤙𞤢𞥄𞤥𞤲𞤢𞥄𞤲𞤺𞤫',
        'te' => '𞤚𞤫𞤤𞤫𞤺𞤵𞥅𞤪𞤫',
        'tem' => '𞤚𞤫𞤥𞤫𞤲𞤫𞥅𞤪𞤫',
        'teo' => '𞤚𞤫𞤧𞤮𞥅𞤪𞤫',
        'tet' => '𞤚𞤫𞤼𞤵𞤥𞤪𞤫',
        'tg' => '𞤚𞤢𞤶𞤭𞤳𞤪𞤫',
        'tgx' => '𞤚𞤢𞤺𞤭𞥃𞤪𞤫',
        'th' => '𞤚𞤢𞤴𞤤𞤢𞤲𞤣𞤫𞥅𞤪𞤫',
        'tht' => '𞤚𞤢𞤸𞤢𞤤𞤼𞤢𞤲𞤪𞤫',
        'ti' => '𞤚𞤭𞤺𞤭𞤪𞤻𞤢𞥄𞤪𞤫',
        'tig' => '𞤚𞤭𞤺𞤭𞤪𞤴𞤢𞤲𞤪𞤫',
        'tk' => '𞤼𞤵𞤪𞤳𞤥𞤢𞤲𞤪𞤫',
        'tlh' => '𞤑𞤭𞤤𞤭𞤲𞤺𞤮𞤲𞤪𞤫',
        'tli' => '𞤚𞤤𞤭𞤲𞤺𞤭𞤼𞤪𞤫',
        'tn' => '𞤚𞤭𞤧𞤱𞤢𞤲𞤢𞥄𞤪𞤫',
        'to' => '𞤚𞤮𞤲𞤺𞤢𞤲𞤪𞤫',
        'tok' => '𞤚𞤮𞤳𞤭 𞤆𞤮𞤲𞤢𞥄𞤪𞤫',
        'tpi' => '𞤚𞤮𞤳 𞤆𞤭𞤧𞤭𞤲𞤪𞤫',
        'tr' => '𞤚𞤵𞥅𞤪𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'trv' => '𞤚𞤢𞤪𞤮𞤳𞤮𞥅𞤪𞤫',
        'ts' => '𞤚𞤭𞤧𞤮𞤲𞤺𞤢𞥄𞤪𞤫',
        'tt' => '𞤚𞤢𞤼𞤢𞤪𞥇𞤪𞤫',
        'ttm' => '𞤚𞤵𞤼𞤷𞤮𞤲𞤫𞤲𞤪𞤫 𞤐𞤢𞤲𞥆𞤢𞥄𞤲𞤺𞤫𞥅𞤪𞤫',
        'tum' => '𞤚𞤵𞤥𞤦𞤵𞤳𞤢𞥄𞤪𞤫',
        'tvl' => '𞤚𞤵𞤾𞤢𞤤𞤵𞥅𞤪𞤫',
        'twq' => '𞤚𞤢𞤧𞤢𞥄𞤹𞤪𞤫',
        'ty' => '𞤚𞤢𞤸𞤭𞤼𞤭𞤴𞤢𞤲𞤪𞤫',
        'tyv' => '𞤚𞤵𞤾𞤭𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'tzm' => '𞤚𞤢𞤥𞤢𞤶𞤭𞤼𞤪𞤫 𞤅𞤢𞤲𞤼𞤪𞤢𞤤 𞤀𞤼𞤤𞤢𞤧',
        'udm' => '𞤓𞤣𞤥𞤵𞤪𞤼𞤪𞤫',
        'ug' => '𞤓𞥅𞤴𞤺𞤵𞥅𞤪𞤫',
        'uk' => '𞤒𞤵𞤳𞤪𞤫𞤲𞤭𞤴𞤢𞤲𞤪𞤫',
        'umb' => '𞤓𞤥𞤦𞤵𞤲𞤣𞤵𞥅𞤪𞤫',
        'ur' => '𞤓𞤪𞤣𞤵𞥅𞤪𞤫',
        'uz' => '𞤓𞥅𞤧𞤦𞤫𞤳𞤪𞤫',
        'vai' => '𞤾𞤢𞥄𞤴𞤪𞤫',
        've' => '𞤏𞤫𞤲𞤣𞤢𞥄𞤪𞤫',
        'vec' => '𞤏𞤫𞤲𞤭𞥅𞤧𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'vi' => '𞤏𞤭𞤴𞤫𞤼𞤲𞤢𞤥𞤭𞤲𞤳𞤮𞥅𞤪𞤫',
        'vo' => '𞤏𞤮𞤤𞤢𞤨𞤵𞤳𞤪𞤫',
        'vun' => '𞤏𞤵𞤲𞤶𞤮𞥅𞤪𞤫',
        'wa' => '𞤏𞤢𞥄𞤤𞤮𞤲𞤳𞤮𞥅𞤪𞤫',
        'wae' => '𞤏𞤢𞤤𞤧𞤫𞥅𞤪𞤫',
        'wal' => '𞤏𞤮𞥅𞤤𞤢𞤴𞤼𞤢𞥄𞤪𞤫',
        'war' => '𞤏𞤢𞤪𞤢𞤴𞤫𞥅𞤪𞤫',
        'wo' => '𞤏𞤮𞤤𞤮𞤬𞤪𞤫',
        'wuu' => '𞤏𞤵𞥅𞤪𞤫 𞤅𞤭𞥅𞤲',
        'xal' => '𞤑𞤢𞤤𞤥𞤵𞤳𞤪𞤫',
        'xh' => '𞤑𞤮𞥅𞤧𞤢𞥄𞤪𞤫',
        'xog' => '𞤅𞤮𞤺𞤢𞥄𞤪𞤫',
        'yav' => '𞤒𞤢𞤲𞤺𞤦𞤫𞥅𞤪𞤫',
        'ybb' => '𞤒𞤫𞤥𞤦𞤢𞥄𞤪𞤫',
        'yi' => '𞤒𞤭𞤣𞤭𞤧𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'yo' => '𞤒𞤮𞥅𞤪𞤵𞤦𞤢𞥄𞤪𞤫',
        'yrl' => '𞤛𞤫𞥅𞤲𞤺𞤢𞤼𞤵𞥅𞤪𞤫',
        'yue' => '𞤑𞤢𞤲𞤼𞤮𞤲𞤫𞥅𞤪𞤫',
        'zgh' => '𞤚𞤢𞤥𞤢𞥁𞤭𞤼𞤪𞤫 𞤖𞤢𞤲𞤼𞤵𞤲𞥋𞤣𞤫 𞤃𞤢𞤪𞤮𞥅𞤳',
        'zh' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'zu' => '𞥁𞤵𞤤𞤵𞥅𞤪𞤫',
        'zun' => '𞤟𞤵𞤲𞤭𞥅𞤪𞤫',
        'zza' => '𞤟𞤢𞥁𞤢𞥄𞤪𞤫',
    ],
    'LocalizedNames' => [
        'ar_001' => '𞤀𞥄𞤪𞤢𞤦𞤫𞥅𞤪𞤫 𞤊𞤵𞤧𞤸𞤢 𞤒𞤫𞤲𞤯𞤵𞤳𞤢',
        'de_AT' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 𞤌𞤼𞤭𞤪𞤧𞤢',
        'de_CH' => '𞤔𞤫𞤪𞤥𞤢𞤲𞤭𞤲𞤳𞤮𞥅𞤪𞤫 𞤅𞤵𞤱𞤭𞥅𞤧',
        'en_AU' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 𞤌𞤧𞤼𞤢𞤪𞤤𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'en_CA' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 𞤑𞤢𞤲𞤢𞤣𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'en_GB' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 𞤄𞤭𞤪𞤼𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'en_US' => '𞤉𞤲𞤺𞤭𞤤𞤫𞥅𞤪𞤫 𞤀𞤥𞤫𞤪𞤭𞤳𞤢𞤲𞤳𞤮𞤪𞤫',
        'es_419' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤀𞤥𞤭𞤪𞤭𞤳 𞤂𞤢𞤼𞤭𞤲𞤭𞤴𞤢',
        'es_ES' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤀𞤪𞤮𞤦𞤢',
        'es_MX' => '𞤅𞤭𞤨𞤢𞤲𞤭𞤴𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤃𞤫𞤳𞤧𞤭𞤳',
        'fa_AF' => '𞤁𞤢𞤪𞤭𞥅𞤪𞤫',
        'fr_CA' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 𞤑𞤢𞤲𞤢𞤣𞤢𞤲𞤳𞤮𞥅𞤪𞤫',
        'fr_CH' => '𞤊𞤢𞤪𞤢𞤲𞤧𞤭𞥅𞤪𞤫 𞤅𞤵𞤱𞤭𞥅𞤧',
        'nds_NL' => '𞤂𞤫𞤧 𞤅𞤢𞤳𞤧𞤮𞤲𞤪𞤫',
        'nl_BE' => '𞤊𞤭𞤤𞤢𞤥𞤢𞤲𞤪𞤫',
        'pt_BR' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 𞤄𞤪𞤫𞥁𞤭𞤤',
        'pt_PT' => '𞤆𞤮𞤪𞤼𞤮𞤳𞤫𞥅𞤧𞤭𞥅𞤪𞤫 𞤆𞤮𞤪𞤼𞤭𞤺𞤢𞥄𞤤',
        'ro_MD' => '𞤃𞤮𞤤𞤣𞤢𞤾𞤭𞤴𞤢𞤲𞤪𞤫',
        'sw_CD' => '𞤅𞤵𞤱𞤢𞤸𞤭𞤤𞤭𞥅𞤪𞤫 𞤑𞤮𞤲𞤺𞤮 𞤑𞤭𞤲𞤧𞤢𞤧𞤢',
        'zh_Hans' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤖𞤮𞤴𞤬𞤭𞤲𞤢𞥄𞤲𞤣𞤫',
        'zh_Hant' => '𞤕𞤢𞤴𞤲𞤢𞤲𞤳𞤮𞥅𞤪𞤫 𞤒𞤫𞤷𞥆𞤵𞤲𞥋𞤣𞤫',
    ],
];
