<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorra Pezetası',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Birleşik Arap Emirlikleri Dirhemi',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afganistan Afganisi (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afganistan Afganisi',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Arnavutluk Leki (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Arnavutluk Leki',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Ermenistan Dramı',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Hollanda Antilleri Guldeni',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angola Kvanzası',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angola Kvanzası (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Yeni Angola Kvanzası (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angola Kvanzası Reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Arjantin Australi',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Arjantin Peso Leyi (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Arjantin Pesosu (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Arjantin Pezosu (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Arjantin Pesosu',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Avusturya Şilini',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Avustralya Doları',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruba Florini',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbaycan Manatı (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaycan Manatı',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosna Hersek Dinarı',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Konvertibl Bosna Hersek Markı',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Yeni Bosna Hersek Dinarı (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados Doları',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladeş Takası',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belçika Frangı (konvertibl)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belçika Frangı',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belçika Frangı (finansal)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgar Levası (Hard)',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Sosyalist Bulgaristan Levası',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgar Levası',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Bulgar Levası (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreyn Dinarı',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi Frangı',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda Doları',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunei Doları',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivya Bolivyanosu',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Bolivya Bolivyanosu (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Bolivya Pezosu',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Bolivya Mvdolu',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Yeni Brezilya Kruzeirosu (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Brezilya Kruzadosu',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Brezilya Kruzeirosu (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Brezilya Reali',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Yeni Brezilya Kruzadosu',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brezilya Kruzeirosu',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Brezilya Kruzeirosu (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahama Doları',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butan Ngultrumu',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Burma Kyatı',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botsvana Pulası',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Yeni Beyaz Rusya Rublesi (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarus Rublesi',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Beyaz Rusya Rublesi (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belize Doları',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanada Doları',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongo Frangı',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR Avrosu',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'İsviçre Frangı',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR Frangı',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Şili Esküdosu',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Şili Unidades de Fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Şili Pesosu',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Çin Yuanı (offshore)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Çin Halk Cumhuriyeti Merkez Bankası Doları',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Çin Yuanı',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolombiya Pesosu',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Unidad de Valor Real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kosta Rika Kolonu',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Eski Sırbistan Dinarı',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Çekoslavak Korunası (Hard)',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Konvertibl Küba Pesosu',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Küba Pesosu',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Cape Verde Esküdosu',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Güney Kıbrıs Lirası',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Çek Korunası',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Doğu Alman Markı',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Alman Markı',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Cibuti Frangı',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Danimarka Kronu',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominik Pesosu',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Cezayir Dinarı',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ekvador Sukresi',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Ekvador Unidad de Valor Constante (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estonya Krunu',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Mısır Lirası',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritre Nakfası',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'İspanyol Pezetası (A hesabı)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'İspanyol Pezetası (konvertibl hesap)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'İspanyol Pezetası',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiyopya Birri',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Fin Markkası',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fiji Doları',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falkland Adaları Lirası',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Fransız Frangı',
        ],
        'GBP' => [
            0 => '£',
            1 => 'İngiliz Sterlini',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Gürcistan Kupon Larisi',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gürcistan Larisi',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Gana Sedisi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Gana Sedisi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Cebelitarık Lirası',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambiya Dalasisi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gine Frangı',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Gine Sylisi',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ekvator Ginesi Ekuelesi',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Yunan Drahmisi',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemala Quetzalı',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portekiz Ginesi Esküdosu',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Gine-Bissau Pezosu',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyana Doları',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hong Kong Doları',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Honduras Lempirası',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Hırvatistan Dinarı',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Hırvatistan Kunası',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haiti Gurdu',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Macar Forinti',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Endonezya Rupisi',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'İrlanda Lirası',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'İsrail Lirası',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'İsrail Şekeli (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Yeni İsrail Şekeli',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Hindistan Rupisi',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irak Dinarı',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'İran Riyali',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'İzlanda Kronu (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'İzlanda Kronu',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'İtalyan Lireti',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaika Doları',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Ürdün Dinarı',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Japon Yeni',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenya Şilini',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kırgızistan Somu',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kamboçya Rieli',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komorlar Frangı',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Kuzey Kore Wonu',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Güney Kore Hwanı (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Güney Kore Wonu (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Güney Kore Wonu',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuveyt Dinarı',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Cayman Adaları Doları',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazakistan Tengesi',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laos Kipi',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Lübnan Lirası',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lanka Rupisi',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberya Doları',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesotho Lotisi',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litvanya Litası',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litvanya Talonu',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Konvertibl Lüksemburg Frangı',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Lüksemburg Frangı',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Finansal Lüksemburg Frangı',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Letonya Latı',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Letonya Rublesi',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libya Dinarı',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Fas Dirhemi',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Fas Frangı',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Monako Frangı',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Moldova Kuponu',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldova Leyi',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskar Ariarisi',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Madagaskar Frangı',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedonya Dinarı',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Makedonya Dinarı (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Mali Frangı',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmar Kyatı',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Moğolistan Tugriki',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao Patakası',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Moritanya Ugiyası (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Moritanya Ugiyası',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Malta Lirası',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Malta Sterlini',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritius Rupisi',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'Maldiv Rupisi',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldiv Rufiyaası',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malavi Kvaçası',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksika Pesosu',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Gümüş Meksika Pezosu (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Meksika Unidad de Inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malezya Ringgiti',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambik Esküdosu',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Eski Mozambik Metikali',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambik Metikali',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibya Doları',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nijerya Nairası',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nikaragua Kordobası (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragua Kordobası',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Hollanda Florini',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norveç Kronu',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepal Rupisi',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Yeni Zelanda Doları',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Umman Riyali',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panama Balboası',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peru İnti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru Solü',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peru Solü (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua Yeni Gine Kinası',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filipinler Pesosu',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistan Rupisi',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polonya Zlotisi',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Polonya Zlotisi (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portekiz Esküdosu',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguay Guaranisi',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katar Riyali',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rodezya Doları',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Eski Romen Leyi',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Romen Leyi',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Sırp Dinarı',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rus Rublesi',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rus Rublesi (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruanda Frangı',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Suudi Arabistan Riyali',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomon Adaları Doları',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seyşeller Rupisi',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Eski Sudan Dinarı',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudan Lirası',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Eski Sudan Lirası',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'İsveç Kronu',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapur Doları',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Saint Helena Lirası',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slovenya Toları',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovak Korunası',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra Leone Leonesi',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somali Şilini',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinam Doları',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinam Guldeni',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Güney Sudan Lirası',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'São Tomé ve Príncipe Dobrası (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Sao Tome ve Principe Dobrası',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovyet Rublesi',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'El Salvador Kolonu',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Suriye Lirası',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svaziland Lilangenisi',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Tayland Bahtı',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tacikistan Rublesi',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tacikistan Somonisi',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Türkmenistan Manatı (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Türkmenistan Manatı',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunus Dinarı',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tonga Paʻangası',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timor Esküdosu',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Eski Türk Lirası',
        ],
        'TRY' => [
            0 => '₺',
            1 => 'Türk Lirası',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad ve Tobago Doları',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Yeni Tayvan Doları',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzanya Şilini',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrayna Grivnası',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrayna Karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Uganda Şilini (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Uganda Şilini',
        ],
        'USD' => [
            0 => '$',
            1 => 'ABD Doları',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'ABD Doları (Ertesi gün)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'ABD Doları (Aynı gün)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Uruguay Peso en Unidades Indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruguay Pezosu (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguay Pesosu',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Özbekistan Somu',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venezuela Bolivarı (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezuela Bolivarı (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venezuela Bolivarı',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vietnam Dongu',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Vietnam Dongu (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu Vatusu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa Talası',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Orta Afrika CFA Frangı',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Doğu Karayip Doları',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Avrupa Para Birimi',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Fransız Altın Frangı',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Fransız UIC-Frangı',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Batı Afrika CFA Frangı',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP Frangı',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET Fonları',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Yemen Dinarı',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Yemen Riyali',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Yugoslav Dinarı (Hard)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Yeni Yugoslav Dinarı',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Konvertibl Yugoslav Dinarı',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'İyileştirilmiş Yugoslav Dinarı (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Güney Afrika Randı (finansal)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Güney Afrika Randı',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambiya Kvaçası (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambiya Kvaçası',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Yeni Zaire Zairesi',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zaire Zairesi',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabve Doları',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabve Doları (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabve Doları (2008)',
        ],
    ],
];
