<?php

return [
    'Names' => [
        'en_BW' => 'Englisch (Botswana)',
        'en_SB' => 'Englisch (Salomon-Inseln)',
        'en_ZW' => 'Englisch (Zimbabwe)',
        'ms_BN' => 'Malaiisch (Brunei)',
        'nd_ZW' => 'Nord-Ndebele (Zimbabwe)',
        'pt_CV' => 'Portugiesisch (Kapverden)',
        'pt_TL' => 'Portugiesisch (Osttimor)',
        'sn_ZW' => 'Shona (Zimbabwe)',
    ],
];
