<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'andorraga peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'united arab emiratesga dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afghanistanga afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afghanistanga afghani',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'albaniaga lek (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albaniaga lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'armeniaga dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'netherlands antilleaga guilder',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angolaga kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'angolaga kwanza (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'angolaga kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'angolaga kwanza xoxotɔ (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'argentinaga austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'argentinaga peso ley (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'argentinaga peso (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'argentinaga peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentinaga peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'ɔstriaga schilling',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Australiaga dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arubaga lorin',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'azerbaidzanga manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'azerbaidzanga manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'bosnia-herzegovinaga dinar (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'bosnia-herzegovinaga convertible mark',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'bosnia kple herzegovinaga dinar yeyètɔ (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadosga dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladeshga taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'beldziumga franc (convertible)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'beldziumga franc',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'beldziumga franc (financial)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'bɔlgariaga hard lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'bɔlgariaga socialist lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'bulgariaga lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'bulgariaga lev (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahrainga dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'burundiga franc',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'bermudaga dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'bruneiga dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviaga boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'boliviaga boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'boliviaga peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'boliviaga mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'braziliaga cruzeiro xoxotɔ (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'brazilia cruzado (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'braziliaga cruzeiro xoxotɔ gbãtɔ (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'braziliaga real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'brazilia cruzado xoxotɔ (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'braziliaga cruzeiro (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'braziliaga cruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'bahamasga dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'bhutanga ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'burmaga kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'botswanaga pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'belarusiaga ruble yeytɔ (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'belarusiaga ruble',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'belarusiaga ruble (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'belizega dollar',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'canadaga dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'kongoga franc',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR euro CHE',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'switzerlandga franc',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR euro CHW',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'tsilega escudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'tsilegakɔnta dzidzenu UF',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'chilega peso',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'tsainatɔwo ƒe gadzraɖoƒe dollar',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Chinesega yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'colombiaga peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'kolombiaga vavãtɔ',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'costa ricaga colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'serbiaga dinar (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'tsɛkoslovakiaga hard koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'cubaga convertible peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'cubaga peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'kape verdega escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'saipriɔtga pound',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'czechga koruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'ɣedzeƒe germaniaga mark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'germaniaga mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'dziboutiga franc',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'denmarkga krone',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dominicaga peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'aldzeriaga dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'ekuadɔga sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'ekuadɔ dzidzenu matrɔmatrɔ',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'estoniaga kroon',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egyptega pound',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'eritreaga nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'spaniaga peseta (A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'spaniaga peseta (Convertible)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'spaniaga peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'ethiopiaga birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'EUR',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'finlandga markka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fidziga dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'falkland islands pound',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'frentsiga franc',
        ],
        'GBP' => [
            0 => '£',
            1 => 'britainga pound',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'dzɔdziaga kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'dzɔdziaga lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ghana siɖi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GH₵',
            1 => 'ghana siɖi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'gilbratarga pound',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambiaga dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'giniga franc',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'giniga syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekuatorial giniga ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'grisiga drachma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'guatemalaga quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'pɔtugaltɔwo ƒe giniga escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'gini-bisau peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'guyanaga dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hong Kongga dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'honduraga lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'kroatiaga dinar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'croatiaga kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haitiga gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'hungariaga forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesiaga rupiah',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'ireland pound',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'israelga pound',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'israelga sheqel (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'israelga yeyetɔ sheqel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indiaga rupee',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'irakga dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iranga rial',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'aiselandga króna (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'icelandga króna',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'italiaga lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamaicaga dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'yɔdanga dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Japanesega yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenyaga shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgistanga som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'kambodiaga riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'komoroga franc',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'dziehe koreaga won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'anyiehe koreaga hwan (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'anyiehe koreaga won (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'South Koreaga won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuwaitga dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'cayman islandsga dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kazakhstanga tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laosga kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'lebanonga pound',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'sri lankaga rupee',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'liberiaga dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesotoga loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'lithuaniaga litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'lithuaniaga talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'lazembɔgga convertible franc',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'lazembɔgga franc',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'lazembɔgga gadzikpɔ franc',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'latviaga lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'latviaga ruble',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'libyaga dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'morokoga dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'morokoga franc',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'monegaskga franc',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'moldovaga cupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldovaga leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'malagasega ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'malagasega franc',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'marcedoniaga denar',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'makedoniaga denar (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'maliga franc',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'myanmaga kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongoliaga tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'makanesega pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'mɔritaniaga ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mɔritaniaga ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'maltaga lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'maltaga pound',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'mɔritiusga rupee',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldiviaga rufiyaa',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'mexicoga peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malaysiaga ringit',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naidzeriaga naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'nikaraguaga córdoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'nicaraguaga córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'hollandga guilder',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'norwayga krone',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepalga rupee',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'new zealanɖga dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'omanga rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'panamaga balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'peruga inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'peruga sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'peruga sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'papua new guineaga kina',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'filipiniga peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistaniga rupee',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'polandga zloty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'polanɖga zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'pɔtugalga escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paraguayga guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'katarga rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'rhodesiaga dollar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'romaniaga leu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'romaniaga leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'serbiaga dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'russiaga ruble',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'rɔtsiaga ruble (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'rwandaga franc',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudi Arabiaga riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'solomon ƒudomekpo dukɔwo ƒe ga dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'sɛtselsga rupee',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'sudanga dinar (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sudanga pound',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'sudanga pound (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'swedenga krone',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singapɔga dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'saint helenaga pound',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'slovaniaga tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'slovakga koruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'sierra leonega leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'somaliaga shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'surinamga dollar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'surinamega guilder',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'são tomé kple príncipega dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'são tomé kple príncipega dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'sovietga rouble',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'salvadɔga colón',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'syriaga pound',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'swaziga lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Thailandga baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'tajikistanga ruble',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tajikistanga somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'turkmenistanga manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'turkmenistanga manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tunisiaga dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'tonagaga pa’anga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'timɔga escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'tɛkiiga lira (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkishga lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'trinidad & tobagoga dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Taiwanga dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniatɔwofɛgadudu',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ukrainega hryvnia',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ukrainega karbovanet',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'ugandaga shilling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ugandaga shilling',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'us ga dollar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'us ga dollar (ŋkeke si gbɔna tɔ)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'us ga dollar (ŋkeke ma ke tɔ)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'uruguayga peso UYI',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'uruguayga peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'uruguayga peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'uzbekistanga som',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'venezuelaga bolívar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venezuelaga bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venezuelaga bolívar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'vietnamga dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'vietnamga dong (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuatuga vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'samaoga tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'ɣetoɖofe afrikaga CFA franc BEAC',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'east caribbeanga dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'europa gaɖuɖu',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'fransemega sika franc',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'frentsi UIC-franc',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'ɣetoɖofe afrikaga CFA franc BCEAO',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP ga franc',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET gadodo XRE',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'yemeniga dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'yemeniga rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'yugoslaviaga hard dinar (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'yugoslaviaga yeyetɔ dinar (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'yugoslaviaga convertible dinar (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'yugoslaviaga dinar (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'anyiehe afrikaga rand (gadzikpɔtɔ)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'South Africaga rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'zambiaga kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'zambiaga kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zairega yeyetɔ zaire',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zairega zaire (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'zimbabwega dollar (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'zimbabwega dollar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'zimbabwega dollar (2008)',
        ],
    ],
];
