<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Temp Greenwich (Abidjan)',
        'Africa/Accra' => 'Temp Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'temp: Etiopia (Addis Abeba)',
        'Africa/Algiers' => 'Temp da l’Europa Centrala (Algier)',
        'Africa/Asmera' => 'temp: Eritrea (Asmara)',
        'Africa/Bamako' => 'Temp Greenwich (Bamako)',
        'Africa/Bangui' => 'temp: Republica Centralafricana (Bangui)',
        'Africa/Banjul' => 'Temp Greenwich (Banjul)',
        'Africa/Bissau' => 'Temp Greenwich (Bissau)',
        'Africa/Blantyre' => 'temp: Malawi (Blantyre)',
        'Africa/Brazzaville' => 'temp: Congo (Brazzaville)',
        'Africa/Bujumbura' => 'temp: Burundi (Bujumbura)',
        'Africa/Cairo' => 'Temp da l’Europa Orientala (Cairo)',
        'Africa/Casablanca' => 'Temp da l’Europa dal Vest (Casablanca)',
        'Africa/Ceuta' => 'Temp da l’Europa Centrala (Ceuta)',
        'Africa/Conakry' => 'Temp Greenwich (Conakry)',
        'Africa/Dakar' => 'Temp Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'temp: Tansania (Daressalam)',
        'Africa/Djibouti' => 'temp: Dschibuti (Dschibuti)',
        'Africa/Douala' => 'temp: Camerun (Douala)',
        'Africa/El_Aaiun' => 'Temp da l’Europa dal Vest (El Aaiún)',
        'Africa/Freetown' => 'Temp Greenwich (Freetown)',
        'Africa/Gaborone' => 'temp: Botswana (Gaborone)',
        'Africa/Harare' => 'temp: Simbabwe (Harare)',
        'Africa/Johannesburg' => 'temp: Africa dal Sid (Johannesburg)',
        'Africa/Juba' => 'temp: Sudan dal Sid (Juba)',
        'Africa/Kampala' => 'temp: Uganda (Kampala)',
        'Africa/Khartoum' => 'temp: Sudan (Khartum)',
        'Africa/Kigali' => 'temp: Ruanda (Kigali)',
        'Africa/Kinshasa' => 'temp: Congo - Kinshasa (Kinshasa)',
        'Africa/Lagos' => 'temp: Nigeria (Lagos)',
        'Africa/Libreville' => 'temp: Gabun (Libreville)',
        'Africa/Lome' => 'Temp Greenwich (Lomé)',
        'Africa/Luanda' => 'temp: Angola (Luanda)',
        'Africa/Lubumbashi' => 'temp: Congo - Kinshasa (Lubumbashi)',
        'Africa/Lusaka' => 'temp: Sambia (Lusaka)',
        'Africa/Malabo' => 'temp: Guinea Equatoriala (Malabo)',
        'Africa/Maputo' => 'temp: Mosambic (Maputo)',
        'Africa/Maseru' => 'temp: Lesotho (Maseru)',
        'Africa/Mbabane' => 'temp: Eswatini (Mbabane)',
        'Africa/Mogadishu' => 'temp: Somalia (Mogadischu)',
        'Africa/Monrovia' => 'Temp Greenwich (Monrovia)',
        'Africa/Nairobi' => 'temp: Kenia (Nairobi)',
        'Africa/Ndjamena' => 'temp: Tschad (Ndjamena)',
        'Africa/Niamey' => 'temp: Niger (Niamey)',
        'Africa/Nouakchott' => 'Temp Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Temp Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'temp: Benin (Porto-Novo)',
        'Africa/Sao_Tome' => 'Temp Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Temp da l’Europa Orientala (Tripoli)',
        'Africa/Tunis' => 'Temp da l’Europa Centrala (Tunis)',
        'Africa/Windhoek' => 'temp: Namibia (Windhoek)',
        'America/Adak' => 'temp: Stadis Unids da l’America (Adak)',
        'America/Anchorage' => 'temp: Stadis Unids da l’America (Alasca)',
        'America/Anguilla' => 'Temp atlantic (The Valley)',
        'America/Antigua' => 'Temp atlantic (Antigua)',
        'America/Araguaina' => 'temp: Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'temp: Argentinia (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'temp: Argentinia (Rio Gallegos)',
        'America/Argentina/Salta' => 'temp: Argentinia (Salta)',
        'America/Argentina/San_Juan' => 'temp: Argentinia (San Juan, Argentinia)',
        'America/Argentina/San_Luis' => 'temp: Argentinia (San Luis)',
        'America/Argentina/Tucuman' => 'temp: Argentinia (Tucumán)',
        'America/Argentina/Ushuaia' => 'temp: Argentinia (Ushuaïa)',
        'America/Aruba' => 'Temp atlantic (Oranjestad)',
        'America/Asuncion' => 'temp: Paraguai (Asunción)',
        'America/Bahia' => 'temp: Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Temp central (Bahia Banderas)',
        'America/Barbados' => 'Temp atlantic (Barbados)',
        'America/Belem' => 'temp: Brasilia (Belém)',
        'America/Belize' => 'Temp central (Belmopan)',
        'America/Blanc-Sablon' => 'Temp atlantic (Blanc-Sablon)',
        'America/Boa_Vista' => 'temp: Brasilia (Boa Vista)',
        'America/Bogota' => 'temp: Columbia (Bogota)',
        'America/Boise' => 'Temp da muntogna (Boise)',
        'America/Buenos_Aires' => 'temp: Argentinia (Buenos Aires)',
        'America/Cambridge_Bay' => 'Temp da muntogna (Cambridge Bay)',
        'America/Campo_Grande' => 'temp: Brasilia (Campo Grande)',
        'America/Cancun' => 'Temp oriental (Cancún)',
        'America/Caracas' => 'temp: Venezuela (Caracas)',
        'America/Catamarca' => 'temp: Argentinia (Catamarca)',
        'America/Cayenne' => 'temp: Guyana Franzosa (Cayenne)',
        'America/Cayman' => 'Temp oriental (Inslas Cayman)',
        'America/Chicago' => 'Temp central (Chicago)',
        'America/Chihuahua' => 'temp: Mexico (Chihuahua)',
        'America/Coral_Harbour' => 'Temp oriental (Atikokan)',
        'America/Cordoba' => 'temp: Argentinia (Córdoba)',
        'America/Costa_Rica' => 'Temp central (Costa Rica)',
        'America/Creston' => 'Temp da muntogna (Creston)',
        'America/Cuiaba' => 'temp: Brasilia (Cuiabá)',
        'America/Curacao' => 'Temp atlantic (Curaçao)',
        'America/Danmarkshavn' => 'Temp Greenwich (Danmarkshavn)',
        'America/Dawson' => 'temp: Canada (Dawson)',
        'America/Dawson_Creek' => 'Temp da muntogna (Dawson Creek)',
        'America/Denver' => 'Temp da muntogna (Denver)',
        'America/Detroit' => 'Temp oriental (Detroit)',
        'America/Dominica' => 'Temp atlantic (Dominica)',
        'America/Edmonton' => 'Temp da muntogna (Edmonton)',
        'America/Eirunepe' => 'temp: Brasilia (Eirunepé)',
        'America/El_Salvador' => 'Temp central (Salvador)',
        'America/Fort_Nelson' => 'Temp da muntogna (Fort Nelson)',
        'America/Fortaleza' => 'temp: Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Temp atlantic (Glace Bay)',
        'America/Godthab' => 'temp: Grönlanda (Godthåb)',
        'America/Goose_Bay' => 'Temp atlantic (Goose Bay)',
        'America/Grand_Turk' => 'Temp oriental (Cockburn Town)',
        'America/Grenada' => 'Temp atlantic (Grenada)',
        'America/Guadeloupe' => 'Temp atlantic (Basse-Terre)',
        'America/Guatemala' => 'Temp central (Guatemala)',
        'America/Guayaquil' => 'temp: Ecuador (Guayaquil)',
        'America/Guyana' => 'temp: Guyana (Guyana)',
        'America/Halifax' => 'Temp atlantic (Halifax)',
        'America/Havana' => 'temp: Cuba (Havana)',
        'America/Hermosillo' => 'temp: Mexico (Hermosillo)',
        'America/Indiana/Knox' => 'Temp central (Knox)',
        'America/Indiana/Marengo' => 'Temp oriental (Marengo)',
        'America/Indiana/Petersburg' => 'Temp oriental (Petersburg)',
        'America/Indiana/Tell_City' => 'Temp central (Tell City)',
        'America/Indiana/Vevay' => 'Temp oriental (Vevay)',
        'America/Indiana/Vincennes' => 'Temp oriental (Vincennes)',
        'America/Indiana/Winamac' => 'Temp oriental (Winamac)',
        'America/Indianapolis' => 'Temp oriental (Indianapolis)',
        'America/Inuvik' => 'Temp da muntogna (Inuvik)',
        'America/Iqaluit' => 'Temp oriental (Iqaluit)',
        'America/Jamaica' => 'Temp oriental (Giamaica)',
        'America/Jujuy' => 'temp: Argentinia (San Salvador de Jujuy)',
        'America/Juneau' => 'temp: Stadis Unids da l’America (Juneau)',
        'America/Kentucky/Monticello' => 'Temp oriental (Monticello)',
        'America/Kralendijk' => 'Temp atlantic (Kralendijk)',
        'America/La_Paz' => 'temp: Bolivia (La Paz)',
        'America/Lima' => 'temp: Peru (Lima)',
        'America/Los_Angeles' => 'Temp pacific (Los Angeles)',
        'America/Louisville' => 'Temp oriental (Louisville)',
        'America/Lower_Princes' => 'Temp atlantic (Lower Prince’s Quarter)',
        'America/Maceio' => 'temp: Brasilia (Maceio)',
        'America/Managua' => 'Temp central (Managua)',
        'America/Manaus' => 'temp: Brasilia (Manaus)',
        'America/Marigot' => 'Temp atlantic (Marigot)',
        'America/Martinique' => 'Temp atlantic (Martinique)',
        'America/Matamoros' => 'Temp central (Matamoros)',
        'America/Mazatlan' => 'temp: Mexico (Mazatlán)',
        'America/Mendoza' => 'temp: Argentinia (Mendoza)',
        'America/Menominee' => 'Temp central (Menominee)',
        'America/Merida' => 'Temp central (Mérida)',
        'America/Metlakatla' => 'temp: Stadis Unids da l’America (Metlakatla)',
        'America/Mexico_City' => 'Temp central (Citad da Mexico)',
        'America/Miquelon' => 'temp: Saint Pierre e Miquelon (Saint Pierre)',
        'America/Moncton' => 'Temp atlantic (Moncton)',
        'America/Monterrey' => 'Temp central (Monterrey)',
        'America/Montevideo' => 'temp: Uruguay (Montevideo)',
        'America/Montreal' => 'temp: Canada (Montreal)',
        'America/Montserrat' => 'Temp atlantic (Brades)',
        'America/Nassau' => 'Temp oriental (Nassau)',
        'America/New_York' => 'Temp oriental (New York)',
        'America/Nipigon' => 'Temp oriental (Nipigon)',
        'America/Nome' => 'temp: Stadis Unids da l’America (Nome)',
        'America/Noronha' => 'temp: Brasilia (Fernando de Noronha)',
        'America/North_Dakota/Beulah' => 'Temp central (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Temp central (North Dakota (Central))',
        'America/North_Dakota/New_Salem' => 'Temp central (North Dakota (New Salem))',
        'America/Ojinaga' => 'Temp da muntogna (Ojinaga)',
        'America/Panama' => 'Temp oriental (Panama)',
        'America/Pangnirtung' => 'Temp oriental (Pangnirtung)',
        'America/Paramaribo' => 'temp: Surinam (Paramaribo)',
        'America/Phoenix' => 'Temp da muntogna (Phoenix)',
        'America/Port-au-Prince' => 'Temp oriental (Port-au-Prince)',
        'America/Port_of_Spain' => 'Temp atlantic (Port of Spain)',
        'America/Porto_Velho' => 'temp: Brasilia (Porto Velho)',
        'America/Puerto_Rico' => 'Temp atlantic (Puerto Rico)',
        'America/Punta_Arenas' => 'temp: Chile (Punta Arenas)',
        'America/Rainy_River' => 'Temp central (Rainy River)',
        'America/Rankin_Inlet' => 'Temp central (Rankin Inlet)',
        'America/Recife' => 'temp: Brasilia (Recife)',
        'America/Regina' => 'Temp central (Regina)',
        'America/Resolute' => 'Temp central (Resolute)',
        'America/Rio_Branco' => 'temp: Brasilia (Rio Branco)',
        'America/Santa_Isabel' => 'temp: Mexico (Santa Isabel)',
        'America/Santarem' => 'temp: Brasilia (Santarem)',
        'America/Santiago' => 'temp: Chile (Santiago)',
        'America/Santo_Domingo' => 'Temp atlantic (Santo Domingo)',
        'America/Sao_Paulo' => 'temp: Brasilia (São Paulo)',
        'America/Scoresbysund' => 'temp: Grönlanda (Ittoqqortoormiit)',
        'America/Sitka' => 'temp: Stadis Unids da l’America (Sitka)',
        'America/St_Barthelemy' => 'Temp atlantic (St. Barthelemy)',
        'America/St_Johns' => 'temp: Canada (Saint John’s)',
        'America/St_Kitts' => 'Temp atlantic (Saint Kitts)',
        'America/St_Lucia' => 'Temp atlantic (Santa Lucia)',
        'America/St_Thomas' => 'Temp atlantic (Saint Thomas)',
        'America/St_Vincent' => 'Temp atlantic (Saint Vincent)',
        'America/Swift_Current' => 'Temp central (Swift Current)',
        'America/Tegucigalpa' => 'Temp central (Tegucigalpa)',
        'America/Thule' => 'Temp atlantic (Thule)',
        'America/Thunder_Bay' => 'Temp oriental (Thunder Bay)',
        'America/Tijuana' => 'Temp pacific (Tijuana)',
        'America/Toronto' => 'Temp oriental (Toronto)',
        'America/Tortola' => 'Temp atlantic (Road Town)',
        'America/Vancouver' => 'Temp pacific (Vancouver)',
        'America/Whitehorse' => 'temp: Canada (Whitehorse)',
        'America/Winnipeg' => 'Temp central (Winnipeg)',
        'America/Yakutat' => 'temp: Stadis Unids da l’America (Yakutat)',
        'America/Yellowknife' => 'Temp da muntogna (Yellowknife)',
        'Antarctica/Casey' => 'temp: Antarctica (Casey)',
        'Antarctica/Davis' => 'temp: Antarctica (Davis)',
        'Antarctica/DumontDUrville' => 'temp: Antarctica (Dumont d’Urville)',
        'Antarctica/Macquarie' => 'temp: Australia (Macquarie)',
        'Antarctica/Mawson' => 'temp: Antarctica (Mawson)',
        'Antarctica/McMurdo' => 'temp: Antarctica (Mac Murdo)',
        'Antarctica/Palmer' => 'temp: Antarctica (Palmer)',
        'Antarctica/Rothera' => 'temp: Antarctica (Rothera)',
        'Antarctica/Syowa' => 'temp: Antarctica (Showa)',
        'Antarctica/Troll' => 'Temp Greenwich (Troll)',
        'Antarctica/Vostok' => 'temp: Antarctica (Vostok)',
        'Arctic/Longyearbyen' => 'Temp da l’Europa Centrala (Longyearbyen)',
        'Asia/Aden' => 'temp: Jemen (Aden)',
        'Asia/Almaty' => 'temp: Kasachstan (Almaty)',
        'Asia/Amman' => 'Temp da l’Europa Orientala (Amman)',
        'Asia/Anadyr' => 'temp: Russia (Anadyr)',
        'Asia/Aqtau' => 'temp: Kasachstan (Aqtau)',
        'Asia/Aqtobe' => 'temp: Kasachstan (Aqtöbe)',
        'Asia/Ashgabat' => 'temp: Turkmenistan (Aşgabat)',
        'Asia/Atyrau' => 'temp: Kasachstan (Atyrau)',
        'Asia/Baghdad' => 'temp: Irac (Bagdad)',
        'Asia/Bahrain' => 'temp: Bahrain (Bahrain)',
        'Asia/Baku' => 'temp: Aserbaidschan (Baku)',
        'Asia/Bangkok' => 'temp: Tailanda (Bangkok)',
        'Asia/Barnaul' => 'temp: Russia (Barnaul)',
        'Asia/Beirut' => 'Temp da l’Europa Orientala (Beirut)',
        'Asia/Bishkek' => 'temp: Kirgisistan (Bischkek)',
        'Asia/Brunei' => 'temp: Brunei (Bandar Seri Begawan)',
        'Asia/Calcutta' => 'temp: India (Kolkata)',
        'Asia/Chita' => 'temp: Russia (Chita)',
        'Asia/Choibalsan' => 'temp: Mongolia (Tschoibalsan)',
        'Asia/Colombo' => 'temp: Sri Lanka (Colombo)',
        'Asia/Damascus' => 'Temp da l’Europa Orientala (Damascus)',
        'Asia/Dhaka' => 'temp: Bangladesch (Dhaka)',
        'Asia/Dili' => 'temp: Timor da l’Ost (Dili)',
        'Asia/Dubai' => 'temp: Emirats Arabs Unids (Dubai)',
        'Asia/Dushanbe' => 'temp: Tadschikistan (Duschanbe)',
        'Asia/Famagusta' => 'Temp da l’Europa Orientala (Famagusta)',
        'Asia/Gaza' => 'Temp da l’Europa Orientala (Gaza)',
        'Asia/Hebron' => 'Temp da l’Europa Orientala (Hebron)',
        'Asia/Hong_Kong' => 'temp: Regiun d’administraziun speziala da Hongkong, China (Hongkong)',
        'Asia/Hovd' => 'temp: Mongolia (Hovd)',
        'Asia/Irkutsk' => 'temp: Russia (Irkutsk)',
        'Asia/Jakarta' => 'temp: Indonesia (Jakarta)',
        'Asia/Jayapura' => 'temp: Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'temp: Israel (Jerusalem)',
        'Asia/Kabul' => 'temp: Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'temp: Russia (Kamtschatka)',
        'Asia/Karachi' => 'temp: Pakistan (Karatschi)',
        'Asia/Katmandu' => 'temp: Nepal (Kathmandu)',
        'Asia/Khandyga' => 'temp: Russia (Khandyga)',
        'Asia/Krasnoyarsk' => 'temp: Russia (Krasnojarsk)',
        'Asia/Kuala_Lumpur' => 'temp: Malaisia (Kuala Lumpur)',
        'Asia/Kuching' => 'temp: Malaisia (Kuching)',
        'Asia/Kuwait' => 'temp: Kuwait (Kuwait)',
        'Asia/Macau' => 'temp: Regiun d’administraziun speziala Macao, China (Macao)',
        'Asia/Magadan' => 'temp: Russia (Magadan)',
        'Asia/Makassar' => 'temp: Indonesia (Macassar)',
        'Asia/Manila' => 'temp: Filippinas (Manila)',
        'Asia/Muscat' => 'temp: Oman (Mascate)',
        'Asia/Nicosia' => 'Temp da l’Europa Orientala (Nicosia)',
        'Asia/Novokuznetsk' => 'temp: Russia (Novokuznetsk)',
        'Asia/Novosibirsk' => 'temp: Russia (Nowosibirsk)',
        'Asia/Omsk' => 'temp: Russia (Omsk)',
        'Asia/Oral' => 'temp: Kasachstan (Oral)',
        'Asia/Phnom_Penh' => 'temp: Cambodscha (Phnom Penh)',
        'Asia/Pontianak' => 'temp: Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'temp: Corea dal Nord (Pyongyang)',
        'Asia/Qatar' => 'temp: Katar (Qatar)',
        'Asia/Qostanay' => 'temp: Kasachstan (Qostanay)',
        'Asia/Qyzylorda' => 'temp: Kasachstan (Qyzylorda)',
        'Asia/Rangoon' => 'temp: Myanmar (Burma) (Yangon)',
        'Asia/Riyadh' => 'temp: Arabia Saudita (Riyad)',
        'Asia/Saigon' => 'temp: Vietnam (Citad da Ho Chi Minh)',
        'Asia/Sakhalin' => 'temp: Russia (Sachalin)',
        'Asia/Samarkand' => 'temp: Usbekistan (Samarcanda)',
        'Asia/Seoul' => 'temp: Corea dal Sid (Seul)',
        'Asia/Shanghai' => 'temp: China (Shanghai)',
        'Asia/Singapore' => 'temp: Singapur (Singapur)',
        'Asia/Srednekolymsk' => 'temp: Russia (Srednekolymsk)',
        'Asia/Taipei' => 'temp: Taiwan (Taipei)',
        'Asia/Tashkent' => 'temp: Usbekistan (Taschkent)',
        'Asia/Tbilisi' => 'temp: Georgia (Tbilisi)',
        'Asia/Tehran' => 'temp: Iran (Teheran)',
        'Asia/Thimphu' => 'temp: Bhutan (Thimphu)',
        'Asia/Tokyo' => 'temp: Giapun (Tokio)',
        'Asia/Tomsk' => 'temp: Russia (Tomsk)',
        'Asia/Ulaanbaatar' => 'temp: Mongolia (Ulaanbaatar)',
        'Asia/Urumqi' => 'temp: China (Ürümqi)',
        'Asia/Ust-Nera' => 'temp: Russia (Ust-Nera)',
        'Asia/Vientiane' => 'temp: Laos (Vientiane)',
        'Asia/Vladivostok' => 'temp: Russia (Vladivostok)',
        'Asia/Yakutsk' => 'temp: Russia (Jakutsk)',
        'Asia/Yekaterinburg' => 'temp: Russia (Jekaterinburg)',
        'Asia/Yerevan' => 'temp: Armenia (Jerevan)',
        'Atlantic/Azores' => 'temp: Portugal (Azoras)',
        'Atlantic/Bermuda' => 'Temp atlantic (Bermudas)',
        'Atlantic/Canary' => 'Temp da l’Europa dal Vest (Inslas Canarias)',
        'Atlantic/Cape_Verde' => 'temp: Cap Verd (Cap Verd)',
        'Atlantic/Faeroe' => 'Temp da l’Europa dal Vest (Inslas Feroe)',
        'Atlantic/Madeira' => 'Temp da l’Europa dal Vest (Madeira)',
        'Atlantic/Reykjavik' => 'Temp Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'temp: Georgia dal Sid e las Inslas Sandwich dal Sid (Georgia dal Sid)',
        'Atlantic/St_Helena' => 'Temp Greenwich (Sontg’elena)',
        'Atlantic/Stanley' => 'temp: Inslas dal Falkland (Port Stanley)',
        'Australia/Adelaide' => 'temp: Australia (Adelaide)',
        'Australia/Brisbane' => 'temp: Australia (Brisbane)',
        'Australia/Broken_Hill' => 'temp: Australia (Broken Hill)',
        'Australia/Currie' => 'temp: Australia (Currie)',
        'Australia/Darwin' => 'temp: Australia (Darwin)',
        'Australia/Eucla' => 'temp: Australia (Eucla)',
        'Australia/Hobart' => 'temp: Australia (Hobart)',
        'Australia/Lindeman' => 'temp: Australia (Lindeman)',
        'Australia/Lord_Howe' => 'temp: Australia (Lord Howe)',
        'Australia/Melbourne' => 'temp: Australia (Melbourne)',
        'Australia/Perth' => 'temp: Australia (Perth)',
        'Australia/Sydney' => 'temp: Australia (Sydney)',
        'CST6CDT' => 'Temp central',
        'EST5EDT' => 'Temp oriental',
        'Etc/GMT' => 'Temp Greenwich',
        'Etc/UTC' => 'Temp universal coordinà',
        'Europe/Amsterdam' => 'Temp da l’Europa Centrala (Amsterdam)',
        'Europe/Andorra' => 'Temp da l’Europa Centrala (Andorra)',
        'Europe/Astrakhan' => 'temp: Russia (Astrakhan)',
        'Europe/Athens' => 'Temp da l’Europa Orientala (Athen)',
        'Europe/Belgrade' => 'Temp da l’Europa Centrala (Belgrade)',
        'Europe/Berlin' => 'Temp da l’Europa Centrala (Berlin)',
        'Europe/Bratislava' => 'Temp da l’Europa Centrala (Bratislava)',
        'Europe/Brussels' => 'Temp da l’Europa Centrala (Bruxelles)',
        'Europe/Bucharest' => 'Temp da l’Europa Orientala (Bucarest)',
        'Europe/Budapest' => 'Temp da l’Europa Centrala (Budapest)',
        'Europe/Busingen' => 'Temp da l’Europa Centrala (Busingen)',
        'Europe/Chisinau' => 'Temp da l’Europa Orientala (Chisinau)',
        'Europe/Copenhagen' => 'Temp da l’Europa Centrala (Copenhagen)',
        'Europe/Dublin' => 'Temp Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Temp da l’Europa Centrala (Gibraltar)',
        'Europe/Guernsey' => 'Temp Greenwich (Saint Peter Port)',
        'Europe/Helsinki' => 'Temp da l’Europa Orientala (Helsinki)',
        'Europe/Isle_of_Man' => 'Temp Greenwich (Douglas)',
        'Europe/Istanbul' => 'temp: Tirchia (Istanbul)',
        'Europe/Jersey' => 'Temp Greenwich (Saint Helier)',
        'Europe/Kaliningrad' => 'Temp da l’Europa Orientala (Kaliningrad)',
        'Europe/Kiev' => 'Temp da l’Europa Orientala (Kyiv)',
        'Europe/Kirov' => 'temp: Russia (Kirov)',
        'Europe/Lisbon' => 'Temp da l’Europa dal Vest (Lissabon)',
        'Europe/Ljubljana' => 'Temp da l’Europa Centrala (Ljubljana)',
        'Europe/London' => 'Temp Greenwich (Londra)',
        'Europe/Luxembourg' => 'Temp da l’Europa Centrala (Luxemburg)',
        'Europe/Madrid' => 'Temp da l’Europa Centrala (Madrid)',
        'Europe/Malta' => 'Temp da l’Europa Centrala (Malta)',
        'Europe/Mariehamn' => 'Temp da l’Europa Orientala (Mariehamn)',
        'Europe/Minsk' => 'temp: Bielorussia (Minsk)',
        'Europe/Monaco' => 'Temp da l’Europa Centrala (Monaco)',
        'Europe/Moscow' => 'temp: Russia (Moscau)',
        'Europe/Oslo' => 'Temp da l’Europa Centrala (Oslo)',
        'Europe/Paris' => 'Temp da l’Europa Centrala (Paris)',
        'Europe/Podgorica' => 'Temp da l’Europa Centrala (Podgorica)',
        'Europe/Prague' => 'Temp da l’Europa Centrala (Prague)',
        'Europe/Riga' => 'Temp da l’Europa Orientala (Riga)',
        'Europe/Rome' => 'Temp da l’Europa Centrala (Roma)',
        'Europe/Samara' => 'temp: Russia (Samara)',
        'Europe/San_Marino' => 'Temp da l’Europa Centrala (San Marino)',
        'Europe/Sarajevo' => 'Temp da l’Europa Centrala (Sarajevo)',
        'Europe/Saratov' => 'temp: Russia (Saratov)',
        'Europe/Simferopol' => 'temp: Ucraina (Simferopol)',
        'Europe/Skopje' => 'Temp da l’Europa Centrala (Skopje)',
        'Europe/Sofia' => 'Temp da l’Europa Orientala (Sofia)',
        'Europe/Stockholm' => 'Temp da l’Europa Centrala (Stockholm)',
        'Europe/Tallinn' => 'Temp da l’Europa Orientala (Tallinn)',
        'Europe/Tirane' => 'Temp da l’Europa Centrala (Tirana)',
        'Europe/Ulyanovsk' => 'temp: Russia (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Temp da l’Europa Orientala (Uschhorod)',
        'Europe/Vaduz' => 'Temp da l’Europa Centrala (Vaduz)',
        'Europe/Vatican' => 'Temp da l’Europa Centrala (Vatican)',
        'Europe/Vienna' => 'Temp da l’Europa Centrala (Vienna)',
        'Europe/Vilnius' => 'Temp da l’Europa Orientala (Vilnius)',
        'Europe/Volgograd' => 'temp: Russia (Volgograd)',
        'Europe/Warsaw' => 'Temp da l’Europa Centrala (Varsovia)',
        'Europe/Zagreb' => 'Temp da l’Europa Centrala (Zagreb)',
        'Europe/Zaporozhye' => 'Temp da l’Europa Orientala (Saporischja)',
        'Europe/Zurich' => 'Temp da l’Europa Centrala (Turitg)',
        'Indian/Antananarivo' => 'temp: Madagascar (Antananarivo)',
        'Indian/Chagos' => 'temp: Territori Britannic en l’Ocean Indic (Chagos)',
        'Indian/Christmas' => 'temp: Insla da Nadal (Flying Fish Cove)',
        'Indian/Cocos' => 'temp: Inslas Cocos (West Island)',
        'Indian/Comoro' => 'temp: Comoras (Comoras)',
        'Indian/Kerguelen' => 'temp: Territoris Franzos Meridiunals (Kerguelen)',
        'Indian/Mahe' => 'temp: Seychellas (Mahe)',
        'Indian/Maldives' => 'temp: Maldivas (Maldivas)',
        'Indian/Mauritius' => 'temp: Mauritius (Mauritius)',
        'Indian/Mayotte' => 'temp: Mayotte (Mayotte)',
        'Indian/Reunion' => 'temp: Réunion (Réunion)',
        'MST7MDT' => 'Temp da muntogna',
        'PST8PDT' => 'Temp pacific',
        'Pacific/Apia' => 'temp: Samoa (Apia)',
        'Pacific/Auckland' => 'temp: Nova Zelanda (Auckland)',
        'Pacific/Bougainville' => 'temp: Papua Nova Guinea (Bougainville)',
        'Pacific/Chatham' => 'temp: Nova Zelanda (Chatham)',
        'Pacific/Easter' => 'temp: Chile (Insla da Pasca)',
        'Pacific/Efate' => 'temp: Vanuatu (Efate)',
        'Pacific/Enderbury' => 'temp: Kiribati (Enderbury)',
        'Pacific/Fakaofo' => 'temp: Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'temp: Fidschi (Fidschi)',
        'Pacific/Funafuti' => 'temp: Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'temp: Ecuador (Galápagos)',
        'Pacific/Gambier' => 'temp: Polinesia Franzosa (Rikitea)',
        'Pacific/Guadalcanal' => 'temp: Inslas Salomonas (Honiara)',
        'Pacific/Guam' => 'temp: Guam (Hagåtña)',
        'Pacific/Honolulu' => 'temp: Stadis Unids da l’America (Honolulu)',
        'Pacific/Johnston' => 'temp: Inslas Pitschnas Perifericas dals Stadis Unids da l’America (Johnston)',
        'Pacific/Kiritimati' => 'temp: Kiribati (Kiritimati)',
        'Pacific/Kosrae' => 'temp: Micronesia (Tofol)',
        'Pacific/Kwajalein' => 'temp: Inslas da Marshall (Kwajalein)',
        'Pacific/Majuro' => 'temp: Inslas da Marshall (Majuro)',
        'Pacific/Marquesas' => 'temp: Polinesia Franzosa (Marquesas)',
        'Pacific/Midway' => 'temp: Inslas Pitschnas Perifericas dals Stadis Unids da l’America (Midway)',
        'Pacific/Nauru' => 'temp: Nauru (Yaren)',
        'Pacific/Niue' => 'temp: Niue (Alofi)',
        'Pacific/Norfolk' => 'temp: Insla Norfolk (Kingston)',
        'Pacific/Noumea' => 'temp: Nova Caledonia (Nouméa)',
        'Pacific/Pago_Pago' => 'temp: Samoa Americana (Pago Pago)',
        'Pacific/Palau' => 'temp: Palau (Melekok)',
        'Pacific/Pitcairn' => 'temp: Pitcairn (Pitcairn)',
        'Pacific/Ponape' => 'temp: Micronesia (Palikir)',
        'Pacific/Port_Moresby' => 'temp: Papua Nova Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'temp: Inslas Cook (Rarotonga)',
        'Pacific/Saipan' => 'temp: Inslas Mariannas dal Nord (Saipan)',
        'Pacific/Tahiti' => 'temp: Polinesia Franzosa (Tahiti)',
        'Pacific/Tarawa' => 'temp: Kiribati (South Tarawa)',
        'Pacific/Tongatapu' => 'temp: Tonga (Nukuʻalofa)',
        'Pacific/Truk' => 'temp: Micronesia (Weno)',
        'Pacific/Wake' => 'temp: Inslas Pitschnas Perifericas dals Stadis Unids da l’America (Wake)',
        'Pacific/Wallis' => 'temp: Wallis & Futuna (Matāʻutu)',
    ],
    'Meta' => [
    ],
];
