<?php

return [
    'Names' => [
        'ARS' => [
            0 => 'ARS',
            1 => 'peso argentin',
        ],
        'AUD' => [
            0 => '$ AU',
            1 => 'dollar australien',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat azerbaïdjanais',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dollar bermudien',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'dollar brunéien',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dollar bélizéen',
        ],
        'CAD' => [
            0 => '$',
            1 => 'dollar canadien',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso chilien',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'yuan renminbi chinois',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso colombien',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo cap-verdien',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dollar fidjien',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'livre des îles Malouines',
        ],
        'GBP' => [
            0 => '£',
            1 => 'livre sterling',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'livre de Gibraltar',
        ],
        'HKD' => [
            0 => '$ HK',
            1 => 'dollar de Hong Kong',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'nouveau shekel israélien',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'roupie indienne',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'rial iranien',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'yen japonais',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'won sud-coréen',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip laotien',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'livre libanaise',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'peso mexicain',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dollar namibien',
        ],
        'NZD' => [
            0 => '$ NZ',
            1 => 'dollar néo-zélandais',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'rial omanais',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'nouveau sol péruvien',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina papou-néo-guinéen',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'riyal du Qatar',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'rial saoudien',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dollar des îles Salomon',
        ],
        'SGD' => [
            0 => '$ SG',
            1 => 'dollar de Singapour',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dollar du Suriname',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'pa’anga',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dollar de Trinité-et-Tobago',
        ],
        'USD' => [
            0 => '$ US',
            1 => 'dollar des États-Unis',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso uruguayen',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'dông vietnamien',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala',
        ],
        'XAF' => [
            0 => 'XAF',
            1 => 'franc CFA (BEAC)',
        ],
        'XOF' => [
            0 => 'XOF',
            1 => 'franc CFA (BCEAO)',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'franc CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'rial yéménite',
        ],
    ],
];
