<?php

return [
    'Names' => [
        'af' => 'אַפֿריקאַנס',
        'af_NA' => 'אַפֿריקאַנס (נאַמיביע)',
        'af_ZA' => 'אַפֿריקאַנס (דרום־אַפֿריקע)',
        'am' => 'אַמהאַריש',
        'am_ET' => 'אַמהאַריש (עטיאפּיע)',
        'ar' => 'אַראַביש',
        'ar_001' => 'אַראַביש (וועלט)',
        'ar_DJ' => 'אַראַביש (דזשיבוטי)',
        'ar_EG' => 'אַראַביש (עגיפּטן)',
        'ar_ER' => 'אַראַביש (עריטרעע)',
        'ar_IL' => 'אַראַביש (ישראל)',
        'ar_KM' => 'אַראַביש (קאמאראס)',
        'ar_LB' => 'אַראַביש (לבנון)',
        'ar_LY' => 'אַראַביש (ליביע)',
        'ar_MA' => 'אַראַביש (מאַראקא)',
        'ar_MR' => 'אַראַביש (מאַריטאַניע)',
        'ar_QA' => 'אַראַביש (קאַטאַר)',
        'ar_SD' => 'אַראַביש (סודאַן)',
        'ar_SO' => 'אַראַביש (סאמאַליע)',
        'ar_SS' => 'אַראַביש (דרום־סודאַן)',
        'ar_SY' => 'אַראַביש (סיריע)',
        'ar_TD' => 'אַראַביש (טשאַד)',
        'ar_TN' => 'אַראַביש (טוניסיע)',
        'ar_YE' => 'אַראַביש (תימן)',
        'as' => 'אַסאַמיש',
        'as_IN' => 'אַסאַמיש (אינדיע)',
        'az' => 'אַזערביידזשאַניש',
        'az_Cyrl' => 'אַזערביידזשאַניש (ציריליש)',
        'az_Latn' => 'אַזערביידזשאַניש (גַלחיש)',
        'be' => 'בעלאַרוסיש',
        'be_BY' => 'בעלאַרוסיש (בעלאַרוס)',
        'bg' => 'בולגאַריש',
        'bg_BG' => 'בולגאַריש (בולגאַריע)',
        'bn' => 'בענגאַליש',
        'bn_BD' => 'בענגאַליש (באַנגלאַדעש)',
        'bn_IN' => 'בענגאַליש (אינדיע)',
        'bo' => 'טיבעטיש',
        'bo_CN' => 'טיבעטיש (כינע)',
        'bo_IN' => 'טיבעטיש (אינדיע)',
        'br' => 'ברעטאניש',
        'br_FR' => 'ברעטאניש (פֿראַנקרייך)',
        'bs' => 'באסניש',
        'bs_BA' => 'באסניש (באסניע הערצעגאווינע)',
        'bs_Cyrl' => 'באסניש (ציריליש)',
        'bs_Cyrl_BA' => 'באסניש (ציריליש, באסניע הערצעגאווינע)',
        'bs_Latn' => 'באסניש (גַלחיש)',
        'bs_Latn_BA' => 'באסניש (גַלחיש, באסניע הערצעגאווינע)',
        'ca' => 'קאַטאַלאניש',
        'ca_AD' => 'קאַטאַלאניש (אַנדארע)',
        'ca_ES' => 'קאַטאַלאניש (שפּאַניע)',
        'ca_FR' => 'קאַטאַלאניש (פֿראַנקרייך)',
        'ca_IT' => 'קאַטאַלאניש (איטאַליע)',
        'cs' => 'טשעכיש',
        'cs_CZ' => 'טשעכיש (טשעכיי)',
        'cy' => 'וועלשיש',
        'cy_GB' => 'וועלשיש (פֿאַראייניגטע קעניגרייך)',
        'da' => 'דעניש',
        'da_DK' => 'דעניש (דענמאַרק)',
        'da_GL' => 'דעניש (גרינלאַנד)',
        'de' => 'דײַטש',
        'de_AT' => 'דײַטש (עסטרייך)',
        'de_BE' => 'דײַטש (בעלגיע)',
        'de_CH' => 'דײַטש (שווייץ)',
        'de_DE' => 'דײַטש (דייטשלאַנד)',
        'de_IT' => 'דײַטש (איטאַליע)',
        'de_LI' => 'דײַטש (ליכטנשטיין)',
        'de_LU' => 'דײַטש (לוקסעמבורג)',
        'el' => 'גריכיש',
        'el_GR' => 'גריכיש (גריכנלאַנד)',
        'en' => 'ענגליש',
        'en_001' => 'ענגליש (וועלט)',
        'en_150' => 'ענגליש (אייראפּע)',
        'en_AG' => 'ענגליש (אַנטיגוע און באַרבודע)',
        'en_AT' => 'ענגליש (עסטרייך)',
        'en_AU' => 'ענגליש (אויסטראַליע)',
        'en_BB' => 'ענגליש (באַרבאַדאס)',
        'en_BE' => 'ענגליש (בעלגיע)',
        'en_BI' => 'ענגליש (בורונדי)',
        'en_BM' => 'ענגליש (בערמודע)',
        'en_BS' => 'ענגליש (באַהאַמאַס)',
        'en_BW' => 'ענגליש (באצוואַנע)',
        'en_BZ' => 'ענגליש (בעליז)',
        'en_CA' => 'ענגליש (קאַנאַדע)',
        'en_CH' => 'ענגליש (שווייץ)',
        'en_CK' => 'ענגליש (קוק אינזלען)',
        'en_CM' => 'ענגליש (קאַמערון)',
        'en_DE' => 'ענגליש (דייטשלאַנד)',
        'en_DK' => 'ענגליש (דענמאַרק)',
        'en_DM' => 'ענגליש (דאמיניקע)',
        'en_ER' => 'ענגליש (עריטרעע)',
        'en_FI' => 'ענגליש (פֿינלאַנד)',
        'en_FJ' => 'ענגליש (פֿידזשי)',
        'en_FK' => 'ענגליש (פֿאַלקלאַנד אינזלען)',
        'en_FM' => 'ענגליש (מיקראנעזיע)',
        'en_GB' => 'ענגליש (פֿאַראייניגטע קעניגרייך)',
        'en_GD' => 'ענגליש (גרענאַדאַ)',
        'en_GG' => 'ענגליש (גערנזי)',
        'en_GH' => 'ענגליש (גהאַנע)',
        'en_GI' => 'ענגליש (גיבראַלטאַר)',
        'en_GM' => 'ענגליש (גאַמביע)',
        'en_GU' => 'ענגליש (גוואַם)',
        'en_GY' => 'ענגליש (גויאַנע)',
        'en_IE' => 'ענגליש (אירלאַנד)',
        'en_IL' => 'ענגליש (ישראל)',
        'en_IN' => 'ענגליש (אינדיע)',
        'en_JE' => 'ענגליש (דזשערזי)',
        'en_JM' => 'ענגליש (דזשאַמייקע)',
        'en_KE' => 'ענגליש (קעניע)',
        'en_KI' => 'ענגליש (קיריבאַטי)',
        'en_KY' => 'ענגליש (קיימאַן אינזלען)',
        'en_LR' => 'ענגליש (ליבעריע)',
        'en_LS' => 'ענגליש (לעסאטא)',
        'en_MG' => 'ענגליש (מאַדאַגאַסקאַר)',
        'en_MH' => 'ענגליש (מאַרשאַל אינזלען)',
        'en_MS' => 'ענגליש (מאנטסעראַט)',
        'en_MT' => 'ענגליש (מאַלטאַ)',
        'en_MU' => 'ענגליש (מאריציוס)',
        'en_MV' => 'ענגליש (מאַלדיוון)',
        'en_MW' => 'ענגליש (מאַלאַווי)',
        'en_MY' => 'ענגליש (מאַלייזיע)',
        'en_NA' => 'ענגליש (נאַמיביע)',
        'en_NF' => 'ענגליש (נארפֿאלק אינזל)',
        'en_NG' => 'ענגליש (ניגעריע)',
        'en_NL' => 'ענגליש (האלאַנד)',
        'en_NZ' => 'ענגליש (ניו זילאַנד)',
        'en_PG' => 'ענגליש (פּאַפּואַ נײַ גינע)',
        'en_PH' => 'ענגליש (פֿיליפּינען)',
        'en_PK' => 'ענגליש (פּאַקיסטאַן)',
        'en_PN' => 'ענגליש (פּיטקערן אינזלען)',
        'en_PR' => 'ענגליש (פּארטא־ריקא)',
        'en_RW' => 'ענגליש (רוואַנדע)',
        'en_SB' => 'ענגליש (סאלאמאן אינזלען)',
        'en_SC' => 'ענגליש (סיישעל)',
        'en_SD' => 'ענגליש (סודאַן)',
        'en_SE' => 'ענגליש (שוועדן)',
        'en_SG' => 'ענגליש (סינגאַפּור)',
        'en_SH' => 'ענגליש (סט העלענע)',
        'en_SI' => 'ענגליש (סלאוועניע)',
        'en_SL' => 'ענגליש (סיערע לעאנע)',
        'en_SS' => 'ענגליש (דרום־סודאַן)',
        'en_SZ' => 'ענגליש (סוואַזילאַנד)',
        'en_TO' => 'ענגליש (טאנגאַ)',
        'en_TT' => 'ענגליש (טרינידאַד און טאבאַגא)',
        'en_TV' => 'ענגליש (טואוואַלו)',
        'en_TZ' => 'ענגליש (טאַנזאַניע)',
        'en_UG' => 'ענגליש (אוגאַנדע)',
        'en_US' => 'ענגליש (פֿאַראייניגטע שטאַטן)',
        'en_VU' => 'ענגליש (וואַנואַטו)',
        'en_WS' => 'ענגליש (סאַמאאַ)',
        'en_ZA' => 'ענגליש (דרום־אַפֿריקע)',
        'en_ZM' => 'ענגליש (זאַמביע)',
        'en_ZW' => 'ענגליש (זימבאַבווע)',
        'eo' => 'עספּעראַנטא',
        'eo_001' => 'עספּעראַנטא (וועלט)',
        'es' => 'שפּאַניש',
        'es_419' => 'שפּאַניש (לאַטיין־אַמעריקע)',
        'es_AR' => 'שפּאַניש (אַרגענטינע)',
        'es_BO' => 'שפּאַניש (באליוויע)',
        'es_BR' => 'שפּאַניש (בראַזיל)',
        'es_BZ' => 'שפּאַניש (בעליז)',
        'es_CL' => 'שפּאַניש (טשילע)',
        'es_CO' => 'שפּאַניש (קאלאמביע)',
        'es_CR' => 'שפּאַניש (קאסטאַ ריקאַ)',
        'es_CU' => 'שפּאַניש (קובאַ)',
        'es_DO' => 'שפּאַניש (דאמיניקאַנישע רעפּובליק)',
        'es_EC' => 'שפּאַניש (עקוואַדאר)',
        'es_ES' => 'שפּאַניש (שפּאַניע)',
        'es_GQ' => 'שפּאַניש (עקוואַטארישע גינע)',
        'es_GT' => 'שפּאַניש (גוואַטעמאַלע)',
        'es_HN' => 'שפּאַניש (האנדוראַס)',
        'es_MX' => 'שפּאַניש (מעקסיקע)',
        'es_NI' => 'שפּאַניש (ניקאַראַגוע)',
        'es_PA' => 'שפּאַניש (פּאַנאַמאַ)',
        'es_PE' => 'שפּאַניש (פּערו)',
        'es_PH' => 'שפּאַניש (פֿיליפּינען)',
        'es_PR' => 'שפּאַניש (פּארטא־ריקא)',
        'es_PY' => 'שפּאַניש (פּאַראַגווײַ)',
        'es_SV' => 'שפּאַניש (על סאַלוואַדאר)',
        'es_US' => 'שפּאַניש (פֿאַראייניגטע שטאַטן)',
        'es_UY' => 'שפּאַניש (אורוגוויי)',
        'es_VE' => 'שפּאַניש (ווענעזועלע)',
        'et' => 'עסטיש',
        'et_EE' => 'עסטיש (עסטלאַנד)',
        'eu' => 'באַסקיש',
        'eu_ES' => 'באַסקיש (שפּאַניע)',
        'fa' => 'פּערסיש',
        'fa_AF' => 'פּערסיש (אַפֿגהאַניסטאַן)',
        'fa_IR' => 'פּערסיש (איראַן)',
        'fi' => 'פֿיניש',
        'fi_FI' => 'פֿיניש (פֿינלאַנד)',
        'fo' => 'פֿאַראיש',
        'fo_DK' => 'פֿאַראיש (דענמאַרק)',
        'fo_FO' => 'פֿאַראיש (פֿאַרא אינזלען)',
        'fr' => 'פֿראַנצויזיש',
        'fr_BE' => 'פֿראַנצויזיש (בעלגיע)',
        'fr_BF' => 'פֿראַנצויזיש (בורקינע פֿאַסא)',
        'fr_BI' => 'פֿראַנצויזיש (בורונדי)',
        'fr_BJ' => 'פֿראַנצויזיש (בענין)',
        'fr_CA' => 'פֿראַנצויזיש (קאַנאַדע)',
        'fr_CD' => 'פֿראַנצויזיש (קאנגא־קינשאַזע)',
        'fr_CF' => 'פֿראַנצויזיש (צענטראַל־אַפֿריקאַנישע רעפּובליק)',
        'fr_CH' => 'פֿראַנצויזיש (שווייץ)',
        'fr_CI' => 'פֿראַנצויזיש (העלפֿאַ נדביין בארטן)',
        'fr_CM' => 'פֿראַנצויזיש (קאַמערון)',
        'fr_DJ' => 'פֿראַנצויזיש (דזשיבוטי)',
        'fr_FR' => 'פֿראַנצויזיש (פֿראַנקרייך)',
        'fr_GA' => 'פֿראַנצויזיש (גאַבאן)',
        'fr_GF' => 'פֿראַנצויזיש (פֿראַנצויזישע גויאַנע)',
        'fr_GN' => 'פֿראַנצויזיש (גינע)',
        'fr_GP' => 'פֿראַנצויזיש (גוואַדעלופ)',
        'fr_GQ' => 'פֿראַנצויזיש (עקוואַטארישע גינע)',
        'fr_HT' => 'פֿראַנצויזיש (האַיטי)',
        'fr_KM' => 'פֿראַנצויזיש (קאמאראס)',
        'fr_LU' => 'פֿראַנצויזיש (לוקסעמבורג)',
        'fr_MA' => 'פֿראַנצויזיש (מאַראקא)',
        'fr_MC' => 'פֿראַנצויזיש (מאנאַקא)',
        'fr_MG' => 'פֿראַנצויזיש (מאַדאַגאַסקאַר)',
        'fr_ML' => 'פֿראַנצויזיש (מאַלי)',
        'fr_MQ' => 'פֿראַנצויזיש (מאַרטיניק)',
        'fr_MR' => 'פֿראַנצויזיש (מאַריטאַניע)',
        'fr_MU' => 'פֿראַנצויזיש (מאריציוס)',
        'fr_NC' => 'פֿראַנצויזיש (נײַ קאַלעדאניע)',
        'fr_NE' => 'פֿראַנצויזיש (ניזשער)',
        'fr_PF' => 'פֿראַנצויזיש (פֿראַנצויזישע פּאלינעזיע)',
        'fr_RE' => 'פֿראַנצויזיש (רעאוניאן)',
        'fr_RW' => 'פֿראַנצויזיש (רוואַנדע)',
        'fr_SC' => 'פֿראַנצויזיש (סיישעל)',
        'fr_SN' => 'פֿראַנצויזיש (סענעגאַל)',
        'fr_SY' => 'פֿראַנצויזיש (סיריע)',
        'fr_TD' => 'פֿראַנצויזיש (טשאַד)',
        'fr_TG' => 'פֿראַנצויזיש (טאגא)',
        'fr_TN' => 'פֿראַנצויזיש (טוניסיע)',
        'fr_VU' => 'פֿראַנצויזיש (וואַנואַטו)',
        'fr_YT' => 'פֿראַנצויזיש (מאַיאט)',
        'fy' => 'מערב־פֿריזיש',
        'fy_NL' => 'מערב־פֿריזיש (האלאַנד)',
        'ga' => 'איריש',
        'ga_GB' => 'איריש (פֿאַראייניגטע קעניגרייך)',
        'ga_IE' => 'איריש (אירלאַנד)',
        'gd' => 'סקאטיש געליש',
        'gd_GB' => 'סקאטיש געליש (פֿאַראייניגטע קעניגרייך)',
        'gl' => 'גאַלישיש',
        'gl_ES' => 'גאַלישיש (שפּאַניע)',
        'gv' => 'מאַנקס',
        'ha' => 'האַוסאַ',
        'ha_GH' => 'האַוסאַ (גהאַנע)',
        'ha_NE' => 'האַוסאַ (ניזשער)',
        'ha_NG' => 'האַוסאַ (ניגעריע)',
        'he' => 'העברעאיש',
        'he_IL' => 'העברעאיש (ישראל)',
        'hi' => 'הינדי',
        'hi_IN' => 'הינדי (אינדיע)',
        'hi_Latn' => 'הינדי (גַלחיש)',
        'hi_Latn_IN' => 'הינדי (גַלחיש, אינדיע)',
        'hr' => 'קראאַטיש',
        'hr_BA' => 'קראאַטיש (באסניע הערצעגאווינע)',
        'hr_HR' => 'קראאַטיש (קראאַטיע)',
        'hu' => 'אונגעריש',
        'hu_HU' => 'אונגעריש (אונגערן)',
        'hy' => 'אַרמעניש',
        'hy_AM' => 'אַרמעניש (אַרמעניע)',
        'id' => 'אינדאנעזיש',
        'id_ID' => 'אינדאנעזיש (אינדאנעזיע)',
        'is' => 'איסלאַנדיש',
        'is_IS' => 'איסלאַנדיש (איסלאַנד)',
        'it' => 'איטאַליעניש',
        'it_CH' => 'איטאַליעניש (שווייץ)',
        'it_IT' => 'איטאַליעניש (איטאַליע)',
        'it_SM' => 'איטאַליעניש (סאַן מאַרינא)',
        'it_VA' => 'איטאַליעניש (וואַטיקאַן שטאָט)',
        'ja' => 'יאַפּאַניש',
        'ja_JP' => 'יאַפּאַניש (יאַפּאַן)',
        'jv' => 'יאַוואַנעזיש',
        'jv_ID' => 'יאַוואַנעזיש (אינדאנעזיע)',
        'ka' => 'גרוזיניש',
        'ka_GE' => 'גרוזיניש (גרוזיע)',
        'kk' => 'קאַזאַכיש',
        'km' => 'כמער',
        'km_KH' => 'כמער (קאַמבאדיע)',
        'kn' => 'קאַנאַדאַ',
        'kn_IN' => 'קאַנאַדאַ (אינדיע)',
        'ko' => 'קארעאיש',
        'ku' => 'קורדיש',
        'ku_TR' => 'קורדיש (טערקיי)',
        'kw' => 'קארניש',
        'kw_GB' => 'קארניש (פֿאַראייניגטע קעניגרייך)',
        'ky' => 'קירגיזיש',
        'lb' => 'לוקסעמבורגיש',
        'lb_LU' => 'לוקסעמבורגיש (לוקסעמבורג)',
        'lo' => 'לאַא',
        'lo_LA' => 'לאַא (לאַאס)',
        'lt' => 'ליטוויש',
        'lt_LT' => 'ליטוויש (ליטע)',
        'lv' => 'לעטיש',
        'lv_LV' => 'לעטיש (לעטלאַנד)',
        'mi' => 'מאַאריש',
        'mi_NZ' => 'מאַאריש (ניו זילאַנד)',
        'mk' => 'מאַקעדאניש',
        'ml' => 'מאַלאַיאַלאַם',
        'ml_IN' => 'מאַלאַיאַלאַם (אינדיע)',
        'mn' => 'מאנגאליש',
        'mn_MN' => 'מאנגאליש (מאנגאליי)',
        'mt' => 'מאַלטעזיש',
        'mt_MT' => 'מאַלטעזיש (מאַלטאַ)',
        'my' => 'בירמאַניש',
        'my_MM' => 'בירמאַניש (מיאַנמאַר)',
        'ne' => 'נעפּאַליש',
        'ne_IN' => 'נעפּאַליש (אינדיע)',
        'ne_NP' => 'נעפּאַליש (נעפּאַל)',
        'nl' => 'האלענדיש',
        'nl_AW' => 'האלענדיש (אַרובאַ)',
        'nl_BE' => 'האלענדיש (בעלגיע)',
        'nl_CW' => 'האלענדיש (קוראַסאַא)',
        'nl_NL' => 'האלענדיש (האלאַנד)',
        'nl_SR' => 'האלענדיש (סורינאַם)',
        'nn' => 'נײַ־נארוועגיש',
        'nn_NO' => 'נײַ־נארוועגיש (נארוועגיע)',
        'no' => 'נארוועגיש',
        'no_NO' => 'נארוועגיש (נארוועגיע)',
        'os' => 'אסעטיש',
        'os_GE' => 'אסעטיש (גרוזיע)',
        'os_RU' => 'אסעטיש (רוסלאַנד)',
        'pl' => 'פּויליש',
        'pl_PL' => 'פּויליש (פּוילן)',
        'ps' => 'פּאַשטאָ',
        'ps_AF' => 'פּאַשטאָ (אַפֿגהאַניסטאַן)',
        'ps_PK' => 'פּאַשטאָ (פּאַקיסטאַן)',
        'pt' => 'פּארטוגעזיש',
        'pt_AO' => 'פּארטוגעזיש (אַנגאלע)',
        'pt_BR' => 'פּארטוגעזיש (בראַזיל)',
        'pt_CH' => 'פּארטוגעזיש (שווייץ)',
        'pt_CV' => 'פּארטוגעזיש (קאַפּווערדישע אינזלען)',
        'pt_GQ' => 'פּארטוגעזיש (עקוואַטארישע גינע)',
        'pt_GW' => 'פּארטוגעזיש (גינע־ביסאַו)',
        'pt_LU' => 'פּארטוגעזיש (לוקסעמבורג)',
        'pt_MZ' => 'פּארטוגעזיש (מאזאַמביק)',
        'pt_PT' => 'פּארטוגעזיש (פּארטוגאַל)',
        'pt_ST' => 'פּארטוגעזיש (סאַא טאמע און פּרינסיפּע)',
        'pt_TL' => 'פּארטוגעזיש (מזרח טימאר)',
        'ro' => 'רומעניש',
        'ro_MD' => 'רומעניש (מאלדאווע)',
        'ro_RO' => 'רומעניש (רומעניע)',
        'ru' => 'רוסיש',
        'ru_BY' => 'רוסיש (בעלאַרוס)',
        'ru_MD' => 'רוסיש (מאלדאווע)',
        'ru_RU' => 'רוסיש (רוסלאַנד)',
        'ru_UA' => 'רוסיש (אוקראַינע)',
        'sa' => 'סאַנסקריט',
        'sa_IN' => 'סאַנסקריט (אינדיע)',
        'sc' => 'סאַרדיש',
        'sc_IT' => 'סאַרדיש (איטאַליע)',
        'sd' => 'סינדהי',
        'sd_Arab' => 'סינדהי (אַראַביש)',
        'sd_Arab_PK' => 'סינדהי (אַראַביש, פּאַקיסטאַן)',
        'sd_Deva' => 'סינדהי (דעוואַנאַגאַרי)',
        'sd_Deva_IN' => 'סינדהי (דעוואַנאַגאַרי, אינדיע)',
        'sd_IN' => 'סינדהי (אינדיע)',
        'sd_PK' => 'סינדהי (פּאַקיסטאַן)',
        'se' => 'נארדסאַמיש',
        'se_FI' => 'נארדסאַמיש (פֿינלאַנד)',
        'se_NO' => 'נארדסאַמיש (נארוועגיע)',
        'se_SE' => 'נארדסאַמיש (שוועדן)',
        'sh' => 'סערבא־קראאַטיש',
        'sh_BA' => 'סערבא־קראאַטיש (באסניע הערצעגאווינע)',
        'si' => 'סינהאַליש',
        'si_LK' => 'סינהאַליש (סרי־לאַנקאַ)',
        'sk' => 'סלאוואַקיש',
        'sk_SK' => 'סלאוואַקיש (סלאוואַקיי)',
        'sl' => 'סלאוועניש',
        'sl_SI' => 'סלאוועניש (סלאוועניע)',
        'sn' => 'שאנאַ',
        'sn_ZW' => 'שאנאַ (זימבאַבווע)',
        'so' => 'סאמאַליש',
        'so_DJ' => 'סאמאַליש (דזשיבוטי)',
        'so_ET' => 'סאמאַליש (עטיאפּיע)',
        'so_KE' => 'סאמאַליש (קעניע)',
        'so_SO' => 'סאמאַליש (סאמאַליע)',
        'sq' => 'אַלבאַניש',
        'sq_AL' => 'אַלבאַניש (אַלבאַניע)',
        'sr' => 'סערביש',
        'sr_BA' => 'סערביש (באסניע הערצעגאווינע)',
        'sr_Cyrl' => 'סערביש (ציריליש)',
        'sr_Cyrl_BA' => 'סערביש (ציריליש, באסניע הערצעגאווינע)',
        'sr_Cyrl_ME' => 'סערביש (ציריליש, מאנטענעגרא)',
        'sr_Cyrl_RS' => 'סערביש (ציריליש, סערביע)',
        'sr_Latn' => 'סערביש (גַלחיש)',
        'sr_Latn_BA' => 'סערביש (גַלחיש, באסניע הערצעגאווינע)',
        'sr_Latn_ME' => 'סערביש (גַלחיש, מאנטענעגרא)',
        'sr_Latn_RS' => 'סערביש (גַלחיש, סערביע)',
        'sr_ME' => 'סערביש (מאנטענעגרא)',
        'sr_RS' => 'סערביש (סערביע)',
        'sv' => 'שוועדיש',
        'sv_FI' => 'שוועדיש (פֿינלאַנד)',
        'sv_SE' => 'שוועדיש (שוועדן)',
        'sw' => 'סוואַהיליש',
        'sw_CD' => 'סוואַהיליש (קאנגא־קינשאַזע)',
        'sw_KE' => 'סוואַהיליש (קעניע)',
        'sw_TZ' => 'סוואַהיליש (טאַנזאַניע)',
        'sw_UG' => 'סוואַהיליש (אוגאַנדע)',
        'ta' => 'טאַמיל',
        'ta_IN' => 'טאַמיל (אינדיע)',
        'ta_LK' => 'טאַמיל (סרי־לאַנקאַ)',
        'ta_MY' => 'טאַמיל (מאַלייזיע)',
        'ta_SG' => 'טאַמיל (סינגאַפּור)',
        'tk' => 'טורקמעניש',
        'tk_TM' => 'טורקמעניש (טורקמעניסטאַן)',
        'tl' => 'טאַגאַלאג',
        'tl_PH' => 'טאַגאַלאג (פֿיליפּינען)',
        'tt' => 'טאָטעריש',
        'tt_RU' => 'טאָטעריש (רוסלאַנד)',
        'uk' => 'אוקראַאיניש',
        'uk_UA' => 'אוקראַאיניש (אוקראַינע)',
        'ur' => 'אורדו',
        'ur_IN' => 'אורדו (אינדיע)',
        'ur_PK' => 'אורדו (פּאַקיסטאַן)',
        'uz' => 'אוזבעקיש',
        'uz_AF' => 'אוזבעקיש (אַפֿגהאַניסטאַן)',
        'uz_Arab' => 'אוזבעקיש (אַראַביש)',
        'uz_Arab_AF' => 'אוזבעקיש (אַראַביש, אַפֿגהאַניסטאַן)',
        'uz_Cyrl' => 'אוזבעקיש (ציריליש)',
        'uz_Latn' => 'אוזבעקיש (גַלחיש)',
        'vi' => 'וויעטנאַמעזיש',
        'vi_VN' => 'וויעטנאַמעזיש (וויעטנאַם)',
        'yi' => 'ייִדיש',
        'yi_001' => 'ייִדיש (וועלט)',
        'zh' => 'כינעזיש',
        'zh_CN' => 'כינעזיש (כינע)',
        'zh_SG' => 'כינעזיש (סינגאַפּור)',
        'zu' => 'זולו',
        'zu_ZA' => 'זולו (דרום־אַפֿריקע)',
    ],
];
