<?php

return [
    'Names' => [
        'aa' => 'афарча',
        'ab' => 'абхазча',
        'ace' => 'ачин',
        'ada' => 'адангмэ',
        'ady' => 'адигей',
        'af' => 'африкаанс',
        'agq' => 'агемча',
        'ain' => 'айну',
        'ak' => 'аканча',
        'ale' => 'алеут',
        'am' => 'амхарча',
        'an' => 'арагон',
        'anp' => 'ангика',
        'ar' => 'арабча',
        'arn' => 'мапудунгун',
        'arp' => 'арапахо',
        'as' => 'ассомча',
        'asa' => 'асуча',
        'ast' => 'астурийча',
        'av' => 'аварча',
        'awa' => 'авадхи',
        'ay' => 'аймара',
        'az' => 'озарбайжонча',
        'ba' => 'бошқирдча',
        'ban' => 'балича',
        'bas' => 'басаа',
        'be' => 'беларусча',
        'bem' => 'бемба',
        'bez' => 'бенача',
        'bg' => 'болгарча',
        'bho' => 'бхожпури',
        'bi' => 'бислама',
        'bin' => 'бини',
        'bm' => 'бамбарча',
        'bn' => 'бенгалча',
        'bo' => 'тибетча',
        'br' => 'бретонча',
        'brx' => 'бодоча',
        'bs' => 'боснийча',
        'bug' => 'бугийча',
        'byn' => 'блинча',
        'ca' => 'каталонча',
        'ce' => 'чечен тили',
        'ceb' => 'себуанча',
        'cgg' => 'чигача',
        'ch' => 'чаморро',
        'chk' => 'чуукча',
        'chm' => 'мари',
        'cho' => 'чоктавча',
        'chr' => 'чероки',
        'chy' => 'шайенн',
        'ckb' => 'сорани-курдча',
        'co' => 'корсиканча',
        'cs' => 'чехча',
        'cu' => 'славянча (черков)',
        'cv' => 'чуваш тили',
        'cy' => 'уэлсча',
        'da' => 'датча',
        'dak' => 'дакотча',
        'dar' => 'даргинча',
        'dav' => 'таитача',
        'de' => 'немисча',
        'dgr' => 'догриб',
        'dje' => 'зарма',
        'dsb' => 'қуйи-сорбча',
        'dua' => 'дуалача',
        'dv' => 'дивехи',
        'dyo' => 'диола-фогни',
        'dz' => 'дзонгка',
        'dzg' => 'дазага',
        'ebu' => 'эмбуча',
        'ee' => 'эвеча',
        'efi' => 'эфик',
        'eka' => 'экажук',
        'el' => 'грекча',
        'en' => 'инглизча',
        'eo' => 'эсперанто',
        'es' => 'испанча',
        'et' => 'эстонча',
        'eu' => 'баскча',
        'ewo' => 'эвондонча',
        'fa' => 'форсий',
        'ff' => 'фулаҳ',
        'fi' => 'финча',
        'fil' => 'филипинча',
        'fj' => 'фижича',
        'fo' => 'фарерча',
        'fon' => 'фон',
        'fr' => 'французча',
        'fur' => 'фриулча',
        'fy' => 'ғарбий фризча',
        'ga' => 'ирландча',
        'gaa' => 'га',
        'gd' => 'шотландча гаелик',
        'gez' => 'геэз',
        'gil' => 'гилбертча',
        'gl' => 'галицийча',
        'gn' => 'гуарани',
        'gor' => 'горонтало',
        'gu' => 'гужаротча',
        'guz' => 'гусии',
        'gv' => 'мэнча',
        'gwi' => 'гвичин',
        'ha' => 'хауса',
        'haw' => 'гавайча',
        'he' => 'иброний',
        'hi' => 'ҳинди',
        'hil' => 'хилигайнон',
        'hmn' => 'хмонгча',
        'hr' => 'хорватча',
        'hsb' => 'юқори сорбча',
        'ht' => 'гаитянча',
        'hu' => 'венгерча',
        'hup' => 'хупа тили',
        'hy' => 'арманча',
        'hz' => 'гереро',
        'ia' => 'интерлингва',
        'iba' => 'ибан тили',
        'ibb' => 'ибибо',
        'id' => 'индонезча',
        'ig' => 'игбо',
        'ilo' => 'илоко',
        'inh' => 'ингушча',
        'io' => 'идо',
        'is' => 'исландча',
        'it' => 'италянча',
        'iu' => 'инуктитут',
        'ja' => 'японча',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме тили',
        'jv' => 'яванча',
        'ka' => 'грузинча',
        'kab' => 'кабилча',
        'kaj' => 'кажи',
        'kam' => 'камбача',
        'kde' => 'макондеча',
        'kea' => 'кабувердиану',
        'khq' => 'койра-чиини',
        'ki' => 'кикую',
        'kk' => 'қозоқча',
        'kkj' => 'како',
        'kl' => 'гренландча',
        'kln' => 'каленжинча',
        'km' => 'хмерча',
        'kn' => 'каннада',
        'ko' => 'корейсча',
        'kok' => 'конканча',
        'kr' => 'канури',
        'ks' => 'кашмирча',
        'ksb' => 'шамбала',
        'ksf' => 'бафияча',
        'ksh' => 'кёлнча',
        'ku' => 'курдча',
        'kw' => 'корнча',
        'ky' => 'қирғизча',
        'la' => 'лотинча',
        'lag' => 'лангича',
        'lb' => 'люксембургча',
        'lg' => 'гандача',
        'lkt' => 'лакотачалакотача',
        'ln' => 'лингалча',
        'lo' => 'лаосча',
        'lrc' => 'шимолий лури',
        'lt' => 'литвача',
        'lu' => 'луба-катанга',
        'lus' => 'лушай',
        'luy' => 'луҳя',
        'lv' => 'латишча',
        'mas' => 'масайча',
        'mdf' => 'мокша тили',
        'men' => 'менде',
        'mer' => 'меруча',
        'mfe' => 'морисьен',
        'mg' => 'малагасийча',
        'mgh' => 'махува-митто',
        'mgo' => 'мета',
        'mh' => 'маршалл тили',
        'mi' => 'маори',
        'mic' => 'микмак',
        'min' => 'минангкабау',
        'mk' => 'македонча',
        'ml' => 'малаялам',
        'mn' => 'мўғулча',
        'mni' => 'манипурча',
        'moh' => 'могавк',
        'mos' => 'мосси',
        'mr' => 'маратхи',
        'ms' => 'малай тил',
        'mt' => 'малтача',
        'mua' => 'мунданг',
        'mus' => 'крикча',
        'mwl' => 'мирандес',
        'my' => 'бирманча',
        'myv' => 'эрзянча',
        'mzn' => 'мазандеран',
        'naq' => 'нама',
        'nb' => 'норвегча бокмал',
        'nd' => 'шимолий ндебеле',
        'ne' => 'непалча',
        'niu' => 'ниуэча',
        'nl' => 'голландча',
        'nmg' => 'квасио',
        'nn' => 'норвегча нюнорск',
        'nnh' => 'нгиембун',
        'nqo' => 'нко',
        'nr' => 'жанубий ндебелча',
        'nus' => 'нуэрча',
        'ny' => 'чева',
        'nyn' => 'нянколе',
        'oc' => 'окситанча',
        'om' => 'оромо',
        'or' => 'одия',
        'pa' => 'панжобча',
        'pap' => 'папияменто',
        'pl' => 'полякча',
        'ps' => 'пушту',
        'pt' => 'португалча',
        'qu' => 'кечуа',
        'quc' => 'кичэ',
        'rm' => 'романшча',
        'rn' => 'рунди',
        'ro' => 'руминча',
        'rof' => 'ромбоча',
        'ru' => 'русча',
        'rup' => 'арумин',
        'rw' => 'киняруанда',
        'rwk' => 'руанда тили',
        'sa' => 'санскрит',
        'sah' => 'саха',
        'saq' => 'самбуруча',
        'sat' => 'сантали',
        'sbp' => 'сангуча',
        'sd' => 'синдҳи',
        'se' => 'шимолий саамча',
        'seh' => 'сена',
        'ses' => 'койраборо-сенни',
        'sg' => 'санго',
        'shi' => 'ташелхит',
        'si' => 'сингалча',
        'sk' => 'словакча',
        'sl' => 'словенча',
        'sma' => 'жанубий саамча',
        'smj' => 'луле-саамча',
        'smn' => 'инари-саамча',
        'sms' => 'сколт-саамча',
        'sn' => 'шона',
        'so' => 'сомалича',
        'sq' => 'албанча',
        'sr' => 'сербча',
        'ss' => 'свати',
        'ssy' => 'саҳоча',
        'su' => 'сунданча',
        'sv' => 'шведча',
        'sw' => 'суахили',
        'swb' => 'коморча',
        'syr' => 'сурияча',
        'ta' => 'тамилча',
        'te' => 'телугу',
        'teo' => 'тесо',
        'tg' => 'тожикча',
        'th' => 'тайча',
        'ti' => 'тигриняча',
        'tig' => 'тигре',
        'tk' => 'туркманча',
        'to' => 'тонганча',
        'tr' => 'туркча',
        'tt' => 'татарча',
        'twq' => 'тасавак',
        'tzm' => 'марказий атлас тамазигхт',
        'ug' => 'уйғурча',
        'uk' => 'украинча',
        'ur' => 'урду',
        'uz' => 'ўзбекча',
        'vai' => 'ваи',
        've' => 'венда',
        'vi' => 'ветнамча',
        'vo' => 'волапюк',
        'vun' => 'вунжо',
        'wae' => 'валсерча',
        'wal' => 'волятта',
        'wo' => 'волофча',
        'xh' => 'хоса',
        'xog' => 'сога',
        'yav' => 'янгбен',
        'yi' => 'иддиш',
        'yo' => 'йоруба',
        'yue' => 'кантонча',
        'zgh' => 'тамазигхт',
        'zh' => 'хитойча',
        'zu' => 'зулу',
    ],
    'LocalizedNames' => [
        'ar_001' => 'стандарт арабча',
        'en_GB' => 'инглизча (Британия)',
        'en_US' => 'инглизча (Америка)',
        'nl_BE' => 'фламандча',
        'sw_CD' => 'конго-суахили',
        'zh_Hans' => 'соддалаштирилган хитойча',
        'zh_Hant' => 'анъанавий хитойча',
    ],
];
