<?php

return [
    'Names' => [
        'aa' => 'اَفار',
        'ab' => 'اَبخازِیان',
        'ace' => 'اَچَےنیٖز',
        'ach' => 'اَکولی',
        'ada' => 'اَدَنگمیے',
        'ady' => 'اَدَیٖگیے',
        'ae' => 'اَویستَن',
        'af' => 'اَفریٖکانز',
        'afh' => 'اَفرِہِلی',
        'ain' => 'اینوٗ',
        'ak' => 'اَکان',
        'akk' => 'اَکادِیَن',
        'ale' => 'اَلویتی',
        'alt' => 'جنوٗبی اَلتایی',
        'am' => 'اَمہاری',
        'an' => 'اَراگونی',
        'ang' => 'پرون اَنگریٖزی',
        'anp' => 'اَنگِکا',
        'ar' => 'عربی',
        'arc' => 'اَرَمیک',
        'arn' => 'ایرو کونِیَن',
        'arp' => 'اَراپاہو',
        'arw' => 'اَراوَک',
        'as' => 'اسٲمۍ',
        'ast' => 'ایسٹوٗریَن',
        'av' => 'اَوارِک',
        'awa' => 'اَوَدی',
        'ay' => 'ایمارا',
        'az' => 'اَزَربیجانی',
        'ba' => 'بَشکیٖر',
        'bal' => 'بَلوٗچی',
        'ban' => 'بالِنیٖز',
        'bas' => 'باسا',
        'be' => 'بیلَروٗشیَن',
        'bej' => 'بیجا',
        'bem' => 'بیمبا',
        'bg' => 'بینا',
        'bho' => 'بوجپوٗری',
        'bi' => 'بِسلاما',
        'bik' => 'بِکول',
        'bin' => 'بِنی',
        'bla' => 'سِکسِکا',
        'bm' => 'بَمبارا',
        'bn' => 'بَنگٲلۍ',
        'bo' => 'تِبتی',
        'br' => 'بریٹَن',
        'bra' => 'برج',
        'bs' => 'بوسنِیَن',
        'bua' => 'بُرِیَت',
        'bug' => 'بَگنیٖز',
        'byn' => 'بٕلِن',
        'ca' => 'کَتلان',
        'cad' => 'کاڈو',
        'car' => 'کارِب',
        'cch' => 'اتسَم',
        'ce' => 'چیچَن',
        'ceb' => 'سیباونو',
        'ch' => 'کَمورو',
        'chb' => 'چیٖبچا',
        'chg' => 'چھَگتاے',
        'chk' => 'چُکیٖز',
        'chm' => 'ماری',
        'chn' => 'چِنوٗک جارگَن',
        'cho' => 'چوکتَو',
        'chp' => 'شیپویان',
        'chr' => 'چیروکی',
        'chy' => 'شییون',
        'co' => 'کارسِکَن',
        'cop' => 'کاپٹِک',
        'cr' => 'کری',
        'crh' => 'کرٕمیٖن تُرکی',
        'cs' => 'چیک',
        'csb' => 'کَشوٗبِیَن',
        'cu' => 'چٔرچ سلاوِک',
        'cv' => 'چُواش',
        'cy' => 'ویلش',
        'da' => 'ڈینِش',
        'dak' => 'ڈکوٹا',
        'dar' => 'دَرگوا',
        'de' => 'جٔرمَن',
        'del' => 'ڈیلوییَر',
        'den' => 'سلیو',
        'dgr' => 'ڈاگرِب',
        'din' => 'ڈِنکا',
        'doi' => 'ڈوگری',
        'dsb' => 'بۆنِم ساربِیَن',
        'dua' => 'دُوالا',
        'dum' => 'وَستی پُرتُگالی',
        'dv' => 'دِویہی',
        'dyu' => 'ڈِیوٗلا',
        'dz' => 'زونگکھا',
        'ee' => 'ایٖو',
        'efi' => 'ایفِک',
        'egy' => 'قدیٖمی مِصری',
        'eka' => 'ایکاجُک',
        'el' => 'یوٗنٲنی',
        'elx' => 'ایلامایِٹ',
        'en' => 'اَنگیٖزۍ',
        'enm' => 'وَسطی اَنگریٖزۍ',
        'eo' => 'ایسپَرینٹو',
        'es' => 'ہسپانوی',
        'et' => 'ایسٹونیَن',
        'eu' => 'باسک',
        'ewo' => 'ایوونڈو',
        'fa' => 'فارسی',
        'fan' => 'فینگ',
        'fat' => 'فانٹی',
        'ff' => 'فُلاہ',
        'fi' => 'فِنِش',
        'fil' => 'فِلِپیٖنو',
        'fj' => 'فِجیَن',
        'fo' => 'فَروس',
        'fon' => 'فون',
        'fr' => 'فرانسیسی',
        'frm' => 'وسطی فرینچ',
        'fro' => 'پرون فرینچ',
        'frr' => 'شُمٲلی فرِشیَن',
        'frs' => 'مشرِقی فرِشیَن',
        'fur' => 'فروٗلِیَن',
        'fy' => 'مغربی فرِشیَن',
        'ga' => 'اَیرِش',
        'gaa' => 'گا',
        'gay' => 'گیےیو',
        'gba' => 'گبایا',
        'gd' => 'سکوٹِش گیےلِک',
        'gez' => 'گیٖز',
        'gil' => 'گِلبٔرٹیٖز',
        'gl' => 'گیلِشِیَن',
        'gmh' => 'وَسطی ہاے جٔرمَن',
        'gn' => 'گُوارَنی',
        'goh' => 'پرون ہاے جٔرمَن',
        'gon' => 'گوندی',
        'gor' => 'گورینٹیلو',
        'got' => 'گوتھِک',
        'grb' => 'گرِبو',
        'grc' => 'قدیٖم یوٗنٲنی',
        'gsw' => 'سٕوِس جٔرمَن',
        'gu' => 'گُجرٲتی',
        'gv' => 'مینکس',
        'gwi' => 'گُوِچ اِن',
        'ha' => 'ہاوسا',
        'hai' => 'ہَیدا',
        'haw' => 'ہوایِیَن',
        'he' => 'عبرٲنۍ',
        'hi' => 'ہِندی',
        'hil' => 'ہِلیٖگینَن',
        'hit' => 'ہِتایِت',
        'hmn' => 'ہمونگ',
        'ho' => 'ہِری موتوٗ',
        'hr' => 'کروشِیَن',
        'hsb' => 'ہیرِم ساربِیَن',
        'ht' => 'ہیتِیاں',
        'hu' => 'ہَنگیریَن',
        'hup' => 'ہُپا',
        'hy' => 'اَرمینیَن',
        'hz' => 'ہیریٖرو',
        'ia' => 'اِنٹَرلِنگوا',
        'iba' => 'اِبان',
        'id' => 'اِنڈونیشیا',
        'ie' => 'اِنٹَر لِننگویے',
        'ig' => 'اِگبو',
        'ii' => 'سِچوان یٖی',
        'ik' => 'اِنُپِیاک',
        'ilo' => 'اِلوکو',
        'inh' => 'اِنگُش',
        'io' => 'اِڈو',
        'is' => 'آیِسلینڈِک',
        'it' => 'اِطالوی',
        'iu' => 'اِنُکتِتوٗ',
        'ja' => 'جاپٲنۍ',
        'jbo' => 'لوجبان',
        'jpr' => 'جوڈیو فارسی',
        'jrb' => 'جوڈیو عربی',
        'jv' => 'جَوَنیٖز',
        'ka' => 'جارجِیَن',
        'kaa' => 'کارا کَلپَک',
        'kab' => 'کَبایِل',
        'kac' => 'کاچِن',
        'kaj' => 'جُوٗ',
        'kam' => 'کامبا',
        'kaw' => 'کَوی',
        'kbd' => 'کَبارڈِیَن',
        'kcg' => 'تَیَپ',
        'kfo' => 'کورو',
        'kg' => 'کونگو',
        'kha' => 'کھاسی',
        'kho' => 'کھوتَنیٖز',
        'ki' => 'کِکُیوٗ',
        'kj' => 'کُوانیاما',
        'kk' => 'کازَخ',
        'kl' => 'کَلالِسُت',
        'km' => 'خَمیر',
        'kmb' => 'کِمبُندوٗ',
        'kn' => 'کَنَڑ',
        'ko' => 'کوریَن',
        'kok' => 'کونکَنی',
        'kos' => 'کوسرییَن',
        'kpe' => 'کَپیلی',
        'kr' => 'کَنوٗری',
        'krc' => 'کراچیے بَلکار',
        'krl' => 'کَریلِیَن',
        'kru' => 'کُرُکھ',
        'ks' => 'کٲشُر',
        'ku' => 'کُردِش',
        'kum' => 'کُمِک',
        'kut' => 'کُتینَے',
        'kv' => 'کومی',
        'kw' => 'کورنِش',
        'ky' => 'کِرگِز',
        'la' => 'لاتیٖنی',
        'lad' => 'لیڈِنو',
        'lah' => 'لَہَندا',
        'lam' => 'لَمبا',
        'lb' => 'لُکھزیمبورگِش',
        'lez' => 'لیزگِیَن',
        'lg' => 'گاندا',
        'li' => 'لِمبٔرگِش',
        'ln' => 'لِنگالا',
        'lo' => 'لاو',
        'lol' => 'مونگو',
        'loz' => 'لوزی',
        'lt' => 'لِتھوانِیَن',
        'lu' => 'لوُبا کَتَنگا',
        'lua' => 'لوٗبا لوٗلُوا',
        'lui' => 'لویِسینو',
        'lun' => 'لُندا',
        'luo' => 'لُوو',
        'lus' => 'لُسہاے',
        'lv' => 'لَتوِیَن',
        'mad' => 'مَدُریٖز',
        'mag' => 'مَگاے',
        'mai' => 'میتَھلی',
        'mak' => 'مَکَسار',
        'man' => 'مَندِنگو',
        'mas' => 'مَساے',
        'mdf' => 'موکشا',
        'mdr' => 'مَندَر',
        'men' => 'میندیے',
        'mg' => 'مَلاگَسی',
        'mga' => 'وَستی ایرِش',
        'mh' => 'مارشَلیٖز',
        'mi' => 'ماوری',
        'mic' => 'مِکمیک',
        'min' => 'مِنَنگکَباو',
        'mk' => 'میکَڈونیَن',
        'ml' => 'مٔلیالَم',
        'mn' => 'مَنگولی',
        'mnc' => 'مانچوٗ',
        'mni' => 'مَنیپوٗری',
        'moh' => 'موہاک',
        'mos' => 'موسی',
        'mr' => 'مَرٲٹھۍ',
        'ms' => 'مَلَے',
        'mt' => 'مَلتیٖس',
        'mus' => 'کریٖک',
        'mwl' => 'مِراندیٖز',
        'mwr' => 'مارواڑی',
        'my' => 'بٔمیٖز',
        'myv' => 'ایرزِیا',
        'na' => 'ناورُ',
        'nap' => 'نیٖپالیٹَن',
        'nb' => 'ناروییَن بوکمال',
        'nd' => 'شُمال ڈَبیل',
        'nds' => 'بۆنِم جٔرمَن',
        'ne' => 'نیپٲلۍ',
        'new' => 'نیواری',
        'ng' => 'ڈونگا',
        'nia' => 'نِیاس',
        'niu' => 'نِیویَن',
        'nl' => 'ڈَچ',
        'nn' => 'ناروییَن نَے نورسک',
        'no' => 'ناروییَن',
        'nog' => 'نوگاے',
        'non' => 'پرون نارسی',
        'nqo' => 'این کو',
        'nr' => 'جنوب ڈیبیل',
        'nso' => 'شمالی ستھو',
        'nv' => 'نَواجو',
        'nwc' => 'کلاسِکَل نیواری',
        'ny' => 'نِیَنجا',
        'nym' => 'نِیَمویزی',
        'nyn' => 'نِیَنکول',
        'nyo' => 'نِیورو',
        'nzi' => 'نَظیٖما',
        'oc' => 'اوکسیٖٹَن',
        'oj' => 'اوجِبوا',
        'om' => 'اۆرومو',
        'or' => 'اۆرِیا',
        'os' => 'اۆسیٹِک',
        'osa' => 'اۆسیج',
        'ota' => 'اوٹومَن تُرکِش',
        'pa' => 'پَنجٲبۍ',
        'pag' => 'پَنگاسِنَن',
        'pal' => 'پَہلَوی',
        'pam' => 'پَمپَنگا',
        'pap' => 'پَپِیامینٹو',
        'pau' => 'پَلااُواں',
        'peo' => 'پرون فارسی',
        'phn' => 'فونیٖشیَن',
        'pi' => 'پالی',
        'pl' => 'پالِش',
        'pon' => 'پانپییَن',
        'pro' => 'پرون پرووینچَل',
        'ps' => 'پَشتوٗ',
        'pt' => 'پُرتَگیٖز',
        'qu' => 'کُویشُوا',
        'raj' => 'راجِستھٲنۍ',
        'rap' => 'رَپانوی',
        'rar' => 'رَروٹونگَن',
        'rm' => 'رومانش',
        'rn' => 'رُندی',
        'ro' => 'رومٲنی',
        'rom' => 'رومَنی',
        'ru' => 'روٗسی',
        'rup' => 'اَرومانی',
        'rw' => 'کِنیاوِندا',
        'sa' => 'سَنسکرٕت',
        'sad' => 'سَندَویے',
        'sah' => 'یاکُت',
        'sam' => 'سَمارِتَن اَرامیک',
        'sas' => 'سَسَک',
        'sat' => 'سَنتالی',
        'sc' => 'سراڈیٖنی',
        'scn' => 'سِچِلِیَن',
        'sco' => 'سکاٹس',
        'sd' => 'سِندی',
        'se' => 'شُمٲلی سَمی',
        'sel' => 'سیلکُپ',
        'sg' => 'سَنگو',
        'sga' => 'پرون ایرِش',
        'sh' => 'سیربو کروشِیَن',
        'shn' => 'شان',
        'si' => 'سِنہالا',
        'sid' => 'سِدامو',
        'sk' => 'سلووَک',
        'sl' => 'سلووینیَن',
        'sm' => 'سَمواَن',
        'sma' => 'جنوٗبی سَمی',
        'smj' => 'لولیے سَمی',
        'smn' => 'اِناری سَمی',
        'sms' => 'سکولٹ سَمی',
        'sn' => 'شونا',
        'snk' => 'سونِنکیے',
        'so' => 'سومٲلی',
        'sog' => 'سوگڈِیَن',
        'sq' => 'البانِیَن',
        'sr' => 'سٔربِیَن',
        'srn' => 'سرانَن ٹونگو',
        'srr' => 'سیریر',
        'ss' => 'سواتی',
        'st' => 'جنوبی ستھو',
        'su' => 'سَنڈَنیٖز',
        'suk' => 'سُکُما',
        'sus' => 'سُسوٗ',
        'sux' => 'سُمیریَن',
        'sv' => 'سویٖڈِش',
        'sw' => 'سواہِلی',
        'syr' => 'سیٖریٲیی',
        'ta' => 'تَمِل',
        'te' => 'تیلگوٗ',
        'tem' => 'ٹِمنیے',
        'ter' => 'ٹیرینو',
        'tet' => 'ٹیٹَم',
        'tg' => 'تاجِک',
        'th' => 'تھاے',
        'ti' => 'ٹِگرِنیا',
        'tig' => 'ٹاےگریے',
        'tiv' => 'تیٖو',
        'tk' => 'تُرکمین',
        'tkl' => 'ٹوکیٖلاو',
        'tl' => 'تَماشیک',
        'tlh' => 'کِلِنگون',
        'tli' => 'ٹِلِنگِت',
        'tmh' => 'تاماشیک',
        'tn' => 'سوانا',
        'to' => 'ٹونگا',
        'tog' => 'نیاسا ٹونگا',
        'tpi' => 'ٹاک پِسِن',
        'tr' => 'تُرکِش',
        'ts' => 'ژونگا',
        'tsi' => 'ژھِمشِیان',
        'tt' => 'تَتار',
        'tum' => 'تُمبُکا',
        'tvl' => 'تُوالوٗ',
        'tw' => 'توی',
        'ty' => 'تاہیشِیَن',
        'tyv' => 'تُویٖنیَن',
        'udm' => 'اُدمُرت',
        'uga' => 'اُگارتِک',
        'uk' => 'یوٗکرینیٲیی',
        'umb' => 'یُمبُندوٗ',
        'ur' => 'اُردوٗ',
        'uz' => 'اُزبیک',
        'vai' => 'واے',
        've' => 'ویندا',
        'vi' => 'وِیَتنَمیٖز',
        'vo' => 'وولَپُک',
        'vot' => 'ووتِک',
        'wa' => 'وَلوٗن',
        'wal' => 'والامو',
        'war' => 'وَریے',
        'was' => 'واشو',
        'wo' => 'وولوف',
        'xal' => 'کالمِک',
        'xh' => 'کھوسا',
        'yao' => 'یاو',
        'yap' => 'یَپیٖز',
        'yi' => 'یِدِش',
        'yo' => 'یورُبا',
        'za' => 'زُہانگ',
        'zap' => 'زَپوتیک',
        'zen' => 'زیناگا',
        'zh' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾',
        'zu' => 'زُلوٗ',
        'zun' => 'زوٗنی',
        'zza' => 'زازا',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ماڈرن معیٲری عربی',
        'de_AT' => 'آسٹرِیَن جٔرمَن',
        'de_CH' => 'سٕوِس ہائی جٔرمَن',
        'en_AU' => 'آسٹریلیَن اَنگریٖزۍ',
        'en_CA' => 'کینَڈِیٲیی اَنگریٖزۍ',
        'en_GB' => 'بَرطانوی اَنگریٖزۍ',
        'en_US' => 'امریٖکی اَنٛگریٖزۍ',
        'es_419' => 'لاطیٖنی امریٖکی ہسپانوی',
        'es_ES' => 'یوٗرپی ہسپانوی',
        'es_MX' => 'میکسیکن ہسپانوی',
        'fr_CA' => 'کَنیڈیَن فرانسیسی',
        'fr_CH' => 'سٕوٕس فرانسیسی',
        'nl_BE' => 'فلیمِش',
        'pt_BR' => 'برازیٖلی پُرتَگیٖز',
        'pt_PT' => 'یوٗرپی پُرتَگیٖز',
        'ro_MD' => 'مولداوِیَن',
        'zh_Hans' => 'سَہل چیٖنی',
        'zh_Hant' => 'رِوٲجی چیٖنی',
    ],
];
