<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'andorrská peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'SAE dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afganský afgání (1927 – 2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afganský afgání',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'albánsky lek (1946 – 1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albánsky lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'arménsky dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'antilský gulden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angolská kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'angolská kwanza (1977 – 1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'angolská nová kwanza (1990 – 2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'angolská upravená kwanza (1995 – 1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'argentínsky austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'argentínske peso ley (1970 – 1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'argentínske peso (1881 – 1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'argentínske peso (1983 – 1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentínske peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'rakúsky šiling',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'austrálsky dolár',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arubský gulden',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'azerbajdžanský manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'azerbajdžanský manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'bosniansko-hercegovinský dinár (1992 – 1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'bosniansko-hercegovinská konvertibilná marka',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'bosniansko-hercegovinský nový dinár (1994 – 1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadoský dolár',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladéšska taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'belgický frank (konvertibilný)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'belgický frank',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'belgický frank (finančný)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'bulharský tvrdý lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'bulharský socialistický lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'bulharský lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'bulharský lev (1879 – 1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahrajnský dinár',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'burundský frank',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'bermudský dolár',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'brunejský dolár',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'bolívijské boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'bolívijské boliviano (1863 – 1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'bolívijské peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'bolívijské MVDOL',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'brazílske nové cruzeiro (1967 – 1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'brazílske cruzado (1986 – 1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'brazílske cruzeiro (1990 – 1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'brazílsky real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'brazílske nové cruzado (1989 – 1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brazílske cruzeiro',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'brazílske cruzeiro (1942 – 1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'bahamský dolár',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'bhutánsky ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'barmský kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'botswanská pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'bieloruský rubeľ (1994 – 1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'bieloruský rubeľ',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'bieloruský rubeľ (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'belizský dolár',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'kanadský dolár',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'konžský frank',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'švajčiarske WIR euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'švajčiarsky frank',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'švajčiarsky WIR frank',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'čilské escudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'čilská účtovná jednotka (UF)',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'čilské peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'čínsky jüan (pobrežný)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'čínsky dolár ČĽB',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'čínsky jüan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'kolumbijské peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'kolumbijská jednotka reálnej hodnoty',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'kostarický colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'srbský dinár (2002 – 2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'československá koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'kubánske konvertibilné peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'kubánske peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'kapverdské escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'cyperská libra',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'česká koruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'východonemecká marka',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'nemecká marka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'džibutský frank',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'dánska koruna',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dominikánske peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'alžírsky dinár',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'ekvádorský sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'ekvádorská jednotka konštantnej hodnoty',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'estónska koruna',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egyptská libra',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'eritrejská nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'španielska peseta (účet A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'španielska peseta (konvertibilný účet)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'španielska peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'etiópsky birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'fínska marka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fidžijský dolár',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'falklandská libra',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'francúzsky frank',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'britská libra',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'gruzínske kupónové lari',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'gruzínske lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ghanské cedi (1979 – 2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ghanské cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'gibraltárska libra',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambijské dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'guinejský frank',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'guinejské syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'rovníkovoguinejský ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'grécka drachma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'guatemalský quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'portugalsko-guinejské escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'guinejsko-bissauské peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'guyanský dolár',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'hongkonský dolár',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'honduraská lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'chorvátsky dinár',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'chorvátska kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haitské gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'maďarský forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indonézska rupia',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'írska libra',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'izraelská libra',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'izraelský šekel (1980 – 1985)',
        ],
        'ILS' => [
            0 => 'NIS',
            1 => 'izraelský šekel',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'indická rupia',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'iracký dinár',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iránsky rial',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'islandská koruna (1918 – 1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'islandská koruna',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'talianska líra',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamajský dolár',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jordánsky dinár',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'japonský jen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenský šiling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgizský som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'kambodžský riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'komorský frank',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'severokórejský won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'juhokórejský hwan (1953 – 1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'juhokórejský won (1945 – 1953)',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'juhokórejský won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuvajtský dinár',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'kajmanský dolár',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kazašské tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laoský kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'libanonská libra',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'srílanská rupia',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'libérijský dolár',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesothský loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litovský litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'litovský talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'luxemburský frank (konvertibilný)',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'luxemburský frank',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'luxemburský frank (finančný)',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'lotyšský lat',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'lotyšský rubeľ',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'líbyjský dinár',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'marocký dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'marocký frank',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'monacký frank',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'moldavský kupón',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldavský lei',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'malgašský ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'madagaskarský frank',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'macedónsky denár',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'macedónsky denár (1992 – 1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'malijský frank',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'mjanmarský kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongolský tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'macajská pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'mauritánska ukija (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mauritánska ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'maltská líra',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'maltská libra',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'maurícijská rupia',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'maldivská rupia (1947 – 1981)',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldivská rupia',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'malawijská kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'mexické peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'mexické strieborné peso (1861 – 1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'mexická investičná jednotka',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malajzijský ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'mozambické escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'mozambický metical (1980 – 2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'mozambický metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'namíbijský dolár',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nigérijská naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'nikaragujská córdoba (1988 – 1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'nikaragujská córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'holandský gulden',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'nórska koruna',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepálska rupia',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'novozélandský dolár',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'ománsky rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'panamská balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'peruánsky inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'peruánsky sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'peruánsky sol (1863 – 1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'papuánska kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'filipínske peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistanská rupia',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'poľský zlotý',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'poľský zlotý (1950 – 1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'portugalské escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paraguajské guaraní',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'katarský rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'rodézsky dolár',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'rumunský lei (1952 – 2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'rumunský lei',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'srbský dinár',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'ruský rubeľ',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'ruský rubeľ (1991 – 1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'rwandský frank',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'saudskoarabský rial',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'šalamúnsky dolár',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'seychelská rupia',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'sudánsky dinár (1992 – 2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sudánska libra',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'sudánska libra (1957 – 1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'švédska koruna',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singapurský dolár',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'svätohelenská libra',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'slovinský toliar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'slovenská koruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'sierraleonský leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'somálsky šiling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'surinamský dolár',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'surinamský zlatý',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'juhosudánska libra',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'svätotomášska dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'svätotomášska dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'sovietsky rubeľ',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'salvádorský colón',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'sýrska libra',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'svazijský lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'thajský baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'tadžický rubeľ',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tadžické somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'turkménsky manat (1993 – 2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'turkménsky manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tuniský dinár',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'tongská paʻanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'timorské escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'turecká líra (1922 – 2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'turecká líra',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'trinidadsko-tobažský dolár',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'nový taiwanský dolár',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'tanzánsky šiling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ukrajinská hrivna',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ukrajinský karbovanec',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'ugandský šiling (1966 – 1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ugandský šiling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'americký dolár',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'americký dolár (ďalší deň)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'americký dolár (rovnaký deň)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'uruguajské peso (v indexovaných jednotkách)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'uruguajské peso (1975 – 1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'uruguajské peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'uzbecký sum',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'venezuelský bolívar (1871 – 2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venezuelský bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venezuelský bolívar',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'vietnamský dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'vietnamský dong (1978 – 1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuatské vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'samojská tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'stredoafrický frank',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'východokaribský dolár',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'európska menová jednotka',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'francúzsky zlatý frank',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'francúzsky UIC frank',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'západoafrický frank',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP frank',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'fondy RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'jemenský dinár',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'jemenský rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Juhoslávsky dinár [YUD]',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'juhoslovanský nový dinár (1994 – 2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'juhoslovanský konvertibilný dinár (1990 – 1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'juhoslovanský reformovaný dinár (1992 – 1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'juhoafrický rand (finančný)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'juhoafrický rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'zambijská kwacha (1968 – 2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'zambijská kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zairský nový zaire (1993 – 1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zairský zaire (1971 – 1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'zimbabwiansky dolár (1980 – 2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'zimbabwiansky dolár (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'zimbabwiansky dolár (2008)',
        ],
    ],
];
