<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorska pezeta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Dirham Ujedinjenih Arapskih Emirata',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Avganistanski avgani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afganistanski afgan',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Albanski lek (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanski lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armenski dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Holandskoantilski gulden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolska kvanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolijska kvanza (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolijska nova kvanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolijska kvanza reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentinski austral',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentinski pezo (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentinski pezos',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Austrijski šiling',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'Australijski dolar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Arubanski florin',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbejdžanski manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbejdžanski manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosanskohercegovački dinar',
        ],
        'BAM' => [
            0 => 'KM',
            1 => 'Bosanskohercegovačka konvertibilna marka',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Bosanskohercegovački novi dinar',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadoski dolar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladeška taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belgijski frank (konvertibilni)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgijski franak',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belgijski frank (finansijski)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bugarski tvrdi lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Bugarski socijalistički lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bugarski lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Bugarski lev (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreinski dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundski franak',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermudski dolar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunejski dolar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivijski boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Bolivijski boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Bolivijski pezo',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Bolivijski mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Brazilski kruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Brazilski kruzado (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Brazilski kruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Brazilski real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Brazilski kruzado novo (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Brazilski kruzeiro (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Brazilski kruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamski dolar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butanski ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Burmanski kjat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Bocvanska pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Beloruska nova rublja (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Bjeloruska rublja',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Bjeloruska rublja (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belizeanski dolar',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Kanadski dolar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongoanski franak',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR Evro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Švicarski franak',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR franak',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Čileanski eskudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Čileanski unidades de fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Čileanski pezos',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Kineski juan (izvanteritorijalni)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'Dolar kineske narodne banke',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Kineski juan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolumbijski pezos',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Kolumbijski Unidade real de valor',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kostarikanski kolon',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Srpski dinar (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Čehoslovačka tvrda koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kubanski konvertibilni pezos',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'kubanski pezos',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Zelenortski eskudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Kipratska funta',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Češka kruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Istočnoevropska marka',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Nemačka marka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Džibutski franak',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Danska kruna',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikanski pezos',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Alžirski dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ekvadorijski sukr',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Ekvadorski unidad de valor konstantin (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estonska kruna',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egipatska funta',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrejska nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Španska pezeta (račun) ESA',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Španska pezeta (konvertibilni račun)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Španska pezeta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiopski bir',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Finska marka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fidžijski dolar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Folklandska funta',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Francuski franak',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'Britanska funta',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Gruzijski kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Gruzijski lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ganijski cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ganski cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltarska funta',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambijski dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Gvinejski franak',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Gvinejski sili',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Evatorijalna gvineja ekvele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Drahma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Gvatemalski kecal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugalska Gvineja eskudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Gvineja bisao pezo',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Gvajanski dolar',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Honkonški dolar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Honduraška lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Hrvatski dinar',
        ],
        'HRK' => [
            0 => 'kn',
            1 => 'Hrvatska kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haićanski gurd',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Mađarska forinta',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonežanska rupija',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Irska funta',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Izraelska funta',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'stari izraelski šekeli',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Izraelski novi šekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indijska rupija',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irački dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iranski rijal',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'stara islandska kruna',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Islandska kruna',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italijanska lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamajčanski dolar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordanski dinar',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Japanski jen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenijski šiling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgistanski som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodžanski rijel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komorski franak',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Sjevernokorejski von',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Južno-korejski hvan (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Južno-korejski Von (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Južnokorejski von',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuvajtski dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kajmanski dolar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazahstanski tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laoski kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libanska funta',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Šrilankanska rupija',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberijski dolar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesotski loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litvanski litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litvanski talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Luksemburški konvertibilni franak',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Luksemburški franak',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Luksemburški finansijski franak',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Letonski lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Latvijska rublja',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libijski dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokanski dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokanski franak',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Monegaskaški franak',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Moldavski kupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldavski lej',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagaški arijari',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Malagasijski franak',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedonski denar',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Makedonski denar (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malijanski franak',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Mijanmarski kjat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolski tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makaonska pataka',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritanijska ugvija (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritanijska ugvija',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Malteška lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Malteška funta',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauricijska rupija',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldivska rufija',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malavijska kvača',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Meksički pezos',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Meksijski srebrno pezo (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Meksijski unidad de inverzion',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malezijski ringit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambijski eskudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Mozambijski metikal (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambijski metikal',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibijski dolar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigerijska naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nikaragvanška kordoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragvanska kordoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Holandski gulden',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norveška kruna',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalska rupija',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'Novozelandski dolar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omanski rijal',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamska balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peruvijski inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruanski sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peruvijski sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina Papue Nove Gvineje',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filipinski pezos',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistanska rupija',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Poljski zlot',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Poljski zloti (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugalski eskudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paragvajski gvarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katarski rijal',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rodizijski dolar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Rumunski leu (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumunski lej',
        ],
        'RSD' => [
            0 => 'din.',
            1 => 'Srpski dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Ruska rublja',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Ruska rublja (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruandski franak',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudijski rijal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomonski dolar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Sejšelska rupija',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Sudanski dinar (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudanska funta',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Sudanska funta (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Švedska kruna',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapurski dolar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Svetohelenska funta',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Slovenski tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slovačka kruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sijeraleonski leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalski šiling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinamski dolar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinamski gilder',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Južnosudanska funta',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra Sao Toma i Principa (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra Sao Toma i Principa',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovjetska rublja',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Salvadorski kolon',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Sirijska funta',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svazilendski lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Tajlandski baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadžakistanska rublja',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadžikistanski somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmenistanski manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistanski manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tuniški dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tonganska panga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timorški eskudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turska lira (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turska lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidadtobaški dolar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Novi tajvanski dolar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzanijski šiling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrajinska hrivnja',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Ukrajinski karbovaneti',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Ugandijski šiling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandski šiling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'Američki dolar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'SAD dolar (sledeći dan)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'SAD dolar (isti dan)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Urugvajski pezo en unidades indeksades',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Urugvajski pezo (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Urugvajski pezos',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Uzbekistanski som',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venecuelanski bolivar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venecuelanski bolivar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venecuelanski bolivar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vijetnamski dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Vijetnamski dong (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatski vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoanska tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Centralnoafrički franak (CFA)',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'Istočnokaripski dolar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'Evropska valutna jedinica',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Francuski zlatni frank',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Francuski UIC-frank',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Zapadnoafrički franak (CFA)',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'Franak (CFP)',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET fondovi',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemenski dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemenski rijal',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Jugoslovenski tvrdi dinar',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Jugoslovenski novi dinar',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Jugoslovenski konvertibilni dinar',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Jugoslovenski reformirani dinar',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Južnoafrički rand (finansijski)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Južnoafrički rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambijska kvača (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambijska kvača',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zairski novi zair (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zairski zair (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabvejski dolar (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabvejski dolar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabvejski dolar (2008)',
        ],
    ],
];
