<footer id="footer">
  <div class="wrap">
    <div class="center copyrights">&copy; 2007-{{ year }} <a href="https://simplesamlphp.org/">SimpleSAMLphp</a>
    </div>
    <div class="logo-footer-space show-for-large">
      <div class="logo-footer">
        <img class="pure-img" src="{{ asset("icons/ssplogo-fish-small.png") }}" alt="Small fish logo">
      </div>
    </div>
  </div>
</footer>
