<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namìbia)',
        'af_ZA' => 'afrikaans (Sudàfrica)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amàricu',
        'am_ET' => 'amàricu (Etiòpia)',
        'ar' => 'àrabu',
        'ar_001' => 'àrabu (Mundu)',
        'ar_AE' => 'àrabu (Emirados Àrabos Unidos)',
        'ar_BH' => 'àrabu (Bahrein)',
        'ar_DJ' => 'àrabu (Gibuti)',
        'ar_DZ' => 'àrabu (Algeria)',
        'ar_EG' => 'àrabu (Egitu)',
        'ar_EH' => 'àrabu (Sahara otzidentale)',
        'ar_ER' => 'àrabu (Eritrea)',
        'ar_IL' => 'àrabu (Israele)',
        'ar_IQ' => 'àrabu (Iraq)',
        'ar_JO' => 'àrabu (Giordània)',
        'ar_KM' => 'àrabu (Comoras)',
        'ar_KW' => 'àrabu (Kuwait)',
        'ar_LB' => 'àrabu (Lèbanu)',
        'ar_LY' => 'àrabu (Lìbia)',
        'ar_MA' => 'àrabu (Marocu)',
        'ar_MR' => 'àrabu (Mauritània)',
        'ar_OM' => 'àrabu (Omàn)',
        'ar_PS' => 'àrabu (Territòrios palestinesos)',
        'ar_QA' => 'àrabu (Catar)',
        'ar_SA' => 'àrabu (Aràbia Saudita)',
        'ar_SD' => 'àrabu (Sudàn)',
        'ar_SO' => 'àrabu (Somàlia)',
        'ar_SS' => 'àrabu (Sudan de su Sud)',
        'ar_SY' => 'àrabu (Sìria)',
        'ar_TD' => 'àrabu (Chad)',
        'ar_TN' => 'àrabu (Tunisia)',
        'ar_YE' => 'àrabu (Yemen)',
        'as' => 'assamesu',
        'as_IN' => 'assamesu (Ìndia)',
        'az' => 'azerbaigianu',
        'az_AZ' => 'azerbaigianu (Azerbaigiàn)',
        'az_Cyrl' => 'azerbaigianu (tzirìllicu)',
        'az_Cyrl_AZ' => 'azerbaigianu (tzirìllicu, Azerbaigiàn)',
        'az_Latn' => 'azerbaigianu (latinu)',
        'az_Latn_AZ' => 'azerbaigianu (latinu, Azerbaigiàn)',
        'be' => 'bielorussu',
        'be_BY' => 'bielorussu (Bielorùssia)',
        'bg' => 'bùlgaru',
        'bg_BG' => 'bùlgaru (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengalesu',
        'bn_BD' => 'bengalesu (Bangladèsh)',
        'bn_IN' => 'bengalesu (Ìndia)',
        'bo' => 'tibetanu',
        'bo_CN' => 'tibetanu (Tzina)',
        'bo_IN' => 'tibetanu (Ìndia)',
        'br' => 'brètone',
        'br_FR' => 'brètone (Frantza)',
        'bs' => 'bosnìacu',
        'bs_BA' => 'bosnìacu (Bòsnia e Erzegòvina)',
        'bs_Cyrl' => 'bosnìacu (tzirìllicu)',
        'bs_Cyrl_BA' => 'bosnìacu (tzirìllicu, Bòsnia e Erzegòvina)',
        'bs_Latn' => 'bosnìacu (latinu)',
        'bs_Latn_BA' => 'bosnìacu (latinu, Bòsnia e Erzegòvina)',
        'ca' => 'catalanu',
        'ca_AD' => 'catalanu (Andorra)',
        'ca_ES' => 'catalanu (Ispagna)',
        'ca_FR' => 'catalanu (Frantza)',
        'ca_IT' => 'catalanu (Itàlia)',
        'ce' => 'cecenu',
        'ce_RU' => 'cecenu (Rùssia)',
        'cs' => 'tzecu',
        'cs_CZ' => 'tzecu (Tzèchia)',
        'cv' => 'ciuvàsciu',
        'cv_RU' => 'ciuvàsciu (Rùssia)',
        'cy' => 'gallesu',
        'cy_GB' => 'gallesu (Regnu Unidu)',
        'da' => 'danesu',
        'da_DK' => 'danesu (Danimarca)',
        'da_GL' => 'danesu (Groenlàndia)',
        'de' => 'tedescu',
        'de_AT' => 'tedescu (Àustria)',
        'de_BE' => 'tedescu (Bèlgiu)',
        'de_CH' => 'tedescu (Isvìtzera)',
        'de_DE' => 'tedescu (Germània)',
        'de_IT' => 'tedescu (Itàlia)',
        'de_LI' => 'tedescu (Liechtenstein)',
        'de_LU' => 'tedescu (Lussemburgu)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutàn)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'grecu',
        'el_CY' => 'grecu (Tzipru)',
        'el_GR' => 'grecu (Grètzia)',
        'en' => 'inglesu',
        'en_001' => 'inglesu (Mundu)',
        'en_150' => 'inglesu (Europa)',
        'en_AE' => 'inglesu (Emirados Àrabos Unidos)',
        'en_AG' => 'inglesu (Antigua e Barbuda)',
        'en_AI' => 'inglesu (Anguilla)',
        'en_AS' => 'inglesu (Samoa americanas)',
        'en_AT' => 'inglesu (Àustria)',
        'en_AU' => 'inglesu (Austràlia)',
        'en_BB' => 'inglesu (Barbados)',
        'en_BE' => 'inglesu (Bèlgiu)',
        'en_BI' => 'inglesu (Burundi)',
        'en_BM' => 'inglesu (Bermudas)',
        'en_BS' => 'inglesu (Bahamas)',
        'en_BW' => 'inglesu (Botswana)',
        'en_BZ' => 'inglesu (Belize)',
        'en_CA' => 'inglesu (Cànada)',
        'en_CC' => 'inglesu (Ìsulas Cocos [Keeling])',
        'en_CH' => 'inglesu (Isvìtzera)',
        'en_CK' => 'inglesu (Ìsulas Cook)',
        'en_CM' => 'inglesu (Camerùn)',
        'en_CX' => 'inglesu (Ìsula de sa Natividade)',
        'en_CY' => 'inglesu (Tzipru)',
        'en_DE' => 'inglesu (Germània)',
        'en_DK' => 'inglesu (Danimarca)',
        'en_DM' => 'inglesu (Dominica)',
        'en_ER' => 'inglesu (Eritrea)',
        'en_FI' => 'inglesu (Finlàndia)',
        'en_FJ' => 'inglesu (Fiji)',
        'en_FK' => 'inglesu (Ìsulas Falkland)',
        'en_FM' => 'inglesu (Micronèsia)',
        'en_GB' => 'inglesu (Regnu Unidu)',
        'en_GD' => 'inglesu (Grenada)',
        'en_GG' => 'inglesu (Guernsey)',
        'en_GH' => 'inglesu (Ghana)',
        'en_GI' => 'inglesu (Gibilterra)',
        'en_GM' => 'inglesu (Gàmbia)',
        'en_GU' => 'inglesu (Guàm)',
        'en_GY' => 'inglesu (Guyana)',
        'en_HK' => 'inglesu (RAS tzinesa de Hong Kong)',
        'en_IE' => 'inglesu (Irlanda)',
        'en_IL' => 'inglesu (Israele)',
        'en_IM' => 'inglesu (Ìsula de Man)',
        'en_IN' => 'inglesu (Ìndia)',
        'en_IO' => 'inglesu (Territòriu Britànnicu de s’Otzèanu Indianu)',
        'en_JE' => 'inglesu (Jersey)',
        'en_JM' => 'inglesu (Giamàica)',
        'en_KE' => 'inglesu (Kènya)',
        'en_KI' => 'inglesu (Kiribati)',
        'en_KN' => 'inglesu (Santu Cristolu e Nevis)',
        'en_KY' => 'inglesu (Ìsulas Cayman)',
        'en_LC' => 'inglesu (Santa Lughia)',
        'en_LR' => 'inglesu (Libèria)',
        'en_LS' => 'inglesu (Lesotho)',
        'en_MG' => 'inglesu (Madagascàr)',
        'en_MH' => 'inglesu (Ìsulas Marshall)',
        'en_MO' => 'inglesu (RAS tzinesa de Macao)',
        'en_MP' => 'inglesu (Ìsulas Mariannas setentrionales)',
        'en_MS' => 'inglesu (Montserrat)',
        'en_MT' => 'inglesu (Malta)',
        'en_MU' => 'inglesu (Maurìtzius)',
        'en_MV' => 'inglesu (Maldivas)',
        'en_MW' => 'inglesu (Malawi)',
        'en_MY' => 'inglesu (Malèsia)',
        'en_NA' => 'inglesu (Namìbia)',
        'en_NF' => 'inglesu (Ìsula Norfolk)',
        'en_NG' => 'inglesu (Nigèria)',
        'en_NL' => 'inglesu (Paisos Bassos)',
        'en_NR' => 'inglesu (Nauru)',
        'en_NU' => 'inglesu (Niue)',
        'en_NZ' => 'inglesu (Zelanda Noa)',
        'en_PG' => 'inglesu (Pàpua Guinea Noa)',
        'en_PH' => 'inglesu (Filipinas)',
        'en_PK' => 'inglesu (Pàkistan)',
        'en_PN' => 'inglesu (Ìsulas Pìtcairn)',
        'en_PR' => 'inglesu (Puerto Rico)',
        'en_PW' => 'inglesu (Palau)',
        'en_RW' => 'inglesu (Ruanda)',
        'en_SB' => 'inglesu (Ìsulas Salomone)',
        'en_SC' => 'inglesu (Seychelles)',
        'en_SD' => 'inglesu (Sudàn)',
        'en_SE' => 'inglesu (Isvètzia)',
        'en_SG' => 'inglesu (Singapore)',
        'en_SH' => 'inglesu (Santa Elene)',
        'en_SI' => 'inglesu (Islovènia)',
        'en_SL' => 'inglesu (Sierra Leone)',
        'en_SS' => 'inglesu (Sudan de su Sud)',
        'en_SX' => 'inglesu (Sint Maarten)',
        'en_SZ' => 'inglesu (Eswatini)',
        'en_TC' => 'inglesu (Ìsulas Turks e Caicos)',
        'en_TK' => 'inglesu (Tokelau)',
        'en_TO' => 'inglesu (Tonga)',
        'en_TT' => 'inglesu (Trinidad e Tobago)',
        'en_TV' => 'inglesu (Tuvalu)',
        'en_TZ' => 'inglesu (Tanzània)',
        'en_UG' => 'inglesu (Uganda)',
        'en_UM' => 'inglesu (Ìsulas perifèricas de sos Istados Unidos)',
        'en_US' => 'inglesu (Istados Unidos)',
        'en_VC' => 'inglesu (Santu Vissente e sas Grenadinas)',
        'en_VG' => 'inglesu (Ìsulas Vèrgines Britànnicas)',
        'en_VI' => 'inglesu (Ìsulas Vèrgines de sos Istados Unidos)',
        'en_VU' => 'inglesu (Vanuatu)',
        'en_WS' => 'inglesu (Samoa)',
        'en_ZA' => 'inglesu (Sudàfrica)',
        'en_ZM' => 'inglesu (Zàmbia)',
        'en_ZW' => 'inglesu (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Mundu)',
        'es' => 'ispagnolu',
        'es_419' => 'ispagnolu (Amèrica latina)',
        'es_AR' => 'ispagnolu (Argentina)',
        'es_BO' => 'ispagnolu (Bolìvia)',
        'es_BR' => 'ispagnolu (Brasile)',
        'es_BZ' => 'ispagnolu (Belize)',
        'es_CL' => 'ispagnolu (Tzile)',
        'es_CO' => 'ispagnolu (Colòmbia)',
        'es_CR' => 'ispagnolu (Costa Rica)',
        'es_CU' => 'ispagnolu (Cuba)',
        'es_DO' => 'ispagnolu (Repùblica Dominicana)',
        'es_EC' => 'ispagnolu (Ècuador)',
        'es_ES' => 'ispagnolu (Ispagna)',
        'es_GQ' => 'ispagnolu (Guinea Ecuadoriale)',
        'es_GT' => 'ispagnolu (Guatemala)',
        'es_HN' => 'ispagnolu (Honduras)',
        'es_MX' => 'ispagnolu (Mèssicu)',
        'es_NI' => 'ispagnolu (Nicaràgua)',
        'es_PA' => 'ispagnolu (Pànama)',
        'es_PE' => 'ispagnolu (Perù)',
        'es_PH' => 'ispagnolu (Filipinas)',
        'es_PR' => 'ispagnolu (Puerto Rico)',
        'es_PY' => 'ispagnolu (Paraguày)',
        'es_SV' => 'ispagnolu (El Salvador)',
        'es_US' => 'ispagnolu (Istados Unidos)',
        'es_UY' => 'ispagnolu (Uruguày)',
        'es_VE' => 'ispagnolu (Venetzuela)',
        'et' => 'èstone',
        'et_EE' => 'èstone (Estònia)',
        'eu' => 'bascu',
        'eu_ES' => 'bascu (Ispagna)',
        'fa' => 'persianu',
        'fa_AF' => 'persianu (Afghànistan)',
        'fa_IR' => 'persianu (Iràn)',
        'ff' => 'fulah',
        'ff_Adlm' => 'fulah (adlam)',
        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulah (adlam, Camerùn)',
        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulah (adlam, Gàmbia)',
        'ff_Adlm_GN' => 'fulah (adlam, Guinea)',
        'ff_Adlm_GW' => 'fulah (adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulah (adlam, Libèria)',
        'ff_Adlm_MR' => 'fulah (adlam, Mauritània)',
        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
        'ff_Adlm_NG' => 'fulah (adlam, Nigèria)',
        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
        'ff_CM' => 'fulah (Camerùn)',
        'ff_GN' => 'fulah (Guinea)',
        'ff_Latn' => 'fulah (latinu)',
        'ff_Latn_BF' => 'fulah (latinu, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latinu, Camerùn)',
        'ff_Latn_GH' => 'fulah (latinu, Ghana)',
        'ff_Latn_GM' => 'fulah (latinu, Gàmbia)',
        'ff_Latn_GN' => 'fulah (latinu, Guinea)',
        'ff_Latn_GW' => 'fulah (latinu, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulah (latinu, Libèria)',
        'ff_Latn_MR' => 'fulah (latinu, Mauritània)',
        'ff_Latn_NE' => 'fulah (latinu, Niger)',
        'ff_Latn_NG' => 'fulah (latinu, Nigèria)',
        'ff_Latn_SL' => 'fulah (latinu, Sierra Leone)',
        'ff_Latn_SN' => 'fulah (latinu, Senegal)',
        'ff_MR' => 'fulah (Mauritània)',
        'ff_SN' => 'fulah (Senegal)',
        'fi' => 'finlandesu',
        'fi_FI' => 'finlandesu (Finlàndia)',
        'fo' => 'faroesu',
        'fo_DK' => 'faroesu (Danimarca)',
        'fo_FO' => 'faroesu (Ìsulas Føroyar)',
        'fr' => 'frantzesu',
        'fr_BE' => 'frantzesu (Bèlgiu)',
        'fr_BF' => 'frantzesu (Burkina Faso)',
        'fr_BI' => 'frantzesu (Burundi)',
        'fr_BJ' => 'frantzesu (Benin)',
        'fr_BL' => 'frantzesu (Santu Bartolomeu)',
        'fr_CA' => 'frantzesu (Cànada)',
        'fr_CD' => 'frantzesu (Congo - Kinshasa)',
        'fr_CF' => 'frantzesu (Repùblica Tzentrafricana)',
        'fr_CG' => 'frantzesu (Congo - Bratzaville)',
        'fr_CH' => 'frantzesu (Isvìtzera)',
        'fr_CI' => 'frantzesu (Costa de Avòriu)',
        'fr_CM' => 'frantzesu (Camerùn)',
        'fr_DJ' => 'frantzesu (Gibuti)',
        'fr_DZ' => 'frantzesu (Algeria)',
        'fr_FR' => 'frantzesu (Frantza)',
        'fr_GA' => 'frantzesu (Gabòn)',
        'fr_GF' => 'frantzesu (Guiana frantzesa)',
        'fr_GN' => 'frantzesu (Guinea)',
        'fr_GP' => 'frantzesu (Guadalupa)',
        'fr_GQ' => 'frantzesu (Guinea Ecuadoriale)',
        'fr_HT' => 'frantzesu (Haiti)',
        'fr_KM' => 'frantzesu (Comoras)',
        'fr_LU' => 'frantzesu (Lussemburgu)',
        'fr_MA' => 'frantzesu (Marocu)',
        'fr_MC' => 'frantzesu (Mònacu)',
        'fr_MF' => 'frantzesu (Santu Martine)',
        'fr_MG' => 'frantzesu (Madagascàr)',
        'fr_ML' => 'frantzesu (Mali)',
        'fr_MQ' => 'frantzesu (Martinica)',
        'fr_MR' => 'frantzesu (Mauritània)',
        'fr_MU' => 'frantzesu (Maurìtzius)',
        'fr_NC' => 'frantzesu (Caledònia Noa)',
        'fr_NE' => 'frantzesu (Niger)',
        'fr_PF' => 'frantzesu (Polinèsia frantzesa)',
        'fr_PM' => 'frantzesu (Santu Predu e Miquelon)',
        'fr_RE' => 'frantzesu (Riunione)',
        'fr_RW' => 'frantzesu (Ruanda)',
        'fr_SC' => 'frantzesu (Seychelles)',
        'fr_SN' => 'frantzesu (Senegal)',
        'fr_SY' => 'frantzesu (Sìria)',
        'fr_TD' => 'frantzesu (Chad)',
        'fr_TG' => 'frantzesu (Togo)',
        'fr_TN' => 'frantzesu (Tunisia)',
        'fr_VU' => 'frantzesu (Vanuatu)',
        'fr_WF' => 'frantzesu (Wallis e Futuna)',
        'fr_YT' => 'frantzesu (Mayotte)',
        'fy' => 'frisone otzidentale',
        'fy_NL' => 'frisone otzidentale (Paisos Bassos)',
        'ga' => 'irlandesu',
        'ga_GB' => 'irlandesu (Regnu Unidu)',
        'ga_IE' => 'irlandesu (Irlanda)',
        'gd' => 'gaèlicu iscotzesu',
        'gd_GB' => 'gaèlicu iscotzesu (Regnu Unidu)',
        'gl' => 'galitzianu',
        'gl_ES' => 'galitzianu (Ispagna)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (Ìndia)',
        'gv' => 'mannesu',
        'gv_IM' => 'mannesu (Ìsula de Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigèria)',
        'he' => 'ebreu',
        'he_IL' => 'ebreu (Israele)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Ìndia)',
        'hi_Latn' => 'hindi (latinu)',
        'hi_Latn_IN' => 'hindi (latinu, Ìndia)',
        'hr' => 'croatu',
        'hr_BA' => 'croatu (Bòsnia e Erzegòvina)',
        'hr_HR' => 'croatu (Croàtzia)',
        'hu' => 'ungheresu',
        'hu_HU' => 'ungheresu (Ungheria)',
        'hy' => 'armenu',
        'hy_AM' => 'armenu (Armènia)',
        'ia' => 'interlìngua',
        'ia_001' => 'interlìngua (Mundu)',
        'id' => 'indonesianu',
        'id_ID' => 'indonesianu (Indonèsia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigèria)',
        'ii' => 'sichuan yi',
        'ii_CN' => 'sichuan yi (Tzina)',
        'is' => 'islandesu',
        'is_IS' => 'islandesu (Islanda)',
        'it' => 'italianu',
        'it_CH' => 'italianu (Isvìtzera)',
        'it_IT' => 'italianu (Itàlia)',
        'it_SM' => 'italianu (Santu Marinu)',
        'it_VA' => 'italianu (Tzitade de su Vaticanu)',
        'ja' => 'giaponesu',
        'ja_JP' => 'giaponesu (Giapone)',
        'jv' => 'giavanesu',
        'jv_ID' => 'giavanesu (Indonèsia)',
        'ka' => 'georgianu',
        'ka_GE' => 'georgianu (Geòrgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kènya)',
        'kk' => 'kazacu',
        'kk_KZ' => 'kazacu (Kazàkistan)',
        'kl' => 'groenlandesu',
        'kl_GL' => 'groenlandesu (Groenlàndia)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Cambòdia)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Ìndia)',
        'ko' => 'coreanu',
        'ko_KP' => 'coreanu (Corea de su Nord)',
        'ko_KR' => 'coreanu (Corea de su Sud)',
        'ks' => 'kashmiri',
        'ks_Arab' => 'kashmiri (àrabu)',
        'ks_Arab_IN' => 'kashmiri (àrabu, Ìndia)',
        'ks_Deva' => 'kashmiri (devanagari)',
        'ks_Deva_IN' => 'kashmiri (devanagari, Ìndia)',
        'ks_IN' => 'kashmiri (Ìndia)',
        'ku' => 'curdu',
        'ku_TR' => 'curdu (Turchia)',
        'kw' => 'còrnicu',
        'kw_GB' => 'còrnicu (Regnu Unidu)',
        'ky' => 'chirghisu',
        'ky_KG' => 'chirghisu (Kirghìzistan)',
        'lb' => 'lussemburghesu',
        'lb_LU' => 'lussemburghesu (Lussemburgu)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo - Kinshasa)',
        'ln_CF' => 'lingala (Repùblica Tzentrafricana)',
        'ln_CG' => 'lingala (Congo - Bratzaville)',
        'lo' => 'laotianu',
        'lo_LA' => 'laotianu (Laos)',
        'lt' => 'lituanu',
        'lt_LT' => 'lituanu (Lituània)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Congo - Kinshasa)',
        'lv' => 'lètone',
        'lv_LV' => 'lètone (Letònia)',
        'mg' => 'malgàsciu',
        'mg_MG' => 'malgàsciu (Madagascàr)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Zelanda Noa)',
        'mk' => 'matzèdone',
        'mk_MK' => 'matzèdone (Matzedònia de su Nord)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (Ìndia)',
        'mn' => 'mòngolu',
        'mn_MN' => 'mòngolu (Mongòlia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (Ìndia)',
        'ms' => 'malesu',
        'ms_BN' => 'malesu (Brunei)',
        'ms_ID' => 'malesu (Indonèsia)',
        'ms_MY' => 'malesu (Malèsia)',
        'ms_SG' => 'malesu (Singapore)',
        'mt' => 'maltesu',
        'mt_MT' => 'maltesu (Malta)',
        'my' => 'burmesu',
        'my_MM' => 'burmesu (Myanmàr [Birmània])',
        'nb' => 'norvegesu bokmål',
        'nb_NO' => 'norvegesu bokmål (Norvègia)',
        'nb_SJ' => 'norvegesu bokmål (Svalbard e Jan Mayen)',
        'nd' => 'ndebele de su nord',
        'nd_ZW' => 'ndebele de su nord (Zimbabwe)',
        'ne' => 'nepalesu',
        'ne_IN' => 'nepalesu (Ìndia)',
        'ne_NP' => 'nepalesu (Nèpal)',
        'nl' => 'olandesu',
        'nl_AW' => 'olandesu (Aruba)',
        'nl_BE' => 'olandesu (Bèlgiu)',
        'nl_BQ' => 'olandesu (Caràibes olandesas)',
        'nl_CW' => 'olandesu (Curaçao)',
        'nl_NL' => 'olandesu (Paisos Bassos)',
        'nl_SR' => 'olandesu (Suriname)',
        'nl_SX' => 'olandesu (Sint Maarten)',
        'nn' => 'norvegesu nynorsk',
        'nn_NO' => 'norvegesu nynorsk (Norvègia)',
        'no' => 'norvegesu',
        'no_NO' => 'norvegesu (Norvègia)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiòpia)',
        'om_KE' => 'oromo (Kènya)',
        'or' => 'odia',
        'or_IN' => 'odia (Ìndia)',
        'os' => 'ossèticu',
        'os_GE' => 'ossèticu (Geòrgia)',
        'os_RU' => 'ossèticu (Rùssia)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (àrabu)',
        'pa_Arab_PK' => 'punjabi (àrabu, Pàkistan)',
        'pa_Guru' => 'punjabi (gurmukhi)',
        'pa_Guru_IN' => 'punjabi (gurmukhi, Ìndia)',
        'pa_IN' => 'punjabi (Ìndia)',
        'pa_PK' => 'punjabi (Pàkistan)',
        'pl' => 'polacu',
        'pl_PL' => 'polacu (Polònia)',
        'ps' => 'pashto',
        'ps_AF' => 'pashto (Afghànistan)',
        'ps_PK' => 'pashto (Pàkistan)',
        'pt' => 'portoghesu',
        'pt_AO' => 'portoghesu (Angola)',
        'pt_BR' => 'portoghesu (Brasile)',
        'pt_CH' => 'portoghesu (Isvìtzera)',
        'pt_CV' => 'portoghesu (Cabu birde)',
        'pt_GQ' => 'portoghesu (Guinea Ecuadoriale)',
        'pt_GW' => 'portoghesu (Guinea-Bissau)',
        'pt_LU' => 'portoghesu (Lussemburgu)',
        'pt_MO' => 'portoghesu (RAS tzinesa de Macao)',
        'pt_MZ' => 'portoghesu (Mozambicu)',
        'pt_PT' => 'portoghesu (Portogallu)',
        'pt_ST' => 'portoghesu (São Tomé e Príncipe)',
        'pt_TL' => 'portoghesu (Timor-Est)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolìvia)',
        'qu_EC' => 'quechua (Ècuador)',
        'qu_PE' => 'quechua (Perù)',
        'rm' => 'romànciu',
        'rm_CH' => 'romànciu (Isvìtzera)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumenu',
        'ro_MD' => 'rumenu (Moldàvia)',
        'ro_RO' => 'rumenu (Romania)',
        'ru' => 'russu',
        'ru_BY' => 'russu (Bielorùssia)',
        'ru_KG' => 'russu (Kirghìzistan)',
        'ru_KZ' => 'russu (Kazàkistan)',
        'ru_MD' => 'russu (Moldàvia)',
        'ru_RU' => 'russu (Rùssia)',
        'ru_UA' => 'russu (Ucraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Ruanda)',
        'sa' => 'sànscritu',
        'sa_IN' => 'sànscritu (Ìndia)',
        'sc' => 'sardu',
        'sc_IT' => 'sardu (Itàlia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (àrabu)',
        'sd_Arab_PK' => 'sindhi (àrabu, Pàkistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, Ìndia)',
        'sd_IN' => 'sindhi (Ìndia)',
        'sd_PK' => 'sindhi (Pàkistan)',
        'se' => 'sami setentrionale',
        'se_FI' => 'sami setentrionale (Finlàndia)',
        'se_NO' => 'sami setentrionale (Norvègia)',
        'se_SE' => 'sami setentrionale (Isvètzia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Repùblica Tzentrafricana)',
        'si' => 'singalesu',
        'si_LK' => 'singalesu (Sri Lanka)',
        'sk' => 'islovacu',
        'sk_SK' => 'islovacu (Islovàchia)',
        'sl' => 'islovenu',
        'sl_SI' => 'islovenu (Islovènia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'sòmalu',
        'so_DJ' => 'sòmalu (Gibuti)',
        'so_ET' => 'sòmalu (Etiòpia)',
        'so_KE' => 'sòmalu (Kènya)',
        'so_SO' => 'sòmalu (Somàlia)',
        'sq' => 'albanesu',
        'sq_AL' => 'albanesu (Albania)',
        'sq_MK' => 'albanesu (Matzedònia de su Nord)',
        'sr' => 'serbu',
        'sr_BA' => 'serbu (Bòsnia e Erzegòvina)',
        'sr_Cyrl' => 'serbu (tzirìllicu)',
        'sr_Cyrl_BA' => 'serbu (tzirìllicu, Bòsnia e Erzegòvina)',
        'sr_Cyrl_ME' => 'serbu (tzirìllicu, Montenegro)',
        'sr_Cyrl_RS' => 'serbu (tzirìllicu, Sèrbia)',
        'sr_Latn' => 'serbu (latinu)',
        'sr_Latn_BA' => 'serbu (latinu, Bòsnia e Erzegòvina)',
        'sr_Latn_ME' => 'serbu (latinu, Montenegro)',
        'sr_Latn_RS' => 'serbu (latinu, Sèrbia)',
        'sr_ME' => 'serbu (Montenegro)',
        'sr_RS' => 'serbu (Sèrbia)',
        'su' => 'sundanesu',
        'su_ID' => 'sundanesu (Indonèsia)',
        'su_Latn' => 'sundanesu (latinu)',
        'su_Latn_ID' => 'sundanesu (latinu, Indonèsia)',
        'sv' => 'isvedesu',
        'sv_AX' => 'isvedesu (Ìsulas Åland)',
        'sv_FI' => 'isvedesu (Finlàndia)',
        'sv_SE' => 'isvedesu (Isvètzia)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Congo - Kinshasa)',
        'sw_KE' => 'swahili (Kènya)',
        'sw_TZ' => 'swahili (Tanzània)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (Ìndia)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malèsia)',
        'ta_SG' => 'tamil (Singapore)',
        'te' => 'telugu',
        'te_IN' => 'telugu (Ìndia)',
        'tg' => 'tagicu',
        'tg_TJ' => 'tagicu (Tagìkistan)',
        'th' => 'tailandesu',
        'th_TH' => 'tailandesu (Tailàndia)',
        'ti' => 'tigrignu',
        'ti_ER' => 'tigrignu (Eritrea)',
        'ti_ET' => 'tigrignu (Etiòpia)',
        'tk' => 'turcmenu',
        'tk_TM' => 'turcmenu (Turkmènistan)',
        'to' => 'tonganu',
        'to_TO' => 'tonganu (Tonga)',
        'tr' => 'turcu',
        'tr_CY' => 'turcu (Tzipru)',
        'tr_TR' => 'turcu (Turchia)',
        'tt' => 'tàtaru',
        'tt_RU' => 'tàtaru (Rùssia)',
        'ug' => 'uiguru',
        'ug_CN' => 'uiguru (Tzina)',
        'uk' => 'ucrainu',
        'uk_UA' => 'ucrainu (Ucraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Ìndia)',
        'ur_PK' => 'urdu (Pàkistan)',
        'uz' => 'uzbecu',
        'uz_AF' => 'uzbecu (Afghànistan)',
        'uz_Arab' => 'uzbecu (àrabu)',
        'uz_Arab_AF' => 'uzbecu (àrabu, Afghànistan)',
        'uz_Cyrl' => 'uzbecu (tzirìllicu)',
        'uz_Cyrl_UZ' => 'uzbecu (tzirìllicu, Uzbèkistan)',
        'uz_Latn' => 'uzbecu (latinu)',
        'uz_Latn_UZ' => 'uzbecu (latinu, Uzbèkistan)',
        'uz_UZ' => 'uzbecu (Uzbèkistan)',
        'vi' => 'vietnamita',
        'vi_VN' => 'vietnamita (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Sudàfrica)',
        'yi' => 'yiddish',
        'yi_001' => 'yiddish (Mundu)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigèria)',
        'zh' => 'tzinesu',
        'zh_CN' => 'tzinesu (Tzina)',
        'zh_HK' => 'tzinesu (RAS tzinesa de Hong Kong)',
        'zh_Hans' => 'tzinesu (semplificadu)',
        'zh_Hans_CN' => 'tzinesu (semplificadu, Tzina)',
        'zh_Hans_HK' => 'tzinesu (semplificadu, RAS tzinesa de Hong Kong)',
        'zh_Hans_MO' => 'tzinesu (semplificadu, RAS tzinesa de Macao)',
        'zh_Hans_SG' => 'tzinesu (semplificadu, Singapore)',
        'zh_Hant' => 'tzinesu (traditzionale)',
        'zh_Hant_HK' => 'tzinesu (traditzionale, RAS tzinesa de Hong Kong)',
        'zh_Hant_MO' => 'tzinesu (traditzionale, RAS tzinesa de Macao)',
        'zh_Hant_TW' => 'tzinesu (traditzionale, Taiwàn)',
        'zh_MO' => 'tzinesu (RAS tzinesa de Macao)',
        'zh_SG' => 'tzinesu (Singapore)',
        'zh_TW' => 'tzinesu (Taiwàn)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Sudàfrica)',
    ],
];
