<?php

return [
    'Names' => [
        'ab' => 'ኣብካዝኛ',
        'ace' => 'ኣቸኒዝኛ',
        'ada' => 'ኣዳንግሜ',
        'ady' => 'ኣዲጊ',
        'af' => 'ኣፍሪካንስ',
        'agq' => 'ኣገም',
        'ain' => 'ኣይኑ',
        'ak' => 'ኣካን',
        'ale' => 'ኣለውትኛ',
        'alt' => 'ደቡባዊ ኣልታይ',
        'am' => 'ኣምሓርኛ',
        'an' => 'ኣራጎንኛ',
        'ann' => 'ኦቦሎ',
        'anp' => 'ኣንጂካ',
        'ar' => 'ዓረብ',
        'arn' => 'ማፑቺ',
        'arp' => 'ኣራፓሆ',
        'ars' => 'ናጅዲ ዓረብኛ',
        'as' => 'ኣሳሜዝኛ',
        'asa' => 'ኣሱ',
        'ast' => 'ኣስቱርያን',
        'atj' => 'ኣቲካመክ',
        'av' => 'ኣቫር',
        'awa' => 'ኣዋዲ',
        'ay' => 'ኣይማራ',
        'az' => 'ኣዘርባጃንኛ',
        'ba' => 'ባሽኪር',
        'ban' => 'ባሊንኛ',
        'bas' => 'ባሳ',
        'be' => 'ቤላሩስኛ',
        'bem' => 'ቤምባ',
        'bez' => 'በና',
        'bg' => 'ቡልጋርኛ',
        'bho' => 'ቦጅፑሪ',
        'bi' => 'ቢስላማ',
        'bin' => 'ቢኒ',
        'bla' => 'ሲክሲካ',
        'bm' => 'ባምባራ',
        'bn' => 'በንጋሊ',
        'bo' => 'ቲበታንኛ',
        'br' => 'ብረቶንኛ',
        'brx' => 'ቦዶ',
        'bs' => 'ቦዝንኛ',
        'bug' => 'ቡጊንኛ',
        'byn' => 'ብሊን',
        'ca' => 'ካታላን',
        'cay' => 'ካዩጋ',
        'ccp' => 'ቻክማ',
        'ce' => 'ቸቸንይና',
        'ceb' => 'ሰብዋኖ',
        'cgg' => 'ቺጋ',
        'ch' => 'ቻሞሮ',
        'chk' => 'ቹኪዝኛ',
        'chm' => 'ማሪ',
        'cho' => 'ቾክቶ',
        'chp' => 'ቺፐውያን',
        'chr' => 'ቸሮኪ',
        'chy' => 'ሻያን',
        'ckb' => 'ሶራኒ ኩርዲሽ',
        'clc' => 'ቺልኮቲን',
        'co' => 'ኮርስኛ',
        'crg' => 'ሚቺፍ',
        'crj' => 'ደቡባዊ ምብራቕ ክሪ',
        'crk' => 'ክሪ ፕሌንስ',
        'crl' => 'ሰሜናዊ ምብራቕ ክሪ',
        'crm' => 'ሙስ ክሪ',
        'crr' => 'ካቶሊና አልጎንጉያኛ',
        'cs' => 'ቸክኛ',
        'csw' => 'ክሪ ረግረግ',
        'cu' => 'ቤተ-ክርስትያን ስላቭኛ',
        'cv' => 'ቹቫሽኛ',
        'cy' => 'ዌልስኛ',
        'da' => 'ዳኒሽ',
        'dak' => 'ዳኮታ',
        'dar' => 'ዳርግዋ',
        'dav' => 'ታይታ',
        'de' => 'ጀርመን',
        'dgr' => 'ዶግሪብ',
        'dje' => 'ዛርማ',
        'doi' => 'ዶግሪ',
        'dsb' => 'ታሕተዋይ ሶርብኛ',
        'dua' => 'ድዋላ',
        'dv' => 'ዲቨሂ',
        'dyo' => 'ጆላ-ፎኒይ',
        'dz' => 'ድዞንግካ',
        'dzg' => 'ዳዛጋ',
        'ebu' => 'ኤምቡ',
        'ee' => 'ኢው',
        'efi' => 'ኤፊክ',
        'eka' => 'ኤካጁክ',
        'el' => 'ግሪኽኛ',
        'en' => 'እንግሊዝኛ',
        'eo' => 'ኤስፐራንቶ',
        'es' => 'ስጳንኛ',
        'et' => 'ኤስቶንኛ',
        'eu' => 'ባስክኛ',
        'ewo' => 'ኤዎንዶ',
        'fa' => 'ፋርስኛ',
        'ff' => 'ፉላ',
        'fi' => 'ፊንላንድኛ',
        'fil' => 'ፊሊፒንኛ',
        'fj' => 'ፊጅያንኛ',
        'fo' => 'ፋሮእይና',
        'fon' => 'ፎን',
        'fr' => 'ፈረንሳይኛ',
        'frc' => 'ካጁን ፈረንሳይ',
        'frr' => 'ሰሜናዊ ፍሪስኛ',
        'fur' => 'ፍርዩልኛ',
        'fy' => 'ምዕራባዊ ፍሪስኛ',
        'ga' => 'ኣየርላንድኛ',
        'gaa' => 'ጋ',
        'gd' => 'ስኮትላንዳዊ ጋኤሊክኛ',
        'gez' => 'ግእዝ',
        'gil' => 'ጊልበርትኛ',
        'gl' => 'ጋሊሽያን',
        'gn' => 'ጓራኒ',
        'gor' => 'ጎሮንታሎ',
        'gsw' => 'ስዊዘርላንዳዊ ጀርመን',
        'gu' => 'ጉጃራቲ',
        'guz' => 'ጉሲ',
        'gv' => 'ማንክስ',
        'gwi' => 'ጒቺን',
        'ha' => 'ሃውሳ',
        'hai' => 'ሃይዳ',
        'haw' => 'ሃዋይኛ',
        'hax' => 'ደቡባዊ ሃይዳ',
        'he' => 'እብራይስጢ',
        'hi' => 'ሂንዲ',
        'hil' => 'ሂሊጋይኖን',
        'hmn' => 'ህሞንግ',
        'hr' => 'ክሮኤሽያን',
        'hsb' => 'ላዕለዋይ ሶርብኛ',
        'ht' => 'ክርዮል ሃይትኛ',
        'hu' => 'ሃንጋርኛ',
        'hup' => 'ሁፓ',
        'hur' => 'ሃልኮመለም',
        'hy' => 'ኣርሜንኛ',
        'hz' => 'ሄረሮ',
        'ia' => 'ኢንተርሊንጓ',
        'iba' => 'ኢባን',
        'ibb' => 'ኢቢብዮ',
        'id' => 'ኢንዶነዥኛ',
        'ig' => 'ኢግቦ',
        'ii' => 'ሲችዋን ዪ',
        'ikt' => 'ምዕራባዊ ካናዳዊ ኢናክቲቱት',
        'ilo' => 'ኢሎካኖ',
        'inh' => 'ኢንጉሽኛ',
        'io' => 'ኢዶ',
        'is' => 'ኣይስላንድኛ',
        'it' => 'ጥልያን',
        'iu' => 'ኢናክቲቱት',
        'ja' => 'ጃፓንኛ',
        'jbo' => 'ሎጅባን',
        'jgo' => 'ኤንጎምባ',
        'jmc' => 'ማኬም',
        'jv' => 'ጃቫንኛ',
        'ka' => 'ጆርጅያንኛ',
        'kab' => 'ካቢልኛ',
        'kac' => 'ካቺን',
        'kaj' => 'ጅጁ',
        'kam' => 'ካምባ',
        'kbd' => 'ካባርድኛ',
        'kcg' => 'ታያፕ',
        'kde' => 'ማኮንደ',
        'kea' => 'ክርዮል ኬፕ ቨርድኛ',
        'kfo' => 'ኮሮ',
        'kgp' => 'ካይንጋንግ',
        'kha' => 'ካሲ',
        'khq' => 'ኮይራ ቺኒ',
        'ki' => 'ኪኩዩ',
        'kj' => 'ክዋንያማ',
        'kk' => 'ካዛክ',
        'kkj' => 'ካኮ',
        'kl' => 'ግሪንላንድኛ',
        'kln' => 'ካለንጂን',
        'km' => 'ክመር',
        'kmb' => 'ኪምቡንዱ',
        'kn' => 'ካንናዳ',
        'ko' => 'ኮርይኛ',
        'kok' => 'ኮንካኒ',
        'kpe' => 'ክፐለ',
        'kr' => 'ካኑሪ',
        'krc' => 'ካራቻይ-ባልካርኛ',
        'krl' => 'ካረልኛ',
        'kru' => 'ኩሩክ',
        'ks' => 'ካሽሚሪ',
        'ksb' => 'ሻምባላ',
        'ksf' => 'ባፍያ',
        'ksh' => 'ኮልሽ',
        'ku' => 'ኩርዲሽ',
        'kum' => 'ኩሚይክ',
        'kv' => 'ኮሚ',
        'kw' => 'ኮርንኛ',
        'kwk' => 'ክዋክዋላ',
        'ky' => 'ኪርጊዝኛ',
        'la' => 'ላቲን',
        'lad' => 'ላዲኖ',
        'lag' => 'ላንጊ',
        'lb' => 'ሉክሰምበርግኛ',
        'lez' => 'ለዝግኛ',
        'lg' => 'ጋንዳ',
        'li' => 'ሊምበርግኛ',
        'lij' => 'ሊጉርኛ',
        'lil' => 'ሊሉት',
        'lkt' => 'ላኮታ',
        'ln' => 'ሊንጋላ',
        'lo' => 'ላኦ',
        'lou' => 'ክርዮል ሉዊዝያና',
        'loz' => 'ሎዚ',
        'lrc' => 'ሰሜናዊ ሉሪ',
        'lsm' => 'ሳምያ',
        'lt' => 'ሊትዌንኛ',
        'lu' => 'ሉባ-ካታንጋ',
        'lua' => 'ሉባ-ሉልዋ',
        'lun' => 'ሉንዳ',
        'luo' => 'ሉኦ',
        'lus' => 'ማይዞ',
        'luy' => 'ሉይያ',
        'lv' => 'ላትቭኛ',
        'mad' => 'ማዱሪዝኛ',
        'mag' => 'ማጋሂ',
        'mai' => 'ማይቲሊ',
        'mak' => 'ማካሳር',
        'mas' => 'ማሳይ',
        'mdf' => 'ሞክሻ',
        'men' => 'መንዴ',
        'mer' => 'መሩ',
        'mfe' => 'ክርዮል ማውሪሽይና',
        'mg' => 'ማላጋሲ',
        'mgh' => 'ማክዋ-ሜቶ',
        'mgo' => 'መታ',
        'mh' => 'ማርሻሊዝኛ',
        'mi' => 'ማኦሪ',
        'mic' => 'ሚክማክ',
        'min' => 'ሚናንግካባው',
        'mk' => 'መቄዶንኛ',
        'ml' => 'ማላያላም',
        'mn' => 'ሞንጎልኛ',
        'mni' => 'ማኒፑሪ',
        'moe' => 'ኢኑ-ኤመን',
        'moh' => 'ሞሃውክ',
        'mos' => 'ሞሲ',
        'mr' => 'ማራቲ',
        'ms' => 'ማላይኛ',
        'mt' => 'ማልትኛ',
        'mua' => 'ሙንዳንግ',
        'mus' => 'ክሪክ',
        'mwl' => 'ሚራንዲዝኛ',
        'my' => 'በርምኛ',
        'myv' => 'ኤርዝያ',
        'mzn' => 'ማዛንደራኒ',
        'na' => 'ናውርዋንኛ',
        'nap' => 'ናፖሊታንኛ',
        'naq' => 'ናማ',
        'nb' => 'ኖርወያዊ ቦክማል',
        'nd' => 'ሰሜን ኤንደበለ',
        'nds' => 'ትሑት ጀርመን',
        'ne' => 'ኔፓሊ',
        'new' => 'ነዋሪ',
        'ng' => 'ኤንዶንጋ',
        'nia' => 'ንያስ',
        'niu' => 'ንዌንኛ',
        'nl' => 'ዳች',
        'nmg' => 'ክዋስዮ',
        'nn' => 'ኖርወያዊ ናይኖርስክ',
        'nnh' => 'ኤንጌምቡን',
        'no' => 'ኖርወይኛ',
        'nog' => 'ኖጋይኛ',
        'nqo' => 'ኤንኮ',
        'nr' => 'ደቡብ ኤንደበለ',
        'nso' => 'ሰሜናዊ ሶቶ',
        'nus' => 'ንዌር',
        'nv' => 'ናቫሆ',
        'ny' => 'ንያንጃ',
        'nyn' => 'ንያንኮል',
        'oc' => 'ኦክሲታንኛ',
        'ojb' => 'ሰሜናዊ ምዕራብ ኦጂብዋ',
        'ojc' => 'ማእከላይ ኦጂብዋ',
        'ojs' => 'ኦጂ-ክሪ',
        'ojw' => 'ምዕራባዊ ኦጂብዋ',
        'oka' => 'ኦካናጋን',
        'om' => 'ኦሮሞ',
        'or' => 'ኦድያ',
        'os' => 'ኦሰትኛ',
        'pa' => 'ፑንጃቢ',
        'pag' => 'ፓንጋሲናን',
        'pam' => 'ፓምፓንጋ',
        'pap' => 'ፓፕያመንቶ',
        'pau' => 'ፓላውኛ',
        'pcm' => 'ፒጂን ናይጀርያ',
        'pis' => 'ፒጂን',
        'pl' => 'ፖሊሽ',
        'pqm' => 'ማሊሲት-ፓሳማኳዲ',
        'prg' => 'ፕሩስኛ',
        'ps' => 'ፓሽቶ',
        'pt' => 'ፖርቱጊዝኛ',
        'qu' => 'ቀችዋ',
        'rap' => 'ራፓኑይ',
        'rar' => 'ራሮቶንጋንኛ',
        'rhg' => 'ሮሂንግያ',
        'rm' => 'ሮማንሽ',
        'rn' => 'ኪሩንዲ',
        'ro' => 'ሩማንኛ',
        'rof' => 'ሮምቦ',
        'ru' => 'ሩስኛ',
        'rup' => 'ኣሩማንኛ',
        'rw' => 'ኪንያርዋንዳ',
        'rwk' => 'ርዋ',
        'sa' => 'ሳንስክሪት',
        'sad' => 'ሳንዳወ',
        'sah' => 'ሳኻ',
        'saq' => 'ሳምቡሩ',
        'sat' => 'ሳንታሊ',
        'sba' => 'ኤንጋምባይ',
        'sbp' => 'ሳንጉ',
        'sc' => 'ሳርዲንኛ',
        'scn' => 'ሲሲልኛ',
        'sco' => 'ስኮትኛ',
        'sd' => 'ሲንድሂ',
        'se' => 'ሰሜናዊ ሳሚ',
        'seh' => 'ሰና',
        'ses' => 'ኮይራቦሮ ሰኒ',
        'sg' => 'ሳንጎ',
        'sh' => 'ሰርቦ-ክሮኤሽያን',
        'shi' => 'ታቸልሂት',
        'shn' => 'ሻን',
        'si' => 'ሲንሃላ',
        'sk' => 'ስሎቫክኛ',
        'sl' => 'ስሎቬንኛ',
        'slh' => 'ደቡባዊ ሉሹትሲድ',
        'sm' => 'ሳሞእኛ',
        'smn' => 'ሳሚ ኢናሪ',
        'sms' => 'ሳሚ ስኮልት',
        'sn' => 'ሾና',
        'snk' => 'ሶኒንከ',
        'so' => 'ሶማሊ',
        'sq' => 'ኣልባንኛ',
        'sr' => 'ቃንቃ ሰርቢያ',
        'srn' => 'ስራናን ቶንጎ',
        'ss' => 'ስዋዚ',
        'st' => 'ደቡባዊ ሶቶ',
        'str' => 'ሳሊሽ መጻብቦታት',
        'su' => 'ሱንዳንኛ',
        'suk' => 'ሱኩማ',
        'sv' => 'ስዊድንኛ',
        'sw' => 'ስዋሂሊ',
        'swb' => 'ኮሞርኛ',
        'syr' => 'ሱርስት',
        'ta' => 'ታሚል',
        'tce' => 'ደቡባዊ ታትቾን',
        'te' => 'ተሉጉ',
        'tem' => 'ቲምኔ',
        'teo' => 'ተሶ',
        'tet' => 'ቲተም',
        'tg' => 'ታጂክኛ',
        'tgx' => 'ታጊሽ',
        'th' => 'ታይኛ',
        'tht' => 'ታልተን',
        'ti' => 'ትግርኛ',
        'tig' => 'ትግረ',
        'tk' => 'ቱርክመንኛ',
        'tlh' => 'ክሊንጎን',
        'tli' => 'ትሊንጊት',
        'tn' => 'ስዋና',
        'to' => 'ቶንጋንኛ',
        'tok' => 'ቶኪ ፖና',
        'tpi' => 'ቶክ ፒሲን',
        'tr' => 'ቱርክኛ',
        'trv' => 'ታሮኮ',
        'ts' => 'ሶንጋ',
        'tt' => 'ታታር',
        'ttm' => 'ሰሜናዊ ታትቾን',
        'tum' => 'ተምቡካ',
        'tvl' => 'ቱቫልዋንኛ',
        'tw' => 'ትዊ',
        'twq' => 'ታሳዋቅ',
        'ty' => 'ታሂትኛ',
        'tyv' => 'ቱቪንኛ',
        'tzm' => 'ማእከላይ ኣትላስ ታማዛይት',
        'udm' => 'ዩድሙርት',
        'ug' => 'ኡይጉር',
        'uk' => 'ዩክረይንኛ',
        'umb' => 'ኣምቡንዱ',
        'ur' => 'ኡርዱ',
        'uz' => 'ኡዝበክኛ',
        'vai' => 'ቫይ',
        've' => 'ቨንዳ',
        'vec' => 'ቬንቲያንኛ',
        'vi' => 'ቬትናምኛ',
        'vo' => 'ቮላፑክ',
        'vun' => 'ቩንጆ',
        'wa' => 'ዋሎን',
        'wae' => 'ዋልሰር',
        'wal' => 'ዎላይታኛ',
        'war' => 'ዋራይ',
        'wo' => 'ዎሎፍ',
        'wuu' => 'ቻይናዊ ዉ',
        'xal' => 'ካልምይክ',
        'xh' => 'ኮሳ',
        'xog' => 'ሶጋ',
        'yav' => 'ያንግበን',
        'ybb' => 'የምባ',
        'yi' => 'ይሁድኛ',
        'yo' => 'ዮሩባ',
        'yrl' => 'ኒንጋቱ',
        'yue' => 'ካንቶንኛ',
        'zgh' => 'ሞሮካዊ ምዱብ ታማዛይት',
        'zh' => 'ቻይንኛ',
        'zu' => 'ዙሉ',
        'zun' => 'ዙኚ',
        'zza' => 'ዛዛኪ',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ዘመናዊ ምዱብ ዓረብ',
        'en_US' => 'እንግሊዝኛ (ሕቡራት መንግስታት)',
        'fa_AF' => 'ዳሪ',
        'nds_NL' => 'ትሑት ሳክሰን',
        'nl_BE' => 'ፍላሚሽ',
        'ro_MD' => 'ሞልዶቨኛ',
        'sw_CD' => 'ስዋሂሊ (ኮንጎ)',
        'zh_Hans' => 'ቀሊል ቻይንኛ',
        'zh_Hant' => 'ባህላዊ ቻይንኛ',
    ],
];
