<?php

return [
    'Names' => [
        'af' => 'афрыкаанс',
        'af_NA' => 'афрыкаанс (Намібія)',
        'af_ZA' => 'афрыкаанс (Паўднёва-Афрыканская Рэспубліка)',
        'ak' => 'акан',
        'ak_GH' => 'акан (Гана)',
        'am' => 'амхарская',
        'am_ET' => 'амхарская (Эфіопія)',
        'ar' => 'арабская',
        'ar_001' => 'арабская (Свет)',
        'ar_AE' => 'арабская (Аб’яднаныя Арабскія Эміраты)',
        'ar_BH' => 'арабская (Бахрэйн)',
        'ar_DJ' => 'арабская (Джыбуці)',
        'ar_DZ' => 'арабская (Алжыр)',
        'ar_EG' => 'арабская (Егіпет)',
        'ar_EH' => 'арабская (Заходняя Сахара)',
        'ar_ER' => 'арабская (Эрытрэя)',
        'ar_IL' => 'арабская (Ізраіль)',
        'ar_IQ' => 'арабская (Ірак)',
        'ar_JO' => 'арабская (Іарданія)',
        'ar_KM' => 'арабская (Каморскія астравы)',
        'ar_KW' => 'арабская (Кувейт)',
        'ar_LB' => 'арабская (Ліван)',
        'ar_LY' => 'арабская (Лівія)',
        'ar_MA' => 'арабская (Марока)',
        'ar_MR' => 'арабская (Маўрытанія)',
        'ar_OM' => 'арабская (Аман)',
        'ar_PS' => 'арабская (Палесцінскія Тэрыторыі)',
        'ar_QA' => 'арабская (Катар)',
        'ar_SA' => 'арабская (Саудаўская Аравія)',
        'ar_SD' => 'арабская (Судан)',
        'ar_SO' => 'арабская (Самалі)',
        'ar_SS' => 'арабская (Паўднёвы Судан)',
        'ar_SY' => 'арабская (Сірыя)',
        'ar_TD' => 'арабская (Чад)',
        'ar_TN' => 'арабская (Туніс)',
        'ar_YE' => 'арабская (Емен)',
        'as' => 'асамская',
        'as_IN' => 'асамская (Індыя)',
        'az' => 'азербайджанская',
        'az_AZ' => 'азербайджанская (Азербайджан)',
        'az_Cyrl' => 'азербайджанская (кірыліца)',
        'az_Cyrl_AZ' => 'азербайджанская (кірыліца, Азербайджан)',
        'az_Latn' => 'азербайджанская (лацініца)',
        'az_Latn_AZ' => 'азербайджанская (лацініца, Азербайджан)',
        'be' => 'беларуская',
        'be_BY' => 'беларуская (Беларусь)',
        'bg' => 'балгарская',
        'bg_BG' => 'балгарская (Балгарыя)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Малі)',
        'bn' => 'бенгальская',
        'bn_BD' => 'бенгальская (Бангладэш)',
        'bn_IN' => 'бенгальская (Індыя)',
        'bo' => 'тыбецкая',
        'bo_CN' => 'тыбецкая (Кітай)',
        'bo_IN' => 'тыбецкая (Індыя)',
        'br' => 'брэтонская',
        'br_FR' => 'брэтонская (Францыя)',
        'bs' => 'баснійская',
        'bs_BA' => 'баснійская (Боснія і Герцагавіна)',
        'bs_Cyrl' => 'баснійская (кірыліца)',
        'bs_Cyrl_BA' => 'баснійская (кірыліца, Боснія і Герцагавіна)',
        'bs_Latn' => 'баснійская (лацініца)',
        'bs_Latn_BA' => 'баснійская (лацініца, Боснія і Герцагавіна)',
        'ca' => 'каталанская',
        'ca_AD' => 'каталанская (Андора)',
        'ca_ES' => 'каталанская (Іспанія)',
        'ca_FR' => 'каталанская (Францыя)',
        'ca_IT' => 'каталанская (Італія)',
        'ce' => 'чачэнская',
        'ce_RU' => 'чачэнская (Расія)',
        'cs' => 'чэшская',
        'cs_CZ' => 'чэшская (Чэхія)',
        'cv' => 'чувашская',
        'cv_RU' => 'чувашская (Расія)',
        'cy' => 'валійская',
        'cy_GB' => 'валійская (Вялікабрытанія)',
        'da' => 'дацкая',
        'da_DK' => 'дацкая (Данія)',
        'da_GL' => 'дацкая (Грэнландыя)',
        'de' => 'нямецкая',
        'de_AT' => 'нямецкая (Аўстрыя)',
        'de_BE' => 'нямецкая (Бельгія)',
        'de_CH' => 'нямецкая (Швейцарыя)',
        'de_DE' => 'нямецкая (Германія)',
        'de_IT' => 'нямецкая (Італія)',
        'de_LI' => 'нямецкая (Ліхтэнштэйн)',
        'de_LU' => 'нямецкая (Люксембург)',
        'dz' => 'дзонг-кэ',
        'dz_BT' => 'дзонг-кэ (Бутан)',
        'ee' => 'эве',
        'ee_GH' => 'эве (Гана)',
        'ee_TG' => 'эве (Тога)',
        'el' => 'грэчаская',
        'el_CY' => 'грэчаская (Кіпр)',
        'el_GR' => 'грэчаская (Грэцыя)',
        'en' => 'англійская',
        'en_001' => 'англійская (Свет)',
        'en_150' => 'англійская (Еўропа)',
        'en_AE' => 'англійская (Аб’яднаныя Арабскія Эміраты)',
        'en_AG' => 'англійская (Антыгуа і Барбуда)',
        'en_AI' => 'англійская (Ангілья)',
        'en_AS' => 'англійская (Амерыканскае Самоа)',
        'en_AT' => 'англійская (Аўстрыя)',
        'en_AU' => 'англійская (Аўстралія)',
        'en_BB' => 'англійская (Барбадас)',
        'en_BE' => 'англійская (Бельгія)',
        'en_BI' => 'англійская (Бурундзі)',
        'en_BM' => 'англійская (Бермудскія астравы)',
        'en_BS' => 'англійская (Багамскія астравы)',
        'en_BW' => 'англійская (Батсвана)',
        'en_BZ' => 'англійская (Беліз)',
        'en_CA' => 'англійская (Канада)',
        'en_CC' => 'англійская (Какосавыя [Кілінг] астравы)',
        'en_CH' => 'англійская (Швейцарыя)',
        'en_CK' => 'англійская (Астравы Кука)',
        'en_CM' => 'англійская (Камерун)',
        'en_CX' => 'англійская (Востраў Каляд)',
        'en_CY' => 'англійская (Кіпр)',
        'en_DE' => 'англійская (Германія)',
        'en_DK' => 'англійская (Данія)',
        'en_DM' => 'англійская (Дамініка)',
        'en_ER' => 'англійская (Эрытрэя)',
        'en_FI' => 'англійская (Фінляндыя)',
        'en_FJ' => 'англійская (Фіджы)',
        'en_FK' => 'англійская (Фалклендскія астравы)',
        'en_FM' => 'англійская (Мікранезія)',
        'en_GB' => 'англійская (Вялікабрытанія)',
        'en_GD' => 'англійская (Грэнада)',
        'en_GG' => 'англійская (Гернсі)',
        'en_GH' => 'англійская (Гана)',
        'en_GI' => 'англійская (Гібралтар)',
        'en_GM' => 'англійская (Гамбія)',
        'en_GU' => 'англійская (Гуам)',
        'en_GY' => 'англійская (Гаяна)',
        'en_HK' => 'англійская (Ганконг, САР [Кітай])',
        'en_IE' => 'англійская (Ірландыя)',
        'en_IL' => 'англійская (Ізраіль)',
        'en_IM' => 'англійская (Востраў Мэн)',
        'en_IN' => 'англійская (Індыя)',
        'en_IO' => 'англійская (Брытанская тэрыторыя ў Індыйскім акіяне)',
        'en_JE' => 'англійская (Джэрсі)',
        'en_JM' => 'англійская (Ямайка)',
        'en_KE' => 'англійская (Кенія)',
        'en_KI' => 'англійская (Кірыбаці)',
        'en_KN' => 'англійская (Сент-Кітс і Невіс)',
        'en_KY' => 'англійская (Кайманавы астравы)',
        'en_LC' => 'англійская (Сент-Люсія)',
        'en_LR' => 'англійская (Ліберыя)',
        'en_LS' => 'англійская (Лесота)',
        'en_MG' => 'англійская (Мадагаскар)',
        'en_MH' => 'англійская (Маршалавы астравы)',
        'en_MO' => 'англійская (Макаа, САР [Кітай])',
        'en_MP' => 'англійская (Паўночныя Марыянскія астравы)',
        'en_MS' => 'англійская (Мантсерат)',
        'en_MT' => 'англійская (Мальта)',
        'en_MU' => 'англійская (Маўрыкій)',
        'en_MV' => 'англійская (Мальдывы)',
        'en_MW' => 'англійская (Малаві)',
        'en_MY' => 'англійская (Малайзія)',
        'en_NA' => 'англійская (Намібія)',
        'en_NF' => 'англійская (Востраў Норфалк)',
        'en_NG' => 'англійская (Нігерыя)',
        'en_NL' => 'англійская (Нідэрланды)',
        'en_NR' => 'англійская (Науру)',
        'en_NU' => 'англійская (Ніуэ)',
        'en_NZ' => 'англійская (Новая Зеландыя)',
        'en_PG' => 'англійская (Папуа-Новая Гвінея)',
        'en_PH' => 'англійская (Філіпіны)',
        'en_PK' => 'англійская (Пакістан)',
        'en_PN' => 'англійская (Астравы Піткэрн)',
        'en_PR' => 'англійская (Пуэрта-Рыка)',
        'en_PW' => 'англійская (Палау)',
        'en_RW' => 'англійская (Руанда)',
        'en_SB' => 'англійская (Саламонавы астравы)',
        'en_SC' => 'англійская (Сейшэльскія астравы)',
        'en_SD' => 'англійская (Судан)',
        'en_SE' => 'англійская (Швецыя)',
        'en_SG' => 'англійская (Сінгапур)',
        'en_SH' => 'англійская (Востраў Святой Алены)',
        'en_SI' => 'англійская (Славенія)',
        'en_SL' => 'англійская (Сьера-Леонэ)',
        'en_SS' => 'англійская (Паўднёвы Судан)',
        'en_SX' => 'англійская (Сінт-Мартэн)',
        'en_SZ' => 'англійская (Эсватыні)',
        'en_TC' => 'англійская (Астравы Цёркс і Кайкас)',
        'en_TK' => 'англійская (Такелау)',
        'en_TO' => 'англійская (Тонга)',
        'en_TT' => 'англійская (Трынідад і Табага)',
        'en_TV' => 'англійская (Тувалу)',
        'en_TZ' => 'англійская (Танзанія)',
        'en_UG' => 'англійская (Уганда)',
        'en_UM' => 'англійская (Малыя Аддаленыя астравы ЗША)',
        'en_US' => 'англійская (Злучаныя Штаты)',
        'en_VC' => 'англійская (Сент-Вінсент і Грэнадзіны)',
        'en_VG' => 'англійская (Брытанскія Віргінскія астравы)',
        'en_VI' => 'англійская (Амерыканскія Віргінскія астравы)',
        'en_VU' => 'англійская (Вануату)',
        'en_WS' => 'англійская (Самоа)',
        'en_ZA' => 'англійская (Паўднёва-Афрыканская Рэспубліка)',
        'en_ZM' => 'англійская (Замбія)',
        'en_ZW' => 'англійская (Зімбабвэ)',
        'eo' => 'эсперанта',
        'eo_001' => 'эсперанта (Свет)',
        'es' => 'іспанская',
        'es_419' => 'іспанская (Лацінская Амерыка)',
        'es_AR' => 'іспанская (Аргенціна)',
        'es_BO' => 'іспанская (Балівія)',
        'es_BR' => 'іспанская (Бразілія)',
        'es_BZ' => 'іспанская (Беліз)',
        'es_CL' => 'іспанская (Чылі)',
        'es_CO' => 'іспанская (Калумбія)',
        'es_CR' => 'іспанская (Коста-Рыка)',
        'es_CU' => 'іспанская (Куба)',
        'es_DO' => 'іспанская (Дамініканская Рэспубліка)',
        'es_EC' => 'іспанская (Эквадор)',
        'es_ES' => 'іспанская (Іспанія)',
        'es_GQ' => 'іспанская (Экватарыяльная Гвінея)',
        'es_GT' => 'іспанская (Гватэмала)',
        'es_HN' => 'іспанская (Гандурас)',
        'es_MX' => 'іспанская (Мексіка)',
        'es_NI' => 'іспанская (Нікарагуа)',
        'es_PA' => 'іспанская (Панама)',
        'es_PE' => 'іспанская (Перу)',
        'es_PH' => 'іспанская (Філіпіны)',
        'es_PR' => 'іспанская (Пуэрта-Рыка)',
        'es_PY' => 'іспанская (Парагвай)',
        'es_SV' => 'іспанская (Сальвадор)',
        'es_US' => 'іспанская (Злучаныя Штаты)',
        'es_UY' => 'іспанская (Уругвай)',
        'es_VE' => 'іспанская (Венесуэла)',
        'et' => 'эстонская',
        'et_EE' => 'эстонская (Эстонія)',
        'eu' => 'баскская',
        'eu_ES' => 'баскская (Іспанія)',
        'fa' => 'фарсі',
        'fa_AF' => 'фарсі (Афганістан)',
        'fa_IR' => 'фарсі (Іран)',
        'ff' => 'фула',
        'ff_Adlm' => 'фула (адлам)',
        'ff_Adlm_BF' => 'фула (адлам, Буркіна-Фасо)',
        'ff_Adlm_CM' => 'фула (адлам, Камерун)',
        'ff_Adlm_GH' => 'фула (адлам, Гана)',
        'ff_Adlm_GM' => 'фула (адлам, Гамбія)',
        'ff_Adlm_GN' => 'фула (адлам, Гвінея)',
        'ff_Adlm_GW' => 'фула (адлам, Гвінея-Бісау)',
        'ff_Adlm_LR' => 'фула (адлам, Ліберыя)',
        'ff_Adlm_MR' => 'фула (адлам, Маўрытанія)',
        'ff_Adlm_NE' => 'фула (адлам, Нігер)',
        'ff_Adlm_NG' => 'фула (адлам, Нігерыя)',
        'ff_Adlm_SL' => 'фула (адлам, Сьера-Леонэ)',
        'ff_Adlm_SN' => 'фула (адлам, Сенегал)',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвінея)',
        'ff_Latn' => 'фула (лацініца)',
        'ff_Latn_BF' => 'фула (лацініца, Буркіна-Фасо)',
        'ff_Latn_CM' => 'фула (лацініца, Камерун)',
        'ff_Latn_GH' => 'фула (лацініца, Гана)',
        'ff_Latn_GM' => 'фула (лацініца, Гамбія)',
        'ff_Latn_GN' => 'фула (лацініца, Гвінея)',
        'ff_Latn_GW' => 'фула (лацініца, Гвінея-Бісау)',
        'ff_Latn_LR' => 'фула (лацініца, Ліберыя)',
        'ff_Latn_MR' => 'фула (лацініца, Маўрытанія)',
        'ff_Latn_NE' => 'фула (лацініца, Нігер)',
        'ff_Latn_NG' => 'фула (лацініца, Нігерыя)',
        'ff_Latn_SL' => 'фула (лацініца, Сьера-Леонэ)',
        'ff_Latn_SN' => 'фула (лацініца, Сенегал)',
        'ff_MR' => 'фула (Маўрытанія)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фінская',
        'fi_FI' => 'фінская (Фінляндыя)',
        'fo' => 'фарэрская',
        'fo_DK' => 'фарэрская (Данія)',
        'fo_FO' => 'фарэрская (Фарэрскія астравы)',
        'fr' => 'французская',
        'fr_BE' => 'французская (Бельгія)',
        'fr_BF' => 'французская (Буркіна-Фасо)',
        'fr_BI' => 'французская (Бурундзі)',
        'fr_BJ' => 'французская (Бенін)',
        'fr_BL' => 'французская (Сен-Бартэльмі)',
        'fr_CA' => 'французская (Канада)',
        'fr_CD' => 'французская (Конга [Кіншаса])',
        'fr_CF' => 'французская (Цэнтральна-Афрыканская Рэспубліка)',
        'fr_CG' => 'французская (Конга - Бразавіль)',
        'fr_CH' => 'французская (Швейцарыя)',
        'fr_CI' => 'французская (Кот-д’Івуар)',
        'fr_CM' => 'французская (Камерун)',
        'fr_DJ' => 'французская (Джыбуці)',
        'fr_DZ' => 'французская (Алжыр)',
        'fr_FR' => 'французская (Францыя)',
        'fr_GA' => 'французская (Габон)',
        'fr_GF' => 'французская (Французская Гвіяна)',
        'fr_GN' => 'французская (Гвінея)',
        'fr_GP' => 'французская (Гвадэлупа)',
        'fr_GQ' => 'французская (Экватарыяльная Гвінея)',
        'fr_HT' => 'французская (Гаіці)',
        'fr_KM' => 'французская (Каморскія астравы)',
        'fr_LU' => 'французская (Люксембург)',
        'fr_MA' => 'французская (Марока)',
        'fr_MC' => 'французская (Манака)',
        'fr_MF' => 'французская (Сен-Мартэн)',
        'fr_MG' => 'французская (Мадагаскар)',
        'fr_ML' => 'французская (Малі)',
        'fr_MQ' => 'французская (Марцініка)',
        'fr_MR' => 'французская (Маўрытанія)',
        'fr_MU' => 'французская (Маўрыкій)',
        'fr_NC' => 'французская (Новая Каледонія)',
        'fr_NE' => 'французская (Нігер)',
        'fr_PF' => 'французская (Французская Палінезія)',
        'fr_PM' => 'французская (Сен-П’ер і Мікелон)',
        'fr_RE' => 'французская (Рэюньён)',
        'fr_RW' => 'французская (Руанда)',
        'fr_SC' => 'французская (Сейшэльскія астравы)',
        'fr_SN' => 'французская (Сенегал)',
        'fr_SY' => 'французская (Сірыя)',
        'fr_TD' => 'французская (Чад)',
        'fr_TG' => 'французская (Тога)',
        'fr_TN' => 'французская (Туніс)',
        'fr_VU' => 'французская (Вануату)',
        'fr_WF' => 'французская (Уоліс і Футуна)',
        'fr_YT' => 'французская (Маёта)',
        'fy' => 'заходняя фрызская',
        'fy_NL' => 'заходняя фрызская (Нідэрланды)',
        'ga' => 'ірландская',
        'ga_GB' => 'ірландская (Вялікабрытанія)',
        'ga_IE' => 'ірландская (Ірландыя)',
        'gd' => 'шатландская гэльская',
        'gd_GB' => 'шатландская гэльская (Вялікабрытанія)',
        'gl' => 'галісійская',
        'gl_ES' => 'галісійская (Іспанія)',
        'gu' => 'гуджараці',
        'gu_IN' => 'гуджараці (Індыя)',
        'gv' => 'мэнская',
        'gv_IM' => 'мэнская (Востраў Мэн)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нігер)',
        'ha_NG' => 'хауса (Нігерыя)',
        'he' => 'іўрыт',
        'he_IL' => 'іўрыт (Ізраіль)',
        'hi' => 'хіндзі',
        'hi_IN' => 'хіндзі (Індыя)',
        'hi_Latn' => 'хіндзі (лацініца)',
        'hi_Latn_IN' => 'хіндзі (лацініца, Індыя)',
        'hr' => 'харвацкая',
        'hr_BA' => 'харвацкая (Боснія і Герцагавіна)',
        'hr_HR' => 'харвацкая (Харватыя)',
        'hu' => 'венгерская',
        'hu_HU' => 'венгерская (Венгрыя)',
        'hy' => 'армянская',
        'hy_AM' => 'армянская (Арменія)',
        'ia' => 'інтэрлінгва',
        'ia_001' => 'інтэрлінгва (Свет)',
        'id' => 'інданезійская',
        'id_ID' => 'інданезійская (Інданезія)',
        'ig' => 'ігба',
        'ig_NG' => 'ігба (Нігерыя)',
        'ii' => 'сычуаньская йі',
        'ii_CN' => 'сычуаньская йі (Кітай)',
        'is' => 'ісландская',
        'is_IS' => 'ісландская (Ісландыя)',
        'it' => 'італьянская',
        'it_CH' => 'італьянская (Швейцарыя)',
        'it_IT' => 'італьянская (Італія)',
        'it_SM' => 'італьянская (Сан-Марына)',
        'it_VA' => 'італьянская (Ватыкан)',
        'ja' => 'японская',
        'ja_JP' => 'японская (Японія)',
        'jv' => 'яванская',
        'jv_ID' => 'яванская (Інданезія)',
        'ka' => 'грузінская',
        'ka_GE' => 'грузінская (Грузія)',
        'ki' => 'кікуйю',
        'ki_KE' => 'кікуйю (Кенія)',
        'kk' => 'казахская',
        'kk_KZ' => 'казахская (Казахстан)',
        'kl' => 'грэнландская',
        'kl_GL' => 'грэнландская (Грэнландыя)',
        'km' => 'кхмерская',
        'km_KH' => 'кхмерская (Камбоджа)',
        'kn' => 'канада',
        'kn_IN' => 'канада (Індыя)',
        'ko' => 'карэйская',
        'ko_KP' => 'карэйская (Паўночная Карэя)',
        'ko_KR' => 'карэйская (Паўднёвая Карэя)',
        'ks' => 'кашмірская',
        'ks_Arab' => 'кашмірская (арабскае)',
        'ks_Arab_IN' => 'кашмірская (арабскае, Індыя)',
        'ks_Deva' => 'кашмірская (дэванагары)',
        'ks_Deva_IN' => 'кашмірская (дэванагары, Індыя)',
        'ks_IN' => 'кашмірская (Індыя)',
        'ku' => 'курдская',
        'ku_TR' => 'курдская (Турцыя)',
        'kw' => 'корнская',
        'kw_GB' => 'корнская (Вялікабрытанія)',
        'ky' => 'кіргізская',
        'ky_KG' => 'кіргізская (Кыргызстан)',
        'lb' => 'люксембургская',
        'lb_LU' => 'люксембургская (Люксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лінгала',
        'ln_AO' => 'лінгала (Ангола)',
        'ln_CD' => 'лінгала (Конга [Кіншаса])',
        'ln_CF' => 'лінгала (Цэнтральна-Афрыканская Рэспубліка)',
        'ln_CG' => 'лінгала (Конга - Бразавіль)',
        'lo' => 'лаоская',
        'lo_LA' => 'лаоская (Лаос)',
        'lt' => 'літоўская',
        'lt_LT' => 'літоўская (Літва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конга [Кіншаса])',
        'lv' => 'латышская',
        'lv_LV' => 'латышская (Латвія)',
        'mg' => 'малагасійская',
        'mg_MG' => 'малагасійская (Мадагаскар)',
        'mi' => 'маары',
        'mi_NZ' => 'маары (Новая Зеландыя)',
        'mk' => 'македонская',
        'mk_MK' => 'македонская (Паўночная Македонія)',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (Індыя)',
        'mn' => 'мангольская',
        'mn_MN' => 'мангольская (Манголія)',
        'mr' => 'маратхі',
        'mr_IN' => 'маратхі (Індыя)',
        'ms' => 'малайская',
        'ms_BN' => 'малайская (Бруней)',
        'ms_ID' => 'малайская (Інданезія)',
        'ms_MY' => 'малайская (Малайзія)',
        'ms_SG' => 'малайская (Сінгапур)',
        'mt' => 'мальтыйская',
        'mt_MT' => 'мальтыйская (Мальта)',
        'my' => 'бірманская',
        'my_MM' => 'бірманская (М’янма [Бірма])',
        'nb' => 'нарвежская [букмол]',
        'nb_NO' => 'нарвежская [букмол] (Нарвегія)',
        'nb_SJ' => 'нарвежская [букмол] (Шпіцберген і Ян-Маен)',
        'nd' => 'паўночная ндэбеле',
        'nd_ZW' => 'паўночная ндэбеле (Зімбабвэ)',
        'ne' => 'непальская',
        'ne_IN' => 'непальская (Індыя)',
        'ne_NP' => 'непальская (Непал)',
        'nl' => 'нідэрландская',
        'nl_AW' => 'нідэрландская (Аруба)',
        'nl_BE' => 'нідэрландская (Бельгія)',
        'nl_BQ' => 'нідэрландская (Карыбскія Нідэрланды)',
        'nl_CW' => 'нідэрландская (Кюрасаа)',
        'nl_NL' => 'нідэрландская (Нідэрланды)',
        'nl_SR' => 'нідэрландская (Сурынам)',
        'nl_SX' => 'нідэрландская (Сінт-Мартэн)',
        'nn' => 'нарвежская [нюношк]',
        'nn_NO' => 'нарвежская [нюношк] (Нарвегія)',
        'no' => 'нарвежская',
        'no_NO' => 'нарвежская (Нарвегія)',
        'om' => 'арома',
        'om_ET' => 'арома (Эфіопія)',
        'om_KE' => 'арома (Кенія)',
        'or' => 'орыя',
        'or_IN' => 'орыя (Індыя)',
        'os' => 'асецінская',
        'os_GE' => 'асецінская (Грузія)',
        'os_RU' => 'асецінская (Расія)',
        'pa' => 'панджабі',
        'pa_Arab' => 'панджабі (арабскае)',
        'pa_Arab_PK' => 'панджабі (арабскае, Пакістан)',
        'pa_Guru' => 'панджабі (гурмукхі)',
        'pa_Guru_IN' => 'панджабі (гурмукхі, Індыя)',
        'pa_IN' => 'панджабі (Індыя)',
        'pa_PK' => 'панджабі (Пакістан)',
        'pl' => 'польская',
        'pl_PL' => 'польская (Польшча)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Афганістан)',
        'ps_PK' => 'пушту (Пакістан)',
        'pt' => 'партугальская',
        'pt_AO' => 'партугальская (Ангола)',
        'pt_BR' => 'партугальская (Бразілія)',
        'pt_CH' => 'партугальская (Швейцарыя)',
        'pt_CV' => 'партугальская (Каба-Вердэ)',
        'pt_GQ' => 'партугальская (Экватарыяльная Гвінея)',
        'pt_GW' => 'партугальская (Гвінея-Бісау)',
        'pt_LU' => 'партугальская (Люксембург)',
        'pt_MO' => 'партугальская (Макаа, САР [Кітай])',
        'pt_MZ' => 'партугальская (Мазамбік)',
        'pt_PT' => 'партугальская (Партугалія)',
        'pt_ST' => 'партугальская (Сан-Тамэ і Прынсіпі)',
        'pt_TL' => 'партугальская (Тымор-Лешці)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Балівія)',
        'qu_EC' => 'кечуа (Эквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'рэтараманская',
        'rm_CH' => 'рэтараманская (Швейцарыя)',
        'rn' => 'рундзі',
        'rn_BI' => 'рундзі (Бурундзі)',
        'ro' => 'румынская',
        'ro_MD' => 'румынская (Малдова)',
        'ro_RO' => 'румынская (Румынія)',
        'ru' => 'руская',
        'ru_BY' => 'руская (Беларусь)',
        'ru_KG' => 'руская (Кыргызстан)',
        'ru_KZ' => 'руская (Казахстан)',
        'ru_MD' => 'руская (Малдова)',
        'ru_RU' => 'руская (Расія)',
        'ru_UA' => 'руская (Украіна)',
        'rw' => 'руанда',
        'rw_RW' => 'руанда (Руанда)',
        'sa' => 'санскрыт',
        'sa_IN' => 'санскрыт (Індыя)',
        'sc' => 'сардзінская',
        'sc_IT' => 'сардзінская (Італія)',
        'sd' => 'сіндхі',
        'sd_Arab' => 'сіндхі (арабскае)',
        'sd_Arab_PK' => 'сіндхі (арабскае, Пакістан)',
        'sd_Deva' => 'сіндхі (дэванагары)',
        'sd_Deva_IN' => 'сіндхі (дэванагары, Індыя)',
        'sd_IN' => 'сіндхі (Індыя)',
        'sd_PK' => 'сіндхі (Пакістан)',
        'se' => 'паўночнасаамская',
        'se_FI' => 'паўночнасаамская (Фінляндыя)',
        'se_NO' => 'паўночнасаамская (Нарвегія)',
        'se_SE' => 'паўночнасаамская (Швецыя)',
        'sg' => 'санга',
        'sg_CF' => 'санга (Цэнтральна-Афрыканская Рэспубліка)',
        'sh' => 'сербскахарвацкая',
        'sh_BA' => 'сербскахарвацкая (Боснія і Герцагавіна)',
        'si' => 'сінгальская',
        'si_LK' => 'сінгальская (Шры-Ланка)',
        'sk' => 'славацкая',
        'sk_SK' => 'славацкая (Славакія)',
        'sl' => 'славенская',
        'sl_SI' => 'славенская (Славенія)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зімбабвэ)',
        'so' => 'самалі',
        'so_DJ' => 'самалі (Джыбуці)',
        'so_ET' => 'самалі (Эфіопія)',
        'so_KE' => 'самалі (Кенія)',
        'so_SO' => 'самалі (Самалі)',
        'sq' => 'албанская',
        'sq_AL' => 'албанская (Албанія)',
        'sq_MK' => 'албанская (Паўночная Македонія)',
        'sr' => 'сербская',
        'sr_BA' => 'сербская (Боснія і Герцагавіна)',
        'sr_Cyrl' => 'сербская (кірыліца)',
        'sr_Cyrl_BA' => 'сербская (кірыліца, Боснія і Герцагавіна)',
        'sr_Cyrl_ME' => 'сербская (кірыліца, Чарнагорыя)',
        'sr_Cyrl_RS' => 'сербская (кірыліца, Сербія)',
        'sr_Latn' => 'сербская (лацініца)',
        'sr_Latn_BA' => 'сербская (лацініца, Боснія і Герцагавіна)',
        'sr_Latn_ME' => 'сербская (лацініца, Чарнагорыя)',
        'sr_Latn_RS' => 'сербская (лацініца, Сербія)',
        'sr_ME' => 'сербская (Чарнагорыя)',
        'sr_RS' => 'сербская (Сербія)',
        'su' => 'сунда',
        'su_ID' => 'сунда (Інданезія)',
        'su_Latn' => 'сунда (лацініца)',
        'su_Latn_ID' => 'сунда (лацініца, Інданезія)',
        'sv' => 'шведская',
        'sv_AX' => 'шведская (Аландскія астравы)',
        'sv_FI' => 'шведская (Фінляндыя)',
        'sv_SE' => 'шведская (Швецыя)',
        'sw' => 'суахілі',
        'sw_CD' => 'суахілі (Конга [Кіншаса])',
        'sw_KE' => 'суахілі (Кенія)',
        'sw_TZ' => 'суахілі (Танзанія)',
        'sw_UG' => 'суахілі (Уганда)',
        'ta' => 'тамільская',
        'ta_IN' => 'тамільская (Індыя)',
        'ta_LK' => 'тамільская (Шры-Ланка)',
        'ta_MY' => 'тамільская (Малайзія)',
        'ta_SG' => 'тамільская (Сінгапур)',
        'te' => 'тэлугу',
        'te_IN' => 'тэлугу (Індыя)',
        'tg' => 'таджыкская',
        'tg_TJ' => 'таджыкская (Таджыкістан)',
        'th' => 'тайская',
        'th_TH' => 'тайская (Тайланд)',
        'ti' => 'тыгрынья',
        'ti_ER' => 'тыгрынья (Эрытрэя)',
        'ti_ET' => 'тыгрынья (Эфіопія)',
        'tk' => 'туркменская',
        'tk_TM' => 'туркменская (Туркменістан)',
        'to' => 'танганская',
        'to_TO' => 'танганская (Тонга)',
        'tr' => 'турэцкая',
        'tr_CY' => 'турэцкая (Кіпр)',
        'tr_TR' => 'турэцкая (Турцыя)',
        'tt' => 'татарская',
        'tt_RU' => 'татарская (Расія)',
        'ug' => 'уйгурская',
        'ug_CN' => 'уйгурская (Кітай)',
        'uk' => 'украінская',
        'uk_UA' => 'украінская (Украіна)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Індыя)',
        'ur_PK' => 'урду (Пакістан)',
        'uz' => 'узбекская',
        'uz_AF' => 'узбекская (Афганістан)',
        'uz_Arab' => 'узбекская (арабскае)',
        'uz_Arab_AF' => 'узбекская (арабскае, Афганістан)',
        'uz_Cyrl' => 'узбекская (кірыліца)',
        'uz_Cyrl_UZ' => 'узбекская (кірыліца, Узбекістан)',
        'uz_Latn' => 'узбекская (лацініца)',
        'uz_Latn_UZ' => 'узбекская (лацініца, Узбекістан)',
        'uz_UZ' => 'узбекская (Узбекістан)',
        'vi' => 'в’етнамская',
        'vi_VN' => 'в’етнамская (В’етнам)',
        'wo' => 'валоф',
        'wo_SN' => 'валоф (Сенегал)',
        'xh' => 'коса',
        'xh_ZA' => 'коса (Паўднёва-Афрыканская Рэспубліка)',
        'yi' => 'ідыш',
        'yi_001' => 'ідыш (Свет)',
        'yo' => 'ёруба',
        'yo_BJ' => 'ёруба (Бенін)',
        'yo_NG' => 'ёруба (Нігерыя)',
        'zh' => 'кітайская',
        'zh_CN' => 'кітайская (Кітай)',
        'zh_HK' => 'кітайская (Ганконг, САР [Кітай])',
        'zh_Hans' => 'кітайская (спрошчанае кітайскае)',
        'zh_Hans_CN' => 'кітайская (спрошчанае кітайскае, Кітай)',
        'zh_Hans_HK' => 'кітайская (спрошчанае кітайскае, Ганконг, САР [Кітай])',
        'zh_Hans_MO' => 'кітайская (спрошчанае кітайскае, Макаа, САР [Кітай])',
        'zh_Hans_SG' => 'кітайская (спрошчанае кітайскае, Сінгапур)',
        'zh_Hant' => 'кітайская (традыцыйнае кітайскае)',
        'zh_Hant_HK' => 'кітайская (традыцыйнае кітайскае, Ганконг, САР [Кітай])',
        'zh_Hant_MO' => 'кітайская (традыцыйнае кітайскае, Макаа, САР [Кітай])',
        'zh_Hant_TW' => 'кітайская (традыцыйнае кітайскае, Тайвань)',
        'zh_MO' => 'кітайская (Макаа, САР [Кітай])',
        'zh_SG' => 'кітайская (Сінгапур)',
        'zh_TW' => 'кітайская (Тайвань)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Паўднёва-Афрыканская Рэспубліка)',
    ],
];
