<?php

return [
    'Names' => [
        'Beng' => 'Kibangla',
        'Brai' => 'Breli',
        'Cans' => 'Silabi za Asili Zilizounganishwa za Kanada',
        'Cher' => 'Kicherokii',
        'Cyrl' => 'Kikrili',
        'Ethi' => 'Kihabeshi',
        'Hanb' => 'Kihan chenye Kibopomofo',
        'Hans' => 'Kilichorahisishwa',
        'Hira' => 'Kihiragana',
        'Hrkt' => 'Silabi za Kijapani',
        'Jamo' => 'Kijamo',
        'Khmr' => 'Kikhema',
        'Mtei' => 'Kimeiteimayek',
        'Mymr' => 'Kimyanma',
        'Nkoo' => 'Kiin’ko',
        'Olck' => 'Kiolchiki',
        'Orya' => 'Kiodia',
        'Sund' => 'Kisundani',
        'Syrc' => 'Kisiria',
        'Taml' => 'Kitamili',
        'Yiii' => 'Kiiyi',
        'Zmth' => 'Mwandiko wa kihisabati',
    ],
];
