<?php

return [
    'Names' => [
        'af' => 'африкаанс тілі',
        'af_NA' => 'африкаанс тілі (Намибия)',
        'af_ZA' => 'африкаанс тілі (Оңтүстік Африка)',
        'ak' => 'акан тілі',
        'ak_GH' => 'акан тілі (Гана)',
        'am' => 'амхар тілі',
        'am_ET' => 'амхар тілі (Эфиопия)',
        'ar' => 'араб тілі',
        'ar_001' => 'араб тілі (әлем)',
        'ar_AE' => 'араб тілі (Біріккен Араб Әмірліктері)',
        'ar_BH' => 'араб тілі (Бахрейн)',
        'ar_DJ' => 'араб тілі (Джибути)',
        'ar_DZ' => 'араб тілі (Алжир)',
        'ar_EG' => 'араб тілі (Мысыр)',
        'ar_EH' => 'араб тілі (Батыс Сахара)',
        'ar_ER' => 'араб тілі (Эритрея)',
        'ar_IL' => 'араб тілі (Израиль)',
        'ar_IQ' => 'араб тілі (Ирак)',
        'ar_JO' => 'араб тілі (Иордания)',
        'ar_KM' => 'араб тілі (Комор аралдары)',
        'ar_KW' => 'араб тілі (Кувейт)',
        'ar_LB' => 'араб тілі (Ливан)',
        'ar_LY' => 'араб тілі (Ливия)',
        'ar_MA' => 'араб тілі (Марокко)',
        'ar_MR' => 'араб тілі (Мавритания)',
        'ar_OM' => 'араб тілі (Оман)',
        'ar_PS' => 'араб тілі (Палестина аймақтары)',
        'ar_QA' => 'араб тілі (Катар)',
        'ar_SA' => 'араб тілі (Сауд Арабиясы)',
        'ar_SD' => 'араб тілі (Судан)',
        'ar_SO' => 'араб тілі (Сомали)',
        'ar_SS' => 'араб тілі (Оңтүстік Судан)',
        'ar_SY' => 'араб тілі (Сирия)',
        'ar_TD' => 'араб тілі (Чад)',
        'ar_TN' => 'араб тілі (Тунис)',
        'ar_YE' => 'араб тілі (Йемен)',
        'as' => 'ассам тілі',
        'as_IN' => 'ассам тілі (Үндістан)',
        'az' => 'әзірбайжан тілі',
        'az_AZ' => 'әзірбайжан тілі (Әзірбайжан)',
        'az_Cyrl' => 'әзірбайжан тілі (кирилл жазуы)',
        'az_Cyrl_AZ' => 'әзірбайжан тілі (кирилл жазуы, Әзірбайжан)',
        'az_Latn' => 'әзірбайжан тілі (латын жазуы)',
        'az_Latn_AZ' => 'әзірбайжан тілі (латын жазуы, Әзірбайжан)',
        'be' => 'беларусь тілі',
        'be_BY' => 'беларусь тілі (Беларусь)',
        'bg' => 'болгар тілі',
        'bg_BG' => 'болгар тілі (Болгария)',
        'bm' => 'бамбара тілі',
        'bm_ML' => 'бамбара тілі (Мали)',
        'bn' => 'бенгал тілі',
        'bn_BD' => 'бенгал тілі (Бангладеш)',
        'bn_IN' => 'бенгал тілі (Үндістан)',
        'bo' => 'тибет тілі',
        'bo_CN' => 'тибет тілі (Қытай)',
        'bo_IN' => 'тибет тілі (Үндістан)',
        'br' => 'бретон тілі',
        'br_FR' => 'бретон тілі (Франция)',
        'bs' => 'босния тілі',
        'bs_BA' => 'босния тілі (Босния және Герцеговина)',
        'bs_Cyrl' => 'босния тілі (кирилл жазуы)',
        'bs_Cyrl_BA' => 'босния тілі (кирилл жазуы, Босния және Герцеговина)',
        'bs_Latn' => 'босния тілі (латын жазуы)',
        'bs_Latn_BA' => 'босния тілі (латын жазуы, Босния және Герцеговина)',
        'ca' => 'каталан тілі',
        'ca_AD' => 'каталан тілі (Андорра)',
        'ca_ES' => 'каталан тілі (Испания)',
        'ca_FR' => 'каталан тілі (Франция)',
        'ca_IT' => 'каталан тілі (Италия)',
        'ce' => 'шешен тілі',
        'ce_RU' => 'шешен тілі (Ресей)',
        'cs' => 'чех тілі',
        'cs_CZ' => 'чех тілі (Чехия)',
        'cv' => 'чуваш тілі',
        'cv_RU' => 'чуваш тілі (Ресей)',
        'cy' => 'валлий тілі',
        'cy_GB' => 'валлий тілі (Ұлыбритания)',
        'da' => 'дат тілі',
        'da_DK' => 'дат тілі (Дания)',
        'da_GL' => 'дат тілі (Гренландия)',
        'de' => 'неміс тілі',
        'de_AT' => 'неміс тілі (Аустрия)',
        'de_BE' => 'неміс тілі (Бельгия)',
        'de_CH' => 'неміс тілі (Швейцария)',
        'de_DE' => 'неміс тілі (Германия)',
        'de_IT' => 'неміс тілі (Италия)',
        'de_LI' => 'неміс тілі (Лихтенштейн)',
        'de_LU' => 'неміс тілі (Люксембург)',
        'dz' => 'дзонг-кэ тілі',
        'dz_BT' => 'дзонг-кэ тілі (Бутан)',
        'ee' => 'эве тілі',
        'ee_GH' => 'эве тілі (Гана)',
        'ee_TG' => 'эве тілі (Того)',
        'el' => 'грек тілі',
        'el_CY' => 'грек тілі (Кипр)',
        'el_GR' => 'грек тілі (Грекия)',
        'en' => 'ағылшын тілі',
        'en_001' => 'ағылшын тілі (әлем)',
        'en_150' => 'ағылшын тілі (Еуропа)',
        'en_AE' => 'ағылшын тілі (Біріккен Араб Әмірліктері)',
        'en_AG' => 'ағылшын тілі (Антигуа және Барбуда)',
        'en_AI' => 'ағылшын тілі (Ангилья)',
        'en_AS' => 'ағылшын тілі (Америкалық Самоа)',
        'en_AT' => 'ағылшын тілі (Аустрия)',
        'en_AU' => 'ағылшын тілі (Аустралия)',
        'en_BB' => 'ағылшын тілі (Барбадос)',
        'en_BE' => 'ағылшын тілі (Бельгия)',
        'en_BI' => 'ағылшын тілі (Бурунди)',
        'en_BM' => 'ағылшын тілі (Бермуд аралдары)',
        'en_BS' => 'ағылшын тілі (Багам аралдары)',
        'en_BW' => 'ағылшын тілі (Ботсвана)',
        'en_BZ' => 'ағылшын тілі (Белиз)',
        'en_CA' => 'ағылшын тілі (Канада)',
        'en_CC' => 'ағылшын тілі (Кокос [Килинг] аралдары)',
        'en_CH' => 'ағылшын тілі (Швейцария)',
        'en_CK' => 'ағылшын тілі (Кук аралдары)',
        'en_CM' => 'ағылшын тілі (Камерун)',
        'en_CX' => 'ағылшын тілі (Рождество аралы)',
        'en_CY' => 'ағылшын тілі (Кипр)',
        'en_DE' => 'ағылшын тілі (Германия)',
        'en_DK' => 'ағылшын тілі (Дания)',
        'en_DM' => 'ағылшын тілі (Доминика)',
        'en_ER' => 'ағылшын тілі (Эритрея)',
        'en_FI' => 'ағылшын тілі (Финляндия)',
        'en_FJ' => 'ағылшын тілі (Фиджи)',
        'en_FK' => 'ағылшын тілі (Фолкленд аралдары)',
        'en_FM' => 'ағылшын тілі (Микронезия)',
        'en_GB' => 'ағылшын тілі (Ұлыбритания)',
        'en_GD' => 'ағылшын тілі (Гренада)',
        'en_GG' => 'ағылшын тілі (Гернси)',
        'en_GH' => 'ағылшын тілі (Гана)',
        'en_GI' => 'ағылшын тілі (Гибралтар)',
        'en_GM' => 'ағылшын тілі (Гамбия)',
        'en_GU' => 'ағылшын тілі (Гуам)',
        'en_GY' => 'ағылшын тілі (Гайана)',
        'en_HK' => 'ағылшын тілі (Сянган АӘА)',
        'en_IE' => 'ағылшын тілі (Ирландия)',
        'en_IL' => 'ағылшын тілі (Израиль)',
        'en_IM' => 'ағылшын тілі (Мэн аралы)',
        'en_IN' => 'ағылшын тілі (Үндістан)',
        'en_IO' => 'ағылшын тілі (Үнді мұхитындағы Британ аймағы)',
        'en_JE' => 'ағылшын тілі (Джерси)',
        'en_JM' => 'ағылшын тілі (Ямайка)',
        'en_KE' => 'ағылшын тілі (Кения)',
        'en_KI' => 'ағылшын тілі (Кирибати)',
        'en_KN' => 'ағылшын тілі (Сент-Китс және Невис)',
        'en_KY' => 'ағылшын тілі (Кайман аралдары)',
        'en_LC' => 'ағылшын тілі (Сент-Люсия)',
        'en_LR' => 'ағылшын тілі (Либерия)',
        'en_LS' => 'ағылшын тілі (Лесото)',
        'en_MG' => 'ағылшын тілі (Мадагаскар)',
        'en_MH' => 'ағылшын тілі (Маршалл аралдары)',
        'en_MO' => 'ағылшын тілі (Макао АӘА)',
        'en_MP' => 'ағылшын тілі (Солтүстік Мариана аралдары)',
        'en_MS' => 'ағылшын тілі (Монтсеррат)',
        'en_MT' => 'ағылшын тілі (Мальта)',
        'en_MU' => 'ағылшын тілі (Маврикий)',
        'en_MV' => 'ағылшын тілі (Мальдив аралдары)',
        'en_MW' => 'ағылшын тілі (Малави)',
        'en_MY' => 'ағылшын тілі (Малайзия)',
        'en_NA' => 'ағылшын тілі (Намибия)',
        'en_NF' => 'ағылшын тілі (Норфолк аралы)',
        'en_NG' => 'ағылшын тілі (Нигерия)',
        'en_NL' => 'ағылшын тілі (Нидерланд)',
        'en_NR' => 'ағылшын тілі (Науру)',
        'en_NU' => 'ағылшын тілі (Ниуэ)',
        'en_NZ' => 'ағылшын тілі (Жаңа Зеландия)',
        'en_PG' => 'ағылшын тілі (Папуа — Жаңа Гвинея)',
        'en_PH' => 'ағылшын тілі (Филиппин аралдары)',
        'en_PK' => 'ағылшын тілі (Пәкістан)',
        'en_PN' => 'ағылшын тілі (Питкэрн аралдары)',
        'en_PR' => 'ағылшын тілі (Пуэрто-Рико)',
        'en_PW' => 'ағылшын тілі (Палау)',
        'en_RW' => 'ағылшын тілі (Руанда)',
        'en_SB' => 'ағылшын тілі (Соломон аралдары)',
        'en_SC' => 'ағылшын тілі (Сейшель аралдары)',
        'en_SD' => 'ағылшын тілі (Судан)',
        'en_SE' => 'ағылшын тілі (Швеция)',
        'en_SG' => 'ағылшын тілі (Сингапур)',
        'en_SH' => 'ағылшын тілі (Әулие Елена аралы)',
        'en_SI' => 'ағылшын тілі (Словения)',
        'en_SL' => 'ағылшын тілі (Сьерра-Леоне)',
        'en_SS' => 'ағылшын тілі (Оңтүстік Судан)',
        'en_SX' => 'ағылшын тілі (Синт-Мартен)',
        'en_SZ' => 'ағылшын тілі (Эсватини)',
        'en_TC' => 'ағылшын тілі (Теркс және Кайкос аралдары)',
        'en_TK' => 'ағылшын тілі (Токелау)',
        'en_TO' => 'ағылшын тілі (Тонга)',
        'en_TT' => 'ағылшын тілі (Тринидад және Тобаго)',
        'en_TV' => 'ағылшын тілі (Тувалу)',
        'en_TZ' => 'ағылшын тілі (Танзания)',
        'en_UG' => 'ағылшын тілі (Уганда)',
        'en_UM' => 'ағылшын тілі (АҚШ-тың сыртқы кіші аралдары)',
        'en_US' => 'ағылшын тілі (Америка Құрама Штаттары)',
        'en_VC' => 'ағылшын тілі (Сент-Винсент және Гренадин аралдары)',
        'en_VG' => 'ағылшын тілі (Британдық Виргин аралдары)',
        'en_VI' => 'ағылшын тілі (АҚШ-тың Виргин аралдары)',
        'en_VU' => 'ағылшын тілі (Вануату)',
        'en_WS' => 'ағылшын тілі (Самоа)',
        'en_ZA' => 'ағылшын тілі (Оңтүстік Африка)',
        'en_ZM' => 'ағылшын тілі (Замбия)',
        'en_ZW' => 'ағылшын тілі (Зимбабве)',
        'eo' => 'эсперанто тілі',
        'eo_001' => 'эсперанто тілі (әлем)',
        'es' => 'испан тілі',
        'es_419' => 'испан тілі (Латын Америкасы)',
        'es_AR' => 'испан тілі (Аргентина)',
        'es_BO' => 'испан тілі (Боливия)',
        'es_BR' => 'испан тілі (Бразилия)',
        'es_BZ' => 'испан тілі (Белиз)',
        'es_CL' => 'испан тілі (Чили)',
        'es_CO' => 'испан тілі (Колумбия)',
        'es_CR' => 'испан тілі (Коста-Рика)',
        'es_CU' => 'испан тілі (Куба)',
        'es_DO' => 'испан тілі (Доминикан Республикасы)',
        'es_EC' => 'испан тілі (Эквадор)',
        'es_ES' => 'испан тілі (Испания)',
        'es_GQ' => 'испан тілі (Экваторлық Гвинея)',
        'es_GT' => 'испан тілі (Гватемала)',
        'es_HN' => 'испан тілі (Гондурас)',
        'es_MX' => 'испан тілі (Мексика)',
        'es_NI' => 'испан тілі (Никарагуа)',
        'es_PA' => 'испан тілі (Панама)',
        'es_PE' => 'испан тілі (Перу)',
        'es_PH' => 'испан тілі (Филиппин аралдары)',
        'es_PR' => 'испан тілі (Пуэрто-Рико)',
        'es_PY' => 'испан тілі (Парагвай)',
        'es_SV' => 'испан тілі (Сальвадор)',
        'es_US' => 'испан тілі (Америка Құрама Штаттары)',
        'es_UY' => 'испан тілі (Уругвай)',
        'es_VE' => 'испан тілі (Венесуэла)',
        'et' => 'эстон тілі',
        'et_EE' => 'эстон тілі (Эстония)',
        'eu' => 'баск тілі',
        'eu_ES' => 'баск тілі (Испания)',
        'fa' => 'парсы тілі',
        'fa_AF' => 'парсы тілі (Ауғанстан)',
        'fa_IR' => 'парсы тілі (Иран)',
        'ff' => 'фула тілі',
        'ff_Adlm' => 'фула тілі (адлам жазуы)',
        'ff_Adlm_BF' => 'фула тілі (адлам жазуы, Буркина-Фасо)',
        'ff_Adlm_CM' => 'фула тілі (адлам жазуы, Камерун)',
        'ff_Adlm_GH' => 'фула тілі (адлам жазуы, Гана)',
        'ff_Adlm_GM' => 'фула тілі (адлам жазуы, Гамбия)',
        'ff_Adlm_GN' => 'фула тілі (адлам жазуы, Гвинея)',
        'ff_Adlm_GW' => 'фула тілі (адлам жазуы, Гвинея-Бисау)',
        'ff_Adlm_LR' => 'фула тілі (адлам жазуы, Либерия)',
        'ff_Adlm_MR' => 'фула тілі (адлам жазуы, Мавритания)',
        'ff_Adlm_NE' => 'фула тілі (адлам жазуы, Нигер)',
        'ff_Adlm_NG' => 'фула тілі (адлам жазуы, Нигерия)',
        'ff_Adlm_SL' => 'фула тілі (адлам жазуы, Сьерра-Леоне)',
        'ff_Adlm_SN' => 'фула тілі (адлам жазуы, Сенегал)',
        'ff_CM' => 'фула тілі (Камерун)',
        'ff_GN' => 'фула тілі (Гвинея)',
        'ff_Latn' => 'фула тілі (латын жазуы)',
        'ff_Latn_BF' => 'фула тілі (латын жазуы, Буркина-Фасо)',
        'ff_Latn_CM' => 'фула тілі (латын жазуы, Камерун)',
        'ff_Latn_GH' => 'фула тілі (латын жазуы, Гана)',
        'ff_Latn_GM' => 'фула тілі (латын жазуы, Гамбия)',
        'ff_Latn_GN' => 'фула тілі (латын жазуы, Гвинея)',
        'ff_Latn_GW' => 'фула тілі (латын жазуы, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фула тілі (латын жазуы, Либерия)',
        'ff_Latn_MR' => 'фула тілі (латын жазуы, Мавритания)',
        'ff_Latn_NE' => 'фула тілі (латын жазуы, Нигер)',
        'ff_Latn_NG' => 'фула тілі (латын жазуы, Нигерия)',
        'ff_Latn_SL' => 'фула тілі (латын жазуы, Сьерра-Леоне)',
        'ff_Latn_SN' => 'фула тілі (латын жазуы, Сенегал)',
        'ff_MR' => 'фула тілі (Мавритания)',
        'ff_SN' => 'фула тілі (Сенегал)',
        'fi' => 'фин тілі',
        'fi_FI' => 'фин тілі (Финляндия)',
        'fo' => 'фарер тілі',
        'fo_DK' => 'фарер тілі (Дания)',
        'fo_FO' => 'фарер тілі (Фарер аралдары)',
        'fr' => 'француз тілі',
        'fr_BE' => 'француз тілі (Бельгия)',
        'fr_BF' => 'француз тілі (Буркина-Фасо)',
        'fr_BI' => 'француз тілі (Бурунди)',
        'fr_BJ' => 'француз тілі (Бенин)',
        'fr_BL' => 'француз тілі (Сен-Бартелеми)',
        'fr_CA' => 'француз тілі (Канада)',
        'fr_CD' => 'француз тілі (Конго)',
        'fr_CF' => 'француз тілі (Орталық Африка Республикасы)',
        'fr_CG' => 'француз тілі (Конго-Браззавиль Республикасы)',
        'fr_CH' => 'француз тілі (Швейцария)',
        'fr_CI' => 'француз тілі (Кот-д’Ивуар)',
        'fr_CM' => 'француз тілі (Камерун)',
        'fr_DJ' => 'француз тілі (Джибути)',
        'fr_DZ' => 'француз тілі (Алжир)',
        'fr_FR' => 'француз тілі (Франция)',
        'fr_GA' => 'француз тілі (Габон)',
        'fr_GF' => 'француз тілі (Француз Гвианасы)',
        'fr_GN' => 'француз тілі (Гвинея)',
        'fr_GP' => 'француз тілі (Гваделупа)',
        'fr_GQ' => 'француз тілі (Экваторлық Гвинея)',
        'fr_HT' => 'француз тілі (Гаити)',
        'fr_KM' => 'француз тілі (Комор аралдары)',
        'fr_LU' => 'француз тілі (Люксембург)',
        'fr_MA' => 'француз тілі (Марокко)',
        'fr_MC' => 'француз тілі (Монако)',
        'fr_MF' => 'француз тілі (Сен-Мартен)',
        'fr_MG' => 'француз тілі (Мадагаскар)',
        'fr_ML' => 'француз тілі (Мали)',
        'fr_MQ' => 'француз тілі (Мартиника)',
        'fr_MR' => 'француз тілі (Мавритания)',
        'fr_MU' => 'француз тілі (Маврикий)',
        'fr_NC' => 'француз тілі (Жаңа Каледония)',
        'fr_NE' => 'француз тілі (Нигер)',
        'fr_PF' => 'француз тілі (Француз Полинезиясы)',
        'fr_PM' => 'француз тілі (Сен-Пьер және Микелон)',
        'fr_RE' => 'француз тілі (Реюньон)',
        'fr_RW' => 'француз тілі (Руанда)',
        'fr_SC' => 'француз тілі (Сейшель аралдары)',
        'fr_SN' => 'француз тілі (Сенегал)',
        'fr_SY' => 'француз тілі (Сирия)',
        'fr_TD' => 'француз тілі (Чад)',
        'fr_TG' => 'француз тілі (Того)',
        'fr_TN' => 'француз тілі (Тунис)',
        'fr_VU' => 'француз тілі (Вануату)',
        'fr_WF' => 'француз тілі (Уоллис және Футуна)',
        'fr_YT' => 'француз тілі (Майотта)',
        'fy' => 'батыс фриз тілі',
        'fy_NL' => 'батыс фриз тілі (Нидерланд)',
        'ga' => 'ирланд тілі',
        'ga_GB' => 'ирланд тілі (Ұлыбритания)',
        'ga_IE' => 'ирланд тілі (Ирландия)',
        'gd' => 'шотландиялық гэль тілі',
        'gd_GB' => 'шотландиялық гэль тілі (Ұлыбритания)',
        'gl' => 'галисия тілі',
        'gl_ES' => 'галисия тілі (Испания)',
        'gu' => 'гуджарати тілі',
        'gu_IN' => 'гуджарати тілі (Үндістан)',
        'gv' => 'мэн тілі',
        'gv_IM' => 'мэн тілі (Мэн аралы)',
        'ha' => 'хауса тілі',
        'ha_GH' => 'хауса тілі (Гана)',
        'ha_NE' => 'хауса тілі (Нигер)',
        'ha_NG' => 'хауса тілі (Нигерия)',
        'he' => 'иврит тілі',
        'he_IL' => 'иврит тілі (Израиль)',
        'hi' => 'хинди тілі',
        'hi_IN' => 'хинди тілі (Үндістан)',
        'hi_Latn' => 'хинди тілі (латын жазуы)',
        'hi_Latn_IN' => 'хинди тілі (латын жазуы, Үндістан)',
        'hr' => 'хорват тілі',
        'hr_BA' => 'хорват тілі (Босния және Герцеговина)',
        'hr_HR' => 'хорват тілі (Хорватия)',
        'hu' => 'венгр тілі',
        'hu_HU' => 'венгр тілі (Венгрия)',
        'hy' => 'армян тілі',
        'hy_AM' => 'армян тілі (Армения)',
        'ia' => 'интерлингва тілі',
        'ia_001' => 'интерлингва тілі (әлем)',
        'id' => 'индонезия тілі',
        'id_ID' => 'индонезия тілі (Индонезия)',
        'ig' => 'игбо тілі',
        'ig_NG' => 'игбо тілі (Нигерия)',
        'ii' => 'сычуан и тілі',
        'ii_CN' => 'сычуан и тілі (Қытай)',
        'is' => 'исланд тілі',
        'is_IS' => 'исланд тілі (Исландия)',
        'it' => 'итальян тілі',
        'it_CH' => 'итальян тілі (Швейцария)',
        'it_IT' => 'итальян тілі (Италия)',
        'it_SM' => 'итальян тілі (Сан-Марино)',
        'it_VA' => 'итальян тілі (Ватикан)',
        'ja' => 'жапон тілі',
        'ja_JP' => 'жапон тілі (Жапония)',
        'jv' => 'ява тілі',
        'jv_ID' => 'ява тілі (Индонезия)',
        'ka' => 'грузин тілі',
        'ka_GE' => 'грузин тілі (Грузия)',
        'ki' => 'кикуйю тілі',
        'ki_KE' => 'кикуйю тілі (Кения)',
        'kk' => 'қазақ тілі',
        'kk_KZ' => 'қазақ тілі (Қазақстан)',
        'kl' => 'калаалисут тілі',
        'kl_GL' => 'калаалисут тілі (Гренландия)',
        'km' => 'кхмер тілі',
        'km_KH' => 'кхмер тілі (Камбоджа)',
        'kn' => 'каннада тілі',
        'kn_IN' => 'каннада тілі (Үндістан)',
        'ko' => 'корей тілі',
        'ko_KP' => 'корей тілі (Солтүстік Корея)',
        'ko_KR' => 'корей тілі (Оңтүстік Корея)',
        'ks' => 'кашмир тілі',
        'ks_Arab' => 'кашмир тілі (араб жазуы)',
        'ks_Arab_IN' => 'кашмир тілі (араб жазуы, Үндістан)',
        'ks_Deva' => 'кашмир тілі (деванагари жазуы)',
        'ks_Deva_IN' => 'кашмир тілі (деванагари жазуы, Үндістан)',
        'ks_IN' => 'кашмир тілі (Үндістан)',
        'ku' => 'күрд тілі',
        'ku_TR' => 'күрд тілі (Түркия)',
        'kw' => 'корн тілі',
        'kw_GB' => 'корн тілі (Ұлыбритания)',
        'ky' => 'қырғыз тілі',
        'ky_KG' => 'қырғыз тілі (Қырғызстан)',
        'lb' => 'люксембург тілі',
        'lb_LU' => 'люксембург тілі (Люксембург)',
        'lg' => 'ганда тілі',
        'lg_UG' => 'ганда тілі (Уганда)',
        'ln' => 'лингала тілі',
        'ln_AO' => 'лингала тілі (Ангола)',
        'ln_CD' => 'лингала тілі (Конго)',
        'ln_CF' => 'лингала тілі (Орталық Африка Республикасы)',
        'ln_CG' => 'лингала тілі (Конго-Браззавиль Республикасы)',
        'lo' => 'лаос тілі',
        'lo_LA' => 'лаос тілі (Лаос)',
        'lt' => 'литва тілі',
        'lt_LT' => 'литва тілі (Литва)',
        'lu' => 'луба-катанга тілі',
        'lu_CD' => 'луба-катанга тілі (Конго)',
        'lv' => 'латыш тілі',
        'lv_LV' => 'латыш тілі (Латвия)',
        'mg' => 'малагаси тілі',
        'mg_MG' => 'малагаси тілі (Мадагаскар)',
        'mi' => 'маори тілі',
        'mi_NZ' => 'маори тілі (Жаңа Зеландия)',
        'mk' => 'македон тілі',
        'mk_MK' => 'македон тілі (Солтүстік Македония)',
        'ml' => 'малаялам тілі',
        'ml_IN' => 'малаялам тілі (Үндістан)',
        'mn' => 'моңғол тілі',
        'mn_MN' => 'моңғол тілі (Моңғолия)',
        'mr' => 'маратхи тілі',
        'mr_IN' => 'маратхи тілі (Үндістан)',
        'ms' => 'малай тілі',
        'ms_BN' => 'малай тілі (Бруней)',
        'ms_ID' => 'малай тілі (Индонезия)',
        'ms_MY' => 'малай тілі (Малайзия)',
        'ms_SG' => 'малай тілі (Сингапур)',
        'mt' => 'мальта тілі',
        'mt_MT' => 'мальта тілі (Мальта)',
        'my' => 'бирма тілі',
        'my_MM' => 'бирма тілі (Мьянма [Бирма])',
        'nb' => 'норвегиялық букмол тілі',
        'nb_NO' => 'норвегиялық букмол тілі (Норвегия)',
        'nb_SJ' => 'норвегиялық букмол тілі (Шпицберген және Ян-Майен)',
        'nd' => 'солтүстік ндебеле тілі',
        'nd_ZW' => 'солтүстік ндебеле тілі (Зимбабве)',
        'ne' => 'непал тілі',
        'ne_IN' => 'непал тілі (Үндістан)',
        'ne_NP' => 'непал тілі (Непал)',
        'nl' => 'нидерланд тілі',
        'nl_AW' => 'нидерланд тілі (Аруба)',
        'nl_BE' => 'нидерланд тілі (Бельгия)',
        'nl_BQ' => 'нидерланд тілі (Бонэйр, Синт-Эстатиус және Саба)',
        'nl_CW' => 'нидерланд тілі (Кюрасао)',
        'nl_NL' => 'нидерланд тілі (Нидерланд)',
        'nl_SR' => 'нидерланд тілі (Суринам)',
        'nl_SX' => 'нидерланд тілі (Синт-Мартен)',
        'nn' => 'норвегиялық нюнорск тілі',
        'nn_NO' => 'норвегиялық нюнорск тілі (Норвегия)',
        'no' => 'норвег тілі',
        'no_NO' => 'норвег тілі (Норвегия)',
        'om' => 'оромо тілі',
        'om_ET' => 'оромо тілі (Эфиопия)',
        'om_KE' => 'оромо тілі (Кения)',
        'or' => 'ория тілі',
        'or_IN' => 'ория тілі (Үндістан)',
        'os' => 'осетин тілі',
        'os_GE' => 'осетин тілі (Грузия)',
        'os_RU' => 'осетин тілі (Ресей)',
        'pa' => 'пенджаб тілі',
        'pa_Arab' => 'пенджаб тілі (араб жазуы)',
        'pa_Arab_PK' => 'пенджаб тілі (араб жазуы, Пәкістан)',
        'pa_Guru' => 'пенджаб тілі (гурмукхи жазуы)',
        'pa_Guru_IN' => 'пенджаб тілі (гурмукхи жазуы, Үндістан)',
        'pa_IN' => 'пенджаб тілі (Үндістан)',
        'pa_PK' => 'пенджаб тілі (Пәкістан)',
        'pl' => 'поляк тілі',
        'pl_PL' => 'поляк тілі (Польша)',
        'ps' => 'пушту тілі',
        'ps_AF' => 'пушту тілі (Ауғанстан)',
        'ps_PK' => 'пушту тілі (Пәкістан)',
        'pt' => 'португал тілі',
        'pt_AO' => 'португал тілі (Ангола)',
        'pt_BR' => 'португал тілі (Бразилия)',
        'pt_CH' => 'португал тілі (Швейцария)',
        'pt_CV' => 'португал тілі (Кабо-Верде)',
        'pt_GQ' => 'португал тілі (Экваторлық Гвинея)',
        'pt_GW' => 'португал тілі (Гвинея-Бисау)',
        'pt_LU' => 'португал тілі (Люксембург)',
        'pt_MO' => 'португал тілі (Макао АӘА)',
        'pt_MZ' => 'португал тілі (Мозамбик)',
        'pt_PT' => 'португал тілі (Португалия)',
        'pt_ST' => 'португал тілі (Сан-Томе және Принсипи)',
        'pt_TL' => 'португал тілі (Тимор-Лесте)',
        'qu' => 'кечуа тілі',
        'qu_BO' => 'кечуа тілі (Боливия)',
        'qu_EC' => 'кечуа тілі (Эквадор)',
        'qu_PE' => 'кечуа тілі (Перу)',
        'rm' => 'романш тілі',
        'rm_CH' => 'романш тілі (Швейцария)',
        'rn' => 'рунди тілі',
        'rn_BI' => 'рунди тілі (Бурунди)',
        'ro' => 'румын тілі',
        'ro_MD' => 'румын тілі (Молдова)',
        'ro_RO' => 'румын тілі (Румыния)',
        'ru' => 'орыс тілі',
        'ru_BY' => 'орыс тілі (Беларусь)',
        'ru_KG' => 'орыс тілі (Қырғызстан)',
        'ru_KZ' => 'орыс тілі (Қазақстан)',
        'ru_MD' => 'орыс тілі (Молдова)',
        'ru_RU' => 'орыс тілі (Ресей)',
        'ru_UA' => 'орыс тілі (Украина)',
        'rw' => 'киньяруанда тілі',
        'rw_RW' => 'киньяруанда тілі (Руанда)',
        'sa' => 'санскрит тілі',
        'sa_IN' => 'санскрит тілі (Үндістан)',
        'sc' => 'сардин тілі',
        'sc_IT' => 'сардин тілі (Италия)',
        'sd' => 'синдхи тілі',
        'sd_Arab' => 'синдхи тілі (араб жазуы)',
        'sd_Arab_PK' => 'синдхи тілі (араб жазуы, Пәкістан)',
        'sd_Deva' => 'синдхи тілі (деванагари жазуы)',
        'sd_Deva_IN' => 'синдхи тілі (деванагари жазуы, Үндістан)',
        'sd_IN' => 'синдхи тілі (Үндістан)',
        'sd_PK' => 'синдхи тілі (Пәкістан)',
        'se' => 'солтүстік саам тілі',
        'se_FI' => 'солтүстік саам тілі (Финляндия)',
        'se_NO' => 'солтүстік саам тілі (Норвегия)',
        'se_SE' => 'солтүстік саам тілі (Швеция)',
        'sg' => 'санго тілі',
        'sg_CF' => 'санго тілі (Орталық Африка Республикасы)',
        'sh' => 'серб-хорват тілі',
        'sh_BA' => 'серб-хорват тілі (Босния және Герцеговина)',
        'si' => 'сингал тілі',
        'si_LK' => 'сингал тілі (Шри-Ланка)',
        'sk' => 'словак тілі',
        'sk_SK' => 'словак тілі (Словакия)',
        'sl' => 'словен тілі',
        'sl_SI' => 'словен тілі (Словения)',
        'sn' => 'шона тілі',
        'sn_ZW' => 'шона тілі (Зимбабве)',
        'so' => 'сомали тілі',
        'so_DJ' => 'сомали тілі (Джибути)',
        'so_ET' => 'сомали тілі (Эфиопия)',
        'so_KE' => 'сомали тілі (Кения)',
        'so_SO' => 'сомали тілі (Сомали)',
        'sq' => 'албан тілі',
        'sq_AL' => 'албан тілі (Албания)',
        'sq_MK' => 'албан тілі (Солтүстік Македония)',
        'sr' => 'серб тілі',
        'sr_BA' => 'серб тілі (Босния және Герцеговина)',
        'sr_Cyrl' => 'серб тілі (кирилл жазуы)',
        'sr_Cyrl_BA' => 'серб тілі (кирилл жазуы, Босния және Герцеговина)',
        'sr_Cyrl_ME' => 'серб тілі (кирилл жазуы, Черногория)',
        'sr_Cyrl_RS' => 'серб тілі (кирилл жазуы, Сербия)',
        'sr_Latn' => 'серб тілі (латын жазуы)',
        'sr_Latn_BA' => 'серб тілі (латын жазуы, Босния және Герцеговина)',
        'sr_Latn_ME' => 'серб тілі (латын жазуы, Черногория)',
        'sr_Latn_RS' => 'серб тілі (латын жазуы, Сербия)',
        'sr_ME' => 'серб тілі (Черногория)',
        'sr_RS' => 'серб тілі (Сербия)',
        'su' => 'сундан тілі',
        'su_ID' => 'сундан тілі (Индонезия)',
        'su_Latn' => 'сундан тілі (латын жазуы)',
        'su_Latn_ID' => 'сундан тілі (латын жазуы, Индонезия)',
        'sv' => 'швед тілі',
        'sv_AX' => 'швед тілі (Аланд аралдары)',
        'sv_FI' => 'швед тілі (Финляндия)',
        'sv_SE' => 'швед тілі (Швеция)',
        'sw' => 'суахили тілі',
        'sw_CD' => 'суахили тілі (Конго)',
        'sw_KE' => 'суахили тілі (Кения)',
        'sw_TZ' => 'суахили тілі (Танзания)',
        'sw_UG' => 'суахили тілі (Уганда)',
        'ta' => 'тамил тілі',
        'ta_IN' => 'тамил тілі (Үндістан)',
        'ta_LK' => 'тамил тілі (Шри-Ланка)',
        'ta_MY' => 'тамил тілі (Малайзия)',
        'ta_SG' => 'тамил тілі (Сингапур)',
        'te' => 'телугу тілі',
        'te_IN' => 'телугу тілі (Үндістан)',
        'tg' => 'тәжік тілі',
        'tg_TJ' => 'тәжік тілі (Тәжікстан)',
        'th' => 'тай тілі',
        'th_TH' => 'тай тілі (Таиланд)',
        'ti' => 'тигринья тілі',
        'ti_ER' => 'тигринья тілі (Эритрея)',
        'ti_ET' => 'тигринья тілі (Эфиопия)',
        'tk' => 'түрікмен тілі',
        'tk_TM' => 'түрікмен тілі (Түрікменстан)',
        'to' => 'тонган тілі',
        'to_TO' => 'тонган тілі (Тонга)',
        'tr' => 'түрік тілі',
        'tr_CY' => 'түрік тілі (Кипр)',
        'tr_TR' => 'түрік тілі (Түркия)',
        'tt' => 'татар тілі',
        'tt_RU' => 'татар тілі (Ресей)',
        'ug' => 'ұйғыр тілі',
        'ug_CN' => 'ұйғыр тілі (Қытай)',
        'uk' => 'украин тілі',
        'uk_UA' => 'украин тілі (Украина)',
        'ur' => 'урду тілі',
        'ur_IN' => 'урду тілі (Үндістан)',
        'ur_PK' => 'урду тілі (Пәкістан)',
        'uz' => 'өзбек тілі',
        'uz_AF' => 'өзбек тілі (Ауғанстан)',
        'uz_Arab' => 'өзбек тілі (араб жазуы)',
        'uz_Arab_AF' => 'өзбек тілі (араб жазуы, Ауғанстан)',
        'uz_Cyrl' => 'өзбек тілі (кирилл жазуы)',
        'uz_Cyrl_UZ' => 'өзбек тілі (кирилл жазуы, Өзбекстан)',
        'uz_Latn' => 'өзбек тілі (латын жазуы)',
        'uz_Latn_UZ' => 'өзбек тілі (латын жазуы, Өзбекстан)',
        'uz_UZ' => 'өзбек тілі (Өзбекстан)',
        'vi' => 'вьетнам тілі',
        'vi_VN' => 'вьетнам тілі (Вьетнам)',
        'wo' => 'волоф тілі',
        'wo_SN' => 'волоф тілі (Сенегал)',
        'xh' => 'кхоса тілі',
        'xh_ZA' => 'кхоса тілі (Оңтүстік Африка)',
        'yi' => 'идиш тілі',
        'yi_001' => 'идиш тілі (әлем)',
        'yo' => 'йоруба тілі',
        'yo_BJ' => 'йоруба тілі (Бенин)',
        'yo_NG' => 'йоруба тілі (Нигерия)',
        'zh' => 'қытай тілі',
        'zh_CN' => 'қытай тілі (Қытай)',
        'zh_HK' => 'қытай тілі (Сянган АӘА)',
        'zh_Hans' => 'қытай тілі (жеңілдетілген жазу)',
        'zh_Hans_CN' => 'қытай тілі (жеңілдетілген жазу, Қытай)',
        'zh_Hans_HK' => 'қытай тілі (жеңілдетілген жазу, Сянган АӘА)',
        'zh_Hans_MO' => 'қытай тілі (жеңілдетілген жазу, Макао АӘА)',
        'zh_Hans_SG' => 'қытай тілі (жеңілдетілген жазу, Сингапур)',
        'zh_Hant' => 'қытай тілі (дәстүрлі жазу)',
        'zh_Hant_HK' => 'қытай тілі (дәстүрлі жазу, Сянган АӘА)',
        'zh_Hant_MO' => 'қытай тілі (дәстүрлі жазу, Макао АӘА)',
        'zh_Hant_TW' => 'қытай тілі (дәстүрлі жазу, Тайвань)',
        'zh_MO' => 'қытай тілі (Макао АӘА)',
        'zh_SG' => 'қытай тілі (Сингапур)',
        'zh_TW' => 'қытай тілі (Тайвань)',
        'zu' => 'зулу тілі',
        'zu_ZA' => 'зулу тілі (Оңтүстік Африка)',
    ],
];
