<?php

return [
    'Names' => [
        'aa' => 'афарская',
        'ab' => 'абхазская',
        'ace' => 'ачэх',
        'ada' => 'адангмэ',
        'ady' => 'адыгейская',
        'af' => 'афрыкаанс',
        'agq' => 'агем',
        'ain' => 'айнская',
        'ak' => 'акан',
        'akk' => 'акадская',
        'ale' => 'алеуцкая',
        'alt' => 'паўднёваалтайская',
        'am' => 'амхарская',
        'an' => 'арагонская',
        'ang' => 'стараанглійская',
        'ann' => 'абола',
        'anp' => 'ангіка',
        'ar' => 'арабская',
        'arc' => 'арамейская',
        'arn' => 'мапудунгун',
        'arp' => 'арапаха',
        'ars' => 'недждыйская арабская',
        'as' => 'асамская',
        'asa' => 'асу',
        'ast' => 'астурыйская',
        'atj' => 'атыкамек',
        'av' => 'аварская',
        'awa' => 'авадхі',
        'ay' => 'аймара',
        'az' => 'азербайджанская',
        'ba' => 'башкірская',
        'ban' => 'балійская',
        'bas' => 'басаа',
        'be' => 'беларуская',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bg' => 'балгарская',
        'bgn' => 'заходняя белуджская',
        'bho' => 'бхаджпуры',
        'bi' => 'біслама',
        'bin' => 'эда',
        'bla' => 'блэкфут',
        'bm' => 'бамбара',
        'bn' => 'бенгальская',
        'bo' => 'тыбецкая',
        'br' => 'брэтонская',
        'brx' => 'бода',
        'bs' => 'баснійская',
        'bua' => 'бурацкая',
        'bug' => 'бугіс',
        'byn' => 'білен',
        'ca' => 'каталанская',
        'cay' => 'каюга',
        'ccp' => 'чакма',
        'ce' => 'чачэнская',
        'ceb' => 'себуана',
        'cgg' => 'чыга',
        'ch' => 'чамора',
        'chb' => 'чыбча',
        'chk' => 'чуук',
        'chm' => 'мары',
        'cho' => 'чокта',
        'chp' => 'чыпеваян',
        'chr' => 'чэрокі',
        'chy' => 'шэйен',
        'ckb' => 'цэнтральнакурдская',
        'clc' => 'чылькатын',
        'co' => 'карсіканская',
        'cop' => 'копцкая',
        'crg' => 'мічыф',
        'crj' => 'паўднёва-ўсходняя кры',
        'crk' => 'раўнінны кры',
        'crl' => 'паўночна-ўсходняя кры',
        'crm' => 'муская кры',
        'crr' => 'каралінская алганкійская',
        'crs' => 'сэсэльва',
        'cs' => 'чэшская',
        'csw' => 'балотная кры',
        'cu' => 'царкоўнаславянская',
        'cv' => 'чувашская',
        'cy' => 'валійская',
        'da' => 'дацкая',
        'dak' => 'дакота',
        'dar' => 'даргінская',
        'dav' => 'таіта',
        'de' => 'нямецкая',
        'dgr' => 'догрыб',
        'dje' => 'зарма',
        'doi' => 'догры',
        'dsb' => 'ніжнялужыцкая',
        'dua' => 'дуала',
        'dv' => 'мальдыўская',
        'dyo' => 'джола-фоньі',
        'dz' => 'дзонг-кэ',
        'dzg' => 'дазага',
        'ebu' => 'эмбу',
        'ee' => 'эве',
        'efi' => 'эфік',
        'egy' => 'старажытнаегіпецкая',
        'eka' => 'экаджук',
        'el' => 'грэчаская',
        'en' => 'англійская',
        'eo' => 'эсперанта',
        'es' => 'іспанская',
        'et' => 'эстонская',
        'eu' => 'баскская',
        'ewo' => 'эвонда',
        'fa' => 'фарсі',
        'ff' => 'фула',
        'fi' => 'фінская',
        'fil' => 'філіпінская',
        'fj' => 'фіджыйская',
        'fo' => 'фарэрская',
        'fon' => 'фон',
        'fr' => 'французская',
        'frc' => 'каджунская французская',
        'fro' => 'старафранцузская',
        'frr' => 'паўночнафрызская',
        'fur' => 'фрыульская',
        'fy' => 'заходняя фрызская',
        'ga' => 'ірландская',
        'gaa' => 'га',
        'gag' => 'гагаузская',
        'gd' => 'шатландская гэльская',
        'gez' => 'геэз',
        'gil' => 'кірыбаці',
        'gl' => 'галісійская',
        'gn' => 'гуарані',
        'gor' => 'гарантала',
        'grc' => 'старажытнагрэчаская',
        'gsw' => 'швейцарская нямецкая',
        'gu' => 'гуджараці',
        'guz' => 'гусіі',
        'gv' => 'мэнская',
        'gwi' => 'гуіч’ін',
        'ha' => 'хауса',
        'hai' => 'хайда',
        'haw' => 'гавайская',
        'hax' => 'паўднёвая хайда',
        'he' => 'іўрыт',
        'hi' => 'хіндзі',
        'hil' => 'хілігайнон',
        'hmn' => 'хмонг',
        'hr' => 'харвацкая',
        'hsb' => 'верхнялужыцкая',
        'ht' => 'гаіцянская крэольская',
        'hu' => 'венгерская',
        'hup' => 'хупа',
        'hur' => 'халкамелем',
        'hy' => 'армянская',
        'hz' => 'герэра',
        'ia' => 'інтэрлінгва',
        'iba' => 'ібан',
        'ibb' => 'ібібія',
        'id' => 'інданезійская',
        'ie' => 'інтэрлінгвэ',
        'ig' => 'ігба',
        'ii' => 'сычуаньская йі',
        'ikt' => 'заходнеканадская інуктытут',
        'ilo' => 'ілакана',
        'inh' => 'інгушская',
        'io' => 'іда',
        'is' => 'ісландская',
        'it' => 'італьянская',
        'iu' => 'інуктытут',
        'ja' => 'японская',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачамбэ',
        'jv' => 'яванская',
        'ka' => 'грузінская',
        'kab' => 'кабільская',
        'kac' => 'качынская',
        'kaj' => 'дджу',
        'kam' => 'камба',
        'kbd' => 'кабардзінская',
        'kcg' => 'т’яп',
        'kde' => 'макондэ',
        'kea' => 'кабувердыяну',
        'kfo' => 'кора',
        'kgp' => 'каінганг',
        'kha' => 'кхасі',
        'khq' => 'койра чыіні',
        'ki' => 'кікуйю',
        'kj' => 'куаньяма',
        'kk' => 'казахская',
        'kkj' => 'како',
        'kl' => 'грэнландская',
        'kln' => 'календжын',
        'km' => 'кхмерская',
        'kmb' => 'кімбунду',
        'kn' => 'канада',
        'ko' => 'карэйская',
        'koi' => 'комі-пярмяцкая',
        'kok' => 'канкані',
        'kpe' => 'кпеле',
        'kr' => 'кануры',
        'krc' => 'карачай-балкарская',
        'krl' => 'карэльская',
        'kru' => 'курух',
        'ks' => 'кашмірская',
        'ksb' => 'шамбала',
        'ksf' => 'бафія',
        'ksh' => 'кёльнская',
        'ku' => 'курдская',
        'kum' => 'кумыцкая',
        'kv' => 'комі',
        'kw' => 'корнская',
        'kwk' => 'квакіутль',
        'ky' => 'кіргізская',
        'la' => 'лацінская',
        'lad' => 'ладына',
        'lag' => 'лангі',
        'lb' => 'люксембургская',
        'lez' => 'лезгінская',
        'lg' => 'ганда',
        'li' => 'лімбургская',
        'lil' => 'лілуэт',
        'lkt' => 'лакота',
        'ln' => 'лінгала',
        'lo' => 'лаоская',
        'lol' => 'монга',
        'lou' => 'луізіянская крэольская',
        'loz' => 'лозі',
        'lrc' => 'паўночная луры',
        'lsm' => 'саамія',
        'lt' => 'літоўская',
        'lu' => 'луба-катанга',
        'lua' => 'луба-касаі',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'мізо',
        'luy' => 'луйя',
        'lv' => 'латышская',
        'mad' => 'мадурская',
        'mag' => 'магахі',
        'mai' => 'майтхілі',
        'mak' => 'макасар',
        'man' => 'мандынг',
        'mas' => 'маасай',
        'mdf' => 'макшанская',
        'men' => 'мендэ',
        'mer' => 'меру',
        'mfe' => 'марысьен',
        'mg' => 'малагасійская',
        'mgh' => 'макуўа-меета',
        'mgo' => 'мета',
        'mh' => 'маршальская',
        'mi' => 'маары',
        'mic' => 'мікмак',
        'min' => 'мінангкабау',
        'mk' => 'македонская',
        'ml' => 'малаялам',
        'mn' => 'мангольская',
        'mni' => 'мейтэй',
        'moe' => 'іну-аймун',
        'moh' => 'мохак',
        'mos' => 'мосі',
        'mr' => 'маратхі',
        'ms' => 'малайская',
        'mt' => 'мальтыйская',
        'mua' => 'мунданг',
        'mus' => 'мускогі',
        'mwl' => 'мірандыйская',
        'my' => 'бірманская',
        'myv' => 'эрзянская',
        'mzn' => 'мазандэранская',
        'na' => 'науру',
        'nap' => 'неапалітанская',
        'naq' => 'нама',
        'nb' => 'нарвежская (букмол)',
        'nd' => 'паўночная ндэбеле',
        'nds' => 'ніжненямецкая',
        'ne' => 'непальская',
        'new' => 'неўары',
        'ng' => 'ндонга',
        'nia' => 'ніас',
        'niu' => 'ніўэ',
        'nl' => 'нідэрландская',
        'nmg' => 'нгумба',
        'nn' => 'нарвежская (нюношк)',
        'nnh' => 'нг’ембон',
        'no' => 'нарвежская',
        'nog' => 'нагайская',
        'non' => 'старанарвежская',
        'nqo' => 'нко',
        'nr' => 'паўднёвая ндэбеле',
        'nso' => 'паўночная сота',
        'nus' => 'нуэр',
        'nv' => 'наваха',
        'ny' => 'ньянджа',
        'nyn' => 'ньянколе',
        'oc' => 'аксітанская',
        'oj' => 'аджыбвэ',
        'ojb' => 'паўночна-заходняя аджыбвэ',
        'ojc' => 'цэнтральная аджыбвэ',
        'ojs' => 'оджы-кры',
        'ojw' => 'заходняя аджыбвэ',
        'oka' => 'аканаган',
        'om' => 'арома',
        'or' => 'орыя',
        'os' => 'асецінская',
        'pa' => 'панджабі',
        'pag' => 'пангасінан',
        'pam' => 'пампанга',
        'pap' => 'пап’яменту',
        'pau' => 'палау',
        'pcm' => 'нігерыйскі піджын',
        'peo' => 'стараперсідская',
        'phn' => 'фінікійская',
        'pis' => 'саламонскі піджын',
        'pl' => 'польская',
        'pqm' => 'малесіт-пасамакуоды',
        'prg' => 'пруская',
        'pro' => 'стараправансальская',
        'ps' => 'пушту',
        'pt' => 'партугальская',
        'qu' => 'кечуа',
        'quc' => 'кічэ',
        'raj' => 'раджастханская',
        'rap' => 'рапануі',
        'rar' => 'раратонг',
        'rhg' => 'рахінджа',
        'rm' => 'рэтараманская',
        'rn' => 'рундзі',
        'ro' => 'румынская',
        'rof' => 'ромба',
        'ru' => 'руская',
        'rup' => 'арумунская',
        'rw' => 'руанда',
        'rwk' => 'руа',
        'sa' => 'санскрыт',
        'sad' => 'сандаўэ',
        'sah' => 'якуцкая',
        'saq' => 'самбуру',
        'sat' => 'санталі',
        'sba' => 'нгамбай',
        'sbp' => 'сангу',
        'sc' => 'сардзінская',
        'scn' => 'сіцылійская',
        'sco' => 'шатландская',
        'sd' => 'сіндхі',
        'sdh' => 'паўднёвакурдская',
        'se' => 'паўночнасаамская',
        'seh' => 'сена',
        'ses' => 'кайрабора сэні',
        'sg' => 'санга',
        'sga' => 'стараірландская',
        'sh' => 'сербскахарвацкая',
        'shi' => 'ташэльхіт',
        'shn' => 'шан',
        'si' => 'сінгальская',
        'sk' => 'славацкая',
        'sl' => 'славенская',
        'slh' => 'паўднёвая лушуцыд',
        'sm' => 'самоа',
        'sma' => 'паўднёвасаамская',
        'smj' => 'луле-саамская',
        'smn' => 'інары-саамская',
        'sms' => 'колта-саамская',
        'sn' => 'шона',
        'snk' => 'санінке',
        'so' => 'самалі',
        'sq' => 'албанская',
        'sr' => 'сербская',
        'srn' => 'сранан-тонга',
        'ss' => 'суаці',
        'ssy' => 'саха',
        'st' => 'сесута',
        'str' => 'стрэйтс саліш',
        'su' => 'сунда',
        'suk' => 'сукума',
        'sux' => 'шумерская',
        'sv' => 'шведская',
        'sw' => 'суахілі',
        'swb' => 'каморская',
        'syr' => 'сірыйская',
        'ta' => 'тамільская',
        'tce' => 'паўднёвая тутчонэ',
        'te' => 'тэлугу',
        'tem' => 'тэмнэ',
        'teo' => 'тэсо',
        'tet' => 'тэтум',
        'tg' => 'таджыкская',
        'tgx' => 'тагіш',
        'th' => 'тайская',
        'tht' => 'тальтан',
        'ti' => 'тыгрынья',
        'tig' => 'тыгрэ',
        'tk' => 'туркменская',
        'tlh' => 'клінган',
        'tli' => 'тлінгіт',
        'tn' => 'тсвана',
        'to' => 'танганская',
        'tok' => 'такіпона',
        'tpi' => 'ток-пісін',
        'tr' => 'турэцкая',
        'trv' => 'тарока',
        'ts' => 'тсонга',
        'tt' => 'татарская',
        'ttm' => 'паўночная тутчонэ',
        'tum' => 'тумбука',
        'tvl' => 'тувалу',
        'twq' => 'тасаўак',
        'ty' => 'таіці',
        'tyv' => 'тувінская',
        'tzm' => 'сярэднеатлаская тамазігхт',
        'udm' => 'удмурцкая',
        'ug' => 'уйгурская',
        'uk' => 'украінская',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбекская',
        'vai' => 'ваі',
        've' => 'венда',
        'vi' => 'в’етнамская',
        'vo' => 'валапюк',
        'vun' => 'вунджо',
        'wa' => 'валонская',
        'wae' => 'вальшская',
        'wal' => 'волайта',
        'war' => 'варай',
        'wbp' => 'варлпіры',
        'wo' => 'валоф',
        'wuu' => 'ву',
        'xal' => 'калмыцкая',
        'xh' => 'коса',
        'xog' => 'сога',
        'yav' => 'янгбэн',
        'ybb' => 'йемба',
        'yi' => 'ідыш',
        'yo' => 'ёруба',
        'yrl' => 'ньенгату',
        'yue' => 'кантонскі дыялект кітайскай',
        'zap' => 'сапатэк',
        'zgh' => 'стандартная мараканская тамазіхт',
        'zh' => 'кітайская',
        'zu' => 'зулу',
        'zun' => 'зуні',
        'zza' => 'зазакі',
    ],
    'LocalizedNames' => [
        'ar_001' => 'сучасная стандартная арабская',
        'de_AT' => 'аўстрыйская нямецкая',
        'de_CH' => 'швейцарская літаратурная нямецкая',
        'en_AU' => 'аўстралійская англійская',
        'en_CA' => 'канадская англійская',
        'en_GB' => 'брытанская англійская',
        'en_US' => 'амерыканская англійская',
        'es_419' => 'лацінаамерыканская іспанская',
        'es_ES' => 'еўрапейская іспанская',
        'es_MX' => 'мексіканская іспанская',
        'fa_AF' => 'дары',
        'fr_CA' => 'канадская французская',
        'fr_CH' => 'швейцарская французская',
        'nds_NL' => 'ніжнесаксонская',
        'nl_BE' => 'фламандская',
        'pt_BR' => 'бразільская партугальская',
        'pt_PT' => 'еўрапейская партугальская',
        'ro_MD' => 'малдаўская',
        'sw_CD' => 'кангалезская суахілі',
        'zh_Hans' => 'кітайская (спрошчаныя іерогліфы)',
        'zh_Hant' => 'кітайская (традыцыйныя іерогліфы)',
    ],
];
