<?php

return [
    'Names' => [
        'ace' => 'acehnés',
        'alt' => 'altái meridional',
        'arp' => 'arapaho',
        'ars' => 'árabe najdi',
        'bax' => 'bamun',
        'bho' => 'bhojpuri',
        'bla' => 'siksika',
        'bua' => 'buriat',
        'clc' => 'chilcotín',
        'crj' => 'cree del sureste',
        'crl' => 'cree del noreste',
        'crm' => 'moose cree',
        'crr' => 'algonquian',
        'dum' => 'neerlandés medieval',
        'enm' => 'inglés medieval',
        'eu' => 'euskera',
        'frm' => 'francés medieval',
        'gan' => 'gan (China)',
        'gmh' => 'alemán de la alta edad media',
        'grc' => 'griego antiguo',
        'gu' => 'gurayatí',
        'hax' => 'haida del sur',
        'hil' => 'hiligainón',
        'hsn' => 'xiang (China)',
        'ht' => 'criollo haitiano',
        'ikt' => 'inuktitut del oeste de Canadá',
        'inh' => 'ingusetio',
        'kab' => 'cabilio',
        'krc' => 'karachay-balkar',
        'lo' => 'lao',
        'lou' => 'creole de Luisiana',
        'lrc' => 'lorí del norte',
        'lsm' => 'saamia',
        'mga' => 'irlandés medieval',
        'nd' => 'ndebele del norte',
        'nr' => 'ndebele meridional',
        'ojb' => 'ojibwa del noroeste',
        'ojw' => 'ojibwa del oeste',
        'pis' => 'pijín',
        'rm' => 'romanche',
        'se' => 'sami del norte',
        'shu' => 'árabe chadiano',
        'slh' => 'lushootseed del sur',
        'sma' => 'sami meridional',
        'smn' => 'sami de Inari',
        'ss' => 'siswati',
        'str' => 'straits salish',
        'syr' => 'siriaco',
        'tce' => 'tutchone del sur',
        'tet' => 'tetún',
        'ttm' => 'tutchone del norte',
        'tyv' => 'tuviniano',
        'wal' => 'wolayta',
    ],
    'LocalizedNames' => [
        'sw_CD' => 'swahili del Congo',
    ],
];
