<?php

return [
    'Names' => [
        'ak' => 'Akâan',
        'ak_GH' => 'Akâan (Ganäa)',
        'am' => 'Amarîki',
        'am_ET' => 'Amarîki (Etiopïi)',
        'ar' => 'Arâbo',
        'ar_AE' => 'Arâbo (Arâbo Emirâti Ôko)',
        'ar_BH' => 'Arâbo (Bahrâina)',
        'ar_DJ' => 'Arâbo (Dibutùii)',
        'ar_DZ' => 'Arâbo (Alzerïi)',
        'ar_EG' => 'Arâbo (Kâmitâ)',
        'ar_ER' => 'Arâbo (Eritrëe)',
        'ar_IL' => 'Arâbo (Israëli)',
        'ar_IQ' => 'Arâbo (Irâki)',
        'ar_JO' => 'Arâbo (Zordanïi)',
        'ar_KM' => 'Arâbo (Kömôro)',
        'ar_KW' => 'Arâbo (Köwêti)',
        'ar_LB' => 'Arâbo (Libùaan)',
        'ar_LY' => 'Arâbo (Libïi)',
        'ar_MA' => 'Arâbo (Marôko)',
        'ar_MR' => 'Arâbo (Moritanïi)',
        'ar_OM' => 'Arâbo (Omâni)',
        'ar_PS' => 'Arâbo (Sêse tî Palestîni)',
        'ar_QA' => 'Arâbo (Katära)',
        'ar_SA' => 'Arâbo (Saûdi Arabïi)',
        'ar_SD' => 'Arâbo (Sudäan)',
        'ar_SO' => 'Arâbo (Somalïi)',
        'ar_SY' => 'Arâbo (Sirïi)',
        'ar_TD' => 'Arâbo (Tyâde)',
        'ar_TN' => 'Arâbo (Tunizïi)',
        'ar_YE' => 'Arâbo (Yëmêni)',
        'be' => 'Bielörûsi',
        'be_BY' => 'Bielörûsi (Belarüsi)',
        'bg' => 'Bulugäri',
        'bg_BG' => 'Bulugäri (Bulugarïi)',
        'bn' => 'Bengäli',
        'bn_BD' => 'Bengäli (Bengladêshi)',
        'bn_IN' => 'Bengäli (Ênnde)',
        'cs' => 'Tyêki',
        'cs_CZ' => 'Tyêki (Ködörösêse tî Tyêki)',
        'de' => 'Zâmani',
        'de_AT' => 'Zâmani (Otrîsi)',
        'de_BE' => 'Zâmani (Bêleze, Belezîki)',
        'de_CH' => 'Zâmani (Sûîsi)',
        'de_DE' => 'Zâmani (Zâmani)',
        'de_IT' => 'Zâmani (Italùii)',
        'de_LI' => 'Zâmani (Liechtenstein,)',
        'de_LU' => 'Zâmani (Lugzambûru)',
        'el' => 'Gerêki',
        'el_CY' => 'Gerêki (Sîpri)',
        'el_GR' => 'Gerêki (Gerêsi)',
        'en' => 'Anglëe',
        'en_AE' => 'Anglëe (Arâbo Emirâti Ôko)',
        'en_AG' => 'Anglëe (Antîgua na Barbûda)',
        'en_AI' => 'Anglëe (Angûîla)',
        'en_AS' => 'Anglëe (Samöa tî Amerîka)',
        'en_AT' => 'Anglëe (Otrîsi)',
        'en_AU' => 'Anglëe (Ostralïi, Sotralïi)',
        'en_BB' => 'Anglëe (Barabâda)',
        'en_BE' => 'Anglëe (Bêleze, Belezîki)',
        'en_BI' => 'Anglëe (Burundïi)',
        'en_BM' => 'Anglëe (Beremûda)',
        'en_BS' => 'Anglëe (Bahâmasa)',
        'en_BW' => 'Anglëe (Botswana)',
        'en_BZ' => 'Anglëe (Belîzi)',
        'en_CA' => 'Anglëe (Kanadäa)',
        'en_CH' => 'Anglëe (Sûîsi)',
        'en_CK' => 'Anglëe (âzûâ Kûku)',
        'en_CM' => 'Anglëe (Kamerûne)',
        'en_CY' => 'Anglëe (Sîpri)',
        'en_DE' => 'Anglëe (Zâmani)',
        'en_DK' => 'Anglëe (Danemêrke)',
        'en_DM' => 'Anglëe (Dömïnîka)',
        'en_ER' => 'Anglëe (Eritrëe)',
        'en_FI' => 'Anglëe (Fëlânde)',
        'en_FJ' => 'Anglëe (Fidyïi)',
        'en_FK' => 'Anglëe (Âzûâ tî Mälüîni)',
        'en_FM' => 'Anglëe (Mikronezïi)',
        'en_GB' => 'Anglëe (Ködörögbïä--Ôko)',
        'en_GD' => 'Anglëe (Grenâda)',
        'en_GH' => 'Anglëe (Ganäa)',
        'en_GI' => 'Anglëe (Zibraltära, Zibaratära)',
        'en_GM' => 'Anglëe (Gambïi)',
        'en_GU' => 'Anglëe (Guâm)',
        'en_GY' => 'Anglëe (Gayâna)',
        'en_IE' => 'Anglëe (Irlânde)',
        'en_IL' => 'Anglëe (Israëli)',
        'en_IN' => 'Anglëe (Ênnde)',
        'en_IO' => 'Anglëe (Sêse tî Anglëe na Ngûyämä tî Ênnde)',
        'en_JM' => 'Anglëe (Zamaîka)',
        'en_KE' => 'Anglëe (Kenyäa)',
        'en_KI' => 'Anglëe (Kiribati)',
        'en_KN' => 'Anglëe (Sên-Krïstôfo-na-Nevîsi)',
        'en_KY' => 'Anglëe (Âzûâ Ngundë, Kaimäni)',
        'en_LC' => 'Anglëe (Sênt-Lisïi)',
        'en_LR' => 'Anglëe (Liberïa)',
        'en_LS' => 'Anglëe (Lesôtho)',
        'en_MG' => 'Anglëe (Madagaskära)',
        'en_MH' => 'Anglëe (Âzûâ Märshâl)',
        'en_MP' => 'Anglëe (Âzûâ Märïâni tî Banga)',
        'en_MS' => 'Anglëe (Monserâte)',
        'en_MT' => 'Anglëe (Mâlta)',
        'en_MU' => 'Anglëe (Mörîsi)',
        'en_MV' => 'Anglëe (Maldîva)',
        'en_MW' => 'Anglëe (Malawïi)',
        'en_MY' => 'Anglëe (Malezïi)',
        'en_NA' => 'Anglëe (Namibùii)',
        'en_NF' => 'Anglëe (Zûâ Nôrfôlko)',
        'en_NG' => 'Anglëe (Nizerïa)',
        'en_NL' => 'Anglëe (Holände)',
        'en_NR' => 'Anglëe (Nauru)',
        'en_NU' => 'Anglëe (Niue)',
        'en_NZ' => 'Anglëe (Finî Zelânde)',
        'en_PG' => 'Anglëe (Papû Finî Ginëe, Papuazïi)',
        'en_PH' => 'Anglëe (Filipîni)',
        'en_PK' => 'Anglëe (Pakistäan)',
        'en_PN' => 'Anglëe (Pitikêrni)',
        'en_PR' => 'Anglëe (Porto Rîko)',
        'en_PW' => 'Anglëe (Palau)',
        'en_RW' => 'Anglëe (Ruandäa)',
        'en_SB' => 'Anglëe (Zûâ Salomöon)',
        'en_SC' => 'Anglëe (Sëyshêle)',
        'en_SD' => 'Anglëe (Sudäan)',
        'en_SE' => 'Anglëe (Suêde)',
        'en_SG' => 'Anglëe (Sïngäpûru)',
        'en_SH' => 'Anglëe (Sênt-Helêna)',
        'en_SI' => 'Anglëe (Solovenïi)',
        'en_SL' => 'Anglëe (Sierä-Leône)',
        'en_SZ' => 'Anglëe (Swäzïlânde)',
        'en_TC' => 'Anglëe (Âzûâ Turku na Kaîki)',
        'en_TK' => 'Anglëe (Tokelau)',
        'en_TO' => 'Anglëe (Tonga)',
        'en_TT' => 'Anglëe (Trinitùee na Tobagö)',
        'en_TV' => 'Anglëe (Tüvalü)',
        'en_TZ' => 'Anglëe (Tanzanïi)',
        'en_UG' => 'Anglëe (Ugandäa)',
        'en_US' => 'Anglëe (ÂLeaa-Ôko tî Amerika)',
        'en_VC' => 'Anglëe (Sên-Vensäan na âGrenadîni)',
        'en_VG' => 'Anglëe (Âzôâ Viîrîggo tî Anglëe)',
        'en_VI' => 'Anglëe (Âzûâ Virîgo tî Amerîka)',
        'en_VU' => 'Anglëe (Vanuatü)',
        'en_WS' => 'Anglëe (Samoäa)',
        'en_ZA' => 'Anglëe (Mbongo-Afrîka)',
        'en_ZM' => 'Anglëe (Zambïi)',
        'en_ZW' => 'Anglëe (Zimbäbwe)',
        'es' => 'Espanyöl',
        'es_AR' => 'Espanyöl (Arzantîna)',
        'es_BO' => 'Espanyöl (Bolivïi)',
        'es_BR' => 'Espanyöl (Brezîli)',
        'es_BZ' => 'Espanyöl (Belîzi)',
        'es_CL' => 'Espanyöl (Shilïi)',
        'es_CO' => 'Espanyöl (Kolombïi)',
        'es_CR' => 'Espanyöl (Kôsta Rîka)',
        'es_CU' => 'Espanyöl (Kubäa)',
        'es_DO' => 'Espanyöl (Ködörösêse tî Dominîka)',
        'es_EC' => 'Espanyöl (Ekuatëre)',
        'es_ES' => 'Espanyöl (Espânye)',
        'es_GQ' => 'Espanyöl (Ginëe tî Ekuatëre)',
        'es_GT' => 'Espanyöl (Guatêmälä)',
        'es_HN' => 'Espanyöl (Honduräsi)',
        'es_MX' => 'Espanyöl (Mekisîki)',
        'es_NI' => 'Espanyöl (Nikaragua)',
        'es_PA' => 'Espanyöl (Panama)',
        'es_PE' => 'Espanyöl (Perüu)',
        'es_PH' => 'Espanyöl (Filipîni)',
        'es_PR' => 'Espanyöl (Porto Rîko)',
        'es_PY' => 'Espanyöl (Paraguëe)',
        'es_SV' => 'Espanyöl (Salvadöro)',
        'es_US' => 'Espanyöl (ÂLeaa-Ôko tî Amerika)',
        'es_UY' => 'Espanyöl (Uruguëe)',
        'es_VE' => 'Espanyöl (Venezueläa)',
        'fa' => 'Farsî',
        'fa_AF' => 'Farsî (Faganïta, Afganïstäan)',
        'fa_IR' => 'Farsî (Iräan)',
        'fr' => 'Farânzi',
        'fr_BE' => 'Farânzi (Bêleze, Belezîki)',
        'fr_BF' => 'Farânzi (Burkina Faso)',
        'fr_BI' => 'Farânzi (Burundïi)',
        'fr_BJ' => 'Farânzi (Benëen)',
        'fr_CA' => 'Farânzi (Kanadäa)',
        'fr_CD' => 'Farânzi (Ködörösêse tî Ngunuhalëzo tî kongö)',
        'fr_CF' => 'Farânzi (Ködörösêse tî Bêafrîka)',
        'fr_CG' => 'Farânzi (Kongö)',
        'fr_CH' => 'Farânzi (Sûîsi)',
        'fr_CI' => 'Farânzi (Kôdivüära)',
        'fr_CM' => 'Farânzi (Kamerûne)',
        'fr_DJ' => 'Farânzi (Dibutùii)',
        'fr_DZ' => 'Farânzi (Alzerïi)',
        'fr_FR' => 'Farânzi (Farânzi)',
        'fr_GA' => 'Farânzi (Gaböon)',
        'fr_GF' => 'Farânzi (Güyâni tî farânzi)',
        'fr_GN' => 'Farânzi (Ginëe)',
        'fr_GP' => 'Farânzi (Guadelûpu)',
        'fr_GQ' => 'Farânzi (Ginëe tî Ekuatëre)',
        'fr_HT' => 'Farânzi (Haitïi)',
        'fr_KM' => 'Farânzi (Kömôro)',
        'fr_LU' => 'Farânzi (Lugzambûru)',
        'fr_MA' => 'Farânzi (Marôko)',
        'fr_MC' => 'Farânzi (Monaköo)',
        'fr_MG' => 'Farânzi (Madagaskära)',
        'fr_ML' => 'Farânzi (Malïi)',
        'fr_MQ' => 'Farânzi (Märtïnîki)',
        'fr_MR' => 'Farânzi (Moritanïi)',
        'fr_MU' => 'Farânzi (Mörîsi)',
        'fr_NC' => 'Farânzi (Finî Kaledonïi)',
        'fr_NE' => 'Farânzi (Nizëre)',
        'fr_PF' => 'Farânzi (Polinezïi tî farânzi)',
        'fr_PM' => 'Farânzi (Sên-Pyêre na Mikelöon)',
        'fr_RE' => 'Farânzi (Reinïon)',
        'fr_RW' => 'Farânzi (Ruandäa)',
        'fr_SC' => 'Farânzi (Sëyshêle)',
        'fr_SN' => 'Farânzi (Senegäle)',
        'fr_SY' => 'Farânzi (Sirïi)',
        'fr_TD' => 'Farânzi (Tyâde)',
        'fr_TG' => 'Farânzi (Togö)',
        'fr_TN' => 'Farânzi (Tunizïi)',
        'fr_VU' => 'Farânzi (Vanuatü)',
        'fr_WF' => 'Farânzi (Walîsi na Futuna)',
        'fr_YT' => 'Farânzi (Mäyôte)',
        'ha' => 'Haüsä',
        'ha_GH' => 'Haüsä (Ganäa)',
        'ha_NE' => 'Haüsä (Nizëre)',
        'ha_NG' => 'Haüsä (Nizerïa)',
        'hi' => 'Hîndi',
        'hi_IN' => 'Hîndi (Ênnde)',
        'hu' => 'Hongruäa',
        'hu_HU' => 'Hongruäa (Hongirùii)',
        'id' => 'Enndonezïi',
        'id_ID' => 'Enndonezïi (Ênndonezïi)',
        'ig' => 'Ïgbö',
        'ig_NG' => 'Ïgbö (Nizerïa)',
        'it' => 'Ênnde',
        'it_CH' => 'Ênnde (Sûîsi)',
        'it_IT' => 'Ênnde (Italùii)',
        'it_SM' => 'Ênnde (Sên-Marëen)',
        'it_VA' => 'Ênnde (Letëe tî Vatikäan)',
        'ja' => 'Zaponëe',
        'ja_JP' => 'Zaponëe (Zapöon)',
        'jv' => 'Zavanëe',
        'jv_ID' => 'Zavanëe (Ênndonezïi)',
        'km' => 'Kmêre',
        'km_KH' => 'Kmêre (Kämbôzi)',
        'ko' => 'Koreyëen',
        'ko_KP' => 'Koreyëen (Korëe tî Banga)',
        'ko_KR' => 'Koreyëen (Korëe tî Mbongo)',
        'ms' => 'Malëe',
        'ms_BN' => 'Malëe (Brunêi)',
        'ms_ID' => 'Malëe (Ênndonezïi)',
        'ms_MY' => 'Malëe (Malezïi)',
        'ms_SG' => 'Malëe (Sïngäpûru)',
        'my' => 'Miamära, Birimäni',
        'my_MM' => 'Miamära, Birimäni (Myämâra)',
        'ne' => 'Nepalëe',
        'ne_IN' => 'Nepalëe (Ênnde)',
        'ne_NP' => 'Nepalëe (Nëpâli)',
        'nl' => 'Holandëe',
        'nl_AW' => 'Holandëe (Arûba)',
        'nl_BE' => 'Holandëe (Bêleze, Belezîki)',
        'nl_NL' => 'Holandëe (Holände)',
        'nl_SR' => 'Holandëe (Surinäm)',
        'pa' => 'Penzäbï',
        'pa_IN' => 'Penzäbï (Ênnde)',
        'pa_PK' => 'Penzäbï (Pakistäan)',
        'pl' => 'Polonëe',
        'pl_PL' => 'Polonëe (Pölôni)',
        'pt' => 'Portugëe, Pûra',
        'pt_AO' => 'Portugëe, Pûra (Angoläa)',
        'pt_BR' => 'Portugëe, Pûra (Brezîli)',
        'pt_CH' => 'Portugëe, Pûra (Sûîsi)',
        'pt_CV' => 'Portugëe, Pûra (Azûâ tî Kâpo-Vêre)',
        'pt_GQ' => 'Portugëe, Pûra (Ginëe tî Ekuatëre)',
        'pt_GW' => 'Portugëe, Pûra (Gninëe-Bisau)',
        'pt_LU' => 'Portugëe, Pûra (Lugzambûru)',
        'pt_MZ' => 'Portugëe, Pûra (Mözämbîka)',
        'pt_PT' => 'Portugëe, Pûra (Pörtugäle, Ködörö Pûra)',
        'pt_ST' => 'Portugëe, Pûra (Sâô Tömê na Prinsîpe)',
        'pt_TL' => 'Portugëe, Pûra (Timôro tî Tö)',
        'ro' => 'Rumëen',
        'ro_MD' => 'Rumëen (Moldavùii)',
        'ro_RO' => 'Rumëen (Rumanïi)',
        'ru' => 'Rûsi',
        'ru_BY' => 'Rûsi (Belarüsi)',
        'ru_KG' => 'Rûsi (Kirigizitùaan)',
        'ru_KZ' => 'Rûsi (Kazakisitäan)',
        'ru_MD' => 'Rûsi (Moldavùii)',
        'ru_RU' => 'Rûsi (Rusïi)',
        'ru_UA' => 'Rûsi (Ukrêni)',
        'rw' => 'Ruandäa',
        'rw_RW' => 'Ruandäa (Ruandäa)',
        'sg' => 'Sängö',
        'sg_CF' => 'Sängö (Ködörösêse tî Bêafrîka)',
        'so' => 'Somalïi',
        'so_DJ' => 'Somalïi (Dibutùii)',
        'so_ET' => 'Somalïi (Etiopïi)',
        'so_KE' => 'Somalïi (Kenyäa)',
        'so_SO' => 'Somalïi (Somalïi)',
        'sv' => 'Sueduäa',
        'sv_FI' => 'Sueduäa (Fëlânde)',
        'sv_SE' => 'Sueduäa (Suêde)',
        'ta' => 'Tämûli',
        'ta_IN' => 'Tämûli (Ênnde)',
        'ta_LK' => 'Tämûli (Sirî-Lanka)',
        'ta_MY' => 'Tämûli (Malezïi)',
        'ta_SG' => 'Tämûli (Sïngäpûru)',
        'th' => 'Thâi',
        'th_TH' => 'Thâi (Tailânde)',
        'tr' => 'Tûrûku',
        'tr_CY' => 'Tûrûku (Sîpri)',
        'tr_TR' => 'Tûrûku (Turukïi)',
        'uk' => 'Ukrêni',
        'uk_UA' => 'Ukrêni (Ukrêni)',
        'ur' => 'Ûrdu',
        'ur_IN' => 'Ûrdu (Ênnde)',
        'ur_PK' => 'Ûrdu (Pakistäan)',
        'vi' => 'Vietnäm',
        'vi_VN' => 'Vietnäm (Vietnäm)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benëen)',
        'yo_NG' => 'Yoruba (Nizerïa)',
        'zh' => 'Shinuäa',
        'zh_CN' => 'Shinuäa (Shîna)',
        'zh_SG' => 'Shinuäa (Sïngäpûru)',
        'zh_TW' => 'Shinuäa (Tâiwâni)',
        'zu' => 'Zûlu',
        'zu_ZA' => 'Zûlu (Mbongo-Afrîka)',
    ],
];
