<?php

$attributemap = [
    'urn:mace:dir:attribute-def:sn'                         => 'sn',
    'urn:mace:dir:attribute-def:telephoneNumber'            => 'telephoneNumber',
    'urn:mace:dir:attribute-def:facsimileTelephoneNumber'   => 'facsimileTelephoneNumber',
    'urn:mace:dir:attribute-def:postalAddress'              => 'postalAddress',
    'urn:mace:dir:attribute-def:givenName'                  => 'givenName',
    'urn:mace:dir:attribute-def:homePhone'                  => 'homePhone',
    'urn:mace:dir:attribute-def:homePostalAddress'          => 'homePostalAddress',
    'urn:mace:dir:attribute-def:mail'                       => 'mail',
    'urn:mace:dir:attribute-def:mobile'                     => 'mobile',
    'urn:mace:dir:attribute-def:preferredLanguage'          => 'preferredLanguage',
    'urn:mace:dir:attribute-def:eduPersonPrincipalName'     => 'eduPersonPrincipalName',
    'urn:mace:dir:attribute-def:eduPersonAffiliation'       => 'eduPersonAffiliation',
    'urn:mace:dir:attribute-def:eduPersonScopedAffiliation' => 'eduPersonScopedAffiliation',
    'urn:mace:dir:attribute-def:eduPersonEntitlement'       => 'eduPersonEntitlement',
    'urn:mace:dir:attribute-def:eduPersonOrgDN'             => 'eduPersonOrgDN',
    'urn:mace:dir:attribute-def:eduPersonOrgUnitDN'         => 'eduPersonOrgUnitDN',
];
