<?php

return [
    'Names' => [
        'ak' => 'akan',
        'am' => 'liamariki',
        'ar' => 'lialabo',
        'be' => 'libyelorisí',
        'bg' => 'libiligali',
        'bn' => 'libengali',
        'cs' => 'litshekɛ',
        'de' => 'lialemá',
        'el' => 'ligeleki',
        'en' => 'lingɛlɛ́sa',
        'es' => 'lisipanye',
        'fa' => 'lipelésanɛ',
        'fr' => 'lifalansɛ́',
        'ha' => 'hausa',
        'hi' => 'lihindi',
        'hu' => 'liongili',
        'id' => 'lindonezi',
        'ig' => 'igbo',
        'it' => 'litaliano',
        'ja' => 'lizapɔ',
        'jv' => 'lizava',
        'km' => 'likambodza',
        'ko' => 'likoreya',
        'ln' => 'lingála',
        'ms' => 'limalezi',
        'my' => 'libilimá',
        'ne' => 'linepalɛ',
        'nl' => 'lifalamá',
        'pa' => 'lipendzabi',
        'pl' => 'lipolonɛ',
        'pt' => 'lipulutugɛ́si',
        'ro' => 'liromani',
        'ru' => 'lirisí',
        'rw' => 'kinyarwanda',
        'so' => 'lisomali',
        'sv' => 'lisuwedɛ',
        'ta' => 'litamuli',
        'th' => 'litaye',
        'tr' => 'litiliki',
        'uk' => 'likrɛni',
        'ur' => 'liurdu',
        'vi' => 'liviyetinámi',
        'yo' => 'yoruba',
        'zh' => 'lisinwa',
        'zu' => 'zulu',
    ],
    'LocalizedNames' => [
    ],
];
