<?php

return [
    'Names' => [
        'ab' => 'abcasu',
        'ace' => 'acehnesu',
        'ada' => 'adangme',
        'ady' => 'adighè',
        'af' => 'afrikaans',
        'agq' => 'aghem',
        'ain' => 'àinu',
        'ak' => 'akan',
        'ale' => 'aleutinu',
        'alt' => 'altai meridionale',
        'am' => 'amàricu',
        'an' => 'aragonesu',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'àrabu',
        'arn' => 'mapudungun',
        'arp' => 'arapaho',
        'ars' => 'àrabu najdi',
        'as' => 'assamesu',
        'asa' => 'asu',
        'ast' => 'asturianu',
        'atj' => 'atikamekw',
        'av' => 'avaru',
        'awa' => 'awadhi',
        'ay' => 'aimara',
        'az' => 'azerbaigianu',
        'ba' => 'baschiru',
        'ban' => 'balinesu',
        'bas' => 'basaa',
        'be' => 'bielorussu',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bùlgaru',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bin' => 'bini',
        'bla' => 'pees nieddos',
        'bm' => 'bambara',
        'bn' => 'bengalesu',
        'bo' => 'tibetanu',
        'br' => 'brètone',
        'brx' => 'bodo',
        'bs' => 'bosnìacu',
        'bug' => 'buginesu',
        'byn' => 'blin',
        'ca' => 'catalanu',
        'cay' => 'cayuga',
        'ccp' => 'chakma',
        'ce' => 'cecenu',
        'ceb' => 'cebuanu',
        'cgg' => 'chiga',
        'ch' => 'chamorru',
        'chk' => 'chuukesu',
        'chm' => 'mari',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'curdu tzentrale',
        'clc' => 'chilcotin',
        'co' => 'corsicanu',
        'crg' => 'michif',
        'crj' => 'cree sud-orientale',
        'crk' => 'cree de sas campuras',
        'crl' => 'cree nord-orientale',
        'crm' => 'cree moose',
        'crr' => 'algonchinu de sa Carolina',
        'cs' => 'tzecu',
        'csw' => 'cree de sas paludes',
        'cu' => 'islavu eclesiàsticu',
        'cv' => 'ciuvàsciu',
        'cy' => 'gallesu',
        'da' => 'danesu',
        'dak' => 'dakota',
        'dar' => 'dargua',
        'dav' => 'taita',
        'de' => 'tedescu',
        'dgr' => 'dogrib',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'sòrabu bassu',
        'dua' => 'duala',
        'dv' => 'malvidianu',
        'dyo' => 'jola-fonyi',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'eka' => 'ekajuk',
        'el' => 'grecu',
        'en' => 'inglesu',
        'eo' => 'esperanto',
        'es' => 'ispagnolu',
        'et' => 'èstone',
        'eu' => 'bascu',
        'ewo' => 'ewondo',
        'fa' => 'persianu',
        'ff' => 'fulah',
        'fi' => 'finlandesu',
        'fil' => 'filipinu',
        'fj' => 'fijianu',
        'fo' => 'faroesu',
        'fon' => 'fon',
        'fr' => 'frantzesu',
        'frc' => 'frantzesu cajun',
        'frr' => 'frisone setentrionale',
        'fur' => 'friulanu',
        'fy' => 'frisone otzidentale',
        'ga' => 'irlandesu',
        'gaa' => 'ga',
        'gd' => 'gaèlicu iscotzesu',
        'gez' => 'ge’ez',
        'gil' => 'gilbertesu',
        'gl' => 'galitzianu',
        'gn' => 'guaranì',
        'gor' => 'gorontalo',
        'gsw' => 'tedescu isvìtzeru',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'mannesu',
        'gwi' => 'gwichʼin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'haw' => 'hawaianu',
        'hax' => 'haida meridionale',
        'he' => 'ebreu',
        'hi' => 'hindi',
        'hil' => 'ilongu',
        'hmn' => 'hmong',
        'hr' => 'croatu',
        'hsb' => 'sòrabu artu',
        'ht' => 'crèolu haitianu',
        'hu' => 'ungheresu',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armenu',
        'hz' => 'herero',
        'ia' => 'interlìngua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesianu',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ikt' => 'inuktitut canadesu otzidentale',
        'ilo' => 'ilocanu',
        'inh' => 'ingùsciu',
        'io' => 'ido',
        'is' => 'islandesu',
        'it' => 'italianu',
        'iu' => 'inuktitut',
        'ja' => 'giaponesu',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'giavanesu',
        'ka' => 'georgianu',
        'kab' => 'cabilu',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kbd' => 'cabardianu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'cabubirdianu',
        'kfo' => 'koro',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kazacu',
        'kkj' => 'kako',
        'kl' => 'groenlandesu',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'coreanu',
        'kok' => 'konkani',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'caraciai-balcaru',
        'krl' => 'carelianu',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'coloniesu',
        'ku' => 'curdu',
        'kum' => 'cumucu',
        'kv' => 'komi',
        'kw' => 'còrnicu',
        'kwk' => 'kwakʼwala',
        'ky' => 'chirghisu',
        'la' => 'latinu',
        'lad' => 'giudeu-ispagnolu',
        'lag' => 'langi',
        'lb' => 'lussemburghesu',
        'lez' => 'lezghianu',
        'lg' => 'ganda',
        'li' => 'limburghesu',
        'lij' => 'lìgure',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'laotianu',
        'lou' => 'crèolu de sa Louisiana',
        'loz' => 'lozi',
        'lrc' => 'luri setentrionale',
        'lsm' => 'sàmia',
        'lt' => 'lituanu',
        'lu' => 'luba-katanga',
        'lua' => 'tshiluba',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'lètone',
        'mad' => 'maduresu',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makassaresu',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'crèolu mauritzianu',
        'mg' => 'malgàsciu',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshallesu',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'matzèdone',
        'ml' => 'malayalam',
        'mn' => 'mòngolu',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'moore',
        'mr' => 'marathi',
        'ms' => 'malesu',
        'mt' => 'maltesu',
        'mua' => 'mundang',
        'mus' => 'muscogee',
        'mwl' => 'mirandesu',
        'my' => 'burmesu',
        'myv' => 'erzya',
        'mzn' => 'mazandarani',
        'na' => 'nauru',
        'nap' => 'napoletanu',
        'naq' => 'nama',
        'nb' => 'norvegesu bokmål',
        'nd' => 'ndebele de su nord',
        'nds' => 'tedescu bassu',
        'ne' => 'nepalesu',
        'new' => 'nepal bhasa',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niueanu',
        'nl' => 'olandesu',
        'nmg' => 'kwasio',
        'nn' => 'norvegesu nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norvegesu',
        'nog' => 'nogai',
        'nqo' => 'n’ko',
        'nr' => 'ndebele de su sud',
        'nso' => 'sotho setentrionale',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'ny' => 'nyanja',
        'nyn' => 'nyankole',
        'oc' => 'otzitanu',
        'ojb' => 'ojibwa nord-otzidentale',
        'ojc' => 'ojibwa tzentrale',
        'ojs' => 'oji-Cree',
        'ojw' => 'ojibwa otzidentale',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'odia',
        'os' => 'ossèticu',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pam' => 'pampanga',
        'pap' => 'papiamentu',
        'pau' => 'palauanu',
        'pcm' => 'pidgin nigerianu',
        'pis' => 'pijin',
        'pl' => 'polacu',
        'pqm' => 'malecite-passamaquoddy',
        'prg' => 'prussianu',
        'ps' => 'pashto',
        'pt' => 'portoghesu',
        'qu' => 'quechua',
        'rap' => 'rapanui',
        'rar' => 'rarotonganu',
        'rhg' => 'rohingya',
        'rm' => 'romànciu',
        'rn' => 'rundi',
        'ro' => 'rumenu',
        'rof' => 'rombo',
        'ru' => 'russu',
        'rup' => 'arumenu',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sànscritu',
        'sad' => 'sandawe',
        'sah' => 'yakut',
        'saq' => 'samburu',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardu',
        'scn' => 'sitzilianu',
        'sco' => 'scots',
        'sd' => 'sindhi',
        'se' => 'sami setentrionale',
        'seh' => 'sena',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'shi' => 'tashelhit',
        'shn' => 'shan',
        'si' => 'singalesu',
        'sk' => 'islovacu',
        'sl' => 'islovenu',
        'slh' => 'lushootseed meridionale',
        'sm' => 'samoanu',
        'smn' => 'sami de sos inari',
        'sms' => 'sami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'sòmalu',
        'sq' => 'albanesu',
        'sr' => 'serbu',
        'srn' => 'sranan tongo',
        'ss' => 'swati',
        'st' => 'sotho meridionale',
        'str' => 'salish de sas astrinturas',
        'su' => 'sundanesu',
        'suk' => 'sukuma',
        'sv' => 'isvedesu',
        'sw' => 'swahili',
        'swb' => 'comorianu',
        'syr' => 'sirìacu',
        'ta' => 'tamil',
        'tce' => 'tutchone meridionale',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'tet' => 'tetum',
        'tg' => 'tagicu',
        'tgx' => 'tagish',
        'th' => 'tailandesu',
        'tht' => 'tahltan',
        'ti' => 'tigrignu',
        'tig' => 'tigrè',
        'tk' => 'turcmenu',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tn' => 'tswana',
        'to' => 'tonganu',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turcu',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tt' => 'tàtaru',
        'ttm' => 'tutchone setentrionale',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'twq' => 'tasawaq',
        'ty' => 'taitianu',
        'tyv' => 'tuvanu',
        'tzm' => 'tamazight de s’Atlànte tzentrale',
        'udm' => 'udmurtu',
        'ug' => 'uiguru',
        'uk' => 'ucrainu',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbecu',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'vènetu',
        'vi' => 'vietnamita',
        'vo' => 'volapük',
        'vun' => 'vunjo',
        'wa' => 'vallonu',
        'wae' => 'walser',
        'wal' => 'wolaita',
        'war' => 'waray',
        'wo' => 'wolof',
        'wuu' => 'wu',
        'xal' => 'calmucu',
        'xh' => 'xhosa',
        'xog' => 'soga',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'yiddish',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'cantonesu',
        'zgh' => 'tamazight istandard marochinu',
        'zh' => 'tzinesu',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zazaki',
    ],
    'LocalizedNames' => [
        'ar_001' => 'àrabu modernu istandard',
        'de_AT' => 'tedescu austrìacu',
        'de_CH' => 'tedescu artu isvìtzeru',
        'en_AU' => 'inglesu australianu',
        'en_CA' => 'inglesu canadesu',
        'en_GB' => 'inglesu britànnicu',
        'en_US' => 'inglesu americanu',
        'es_419' => 'ispagnolu latinoamericanu',
        'es_ES' => 'ispagnolu europeu',
        'es_MX' => 'ispagnolu messicanu',
        'fa_AF' => 'dari',
        'fr_CA' => 'frantzesu canadesu',
        'fr_CH' => 'frantzesu isvìtzeru',
        'hi_Latn' => 'hindi (caràteres latinos)',
        'nds_NL' => 'sàssone bassu',
        'nl_BE' => 'fiammingu',
        'pt_BR' => 'portoghesu brasilianu',
        'pt_PT' => 'portoghesu europeu',
        'ro_MD' => 'moldavu',
        'sw_CD' => 'swahili de su Congo',
        'zh_Hans' => 'tzinesu semplificadu',
        'zh_Hant' => 'tzinesu traditzionale',
    ],
];
