<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ဂရင်းနစ် စံတော်ချိန် (အာဘီဂျန်)',
        'Africa/Accra' => 'ဂရင်းနစ် စံတော်ချိန် (အက်ကရာ)',
        'Africa/Addis_Ababa' => 'အရှေ့အာဖရိက အချိန် (အားဒစ် အဘာဘာ)',
        'Africa/Algiers' => 'ဥရောပအလယ်ပိုင်း အချိန် (အယ်လ်ဂျီးရီးယား)',
        'Africa/Asmera' => 'အရှေ့အာဖရိက အချိန် (အားစ်မားရာ)',
        'Africa/Bamako' => 'ဂရင်းနစ် စံတော်ချိန် (ဘာမာကို)',
        'Africa/Bangui' => 'အနောက်အာဖရိက အချိန် (ဘာန်ဂီး)',
        'Africa/Banjul' => 'ဂရင်းနစ် စံတော်ချိန် (ဘန်ဂျုးလ်)',
        'Africa/Bissau' => 'ဂရင်းနစ် စံတော်ချိန် (ဘီစာအို)',
        'Africa/Blantyre' => 'အလယ်အာဖရိက အချိန် (ဘလန်တိုင်းရဲလ်)',
        'Africa/Brazzaville' => 'အနောက်အာဖရိက အချိန် (ဘရားဇာဗီးလ်)',
        'Africa/Bujumbura' => 'အလယ်အာဖရိက အချိန် (ဘူဂျွန်ဘူးရာ)',
        'Africa/Cairo' => 'အရှေ့ဥရောပ အချိန် (ကိုင်ရို)',
        'Africa/Casablanca' => 'အနောက်ဥရောပ အချိန် (ကာဆာဘလန်ကာ)',
        'Africa/Ceuta' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဆီရူးတာ)',
        'Africa/Conakry' => 'ဂရင်းနစ် စံတော်ချိန် (ကိုနာကရီး)',
        'Africa/Dakar' => 'ဂရင်းနစ် စံတော်ချိန် (ဒကျကား)',
        'Africa/Dar_es_Salaam' => 'အရှေ့အာဖရိက အချိန် (ဒါရက်စ်ဆာလမ်)',
        'Africa/Djibouti' => 'အရှေ့အာဖရိက အချိန် (ဂျီဘူတီ)',
        'Africa/Douala' => 'အနောက်အာဖရိက အချိန် (ဒိုအူအာလာ)',
        'Africa/El_Aaiun' => 'အနောက်ဥရောပ အချိန် (အယ်လ်အာယွန်း)',
        'Africa/Freetown' => 'ဂရင်းနစ် စံတော်ချိန် (ဖရီးတောင်းန်)',
        'Africa/Gaborone' => 'အလယ်အာဖရိက အချိန် (ဂါဘာရွန်းနီ)',
        'Africa/Harare' => 'အလယ်အာဖရိက အချိန် (ဟာရားရဲယ်)',
        'Africa/Johannesburg' => 'တောင်အာဖရိက အချိန် (ဂျိုဟန်းနက်စဘတ်)',
        'Africa/Juba' => 'အလယ်အာဖရိက အချိန် (ဂျုဘာ)',
        'Africa/Kampala' => 'အရှေ့အာဖရိက အချိန် (ကမ်ပါလာ)',
        'Africa/Khartoum' => 'အလယ်အာဖရိက အချိန် (ခါတိုအန်)',
        'Africa/Kigali' => 'အလယ်အာဖရိက အချိန် (ကီဂါးလီ)',
        'Africa/Kinshasa' => 'အနောက်အာဖရိက အချိန် (ကင်ရှာစာ)',
        'Africa/Lagos' => 'အနောက်အာဖရိက အချိန် (လာဂိုစ်)',
        'Africa/Libreville' => 'အနောက်အာဖရိက အချိန် (လီဗရာဗီးလ်)',
        'Africa/Lome' => 'ဂရင်းနစ် စံတော်ချိန် (လိုမီ)',
        'Africa/Luanda' => 'အနောက်အာဖရိက အချိန် (လူဝမ်ဒါ)',
        'Africa/Lubumbashi' => 'အလယ်အာဖရိက အချိန် (လူဘွန်းဘာရှီ)',
        'Africa/Lusaka' => 'အလယ်အာဖရိက အချိန် (လူစာကာ)',
        'Africa/Malabo' => 'အနောက်အာဖရိက အချိန် (မာလာဘို)',
        'Africa/Maputo' => 'အလယ်အာဖရိက အချိန် (မာပူးတို)',
        'Africa/Maseru' => 'တောင်အာဖရိက အချိန် (မာဆူရူး)',
        'Africa/Mbabane' => 'တောင်အာဖရိက အချိန် (ဘားဘာန်း)',
        'Africa/Mogadishu' => 'အရှေ့အာဖရိက အချိန် (မော်ဂါဒီးသျုး)',
        'Africa/Monrovia' => 'ဂရင်းနစ် စံတော်ချိန် (မွန်ရိုးဗီးယား)',
        'Africa/Nairobi' => 'အရှေ့အာဖရိက အချိန် (နိုင်ရိုဘီ)',
        'Africa/Ndjamena' => 'အနောက်အာဖရိက အချိန် (အင်ဂျာမီနာ)',
        'Africa/Niamey' => 'အနောက်အာဖရိက အချိန် (ညာမဲယ်)',
        'Africa/Nouakchott' => 'ဂရင်းနစ် စံတော်ချိန် (နိုအာ့ခ်ရှော့တ်)',
        'Africa/Ouagadougou' => 'ဂရင်းနစ် စံတော်ချိန် (ဝါဂါဒူးဂူ)',
        'Africa/Porto-Novo' => 'အနောက်အာဖရိက အချိန် (ပိုတို-နိုဗို)',
        'Africa/Sao_Tome' => 'ဂရင်းနစ် စံတော်ချိန် (ဆောင်တူမေး)',
        'Africa/Tripoli' => 'အရှေ့ဥရောပ အချိန် (ထရီပိုလီ)',
        'Africa/Tunis' => 'ဥရောပအလယ်ပိုင်း အချိန် (တူနီစ်)',
        'Africa/Windhoek' => 'အလယ်အာဖရိက အချိန် (ဗင်းဟူးခ်)',
        'America/Adak' => 'ဟာဝိုင်ယီ အယ်လူးရှန်း အချိန် (အာဒချ)',
        'America/Anchorage' => 'အလာစကာ အချိန် (အန်ကာရေ့ဂျ်)',
        'America/Anguilla' => 'အတ္တလန်တစ် အချိန် (အန်ဂီလာ)',
        'America/Antigua' => 'အတ္တလန်တစ် အချိန် (အန်တီဂွါ)',
        'America/Araguaina' => 'ဘရာဇီး အချိန် (အာရာဂွါအီနာ)',
        'America/Argentina/La_Rioja' => 'အာဂျင်တီးနား အချိန် (လာ ရီယိုဟာ)',
        'America/Argentina/Rio_Gallegos' => 'အာဂျင်တီးနား အချိန် (ရီယို ဂါလီဂိုစ်)',
        'America/Argentina/Salta' => 'အာဂျင်တီးနား အချိန် (ဆာလ်တာ)',
        'America/Argentina/San_Juan' => 'အာဂျင်တီးနား အချိန် (ဆန် ဂွမ်)',
        'America/Argentina/San_Luis' => 'အာဂျင်တီးနား အချိန် (ဆန် လူဝီစ်)',
        'America/Argentina/Tucuman' => 'အာဂျင်တီးနား အချိန် (တူကူမန်)',
        'America/Argentina/Ushuaia' => 'အာဂျင်တီးနား အချိန် (ဥဆွာအီအာ)',
        'America/Aruba' => 'အတ္တလန်တစ် အချိန် (အာရူးဗာ)',
        'America/Asuncion' => 'ပါရာဂွေး အချိန် (အာဆူစီအွန်း)',
        'America/Bahia' => 'ဘရာဇီး အချိန် (ဘာဟီအာ)',
        'America/Bahia_Banderas' => 'အလယ်ပိုင်းအချိန် (ဘာဟီအာ ဘန်ဒရက်စ်)',
        'America/Barbados' => 'အတ္တလန်တစ် အချိန် (ဘာဘေးဒိုးစ်)',
        'America/Belem' => 'ဘရာဇီး အချိန် (ဘီလင်မ်)',
        'America/Belize' => 'အလယ်ပိုင်းအချိန် (ဘလိဇ်)',
        'America/Blanc-Sablon' => 'အတ္တလန်တစ် အချိန် (ဘလွန်ခ်-စာဘလွန်)',
        'America/Boa_Vista' => 'အမေဇုံ အချိန် (ဘိုအာဗီစ်တာ)',
        'America/Bogota' => 'ကိုလံဘီယာ အချိန် (ဘိုဂိုတာ)',
        'America/Boise' => 'တောင်တန်းအချိန် (ဗွိုက်စီ)',
        'America/Buenos_Aires' => 'အာဂျင်တီးနား အချိန် (ဗျူနိုအေးရိစ်)',
        'America/Cambridge_Bay' => 'တောင်တန်းအချိန် (ကိန်းဘရစ်ချ် ဘေး)',
        'America/Campo_Grande' => 'အမေဇုံ အချိန် (ကိမ်ပို ဂရန်ဒီ)',
        'America/Cancun' => 'အရှေ့ပိုင်းအချိန် (ကန်ခန်)',
        'America/Caracas' => 'ဗင်နီဇွဲလား အချိန် (ကာရာကာစ်)',
        'America/Catamarca' => 'အာဂျင်တီးနား အချိန် (ကာတာမာရကာ)',
        'America/Cayenne' => 'ပြင်သစ် ဂီအားနား အချိန် (ကေညင်န်)',
        'America/Cayman' => 'အရှေ့ပိုင်းအချိန် (ကေမန်)',
        'America/Chicago' => 'အလယ်ပိုင်းအချိန် (ချီကာကို)',
        'America/Chihuahua' => 'မက္ကဆီကန် ပစိဖိတ် အချိန် (ချီဟူအာဟူအာ)',
        'America/Coral_Harbour' => 'အရှေ့ပိုင်းအချိန် (အာတီကိုကန်)',
        'America/Cordoba' => 'အာဂျင်တီးနား အချိန် (ကိုဒိုဘာ)',
        'America/Costa_Rica' => 'အလယ်ပိုင်းအချိန် (ကို့စတာရီကာ)',
        'America/Creston' => 'တောင်တန်းအချိန် (ကရစ်စတွန်)',
        'America/Cuiaba' => 'အမေဇုံ အချိန် (ကွီရာဘာ)',
        'America/Curacao' => 'အတ္တလန်တစ် အချိန် (ကျူရေးကိုး)',
        'America/Danmarkshavn' => 'ဂရင်းနစ် စံတော်ချိန် (ဒန်မတ်ရှ်ဗာန်)',
        'America/Dawson' => 'ယူကွန်း အချိန် (ဒေါ်ဆန်)',
        'America/Dawson_Creek' => 'တောင်တန်းအချိန် (ဒေါ်ဆန် ခရိခ်)',
        'America/Denver' => 'တောင်တန်းအချိန် (ဒင်န်ဗာ)',
        'America/Detroit' => 'အရှေ့ပိုင်းအချိန် (ဒက်ထရွိုက်)',
        'America/Dominica' => 'အတ္တလန်တစ် အချိန် (ဒိုမီနီကာ)',
        'America/Edmonton' => 'တောင်တန်းအချိန် (အက်ဒ်မွန်တန်)',
        'America/Eirunepe' => 'ဘရာဇီး အချိန် (အီရူနီပီ)',
        'America/El_Salvador' => 'အလယ်ပိုင်းအချိန် (အယ်လ်ဆာဗေဒို)',
        'America/Fort_Nelson' => 'တောင်တန်းအချိန် (ဖို့တ် နယ်လ်ဆင်)',
        'America/Fortaleza' => 'ဘရာဇီး အချိန် (ဖို့တ်တာလီဇာ)',
        'America/Glace_Bay' => 'အတ္တလန်တစ် အချိန် (ဂလဲစ်ဘေး)',
        'America/Godthab' => 'အနောက် ဂရင်းလန်း အချိန် (နုခ်)',
        'America/Goose_Bay' => 'အတ္တလန်တစ် အချိန် (ဂူးစ်ဘေး)',
        'America/Grand_Turk' => 'အရှေ့ပိုင်းအချိန် (ဂရန်ဒ် တခ်)',
        'America/Grenada' => 'အတ္တလန်တစ် အချိန် (ဂရီနေဒါ)',
        'America/Guadeloupe' => 'အတ္တလန်တစ် အချိန် (ဂွါဒီလုပ်)',
        'America/Guatemala' => 'အလယ်ပိုင်းအချိန် (ဂွါတီမာလာ)',
        'America/Guayaquil' => 'အီကွေဒေါ အချိန် (ဂွါရာကွီးလ်)',
        'America/Guyana' => 'ဂိုင်ယာနာ အချိန်',
        'America/Halifax' => 'အတ္တလန်တစ် အချိန် (ဟလီဖက်စ်)',
        'America/Havana' => 'ကျူးဘား အချိန် (ဟာဗာနာ)',
        'America/Hermosillo' => 'မက္ကဆီကန် ပစိဖိတ် အချိန် (ဟာမိုစ်စီလို)',
        'America/Indiana/Knox' => 'အလယ်ပိုင်းအချိန် (နောက်ခ်စ်၊ အင်ဒီယားနား)',
        'America/Indiana/Marengo' => 'အရှေ့ပိုင်းအချိန် (မာရန်ဂို၊ အင်ဒီယားနား)',
        'America/Indiana/Petersburg' => 'အရှေ့ပိုင်းအချိန် (ပီတာစ်ဘတ်ခ်၊ အင်ဒီယားနား)',
        'America/Indiana/Tell_City' => 'အလယ်ပိုင်းအချိန် (တဲလ်စီးတီး၊ အင်ဒီယားနား)',
        'America/Indiana/Vevay' => 'အရှေ့ပိုင်းအချိန် (ဗီဗဲ၊ အင်ဒီယားနား)',
        'America/Indiana/Vincennes' => 'အရှေ့ပိုင်းအချိန် (ဗင်ဆင့်စ်၊ အင်ဒီယားနား)',
        'America/Indiana/Winamac' => 'အရှေ့ပိုင်းအချိန် (ဝီနာမက်ခ်၊ အင်ဒီယားနား)',
        'America/Indianapolis' => 'အရှေ့ပိုင်းအချိန် (အင်ဒီယားနား ပိုလိစ်)',
        'America/Inuvik' => 'တောင်တန်းအချိန် (အီနုဗီခ်)',
        'America/Iqaluit' => 'အရှေ့ပိုင်းအချိန် (အီကာလူအီတ်)',
        'America/Jamaica' => 'အရှေ့ပိုင်းအချိန် (ဂျမေကာ)',
        'America/Jujuy' => 'အာဂျင်တီးနား အချိန် (ဂျုဂျေ)',
        'America/Juneau' => 'အလာစကာ အချိန် (ဂျုနိုအော)',
        'America/Kentucky/Monticello' => 'အရှေ့ပိုင်းအချိန် (မွန်တီချယ်လို၊ ကင်တပ်ကီ)',
        'America/Kralendijk' => 'အတ္တလန်တစ် အချိန် (ခရာလဲန်းဒစ်ချ်)',
        'America/La_Paz' => 'ဘိုလီးဘီးယား အချိန် (လာပါဇ်)',
        'America/Lima' => 'ပီရူး အချိန် (လီမာ)',
        'America/Los_Angeles' => 'ပစိဖိတ်အချိန် (လော့စ်အိန်ဂျယ်လိစ်)',
        'America/Louisville' => 'အရှေ့ပိုင်းအချိန် (လူဝီဗီးလ်)',
        'America/Lower_Princes' => 'အတ္တလန်တစ် အချိန် (လိုအာပရင့်စ် ကွာတာ)',
        'America/Maceio' => 'ဘရာဇီး အချိန် (မာဆဲသွာ)',
        'America/Managua' => 'အလယ်ပိုင်းအချိန် (မာနာဂွါ)',
        'America/Manaus' => 'အမေဇုံ အချိန် (မာနောက်စ်)',
        'America/Marigot' => 'အတ္တလန်တစ် အချိန် (မာရီဂေါ့)',
        'America/Martinique' => 'အတ္တလန်တစ် အချိန် (မာတီနီဂ်)',
        'America/Matamoros' => 'အလယ်ပိုင်းအချိန် (မာတာမိုရိုစ်)',
        'America/Mazatlan' => 'မက္ကဆီကန် ပစိဖိတ် အချိန် (မာဇတ်လန်)',
        'America/Mendoza' => 'အာဂျင်တီးနား အချိန် (မန်ဒိုဇာ)',
        'America/Menominee' => 'အလယ်ပိုင်းအချိန် (မီနိုမီနီး)',
        'America/Merida' => 'အလယ်ပိုင်းအချိန် (မီရီဒါ)',
        'America/Metlakatla' => 'အလာစကာ အချိန် (မက်တ်လာကက်လာ)',
        'America/Mexico_City' => 'အလယ်ပိုင်းအချိန် (မက်ကဆီကို စီးတီး)',
        'America/Miquelon' => 'စိန့်ပီအဲနှင့်မီခွီလွန်အချိန် (မီကွီလွန်)',
        'America/Moncton' => 'အတ္တလန်တစ် အချိန် (မွန်ခ်တွန်)',
        'America/Monterrey' => 'အလယ်ပိုင်းအချိန် (မွန်တဲရေး)',
        'America/Montevideo' => 'ဥရုဂွေး အချိန် (မွန်တီဗီဒီအို)',
        'America/Montreal' => 'ကနေဒါ အချိန် (Montreal)',
        'America/Montserrat' => 'အတ္တလန်တစ် အချိန် (မွန့်(တ်)ဆေးရတ်)',
        'America/Nassau' => 'အရှေ့ပိုင်းအချိန် (နာ့ဆော်)',
        'America/New_York' => 'အရှေ့ပိုင်းအချိန် (နယူးယောက်)',
        'America/Nipigon' => 'အရှေ့ပိုင်းအချိန် (နီပီဂွန်)',
        'America/Nome' => 'အလာစကာ အချိန် (နိုမီ)',
        'America/Noronha' => 'ဖာနန်ဒိုးဒီနိုးရိုးညာ အချိန် (နိုရိုညာ)',
        'America/North_Dakota/Beulah' => 'အလယ်ပိုင်းအချိန် (ဗြူလာ၊ မြောက်ဒါကိုတာ)',
        'America/North_Dakota/Center' => 'အလယ်ပိုင်းအချိန် (စင်တာ၊ မြောက်ဒါကိုတာ)',
        'America/North_Dakota/New_Salem' => 'အလယ်ပိုင်းအချိန် (နယူးဆေးလမ်၊ မြောက်ဒါကိုတာ)',
        'America/Ojinaga' => 'တောင်တန်းအချိန် (အိုခီနဂါ)',
        'America/Panama' => 'အရှေ့ပိုင်းအချိန် (ပနားမား)',
        'America/Pangnirtung' => 'အရှေ့ပိုင်းအချိန် (ဖန်ဂ်နသ်တံ)',
        'America/Paramaribo' => 'စူးရီနာမ်အချိန် (ပါရာမာရီဘို)',
        'America/Phoenix' => 'တောင်တန်းအချိန် (ဖီးနစ်)',
        'America/Port-au-Prince' => 'အရှေ့ပိုင်းအချိန် (ပို့တ်-အို-ပရင့်စ်)',
        'America/Port_of_Spain' => 'အတ္တလန်တစ် အချိန် (ပို့တ် အော့ဖ် စပိန်)',
        'America/Porto_Velho' => 'အမေဇုံ အချိန် (ပို့တ်တို ဗဲလီယို)',
        'America/Puerto_Rico' => 'အတ္တလန်တစ် အချိန် (ပေါ်တိုရီကို)',
        'America/Punta_Arenas' => 'ချီလီ အချိန် (ပွန်တာ အရီနာစ်)',
        'America/Rainy_River' => 'အလယ်ပိုင်းအချိန် (ရိမ်းနီး ရီဗာ)',
        'America/Rankin_Inlet' => 'အလယ်ပိုင်းအချိန် (ရန်ကင် အင်းလက်)',
        'America/Recife' => 'ဘရာဇီး အချိန် (ဟေစီဖီလ်)',
        'America/Regina' => 'အလယ်ပိုင်းအချိန် (ရယ်ဂျီနာ)',
        'America/Resolute' => 'အလယ်ပိုင်းအချိန် (ရီဆိုလုပ်(တ်))',
        'America/Rio_Branco' => 'ဘရာဇီး အချိန် (ရီယို ဘရန်ကို)',
        'America/Santa_Isabel' => 'အနောက်တောင် မက္ကဆီကို အချိန် (ဆန်တာ အစ္ဇဘဲလ်)',
        'America/Santarem' => 'ဘရာဇီး အချိန် (ဆန်တာရမ်)',
        'America/Santiago' => 'ချီလီ အချိန် (ဆန်တီအာဂို)',
        'America/Santo_Domingo' => 'အတ္တလန်တစ် အချိန် (ဆန်တို ဒိုမင်းဂို)',
        'America/Sao_Paulo' => 'ဘရာဇီး အချိန် (ဆော်ပိုလို)',
        'America/Scoresbysund' => 'အရှေ့ဂရင်းလန်း အချိန် (အစ်တာကာ တိုးမိရက်တ်)',
        'America/Sitka' => 'အလာစကာ အချိန် (စစ်ကာ)',
        'America/St_Barthelemy' => 'အတ္တလန်တစ် အချိန် (စိန့်ဘာသယ်လမီ)',
        'America/St_Johns' => 'နယူးဖောင်လန် အချိန် (စိန့်ဂျွန်း)',
        'America/St_Kitts' => 'အတ္တလန်တစ် အချိန် (စိန့်ကိစ်)',
        'America/St_Lucia' => 'အတ္တလန်တစ် အချိန် (စိန့်လူစီယာ)',
        'America/St_Thomas' => 'အတ္တလန်တစ် အချိန် (စိန့်သောမတ်စ်)',
        'America/St_Vincent' => 'အတ္တလန်တစ် အချိန် (စိန့်ဗင်းဆင့်)',
        'America/Swift_Current' => 'အလယ်ပိုင်းအချိန် (စွတ်ဖ်တ် ကားရင့်)',
        'America/Tegucigalpa' => 'အလယ်ပိုင်းအချိန် (တီဂူစီဂလ်ပါ)',
        'America/Thule' => 'အတ္တလန်တစ် အချိန် (သုလီ)',
        'America/Thunder_Bay' => 'အရှေ့ပိုင်းအချိန် (သန်းန်ဒါး ဘေး)',
        'America/Tijuana' => 'ပစိဖိတ်အချိန် (တီဂွါနာ)',
        'America/Toronto' => 'အရှေ့ပိုင်းအချိန် (တိုရန်တို)',
        'America/Tortola' => 'အတ္တလန်တစ် အချိန် (တောတိုလာ)',
        'America/Vancouver' => 'ပစိဖိတ်အချိန် (ဗန်ကူးဗား)',
        'America/Whitehorse' => 'ယူကွန်း အချိန် (ဝိုက်(တ်)ဟိုစ်)',
        'America/Winnipeg' => 'အလယ်ပိုင်းအချိန် (ဝီနီဗက်ဂ်)',
        'America/Yakutat' => 'အလာစကာ အချိန် (ရာကုတတ်)',
        'America/Yellowknife' => 'တောင်တန်းအချိန် (ရဲလိုနိုက်ဖ်)',
        'Antarctica/Casey' => 'အန်တာတိက အချိန် (ကေစီ)',
        'Antarctica/Davis' => 'ဒေးဗစ် အချိန်',
        'Antarctica/DumontDUrville' => 'ဒူးမော့တ် ဒါရ်ဗီးလ် အချိန်',
        'Antarctica/Macquarie' => 'အရှေ့ဩစတြေးလျ အချိန် (မက်ကွယ်ရီ)',
        'Antarctica/Mawson' => 'မော်စွန် အချိန်',
        'Antarctica/McMurdo' => 'နယူးဇီလန် အချိန် (မက်မူဒိုး)',
        'Antarctica/Palmer' => 'ချီလီ အချိန် (ပါလ်မာ)',
        'Antarctica/Rothera' => 'ရိုသီရာ အချိန်',
        'Antarctica/Syowa' => 'ရှိုဝါ အချိန် (ရှိုးဝါ)',
        'Antarctica/Troll' => 'ဂရင်းနစ် စံတော်ချိန် (ထရိုလ်)',
        'Antarctica/Vostok' => 'ဗိုစ်တိုခ် အချိန်',
        'Arctic/Longyearbyen' => 'ဥရောပအလယ်ပိုင်း အချိန် (လောင်ရီယားဘရံ)',
        'Asia/Aden' => 'အာရေဗျ အချိန် (အာဒင်)',
        'Asia/Almaty' => 'အရှေ့ကာဇက်စတန် အချိန် (အော်မာတီ)',
        'Asia/Amman' => 'အရှေ့ဥရောပ အချိန် (အာမာန်း)',
        'Asia/Anadyr' => 'ရုရှား အချိန် (အန်အာဒီအာ)',
        'Asia/Aqtau' => 'အနောက်ကာဇက်စတန် အချိန် (အက်တာဥု)',
        'Asia/Aqtobe' => 'အနောက်ကာဇက်စတန် အချိန် (အာချတူးဘီ)',
        'Asia/Ashgabat' => 'တာ့ခ်မင်နစ္စတန် အချိန် (အာရှ်ဂါဘာဒ်)',
        'Asia/Atyrau' => 'အနောက်ကာဇက်စတန် အချိန် (အာတီရအူ)',
        'Asia/Baghdad' => 'အာရေဗျ အချိန် (ဘဂ္ဂဒက်)',
        'Asia/Bahrain' => 'အာရေဗျ အချိန် (ဘာရိန်း)',
        'Asia/Baku' => 'အဇာဘိုင်ဂျန် အချိန် (ဘာကူ)',
        'Asia/Bangkok' => 'အင်ဒိုချိုင်းနား အချိန် (ဘန်ကောက်)',
        'Asia/Barnaul' => 'ရုရှား အချိန် (ဘရ်နာအူ)',
        'Asia/Beirut' => 'အရှေ့ဥရောပ အချိန် (ဘေရွတ်)',
        'Asia/Bishkek' => 'ကာဂျစ္စတန် အချိန် (ဘီရှ်ခက်)',
        'Asia/Brunei' => 'ဘရူနိုင်း စံတော်ချိန်',
        'Asia/Calcutta' => 'အိန္ဒိယ စံတော်ချိန် (ကိုလျကတ်တား)',
        'Asia/Chita' => 'ယူခူးတ်စ် အချိန် (ချီတာ)',
        'Asia/Choibalsan' => 'ဥလန်ဘာတော အချိန် (ချွဲဘောဆန်)',
        'Asia/Colombo' => 'အိန္ဒိယ စံတော်ချိန် (ကိုလံဘို)',
        'Asia/Damascus' => 'အရှေ့ဥရောပ အချိန် (ဒမားစကပ်)',
        'Asia/Dhaka' => 'ဘင်္ဂလားဒေ့ရှ် အချိန် (ဒက်ကာ)',
        'Asia/Dili' => 'အရှေ့တီမော အချိန် (ဒစ်လီ)',
        'Asia/Dubai' => 'ပင်လယ်ကွေ့ အချိန် (ဒူဘိုင်း)',
        'Asia/Dushanbe' => 'တာဂျစ်ကစ္စတန် အချိန် (ဒူရှန်းဘဲ)',
        'Asia/Famagusta' => 'အရှေ့ဥရောပ အချိန် (ဖာမာဂူစတာ)',
        'Asia/Gaza' => 'အရှေ့ဥရောပ အချိန် (ဂါဇာ)',
        'Asia/Hebron' => 'အရှေ့ဥရောပ အချိန် (ဟီဘရွန်)',
        'Asia/Hong_Kong' => 'ဟောင်ကောင် အချိန်',
        'Asia/Hovd' => 'ဟိုးဗ် အချိန် (ဟိုးဗျ)',
        'Asia/Irkutsk' => 'အီရူခူတ် အချိန်',
        'Asia/Jakarta' => 'အနောက်ပိုင်း အင်ဒိုနီးရှား အချိန် (ဂျကာတာ)',
        'Asia/Jayapura' => 'အရှေ့ပိုင်း အင်ဒိုနီးရှား အချိန် (ဂျာရာပူရာ)',
        'Asia/Jerusalem' => 'အစ္စရေး အချိန် (ဂျေရုဆလင်)',
        'Asia/Kabul' => 'အာဖဂန်နစ္စတန် အချိန် (ကဘူးလျ)',
        'Asia/Kamchatka' => 'ရုရှား အချိန် (ခမ်ချာ့ခါ)',
        'Asia/Karachi' => 'ပါကစ္စတန် အချိန် (ကရာချိ)',
        'Asia/Katmandu' => 'နီပေါ အချိန် (ခတ်တမန်ဒူ)',
        'Asia/Khandyga' => 'ယူခူးတ်စ် အချိန် (ခန်ဒိုင်ဂါ)',
        'Asia/Krasnoyarsk' => 'ခရာ့စ်နိုရာစ် အချိန်',
        'Asia/Kuala_Lumpur' => 'မလေးရှား အချိန် (ကွာလာလမ်ပူ)',
        'Asia/Kuching' => 'မလေးရှား အချိန် (ကူချင်)',
        'Asia/Kuwait' => 'အာရေဗျ အချိန် (ကူဝိတ်)',
        'Asia/Macau' => 'တရုတ် အချိန် (မကာအို)',
        'Asia/Magadan' => 'မာဂါဒန်း အချိန်',
        'Asia/Makassar' => 'အလယ်ပိုင်း အင်ဒိုနီးရှား အချိန် (မခက်စ်ဆာ)',
        'Asia/Manila' => 'ဖိလစ်ပိုင် အချိန် (မနီလာ)',
        'Asia/Muscat' => 'ပင်လယ်ကွေ့ အချိန် (မတ်စ်ကက်တ်)',
        'Asia/Nicosia' => 'အရှေ့ဥရောပ အချိန် (နီကိုရှား)',
        'Asia/Novokuznetsk' => 'ခရာ့စ်နိုရာစ် အချိန် (နိုဗိုခူဇ်နက်စ်)',
        'Asia/Novosibirsk' => 'နိုဗိုစဲဘီအဲယ်စ် အချိန်',
        'Asia/Omsk' => 'အွမ်းစ်ခ် အချိန်',
        'Asia/Oral' => 'အနောက်ကာဇက်စတန် အချိန် (အော်ရဲလ်)',
        'Asia/Phnom_Penh' => 'အင်ဒိုချိုင်းနား အချိန် (ဖနွမ်ပင်)',
        'Asia/Pontianak' => 'အနောက်ပိုင်း အင်ဒိုနီးရှား အချိန် (ပွန်တီအားနာ့ခ်)',
        'Asia/Pyongyang' => 'ကိုရီးယား အချိန် (ပြုံယန်း)',
        'Asia/Qatar' => 'အာရေဗျ အချိန် (ကာတာ)',
        'Asia/Qostanay' => 'အရှေ့ကာဇက်စတန် အချိန် (ကော့စ်တနေ)',
        'Asia/Qyzylorda' => 'အနောက်ကာဇက်စတန် အချိန် (ကီဇလော်ဒါ)',
        'Asia/Rangoon' => 'မြန်မာ အချိန် (ရန်ကုန်)',
        'Asia/Riyadh' => 'အာရေဗျ အချိန် (ရီယားဒ်)',
        'Asia/Saigon' => 'အင်ဒိုချိုင်းနား အချိန် (ဟိုချီမင်းစီးတီး)',
        'Asia/Sakhalin' => 'ဆာခါလင် အချိန်',
        'Asia/Samarkand' => 'ဥဇဘက်ကစ္စတန် အချိန် (ဆမ်းမာခန်းဒ်)',
        'Asia/Seoul' => 'ကိုရီးယား အချိန် (ဆိုးလ်)',
        'Asia/Shanghai' => 'တရုတ် အချိန် (ရှန်ဟိုင်း)',
        'Asia/Singapore' => 'စင်္ကာပူ အချိန်',
        'Asia/Srednekolymsk' => 'မာဂါဒန်း အချိန် (ဆရစ်နစ်ကာလင်မ်စ်)',
        'Asia/Taipei' => 'ထိုင်ပေ အချိန် (တိုင်ပေ)',
        'Asia/Tashkent' => 'ဥဇဘက်ကစ္စတန် အချိန် (တာရှ်ကဲန့်)',
        'Asia/Tbilisi' => 'ဂျော်ဂျီယာ အချိန် (တဘီးလီစီ)',
        'Asia/Tehran' => 'အီရန် အချိန် (တီဟီရန်)',
        'Asia/Thimphu' => 'ဘူတန် အချိန် (တင်ဖူး)',
        'Asia/Tokyo' => 'ဂျပန် အချိန် (တိုကျို)',
        'Asia/Tomsk' => 'ရုရှား အချိန် (တွန်မ်စ်ခ်)',
        'Asia/Ulaanbaatar' => 'ဥလန်ဘာတော အချိန်',
        'Asia/Urumqi' => 'တရုတ် အချိန် (အူရုမ်ချီ)',
        'Asia/Ust-Nera' => 'ဗလာဒီဗော့စတော့ခ် အချိန် (အူးစ် နီရား)',
        'Asia/Vientiane' => 'အင်ဒိုချိုင်းနား အချိန် (ဗီယင်ကျန်း)',
        'Asia/Vladivostok' => 'ဗလာဒီဗော့စတော့ခ် အချိန်',
        'Asia/Yakutsk' => 'ယူခူးတ်စ် အချိန်',
        'Asia/Yekaterinburg' => 'ရယ်ခါးတီရင်ဘားခ် အချိန်',
        'Asia/Yerevan' => 'အာမေးနီးယား အချိန် (ရဲယ်ရေဗန်း)',
        'Atlantic/Azores' => 'အေဇိုးရီးစ် အချိန်',
        'Atlantic/Bermuda' => 'အတ္တလန်တစ် အချိန် (ဘာမြူဒါ)',
        'Atlantic/Canary' => 'အနောက်ဥရောပ အချိန် (ကနေရီ)',
        'Atlantic/Cape_Verde' => 'ကိတ်ဗာဒီ အချိန် (ကိတ်ပ် ဗာဒီ)',
        'Atlantic/Faeroe' => 'အနောက်ဥရောပ အချိန် (ဖါရို)',
        'Atlantic/Madeira' => 'အနောက်ဥရောပ အချိန် (မဒီးရာ)',
        'Atlantic/Reykjavik' => 'ဂရင်းနစ် စံတော်ချိန် (ရေးကီဗစ်ခ်)',
        'Atlantic/South_Georgia' => 'တောင်ဂျော်ဂျီယာ အချိန်',
        'Atlantic/St_Helena' => 'ဂရင်းနစ် စံတော်ချိန် (စိန့်ဟယ်လယ်နာ)',
        'Atlantic/Stanley' => 'ဖော့ကလန်ကျွန်းစု အချိန် (စတန်လေ)',
        'Australia/Adelaide' => 'ဩစတြေးလျ အလယ်ပိုင်း အချိန် (အန္ဒီလိတ်ဒ်)',
        'Australia/Brisbane' => 'အရှေ့ဩစတြေးလျ အချိန် (ဘရစ္စဘိန်း)',
        'Australia/Broken_Hill' => 'ဩစတြေးလျ အလယ်ပိုင်း အချိန် (ဘရိုကင်ဟီးလ်)',
        'Australia/Currie' => 'အရှေ့ဩစတြေးလျ အချိန် (ကာရီ)',
        'Australia/Darwin' => 'ဩစတြေးလျ အလယ်ပိုင်း အချိန် (ဒါဝင်)',
        'Australia/Eucla' => 'သြစတြေးလျား အနောက်အလယ်ပိုင်း အချိန် (ယူးခလာ)',
        'Australia/Hobart' => 'အရှေ့ဩစတြေးလျ အချိန် (ဟိုးဘားတ်)',
        'Australia/Lindeman' => 'အရှေ့ဩစတြေးလျ အချိန် (လင်းဒီမန်း)',
        'Australia/Lord_Howe' => 'လော့ဒ်ဟောင် အချိန် (လော့ဒ် ဟောင်)',
        'Australia/Melbourne' => 'အရှေ့ဩစတြေးလျ အချိန် (မဲလ်ဘုန်း)',
        'Australia/Perth' => 'အနောက်ဩစတြေးလျ အချိန် (ပါးသ်)',
        'Australia/Sydney' => 'အရှေ့ဩစတြေးလျ အချိန် (ဆစ်ဒနီ)',
        'CST6CDT' => 'အလယ်ပိုင်းအချိန်',
        'EST5EDT' => 'အရှေ့ပိုင်းအချိန်',
        'Etc/GMT' => 'ဂရင်းနစ် စံတော်ချိန်',
        'Etc/UTC' => 'ညှိထားသည့် ကမ္ဘာ့ စံတော်ချိန်',
        'Europe/Amsterdam' => 'ဥရောပအလယ်ပိုင်း အချိန် (အမ်စတာဒမ်)',
        'Europe/Andorra' => 'ဥရောပအလယ်ပိုင်း အချိန် (အန်ဒိုရာ)',
        'Europe/Astrakhan' => 'မော်စကို အချိန် (အားစ်တရခန်း)',
        'Europe/Athens' => 'အရှေ့ဥရောပ အချိန် (အေသင်)',
        'Europe/Belgrade' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဘဲလ်ဂရိတ်)',
        'Europe/Berlin' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဘာလင်)',
        'Europe/Bratislava' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဘရာတီးစ်လားဗာ)',
        'Europe/Brussels' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဘရပ်ဆဲလ်)',
        'Europe/Bucharest' => 'အရှေ့ဥရောပ အချိန် (ဘူခါရက်စ်)',
        'Europe/Budapest' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဘူဒါပက်စ်)',
        'Europe/Busingen' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဘူရှင်ဂျင်)',
        'Europe/Chisinau' => 'အရှေ့ဥရောပ အချိန် (ချီရှီနားအူ)',
        'Europe/Copenhagen' => 'ဥရောပအလယ်ပိုင်း အချိန် (ကိုပင်ဟေဂင်)',
        'Europe/Dublin' => 'ဂရင်းနစ် စံတော်ချိန် (ဒတ်ဘလင်)',
        'Europe/Gibraltar' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဂျီဘရော်လ်တာ)',
        'Europe/Guernsey' => 'ဂရင်းနစ် စံတော်ချိန် (ဂွန်းဇီ)',
        'Europe/Helsinki' => 'အရှေ့ဥရောပ အချိန် (ဟဲလ်စင်ကီ)',
        'Europe/Isle_of_Man' => 'ဂရင်းနစ် စံတော်ချိန် (မန်းကျွန်း)',
        'Europe/Istanbul' => 'တူရကီ အချိန် (အစ္စတန်ဘူလ်)',
        'Europe/Jersey' => 'ဂရင်းနစ် စံတော်ချိန် (ဂျာစီ)',
        'Europe/Kaliningrad' => 'အရှေ့ဥရောပ အချိန် (ခါလီနင်ဂရက်)',
        'Europe/Kiev' => 'အရှေ့ဥရောပ အချိန် (ခီးအက်ဖ်)',
        'Europe/Kirov' => 'ရုရှား အချိန် (ခီရိုဗ်)',
        'Europe/Lisbon' => 'အနောက်ဥရောပ အချိန် (လစ္စဘွန်း)',
        'Europe/Ljubljana' => 'ဥရောပအလယ်ပိုင်း အချိန် (လူဘလီအားနား)',
        'Europe/London' => 'ဂရင်းနစ် စံတော်ချိန် (လန်ဒန်)',
        'Europe/Luxembourg' => 'ဥရောပအလယ်ပိုင်း အချိန် (လူဇင်ဘတ်)',
        'Europe/Madrid' => 'ဥရောပအလယ်ပိုင်း အချိန် (မဒရစ်)',
        'Europe/Malta' => 'ဥရောပအလယ်ပိုင်း အချိန် (မော်လ်တာ)',
        'Europe/Mariehamn' => 'အရှေ့ဥရောပ အချိန် (မရီအာ ဟားမန်)',
        'Europe/Minsk' => 'မော်စကို အချိန် (မင်းစခ်)',
        'Europe/Monaco' => 'ဥရောပအလယ်ပိုင်း အချိန် (မိုနာကို)',
        'Europe/Moscow' => 'မော်စကို အချိန်',
        'Europe/Oslo' => 'ဥရောပအလယ်ပိုင်း အချိန် (အော်စလို)',
        'Europe/Paris' => 'ဥရောပအလယ်ပိုင်း အချိန် (ပဲရစ်)',
        'Europe/Podgorica' => 'ဥရောပအလယ်ပိုင်း အချိန် (ပေါ့ဂိုရီကာ)',
        'Europe/Prague' => 'ဥရောပအလယ်ပိုင်း အချိန် (ပရက်ဂ်)',
        'Europe/Riga' => 'အရှေ့ဥရောပ အချိန် (ရီဂါ)',
        'Europe/Rome' => 'ဥရောပအလယ်ပိုင်း အချိန် (ရောမ)',
        'Europe/Samara' => 'ရုရှား အချိန် (ဆာမားရာ)',
        'Europe/San_Marino' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဆန်မရီးနို)',
        'Europe/Sarajevo' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဆာရာယေဗို)',
        'Europe/Saratov' => 'မော်စကို အချိန် (ဆာရာတို့ဖ်)',
        'Europe/Simferopol' => 'မော်စကို အချိန် (စင်ဖာရိုးဖို)',
        'Europe/Skopje' => 'ဥရောပအလယ်ပိုင်း အချိန် (စကော့ပ်ရာ)',
        'Europe/Sofia' => 'အရှေ့ဥရောပ အချိန် (ဆိုဖီအာ)',
        'Europe/Stockholm' => 'ဥရောပအလယ်ပိုင်း အချိန် (စတော့ဟုမ်း)',
        'Europe/Tallinn' => 'အရှေ့ဥရောပ အချိန် (ထားလင်)',
        'Europe/Tirane' => 'ဥရောပအလယ်ပိုင်း အချိန် (တီရာနီ)',
        'Europe/Ulyanovsk' => 'မော်စကို အချိန် (အူလီယာနိုစကစ်ဖ်)',
        'Europe/Uzhgorod' => 'အရှေ့ဥရောပ အချိန် (ဥဇ်ဂိုရို့တ်)',
        'Europe/Vaduz' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဗာဒူးစ်)',
        'Europe/Vatican' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဗာတီကန်)',
        'Europe/Vienna' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဗီယင်နာ)',
        'Europe/Vilnius' => 'အရှေ့ဥရောပ အချိန် (ဗီးလ်နီအိုးစ်)',
        'Europe/Volgograd' => 'ဗိုလ်ဂိုဂရက် အချိန်',
        'Europe/Warsaw' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဝါဆော)',
        'Europe/Zagreb' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဇာဂ်ဂရက်ဘ်)',
        'Europe/Zaporozhye' => 'အရှေ့ဥရောပ အချိန် (ဇာဖိုရိုးစ်ဂျာ)',
        'Europe/Zurich' => 'ဥရောပအလယ်ပိုင်း အချိန် (ဇူးရစ်ချ်)',
        'Indian/Antananarivo' => 'အရှေ့အာဖရိက အချိန် (အန်တာနာနာရီးဘို)',
        'Indian/Chagos' => 'အိန္ဒိယသမုဒ္ဒရာ အချိန် (ချာဂိုစ်)',
        'Indian/Christmas' => 'ခရစ်စမတ်ကျွန်း အချိန်',
        'Indian/Cocos' => 'ကိုကိုးကျွန်း အချိန် (ကိုကိုးစ်)',
        'Indian/Comoro' => 'အရှေ့အာဖရိက အချိန် (ကိုမိုရို)',
        'Indian/Kerguelen' => 'ပြင်သစ်တောင်ပိုင်းနှင့် အန္တာတိတ် အချိန် (ခါဂါလန်)',
        'Indian/Mahe' => 'ဆေးရှဲ အချိန် (မာဟီ)',
        'Indian/Maldives' => 'မော်လဒိုက် အချိန်',
        'Indian/Mauritius' => 'မောရစ်ရှ အချိန်',
        'Indian/Mayotte' => 'အရှေ့အာဖရိက အချိန် (မာယိုတဲ)',
        'Indian/Reunion' => 'ရီယူနီယံ အချိန် (ရီယူနီယန်)',
        'MST7MDT' => 'တောင်တန်းအချိန်',
        'PST8PDT' => 'ပစိဖိတ်အချိန်',
        'Pacific/Apia' => 'အပီယာ အချိန် (အားပီအား)',
        'Pacific/Auckland' => 'နယူးဇီလန် အချိန် (အော့ကလန်)',
        'Pacific/Bougainville' => 'ပါပူအာနယူးဂီနီ အချိန် (ဘူဂန်ဗီးလီးယား)',
        'Pacific/Chatham' => 'ချားသမ်အချိန်',
        'Pacific/Easter' => 'အီစတာကျွန်း အချိန်',
        'Pacific/Efate' => 'ဗနွားတူ အချိန် (အီဖာတီ)',
        'Pacific/Enderbury' => 'ဖီးနစ်ကျွန်းစု အချိန် (အန်ဒါဘူရီ)',
        'Pacific/Fakaofo' => 'တိုကီလာဥ အချိန် (ဖာခါအိုဖို)',
        'Pacific/Fiji' => 'ဖီဂျီ အချိန်',
        'Pacific/Funafuti' => 'တူဗားလူ အချိန် (ဖူနာဖူတီ)',
        'Pacific/Galapagos' => 'ဂါလားပါဂိုးစ် အချိန် (ဂါလာပါကပ်စ်)',
        'Pacific/Gambier' => 'ဂမ်ဘီယာ အချိန်',
        'Pacific/Guadalcanal' => 'ဆော်လမွန်ကျွန်းစု အချိန် (ဂွါဒါကနဲလ်)',
        'Pacific/Guam' => 'ချာမိုရို အချိန် (ဂူအမ်)',
        'Pacific/Honolulu' => 'ဟာဝိုင်ယီ အယ်လူးရှန်း အချိန် (ဟိုနိုလူလူ)',
        'Pacific/Johnston' => 'ဟာဝိုင်ယီ အယ်လူးရှန်း အချိန် (ဂျွန်စတန်)',
        'Pacific/Kiritimati' => 'လိုင်းကျွန်းစု အချိန် (ခရိဒီမတီ)',
        'Pacific/Kosrae' => 'ခိုစ်ရိုင် အချိန်',
        'Pacific/Kwajalein' => 'မာရှယ်ကျွန်းစု အချိန် (ခွာဂျာလိန်)',
        'Pacific/Majuro' => 'မာရှယ်ကျွန်းစု အချိန် (မာဂျူးရို)',
        'Pacific/Marquesas' => 'မာခေးအပ်စ် အချိန်',
        'Pacific/Midway' => 'ဆမိုအာ အချိန် (မစ်ဒ်ဝေး)',
        'Pacific/Nauru' => 'နာဥူရူ အချိန်',
        'Pacific/Niue' => 'နီဥူအေ အချိန် (နီဦးအေ)',
        'Pacific/Norfolk' => 'နောဖော့ခ်ကျွန်း အချိန် (နော်ဖော့ခ်)',
        'Pacific/Noumea' => 'နယူးကယ်လီဒိုးနီးယား အချိန် (နူမယ်အာ)',
        'Pacific/Pago_Pago' => 'ဆမိုအာ အချိန် (ပါဂိုပါဂို)',
        'Pacific/Palau' => 'ပလာအို အချိန်',
        'Pacific/Pitcairn' => 'ပါတ်ကယ်ရင် အချိန်',
        'Pacific/Ponape' => 'ဖိုနာဖဲအ် အချိန်',
        'Pacific/Port_Moresby' => 'ပါပူအာနယူးဂီနီ အချိန် (ဖို့တ် မိုရက်စ်ဘီ)',
        'Pacific/Rarotonga' => 'ကွတ်ကျွန်းစု အချိန် (ရာရိုတွန်းဂါ)',
        'Pacific/Saipan' => 'ချာမိုရို အချိန် (ဆိုင်ပန်)',
        'Pacific/Tahiti' => 'တဟီတီ အချိန်',
        'Pacific/Tarawa' => 'ဂီလ်ဘတ်ကျွန်းစု အချိန် (တာရာဝါ)',
        'Pacific/Tongatapu' => 'တွန်ဂါ အချိန် (တွန်ဂါတာပု)',
        'Pacific/Truk' => 'ချုခ် အချိန်',
        'Pacific/Wake' => 'ဝိတ်ခ်ကျွန်း အချိန်',
        'Pacific/Wallis' => 'ဝေါလီစ်နှင့် ဖူကျူနာ အချိန်',
    ],
    'Meta' => [
    ],
];
