<?php

return [
    'Names' => [
        'en_PK' => 'ਅੰਗਰੇਜ਼ੀ (پاکستان)',
        'ks_Arab' => 'ਕਸ਼ਮੀਰੀ (عربی)',
        'ks_Arab_IN' => 'ਕਸ਼ਮੀਰੀ (عربی, ਭਾਰਤ)',
        'pa' => 'پنجابی',
        'pa_Arab' => 'پنجابی (عربی)',
        'pa_Arab_PK' => 'پنجابی (عربی, پاکستان)',
        'pa_Guru' => 'پنجابی (گُرمُکھی)',
        'pa_Guru_IN' => 'پنجابی (گُرمُکھی, ਭਾਰਤ)',
        'pa_IN' => 'پنجابی (ਭਾਰਤ)',
        'pa_PK' => 'پنجابی (پاکستان)',
        'ps_PK' => 'ਪਸ਼ਤੋ (پاکستان)',
        'sd_Arab' => 'ਸਿੰਧੀ (عربی)',
        'sd_Arab_PK' => 'ਸਿੰਧੀ (عربی, پاکستان)',
        'sd_PK' => 'ਸਿੰਧੀ (پاکستان)',
        'ur_PK' => 'ਉਰਦੂ (پاکستان)',
        'uz_Arab' => 'ਉਜ਼ਬੇਕ (عربی)',
        'uz_Arab_AF' => 'ਉਜ਼ਬੇਕ (عربی, ਅਫ਼ਗਾਨਿਸਤਾਨ)',
    ],
];
