<?php

return [
    'Names' => [
        'af' => 'افریکانسي',
        'af_NA' => 'افریکانسي (نیمبیا)',
        'af_ZA' => 'افریکانسي (سویلي افریقا)',
        'ak' => 'اکاني',
        'ak_GH' => 'اکاني (ګانا)',
        'am' => 'امهاري',
        'am_ET' => 'امهاري (حبشه)',
        'ar' => 'عربي',
        'ar_001' => 'عربي (نړۍ)',
        'ar_AE' => 'عربي (متحده عرب امارات)',
        'ar_BH' => 'عربي (بحرين)',
        'ar_DJ' => 'عربي (جبوتي)',
        'ar_DZ' => 'عربي (الجزایر)',
        'ar_EG' => 'عربي (مصر)',
        'ar_EH' => 'عربي (لويديځ صحارا)',
        'ar_ER' => 'عربي (اریتره)',
        'ar_IL' => 'عربي (اسراييل)',
        'ar_IQ' => 'عربي (عراق)',
        'ar_JO' => 'عربي (اردن)',
        'ar_KM' => 'عربي (کوموروس)',
        'ar_KW' => 'عربي (کويت)',
        'ar_LB' => 'عربي (لبنان)',
        'ar_LY' => 'عربي (لیبیا)',
        'ar_MA' => 'عربي (مراکش)',
        'ar_MR' => 'عربي (موریتانیا)',
        'ar_OM' => 'عربي (عمان)',
        'ar_PS' => 'عربي (فلسطیني سيمې)',
        'ar_QA' => 'عربي (قطر)',
        'ar_SA' => 'عربي (سعودي عربستان)',
        'ar_SD' => 'عربي (سوډان)',
        'ar_SO' => 'عربي (سومالیا)',
        'ar_SS' => 'عربي (سويلي سوډان)',
        'ar_SY' => 'عربي (سوریه)',
        'ar_TD' => 'عربي (چاډ)',
        'ar_TN' => 'عربي (تونس)',
        'ar_YE' => 'عربي (یمن)',
        'as' => 'اسامي',
        'as_IN' => 'اسامي (هند)',
        'az' => 'اذربایجاني',
        'az_AZ' => 'اذربایجاني (اذربايجان)',
        'az_Cyrl' => 'اذربایجاني (سیریلیک)',
        'az_Cyrl_AZ' => 'اذربایجاني (سیریلیک, اذربايجان)',
        'az_Latn' => 'اذربایجاني (لاتين/لاتيني)',
        'az_Latn_AZ' => 'اذربایجاني (لاتين/لاتيني, اذربايجان)',
        'be' => 'بېلاروسي',
        'be_BY' => 'بېلاروسي (بیلاروس)',
        'bg' => 'بلغاري',
        'bg_BG' => 'بلغاري (بلغاریه)',
        'bm' => 'بمبارا',
        'bm_ML' => 'بمبارا (مالي)',
        'bn' => 'بنگالي',
        'bn_BD' => 'بنگالي (بنگله دېش)',
        'bn_IN' => 'بنگالي (هند)',
        'bo' => 'تبتي',
        'bo_CN' => 'تبتي (چین)',
        'bo_IN' => 'تبتي (هند)',
        'br' => 'برېتون',
        'br_FR' => 'برېتون (فرانسه)',
        'bs' => 'بوسني',
        'bs_BA' => 'بوسني (بوسنيا او هېرزګوينا)',
        'bs_Cyrl' => 'بوسني (سیریلیک)',
        'bs_Cyrl_BA' => 'بوسني (سیریلیک, بوسنيا او هېرزګوينا)',
        'bs_Latn' => 'بوسني (لاتين/لاتيني)',
        'bs_Latn_BA' => 'بوسني (لاتين/لاتيني, بوسنيا او هېرزګوينا)',
        'ca' => 'کټلاني',
        'ca_AD' => 'کټلاني (اندورا)',
        'ca_ES' => 'کټلاني (هسپانیه)',
        'ca_FR' => 'کټلاني (فرانسه)',
        'ca_IT' => 'کټلاني (ایټالیه)',
        'ce' => 'چيچني',
        'ce_RU' => 'چيچني (روسیه)',
        'cs' => 'چېکي',
        'cs_CZ' => 'چېکي (چکیا)',
        'cv' => 'چوواشي',
        'cv_RU' => 'چوواشي (روسیه)',
        'cy' => 'ويلشي',
        'cy_GB' => 'ويلشي (برتانیه)',
        'da' => 'ډنمارکي',
        'da_DK' => 'ډنمارکي (ډنمارک)',
        'da_GL' => 'ډنمارکي (ګرینلینډ)',
        'de' => 'الماني',
        'de_AT' => 'الماني (اتریش)',
        'de_BE' => 'الماني (بیلجیم)',
        'de_CH' => 'الماني (سویس)',
        'de_DE' => 'الماني (المان)',
        'de_IT' => 'الماني (ایټالیه)',
        'de_LI' => 'الماني (لیختن اشتاین)',
        'de_LU' => 'الماني (لوګزامبورګ)',
        'dz' => 'ژونگکه',
        'dz_BT' => 'ژونگکه (بهوټان)',
        'ee' => 'ايو',
        'ee_GH' => 'ايو (ګانا)',
        'ee_TG' => 'ايو (ټوګو)',
        'el' => 'یوناني',
        'el_CY' => 'یوناني (قبرس)',
        'el_GR' => 'یوناني (یونان)',
        'en' => 'انګليسي',
        'en_001' => 'انګليسي (نړۍ)',
        'en_150' => 'انګليسي (اروپا)',
        'en_AE' => 'انګليسي (متحده عرب امارات)',
        'en_AG' => 'انګليسي (انټيګوا او باربودا)',
        'en_AI' => 'انګليسي (انګیلا)',
        'en_AS' => 'انګليسي (امریکایی ساماوا)',
        'en_AT' => 'انګليسي (اتریش)',
        'en_AU' => 'انګليسي (آسټرالیا)',
        'en_BB' => 'انګليسي (باربادوس)',
        'en_BE' => 'انګليسي (بیلجیم)',
        'en_BI' => 'انګليسي (بروندي)',
        'en_BM' => 'انګليسي (برمودا)',
        'en_BS' => 'انګليسي (باهماس)',
        'en_BW' => 'انګليسي (بوتسوانه)',
        'en_BZ' => 'انګليسي (بلیز)',
        'en_CA' => 'انګليسي (کاناډا)',
        'en_CC' => 'انګليسي (کوکوز [کيلنګ] ټاپوګان)',
        'en_CH' => 'انګليسي (سویس)',
        'en_CK' => 'انګليسي (کوک ټاپوګان)',
        'en_CM' => 'انګليسي (کامرون)',
        'en_CX' => 'انګليسي (د کريسمس ټاپو)',
        'en_CY' => 'انګليسي (قبرس)',
        'en_DE' => 'انګليسي (المان)',
        'en_DK' => 'انګليسي (ډنمارک)',
        'en_DM' => 'انګليسي (دومینیکا)',
        'en_ER' => 'انګليسي (اریتره)',
        'en_FI' => 'انګليسي (فنلینډ)',
        'en_FJ' => 'انګليسي (فجي)',
        'en_FK' => 'انګليسي (فاکلينډ ټاپوګان)',
        'en_FM' => 'انګليسي (میکرونیزیا)',
        'en_GB' => 'انګليسي (برتانیه)',
        'en_GD' => 'انګليسي (ګرنادا)',
        'en_GG' => 'انګليسي (ګرنسي)',
        'en_GH' => 'انګليسي (ګانا)',
        'en_GI' => 'انګليسي (جبل الطارق)',
        'en_GM' => 'انګليسي (ګامبیا)',
        'en_GU' => 'انګليسي (ګوام)',
        'en_GY' => 'انګليسي (ګیانا)',
        'en_HK' => 'انګليسي (هانګ کانګ SAR چین)',
        'en_IE' => 'انګليسي (آيرلېنډ)',
        'en_IL' => 'انګليسي (اسراييل)',
        'en_IM' => 'انګليسي (د آئل آف مین)',
        'en_IN' => 'انګليسي (هند)',
        'en_IO' => 'انګليسي (د برتانوي هند سمندري سيمه)',
        'en_JE' => 'انګليسي (جرسی)',
        'en_JM' => 'انګليسي (جمیکا)',
        'en_KE' => 'انګليسي (کینیا)',
        'en_KI' => 'انګليسي (کیري باتي)',
        'en_KN' => 'انګليسي (سینټ کټس او نیویس)',
        'en_KY' => 'انګليسي (کیمان ټاپوګان)',
        'en_LC' => 'انګليسي (سینټ لوسیا)',
        'en_LR' => 'انګليسي (لايبيريا)',
        'en_LS' => 'انګليسي (لسوتو)',
        'en_MG' => 'انګليسي (مدغاسکر)',
        'en_MH' => 'انګليسي (مارشل ټاپوګان)',
        'en_MO' => 'انګليسي (مکاو SAR چین)',
        'en_MP' => 'انګليسي (شمالي ماريانا ټاپوګان)',
        'en_MS' => 'انګليسي (مانټیسیرت)',
        'en_MT' => 'انګليسي (مالټا)',
        'en_MU' => 'انګليسي (موریشیس)',
        'en_MV' => 'انګليسي (مالديپ)',
        'en_MW' => 'انګليسي (مالاوي)',
        'en_MY' => 'انګليسي (مالیزیا)',
        'en_NA' => 'انګليسي (نیمبیا)',
        'en_NF' => 'انګليسي (نارفولک ټاپوګان)',
        'en_NG' => 'انګليسي (نایجیریا)',
        'en_NL' => 'انګليسي (هالېنډ)',
        'en_NR' => 'انګليسي (نایرو)',
        'en_NU' => 'انګليسي (نیوو)',
        'en_NZ' => 'انګليسي (نیوزیلنډ)',
        'en_PG' => 'انګليسي (پاپوا نيو ګيني)',
        'en_PH' => 'انګليسي (فلپين)',
        'en_PK' => 'انګليسي (پاکستان)',
        'en_PN' => 'انګليسي (پيټکيرن ټاپوګان)',
        'en_PR' => 'انګليسي (پورتو ریکو)',
        'en_PW' => 'انګليسي (پلاؤ)',
        'en_RW' => 'انګليسي (روندا)',
        'en_SB' => 'انګليسي (سليمان ټاپوګان)',
        'en_SC' => 'انګليسي (سیچیلیس)',
        'en_SD' => 'انګليسي (سوډان)',
        'en_SE' => 'انګليسي (سویډن)',
        'en_SG' => 'انګليسي (سينگاپور)',
        'en_SH' => 'انګليسي (سینټ هیلینا)',
        'en_SI' => 'انګليسي (سلوانیا)',
        'en_SL' => 'انګليسي (سییرا لیون)',
        'en_SS' => 'انګليسي (سويلي سوډان)',
        'en_SX' => 'انګليسي (سینټ مارټین)',
        'en_SZ' => 'انګليسي (اسواټيني)',
        'en_TC' => 'انګليسي (د ترکیې او کیکاسو ټاپو)',
        'en_TK' => 'انګليسي (توکیلو)',
        'en_TO' => 'انګليسي (تونګا)',
        'en_TT' => 'انګليسي (ټرينيډاډ او ټوباګو)',
        'en_TV' => 'انګليسي (توالیو)',
        'en_TZ' => 'انګليسي (تنزانیا)',
        'en_UG' => 'انګليسي (یوګانډا)',
        'en_UM' => 'انګليسي (د متحده ایالاتو ټاپوګان)',
        'en_US' => 'انګليسي (متحده آيالات)',
        'en_VC' => 'انګليسي (سینټ ویسنټینټ او ګرینډینز)',
        'en_VG' => 'انګليسي (بریتانوی ویګور ټاپوګان)',
        'en_VI' => 'انګليسي (د متحده آيالاتو ورجن ټاپوګان)',
        'en_VU' => 'انګليسي (واناتو)',
        'en_WS' => 'انګليسي (ساماوا)',
        'en_ZA' => 'انګليسي (سویلي افریقا)',
        'en_ZM' => 'انګليسي (زیمبیا)',
        'en_ZW' => 'انګليسي (زیمبابوی)',
        'eo' => 'اسپرانتو',
        'eo_001' => 'اسپرانتو (نړۍ)',
        'es' => 'هسپانوي',
        'es_419' => 'هسپانوي (لاتیني امریکا)',
        'es_AR' => 'هسپانوي (ارجنټاين)',
        'es_BO' => 'هسپانوي (بولیویا)',
        'es_BR' => 'هسپانوي (برازیل)',
        'es_BZ' => 'هسپانوي (بلیز)',
        'es_CL' => 'هسپانوي (چیلي)',
        'es_CO' => 'هسپانوي (کولمبیا)',
        'es_CR' => 'هسپانوي (کوستاریکا)',
        'es_CU' => 'هسپانوي (کیوبا)',
        'es_DO' => 'هسپانوي (جمهوريه ډومينيکن)',
        'es_EC' => 'هسپانوي (اکوادور)',
        'es_ES' => 'هسپانوي (هسپانیه)',
        'es_GQ' => 'هسپانوي (استوایی ګیني)',
        'es_GT' => 'هسپانوي (ګواتیمالا)',
        'es_HN' => 'هسپانوي (هانډوراس)',
        'es_MX' => 'هسپانوي (میکسیکو)',
        'es_NI' => 'هسپانوي (نکاراګوا)',
        'es_PA' => 'هسپانوي (پاناما)',
        'es_PE' => 'هسپانوي (پیرو)',
        'es_PH' => 'هسپانوي (فلپين)',
        'es_PR' => 'هسپانوي (پورتو ریکو)',
        'es_PY' => 'هسپانوي (پاراګوی)',
        'es_SV' => 'هسپانوي (سالوېډور)',
        'es_US' => 'هسپانوي (متحده آيالات)',
        'es_UY' => 'هسپانوي (یوروګوی)',
        'es_VE' => 'هسپانوي (وینزویلا)',
        'et' => 'حبشي',
        'et_EE' => 'حبشي (استونیا)',
        'eu' => 'باسکي',
        'eu_ES' => 'باسکي (هسپانیه)',
        'fa' => 'فارسي',
        'fa_AF' => 'فارسي (افغانستان)',
        'fa_IR' => 'فارسي (ايران)',
        'ff' => 'فولاح',
        'ff_Adlm' => 'فولاح (اډلام)',
        'ff_Adlm_BF' => 'فولاح (اډلام, بورکینا فاسو)',
        'ff_Adlm_CM' => 'فولاح (اډلام, کامرون)',
        'ff_Adlm_GH' => 'فولاح (اډلام, ګانا)',
        'ff_Adlm_GM' => 'فولاح (اډلام, ګامبیا)',
        'ff_Adlm_GN' => 'فولاح (اډلام, ګینه)',
        'ff_Adlm_GW' => 'فولاح (اډلام, ګینه بیسو)',
        'ff_Adlm_LR' => 'فولاح (اډلام, لايبيريا)',
        'ff_Adlm_MR' => 'فولاح (اډلام, موریتانیا)',
        'ff_Adlm_NE' => 'فولاح (اډلام, نايجير)',
        'ff_Adlm_NG' => 'فولاح (اډلام, نایجیریا)',
        'ff_Adlm_SL' => 'فولاح (اډلام, سییرا لیون)',
        'ff_Adlm_SN' => 'فولاح (اډلام, سينيګال)',
        'ff_CM' => 'فولاح (کامرون)',
        'ff_GN' => 'فولاح (ګینه)',
        'ff_Latn' => 'فولاح (لاتين/لاتيني)',
        'ff_Latn_BF' => 'فولاح (لاتين/لاتيني, بورکینا فاسو)',
        'ff_Latn_CM' => 'فولاح (لاتين/لاتيني, کامرون)',
        'ff_Latn_GH' => 'فولاح (لاتين/لاتيني, ګانا)',
        'ff_Latn_GM' => 'فولاح (لاتين/لاتيني, ګامبیا)',
        'ff_Latn_GN' => 'فولاح (لاتين/لاتيني, ګینه)',
        'ff_Latn_GW' => 'فولاح (لاتين/لاتيني, ګینه بیسو)',
        'ff_Latn_LR' => 'فولاح (لاتين/لاتيني, لايبيريا)',
        'ff_Latn_MR' => 'فولاح (لاتين/لاتيني, موریتانیا)',
        'ff_Latn_NE' => 'فولاح (لاتين/لاتيني, نايجير)',
        'ff_Latn_NG' => 'فولاح (لاتين/لاتيني, نایجیریا)',
        'ff_Latn_SL' => 'فولاح (لاتين/لاتيني, سییرا لیون)',
        'ff_Latn_SN' => 'فولاح (لاتين/لاتيني, سينيګال)',
        'ff_MR' => 'فولاح (موریتانیا)',
        'ff_SN' => 'فولاح (سينيګال)',
        'fi' => 'فینلنډي',
        'fi_FI' => 'فینلنډي (فنلینډ)',
        'fo' => 'فاروئې',
        'fo_DK' => 'فاروئې (ډنمارک)',
        'fo_FO' => 'فاروئې (فارو ټاپو)',
        'fr' => 'فرانسوي',
        'fr_BE' => 'فرانسوي (بیلجیم)',
        'fr_BF' => 'فرانسوي (بورکینا فاسو)',
        'fr_BI' => 'فرانسوي (بروندي)',
        'fr_BJ' => 'فرانسوي (بینن)',
        'fr_BL' => 'فرانسوي (سينټ بارتيلمي)',
        'fr_CA' => 'فرانسوي (کاناډا)',
        'fr_CD' => 'فرانسوي (کانګو - کینشاسا)',
        'fr_CF' => 'فرانسوي (وسطي افريقا جمهور)',
        'fr_CG' => 'فرانسوي (کانګو - بروزوییل)',
        'fr_CH' => 'فرانسوي (سویس)',
        'fr_CI' => 'فرانسوي (د عاج ساحل)',
        'fr_CM' => 'فرانسوي (کامرون)',
        'fr_DJ' => 'فرانسوي (جبوتي)',
        'fr_DZ' => 'فرانسوي (الجزایر)',
        'fr_FR' => 'فرانسوي (فرانسه)',
        'fr_GA' => 'فرانسوي (ګابن)',
        'fr_GF' => 'فرانسوي (فرانسوي ګانا)',
        'fr_GN' => 'فرانسوي (ګینه)',
        'fr_GP' => 'فرانسوي (ګوادلوپ)',
        'fr_GQ' => 'فرانسوي (استوایی ګیني)',
        'fr_HT' => 'فرانسوي (هایټي)',
        'fr_KM' => 'فرانسوي (کوموروس)',
        'fr_LU' => 'فرانسوي (لوګزامبورګ)',
        'fr_MA' => 'فرانسوي (مراکش)',
        'fr_MC' => 'فرانسوي (موناکو)',
        'fr_MF' => 'فرانسوي (سینټ مارټن)',
        'fr_MG' => 'فرانسوي (مدغاسکر)',
        'fr_ML' => 'فرانسوي (مالي)',
        'fr_MQ' => 'فرانسوي (مارټینیک)',
        'fr_MR' => 'فرانسوي (موریتانیا)',
        'fr_MU' => 'فرانسوي (موریشیس)',
        'fr_NC' => 'فرانسوي (نوی کالیډونیا)',
        'fr_NE' => 'فرانسوي (نايجير)',
        'fr_PF' => 'فرانسوي (فرانسوي پولينيسيا)',
        'fr_PM' => 'فرانسوي (سینټ پییر او میکولون)',
        'fr_RE' => 'فرانسوي (ریونین)',
        'fr_RW' => 'فرانسوي (روندا)',
        'fr_SC' => 'فرانسوي (سیچیلیس)',
        'fr_SN' => 'فرانسوي (سينيګال)',
        'fr_SY' => 'فرانسوي (سوریه)',
        'fr_TD' => 'فرانسوي (چاډ)',
        'fr_TG' => 'فرانسوي (ټوګو)',
        'fr_TN' => 'فرانسوي (تونس)',
        'fr_VU' => 'فرانسوي (واناتو)',
        'fr_WF' => 'فرانسوي (والیس او فوتونا)',
        'fr_YT' => 'فرانسوي (مايوټ)',
        'fy' => 'لوېديځ فريشي',
        'fy_NL' => 'لوېديځ فريشي (هالېنډ)',
        'ga' => 'ائيرلېنډي',
        'ga_GB' => 'ائيرلېنډي (برتانیه)',
        'ga_IE' => 'ائيرلېنډي (آيرلېنډ)',
        'gd' => 'سکاټلېنډي ګېلک',
        'gd_GB' => 'سکاټلېنډي ګېلک (برتانیه)',
        'gl' => 'ګلېشيايي',
        'gl_ES' => 'ګلېشيايي (هسپانیه)',
        'gu' => 'ګجراتي',
        'gu_IN' => 'ګجراتي (هند)',
        'gv' => 'مینکس',
        'gv_IM' => 'مینکس (د آئل آف مین)',
        'ha' => 'هوسا',
        'ha_GH' => 'هوسا (ګانا)',
        'ha_NE' => 'هوسا (نايجير)',
        'ha_NG' => 'هوسا (نایجیریا)',
        'he' => 'عبراني',
        'he_IL' => 'عبراني (اسراييل)',
        'hi' => 'هندي',
        'hi_IN' => 'هندي (هند)',
        'hi_Latn' => 'هندي (لاتين/لاتيني)',
        'hi_Latn_IN' => 'هندي (لاتين/لاتيني, هند)',
        'hr' => 'کروايشيايي',
        'hr_BA' => 'کروايشيايي (بوسنيا او هېرزګوينا)',
        'hr_HR' => 'کروايشيايي (کرواشيا)',
        'hu' => 'هنګري',
        'hu_HU' => 'هنګري (مجارستان)',
        'hy' => 'آرمينيايي',
        'hy_AM' => 'آرمينيايي (ارمنستان)',
        'ia' => 'انټرلنګوا',
        'ia_001' => 'انټرلنګوا (نړۍ)',
        'id' => 'انډونېزي',
        'id_ID' => 'انډونېزي (اندونیزیا)',
        'ig' => 'اګبو',
        'ig_NG' => 'اګبو (نایجیریا)',
        'ii' => 'سیچیان یی',
        'ii_CN' => 'سیچیان یی (چین)',
        'is' => 'ايسلنډي',
        'is_IS' => 'ايسلنډي (آیسلینډ)',
        'it' => 'ایټالوي',
        'it_CH' => 'ایټالوي (سویس)',
        'it_IT' => 'ایټالوي (ایټالیه)',
        'it_SM' => 'ایټالوي (سان مارینو)',
        'it_VA' => 'ایټالوي (واتیکان ښار)',
        'ja' => 'جاپاني',
        'ja_JP' => 'جاپاني (جاپان)',
        'jv' => 'جاوايي',
        'jv_ID' => 'جاوايي (اندونیزیا)',
        'ka' => 'جورجيائي',
        'ka_GE' => 'جورجيائي (گورجستان)',
        'ki' => 'ککوؤو',
        'ki_KE' => 'ککوؤو (کینیا)',
        'kk' => 'قازق',
        'kk_KZ' => 'قازق (قزاقستان)',
        'kl' => 'کلالیسٹ',
        'kl_GL' => 'کلالیسٹ (ګرینلینډ)',
        'km' => 'خمر',
        'km_KH' => 'خمر (کمبودیا)',
        'kn' => 'کناډا',
        'kn_IN' => 'کناډا (هند)',
        'ko' => 'کوریایی',
        'ko_KP' => 'کوریایی (شمالی کوریا)',
        'ko_KR' => 'کوریایی (سویلي کوریا)',
        'ks' => 'کشمیري',
        'ks_Arab' => 'کشمیري (عربي)',
        'ks_Arab_IN' => 'کشمیري (عربي, هند)',
        'ks_Deva' => 'کشمیري (دیواناګري)',
        'ks_Deva_IN' => 'کشمیري (دیواناګري, هند)',
        'ks_IN' => 'کشمیري (هند)',
        'ku' => 'کردي',
        'ku_TR' => 'کردي (ترکي)',
        'kw' => 'کورنيشي',
        'kw_GB' => 'کورنيشي (برتانیه)',
        'ky' => 'کرغيزي',
        'ky_KG' => 'کرغيزي (قرغزستان)',
        'lb' => 'لوګزامبورګي',
        'lb_LU' => 'لوګزامبورګي (لوګزامبورګ)',
        'lg' => 'ګانده',
        'lg_UG' => 'ګانده (یوګانډا)',
        'ln' => 'لنګالا',
        'ln_AO' => 'لنګالا (انګولا)',
        'ln_CD' => 'لنګالا (کانګو - کینشاسا)',
        'ln_CF' => 'لنګالا (وسطي افريقا جمهور)',
        'ln_CG' => 'لنګالا (کانګو - بروزوییل)',
        'lo' => 'لاو',
        'lo_LA' => 'لاو (لاوس)',
        'lt' => 'ليتواني',
        'lt_LT' => 'ليتواني (لیتوانیا)',
        'lu' => 'لوبا-کټنګا',
        'lu_CD' => 'لوبا-کټنګا (کانګو - کینشاسا)',
        'lv' => 'لېټواني',
        'lv_LV' => 'لېټواني (ليتهويا)',
        'mg' => 'ملغاسي',
        'mg_MG' => 'ملغاسي (مدغاسکر)',
        'mi' => 'ماوري',
        'mi_NZ' => 'ماوري (نیوزیلنډ)',
        'mk' => 'مقدوني',
        'mk_MK' => 'مقدوني (شمالي مقدونيه)',
        'ml' => 'مالايالم',
        'ml_IN' => 'مالايالم (هند)',
        'mn' => 'منګولیایی',
        'mn_MN' => 'منګولیایی (منګوليا)',
        'mr' => 'مراټهي',
        'mr_IN' => 'مراټهي (هند)',
        'ms' => 'ملایا',
        'ms_BN' => 'ملایا (برونائي)',
        'ms_ID' => 'ملایا (اندونیزیا)',
        'ms_MY' => 'ملایا (مالیزیا)',
        'ms_SG' => 'ملایا (سينگاپور)',
        'mt' => 'مالټايي',
        'mt_MT' => 'مالټايي (مالټا)',
        'my' => 'برمایی',
        'my_MM' => 'برمایی (ميانمار [برما])',
        'nb' => 'ناروېئي [بوکمال]',
        'nb_NO' => 'ناروېئي [بوکمال] (ناروۍ)',
        'nb_SJ' => 'ناروېئي [بوکمال] (سوالبارد او جان ميين)',
        'nd' => 'شمالي نديبل',
        'nd_ZW' => 'شمالي نديبل (زیمبابوی)',
        'ne' => 'نېپالي',
        'ne_IN' => 'نېپالي (هند)',
        'ne_NP' => 'نېپالي (نیپال)',
        'nl' => 'هالېنډي',
        'nl_AW' => 'هالېنډي (آروبا)',
        'nl_BE' => 'هالېنډي (بیلجیم)',
        'nl_BQ' => 'هالېنډي (کیریبین هالینډ)',
        'nl_CW' => 'هالېنډي (کوراکاو)',
        'nl_NL' => 'هالېنډي (هالېنډ)',
        'nl_SR' => 'هالېنډي (سورینام)',
        'nl_SX' => 'هالېنډي (سینټ مارټین)',
        'nn' => 'ناروېئي [نائنورسک]',
        'nn_NO' => 'ناروېئي [نائنورسک] (ناروۍ)',
        'no' => 'ناروېئي',
        'no_NO' => 'ناروېئي (ناروۍ)',
        'om' => 'اورومو',
        'om_ET' => 'اورومو (حبشه)',
        'om_KE' => 'اورومو (کینیا)',
        'or' => 'اوڊيا',
        'or_IN' => 'اوڊيا (هند)',
        'os' => 'اوسيټک',
        'os_GE' => 'اوسيټک (گورجستان)',
        'os_RU' => 'اوسيټک (روسیه)',
        'pa' => 'پنجابي',
        'pa_Arab' => 'پنجابي (عربي)',
        'pa_Arab_PK' => 'پنجابي (عربي, پاکستان)',
        'pa_Guru' => 'پنجابي (ګرومي)',
        'pa_Guru_IN' => 'پنجابي (ګرومي, هند)',
        'pa_IN' => 'پنجابي (هند)',
        'pa_PK' => 'پنجابي (پاکستان)',
        'pl' => 'پولنډي',
        'pl_PL' => 'پولنډي (پولنډ)',
        'ps' => 'پښتو',
        'ps_AF' => 'پښتو (افغانستان)',
        'ps_PK' => 'پښتو (پاکستان)',
        'pt' => 'پورتګالي',
        'pt_AO' => 'پورتګالي (انګولا)',
        'pt_BR' => 'پورتګالي (برازیل)',
        'pt_CH' => 'پورتګالي (سویس)',
        'pt_CV' => 'پورتګالي (کیپ ورد)',
        'pt_GQ' => 'پورتګالي (استوایی ګیني)',
        'pt_GW' => 'پورتګالي (ګینه بیسو)',
        'pt_LU' => 'پورتګالي (لوګزامبورګ)',
        'pt_MO' => 'پورتګالي (مکاو SAR چین)',
        'pt_MZ' => 'پورتګالي (موزمبيق)',
        'pt_PT' => 'پورتګالي (پورتګال)',
        'pt_ST' => 'پورتګالي (ساو ټیم او پرنسیپ)',
        'pt_TL' => 'پورتګالي (تيمور-ليسټ)',
        'qu' => 'کېچوا',
        'qu_BO' => 'کېچوا (بولیویا)',
        'qu_EC' => 'کېچوا (اکوادور)',
        'qu_PE' => 'کېچوا (پیرو)',
        'rm' => 'رومانیش',
        'rm_CH' => 'رومانیش (سویس)',
        'rn' => 'رونډی',
        'rn_BI' => 'رونډی (بروندي)',
        'ro' => 'رومانیایی',
        'ro_MD' => 'رومانیایی (مولدوا)',
        'ro_RO' => 'رومانیایی (رومانیا)',
        'ru' => 'روسي',
        'ru_BY' => 'روسي (بیلاروس)',
        'ru_KG' => 'روسي (قرغزستان)',
        'ru_KZ' => 'روسي (قزاقستان)',
        'ru_MD' => 'روسي (مولدوا)',
        'ru_RU' => 'روسي (روسیه)',
        'ru_UA' => 'روسي (اوکراین)',
        'rw' => 'کینیارونډا',
        'rw_RW' => 'کینیارونډا (روندا)',
        'sa' => 'سنسکریټ',
        'sa_IN' => 'سنسکریټ (هند)',
        'sc' => 'سارڊيني',
        'sc_IT' => 'سارڊيني (ایټالیه)',
        'sd' => 'سندهي',
        'sd_Arab' => 'سندهي (عربي)',
        'sd_Arab_PK' => 'سندهي (عربي, پاکستان)',
        'sd_Deva' => 'سندهي (دیواناګري)',
        'sd_Deva_IN' => 'سندهي (دیواناګري, هند)',
        'sd_IN' => 'سندهي (هند)',
        'sd_PK' => 'سندهي (پاکستان)',
        'se' => 'شمالي سامي',
        'se_FI' => 'شمالي سامي (فنلینډ)',
        'se_NO' => 'شمالي سامي (ناروۍ)',
        'se_SE' => 'شمالي سامي (سویډن)',
        'sg' => 'سانګو',
        'sg_CF' => 'سانګو (وسطي افريقا جمهور)',
        'si' => 'سينهالي',
        'si_LK' => 'سينهالي (سريلنکا)',
        'sk' => 'سلوواکي',
        'sk_SK' => 'سلوواکي (سلواکیا)',
        'sl' => 'سلوواني',
        'sl_SI' => 'سلوواني (سلوانیا)',
        'sn' => 'شونا',
        'sn_ZW' => 'شونا (زیمبابوی)',
        'so' => 'سومالي',
        'so_DJ' => 'سومالي (جبوتي)',
        'so_ET' => 'سومالي (حبشه)',
        'so_KE' => 'سومالي (کینیا)',
        'so_SO' => 'سومالي (سومالیا)',
        'sq' => 'الباني',
        'sq_AL' => 'الباني (البانیه)',
        'sq_MK' => 'الباني (شمالي مقدونيه)',
        'sr' => 'سربيائي',
        'sr_BA' => 'سربيائي (بوسنيا او هېرزګوينا)',
        'sr_Cyrl' => 'سربيائي (سیریلیک)',
        'sr_Cyrl_BA' => 'سربيائي (سیریلیک, بوسنيا او هېرزګوينا)',
        'sr_Cyrl_ME' => 'سربيائي (سیریلیک, مونټینیګرو)',
        'sr_Cyrl_RS' => 'سربيائي (سیریلیک, سربيا)',
        'sr_Latn' => 'سربيائي (لاتين/لاتيني)',
        'sr_Latn_BA' => 'سربيائي (لاتين/لاتيني, بوسنيا او هېرزګوينا)',
        'sr_Latn_ME' => 'سربيائي (لاتين/لاتيني, مونټینیګرو)',
        'sr_Latn_RS' => 'سربيائي (لاتين/لاتيني, سربيا)',
        'sr_ME' => 'سربيائي (مونټینیګرو)',
        'sr_RS' => 'سربيائي (سربيا)',
        'su' => 'سوډاني',
        'su_ID' => 'سوډاني (اندونیزیا)',
        'su_Latn' => 'سوډاني (لاتين/لاتيني)',
        'su_Latn_ID' => 'سوډاني (لاتين/لاتيني, اندونیزیا)',
        'sv' => 'سویډنی',
        'sv_AX' => 'سویډنی (الاند ټاپوان)',
        'sv_FI' => 'سویډنی (فنلینډ)',
        'sv_SE' => 'سویډنی (سویډن)',
        'sw' => 'سواهېلي',
        'sw_CD' => 'سواهېلي (کانګو - کینشاسا)',
        'sw_KE' => 'سواهېلي (کینیا)',
        'sw_TZ' => 'سواهېلي (تنزانیا)',
        'sw_UG' => 'سواهېلي (یوګانډا)',
        'ta' => 'تامل',
        'ta_IN' => 'تامل (هند)',
        'ta_LK' => 'تامل (سريلنکا)',
        'ta_MY' => 'تامل (مالیزیا)',
        'ta_SG' => 'تامل (سينگاپور)',
        'te' => 'تېليګو',
        'te_IN' => 'تېليګو (هند)',
        'tg' => 'تاجکي',
        'tg_TJ' => 'تاجکي (تاجکستان)',
        'th' => 'تايلېنډي',
        'th_TH' => 'تايلېنډي (تهايلنډ)',
        'ti' => 'تيګريني',
        'ti_ER' => 'تيګريني (اریتره)',
        'ti_ET' => 'تيګريني (حبشه)',
        'tk' => 'ترکمني',
        'tk_TM' => 'ترکمني (تورکمنستان)',
        'to' => 'تونګان',
        'to_TO' => 'تونګان (تونګا)',
        'tr' => 'ترکي',
        'tr_CY' => 'ترکي (قبرس)',
        'tr_TR' => 'ترکي (ترکي)',
        'tt' => 'تاتار',
        'tt_RU' => 'تاتار (روسیه)',
        'ug' => 'اويغوري',
        'ug_CN' => 'اويغوري (چین)',
        'uk' => 'اوکرايني',
        'uk_UA' => 'اوکرايني (اوکراین)',
        'ur' => 'اردو',
        'ur_IN' => 'اردو (هند)',
        'ur_PK' => 'اردو (پاکستان)',
        'uz' => 'اوزبکي',
        'uz_AF' => 'اوزبکي (افغانستان)',
        'uz_Arab' => 'اوزبکي (عربي)',
        'uz_Arab_AF' => 'اوزبکي (عربي, افغانستان)',
        'uz_Cyrl' => 'اوزبکي (سیریلیک)',
        'uz_Cyrl_UZ' => 'اوزبکي (سیریلیک, اوزبکستان)',
        'uz_Latn' => 'اوزبکي (لاتين/لاتيني)',
        'uz_Latn_UZ' => 'اوزبکي (لاتين/لاتيني, اوزبکستان)',
        'uz_UZ' => 'اوزبکي (اوزبکستان)',
        'vi' => 'وېتنامي',
        'vi_VN' => 'وېتنامي (وېتنام)',
        'wo' => 'ولوف',
        'wo_SN' => 'ولوف (سينيګال)',
        'xh' => 'خوسا',
        'xh_ZA' => 'خوسا (سویلي افریقا)',
        'yi' => 'يديش',
        'yi_001' => 'يديش (نړۍ)',
        'yo' => 'یوروبا',
        'yo_BJ' => 'یوروبا (بینن)',
        'yo_NG' => 'یوروبا (نایجیریا)',
        'zh' => 'چیني',
        'zh_CN' => 'چیني (چین)',
        'zh_HK' => 'چیني (هانګ کانګ SAR چین)',
        'zh_Hans' => 'چیني (ساده شوی)',
        'zh_Hans_CN' => 'چیني (ساده شوی, چین)',
        'zh_Hans_HK' => 'چیني (ساده شوی, هانګ کانګ SAR چین)',
        'zh_Hans_MO' => 'چیني (ساده شوی, مکاو SAR چین)',
        'zh_Hans_SG' => 'چیني (ساده شوی, سينگاپور)',
        'zh_Hant' => 'چیني (دودیزه)',
        'zh_Hant_HK' => 'چیني (دودیزه, هانګ کانګ SAR چین)',
        'zh_Hant_MO' => 'چیني (دودیزه, مکاو SAR چین)',
        'zh_Hant_TW' => 'چیني (دودیزه, تائيوان)',
        'zh_MO' => 'چیني (مکاو SAR چین)',
        'zh_SG' => 'چیني (سينگاپور)',
        'zh_TW' => 'چیني (تائيوان)',
        'zu' => 'زولو',
        'zu_ZA' => 'زولو (سویلي افریقا)',
    ],
];
