<?php

return [
    'Names' => [
        'Adlm' => 'ແອດລາມ',
        'Afak' => 'ອັບຟາກາ',
        'Arab' => 'ອາຣາບິກ',
        'Aran' => 'ນາສຕໍລິກ (ຄຳໃບ້ການແປ: ລະຫັດພິເສດກຳນົດຮູບແບບຕົວໜັງສືອາຣັບ.)',
        'Armi' => 'ອິມພີຮຽນ ອາເມອິກ',
        'Armn' => 'ອາເມນຽນ',
        'Avst' => 'ອະເວສຕະ',
        'Bali' => 'ບາລີ',
        'Bamu' => 'ບາມູມ',
        'Bass' => 'ບັດຊາ',
        'Batk' => 'ບາຕັກ',
        'Beng' => 'ເບັງກາ',
        'Blis' => 'ບລິກຊິມໂບລສ',
        'Bopo' => 'ຈູ້ອິນ',
        'Brah' => 'ພຮາຫມີ',
        'Brai' => 'ເບຣວ',
        'Bugi' => 'ບູກິສ',
        'Buhd' => 'ບູຮິດ',
        'Cakm' => 'ຊາກມາ',
        'Cans' => 'ສັນຍາລັກຊົນເຜົ່າພື້ນເມືອງແຄນນາດາ',
        'Cari' => 'ຄາເຮຍ',
        'Cham' => 'ຈາມ',
        'Cher' => 'ເຊໂຮກີ',
        'Cirt' => 'ເຊີຮ',
        'Copt' => 'ຄອບຕິກ',
        'Cprt' => 'ໄຊເປຍ',
        'Cyrl' => 'ຊີຣິວລິກ',
        'Cyrs' => 'ເຊຮັດສລາ ໂວນິກຊີຮິກລິກໂບຮານ',
        'Deva' => 'ດີວານາກາຣີ',
        'Dsrt' => 'ເດເຊເຮ',
        'Dupl' => 'ຊົວເລດັບໂລຍັນ',
        'Egyd' => 'ດີໂມຕິກອີຍິບ',
        'Egyh' => 'ເຮຍຮາຕິກອີຍິບ',
        'Egyp' => 'ເຮຍໂຮກລິຟອີຍິບ',
        'Ethi' => 'ອີທິໂອປິກ',
        'Geok' => 'ຄອດຊູຮີຈໍເຈຍ',
        'Geor' => 'ຈໍຈຽນ',
        'Glag' => 'ກລາໂກລິຕິກ',
        'Goth' => 'ໂກຮິກ',
        'Gran' => 'ເຄນທາ',
        'Grek' => 'ກຣີກ',
        'Gujr' => 'ຈູຈາຣາທີ',
        'Guru' => 'ກົວມູຄີ',
        'Hanb' => 'ຮັນ',
        'Hang' => 'ຮັນກູນ',
        'Hani' => 'ຮານ',
        'Hano' => 'ຮານູໂນໂອ',
        'Hans' => 'ແບບຮຽບງ່າຍ',
        'Hant' => 'ແບບດັ້ງເດີມ',
        'Hebr' => 'ຮີບຣິວ',
        'Hira' => 'ຣິຣະງະນະ',
        'Hluw' => 'ອັກລຮະອານາໂຕເລຍ',
        'Hmng' => 'ປາເຮາເມັງ',
        'Hrkt' => 'ຕາຕາລາງພະຍາງພາສາຍີ່ປຸ່ນ',
        'Hung' => 'ຮັງກາຮີໂບຮານ',
        'Inds' => 'ອິນດັດ',
        'Ital' => 'ອີຕາລີໂບຮານ',
        'Jamo' => 'ຈາໂມ',
        'Java' => 'ຈາວາ',
        'Jpan' => 'ຍີ່ປຸ່ນ',
        'Jurc' => 'ຈູຮເຊັນ',
        'Kali' => 'ຄຍາ',
        'Kana' => 'ຄະຕະກະນະ',
        'Khar' => 'ຂໍໂຮກສີ',
        'Khmr' => 'ຂະແມ',
        'Khoj' => 'ຄໍຈຄີ',
        'Knda' => 'ຄັນນາດາ',
        'Kore' => 'ເກົາຫຼີ',
        'Kpel' => 'ເປລເລ',
        'Kthi' => 'ກາຍຕິ',
        'Lana' => 'ລ້ານນາ',
        'Laoo' => 'ລາວ',
        'Latf' => 'ລາຕິນ-ຟຮັ່ງເຕຣ',
        'Latg' => 'ລາຕິນ-ແກລິກ',
        'Latn' => 'ລາຕິນ',
        'Lepc' => 'ເລຊາ',
        'Limb' => 'ລິມບູ',
        'Lina' => 'ລີເນຍ',
        'Linb' => 'ລີເນຍຣ',
        'Lisu' => 'ເຟຣເຊຮ',
        'Loma' => 'ໂລມາ',
        'Lyci' => 'ໄລເຊຍ',
        'Lydi' => 'ລີເດຍ',
        'Mand' => 'ແມນດຽນ',
        'Mani' => 'ມານິແຊນ',
        'Maya' => 'ມາຍາໄຮໂຮກລິບ',
        'Mend' => 'ເມນເດ',
        'Merc' => 'ເຄເລີຊີເມໂຮອິຕິກ',
        'Mero' => 'ເມໂຮຕິກ',
        'Mlym' => 'ມາເລຢາລາມ',
        'Mong' => 'ມົງໂກນ',
        'Moon' => 'ມູນ',
        'Mroo' => 'ເມໂຮ',
        'Mtei' => 'ເມເທມາເຍກ',
        'Mymr' => 'ມຽນມາ',
        'Narb' => 'ອາຮະເບຍເໜືອໂບຮານ',
        'Nbat' => 'ນາບາທາທຽນ',
        'Nkgb' => 'ກີບາ-ນາຊີ',
        'Nkoo' => 'ເອັນໂກ',
        'Nshu' => 'ນຸຊຸ',
        'Ogam' => 'ອອກຄອນ',
        'Olck' => 'ໂອຊິກິ',
        'Orkh' => 'ອອກສມັນຍາ',
        'Orya' => 'ໂອເດຍ',
        'Palm' => 'ພາລໄມຮິນ',
        'Perm' => 'ເພີມີໂບຮານ',
        'Phag' => 'ຟາກສ-ປາ',
        'Phli' => 'ປະຫລາວີອິນສຄິບຊັນແນລ',
        'Phlp' => 'ປະຫລາວີຊອດເຕຮ໌',
        'Phlv' => 'ປະຫລາວີບຸກ',
        'Phnx' => 'ຟີນິເຊຍ',
        'Plrd' => 'ສັດຕະສາດພໍຮລາ',
        'Prti' => 'ພາຮ໌ເທຍອິນສຄຮິປຊັນແນລ',
        'Rjng' => 'ເຮຈັງ',
        'Rohg' => 'ຮານິຟີ',
        'Roro' => 'ຮອງໂກຮອງໂກ',
        'Runr' => 'ຮູນິກ',
        'Samr' => 'ຊາມາເລຍ',
        'Sara' => 'ຊາຮາຕິ',
        'Sarb' => 'ອາລະເບຍໃຕ້ໂບຮານ',
        'Saur' => 'ໂສຮັດຕຣະ',
        'Sgnw' => 'ໄຊນ໌ໄຮຕີ້ງ',
        'Shaw' => 'ຊອວຽນ',
        'Shrd' => 'ຊາຮາດາ',
        'Sind' => 'ດຸດາວາດີ',
        'Sinh' => 'ສິນຫາລາ',
        'Sora' => 'ໂສຮາສົມເປັງ',
        'Sund' => 'ຊຸນດາ',
        'Sylo' => 'ຊີໂລຕິນາກຣີ',
        'Syrc' => 'ຊີເຮຍ',
        'Syre' => 'ຊີເຮຍເອສທຮານຈີໂລ',
        'Syrj' => 'ຊີເຮຍຕາເວັນຕົກ',
        'Syrn' => 'ຊີເຮຍຕາເວັນອອກ',
        'Tagb' => 'ຕັກບັນວາ',
        'Takr' => 'ທາຄຮີ',
        'Tale' => 'ໄທເລ',
        'Talu' => 'ໄທລື້ໃໝ່',
        'Taml' => 'ທາມິລ',
        'Tang' => 'ຕັນກັນ',
        'Tavt' => 'ໄທຫວຽດ',
        'Telu' => 'ເທລູກູ',
        'Teng' => 'ເທງກວາຮ',
        'Tfng' => 'ທີຟີນາກ',
        'Tglg' => 'ຕາກາລອກ',
        'Thaa' => 'ທານາ',
        'Thai' => 'ໄທ',
        'Tibt' => 'ທິເບທັນ',
        'Tirh' => 'ເທຮຸທາ',
        'Ugar' => 'ຍູກາຮິດ',
        'Vaii' => 'ໄວ',
        'Visp' => 'ຄຳເວົ້າທີ່ເບີ່ງເຫັນໄດ້',
        'Wara' => 'ວາຮັງກສິຕິ',
        'Wole' => 'ໂອລີເອ',
        'Xpeo' => 'ເປຮເຊຍໂບຮານ',
        'Xsux' => 'ອັກສອນຮູບປລີ່ມສຸເມເຮຍ-ອັດຄາເດຍ',
        'Yiii' => 'ຍີ',
        'Zinh' => 'ອິນເຮຮິດ',
        'Zmth' => 'ເຄື່ອງໝາຍທາງຄະນິດສາດ',
        'Zsye' => 'ອີໂມຈິ',
        'Zsym' => 'ສັນຍາລັກ',
        'Zxxx' => 'ບໍ່ມີພາສາຂຽນ',
        'Zyyy' => 'ສາມັນ',
    ],
];
