<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwichko meridianoaren ordua (Abidjan)',
        'Africa/Accra' => 'Greenwichko meridianoaren ordua (Akkra)',
        'Africa/Addis_Ababa' => 'Afrikako ekialdeko ordua (Addis Abeba)',
        'Africa/Algiers' => 'Europako erdialdeko ordua (Aljer)',
        'Africa/Asmera' => 'Afrikako ekialdeko ordua (Asmara)',
        'Africa/Bamako' => 'Greenwichko meridianoaren ordua (Bamako)',
        'Africa/Bangui' => 'Afrikako mendebaldeko ordua (Bangi)',
        'Africa/Banjul' => 'Greenwichko meridianoaren ordua (Banjul)',
        'Africa/Bissau' => 'Greenwichko meridianoaren ordua (Bissau)',
        'Africa/Blantyre' => 'Afrikako erdialdeko ordua (Blantyre)',
        'Africa/Brazzaville' => 'Afrikako mendebaldeko ordua (Brazzaville)',
        'Africa/Bujumbura' => 'Afrikako erdialdeko ordua (Bujumbura)',
        'Africa/Cairo' => 'Europako ekialdeko ordua (Kairo)',
        'Africa/Casablanca' => 'Europako mendebaldeko ordua (Casablanca)',
        'Africa/Ceuta' => 'Europako erdialdeko ordua (Ceuta)',
        'Africa/Conakry' => 'Greenwichko meridianoaren ordua (Konakry)',
        'Africa/Dakar' => 'Greenwichko meridianoaren ordua (Dakar)',
        'Africa/Dar_es_Salaam' => 'Afrikako ekialdeko ordua (Dar es Salaam)',
        'Africa/Djibouti' => 'Afrikako ekialdeko ordua (Djibuti)',
        'Africa/Douala' => 'Afrikako mendebaldeko ordua (Douala)',
        'Africa/El_Aaiun' => 'Europako mendebaldeko ordua (Aaiun)',
        'Africa/Freetown' => 'Greenwichko meridianoaren ordua (Freetown)',
        'Africa/Gaborone' => 'Afrikako erdialdeko ordua (Gaborone)',
        'Africa/Harare' => 'Afrikako erdialdeko ordua (Harare)',
        'Africa/Johannesburg' => 'Afrikako hegoaldeko ordua (Johannesburgo)',
        'Africa/Juba' => 'Afrikako erdialdeko ordua (Juba)',
        'Africa/Kampala' => 'Afrikako ekialdeko ordua (Kampala)',
        'Africa/Khartoum' => 'Afrikako erdialdeko ordua (Khartoum)',
        'Africa/Kigali' => 'Afrikako erdialdeko ordua (Kigali)',
        'Africa/Kinshasa' => 'Afrikako mendebaldeko ordua (Kinshasa)',
        'Africa/Lagos' => 'Afrikako mendebaldeko ordua (Lagos)',
        'Africa/Libreville' => 'Afrikako mendebaldeko ordua (Libreville)',
        'Africa/Lome' => 'Greenwichko meridianoaren ordua (Lome)',
        'Africa/Luanda' => 'Afrikako mendebaldeko ordua (Luanda)',
        'Africa/Lubumbashi' => 'Afrikako erdialdeko ordua (Lubumbashi)',
        'Africa/Lusaka' => 'Afrikako erdialdeko ordua (Lusaka)',
        'Africa/Malabo' => 'Afrikako mendebaldeko ordua (Malabo)',
        'Africa/Maputo' => 'Afrikako erdialdeko ordua (Maputo)',
        'Africa/Maseru' => 'Afrikako hegoaldeko ordua (Maseru)',
        'Africa/Mbabane' => 'Afrikako hegoaldeko ordua (Mbabane)',
        'Africa/Mogadishu' => 'Afrikako ekialdeko ordua (Muqdisho)',
        'Africa/Monrovia' => 'Greenwichko meridianoaren ordua (Monrovia)',
        'Africa/Nairobi' => 'Afrikako ekialdeko ordua (Nairobi)',
        'Africa/Ndjamena' => 'Afrikako mendebaldeko ordua (N’djamena)',
        'Africa/Niamey' => 'Afrikako mendebaldeko ordua (Niamei)',
        'Africa/Nouakchott' => 'Greenwichko meridianoaren ordua (Nuakxot)',
        'Africa/Ouagadougou' => 'Greenwichko meridianoaren ordua (Uagadugu)',
        'Africa/Porto-Novo' => 'Afrikako mendebaldeko ordua (Porto Novo)',
        'Africa/Sao_Tome' => 'Greenwichko meridianoaren ordua (Sao Tome)',
        'Africa/Tripoli' => 'Europako ekialdeko ordua (Tripoli)',
        'Africa/Tunis' => 'Europako erdialdeko ordua (Tunis)',
        'Africa/Windhoek' => 'Afrikako erdialdeko ordua (Windhoek)',
        'America/Adak' => 'Hawaii-Aleutiar uharteetako ordua (Adak)',
        'America/Anchorage' => 'Alaskako ordua (Anchorage)',
        'America/Anguilla' => 'Ipar Amerikako Atlantikoko ordua (Aingira)',
        'America/Antigua' => 'Ipar Amerikako Atlantikoko ordua (Antigua)',
        'America/Araguaina' => 'Brasiliako ordua (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentinako ordua (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentinako ordua (Rio Gallegos)',
        'America/Argentina/Salta' => 'Argentinako ordua (Salta)',
        'America/Argentina/San_Juan' => 'Argentinako ordua (San Juan)',
        'America/Argentina/San_Luis' => 'Argentinako ordua (San Luis)',
        'America/Argentina/Tucuman' => 'Argentinako ordua (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentinako ordua (Ushuaia)',
        'America/Aruba' => 'Ipar Amerikako Atlantikoko ordua (Aruba)',
        'America/Asuncion' => 'Paraguaiko ordua (Asuncion)',
        'America/Bahia' => 'Brasiliako ordua (Bahia)',
        'America/Bahia_Banderas' => 'Ipar Amerikako erdialdeko ordua (Bahía de Banderas)',
        'America/Barbados' => 'Ipar Amerikako Atlantikoko ordua (Barbados)',
        'America/Belem' => 'Brasiliako ordua (Belem)',
        'America/Belize' => 'Ipar Amerikako erdialdeko ordua (Belize)',
        'America/Blanc-Sablon' => 'Ipar Amerikako Atlantikoko ordua (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazoniako ordua (Boa Vista)',
        'America/Bogota' => 'Kolonbiako ordua (Bogota)',
        'America/Boise' => 'Ipar Amerikako mendialdeko ordua (Boise)',
        'America/Buenos_Aires' => 'Argentinako ordua (Buenos Aires)',
        'America/Cambridge_Bay' => 'Ipar Amerikako mendialdeko ordua (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazoniako ordua (Campo Grande)',
        'America/Cancun' => 'Ipar Amerikako ekialdeko ordua (Cancún)',
        'America/Caracas' => 'Venezuelako ordua (Caracas)',
        'America/Catamarca' => 'Argentinako ordua (Catamarca)',
        'America/Cayenne' => 'Guyana Frantseseko ordua (Cayenne)',
        'America/Cayman' => 'Ipar Amerikako ekialdeko ordua (Kaiman)',
        'America/Chicago' => 'Ipar Amerikako erdialdeko ordua (Chicago)',
        'America/Chihuahua' => 'Mexikoko Pazifikoko ordua (Chihuahua)',
        'America/Coral_Harbour' => 'Ipar Amerikako ekialdeko ordua (Atikokan)',
        'America/Cordoba' => 'Argentinako ordua (Córdoba)',
        'America/Costa_Rica' => 'Ipar Amerikako erdialdeko ordua (Costa Rica)',
        'America/Creston' => 'Ipar Amerikako mendialdeko ordua (Creston)',
        'America/Cuiaba' => 'Amazoniako ordua (Cuiabá)',
        'America/Curacao' => 'Ipar Amerikako Atlantikoko ordua (Curaçao)',
        'America/Danmarkshavn' => 'Greenwichko meridianoaren ordua (Danmarkshavn)',
        'America/Dawson' => 'Yukongo ordua (Dawson)',
        'America/Dawson_Creek' => 'Ipar Amerikako mendialdeko ordua (Dawson Creek)',
        'America/Denver' => 'Ipar Amerikako mendialdeko ordua (Denver)',
        'America/Detroit' => 'Ipar Amerikako ekialdeko ordua (Detroit)',
        'America/Dominica' => 'Ipar Amerikako Atlantikoko ordua (Dominika)',
        'America/Edmonton' => 'Ipar Amerikako mendialdeko ordua (Edmonton)',
        'America/Eirunepe' => 'Acreko ordua (Eirunepé)',
        'America/El_Salvador' => 'Ipar Amerikako erdialdeko ordua (El Salvador)',
        'America/Fort_Nelson' => 'Ipar Amerikako mendialdeko ordua (Fort Nelson)',
        'America/Fortaleza' => 'Brasiliako ordua (Fortaleza)',
        'America/Glace_Bay' => 'Ipar Amerikako Atlantikoko ordua (Glace Bay)',
        'America/Godthab' => 'Groenlandiako mendebaldeko ordua (Nuuk)',
        'America/Goose_Bay' => 'Ipar Amerikako Atlantikoko ordua (Goose Bay)',
        'America/Grand_Turk' => 'Ipar Amerikako ekialdeko ordua (Grand Turk)',
        'America/Grenada' => 'Ipar Amerikako Atlantikoko ordua (Grenada)',
        'America/Guadeloupe' => 'Ipar Amerikako Atlantikoko ordua (Guadalupe)',
        'America/Guatemala' => 'Ipar Amerikako erdialdeko ordua (Guatemala)',
        'America/Guayaquil' => 'Ekuadorreko ordua (Guayaquil)',
        'America/Guyana' => 'Guyanako ordua',
        'America/Halifax' => 'Ipar Amerikako Atlantikoko ordua (Halifax)',
        'America/Havana' => 'Kubako ordua (Habana)',
        'America/Hermosillo' => 'Mexikoko Pazifikoko ordua (Hermosillo)',
        'America/Indiana/Knox' => 'Ipar Amerikako erdialdeko ordua (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Ipar Amerikako ekialdeko ordua (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ipar Amerikako ekialdeko ordua (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ipar Amerikako erdialdeko ordua (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Ipar Amerikako ekialdeko ordua (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Ipar Amerikako ekialdeko ordua (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Ipar Amerikako ekialdeko ordua (Winamac, Indiana)',
        'America/Indianapolis' => 'Ipar Amerikako ekialdeko ordua (Indianapolis)',
        'America/Inuvik' => 'Ipar Amerikako mendialdeko ordua (Inuvik)',
        'America/Iqaluit' => 'Ipar Amerikako ekialdeko ordua (Iqaluit)',
        'America/Jamaica' => 'Ipar Amerikako ekialdeko ordua (Jamaika)',
        'America/Jujuy' => 'Argentinako ordua (Jujuy)',
        'America/Juneau' => 'Alaskako ordua (Juneau)',
        'America/Kentucky/Monticello' => 'Ipar Amerikako ekialdeko ordua (Monticello, Kentucky)',
        'America/Kralendijk' => 'Ipar Amerikako Atlantikoko ordua (Kralendijk)',
        'America/La_Paz' => 'Boliviako ordua (La Paz)',
        'America/Lima' => 'Peruko ordua (Lima)',
        'America/Los_Angeles' => 'Ipar Amerikako Pazifikoko ordua (Los Angeles)',
        'America/Louisville' => 'Ipar Amerikako ekialdeko ordua (Louisville)',
        'America/Lower_Princes' => 'Ipar Amerikako Atlantikoko ordua (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasiliako ordua (Maceió)',
        'America/Managua' => 'Ipar Amerikako erdialdeko ordua (Managua)',
        'America/Manaus' => 'Amazoniako ordua (Manaus)',
        'America/Marigot' => 'Ipar Amerikako Atlantikoko ordua (Marigot)',
        'America/Martinique' => 'Ipar Amerikako Atlantikoko ordua (Martinika)',
        'America/Matamoros' => 'Ipar Amerikako erdialdeko ordua (Matamoros)',
        'America/Mazatlan' => 'Mexikoko Pazifikoko ordua (Mazatlán)',
        'America/Mendoza' => 'Argentinako ordua (Mendoza)',
        'America/Menominee' => 'Ipar Amerikako erdialdeko ordua (Menominee)',
        'America/Merida' => 'Ipar Amerikako erdialdeko ordua (Mérida)',
        'America/Metlakatla' => 'Alaskako ordua (Metlakatla)',
        'America/Mexico_City' => 'Ipar Amerikako erdialdeko ordua (Mexiko Hiria)',
        'America/Miquelon' => 'Saint-Pierre eta Mikeluneko ordua',
        'America/Moncton' => 'Ipar Amerikako Atlantikoko ordua (Moncton)',
        'America/Monterrey' => 'Ipar Amerikako erdialdeko ordua (Monterrey)',
        'America/Montevideo' => 'Uruguaiko ordua (Montevideo)',
        'America/Montreal' => 'Kanada aldeko ordua (Montreal)',
        'America/Montserrat' => 'Ipar Amerikako Atlantikoko ordua (Montserrat)',
        'America/Nassau' => 'Ipar Amerikako ekialdeko ordua (Nassau)',
        'America/New_York' => 'Ipar Amerikako ekialdeko ordua (New York)',
        'America/Nipigon' => 'Ipar Amerikako ekialdeko ordua (Nipigon)',
        'America/Nome' => 'Alaskako ordua (Nome)',
        'America/Noronha' => 'Fernando de Noronhako ordua',
        'America/North_Dakota/Beulah' => 'Ipar Amerikako erdialdeko ordua (Beulah, Ipar Dakota)',
        'America/North_Dakota/Center' => 'Ipar Amerikako erdialdeko ordua (Center, Ipar Dakota)',
        'America/North_Dakota/New_Salem' => 'Ipar Amerikako erdialdeko ordua (New Salem, Ipar Dakota)',
        'America/Ojinaga' => 'Ipar Amerikako mendialdeko ordua (Ojinaga)',
        'America/Panama' => 'Ipar Amerikako ekialdeko ordua (Panama)',
        'America/Pangnirtung' => 'Ipar Amerikako ekialdeko ordua (Pangnirtung)',
        'America/Paramaribo' => 'Surinamgo ordua (Paramaribo)',
        'America/Phoenix' => 'Ipar Amerikako mendialdeko ordua (Phoenix)',
        'America/Port-au-Prince' => 'Ipar Amerikako ekialdeko ordua (Port-au-Prince)',
        'America/Port_of_Spain' => 'Ipar Amerikako Atlantikoko ordua (Port-of-Spain)',
        'America/Porto_Velho' => 'Amazoniako ordua (Porto Velho)',
        'America/Puerto_Rico' => 'Ipar Amerikako Atlantikoko ordua (Puerto Rico)',
        'America/Punta_Arenas' => 'Txileko ordua (Punta Arenas)',
        'America/Rainy_River' => 'Ipar Amerikako erdialdeko ordua (Rainy River)',
        'America/Rankin_Inlet' => 'Ipar Amerikako erdialdeko ordua (Rankin Inlet)',
        'America/Recife' => 'Brasiliako ordua (Recife)',
        'America/Regina' => 'Ipar Amerikako erdialdeko ordua (Regina)',
        'America/Resolute' => 'Ipar Amerikako erdialdeko ordua (Resolute)',
        'America/Rio_Branco' => 'Acreko ordua (Rio Branco)',
        'America/Santa_Isabel' => 'Mexikoko ipar-ekialdeko ordua (Santa Isabel)',
        'America/Santarem' => 'Brasiliako ordua (Santarém)',
        'America/Santiago' => 'Txileko ordua (Santiago)',
        'America/Santo_Domingo' => 'Ipar Amerikako Atlantikoko ordua (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasiliako ordua (São Paulo)',
        'America/Scoresbysund' => 'Groenlandiako ekialdeko ordua (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaskako ordua (Sitka)',
        'America/St_Barthelemy' => 'Ipar Amerikako Atlantikoko ordua (Saint-Barthélemy)',
        'America/St_Johns' => 'Ternuako ordua (Saint John’s)',
        'America/St_Kitts' => 'Ipar Amerikako Atlantikoko ordua (Saint Kitts)',
        'America/St_Lucia' => 'Ipar Amerikako Atlantikoko ordua (Santa Luzia)',
        'America/St_Thomas' => 'Ipar Amerikako Atlantikoko ordua (Saint-Thomas)',
        'America/St_Vincent' => 'Ipar Amerikako Atlantikoko ordua (Saint Vincent)',
        'America/Swift_Current' => 'Ipar Amerikako erdialdeko ordua (Swift Current)',
        'America/Tegucigalpa' => 'Ipar Amerikako erdialdeko ordua (Tegucigalpa)',
        'America/Thule' => 'Ipar Amerikako Atlantikoko ordua (Qaanaac)',
        'America/Thunder_Bay' => 'Ipar Amerikako ekialdeko ordua (Thunder Bay)',
        'America/Tijuana' => 'Ipar Amerikako Pazifikoko ordua (Tijuana)',
        'America/Toronto' => 'Ipar Amerikako ekialdeko ordua (Toronto)',
        'America/Tortola' => 'Ipar Amerikako Atlantikoko ordua (Tortola)',
        'America/Vancouver' => 'Ipar Amerikako Pazifikoko ordua (Vancouver)',
        'America/Whitehorse' => 'Yukongo ordua (Whitehorse)',
        'America/Winnipeg' => 'Ipar Amerikako erdialdeko ordua (Winnipeg)',
        'America/Yakutat' => 'Alaskako ordua (Yakutat)',
        'America/Yellowknife' => 'Ipar Amerikako mendialdeko ordua (Yellowknife)',
        'Antarctica/Casey' => 'Caseyko ordua',
        'Antarctica/Davis' => 'Daviseko ordua',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urvilleko ordua',
        'Antarctica/Macquarie' => 'Australiako ekialdeko ordua (Macquarie)',
        'Antarctica/Mawson' => 'Mawsoneko ordua',
        'Antarctica/McMurdo' => 'Zeelanda Berriko ordua (McMurdo)',
        'Antarctica/Palmer' => 'Txileko ordua (Palmer)',
        'Antarctica/Rothera' => 'Rotherako ordua',
        'Antarctica/Syowa' => 'Syowako ordua',
        'Antarctica/Troll' => 'Greenwichko meridianoaren ordua (Troll)',
        'Antarctica/Vostok' => 'Vostokeko ordua',
        'Arctic/Longyearbyen' => 'Europako erdialdeko ordua (Longyearbyen)',
        'Asia/Aden' => 'Arabiako ordua (Aden)',
        'Asia/Almaty' => 'Kazakhstango ekialdeko ordua (Almaty)',
        'Asia/Amman' => 'Europako ekialdeko ordua (Amman)',
        'Asia/Anadyr' => 'Anadyrreko ordua',
        'Asia/Aqtau' => 'Kazakhstango mendebaldeko ordua (Aktau)',
        'Asia/Aqtobe' => 'Kazakhstango mendebaldeko ordua (Aktobe)',
        'Asia/Ashgabat' => 'Turkmenistango ordua (Asgabat)',
        'Asia/Atyrau' => 'Kazakhstango mendebaldeko ordua (Atyrau)',
        'Asia/Baghdad' => 'Arabiako ordua (Bagdad)',
        'Asia/Bahrain' => 'Arabiako ordua (Bahrain)',
        'Asia/Baku' => 'Azerbaijango ordua (Baku)',
        'Asia/Bangkok' => 'Indotxinako ordua (Bangkok)',
        'Asia/Barnaul' => 'Errusia aldeko ordua (Barnaul)',
        'Asia/Beirut' => 'Europako ekialdeko ordua (Beirut)',
        'Asia/Bishkek' => 'Kirgizistango ordua (Bixkek)',
        'Asia/Brunei' => 'Brunei Darussalamgo ordua',
        'Asia/Calcutta' => 'Indiako ordua (Kalkuta)',
        'Asia/Chita' => 'Jakutskeko ordua (Chita)',
        'Asia/Choibalsan' => 'Ulan Batorreko ordua (Txoibalsan)',
        'Asia/Colombo' => 'Indiako ordua (Kolombo)',
        'Asia/Damascus' => 'Europako ekialdeko ordua (Damasko)',
        'Asia/Dhaka' => 'Bangladesheko ordua (Dhaka)',
        'Asia/Dili' => 'Ekialdeko Timorreko ordua (Dili)',
        'Asia/Dubai' => 'Golkoko ordu estandarra (Dubai)',
        'Asia/Dushanbe' => 'Tadjikistango ordua (Duxanbe)',
        'Asia/Famagusta' => 'Europako ekialdeko ordua (Famagusta)',
        'Asia/Gaza' => 'Europako ekialdeko ordua (Gaza)',
        'Asia/Hebron' => 'Europako ekialdeko ordua (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kongo ordua',
        'Asia/Hovd' => 'Khovdeko ordua',
        'Asia/Irkutsk' => 'Irkutskeko ordua',
        'Asia/Jakarta' => 'Indonesiako mendebaldeko ordua (Jakarta)',
        'Asia/Jayapura' => 'Indonesiako ekialdeko ordua (Jayapura)',
        'Asia/Jerusalem' => 'Israelgo ordua (Jerusalem)',
        'Asia/Kabul' => 'Afganistango ordua (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamchatskiko ordua (Kamtxatka)',
        'Asia/Karachi' => 'Pakistango ordua (Karatxi)',
        'Asia/Katmandu' => 'Nepalgo ordua (Katmandu)',
        'Asia/Khandyga' => 'Jakutskeko ordua (Khandiga)',
        'Asia/Krasnoyarsk' => 'Krasnoiarskeko ordua',
        'Asia/Kuala_Lumpur' => 'Malaysiako ordua (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaysiako ordua (Kuching)',
        'Asia/Kuwait' => 'Arabiako ordua (Kuwait)',
        'Asia/Macau' => 'Txinako ordua (Macau)',
        'Asia/Magadan' => 'Magadango ordua',
        'Asia/Makassar' => 'Indonesiako erdialdeko ordua (Makassar)',
        'Asia/Manila' => 'Filipinetako ordua (Manila)',
        'Asia/Muscat' => 'Golkoko ordu estandarra (Maskat)',
        'Asia/Nicosia' => 'Europako ekialdeko ordua (Nikosia)',
        'Asia/Novokuznetsk' => 'Krasnoiarskeko ordua (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Novosibirskeko ordua',
        'Asia/Omsk' => 'Omskeko ordua',
        'Asia/Oral' => 'Kazakhstango mendebaldeko ordua (Oral)',
        'Asia/Phnom_Penh' => 'Indotxinako ordua (Phnom Penh)',
        'Asia/Pontianak' => 'Indonesiako mendebaldeko ordua (Pontianak)',
        'Asia/Pyongyang' => 'Koreako ordua (Piongiang)',
        'Asia/Qatar' => 'Arabiako ordua (Qatar)',
        'Asia/Qostanay' => 'Kazakhstango ekialdeko ordua (Kostanay)',
        'Asia/Qyzylorda' => 'Kazakhstango mendebaldeko ordua (Kyzylorda)',
        'Asia/Rangoon' => 'Myanmarreko ordua (Yangon)',
        'Asia/Riyadh' => 'Arabiako ordua (Riad)',
        'Asia/Saigon' => 'Indotxinako ordua (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Sakhalingo ordua',
        'Asia/Samarkand' => 'Uzbekistango ordua (Samarkanda)',
        'Asia/Seoul' => 'Koreako ordua (Seul)',
        'Asia/Shanghai' => 'Txinako ordua (Shanghai)',
        'Asia/Singapore' => 'Singapurreko ordu estandarra',
        'Asia/Srednekolymsk' => 'Magadango ordua (Srednekolimsk)',
        'Asia/Taipei' => 'Taipeiko ordua',
        'Asia/Tashkent' => 'Uzbekistango ordua (Taxkent)',
        'Asia/Tbilisi' => 'Georgiako ordua (Tbilisi)',
        'Asia/Tehran' => 'Irango ordua (Teheran)',
        'Asia/Thimphu' => 'Bhutango ordua (Thimphu)',
        'Asia/Tokyo' => 'Japoniako ordua (Tokio)',
        'Asia/Tomsk' => 'Errusia aldeko ordua (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Batorreko ordua',
        'Asia/Urumqi' => 'Txina aldeko ordua (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostokeko ordua (Ust-Nera)',
        'Asia/Vientiane' => 'Indotxinako ordua (Vientian)',
        'Asia/Vladivostok' => 'Vladivostokeko ordua',
        'Asia/Yakutsk' => 'Jakutskeko ordua',
        'Asia/Yekaterinburg' => 'Jekaterinburgeko ordua',
        'Asia/Yerevan' => 'Armeniako ordua (Erevan)',
        'Atlantic/Azores' => 'Azoreetako ordua (Azoreak)',
        'Atlantic/Bermuda' => 'Ipar Amerikako Atlantikoko ordua (Bermuda)',
        'Atlantic/Canary' => 'Europako mendebaldeko ordua (Kanariak)',
        'Atlantic/Cape_Verde' => 'Cabo Verdeko ordua',
        'Atlantic/Faeroe' => 'Europako mendebaldeko ordua (Faroe)',
        'Atlantic/Madeira' => 'Europako mendebaldeko ordua (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwichko meridianoaren ordua (Reykjavik)',
        'Atlantic/South_Georgia' => 'Hegoaldeko Georgietako ordua (South Georgia)',
        'Atlantic/St_Helena' => 'Greenwichko meridianoaren ordua (Santa Helena)',
        'Atlantic/Stanley' => 'Falkland uharteetako ordua (Stanley)',
        'Australia/Adelaide' => 'Australiako erdialdeko ordua (Adelaide)',
        'Australia/Brisbane' => 'Australiako ekialdeko ordua (Brisbane)',
        'Australia/Broken_Hill' => 'Australiako erdialdeko ordua (Broken Hill)',
        'Australia/Currie' => 'Australiako ekialdeko ordua (Currie)',
        'Australia/Darwin' => 'Australiako erdialdeko ordua (Darwin)',
        'Australia/Eucla' => 'Australiako erdi-mendebaldeko ordua (Eucla)',
        'Australia/Hobart' => 'Australiako ekialdeko ordua (Hobart)',
        'Australia/Lindeman' => 'Australiako ekialdeko ordua (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howeko ordua',
        'Australia/Melbourne' => 'Australiako ekialdeko ordua (Melbourne)',
        'Australia/Perth' => 'Australiako mendebaldeko ordua (Perth)',
        'Australia/Sydney' => 'Australiako ekialdeko ordua (Sydney)',
        'CST6CDT' => 'Ipar Amerikako erdialdeko ordua',
        'EST5EDT' => 'Ipar Amerikako ekialdeko ordua',
        'Etc/GMT' => 'Greenwichko meridianoaren ordua',
        'Etc/UTC' => 'ordu unibertsal koordinatua',
        'Europe/Amsterdam' => 'Europako erdialdeko ordua (Amsterdam)',
        'Europe/Andorra' => 'Europako erdialdeko ordua (Andorra)',
        'Europe/Astrakhan' => 'Moskuko ordua (Astrakhan)',
        'Europe/Athens' => 'Europako ekialdeko ordua (Atenas)',
        'Europe/Belgrade' => 'Europako erdialdeko ordua (Belgrad)',
        'Europe/Berlin' => 'Europako erdialdeko ordua (Berlin)',
        'Europe/Bratislava' => 'Europako erdialdeko ordua (Bratislava)',
        'Europe/Brussels' => 'Europako erdialdeko ordua (Brusela)',
        'Europe/Bucharest' => 'Europako ekialdeko ordua (Bukarest)',
        'Europe/Budapest' => 'Europako erdialdeko ordua (Budapest)',
        'Europe/Busingen' => 'Europako erdialdeko ordua (Büsingen)',
        'Europe/Chisinau' => 'Europako ekialdeko ordua (Chisinau)',
        'Europe/Copenhagen' => 'Europako erdialdeko ordua (Kopenhage)',
        'Europe/Dublin' => 'Greenwichko meridianoaren ordua (Dublin)',
        'Europe/Gibraltar' => 'Europako erdialdeko ordua (Gibraltar)',
        'Europe/Guernsey' => 'Greenwichko meridianoaren ordua (Guernesey)',
        'Europe/Helsinki' => 'Europako ekialdeko ordua (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwichko meridianoaren ordua (Man uhartea)',
        'Europe/Istanbul' => 'Turkia aldeko ordua (Istanbul)',
        'Europe/Jersey' => 'Greenwichko meridianoaren ordua (Jersey)',
        'Europe/Kaliningrad' => 'Europako ekialdeko ordua (Kaliningrad)',
        'Europe/Kiev' => 'Europako ekialdeko ordua (Kiev)',
        'Europe/Kirov' => 'Errusia aldeko ordua (Kirov)',
        'Europe/Lisbon' => 'Europako mendebaldeko ordua (Lisboa)',
        'Europe/Ljubljana' => 'Europako erdialdeko ordua (Ljubljana)',
        'Europe/London' => 'Greenwichko meridianoaren ordua (Londres)',
        'Europe/Luxembourg' => 'Europako erdialdeko ordua (Luxenburgo)',
        'Europe/Madrid' => 'Europako erdialdeko ordua (Madril)',
        'Europe/Malta' => 'Europako erdialdeko ordua (Malta)',
        'Europe/Mariehamn' => 'Europako ekialdeko ordua (Mariehamn)',
        'Europe/Minsk' => 'Moskuko ordua (Minsk)',
        'Europe/Monaco' => 'Europako erdialdeko ordua (Monako)',
        'Europe/Moscow' => 'Moskuko ordua',
        'Europe/Oslo' => 'Europako erdialdeko ordua (Oslo)',
        'Europe/Paris' => 'Europako erdialdeko ordua (Paris)',
        'Europe/Podgorica' => 'Europako erdialdeko ordua (Podgorica)',
        'Europe/Prague' => 'Europako erdialdeko ordua (Praga)',
        'Europe/Riga' => 'Europako ekialdeko ordua (Riga)',
        'Europe/Rome' => 'Europako erdialdeko ordua (Erroma)',
        'Europe/Samara' => 'Samarako ordua',
        'Europe/San_Marino' => 'Europako erdialdeko ordua (San Marino)',
        'Europe/Sarajevo' => 'Europako erdialdeko ordua (Sarajevo)',
        'Europe/Saratov' => 'Moskuko ordua (Saratov)',
        'Europe/Simferopol' => 'Moskuko ordua (Simferopol)',
        'Europe/Skopje' => 'Europako erdialdeko ordua (Skopje)',
        'Europe/Sofia' => 'Europako ekialdeko ordua (Sofia)',
        'Europe/Stockholm' => 'Europako erdialdeko ordua (Stockholm)',
        'Europe/Tallinn' => 'Europako ekialdeko ordua (Tallinn)',
        'Europe/Tirane' => 'Europako erdialdeko ordua (Tirana)',
        'Europe/Ulyanovsk' => 'Moskuko ordua (Ulianovsk)',
        'Europe/Uzhgorod' => 'Europako ekialdeko ordua (Uzhhorod)',
        'Europe/Vaduz' => 'Europako erdialdeko ordua (Vaduz)',
        'Europe/Vatican' => 'Europako erdialdeko ordua (Vatikano Hiria)',
        'Europe/Vienna' => 'Europako erdialdeko ordua (Viena)',
        'Europe/Vilnius' => 'Europako ekialdeko ordua (Vilnius)',
        'Europe/Volgograd' => 'Volgogradeko ordua',
        'Europe/Warsaw' => 'Europako erdialdeko ordua (Varsovia)',
        'Europe/Zagreb' => 'Europako erdialdeko ordua (Zagreb)',
        'Europe/Zaporozhye' => 'Europako ekialdeko ordua (Zaporozhye)',
        'Europe/Zurich' => 'Europako erdialdeko ordua (Zürich)',
        'Indian/Antananarivo' => 'Afrikako ekialdeko ordua (Antananarivo)',
        'Indian/Chagos' => 'Indiako Ozeanoko ordua (Chagos)',
        'Indian/Christmas' => 'Christmas uharteko ordua',
        'Indian/Cocos' => 'Cocos uharteetako ordua',
        'Indian/Comoro' => 'Afrikako ekialdeko ordua (Comoro)',
        'Indian/Kerguelen' => 'Frantziaren lurralde austral eta antartikoetako ordutegia (Kerguelen)',
        'Indian/Mahe' => 'Seychelle uharteetako ordua (Mahé)',
        'Indian/Maldives' => 'Maldivetako ordua (Maldivak)',
        'Indian/Mauritius' => 'Maurizioko ordua',
        'Indian/Mayotte' => 'Afrikako ekialdeko ordua (Mayotte)',
        'Indian/Reunion' => 'Reunioneko ordua',
        'MST7MDT' => 'Ipar Amerikako mendialdeko ordua',
        'PST8PDT' => 'Ipar Amerikako Pazifikoko ordua',
        'Pacific/Apia' => 'Apiako ordua',
        'Pacific/Auckland' => 'Zeelanda Berriko ordua (Auckland)',
        'Pacific/Bougainville' => 'Papua Ginea Berriko ordua (Bougainville)',
        'Pacific/Chatham' => 'Chathamgo ordua',
        'Pacific/Easter' => 'Pazko uharteko ordua (Pazko uhartea)',
        'Pacific/Efate' => 'Vanuatuko ordua (Éfaté)',
        'Pacific/Enderbury' => 'Phoenix uharteetako ordua (Enderbury)',
        'Pacific/Fakaofo' => 'Tokelauko ordua (Fakaofo)',
        'Pacific/Fiji' => 'Fijiko ordua',
        'Pacific/Funafuti' => 'Tuvaluko ordua (Funafuti)',
        'Pacific/Galapagos' => 'Galapagoetako ordua (Galapagoak)',
        'Pacific/Gambier' => 'Gambierretako ordua',
        'Pacific/Guadalcanal' => 'Salomon Uharteetako ordua (Guadalcanal)',
        'Pacific/Guam' => 'Chamorroko ordu estandarra (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleutiar uharteetako ordua (Honolulu)',
        'Pacific/Johnston' => 'Hawaii-Aleutiar uharteetako ordua (Johnston)',
        'Pacific/Kiritimati' => 'Line uharteetako ordua (Kiritimati)',
        'Pacific/Kosrae' => 'Kosraeko ordua',
        'Pacific/Kwajalein' => 'Marshall Uharteetako ordua (Kwajalein)',
        'Pacific/Majuro' => 'Marshall Uharteetako ordua (Majuro)',
        'Pacific/Marquesas' => 'Markesetako ordua (Markesak)',
        'Pacific/Midway' => 'Samoako ordua (Midway)',
        'Pacific/Nauru' => 'Nauruko ordua',
        'Pacific/Niue' => 'Niueko ordua',
        'Pacific/Norfolk' => 'Norfolk uharteetako ordua',
        'Pacific/Noumea' => 'Kaledonia Berriko ordua (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoako ordua (Pago Pago)',
        'Pacific/Palau' => 'Palauko ordua',
        'Pacific/Pitcairn' => 'Pitcairneko ordua',
        'Pacific/Ponape' => 'Ponapeko ordua (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua Ginea Berriko ordua (Port Moresby)',
        'Pacific/Rarotonga' => 'Cook uharteetako ordua (Rarotonga)',
        'Pacific/Saipan' => 'Chamorroko ordu estandarra (Saipan)',
        'Pacific/Tahiti' => 'Tahitiko ordua',
        'Pacific/Tarawa' => 'Gilbert uharteetako ordua (Tarawa)',
        'Pacific/Tongatapu' => 'Tongako ordua (Tongatapu)',
        'Pacific/Truk' => 'Chuukeko ordua',
        'Pacific/Wake' => 'Wake uharteko ordua',
        'Pacific/Wallis' => 'Wallis eta Futunako ordutegia',
    ],
    'Meta' => [
    ],
];
