<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirihamɛ ya Lémila alabo',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza ya Angóla',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dolarɛ ya Ositali',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinarɛ ya Bahrɛnɛ',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Falánga ya Burundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula ya Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dolarɛ ya Kanadá',
        ],
        'CDF' => [
            0 => 'FC',
            1 => 'Falánga ya Kongó',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Falánga ya Swisɛ',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuanɛ Renminbi ya Sinɛ',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Esikudo ya Kapevɛrɛ',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Falánga ya Dzibuti',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinarɛ ya Alizeri',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Paunɛ ya Ezípitɛ',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa ya Elitlɛ',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birɛ ya Etsiópi',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Ɛlɔ́',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Paunɛ ya Angɛlɛtɛ́lɛ',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi ya Gana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi ya Gambi',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Falánga ya Ginɛ',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupi ya Índɛ',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni ya Zapɔ',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shilingɛ ya Kenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Falánga ya Komoro',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dolarɛ ya Liberya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ya Lesóto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinarɛ ya Libí',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirihame ya Marokɛ',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Falánga ya Madagasikarɛ',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya ya Moritani (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya ya Moritani',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupi ya Morisi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwasha ya Malawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikali ya Mozambiki',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dolarɛ ya Namibi',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira ya Nizerya',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Falánga ya Rwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyalɛ ya Alabi Sawuditɛ',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupi ya Sɛshɛlɛ',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Dinarɛ ya Sudá',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Paunɛ ya Sudá',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Paunɛ ya Sántu elena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leonɛ',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shilingɛ ya Somali',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra ya Sao Tomé mpé Presipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra ya Sao Tomé mpé Presipe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinarɛ ya Tinizi',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shilingɛ ya Tanzani',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilingɛ ya Uganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dolarɛ ya Ameriki',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Falánga CFA BEAC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Falánga CFA BCEAO',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randɛ ya Afríka Súdi',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwasha ya Zambi (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwasha ya Zambi',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dolarɛ ya Zimbabwɛ',
        ],
    ],
];
