<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'peseta andorska',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham ZEA',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afgani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afgani afgańskie',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albański',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'dram armeński',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'gulden antylski',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolska',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'kwanza angolańska (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'nowa kwanza angolańska (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'kwanza angolańska Reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'austral argentyński',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'peso argentyńskie (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'peso argentyńskie',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'szyling austriacki',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'dolar australijski',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'florin arubański',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'manat azerbejdżański',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat azerski',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'dinar Bośni i Hercegowiny',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'marka zamienna Bośni i Hercegowiny',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dolar barbadoski',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'taka bengalska',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'frank belgijski (zamienny)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'frank belgijski',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'frank belgijski (finansowy)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'lew bułgarski wymienny',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'lew bułgarski socjalistyczny',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lew bułgarski',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'lew bułgarski (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinar bahrański',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'frank burundyjski',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dolar bermudzki',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'dolar brunejski',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviano boliwijskie',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'peso boliwijskie',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'mvdol boliwijski',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'cruzeiro novo brazylijskie (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'cruzado brazylijskie',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'cruzeiro brazylijskie (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'real brazylijski',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'nowe cruzado brazylijskie',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'cruzeiro brazylijskie',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dolar bahamski',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ngultrum bhutański',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'kyat birmański',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula botswańska',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'rubel białoruski (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rubel białoruski',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'rubel białoruski (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dolar belizeński',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'dolar kanadyjski',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'frank kongijski',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'frank szwajcarski',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso chilijskie',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'juan chiński (rynek zewnętrzny)',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'juan chiński',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso kolumbijskie',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colon kostarykański',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'stary dinar serbski',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'korona czechosłowacka',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso kubańskie wymienialne',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso kubańskie',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo zielonoprzylądkowe',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'funt cypryjski',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'korona czeska',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'wschodnia marka wschodnioniemiecka',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'marka niemiecka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'frank dżibutyjski',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'korona duńska',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominikańskie',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinar algierski',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'sucre ekwadorski',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'korona estońska',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'funt egipski',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nakfa erytrejska',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'peseta hiszpańska (Konto A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'peseta hiszpańska (konto wymienne)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'peseta hiszpańska',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr etiopski',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'marka fińska',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dolar fidżyjski',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'funt falklandzki',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'frank francuski',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'funt szterling',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'kupon gruziński larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'lari gruzińskie',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'cedi ghańskie (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cedi ghańskie',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'funt gibraltarski',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambijskie',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'frank gwinejski',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'syli gwinejskie',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekwele gwinejskie Gwinei Równikowej',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'drachma grecka',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal gwatemalski',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'escudo Gwinea Portugalska',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'peso Guinea-Bissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dolar gujański',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'dolar hongkoński',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira honduraska',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'dinar chorwacki',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna chorwacka',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haitański',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'forint węgierski',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'rupia indonezyjska',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'funt irlandzki',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'funt izraelski',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'nowy szekel izraelski',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'rupia indyjska',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'dinar iracki',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'rial irański',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'korona islandzka',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'lir włoski',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dolar jamajski',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'dinar jordański',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'jen japoński',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'szyling kenijski',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'som kirgiski',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'riel kambodżański',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'frank komoryjski',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'won północnokoreański',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'won południowokoreański',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'dinar kuwejcki',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dolar kajmański',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'tenge kazachskie',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip laotański',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'funt libański',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'rupia lankijska',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dolar liberyjski',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti lesotyjskie',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'lit litewski',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'talon litewski',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'frank luksemburski',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'łat łotewski',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'rubel łotewski',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinar libijski',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marokański',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'frank marokański',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'lej mołdawski',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary malgaski',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'frank malgaski',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'denar macedoński',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'frank malijski',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'kiat birmański',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'tugrik mongolski',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'pataca Makau',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ouguiya mauretańska (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ugija mauretańska',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'lira maltańska',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'funt maltański',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupia maurytyjska',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'rupia malediwska',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha malawijska',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'peso meksykańskie',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'peso srebrne meksykańskie (1861–1992)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'ringgit malezyjski',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'escudo mozambickie',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'metical Mozambik',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical mozambicki',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dolar namibijski',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nigeryjska',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'cordoba nikaraguańska (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'cordoba nikaraguańska',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'gulden holenderski',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'korona norweska',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'rupia nepalska',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'dolar nowozelandzki',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'rial omański',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa panamski',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'inti peruwiański',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol peruwiański',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'sol peruwiański (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina papuańska',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'peso filipińskie',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'rupia pakistańska',
        ],
        'PLN' => [
            0 => 'zł',
            1 => 'złoty polski',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'złoty polski (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'escudo portugalskie',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guarani paragwajskie',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'rial katarski',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'dolar rodezyjski',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'lej rumuński (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'lej rumuński',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinar serbski',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rubel rosyjski',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'rubel rosyjski (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'frank ruandyjski',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'rial saudyjski',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dolar Wysp Salomona',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupia seszelska',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'dinar sudański',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'funt sudański',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'funt sudański (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'korona szwedzka',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'dolar singapurski',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'funt Świętej Heleny',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'tolar słoweński',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'korona słowacka',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone sierraleoński',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'szyling somalijski',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dolar surinamski',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'gulden surinamski',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'funt południowosudański',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra Wysp Świętego Tomasza i Książęcej (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra Wysp Świętego Tomasza i Książęcej',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'rubel radziecki',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'colon salwadorski',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'funt syryjski',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni Suazi',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'baht tajski',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'rubel tadżycki',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'somoni tadżyckie',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'manat turkmeński (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'manat turkmeński',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinar tunezyjski',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'pa’anga tongijska',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'escudo timorskie',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'lira turecka (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'lira turecka',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dolar trynidadzki',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'nowy dolar tajwański',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'szyling tanzański',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'hrywna ukraińska',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'karbowaniec ukraiński',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'szyling ugandyjski (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'szyling ugandyjski',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'dolar amerykański',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'peso urugwajskie (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso urugwajskie',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'som uzbecki',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'boliwar wenezuelski (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'boliwar wenezuelski (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'boliwar wenezuelski',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'dong wietnamski',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu wanuackie',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala samoańskie',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'frank CFA BEAC',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'dolar wschodniokaraibski',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'ECU',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'frank złoty francuski',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'UIC-frank francuski',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'frank CFA',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'frank CFP',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'dinar jemeński',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'rial jemeński',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'nowy dinar jugosławiański',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'dinar jugosławiański wymienny',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'rand południowoafrykański (finansowy)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand południowoafrykański',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'kwacha zambijska (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha zambijska',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'nowy zair zairski',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zair zairski',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'dolar Zimbabwe (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'dolar Zimbabwe (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'dolar Zimbabwe (2008)',
        ],
    ],
];
