<?php

return [
    'Names' => [
        'ar_001' => 'Arabic (World)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (Bangladesh)',
        'bn_IN' => 'Bengali (India)',
        'en_001' => 'English (World)',
        'eo_001' => 'Esperanto (World)',
        'ia_001' => 'Interlingua (World)',
        'yi_001' => 'Yiddish (World)',
    ],
];
