<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Ora del meridiano di Greenwich (Abidjan)',
        'Africa/Accra' => 'Ora del meridiano di Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Ora dell’Africa orientale (Addis Abeba)',
        'Africa/Algiers' => 'Ora dell’Europa centrale (Algeri)',
        'Africa/Asmera' => 'Ora dell’Africa orientale (Asmara)',
        'Africa/Bamako' => 'Ora del meridiano di Greenwich (Bamako)',
        'Africa/Bangui' => 'Ora dell’Africa occidentale (Bangui)',
        'Africa/Banjul' => 'Ora del meridiano di Greenwich (Banjul)',
        'Africa/Bissau' => 'Ora del meridiano di Greenwich (Bissau)',
        'Africa/Blantyre' => 'Ora dell’Africa centrale (Blantyre)',
        'Africa/Brazzaville' => 'Ora dell’Africa occidentale (Brazzaville)',
        'Africa/Bujumbura' => 'Ora dell’Africa centrale (Bujumbura)',
        'Africa/Cairo' => 'Ora dell’Europa orientale (Il Cairo)',
        'Africa/Casablanca' => 'Ora dell’Europa occidentale (Casablanca)',
        'Africa/Ceuta' => 'Ora dell’Europa centrale (Ceuta)',
        'Africa/Conakry' => 'Ora del meridiano di Greenwich (Conakry)',
        'Africa/Dakar' => 'Ora del meridiano di Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ora dell’Africa orientale (Dar es Salaam)',
        'Africa/Djibouti' => 'Ora dell’Africa orientale (Gibuti)',
        'Africa/Douala' => 'Ora dell’Africa occidentale (Douala)',
        'Africa/El_Aaiun' => 'Ora dell’Europa occidentale (El Ayun)',
        'Africa/Freetown' => 'Ora del meridiano di Greenwich (Freetown)',
        'Africa/Gaborone' => 'Ora dell’Africa centrale (Gaborone)',
        'Africa/Harare' => 'Ora dell’Africa centrale (Harare)',
        'Africa/Johannesburg' => 'Ora dell’Africa meridionale (Johannesburg)',
        'Africa/Juba' => 'Ora dell’Africa centrale (Giuba)',
        'Africa/Kampala' => 'Ora dell’Africa orientale (Kampala)',
        'Africa/Khartoum' => 'Ora dell’Africa centrale (Khartum)',
        'Africa/Kigali' => 'Ora dell’Africa centrale (Kigali)',
        'Africa/Kinshasa' => 'Ora dell’Africa occidentale (Kinshasa)',
        'Africa/Lagos' => 'Ora dell’Africa occidentale (Lagos)',
        'Africa/Libreville' => 'Ora dell’Africa occidentale (Libreville)',
        'Africa/Lome' => 'Ora del meridiano di Greenwich (Lomé)',
        'Africa/Luanda' => 'Ora dell’Africa occidentale (Luanda)',
        'Africa/Lubumbashi' => 'Ora dell’Africa centrale (Lubumbashi)',
        'Africa/Lusaka' => 'Ora dell’Africa centrale (Lusaka)',
        'Africa/Malabo' => 'Ora dell’Africa occidentale (Malabo)',
        'Africa/Maputo' => 'Ora dell’Africa centrale (Maputo)',
        'Africa/Maseru' => 'Ora dell’Africa meridionale (Maseru)',
        'Africa/Mbabane' => 'Ora dell’Africa meridionale (Mbabane)',
        'Africa/Mogadishu' => 'Ora dell’Africa orientale (Mogadiscio)',
        'Africa/Monrovia' => 'Ora del meridiano di Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Ora dell’Africa orientale (Nairobi)',
        'Africa/Ndjamena' => 'Ora dell’Africa occidentale (N’Djamena)',
        'Africa/Niamey' => 'Ora dell’Africa occidentale (Niamey)',
        'Africa/Nouakchott' => 'Ora del meridiano di Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Ora del meridiano di Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Ora dell’Africa occidentale (Porto-Novo)',
        'Africa/Sao_Tome' => 'Ora del meridiano di Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Ora dell’Europa orientale (Tripoli)',
        'Africa/Tunis' => 'Ora dell’Europa centrale (Tunisi)',
        'Africa/Windhoek' => 'Ora dell’Africa centrale (Windhoek)',
        'America/Adak' => 'Ora delle isole Hawaii-Aleutine (Adak)',
        'America/Anchorage' => 'Ora dell’Alaska (Anchorage)',
        'America/Anguilla' => 'Ora dell’Atlantico (Anguilla)',
        'America/Antigua' => 'Ora dell’Atlantico (Antigua)',
        'America/Araguaina' => 'Ora di Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'Ora dell’Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Ora dell’Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Ora dell’Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Ora dell’Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Ora dell’Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Ora dell’Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Ora dell’Argentina (Ushuaia)',
        'America/Aruba' => 'Ora dell’Atlantico (Aruba)',
        'America/Asuncion' => 'Ora del Paraguay (Asunción)',
        'America/Bahia' => 'Ora di Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Ora centrale USA (Bahía de Banderas)',
        'America/Barbados' => 'Ora dell’Atlantico (Barbados)',
        'America/Belem' => 'Ora di Brasilia (Belem)',
        'America/Belize' => 'Ora centrale USA (Belize)',
        'America/Blanc-Sablon' => 'Ora dell’Atlantico (Blanc-Sablon)',
        'America/Boa_Vista' => 'Ora dell’Amazzonia (Boa Vista)',
        'America/Bogota' => 'Ora della Colombia (Bogotá)',
        'America/Boise' => 'Ora Montagne Rocciose USA (Boise)',
        'America/Buenos_Aires' => 'Ora dell’Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Ora Montagne Rocciose USA (Cambridge Bay)',
        'America/Campo_Grande' => 'Ora dell’Amazzonia (Campo Grande)',
        'America/Cancun' => 'Ora orientale USA (Cancún)',
        'America/Caracas' => 'Ora del Venezuela (Caracas)',
        'America/Catamarca' => 'Ora dell’Argentina (Catamarca)',
        'America/Cayenne' => 'Ora della Guiana francese (Caienna)',
        'America/Cayman' => 'Ora orientale USA (Cayman)',
        'America/Chicago' => 'Ora centrale USA (Chicago)',
        'America/Chihuahua' => 'Ora del Pacifico (Messico) (Chihuahua)',
        'America/Coral_Harbour' => 'Ora orientale USA (Atikokan)',
        'America/Cordoba' => 'Ora dell’Argentina (Cordoba)',
        'America/Costa_Rica' => 'Ora centrale USA (Costa Rica)',
        'America/Creston' => 'Ora Montagne Rocciose USA (Creston)',
        'America/Cuiaba' => 'Ora dell’Amazzonia (Cuiaba)',
        'America/Curacao' => 'Ora dell’Atlantico (Curaçao)',
        'America/Danmarkshavn' => 'Ora del meridiano di Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Ora dello Yukon (Dawson)',
        'America/Dawson_Creek' => 'Ora Montagne Rocciose USA (Dawson Creek)',
        'America/Denver' => 'Ora Montagne Rocciose USA (Denver)',
        'America/Detroit' => 'Ora orientale USA (Detroit)',
        'America/Dominica' => 'Ora dell’Atlantico (Dominica)',
        'America/Edmonton' => 'Ora Montagne Rocciose USA (Edmonton)',
        'America/Eirunepe' => 'Ora Brasile (Eirunepe)',
        'America/El_Salvador' => 'Ora centrale USA (El Salvador)',
        'America/Fort_Nelson' => 'Ora Montagne Rocciose USA (Fort Nelson)',
        'America/Fortaleza' => 'Ora di Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Ora dell’Atlantico (Glace Bay)',
        'America/Godthab' => 'Ora della Groenlandia occidentale (Nuuk)',
        'America/Goose_Bay' => 'Ora dell’Atlantico (Goose Bay)',
        'America/Grand_Turk' => 'Ora orientale USA (Grand Turk)',
        'America/Grenada' => 'Ora dell’Atlantico (Grenada)',
        'America/Guadeloupe' => 'Ora dell’Atlantico (Guadalupa)',
        'America/Guatemala' => 'Ora centrale USA (Guatemala)',
        'America/Guayaquil' => 'Ora dell’Ecuador (Guayaquil)',
        'America/Guyana' => 'Ora della Guyana',
        'America/Halifax' => 'Ora dell’Atlantico (Halifax)',
        'America/Havana' => 'Ora di Cuba (L’Avana)',
        'America/Hermosillo' => 'Ora del Pacifico (Messico) (Hermosillo)',
        'America/Indiana/Knox' => 'Ora centrale USA (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Ora orientale USA (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ora orientale USA (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ora centrale USA (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Ora orientale USA (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Ora orientale USA (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Ora orientale USA (Winamac, Indiana)',
        'America/Indianapolis' => 'Ora orientale USA (Indianapolis)',
        'America/Inuvik' => 'Ora Montagne Rocciose USA (Inuvik)',
        'America/Iqaluit' => 'Ora orientale USA (Iqaluit)',
        'America/Jamaica' => 'Ora orientale USA (Giamaica)',
        'America/Jujuy' => 'Ora dell’Argentina (Jujuy)',
        'America/Juneau' => 'Ora dell’Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Ora orientale USA (Monticello, Kentucky)',
        'America/Kralendijk' => 'Ora dell’Atlantico (Kralendijk)',
        'America/La_Paz' => 'Ora della Bolivia (La Paz)',
        'America/Lima' => 'Ora del Perù (Lima)',
        'America/Los_Angeles' => 'Ora del Pacifico USA (Los Angeles)',
        'America/Louisville' => 'Ora orientale USA (Louisville)',
        'America/Lower_Princes' => 'Ora dell’Atlantico (Lower Prince’s Quarter)',
        'America/Maceio' => 'Ora di Brasilia (Maceio)',
        'America/Managua' => 'Ora centrale USA (Managua)',
        'America/Manaus' => 'Ora dell’Amazzonia (Manaus)',
        'America/Marigot' => 'Ora dell’Atlantico (Marigot)',
        'America/Martinique' => 'Ora dell’Atlantico (Martinica)',
        'America/Matamoros' => 'Ora centrale USA (Matamoros)',
        'America/Mazatlan' => 'Ora del Pacifico (Messico) (Mazatlan)',
        'America/Mendoza' => 'Ora dell’Argentina (Mendoza)',
        'America/Menominee' => 'Ora centrale USA (Menominee)',
        'America/Merida' => 'Ora centrale USA (Mérida)',
        'America/Metlakatla' => 'Ora dell’Alaska (Metlakatla)',
        'America/Mexico_City' => 'Ora centrale USA (Città del Messico)',
        'America/Miquelon' => 'Ora di Saint-Pierre e Miquelon',
        'America/Moncton' => 'Ora dell’Atlantico (Moncton)',
        'America/Monterrey' => 'Ora centrale USA (Monterrey)',
        'America/Montevideo' => 'Ora dell’Uruguay (Montevideo)',
        'America/Montreal' => 'Ora Canada (Montreal)',
        'America/Montserrat' => 'Ora dell’Atlantico (Montserrat)',
        'America/Nassau' => 'Ora orientale USA (Nassau)',
        'America/New_York' => 'Ora orientale USA (New York)',
        'America/Nipigon' => 'Ora orientale USA (Nipigon)',
        'America/Nome' => 'Ora dell’Alaska (Nome)',
        'America/Noronha' => 'Ora di Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Ora centrale USA (Beulah, Dakota del nord)',
        'America/North_Dakota/Center' => 'Ora centrale USA (Center, Dakota del nord)',
        'America/North_Dakota/New_Salem' => 'Ora centrale USA (New Salem, Dakota del nord)',
        'America/Ojinaga' => 'Ora Montagne Rocciose USA (Ojinaga)',
        'America/Panama' => 'Ora orientale USA (Panama)',
        'America/Pangnirtung' => 'Ora orientale USA (Pangnirtung)',
        'America/Paramaribo' => 'Ora del Suriname (Paramaribo)',
        'America/Phoenix' => 'Ora Montagne Rocciose USA (Phoenix)',
        'America/Port-au-Prince' => 'Ora orientale USA (Port-au-Prince)',
        'America/Port_of_Spain' => 'Ora dell’Atlantico (Port of Spain)',
        'America/Porto_Velho' => 'Ora dell’Amazzonia (Porto Velho)',
        'America/Puerto_Rico' => 'Ora dell’Atlantico (Portorico)',
        'America/Punta_Arenas' => 'Ora del Cile (Punta Arenas)',
        'America/Rainy_River' => 'Ora centrale USA (Rainy River)',
        'America/Rankin_Inlet' => 'Ora centrale USA (Rankin Inlet)',
        'America/Recife' => 'Ora di Brasilia (Recife)',
        'America/Regina' => 'Ora centrale USA (Regina)',
        'America/Resolute' => 'Ora centrale USA (Resolute)',
        'America/Rio_Branco' => 'Ora Brasile (Rio Branco)',
        'America/Santa_Isabel' => 'Ora del Messico nord-occidentale (Santa Isabel)',
        'America/Santarem' => 'Ora di Brasilia (Santarém)',
        'America/Santiago' => 'Ora del Cile (Santiago)',
        'America/Santo_Domingo' => 'Ora dell’Atlantico (Santo Domingo)',
        'America/Sao_Paulo' => 'Ora di Brasilia (San Paolo)',
        'America/Scoresbysund' => 'Ora della Groenlandia orientale (Ittoqqortoormiit)',
        'America/Sitka' => 'Ora dell’Alaska (Sitka)',
        'America/St_Barthelemy' => 'Ora dell’Atlantico (Saint-Barthélemy)',
        'America/St_Johns' => 'Ora di Terranova (St. John’s)',
        'America/St_Kitts' => 'Ora dell’Atlantico (St. Kitts)',
        'America/St_Lucia' => 'Ora dell’Atlantico (Santa Lucia)',
        'America/St_Thomas' => 'Ora dell’Atlantico (Saint Thomas)',
        'America/St_Vincent' => 'Ora dell’Atlantico (Saint Vincent)',
        'America/Swift_Current' => 'Ora centrale USA (Swift Current)',
        'America/Tegucigalpa' => 'Ora centrale USA (Tegucigalpa)',
        'America/Thule' => 'Ora dell’Atlantico (Thule)',
        'America/Thunder_Bay' => 'Ora orientale USA (Thunder Bay)',
        'America/Tijuana' => 'Ora del Pacifico USA (Tijuana)',
        'America/Toronto' => 'Ora orientale USA (Toronto)',
        'America/Tortola' => 'Ora dell’Atlantico (Tortola)',
        'America/Vancouver' => 'Ora del Pacifico USA (Vancouver)',
        'America/Whitehorse' => 'Ora dello Yukon (Whitehorse)',
        'America/Winnipeg' => 'Ora centrale USA (Winnipeg)',
        'America/Yakutat' => 'Ora dell’Alaska (Yakutat)',
        'America/Yellowknife' => 'Ora Montagne Rocciose USA (Yellowknife)',
        'Antarctica/Casey' => 'Ora Antartide (Casey)',
        'Antarctica/Davis' => 'Ora di Davis',
        'Antarctica/DumontDUrville' => 'Ora di Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Ora dell’Australia orientale (Macquarie)',
        'Antarctica/Mawson' => 'Ora di Mawson',
        'Antarctica/McMurdo' => 'Ora della Nuova Zelanda (McMurdo)',
        'Antarctica/Palmer' => 'Ora del Cile (Palmer)',
        'Antarctica/Rothera' => 'Ora di Rothera',
        'Antarctica/Syowa' => 'Ora di Syowa',
        'Antarctica/Troll' => 'Ora del meridiano di Greenwich (Troll)',
        'Antarctica/Vostok' => 'Ora di Vostok',
        'Arctic/Longyearbyen' => 'Ora dell’Europa centrale (Longyearbyen)',
        'Asia/Aden' => 'Ora araba (Aden)',
        'Asia/Almaty' => 'Ora del Kazakistan orientale (Almaty)',
        'Asia/Amman' => 'Ora dell’Europa orientale (Amman)',
        'Asia/Anadyr' => 'Ora di Anadyr (Anadyr’)',
        'Asia/Aqtau' => 'Ora del Kazakistan occidentale (Aqtau)',
        'Asia/Aqtobe' => 'Ora del Kazakistan occidentale (Aqtöbe)',
        'Asia/Ashgabat' => 'Ora del Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Ora del Kazakistan occidentale (Atyrau)',
        'Asia/Baghdad' => 'Ora araba (Baghdad)',
        'Asia/Bahrain' => 'Ora araba (Bahrein)',
        'Asia/Baku' => 'Ora dell’Azerbaigian (Baku)',
        'Asia/Bangkok' => 'Ora dell’Indocina (Bangkok)',
        'Asia/Barnaul' => 'Ora Russia (Barnaul)',
        'Asia/Beirut' => 'Ora dell’Europa orientale (Beirut)',
        'Asia/Bishkek' => 'Ora del Kirghizistan (Bishkek)',
        'Asia/Brunei' => 'Ora del Brunei Darussalam',
        'Asia/Calcutta' => 'Ora standard dell’India (Calcutta)',
        'Asia/Chita' => 'Ora di Yakutsk (Čita)',
        'Asia/Choibalsan' => 'Ora di Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Ora standard dell’India (Colombo)',
        'Asia/Damascus' => 'Ora dell’Europa orientale (Damasco)',
        'Asia/Dhaka' => 'Ora del Bangladesh (Dacca)',
        'Asia/Dili' => 'Ora di Timor Est (Dili)',
        'Asia/Dubai' => 'Ora del Golfo (Dubai)',
        'Asia/Dushanbe' => 'Ora del Tagikistan (Dushanbe)',
        'Asia/Famagusta' => 'Ora dell’Europa orientale (Famagosta)',
        'Asia/Gaza' => 'Ora dell’Europa orientale (Gaza)',
        'Asia/Hebron' => 'Ora dell’Europa orientale (Hebron)',
        'Asia/Hong_Kong' => 'Ora di Hong Kong',
        'Asia/Hovd' => 'Ora di Hovd',
        'Asia/Irkutsk' => 'Ora di Irkutsk',
        'Asia/Jakarta' => 'Ora dell’Indonesia occidentale (Giacarta)',
        'Asia/Jayapura' => 'Ora dell’Indonesia orientale (Jayapura)',
        'Asia/Jerusalem' => 'Ora di Israele (Gerusalemme)',
        'Asia/Kabul' => 'Ora dell’Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Ora di Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Ora del Pakistan (Karachi)',
        'Asia/Katmandu' => 'Ora del Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Ora di Yakutsk (Chandyga)',
        'Asia/Krasnoyarsk' => 'Ora di Krasnoyarsk (Krasnojarsk)',
        'Asia/Kuala_Lumpur' => 'Ora della Malesia (Kuala Lumpur)',
        'Asia/Kuching' => 'Ora della Malesia (Kuching)',
        'Asia/Kuwait' => 'Ora araba (Kuwait)',
        'Asia/Macau' => 'Ora della Cina (Macao)',
        'Asia/Magadan' => 'Ora di Magadan',
        'Asia/Makassar' => 'Ora dell’Indonesia centrale (Makassar)',
        'Asia/Manila' => 'Ora delle Filippine (Manila)',
        'Asia/Muscat' => 'Ora del Golfo (Mascate)',
        'Asia/Nicosia' => 'Ora dell’Europa orientale (Nicosia)',
        'Asia/Novokuznetsk' => 'Ora di Krasnoyarsk (Novokuzneck)',
        'Asia/Novosibirsk' => 'Ora di Novosibirsk',
        'Asia/Omsk' => 'Ora di Omsk',
        'Asia/Oral' => 'Ora del Kazakistan occidentale (Oral)',
        'Asia/Phnom_Penh' => 'Ora dell’Indocina (Phnom Penh)',
        'Asia/Pontianak' => 'Ora dell’Indonesia occidentale (Pontianak)',
        'Asia/Pyongyang' => 'Ora coreana (Pyongyang)',
        'Asia/Qatar' => 'Ora araba (Qatar)',
        'Asia/Qostanay' => 'Ora del Kazakistan orientale (Qostanay)',
        'Asia/Qyzylorda' => 'Ora del Kazakistan occidentale (Qyzylorda)',
        'Asia/Rangoon' => 'Ora della Birmania (Rangoon)',
        'Asia/Riyadh' => 'Ora araba (Riyad)',
        'Asia/Saigon' => 'Ora dell’Indocina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Ora di Sakhalin (Sachalin)',
        'Asia/Samarkand' => 'Ora dell’Uzbekistan (Samarcanda)',
        'Asia/Seoul' => 'Ora coreana (Seul)',
        'Asia/Shanghai' => 'Ora della Cina (Shanghai)',
        'Asia/Singapore' => 'Ora di Singapore',
        'Asia/Srednekolymsk' => 'Ora di Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Ora di Taipei',
        'Asia/Tashkent' => 'Ora dell’Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Ora della Georgia (Tbilisi)',
        'Asia/Tehran' => 'Ora dell’Iran (Teheran)',
        'Asia/Thimphu' => 'Ora del Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Ora del Giappone (Tokyo)',
        'Asia/Tomsk' => 'Ora Russia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ora di Ulan Bator',
        'Asia/Urumqi' => 'Ora Cina (Urumqi)',
        'Asia/Ust-Nera' => 'Ora di Vladivostok (Ust’-Nera)',
        'Asia/Vientiane' => 'Ora dell’Indocina (Vientiane)',
        'Asia/Vladivostok' => 'Ora di Vladivostok',
        'Asia/Yakutsk' => 'Ora di Yakutsk (Jakutsk)',
        'Asia/Yekaterinburg' => 'Ora di Ekaterinburg',
        'Asia/Yerevan' => 'Ora dell’Armenia (Yerevan)',
        'Atlantic/Azores' => 'Ora delle Azzorre',
        'Atlantic/Bermuda' => 'Ora dell’Atlantico (Bermuda)',
        'Atlantic/Canary' => 'Ora dell’Europa occidentale (Canarie)',
        'Atlantic/Cape_Verde' => 'Ora di Capo Verde',
        'Atlantic/Faeroe' => 'Ora dell’Europa occidentale (Isole Fær Øer)',
        'Atlantic/Madeira' => 'Ora dell’Europa occidentale (Madeira)',
        'Atlantic/Reykjavik' => 'Ora del meridiano di Greenwich (Reykjavík)',
        'Atlantic/South_Georgia' => 'Ora della Georgia del Sud',
        'Atlantic/St_Helena' => 'Ora del meridiano di Greenwich (Sant’Elena)',
        'Atlantic/Stanley' => 'Ora delle Isole Falkland (Stanley)',
        'Australia/Adelaide' => 'Ora dell’Australia centrale (Adelaide)',
        'Australia/Brisbane' => 'Ora dell’Australia orientale (Brisbane)',
        'Australia/Broken_Hill' => 'Ora dell’Australia centrale (Broken Hill)',
        'Australia/Currie' => 'Ora dell’Australia orientale (Currie)',
        'Australia/Darwin' => 'Ora dell’Australia centrale (Darwin)',
        'Australia/Eucla' => 'Ora dell’Australia centroccidentale (Eucla)',
        'Australia/Hobart' => 'Ora dell’Australia orientale (Hobart)',
        'Australia/Lindeman' => 'Ora dell’Australia orientale (Lindeman)',
        'Australia/Lord_Howe' => 'Ora di Lord Howe',
        'Australia/Melbourne' => 'Ora dell’Australia orientale (Melbourne)',
        'Australia/Perth' => 'Ora dell’Australia occidentale (Perth)',
        'Australia/Sydney' => 'Ora dell’Australia orientale (Sydney)',
        'CST6CDT' => 'Ora centrale USA',
        'EST5EDT' => 'Ora orientale USA',
        'Etc/GMT' => 'Ora del meridiano di Greenwich',
        'Etc/UTC' => 'Tempo coordinato universale',
        'Europe/Amsterdam' => 'Ora dell’Europa centrale (Amsterdam)',
        'Europe/Andorra' => 'Ora dell’Europa centrale (Andorra)',
        'Europe/Astrakhan' => 'Ora di Mosca (Astrakhan)',
        'Europe/Athens' => 'Ora dell’Europa orientale (Atene)',
        'Europe/Belgrade' => 'Ora dell’Europa centrale (Belgrado)',
        'Europe/Berlin' => 'Ora dell’Europa centrale (Berlino)',
        'Europe/Bratislava' => 'Ora dell’Europa centrale (Bratislava)',
        'Europe/Brussels' => 'Ora dell’Europa centrale (Bruxelles)',
        'Europe/Bucharest' => 'Ora dell’Europa orientale (Bucarest)',
        'Europe/Budapest' => 'Ora dell’Europa centrale (Budapest)',
        'Europe/Busingen' => 'Ora dell’Europa centrale (Büsingen)',
        'Europe/Chisinau' => 'Ora dell’Europa orientale (Chisinau)',
        'Europe/Copenhagen' => 'Ora dell’Europa centrale (Copenaghen)',
        'Europe/Dublin' => 'Ora del meridiano di Greenwich (Dublino)',
        'Europe/Gibraltar' => 'Ora dell’Europa centrale (Gibilterra)',
        'Europe/Guernsey' => 'Ora del meridiano di Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Ora dell’Europa orientale (Helsinki)',
        'Europe/Isle_of_Man' => 'Ora del meridiano di Greenwich (Isola di Man)',
        'Europe/Istanbul' => 'Ora Turchia (Istanbul)',
        'Europe/Jersey' => 'Ora del meridiano di Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Ora dell’Europa orientale (Kaliningrad)',
        'Europe/Kiev' => 'Ora dell’Europa orientale (Kiev)',
        'Europe/Kirov' => 'Ora Russia (Kirov)',
        'Europe/Lisbon' => 'Ora dell’Europa occidentale (Lisbona)',
        'Europe/Ljubljana' => 'Ora dell’Europa centrale (Lubiana)',
        'Europe/London' => 'Ora del meridiano di Greenwich (Londra)',
        'Europe/Luxembourg' => 'Ora dell’Europa centrale (Lussemburgo)',
        'Europe/Madrid' => 'Ora dell’Europa centrale (Madrid)',
        'Europe/Malta' => 'Ora dell’Europa centrale (Malta)',
        'Europe/Mariehamn' => 'Ora dell’Europa orientale (Mariehamn)',
        'Europe/Minsk' => 'Ora di Mosca (Minsk)',
        'Europe/Monaco' => 'Ora dell’Europa centrale (Monaco)',
        'Europe/Moscow' => 'Ora di Mosca',
        'Europe/Oslo' => 'Ora dell’Europa centrale (Oslo)',
        'Europe/Paris' => 'Ora dell’Europa centrale (Parigi)',
        'Europe/Podgorica' => 'Ora dell’Europa centrale (Podgorica)',
        'Europe/Prague' => 'Ora dell’Europa centrale (Praga)',
        'Europe/Riga' => 'Ora dell’Europa orientale (Riga)',
        'Europe/Rome' => 'Ora dell’Europa centrale (Roma)',
        'Europe/Samara' => 'Ora di Samara',
        'Europe/San_Marino' => 'Ora dell’Europa centrale (San Marino)',
        'Europe/Sarajevo' => 'Ora dell’Europa centrale (Sarajevo)',
        'Europe/Saratov' => 'Ora di Mosca (Saratov)',
        'Europe/Simferopol' => 'Ora di Mosca (Sinferopoli)',
        'Europe/Skopje' => 'Ora dell’Europa centrale (Skopje)',
        'Europe/Sofia' => 'Ora dell’Europa orientale (Sofia)',
        'Europe/Stockholm' => 'Ora dell’Europa centrale (Stoccolma)',
        'Europe/Tallinn' => 'Ora dell’Europa orientale (Tallinn)',
        'Europe/Tirane' => 'Ora dell’Europa centrale (Tirana)',
        'Europe/Ulyanovsk' => 'Ora di Mosca (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Ora dell’Europa orientale (Užhorod)',
        'Europe/Vaduz' => 'Ora dell’Europa centrale (Vaduz)',
        'Europe/Vatican' => 'Ora dell’Europa centrale (Città del Vaticano)',
        'Europe/Vienna' => 'Ora dell’Europa centrale (Vienna)',
        'Europe/Vilnius' => 'Ora dell’Europa orientale (Vilnius)',
        'Europe/Volgograd' => 'Ora di Volgograd',
        'Europe/Warsaw' => 'Ora dell’Europa centrale (Varsavia)',
        'Europe/Zagreb' => 'Ora dell’Europa centrale (Zagabria)',
        'Europe/Zaporozhye' => 'Ora dell’Europa orientale (Zaporozhye)',
        'Europe/Zurich' => 'Ora dell’Europa centrale (Zurigo)',
        'Indian/Antananarivo' => 'Ora dell’Africa orientale (Antananarivo)',
        'Indian/Chagos' => 'Ora dell’Oceano Indiano (Chagos)',
        'Indian/Christmas' => 'Ora dell’Isola Christmas',
        'Indian/Cocos' => 'Ora delle Isole Cocos',
        'Indian/Comoro' => 'Ora dell’Africa orientale (Comore)',
        'Indian/Kerguelen' => 'Ora delle Terre australi e antartiche francesi (Kerguelen)',
        'Indian/Mahe' => 'Ora delle Seychelles (Mahe)',
        'Indian/Maldives' => 'Ora delle Maldive',
        'Indian/Mauritius' => 'Ora delle Mauritius',
        'Indian/Mayotte' => 'Ora dell’Africa orientale (Mayotte)',
        'Indian/Reunion' => 'Ora di Riunione (La Riunione)',
        'MST7MDT' => 'Ora Montagne Rocciose USA',
        'PST8PDT' => 'Ora del Pacifico USA',
        'Pacific/Apia' => 'Ora di Apia',
        'Pacific/Auckland' => 'Ora della Nuova Zelanda (Auckland)',
        'Pacific/Bougainville' => 'Ora della Papua Nuova Guinea (Bougainville)',
        'Pacific/Chatham' => 'Ora delle Chatham',
        'Pacific/Easter' => 'Ora dell’Isola di Pasqua',
        'Pacific/Efate' => 'Ora del Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Ora delle Isole della Fenice (Enderbury)',
        'Pacific/Fakaofo' => 'Ora di Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Ora delle Figi',
        'Pacific/Funafuti' => 'Ora di Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Ora delle Galapagos',
        'Pacific/Gambier' => 'Ora di Gambier',
        'Pacific/Guadalcanal' => 'Ora delle Isole Salomone (Guadalcanal)',
        'Pacific/Guam' => 'Ora di Chamorro (Guam)',
        'Pacific/Honolulu' => 'Ora delle isole Hawaii-Aleutine (Honolulu)',
        'Pacific/Johnston' => 'Ora delle isole Hawaii-Aleutine (Johnston)',
        'Pacific/Kiritimati' => 'Ora delle Sporadi equatoriali (Kiritimati)',
        'Pacific/Kosrae' => 'Ora del Kosrae',
        'Pacific/Kwajalein' => 'Ora delle Isole Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Ora delle Isole Marshall (Majuro)',
        'Pacific/Marquesas' => 'Ora delle Marchesi',
        'Pacific/Midway' => 'Ora di Samoa (Midway)',
        'Pacific/Nauru' => 'Ora di Nauru',
        'Pacific/Niue' => 'Ora di Niue',
        'Pacific/Norfolk' => 'Ora delle Isole Norfolk',
        'Pacific/Noumea' => 'Ora della Nuova Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'Ora di Samoa (Pago Pago)',
        'Pacific/Palau' => 'Ora di Palau',
        'Pacific/Pitcairn' => 'Ora delle Pitcairn',
        'Pacific/Ponape' => 'Ora di Pohnpei',
        'Pacific/Port_Moresby' => 'Ora della Papua Nuova Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Ora delle isole Cook (Rarotonga)',
        'Pacific/Saipan' => 'Ora di Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Ora di Tahiti',
        'Pacific/Tarawa' => 'Ora delle isole Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Ora di Tonga (Tongatapu)',
        'Pacific/Truk' => 'Ora del Chuuk',
        'Pacific/Wake' => 'Ora dell’Isola di Wake',
        'Pacific/Wallis' => 'Ora di Wallis e Futuna',
    ],
    'Meta' => [
    ],
];
