<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Средње време по Гриничу (Абиџан)',
        'Africa/Accra' => 'Средње време по Гриничу (Акра)',
        'Africa/Addis_Ababa' => 'Источно-афричко време (Адис Абеба)',
        'Africa/Algiers' => 'Средњеевропско време (Алжир)',
        'Africa/Asmera' => 'Источно-афричко време (Асмера)',
        'Africa/Bamako' => 'Средње време по Гриничу (Бамако)',
        'Africa/Bangui' => 'Западно-афричко време (Бангуи)',
        'Africa/Banjul' => 'Средње време по Гриничу (Банжул)',
        'Africa/Bissau' => 'Средње време по Гриничу (Бисао)',
        'Africa/Blantyre' => 'Централно-афричко време (Блантир)',
        'Africa/Brazzaville' => 'Западно-афричко време (Бразавил)',
        'Africa/Bujumbura' => 'Централно-афричко време (Буџумбура)',
        'Africa/Cairo' => 'Источноевропско време (Каиро)',
        'Africa/Casablanca' => 'Западноевропско време (Казабланка)',
        'Africa/Ceuta' => 'Средњеевропско време (Сеута)',
        'Africa/Conakry' => 'Средње време по Гриничу (Конакри)',
        'Africa/Dakar' => 'Средње време по Гриничу (Дакар)',
        'Africa/Dar_es_Salaam' => 'Источно-афричко време (Дар-ес-Салам)',
        'Africa/Djibouti' => 'Источно-афричко време (Џибути)',
        'Africa/Douala' => 'Западно-афричко време (Дуала)',
        'Africa/El_Aaiun' => 'Западноевропско време (Ел Ајун)',
        'Africa/Freetown' => 'Средње време по Гриничу (Фритаун)',
        'Africa/Gaborone' => 'Централно-афричко време (Габорон)',
        'Africa/Harare' => 'Централно-афричко време (Хараре)',
        'Africa/Johannesburg' => 'Јужно-афричко време (Јоханесбург)',
        'Africa/Juba' => 'Централно-афричко време (Џуба)',
        'Africa/Kampala' => 'Источно-афричко време (Кампала)',
        'Africa/Khartoum' => 'Централно-афричко време (Картум)',
        'Africa/Kigali' => 'Централно-афричко време (Кигали)',
        'Africa/Kinshasa' => 'Западно-афричко време (Киншаса)',
        'Africa/Lagos' => 'Западно-афричко време (Лагос)',
        'Africa/Libreville' => 'Западно-афричко време (Либревил)',
        'Africa/Lome' => 'Средње време по Гриничу (Ломе)',
        'Africa/Luanda' => 'Западно-афричко време (Луанда)',
        'Africa/Lubumbashi' => 'Централно-афричко време (Лубумбаши)',
        'Africa/Lusaka' => 'Централно-афричко време (Лусака)',
        'Africa/Malabo' => 'Западно-афричко време (Малабо)',
        'Africa/Maputo' => 'Централно-афричко време (Мапуто)',
        'Africa/Maseru' => 'Јужно-афричко време (Масеру)',
        'Africa/Mbabane' => 'Јужно-афричко време (Мбабане)',
        'Africa/Mogadishu' => 'Источно-афричко време (Могадиш)',
        'Africa/Monrovia' => 'Средње време по Гриничу (Монровија)',
        'Africa/Nairobi' => 'Источно-афричко време (Најроби)',
        'Africa/Ndjamena' => 'Западно-афричко време (Нџамена)',
        'Africa/Niamey' => 'Западно-афричко време (Нијамеј)',
        'Africa/Nouakchott' => 'Средње време по Гриничу (Нуакшот)',
        'Africa/Ouagadougou' => 'Средње време по Гриничу (Уагадугу)',
        'Africa/Porto-Novo' => 'Западно-афричко време (Порто Ново)',
        'Africa/Sao_Tome' => 'Средње време по Гриничу (Сао Томе)',
        'Africa/Tripoli' => 'Источноевропско време (Триполи)',
        'Africa/Tunis' => 'Средњеевропско време (Тунис)',
        'Africa/Windhoek' => 'Централно-афричко време (Виндхук)',
        'America/Adak' => 'Хавајско-алеутско време (Адак)',
        'America/Anchorage' => 'Аљаска (Енкориџ)',
        'America/Anguilla' => 'Атлантско време (Ангвила)',
        'America/Antigua' => 'Атлантско време (Антигва)',
        'America/Araguaina' => 'Бразилија време (Арагвајана)',
        'America/Argentina/La_Rioja' => 'Аргентина време (Ла Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина време (Рио Гаљегос)',
        'America/Argentina/Salta' => 'Аргентина време (Салта)',
        'America/Argentina/San_Juan' => 'Аргентина време (Сан Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина време (Сан Луи)',
        'America/Argentina/Tucuman' => 'Аргентина време (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина време (Ушуаија)',
        'America/Aruba' => 'Атлантско време (Аруба)',
        'America/Asuncion' => 'Парагвај време (Асунсион)',
        'America/Bahia' => 'Бразилија време (Баија)',
        'America/Bahia_Banderas' => 'Северноамеричко централно време (Баија Бандерас)',
        'America/Barbados' => 'Атлантско време (Барбадос)',
        'America/Belem' => 'Бразилија време (Белем)',
        'America/Belize' => 'Северноамеричко централно време (Белизе)',
        'America/Blanc-Sablon' => 'Атлантско време (Бланк-Сејблон)',
        'America/Boa_Vista' => 'Амазон време (Боа Виста)',
        'America/Bogota' => 'Колумбија време (Богота)',
        'America/Boise' => 'Северноамеричко планинско време (Бојзи)',
        'America/Buenos_Aires' => 'Аргентина време (Буенос Ајрес)',
        'America/Cambridge_Bay' => 'Северноамеричко планинско време (Кембриџ Беј)',
        'America/Campo_Grande' => 'Амазон време (Кампо Гранде)',
        'America/Cancun' => 'Северноамеричко источно време (Канкун)',
        'America/Caracas' => 'Венецуела време (Каракас)',
        'America/Catamarca' => 'Аргентина време (Катамарка)',
        'America/Cayenne' => 'Француска Гвајана време (Кајен)',
        'America/Cayman' => 'Северноамеричко источно време (Кајманска Острва)',
        'America/Chicago' => 'Северноамеричко централно време (Чикаго)',
        'America/Chihuahua' => 'Мексички Пацифик (Чихуахуа)',
        'America/Coral_Harbour' => 'Северноамеричко источно време (Корал Харбур)',
        'America/Cordoba' => 'Аргентина време (Кордоба)',
        'America/Costa_Rica' => 'Северноамеричко централно време (Костарика)',
        'America/Creston' => 'Северноамеричко планинско време (Крестон)',
        'America/Cuiaba' => 'Амазон време (Куиаба)',
        'America/Curacao' => 'Атлантско време (Курасао)',
        'America/Danmarkshavn' => 'Средње време по Гриничу (Данмарксхаген)',
        'America/Dawson' => 'Јукон (Досон)',
        'America/Dawson_Creek' => 'Северноамеричко планинско време (Досон Крик)',
        'America/Denver' => 'Северноамеричко планинско време (Денвер)',
        'America/Detroit' => 'Северноамеричко источно време (Детроит)',
        'America/Dominica' => 'Атлантско време (Доминика)',
        'America/Edmonton' => 'Северноамеричко планинско време (Едмонтон)',
        'America/Eirunepe' => 'Акре време (Еирунепе)',
        'America/El_Salvador' => 'Северноамеричко централно време (Салвадор)',
        'America/Fort_Nelson' => 'Северноамеричко планинско време (Форт Нелсон)',
        'America/Fortaleza' => 'Бразилија време (Форталеза)',
        'America/Glace_Bay' => 'Атлантско време (Глејс Беј)',
        'America/Godthab' => 'Западни Гренланд (Готхаб)',
        'America/Goose_Bay' => 'Атлантско време (Гус Беј)',
        'America/Grand_Turk' => 'Северноамеричко источно време (Гранд Турк)',
        'America/Grenada' => 'Атлантско време (Гренада)',
        'America/Guadeloupe' => 'Атлантско време (Гвадалупе)',
        'America/Guatemala' => 'Северноамеричко централно време (Гватемала)',
        'America/Guayaquil' => 'Еквадор време (Гвајакил)',
        'America/Guyana' => 'Гвајана време',
        'America/Halifax' => 'Атлантско време (Халифакс)',
        'America/Havana' => 'Куба (Хавана)',
        'America/Hermosillo' => 'Мексички Пацифик (Хермосиљо)',
        'America/Indiana/Knox' => 'Северноамеричко централно време (Нокс, Индијана)',
        'America/Indiana/Marengo' => 'Северноамеричко источно време (Маренго, Индијана)',
        'America/Indiana/Petersburg' => 'Северноамеричко источно време (Питерсбург, Индијана)',
        'America/Indiana/Tell_City' => 'Северноамеричко централно време (Тел Сити, Индијана)',
        'America/Indiana/Vevay' => 'Северноамеричко источно време (Вевај, Индијана)',
        'America/Indiana/Vincennes' => 'Северноамеричко источно време (Винценес, Индијана)',
        'America/Indiana/Winamac' => 'Северноамеричко источно време (Винамак, Индијана)',
        'America/Indianapolis' => 'Северноамеричко источно време (Индианаполис)',
        'America/Inuvik' => 'Северноамеричко планинско време (Инувик)',
        'America/Iqaluit' => 'Северноамеричко источно време (Иквалуит)',
        'America/Jamaica' => 'Северноамеричко источно време (Јамајка)',
        'America/Jujuy' => 'Аргентина време (Жужуи)',
        'America/Juneau' => 'Аљаска (Жуно)',
        'America/Kentucky/Monticello' => 'Северноамеричко источно време (Монтичело, Кентаки)',
        'America/Kralendijk' => 'Атлантско време (Кралендајк)',
        'America/La_Paz' => 'Боливија време (Ла Паз)',
        'America/Lima' => 'Перу време (Лима)',
        'America/Los_Angeles' => 'Северноамеричко пацифичко време (Лос Анђелес)',
        'America/Louisville' => 'Северноамеричко источно време (Луивиле)',
        'America/Lower_Princes' => 'Атлантско време (Лоуер Принсиз Квортер)',
        'America/Maceio' => 'Бразилија време (Масејо)',
        'America/Managua' => 'Северноамеричко централно време (Манагва)',
        'America/Manaus' => 'Амазон време (Манаус)',
        'America/Marigot' => 'Атлантско време (Мариго)',
        'America/Martinique' => 'Атлантско време (Мартиник)',
        'America/Matamoros' => 'Северноамеричко централно време (Матаморос)',
        'America/Mazatlan' => 'Мексички Пацифик (Мазатлан)',
        'America/Mendoza' => 'Аргентина време (Мендоса)',
        'America/Menominee' => 'Северноамеричко централно време (Меномини)',
        'America/Merida' => 'Северноамеричко централно време (Мерида)',
        'America/Metlakatla' => 'Аљаска (Метлакатла)',
        'America/Mexico_City' => 'Северноамеричко централно време (Мексико Сити)',
        'America/Miquelon' => 'Сен Пјер и Микелон',
        'America/Moncton' => 'Атлантско време (Монктон)',
        'America/Monterrey' => 'Северноамеричко централно време (Монтереј)',
        'America/Montevideo' => 'Уругвај време (Монтевидео)',
        'America/Montreal' => 'Канада (Montreal)',
        'America/Montserrat' => 'Атлантско време (Монтсерат)',
        'America/Nassau' => 'Северноамеричко источно време (Насау)',
        'America/New_York' => 'Северноамеричко источно време (Њујорк)',
        'America/Nipigon' => 'Северноамеричко источно време (Нипигон)',
        'America/Nome' => 'Аљаска (Ном)',
        'America/Noronha' => 'Фернандо де Нороња време',
        'America/North_Dakota/Beulah' => 'Северноамеричко централно време (Бијула, Северна Дакота)',
        'America/North_Dakota/Center' => 'Северноамеричко централно време (Центар, Северна Дакота)',
        'America/North_Dakota/New_Salem' => 'Северноамеричко централно време (Нови Салем, Северна Дакота)',
        'America/Ojinaga' => 'Северноамеричко планинско време (Охинага)',
        'America/Panama' => 'Северноамеричко источно време (Панама)',
        'America/Pangnirtung' => 'Северноамеричко источно време (Пангниртунг)',
        'America/Paramaribo' => 'Суринам време (Парамарибо)',
        'America/Phoenix' => 'Северноамеричко планинско време (Финикс)',
        'America/Port-au-Prince' => 'Северноамеричко источно време (Порт о Пренс)',
        'America/Port_of_Spain' => 'Атлантско време (Порт оф Спејн)',
        'America/Porto_Velho' => 'Амазон време (Порто Вељо)',
        'America/Puerto_Rico' => 'Атлантско време (Порто Рико)',
        'America/Punta_Arenas' => 'Чиле време (Пунта Аренас)',
        'America/Rainy_River' => 'Северноамеричко централно време (Рејни Ривер)',
        'America/Rankin_Inlet' => 'Северноамеричко централно време (Ранкин Инлет)',
        'America/Recife' => 'Бразилија време (Ресифе)',
        'America/Regina' => 'Северноамеричко централно време (Регина)',
        'America/Resolute' => 'Северноамеричко централно време (Ресолут)',
        'America/Rio_Branco' => 'Акре време (Рио Бранко)',
        'America/Santa_Isabel' => 'Северозападни Мексико (Санта Изабел)',
        'America/Santarem' => 'Бразилија време (Сантарем)',
        'America/Santiago' => 'Чиле време (Сантјаго)',
        'America/Santo_Domingo' => 'Атлантско време (Санто Доминго)',
        'America/Sao_Paulo' => 'Бразилија време (Сао Паоло)',
        'America/Scoresbysund' => 'Источни Гренланд (Скорезбисунд)',
        'America/Sitka' => 'Аљаска (Ситка)',
        'America/St_Barthelemy' => 'Атлантско време (Св. Бартоломeј)',
        'America/St_Johns' => 'Њуфаундленд (Св. Џон)',
        'America/St_Kitts' => 'Атлантско време (Сент Китс)',
        'America/St_Lucia' => 'Атлантско време (Св. Луција)',
        'America/St_Thomas' => 'Атлантско време (Св. Тома)',
        'America/St_Vincent' => 'Атлантско време (Сент Винсент)',
        'America/Swift_Current' => 'Северноамеричко централно време (Свифт Курент)',
        'America/Tegucigalpa' => 'Северноамеричко централно време (Тегусигалпа)',
        'America/Thule' => 'Атлантско време (Тул)',
        'America/Thunder_Bay' => 'Северноамеричко источно време (Тандер Беј)',
        'America/Tijuana' => 'Северноамеричко пацифичко време (Тихуана)',
        'America/Toronto' => 'Северноамеричко источно време (Торонто)',
        'America/Tortola' => 'Атлантско време (Тортола)',
        'America/Vancouver' => 'Северноамеричко пацифичко време (Ванкувер)',
        'America/Whitehorse' => 'Јукон (Вајтхорс)',
        'America/Winnipeg' => 'Северноамеричко централно време (Винипег)',
        'America/Yakutat' => 'Аљаска (Јакутат)',
        'America/Yellowknife' => 'Северноамеричко планинско време (Јелоунајф)',
        'Antarctica/Casey' => 'Антарктик (Кејси)',
        'Antarctica/Davis' => 'Дејвис време',
        'Antarctica/DumontDUrville' => 'Димон д’Урвил време',
        'Antarctica/Macquarie' => 'Аустралијско источно време (Меквори)',
        'Antarctica/Mawson' => 'Мосон време',
        'Antarctica/McMurdo' => 'Нови Зеланд време (Макмурдо)',
        'Antarctica/Palmer' => 'Чиле време (Палмер)',
        'Antarctica/Rothera' => 'Ротера време',
        'Antarctica/Syowa' => 'Шова време',
        'Antarctica/Troll' => 'Средње време по Гриничу (Трол)',
        'Antarctica/Vostok' => 'Восток време',
        'Arctic/Longyearbyen' => 'Средњеевропско време (Лонгјербјен)',
        'Asia/Aden' => 'Арабијско време (Аден)',
        'Asia/Almaty' => 'Источно-казахстанско време (Алмати)',
        'Asia/Amman' => 'Источноевропско време (Аман)',
        'Asia/Anadyr' => 'Анадир време',
        'Asia/Aqtau' => 'Западно-казахстанско време (Актау)',
        'Asia/Aqtobe' => 'Западно-казахстанско време (Акутобе)',
        'Asia/Ashgabat' => 'Туркменистан време (Ашхабад)',
        'Asia/Atyrau' => 'Западно-казахстанско време (Атирау)',
        'Asia/Baghdad' => 'Арабијско време (Багдад)',
        'Asia/Bahrain' => 'Арабијско време (Бахреин)',
        'Asia/Baku' => 'Азербејџан време (Баку)',
        'Asia/Bangkok' => 'Индокина време (Бангкок)',
        'Asia/Barnaul' => 'Русија (Барнаул)',
        'Asia/Beirut' => 'Источноевропско време (Бејрут)',
        'Asia/Bishkek' => 'Киргистан време (Бишкек)',
        'Asia/Brunei' => 'Брунеј Дарусалум време',
        'Asia/Calcutta' => 'Индијско стандардно време (Калкута)',
        'Asia/Chita' => 'Јакутск време (Чита)',
        'Asia/Choibalsan' => 'Улан Батор време (Чојбалсан)',
        'Asia/Colombo' => 'Индијско стандардно време (Коломбо)',
        'Asia/Damascus' => 'Источноевропско време (Дамаск)',
        'Asia/Dhaka' => 'Бангладеш време (Дака)',
        'Asia/Dili' => 'Источни тимор време (Дили)',
        'Asia/Dubai' => 'Заливско време (Дубаи)',
        'Asia/Dushanbe' => 'Таџикистан време (Душанбе)',
        'Asia/Famagusta' => 'Источноевропско време (Фамагуста)',
        'Asia/Gaza' => 'Источноевропско време (Газа)',
        'Asia/Hebron' => 'Источноевропско време (Хеброн)',
        'Asia/Hong_Kong' => 'Хонг Конг време (Хонгконг)',
        'Asia/Hovd' => 'Ховд време',
        'Asia/Irkutsk' => 'Иркуцк време',
        'Asia/Jakarta' => 'Западно-индонезијско време (Џакарта)',
        'Asia/Jayapura' => 'Источно-индонезијско време (Џајапура)',
        'Asia/Jerusalem' => 'Израелско време (Јерусалим)',
        'Asia/Kabul' => 'Авганистан време (Кабул)',
        'Asia/Kamchatka' => 'Петропавловско-камчатско време (Камчатка)',
        'Asia/Karachi' => 'Пакистан време (Карачи)',
        'Asia/Katmandu' => 'Непал време (Катманду)',
        'Asia/Khandyga' => 'Јакутск време (Хандига)',
        'Asia/Krasnoyarsk' => 'Краснојарск време',
        'Asia/Kuala_Lumpur' => 'Малезија време (Куала Лумпур)',
        'Asia/Kuching' => 'Малезија време (Кучинг)',
        'Asia/Kuwait' => 'Арабијско време (Кувајт)',
        'Asia/Macau' => 'Кина време (Макао)',
        'Asia/Magadan' => 'Магадан време',
        'Asia/Makassar' => 'Централно-индонезијско време (Макасар)',
        'Asia/Manila' => 'Филипини време (Манила)',
        'Asia/Muscat' => 'Заливско време (Мускат)',
        'Asia/Nicosia' => 'Источноевропско време (Никозија)',
        'Asia/Novokuznetsk' => 'Краснојарск време (Новокузњецк)',
        'Asia/Novosibirsk' => 'Новосибирск време',
        'Asia/Omsk' => 'Омск време',
        'Asia/Oral' => 'Западно-казахстанско време (Орал)',
        'Asia/Phnom_Penh' => 'Индокина време (Пном Пен)',
        'Asia/Pontianak' => 'Западно-индонезијско време (Понтијанак)',
        'Asia/Pyongyang' => 'Корејско време (Пјонгјанг)',
        'Asia/Qatar' => 'Арабијско време (Катар)',
        'Asia/Qostanay' => 'Источно-казахстанско време (Костанај)',
        'Asia/Qyzylorda' => 'Западно-казахстанско време (Кизилорда)',
        'Asia/Rangoon' => 'Мијанмар време (Рангун)',
        'Asia/Riyadh' => 'Арабијско време (Ријад)',
        'Asia/Saigon' => 'Индокина време (Хо Ши Мин)',
        'Asia/Sakhalin' => 'Сахалин време',
        'Asia/Samarkand' => 'Узбекистан време (Самарканд)',
        'Asia/Seoul' => 'Корејско време (Сеул)',
        'Asia/Shanghai' => 'Кина време (Шангај)',
        'Asia/Singapore' => 'Сингапур, стандардно време',
        'Asia/Srednekolymsk' => 'Магадан време (Средњеколимск)',
        'Asia/Taipei' => 'Тајпеј време',
        'Asia/Tashkent' => 'Узбекистан време (Ташкент)',
        'Asia/Tbilisi' => 'Грузија време (Тбилиси)',
        'Asia/Tehran' => 'Иран време (Техеран)',
        'Asia/Thimphu' => 'Бутан време (Тимпу)',
        'Asia/Tokyo' => 'Јапанско време (Токио)',
        'Asia/Tomsk' => 'Русија (Томск)',
        'Asia/Ulaanbaatar' => 'Улан Батор време',
        'Asia/Urumqi' => 'Кина (Урумћи)',
        'Asia/Ust-Nera' => 'Владивосток време (Уст-Нера)',
        'Asia/Vientiane' => 'Индокина време (Вијентијан)',
        'Asia/Vladivostok' => 'Владивосток време',
        'Asia/Yakutsk' => 'Јакутск време',
        'Asia/Yekaterinburg' => 'Јекатеринбург време',
        'Asia/Yerevan' => 'Јерменија време (Јереван)',
        'Atlantic/Azores' => 'Азори време',
        'Atlantic/Bermuda' => 'Атлантско време (Бермуда)',
        'Atlantic/Canary' => 'Западноевропско време (Канарска острва)',
        'Atlantic/Cape_Verde' => 'Зеленортска Острва време',
        'Atlantic/Faeroe' => 'Западноевропско време (Фарска Острва)',
        'Atlantic/Madeira' => 'Западноевропско време (Мадеира)',
        'Atlantic/Reykjavik' => 'Средње време по Гриничу (Рејкјавик)',
        'Atlantic/South_Georgia' => 'Јужна Џорџија време',
        'Atlantic/St_Helena' => 'Средње време по Гриничу (Света Јелена)',
        'Atlantic/Stanley' => 'Фолкландска Острва време (Стенли)',
        'Australia/Adelaide' => 'Аустралијско централно време (Аделејд)',
        'Australia/Brisbane' => 'Аустралијско источно време (Бризбејн)',
        'Australia/Broken_Hill' => 'Аустралијско централно време (Брокен Хил)',
        'Australia/Currie' => 'Аустралијско источно време (Кари)',
        'Australia/Darwin' => 'Аустралијско централно време (Дарвин)',
        'Australia/Eucla' => 'Аустралијско централно западно време (Иукла)',
        'Australia/Hobart' => 'Аустралијско источно време (Хобарт)',
        'Australia/Lindeman' => 'Аустралијско источно време (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд Хов време (Лорд Хау)',
        'Australia/Melbourne' => 'Аустралијско источно време (Мелбурн)',
        'Australia/Perth' => 'Аустралијско западно време (Перт)',
        'Australia/Sydney' => 'Аустралијско источно време (Сиднеј)',
        'CST6CDT' => 'Северноамеричко централно време',
        'EST5EDT' => 'Северноамеричко источно време',
        'Etc/GMT' => 'Средње време по Гриничу',
        'Etc/UTC' => 'Координисано универзално време',
        'Europe/Amsterdam' => 'Средњеевропско време (Амстердам)',
        'Europe/Andorra' => 'Средњеевропско време (Андора)',
        'Europe/Astrakhan' => 'Москва време (Астракан)',
        'Europe/Athens' => 'Источноевропско време (Атина)',
        'Europe/Belgrade' => 'Средњеевропско време (Београд)',
        'Europe/Berlin' => 'Средњеевропско време (Берлин)',
        'Europe/Bratislava' => 'Средњеевропско време (Братислава)',
        'Europe/Brussels' => 'Средњеевропско време (Брисел)',
        'Europe/Bucharest' => 'Источноевропско време (Букурешт)',
        'Europe/Budapest' => 'Средњеевропско време (Будимпешта)',
        'Europe/Busingen' => 'Средњеевропско време (Бисинген)',
        'Europe/Chisinau' => 'Источноевропско време (Кишињев)',
        'Europe/Copenhagen' => 'Средњеевропско време (Копенхаген)',
        'Europe/Dublin' => 'Средње време по Гриничу (Даблин)',
        'Europe/Gibraltar' => 'Средњеевропско време (Гибралтар)',
        'Europe/Guernsey' => 'Средње време по Гриничу (Гернзи)',
        'Europe/Helsinki' => 'Источноевропско време (Хелсинки)',
        'Europe/Isle_of_Man' => 'Средње време по Гриничу (Острво Ман)',
        'Europe/Istanbul' => 'Турска (Истанбул)',
        'Europe/Jersey' => 'Средње време по Гриничу (Џерзи)',
        'Europe/Kaliningrad' => 'Источноевропско време (Калињинград)',
        'Europe/Kiev' => 'Источноевропско време (Кијев)',
        'Europe/Kirov' => 'Русија (Киров)',
        'Europe/Lisbon' => 'Западноевропско време (Лисабон)',
        'Europe/Ljubljana' => 'Средњеевропско време (Љубљана)',
        'Europe/London' => 'Средње време по Гриничу (Лондон)',
        'Europe/Luxembourg' => 'Средњеевропско време (Луксембург)',
        'Europe/Madrid' => 'Средњеевропско време (Мадрид)',
        'Europe/Malta' => 'Средњеевропско време (Малта)',
        'Europe/Mariehamn' => 'Источноевропско време (Марихамн)',
        'Europe/Minsk' => 'Москва време (Минск)',
        'Europe/Monaco' => 'Средњеевропско време (Монако)',
        'Europe/Moscow' => 'Москва време',
        'Europe/Oslo' => 'Средњеевропско време (Осло)',
        'Europe/Paris' => 'Средњеевропско време (Париз)',
        'Europe/Podgorica' => 'Средњеевропско време (Подгорица)',
        'Europe/Prague' => 'Средњеевропско време (Праг)',
        'Europe/Riga' => 'Источноевропско време (Рига)',
        'Europe/Rome' => 'Средњеевропско време (Рим)',
        'Europe/Samara' => 'Самара време',
        'Europe/San_Marino' => 'Средњеевропско време (Сан Марино)',
        'Europe/Sarajevo' => 'Средњеевропско време (Сарајево)',
        'Europe/Saratov' => 'Москва време (Саратов)',
        'Europe/Simferopol' => 'Москва време (Симферопољ)',
        'Europe/Skopje' => 'Средњеевропско време (Скопље)',
        'Europe/Sofia' => 'Источноевропско време (Софија)',
        'Europe/Stockholm' => 'Средњеевропско време (Стокхолм)',
        'Europe/Tallinn' => 'Источноевропско време (Талин)',
        'Europe/Tirane' => 'Средњеевропско време (Тирана)',
        'Europe/Ulyanovsk' => 'Москва време (Уљановск)',
        'Europe/Uzhgorod' => 'Источноевропско време (Ужгород)',
        'Europe/Vaduz' => 'Средњеевропско време (Вадуз)',
        'Europe/Vatican' => 'Средњеевропско време (Ватикан)',
        'Europe/Vienna' => 'Средњеевропско време (Беч)',
        'Europe/Vilnius' => 'Источноевропско време (Вилњус)',
        'Europe/Volgograd' => 'Волгоград време',
        'Europe/Warsaw' => 'Средњеевропско време (Варшава)',
        'Europe/Zagreb' => 'Средњеевропско време (Загреб)',
        'Europe/Zaporozhye' => 'Источноевропско време (Запорожје)',
        'Europe/Zurich' => 'Средњеевропско време (Цирих)',
        'Indian/Antananarivo' => 'Источно-афричко време (Антананариво)',
        'Indian/Chagos' => 'Индијско океанско време (Чагос)',
        'Indian/Christmas' => 'Божићно острво време',
        'Indian/Cocos' => 'Кокос (Келинг) Острва време',
        'Indian/Comoro' => 'Источно-афричко време (Коморо)',
        'Indian/Kerguelen' => 'Француско јужно и антарктичко време (Кергелен)',
        'Indian/Mahe' => 'Сејшели време (Махе)',
        'Indian/Maldives' => 'Малдиви време',
        'Indian/Mauritius' => 'Маурицијус време',
        'Indian/Mayotte' => 'Источно-афричко време (Мајот)',
        'Indian/Reunion' => 'Реинион време (Реунион)',
        'MST7MDT' => 'Северноамеричко планинско време',
        'PST8PDT' => 'Северноамеричко пацифичко време',
        'Pacific/Apia' => 'Апија време',
        'Pacific/Auckland' => 'Нови Зеланд време (Окланд)',
        'Pacific/Bougainville' => 'Папуа Нова Гвинеја време (Буганвил)',
        'Pacific/Chatham' => 'Чатам време',
        'Pacific/Easter' => 'Ускршња острва време (Ускршње острво)',
        'Pacific/Efate' => 'Вануату време (Ефат)',
        'Pacific/Enderbury' => 'Феникс острва време (Ендербери)',
        'Pacific/Fakaofo' => 'Токелау време (Факаофо)',
        'Pacific/Fiji' => 'Фиџи време',
        'Pacific/Funafuti' => 'Тувалу време (Фунафути)',
        'Pacific/Galapagos' => 'Галапагос време',
        'Pacific/Gambier' => 'Гамбије време',
        'Pacific/Guadalcanal' => 'Соломонска Острва време (Гвадалканал)',
        'Pacific/Guam' => 'Чаморо време (Гуам)',
        'Pacific/Honolulu' => 'Хавајско-алеутско време (Хонолулу)',
        'Pacific/Johnston' => 'Хавајско-алеутско време (Џонстон)',
        'Pacific/Kiritimati' => 'Острва Лајн време (Киритимати)',
        'Pacific/Kosrae' => 'Кошре време',
        'Pacific/Kwajalein' => 'Маршалска Острва време (Кваџалејин)',
        'Pacific/Majuro' => 'Маршалска Острва време (Мајуро)',
        'Pacific/Marquesas' => 'Маркиз време',
        'Pacific/Midway' => 'Самоа време (Мидвеј)',
        'Pacific/Nauru' => 'Науру време',
        'Pacific/Niue' => 'Ниуе време',
        'Pacific/Norfolk' => 'Норфолк Острво време',
        'Pacific/Noumea' => 'Нова Каледонија време (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа време (Паго Паго)',
        'Pacific/Palau' => 'Палау време',
        'Pacific/Pitcairn' => 'Питкерн време',
        'Pacific/Ponape' => 'Понпеј време (Понапе)',
        'Pacific/Port_Moresby' => 'Папуа Нова Гвинеја време (Порт Морзби)',
        'Pacific/Rarotonga' => 'Кукова острва време (Раротонга)',
        'Pacific/Saipan' => 'Чаморо време (Сајпан)',
        'Pacific/Tahiti' => 'Тахити време',
        'Pacific/Tarawa' => 'Гилберт острва време (Тарава)',
        'Pacific/Tongatapu' => 'Тонга време (Тонгатапу)',
        'Pacific/Truk' => 'Чуук време (Трук)',
        'Pacific/Wake' => 'Вејк острво време',
        'Pacific/Wallis' => 'Валис и Футуна Острва време',
    ],
    'Meta' => [
    ],
];
