<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Андорска Пезета',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Дирхам на Обединети Арапски Емирати',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Авгани (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Авганистански авгани',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Албански лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Ерменски драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Холандски антилски гилдер',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Анголска кванза',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Анголска Кванза (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Анголска нова Кванза (1990–2000)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Аргентински Пезос (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Аргентински пезос',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Австралиски Шилинг',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'Австралиски долар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Арубиски флорин',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Азербејџански манат',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Босанско-Херцеговски Динар',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Босанско-херцеговска конвертибилна марка',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Барбадоски долар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Бангладешка така',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Белгиски Франк (конвертибилен)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Белгиски Франк',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Белгиски Франк (финансиски)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Бугарски цврст лев',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Бугарски лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Бахреински динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Бурундиски франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Бермудски долар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Брунејски долар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Боливиски боливиано',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Бразилски реал',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Бахамски долар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Бутански нгултрум',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Боцванска пула',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Белоруска нова рубља (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Белоруска рубља',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Белоруска рубља (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Белизиски долар',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Канадски долар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Конголски франк',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Швајцарски франк',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Чилеански пезос',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Кинески јуан (офшор)',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Кинески јуан',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Колумбиски пезос',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Костарикански колон',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Чехословачка цврста корона',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Кубански конвертибилен пезос',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Кубански пезос',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Зелено’ртски ескудо',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Кипарска фунта',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Чешка круна',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Германска Марка',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Џибутски франк',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Данска круна',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Доминикански пезос',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Алжирски динар',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Египетска фунта',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Еритрејска накфа',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Шпанска Пезета',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Етиописки бир',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Евро',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Финска марка',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Фиџиски долар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Фолкландска фунта',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Француски франк',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'Британска фунта',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Грузиски лари',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ганајски Седи',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Гански седи',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Гибралтарска фунта',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Гамбиски даласи',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Гвинејски франк',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Грчка драхма',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Гватемалски кветцал',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Гвинејски Бисау пезос',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Гвајански долар',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Хонгконшки долар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Хондурска лемпира',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Хрватски динар',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Хрватска куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Хаитски гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Унгарска форинта',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Индонезиска рупија',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Ирска фунта',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Изрелска фунта',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Израелски нов шекел',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Индиска рупија',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Ирачки динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Ирански риал',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Исландска крона',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Италијанска лира',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Јамајкански долар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Јордански динар',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'Јапонски јен',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Кениски шилинг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Киргистански сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Камбоџиски рел',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Коморски франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Северно корејски вон',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'Јужно корејски вон',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Кувајтски динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Кајмански долар',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Казахстанска тенга',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Лаоски кип',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Либанска фунта',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Шриланканска рупија',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Либериски долар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Лесотско лоти',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Литваниска лита',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Литваниски литаз',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Луксембуршки франк',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Латвијски лат',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Латвијска рубља',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Либијски динар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Марокански дирхам',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Марокански франк',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Молдавски леу',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Малагасиски ариари',
        ],
        'MKD' => [
            0 => 'ден.',
            1 => 'Македонски денар',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Малски франк',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Мјанмарски киат',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Монголиски тугрик',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Макао патака',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Мавританска угија (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Мавританска угија',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Малтешка лира',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Малтешка фунта',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Мавританска рупија',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Малдивска руфија',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Малависка квача',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Мексикански пезос',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Мексикански сребрен пезос (1861–1992)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Малезиски рингит',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Мозамбиско ескудо',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Стар мозамбиски метикал',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Мозамбиски метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Намибиски долар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Нигериска наира',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Никарагванска кордоба (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Никарагванска кордоба',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Холандски гилдер',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Норвешка круна',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Непалска рупија',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'Новозеландски долар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Омански риал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Панамска балбоа',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Перуански сол',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Перуански сол (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Папуа новогвинејска кина',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Филипински пезос',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Пакистанска рупија',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Полска злота',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Полска злота (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Португалско ескудо',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Парагвајска гуарана',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Катарски риал',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Романска леи (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Романски леу',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Српски динар',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Руска рубља',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Руска рубља (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Руандски франк',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Саудиски ријал',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Соломонски долар',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Сејшелска рупија',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Стар судански динар',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Суданска фунта',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Стара суданска фунта',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Шведска круна',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Сингапурски долар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Фунта на Света Елена',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Словенечки толар',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Словачка круна',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Сиералеонско леоне',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Сомалијски шилинг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Суринамски долар',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Суринамски гилдер',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Јужносуданска фунта',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Добра на Саун Томе и Принсип (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Добра на Сао Томе и Принсипе',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Советска рубља',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Салвадорски колон',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Сиријска фунта',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Свазилендски лиланген',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Таи бат',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Таџикистанска рубља',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Таџикистански сомони',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Туркменистански манат',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Туркменист. манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Тунизиски динар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Тонганска панга',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Тиморски ескудо',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Турска лира (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Турска лира',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Долар на Тринидад и Тобаго',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'Тајвански нов долар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Танзаниски шилинг',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Украинска хривнија',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Угандиски шилинг (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Угандиски шилинг',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Американски долар',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'САД долар (Next day)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'САД долар (Same day)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Уругвајски пезос (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Уругвајски пезос',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Узбекистански сом',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Венецуелски боливар (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Венецуелски боливар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Венецуелски боливар',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'Виетнамски донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Ванатски вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Самоанска тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Централноафрикански франк',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Источнокарипски долар',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Западноафрикански франк',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'ЦФП франк',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Јеменски динар',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Јеменски риал',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Југословенски динар',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Југословенски конвертибилен динар',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Јужно афрички ранд(финансиски)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Јужноафрикански ранд',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Замбијска квача (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Замбијска квача',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Заирско новозаире',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Заирско заире',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Зимбабвиски долар',
        ],
    ],
];
