<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Qrinviç Orta Vaxtı (Abican)',
        'Africa/Accra' => 'Qrinviç Orta Vaxtı (Akkra)',
        'Africa/Addis_Ababa' => 'Şərqi Afrika Vaxtı (Əddis Əbəbə)',
        'Africa/Algiers' => 'Mərkəzi Avropa Vaxtı (Əlcəzair)',
        'Africa/Asmera' => 'Şərqi Afrika Vaxtı (Əsmərə)',
        'Africa/Bamako' => 'Qrinviç Orta Vaxtı (Bamako)',
        'Africa/Bangui' => 'Qərbi Afrika Vaxtı (Banqui)',
        'Africa/Banjul' => 'Qrinviç Orta Vaxtı (Bancul)',
        'Africa/Bissau' => 'Qrinviç Orta Vaxtı (Bissau)',
        'Africa/Blantyre' => 'Mərkəzi Afrika Vaxtı (Blantir)',
        'Africa/Brazzaville' => 'Qərbi Afrika Vaxtı (Brazzavil)',
        'Africa/Bujumbura' => 'Mərkəzi Afrika Vaxtı (Bujumbura)',
        'Africa/Cairo' => 'Şərqi Avropa Vaxtı (Qahirə)',
        'Africa/Casablanca' => 'Qərbi Avropa Vaxtı (Kasablanka)',
        'Africa/Ceuta' => 'Mərkəzi Avropa Vaxtı (Seuta)',
        'Africa/Conakry' => 'Qrinviç Orta Vaxtı (Konakri)',
        'Africa/Dakar' => 'Qrinviç Orta Vaxtı (Dakar)',
        'Africa/Dar_es_Salaam' => 'Şərqi Afrika Vaxtı (Dar es Salam)',
        'Africa/Djibouti' => 'Şərqi Afrika Vaxtı (Cibuti)',
        'Africa/Douala' => 'Qərbi Afrika Vaxtı (Duala)',
        'Africa/El_Aaiun' => 'Qərbi Avropa Vaxtı (Əl Əyun)',
        'Africa/Freetown' => 'Qrinviç Orta Vaxtı (Fritaun)',
        'Africa/Gaborone' => 'Mərkəzi Afrika Vaxtı (Qaboron)',
        'Africa/Harare' => 'Mərkəzi Afrika Vaxtı (Harare)',
        'Africa/Johannesburg' => 'Cənubi Afrika Vaxtı (Yohanesburq)',
        'Africa/Juba' => 'Mərkəzi Afrika Vaxtı (Juba)',
        'Africa/Kampala' => 'Şərqi Afrika Vaxtı (Kampala)',
        'Africa/Khartoum' => 'Mərkəzi Afrika Vaxtı (Xartum)',
        'Africa/Kigali' => 'Mərkəzi Afrika Vaxtı (Kiqali)',
        'Africa/Kinshasa' => 'Qərbi Afrika Vaxtı (Kinşasa)',
        'Africa/Lagos' => 'Qərbi Afrika Vaxtı (Laqos)',
        'Africa/Libreville' => 'Qərbi Afrika Vaxtı (Librevil)',
        'Africa/Lome' => 'Qrinviç Orta Vaxtı (Lome)',
        'Africa/Luanda' => 'Qərbi Afrika Vaxtı (Luanda)',
        'Africa/Lubumbashi' => 'Mərkəzi Afrika Vaxtı (Lubumbaşi)',
        'Africa/Lusaka' => 'Mərkəzi Afrika Vaxtı (Lusaka)',
        'Africa/Malabo' => 'Qərbi Afrika Vaxtı (Malabo)',
        'Africa/Maputo' => 'Mərkəzi Afrika Vaxtı (Maputo)',
        'Africa/Maseru' => 'Cənubi Afrika Vaxtı (Maseru)',
        'Africa/Mbabane' => 'Cənubi Afrika Vaxtı (Mbabane)',
        'Africa/Mogadishu' => 'Şərqi Afrika Vaxtı (Moqadişu)',
        'Africa/Monrovia' => 'Qrinviç Orta Vaxtı (Monrovia)',
        'Africa/Nairobi' => 'Şərqi Afrika Vaxtı (Nairobi)',
        'Africa/Ndjamena' => 'Qərbi Afrika Vaxtı (Ncamena)',
        'Africa/Niamey' => 'Qərbi Afrika Vaxtı (Niamey)',
        'Africa/Nouakchott' => 'Qrinviç Orta Vaxtı (Nouakşot)',
        'Africa/Ouagadougou' => 'Qrinviç Orta Vaxtı (Uqaduqu)',
        'Africa/Porto-Novo' => 'Qərbi Afrika Vaxtı (Porto-Novo)',
        'Africa/Sao_Tome' => 'Qrinviç Orta Vaxtı (San Tom)',
        'Africa/Tripoli' => 'Şərqi Avropa Vaxtı (Tripoli)',
        'Africa/Tunis' => 'Mərkəzi Avropa Vaxtı (Tunis)',
        'Africa/Windhoek' => 'Mərkəzi Afrika Vaxtı (Vindhuk)',
        'America/Adak' => 'Havay-Aleut Vaxtı (Adak)',
        'America/Anchorage' => 'Alyaska Vaxtı (Ankorac)',
        'America/Anguilla' => 'Atlantik Vaxt (Angilya)',
        'America/Antigua' => 'Atlantik Vaxt (Antiqua)',
        'America/Araguaina' => 'Braziliya Vaxtı (Araguayna)',
        'America/Argentina/La_Rioja' => 'Argentina Vaxtı (Rioxa)',
        'America/Argentina/Rio_Gallegos' => 'Argentina Vaxtı (Rio Qalyeqos)',
        'America/Argentina/Salta' => 'Argentina Vaxtı (Salta)',
        'America/Argentina/San_Juan' => 'Argentina Vaxtı (San Xuan)',
        'America/Argentina/San_Luis' => 'Argentina Vaxtı (San Luis)',
        'America/Argentina/Tucuman' => 'Argentina Vaxtı (Tukuman)',
        'America/Argentina/Ushuaia' => 'Argentina Vaxtı (Uşuaya)',
        'America/Aruba' => 'Atlantik Vaxt (Aruba)',
        'America/Asuncion' => 'Paraqvay Vaxtı (Asunsion)',
        'America/Bahia' => 'Braziliya Vaxtı (Bahiya)',
        'America/Bahia_Banderas' => 'Şimali Mərkəzi Amerika Vaxtı (Bahia Banderas)',
        'America/Barbados' => 'Atlantik Vaxt (Barbados)',
        'America/Belem' => 'Braziliya Vaxtı (Belem)',
        'America/Belize' => 'Şimali Mərkəzi Amerika Vaxtı (Beliz)',
        'America/Blanc-Sablon' => 'Atlantik Vaxt (Blank-Sablon)',
        'America/Boa_Vista' => 'Amazon Vaxtı (Boa Vista)',
        'America/Bogota' => 'Kolumbiya Vaxtı (Boqota)',
        'America/Boise' => 'Şimali Dağlıq Amerika Vaxtı (Boyse)',
        'America/Buenos_Aires' => 'Argentina Vaxtı (Buenos Ayres)',
        'America/Cambridge_Bay' => 'Şimali Dağlıq Amerika Vaxtı (Kembric Körfəzi)',
        'America/Campo_Grande' => 'Amazon Vaxtı (Kampo Qrande)',
        'America/Cancun' => 'Şimali Şərqi Amerika Vaxtı (Kankun)',
        'America/Caracas' => 'Venesuela Vaxtı (Karakas)',
        'America/Catamarca' => 'Argentina Vaxtı (Katamarka)',
        'America/Cayenne' => 'Fransız Qvianası Vaxtı (Kayen)',
        'America/Cayman' => 'Şimali Şərqi Amerika Vaxtı (Kayman)',
        'America/Chicago' => 'Şimali Mərkəzi Amerika Vaxtı (Çikaqo)',
        'America/Chihuahua' => 'Meksika Sakit Okean Vaxtı (Çihuahua)',
        'America/Coral_Harbour' => 'Şimali Şərqi Amerika Vaxtı (Atikokan)',
        'America/Cordoba' => 'Argentina Vaxtı (Kordoba)',
        'America/Costa_Rica' => 'Şimali Mərkəzi Amerika Vaxtı (Kosta Rika)',
        'America/Creston' => 'Şimali Dağlıq Amerika Vaxtı (Kreston)',
        'America/Cuiaba' => 'Amazon Vaxtı (Kuyaba)',
        'America/Curacao' => 'Atlantik Vaxt (Kurasao)',
        'America/Danmarkshavn' => 'Qrinviç Orta Vaxtı (Danmarkşavn)',
        'America/Dawson' => 'Yukon Vaxtı (Douson)',
        'America/Dawson_Creek' => 'Şimali Dağlıq Amerika Vaxtı (Douson Krik)',
        'America/Denver' => 'Şimali Dağlıq Amerika Vaxtı (Denver)',
        'America/Detroit' => 'Şimali Şərqi Amerika Vaxtı (Detroyt)',
        'America/Dominica' => 'Atlantik Vaxt (Dominika)',
        'America/Edmonton' => 'Şimali Dağlıq Amerika Vaxtı (Edmondton)',
        'America/Eirunepe' => 'Braziliya Vaxtı (İrunepe)',
        'America/El_Salvador' => 'Şimali Mərkəzi Amerika Vaxtı (Salvador)',
        'America/Fort_Nelson' => 'Şimali Dağlıq Amerika Vaxtı (Fort Nelson)',
        'America/Fortaleza' => 'Braziliya Vaxtı (Fortaleza)',
        'America/Glace_Bay' => 'Atlantik Vaxt (Qleys Körfəzi)',
        'America/Godthab' => 'Qərbi Qrenlandiya Vaxtı (Nuuk)',
        'America/Goose_Bay' => 'Atlantik Vaxt (Quz Körfəzi)',
        'America/Grand_Turk' => 'Şimali Şərqi Amerika Vaxtı (Qrand Turk)',
        'America/Grenada' => 'Atlantik Vaxt (Qrenada)',
        'America/Guadeloupe' => 'Atlantik Vaxt (Qvadelupa)',
        'America/Guatemala' => 'Şimali Mərkəzi Amerika Vaxtı (Qvatemala)',
        'America/Guayaquil' => 'Ekvador Vaxtı (Quayakil)',
        'America/Guyana' => 'Qayana Vaxtı',
        'America/Halifax' => 'Atlantik Vaxt (Halifaks)',
        'America/Havana' => 'Kuba Vaxtı (Havana)',
        'America/Hermosillo' => 'Meksika Sakit Okean Vaxtı (Hermosilo)',
        'America/Indiana/Knox' => 'Şimali Mərkəzi Amerika Vaxtı (Noks)',
        'America/Indiana/Marengo' => 'Şimali Şərqi Amerika Vaxtı (Marenqo)',
        'America/Indiana/Petersburg' => 'Şimali Şərqi Amerika Vaxtı (Pitersburq)',
        'America/Indiana/Tell_City' => 'Şimali Mərkəzi Amerika Vaxtı (Tell)',
        'America/Indiana/Vevay' => 'Şimali Şərqi Amerika Vaxtı (Vivey)',
        'America/Indiana/Vincennes' => 'Şimali Şərqi Amerika Vaxtı (Vinsen)',
        'America/Indiana/Winamac' => 'Şimali Şərqi Amerika Vaxtı (Vinamak)',
        'America/Indianapolis' => 'Şimali Şərqi Amerika Vaxtı (İndianapolis)',
        'America/Inuvik' => 'Şimali Dağlıq Amerika Vaxtı (İnuvik)',
        'America/Iqaluit' => 'Şimali Şərqi Amerika Vaxtı (İqaluit)',
        'America/Jamaica' => 'Şimali Şərqi Amerika Vaxtı (Yamayka)',
        'America/Jujuy' => 'Argentina Vaxtı (Jujuy)',
        'America/Juneau' => 'Alyaska Vaxtı (Cuno)',
        'America/Kentucky/Monticello' => 'Şimali Şərqi Amerika Vaxtı (Montiçello)',
        'America/Kralendijk' => 'Atlantik Vaxt (Kralendik)',
        'America/La_Paz' => 'Boliviya Vaxtı (La Pas)',
        'America/Lima' => 'Peru Vaxtı (Lima)',
        'America/Los_Angeles' => 'Şimali Amerika Sakit Okean Vaxtı (Los Anceles)',
        'America/Louisville' => 'Şimali Şərqi Amerika Vaxtı (Luisvil)',
        'America/Lower_Princes' => 'Atlantik Vaxt (Aşağı Prins Kvartalı)',
        'America/Maceio' => 'Braziliya Vaxtı (Maseyo)',
        'America/Managua' => 'Şimali Mərkəzi Amerika Vaxtı (Manaqua)',
        'America/Manaus' => 'Amazon Vaxtı (Manaus)',
        'America/Marigot' => 'Atlantik Vaxt (Mariqot)',
        'America/Martinique' => 'Atlantik Vaxt (Martinik)',
        'America/Matamoros' => 'Şimali Mərkəzi Amerika Vaxtı (Matamoros)',
        'America/Mazatlan' => 'Meksika Sakit Okean Vaxtı (Mazaltan)',
        'America/Mendoza' => 'Argentina Vaxtı (Mendoza)',
        'America/Menominee' => 'Şimali Mərkəzi Amerika Vaxtı (Menomini)',
        'America/Merida' => 'Şimali Mərkəzi Amerika Vaxtı (Merida)',
        'America/Metlakatla' => 'Alyaska Vaxtı (Metlakatla)',
        'America/Mexico_City' => 'Şimali Mərkəzi Amerika Vaxtı (Mexiko)',
        'America/Miquelon' => 'Müqəddəs Pyer və Mikelon Vaxtı',
        'America/Moncton' => 'Atlantik Vaxt (Monkton)',
        'America/Monterrey' => 'Şimali Mərkəzi Amerika Vaxtı (Monterey)',
        'America/Montevideo' => 'Uruqvay Vaxtı (Montevideo)',
        'America/Montreal' => 'Kanada Vaxtı (Montreal)',
        'America/Montserrat' => 'Atlantik Vaxt (Monserat)',
        'America/Nassau' => 'Şimali Şərqi Amerika Vaxtı (Nassau)',
        'America/New_York' => 'Şimali Şərqi Amerika Vaxtı (Nyu York)',
        'America/Nipigon' => 'Şimali Şərqi Amerika Vaxtı (Nipiqon)',
        'America/Nome' => 'Alyaska Vaxtı (Nom)',
        'America/Noronha' => 'Fernando de Noronya Vaxtı',
        'America/North_Dakota/Beulah' => 'Şimali Mərkəzi Amerika Vaxtı (Beulah, Şimali Dakota)',
        'America/North_Dakota/Center' => 'Şimali Mərkəzi Amerika Vaxtı (Mərkəz, Şimal Dakota)',
        'America/North_Dakota/New_Salem' => 'Şimali Mərkəzi Amerika Vaxtı (Nyu Salem)',
        'America/Ojinaga' => 'Şimali Dağlıq Amerika Vaxtı (Ocinaqa)',
        'America/Panama' => 'Şimali Şərqi Amerika Vaxtı (Panama)',
        'America/Pangnirtung' => 'Şimali Şərqi Amerika Vaxtı (Panqnirtanq)',
        'America/Paramaribo' => 'Surinam Vaxtı (Paramaribo)',
        'America/Phoenix' => 'Şimali Dağlıq Amerika Vaxtı (Feniks)',
        'America/Port-au-Prince' => 'Şimali Şərqi Amerika Vaxtı (Port-o-Prins)',
        'America/Port_of_Spain' => 'Atlantik Vaxt (İspan Limanı)',
        'America/Porto_Velho' => 'Amazon Vaxtı (Porto Velyo)',
        'America/Puerto_Rico' => 'Atlantik Vaxt (Puerto Riko)',
        'America/Punta_Arenas' => 'Çili Vaxtı (Punta Arenas)',
        'America/Rainy_River' => 'Şimali Mərkəzi Amerika Vaxtı (Reyni Çayı)',
        'America/Rankin_Inlet' => 'Şimali Mərkəzi Amerika Vaxtı (Rankin Girişi)',
        'America/Recife' => 'Braziliya Vaxtı (Resif)',
        'America/Regina' => 'Şimali Mərkəzi Amerika Vaxtı (Recina)',
        'America/Resolute' => 'Şimali Mərkəzi Amerika Vaxtı (Rezolyut)',
        'America/Rio_Branco' => 'Braziliya Vaxtı (Rio Branko)',
        'America/Santa_Isabel' => 'Şimal-Qərbi Meksika Vaxtı (Santa İzabel)',
        'America/Santarem' => 'Braziliya Vaxtı (Santarem)',
        'America/Santiago' => 'Çili Vaxtı (Santyaqo)',
        'America/Santo_Domingo' => 'Atlantik Vaxt (Santo Dominqo)',
        'America/Sao_Paulo' => 'Braziliya Vaxtı (San Paulo)',
        'America/Scoresbysund' => 'Şərqi Qrenlandiya Vaxtı (Skoresbisund)',
        'America/Sitka' => 'Alyaska Vaxtı (Sitka)',
        'America/St_Barthelemy' => 'Atlantik Vaxt (Sent-Bartelemi)',
        'America/St_Johns' => 'Nyufaundlend Vaxtı (Sent Cons)',
        'America/St_Kitts' => 'Atlantik Vaxt (San Kits)',
        'America/St_Lucia' => 'Atlantik Vaxt (San Lüsiya)',
        'America/St_Thomas' => 'Atlantik Vaxt (San Tomas)',
        'America/St_Vincent' => 'Atlantik Vaxt (San Vinsent)',
        'America/Swift_Current' => 'Şimali Mərkəzi Amerika Vaxtı (Svift Kurent)',
        'America/Tegucigalpa' => 'Şimali Mərkəzi Amerika Vaxtı (Tequsiqalpa)',
        'America/Thule' => 'Atlantik Vaxt (Tul)',
        'America/Thunder_Bay' => 'Şimali Şərqi Amerika Vaxtı (İldırım Körfəzi)',
        'America/Tijuana' => 'Şimali Amerika Sakit Okean Vaxtı (Tixuana)',
        'America/Toronto' => 'Şimali Şərqi Amerika Vaxtı (Toronto)',
        'America/Tortola' => 'Atlantik Vaxt (Tortola)',
        'America/Vancouver' => 'Şimali Amerika Sakit Okean Vaxtı (Vankuver)',
        'America/Whitehorse' => 'Yukon Vaxtı (Uaythors)',
        'America/Winnipeg' => 'Şimali Mərkəzi Amerika Vaxtı (Vinnipeq)',
        'America/Yakutat' => 'Alyaska Vaxtı (Yakutat)',
        'America/Yellowknife' => 'Şimali Dağlıq Amerika Vaxtı (Yellounayf)',
        'Antarctica/Casey' => 'Antarktika Vaxtı (Keysi)',
        'Antarctica/Davis' => 'Devis Vaxtı (Deyvis)',
        'Antarctica/DumontDUrville' => 'Dümon-d’Ürvil Vaxtı (Dumont d’Urvil)',
        'Antarctica/Macquarie' => 'Şərqi Avstraliya Vaxtı (Makuari)',
        'Antarctica/Mawson' => 'Mouson Vaxtı',
        'Antarctica/McMurdo' => 'Yeni Zelandiya Vaxtı (Mak Murdo)',
        'Antarctica/Palmer' => 'Çili Vaxtı (Palmer)',
        'Antarctica/Rothera' => 'Rotera Vaxtı (Rothera)',
        'Antarctica/Syowa' => 'Syova Vaxtı',
        'Antarctica/Troll' => 'Qrinviç Orta Vaxtı (Troll)',
        'Antarctica/Vostok' => 'Vostok Vaxtı',
        'Arctic/Longyearbyen' => 'Mərkəzi Avropa Vaxtı (Lonqyir)',
        'Asia/Aden' => 'Ərəbistan Vaxtı (Aden)',
        'Asia/Almaty' => 'Şərqi Qazaxıstan Vaxtı (Almatı)',
        'Asia/Amman' => 'Şərqi Avropa Vaxtı (Amman)',
        'Asia/Anadyr' => 'Rusiya Vaxtı (Anadır)',
        'Asia/Aqtau' => 'Qərbi Qazaxıstan Vaxtı (Aktau)',
        'Asia/Aqtobe' => 'Qərbi Qazaxıstan Vaxtı (Aqtobe)',
        'Asia/Ashgabat' => 'Türkmənistan Vaxtı (Aşqabat)',
        'Asia/Atyrau' => 'Qərbi Qazaxıstan Vaxtı (Atırau)',
        'Asia/Baghdad' => 'Ərəbistan Vaxtı (Bağdad)',
        'Asia/Bahrain' => 'Ərəbistan Vaxtı (Bəhreyn)',
        'Asia/Baku' => 'Azərbaycan Vaxtı (Bakı)',
        'Asia/Bangkok' => 'Hindçin Vaxtı (Banqkok)',
        'Asia/Barnaul' => 'Rusiya Vaxtı (Barnaul)',
        'Asia/Beirut' => 'Şərqi Avropa Vaxtı (Beyrut)',
        'Asia/Bishkek' => 'Qırğızıstan Vaxtı (Bişkek)',
        'Asia/Brunei' => 'Brunei Darussalam vaxtı (Bruney)',
        'Asia/Calcutta' => 'Hindistan Vaxtı (Kəlkətə)',
        'Asia/Chita' => 'Yakutsk Vaxtı (Çita)',
        'Asia/Choibalsan' => 'Ulanbator Vaxtı (Çoybalsan)',
        'Asia/Colombo' => 'Hindistan Vaxtı (Kolombo)',
        'Asia/Damascus' => 'Şərqi Avropa Vaxtı (Dəməşq)',
        'Asia/Dhaka' => 'Banqladeş Vaxtı (Dəkkə)',
        'Asia/Dili' => 'Şərqi Timor Vaxtı (Dili)',
        'Asia/Dubai' => 'Körfəz Vaxtı (Dubay)',
        'Asia/Dushanbe' => 'Tacikistan Vaxtı (Düşənbə)',
        'Asia/Famagusta' => 'Şərqi Avropa Vaxtı (Famaqusta)',
        'Asia/Gaza' => 'Şərqi Avropa Vaxtı (Qəza)',
        'Asia/Hebron' => 'Şərqi Avropa Vaxtı (Hebron)',
        'Asia/Hong_Kong' => 'Honq Konq Vaxtı',
        'Asia/Hovd' => 'Hovd Vaxtı',
        'Asia/Irkutsk' => 'İrkutsk Vaxtı',
        'Asia/Jakarta' => 'Qərbi İndoneziya Vaxtı (Cakarta)',
        'Asia/Jayapura' => 'Şərqi İndoneziya Vaxtı (Cayapura)',
        'Asia/Jerusalem' => 'İsrail Vaxtı (Yerusəlim)',
        'Asia/Kabul' => 'Əfqanıstan Vaxtı (Kabil)',
        'Asia/Kamchatka' => 'Rusiya Vaxtı (Kamçatka)',
        'Asia/Karachi' => 'Pakistan Vaxtı (Karaçi)',
        'Asia/Katmandu' => 'Nepal vaxtı (Katmandu)',
        'Asia/Khandyga' => 'Yakutsk Vaxtı (Xandıqa)',
        'Asia/Krasnoyarsk' => 'Krasnoyarsk Vaxtı',
        'Asia/Kuala_Lumpur' => 'Malayziya Vaxtı (Kuala Lumpur)',
        'Asia/Kuching' => 'Malayziya Vaxtı (Kuçinq)',
        'Asia/Kuwait' => 'Ərəbistan Vaxtı (Küveyt)',
        'Asia/Macau' => 'Çin Vaxtı (Makao)',
        'Asia/Magadan' => 'Maqadan Vaxtı',
        'Asia/Makassar' => 'Mərkəzi İndoneziya Vaxtı (Makasar)',
        'Asia/Manila' => 'Filippin Vaxtı (Manila)',
        'Asia/Muscat' => 'Körfəz Vaxtı (Muskat)',
        'Asia/Nicosia' => 'Şərqi Avropa Vaxtı (Nikosiya)',
        'Asia/Novokuznetsk' => 'Krasnoyarsk Vaxtı (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Novosibirsk Vaxtı',
        'Asia/Omsk' => 'Omsk Vaxtı',
        'Asia/Oral' => 'Qərbi Qazaxıstan Vaxtı (Oral)',
        'Asia/Phnom_Penh' => 'Hindçin Vaxtı (Pnom Pen)',
        'Asia/Pontianak' => 'Qərbi İndoneziya Vaxtı (Pontianak)',
        'Asia/Pyongyang' => 'Koreya Vaxtı (Pxenyan)',
        'Asia/Qatar' => 'Ərəbistan Vaxtı (Qatar)',
        'Asia/Qostanay' => 'Şərqi Qazaxıstan Vaxtı (Qostanay)',
        'Asia/Qyzylorda' => 'Qərbi Qazaxıstan Vaxtı (Qızılorda)',
        'Asia/Rangoon' => 'Myanma Vaxtı (Ranqun)',
        'Asia/Riyadh' => 'Ərəbistan Vaxtı (Riyad)',
        'Asia/Saigon' => 'Hindçin Vaxtı (Ho Şi Min)',
        'Asia/Sakhalin' => 'Saxalin Vaxtı',
        'Asia/Samarkand' => 'Özbəkistan Vaxtı (Səmərqənd)',
        'Asia/Seoul' => 'Koreya Vaxtı (Seul)',
        'Asia/Shanghai' => 'Çin Vaxtı (Şanxay)',
        'Asia/Singapore' => 'Sinqapur Vaxtı',
        'Asia/Srednekolymsk' => 'Maqadan Vaxtı (Srednekolımsk)',
        'Asia/Taipei' => 'Taybey Vaxtı',
        'Asia/Tashkent' => 'Özbəkistan Vaxtı (Daşkənd)',
        'Asia/Tbilisi' => 'Gurcüstan Vaxtı (Tbilisi)',
        'Asia/Tehran' => 'İran Vaxtı (Tehran)',
        'Asia/Thimphu' => 'Butan Vaxtı (Thimphu)',
        'Asia/Tokyo' => 'Yaponiya Vaxtı (Tokyo)',
        'Asia/Tomsk' => 'Rusiya Vaxtı (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulanbator Vaxtı',
        'Asia/Urumqi' => 'Çin Vaxtı (Urumçi)',
        'Asia/Ust-Nera' => 'Vladivostok Vaxtı (Ust-Nera)',
        'Asia/Vientiane' => 'Hindçin Vaxtı (Vyentyan)',
        'Asia/Vladivostok' => 'Vladivostok Vaxtı',
        'Asia/Yakutsk' => 'Yakutsk Vaxtı',
        'Asia/Yekaterinburg' => 'Yekaterinburq Vaxtı',
        'Asia/Yerevan' => 'Ermənistan Vaxtı (Yerevan)',
        'Atlantic/Azores' => 'Azor Vaxtı',
        'Atlantic/Bermuda' => 'Atlantik Vaxt (Bermud adaları)',
        'Atlantic/Canary' => 'Qərbi Avropa Vaxtı (Kanar)',
        'Atlantic/Cape_Verde' => 'Kape Verde Vaxtı',
        'Atlantic/Faeroe' => 'Qərbi Avropa Vaxtı (Farer)',
        'Atlantic/Madeira' => 'Qərbi Avropa Vaxtı (Madeyra)',
        'Atlantic/Reykjavik' => 'Qrinviç Orta Vaxtı (Reykyavik)',
        'Atlantic/South_Georgia' => 'Cənubi Corciya Vaxtı',
        'Atlantic/St_Helena' => 'Qrinviç Orta Vaxtı (Müqəddəs Yelena)',
        'Atlantic/Stanley' => 'Folklend Adaları Vaxtı (Stenli)',
        'Australia/Adelaide' => 'Mərkəzi Avstraliya Vaxtı (Adelaida)',
        'Australia/Brisbane' => 'Şərqi Avstraliya Vaxtı (Brisbeyn)',
        'Australia/Broken_Hill' => 'Mərkəzi Avstraliya Vaxtı (Broken Hill)',
        'Australia/Currie' => 'Şərqi Avstraliya Vaxtı (Kuriye)',
        'Australia/Darwin' => 'Mərkəzi Avstraliya Vaxtı (Darvin)',
        'Australia/Eucla' => 'Mərkəzi Qərbi Avstraliya Vaxtı (Yukla)',
        'Australia/Hobart' => 'Şərqi Avstraliya Vaxtı (Hobart)',
        'Australia/Lindeman' => 'Şərqi Avstraliya Vaxtı (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Hau Vaxtı',
        'Australia/Melbourne' => 'Şərqi Avstraliya Vaxtı (Melburn)',
        'Australia/Perth' => 'Qərbi Avstraliya Vaxtı (Pert)',
        'Australia/Sydney' => 'Şərqi Avstraliya Vaxtı (Sidney)',
        'CST6CDT' => 'Şimali Mərkəzi Amerika Vaxtı',
        'EST5EDT' => 'Şimali Şərqi Amerika Vaxtı',
        'Etc/GMT' => 'Qrinviç Orta Vaxtı',
        'Etc/UTC' => 'Koordinasiya edilmiş ümumdünya vaxtı',
        'Europe/Amsterdam' => 'Mərkəzi Avropa Vaxtı (Amsterdam)',
        'Europe/Andorra' => 'Mərkəzi Avropa Vaxtı (Andorra)',
        'Europe/Astrakhan' => 'Moskva Vaxtı (Həştərxan)',
        'Europe/Athens' => 'Şərqi Avropa Vaxtı (Afina)',
        'Europe/Belgrade' => 'Mərkəzi Avropa Vaxtı (Belqrad)',
        'Europe/Berlin' => 'Mərkəzi Avropa Vaxtı (Berlin)',
        'Europe/Bratislava' => 'Mərkəzi Avropa Vaxtı (Bratislava)',
        'Europe/Brussels' => 'Mərkəzi Avropa Vaxtı (Brüssel)',
        'Europe/Bucharest' => 'Şərqi Avropa Vaxtı (Buxarest)',
        'Europe/Budapest' => 'Mərkəzi Avropa Vaxtı (Budapeşt)',
        'Europe/Busingen' => 'Mərkəzi Avropa Vaxtı (Busingen)',
        'Europe/Chisinau' => 'Şərqi Avropa Vaxtı (Kişinyov)',
        'Europe/Copenhagen' => 'Mərkəzi Avropa Vaxtı (Kopenhagen)',
        'Europe/Dublin' => 'Qrinviç Orta Vaxtı (Dublin)',
        'Europe/Gibraltar' => 'Mərkəzi Avropa Vaxtı (Cəbəli-Tariq)',
        'Europe/Guernsey' => 'Qrinviç Orta Vaxtı (Gernzey)',
        'Europe/Helsinki' => 'Şərqi Avropa Vaxtı (Helsinki)',
        'Europe/Isle_of_Man' => 'Qrinviç Orta Vaxtı (Men Adası)',
        'Europe/Istanbul' => 'Türkiyə Vaxtı (İstanbul)',
        'Europe/Jersey' => 'Qrinviç Orta Vaxtı (Cersi)',
        'Europe/Kaliningrad' => 'Şərqi Avropa Vaxtı (Kalininqrad)',
        'Europe/Kiev' => 'Şərqi Avropa Vaxtı (Kiyev)',
        'Europe/Kirov' => 'Rusiya Vaxtı (Kirov)',
        'Europe/Lisbon' => 'Qərbi Avropa Vaxtı (Lissabon)',
        'Europe/Ljubljana' => 'Mərkəzi Avropa Vaxtı (Lyublyana)',
        'Europe/London' => 'Qrinviç Orta Vaxtı (London)',
        'Europe/Luxembourg' => 'Mərkəzi Avropa Vaxtı (Lüksemburq)',
        'Europe/Madrid' => 'Mərkəzi Avropa Vaxtı (Madrid)',
        'Europe/Malta' => 'Mərkəzi Avropa Vaxtı (Malta)',
        'Europe/Mariehamn' => 'Şərqi Avropa Vaxtı (Mariham)',
        'Europe/Minsk' => 'Moskva Vaxtı (Minsk)',
        'Europe/Monaco' => 'Mərkəzi Avropa Vaxtı (Monako)',
        'Europe/Moscow' => 'Moskva Vaxtı',
        'Europe/Oslo' => 'Mərkəzi Avropa Vaxtı (Oslo)',
        'Europe/Paris' => 'Mərkəzi Avropa Vaxtı (Paris)',
        'Europe/Podgorica' => 'Mərkəzi Avropa Vaxtı (Podqoritsa)',
        'Europe/Prague' => 'Mərkəzi Avropa Vaxtı (Praqa)',
        'Europe/Riga' => 'Şərqi Avropa Vaxtı (Riqa)',
        'Europe/Rome' => 'Mərkəzi Avropa Vaxtı (Roma)',
        'Europe/Samara' => 'Samara vaxtı',
        'Europe/San_Marino' => 'Mərkəzi Avropa Vaxtı (San Marino)',
        'Europe/Sarajevo' => 'Mərkəzi Avropa Vaxtı (Sarayevo)',
        'Europe/Saratov' => 'Moskva Vaxtı (Saratov)',
        'Europe/Simferopol' => 'Moskva Vaxtı (Simferopol)',
        'Europe/Skopje' => 'Mərkəzi Avropa Vaxtı (Skopye)',
        'Europe/Sofia' => 'Şərqi Avropa Vaxtı (Sofiya)',
        'Europe/Stockholm' => 'Mərkəzi Avropa Vaxtı (Stokholm)',
        'Europe/Tallinn' => 'Şərqi Avropa Vaxtı (Tallin)',
        'Europe/Tirane' => 'Mərkəzi Avropa Vaxtı (Tirana)',
        'Europe/Ulyanovsk' => 'Moskva Vaxtı (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Şərqi Avropa Vaxtı (Ujqorod)',
        'Europe/Vaduz' => 'Mərkəzi Avropa Vaxtı (Vaduts)',
        'Europe/Vatican' => 'Mərkəzi Avropa Vaxtı (Vatikan)',
        'Europe/Vienna' => 'Mərkəzi Avropa Vaxtı (Vyana)',
        'Europe/Vilnius' => 'Şərqi Avropa Vaxtı (Vilnüs)',
        'Europe/Volgograd' => 'Volqoqrad Vaxtı',
        'Europe/Warsaw' => 'Mərkəzi Avropa Vaxtı (Varşava)',
        'Europe/Zagreb' => 'Mərkəzi Avropa Vaxtı (Zaqreb)',
        'Europe/Zaporozhye' => 'Şərqi Avropa Vaxtı (Zaporojye)',
        'Europe/Zurich' => 'Mərkəzi Avropa Vaxtı (Sürix)',
        'Indian/Antananarivo' => 'Şərqi Afrika Vaxtı (Antananarivo)',
        'Indian/Chagos' => 'Hind Okeanı Vaxtı (Çaqos)',
        'Indian/Christmas' => 'Milad Adası Vaxtı',
        'Indian/Cocos' => 'Kokos Adaları Vaxtı',
        'Indian/Comoro' => 'Şərqi Afrika Vaxtı (Komoro)',
        'Indian/Kerguelen' => 'Fransız Cənubi və Antarktik Vaxtı (Kergelen)',
        'Indian/Mahe' => 'Seyşel Adaları Vaxtı (Mahe)',
        'Indian/Maldives' => 'Maldiv Vaxtı',
        'Indian/Mauritius' => 'Mavriki Vaxtı',
        'Indian/Mayotte' => 'Şərqi Afrika Vaxtı (Mayot)',
        'Indian/Reunion' => 'Reyunyon (Reunion)',
        'MST7MDT' => 'Şimali Dağlıq Amerika Vaxtı',
        'PST8PDT' => 'Şimali Amerika Sakit Okean Vaxtı',
        'Pacific/Apia' => 'Apia Vaxtı',
        'Pacific/Auckland' => 'Yeni Zelandiya Vaxtı (Oklənd)',
        'Pacific/Bougainville' => 'Papua Yeni Qvineya Vaxtı (Buqanvil)',
        'Pacific/Chatham' => 'Çatham Vaxtı (Çatam)',
        'Pacific/Easter' => 'Pasxa Adası Vaxtı',
        'Pacific/Efate' => 'Vanuatu Vaxtı (Efate)',
        'Pacific/Enderbury' => 'Feniks Adaları Vaxtı (Enderböri)',
        'Pacific/Fakaofo' => 'Tokelau Vaxtı (Fakaofo)',
        'Pacific/Fiji' => 'Fici Vaxtı',
        'Pacific/Funafuti' => 'Tuvalu Vaxtı (Funafuti)',
        'Pacific/Galapagos' => 'Qalapaqos Vaxtı',
        'Pacific/Gambier' => 'Qambier Vaxtı (Qambiyer)',
        'Pacific/Guadalcanal' => 'Solomon Adaları Vaxtı (Quadalkanal)',
        'Pacific/Guam' => 'Çamorro Vaxtı (Quam)',
        'Pacific/Honolulu' => 'Havay-Aleut Vaxtı (Honolulu)',
        'Pacific/Johnston' => 'Havay-Aleut Vaxtı (Conston)',
        'Pacific/Kiritimati' => 'Layn Adaları Vaxtı (Kirimati)',
        'Pacific/Kosrae' => 'Korse Vaxtı (Kosraye)',
        'Pacific/Kwajalein' => 'Marşal Adaları Vaxtı (Kvajaleyn)',
        'Pacific/Majuro' => 'Marşal Adaları Vaxtı (Macuro)',
        'Pacific/Marquesas' => 'Markesas Vaxtı',
        'Pacific/Midway' => 'Samoa Vaxtı (Midvey)',
        'Pacific/Nauru' => 'Nauru Vaxtı',
        'Pacific/Niue' => 'Niue Vaxtı',
        'Pacific/Norfolk' => 'Norfolk Adası Vaxtı',
        'Pacific/Noumea' => 'Yeni Kaledoniya Vaxtı (Noumea)',
        'Pacific/Pago_Pago' => 'Samoa Vaxtı (Paqo Paqo)',
        'Pacific/Palau' => 'Palau Vaxtı',
        'Pacific/Pitcairn' => 'Pitkern Vaxtı',
        'Pacific/Ponape' => 'Ponape Vaxtı (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua Yeni Qvineya Vaxtı (Port Moresbi)',
        'Pacific/Rarotonga' => 'Kuk Adaları Vaxtı (Rarotonqa)',
        'Pacific/Saipan' => 'Çamorro Vaxtı (Saypan)',
        'Pacific/Tahiti' => 'Tahiti Vaxtı',
        'Pacific/Tarawa' => 'Gilbert Adaları Vaxtı (Tarava)',
        'Pacific/Tongatapu' => 'Tonqa Vaxtı (Tonqapatu)',
        'Pacific/Truk' => 'Çuuk Vaxtı',
        'Pacific/Wake' => 'Ueyk Vaxtı (Veyk)',
        'Pacific/Wallis' => 'Uollis və Futuna Vaxtı',
    ],
    'Meta' => [
    ],
];
