<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Saa za Greenwich (Abidjan)',
        'Africa/Accra' => 'Saa za Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Saa za Afrika Mashariki (Addis Ababa)',
        'Africa/Algiers' => 'Saa za Ulaya ya Kati (Algiers)',
        'Africa/Asmera' => 'Saa za Afrika Mashariki (Asmara)',
        'Africa/Bamako' => 'Saa za Greenwich (Bamako)',
        'Africa/Bangui' => 'Saa za Afrika Magharibi (Bangui)',
        'Africa/Banjul' => 'Saa za Greenwich (Banjul)',
        'Africa/Bissau' => 'Saa za Greenwich (Bissau)',
        'Africa/Blantyre' => 'Saa za Afrika ya Kati (Blantyre)',
        'Africa/Brazzaville' => 'Saa za Afrika Magharibi (Brazzaville)',
        'Africa/Bujumbura' => 'Saa za Afrika ya Kati (Bujumbura)',
        'Africa/Cairo' => 'Saa za Mashariki mwa Ulaya (Cairo)',
        'Africa/Casablanca' => 'Saa za Magharibi mwa Ulaya (Casablanca)',
        'Africa/Ceuta' => 'Saa za Ulaya ya Kati (Ceuta)',
        'Africa/Conakry' => 'Saa za Greenwich (Conakry)',
        'Africa/Dakar' => 'Saa za Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Saa za Afrika Mashariki (Dar es Salaam)',
        'Africa/Djibouti' => 'Saa za Afrika Mashariki (Djibouti)',
        'Africa/Douala' => 'Saa za Afrika Magharibi (Douala)',
        'Africa/El_Aaiun' => 'Saa za Magharibi mwa Ulaya (El Aaiun)',
        'Africa/Freetown' => 'Saa za Greenwich (Freetown)',
        'Africa/Gaborone' => 'Saa za Afrika ya Kati (Gaborone)',
        'Africa/Harare' => 'Saa za Afrika ya Kati (Harare)',
        'Africa/Johannesburg' => 'Saa za Wastani za Afrika Kusini (Johannesburg)',
        'Africa/Juba' => 'Saa za Afrika ya Kati (Juba)',
        'Africa/Kampala' => 'Saa za Afrika Mashariki (Kampala)',
        'Africa/Khartoum' => 'Saa za Afrika ya Kati (Khartoum)',
        'Africa/Kigali' => 'Saa za Afrika ya Kati (Kigali)',
        'Africa/Kinshasa' => 'Saa za Afrika Magharibi (Kinshasa)',
        'Africa/Lagos' => 'Saa za Afrika Magharibi (Lagos)',
        'Africa/Libreville' => 'Saa za Afrika Magharibi (Libreville)',
        'Africa/Lome' => 'Saa za Greenwich (Lome)',
        'Africa/Luanda' => 'Saa za Afrika Magharibi (Luanda)',
        'Africa/Lubumbashi' => 'Saa za Afrika ya Kati (Lubumbashi)',
        'Africa/Lusaka' => 'Saa za Afrika ya Kati (Lusaka)',
        'Africa/Malabo' => 'Saa za Afrika Magharibi (Malabo)',
        'Africa/Maputo' => 'Saa za Afrika ya Kati (Maputo)',
        'Africa/Maseru' => 'Saa za Wastani za Afrika Kusini (Maseru)',
        'Africa/Mbabane' => 'Saa za Wastani za Afrika Kusini (Mbabane)',
        'Africa/Mogadishu' => 'Saa za Afrika Mashariki (Mogadishu)',
        'Africa/Monrovia' => 'Saa za Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Saa za Afrika Mashariki (Nairobi)',
        'Africa/Ndjamena' => 'Saa za Afrika Magharibi (Ndjamena)',
        'Africa/Niamey' => 'Saa za Afrika Magharibi (Niamey)',
        'Africa/Nouakchott' => 'Saa za Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Saa za Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Saa za Afrika Magharibi (Porto-Novo)',
        'Africa/Sao_Tome' => 'Saa za Greenwich (Sao Tome)',
        'Africa/Tripoli' => 'Saa za Mashariki mwa Ulaya (Tripoli)',
        'Africa/Tunis' => 'Saa za Ulaya ya Kati (Tunis)',
        'Africa/Windhoek' => 'Saa za Afrika ya Kati (Windhoek)',
        'America/Adak' => 'Saa za Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Saa za Alaska (Anchorage)',
        'America/Anguilla' => 'Saa za Atlantiki (Anguilla)',
        'America/Antigua' => 'Saa za Atlantiki (Antigua)',
        'America/Araguaina' => 'Saa za Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'Saa za Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Saa za Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Saa za Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Saa za Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Saa za Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Saa za Argentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'Saa za Argentina (Ushuaia)',
        'America/Aruba' => 'Saa za Atlantiki (Aruba)',
        'America/Asuncion' => 'Saa za Paragwai (Asuncion)',
        'America/Bahia' => 'Saa za Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Saa za Kati (Bahia Banderas)',
        'America/Barbados' => 'Saa za Atlantiki (Barbados)',
        'America/Belem' => 'Saa za Brasilia (Belem)',
        'America/Belize' => 'Saa za Kati (Belize)',
        'America/Blanc-Sablon' => 'Saa za Atlantiki (Blanc-Sablon)',
        'America/Boa_Vista' => 'Saa za Amazon (Boa Vista)',
        'America/Bogota' => 'Saa za Kolombia (Bogota)',
        'America/Boise' => 'Saa za Mountain (Boise)',
        'America/Buenos_Aires' => 'Saa za Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Saa za Mountain (Cambridge Bay)',
        'America/Campo_Grande' => 'Saa za Amazon (Campo Grande)',
        'America/Cancun' => 'Saa za Mashariki (Cancun)',
        'America/Caracas' => 'Saa za Venezuela (Caracas)',
        'America/Catamarca' => 'Saa za Argentina (Catamarca)',
        'America/Cayenne' => 'Saa za Guiana ya Ufaransa (Cayenne)',
        'America/Cayman' => 'Saa za Mashariki (Cayman)',
        'America/Chicago' => 'Saa za Kati (Chicago)',
        'America/Chihuahua' => 'Saa za pasifiki za Meksiko (Chihuahua)',
        'America/Coral_Harbour' => 'Saa za Mashariki (Atikokan)',
        'America/Cordoba' => 'Saa za Argentina (Cordoba)',
        'America/Costa_Rica' => 'Saa za Kati (Costa Rica)',
        'America/Creston' => 'Saa za Mountain (Creston)',
        'America/Cuiaba' => 'Saa za Amazon (Cuiaba)',
        'America/Curacao' => 'Saa za Atlantiki (Curacao)',
        'America/Danmarkshavn' => 'Saa za Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Saa za Yukon (Dawson)',
        'America/Dawson_Creek' => 'Saa za Mountain (Dawson Creek)',
        'America/Denver' => 'Saa za Mountain (Denver)',
        'America/Detroit' => 'Saa za Mashariki (Detroit)',
        'America/Dominica' => 'Saa za Atlantiki (Dominica)',
        'America/Edmonton' => 'Saa za Mountain (Edmonton)',
        'America/Eirunepe' => 'Saa za Brazil (Eirunepe)',
        'America/El_Salvador' => 'Saa za Kati (El Salvador)',
        'America/Fort_Nelson' => 'Saa za Mountain (Fort Nelson)',
        'America/Fortaleza' => 'Saa za Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Saa za Atlantiki (Glace Bay)',
        'America/Godthab' => 'Saa za Greenland Magharibi (Nuuk)',
        'America/Goose_Bay' => 'Saa za Atlantiki (Goose Bay)',
        'America/Grand_Turk' => 'Saa za Mashariki (Grand Turk)',
        'America/Grenada' => 'Saa za Atlantiki (Grenada)',
        'America/Guadeloupe' => 'Saa za Atlantiki (Guadeloupe)',
        'America/Guatemala' => 'Saa za Kati (Guatemala)',
        'America/Guayaquil' => 'Saa za Ekwado (Guayaquil)',
        'America/Guyana' => 'Saa za Guyana',
        'America/Halifax' => 'Saa za Atlantiki (Halifax)',
        'America/Havana' => 'Saa za Kuba (Havana)',
        'America/Hermosillo' => 'Saa za pasifiki za Meksiko (Hermosillo)',
        'America/Indiana/Knox' => 'Saa za Kati (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Saa za Mashariki (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Saa za Mashariki (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Saa za Kati (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Saa za Mashariki (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Saa za Mashariki (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Saa za Mashariki (Winamac, Indiana)',
        'America/Indianapolis' => 'Saa za Mashariki (Indianapolis)',
        'America/Inuvik' => 'Saa za Mountain (Inuvik)',
        'America/Iqaluit' => 'Saa za Mashariki (Iqaluit)',
        'America/Jamaica' => 'Saa za Mashariki (Jamaica)',
        'America/Jujuy' => 'Saa za Argentina (Jujuy)',
        'America/Juneau' => 'Saa za Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Saa za Mashariki (Monticello, Kentucky)',
        'America/Kralendijk' => 'Saa za Atlantiki (Kralendijk)',
        'America/La_Paz' => 'Saa za Bolivia (La Paz)',
        'America/Lima' => 'Saa za Peru (Lima)',
        'America/Los_Angeles' => 'Saa za Pasifiki (Los Angeles)',
        'America/Louisville' => 'Saa za Mashariki (Louisville)',
        'America/Lower_Princes' => 'Saa za Atlantiki (Lower Prince’s Quarter)',
        'America/Maceio' => 'Saa za Brasilia (Maceio)',
        'America/Managua' => 'Saa za Kati (Managua)',
        'America/Manaus' => 'Saa za Amazon (Manaus)',
        'America/Marigot' => 'Saa za Atlantiki (Marigot)',
        'America/Martinique' => 'Saa za Atlantiki (Martinique)',
        'America/Matamoros' => 'Saa za Kati (Matamoros)',
        'America/Mazatlan' => 'Saa za pasifiki za Meksiko (Mazatlan)',
        'America/Mendoza' => 'Saa za Argentina (Mendoza)',
        'America/Menominee' => 'Saa za Kati (Menominee)',
        'America/Merida' => 'Saa za Kati (Merida)',
        'America/Metlakatla' => 'Saa za Alaska (Metlakatla)',
        'America/Mexico_City' => 'Saa za Kati (Jiji la Mexico)',
        'America/Miquelon' => 'Saa za Saint-Pierre na Miquelon',
        'America/Moncton' => 'Saa za Atlantiki (Moncton)',
        'America/Monterrey' => 'Saa za Kati (Monterrey)',
        'America/Montevideo' => 'Saa za Urugwai (Montevideo)',
        'America/Montreal' => 'Saa za Kanada (Montreal)',
        'America/Montserrat' => 'Saa za Atlantiki (Montserrat)',
        'America/Nassau' => 'Saa za Mashariki (Nassau)',
        'America/New_York' => 'Saa za Mashariki (New York)',
        'America/Nipigon' => 'Saa za Mashariki (Nipigon)',
        'America/Nome' => 'Saa za Alaska (Nome)',
        'America/Noronha' => 'Saa za Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Saa za Kati (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Saa za Kati (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Saa za Kati (New Salem, North Dakota)',
        'America/Ojinaga' => 'Saa za Mountain (Ojinaga)',
        'America/Panama' => 'Saa za Mashariki (Panama)',
        'America/Pangnirtung' => 'Saa za Mashariki (Pangnirtung)',
        'America/Paramaribo' => 'Saa za Suriname (Paramaribo)',
        'America/Phoenix' => 'Saa za Mountain (Phoenix)',
        'America/Port-au-Prince' => 'Saa za Mashariki (Port-au-Prince)',
        'America/Port_of_Spain' => 'Saa za Atlantiki (Port of Spain)',
        'America/Porto_Velho' => 'Saa za Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'Saa za Atlantiki (Puerto Rico)',
        'America/Punta_Arenas' => 'Saa za Chile (Punta Arenas)',
        'America/Rainy_River' => 'Saa za Kati (Rainy River)',
        'America/Rankin_Inlet' => 'Saa za Kati (Rankin Inlet)',
        'America/Recife' => 'Saa za Brasilia (Recife)',
        'America/Regina' => 'Saa za Kati (Regina)',
        'America/Resolute' => 'Saa za Kati (Resolute)',
        'America/Rio_Branco' => 'Saa za Brazil (Rio Branco)',
        'America/Santa_Isabel' => 'Saa za Meksiko Kaskazini Magharibi (Santa Isabel)',
        'America/Santarem' => 'Saa za Brasilia (Santarem)',
        'America/Santiago' => 'Saa za Chile (Santiago)',
        'America/Santo_Domingo' => 'Saa za Atlantiki (Santo Domingo)',
        'America/Sao_Paulo' => 'Saa za Brasilia (Sao Paulo)',
        'America/Scoresbysund' => 'Saa za Greenland Mashariki (Ittoqqortoormiit)',
        'America/Sitka' => 'Saa za Alaska (Sitka)',
        'America/St_Barthelemy' => 'Saa za Atlantiki (St. Barthelemy)',
        'America/St_Johns' => 'Saa za Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Saa za Atlantiki (St. Kitts)',
        'America/St_Lucia' => 'Saa za Atlantiki (St. Lucia)',
        'America/St_Thomas' => 'Saa za Atlantiki (St. Thomas)',
        'America/St_Vincent' => 'Saa za Atlantiki (St. Vincent)',
        'America/Swift_Current' => 'Saa za Kati (Swift Current)',
        'America/Tegucigalpa' => 'Saa za Kati (Tegucigalpa)',
        'America/Thule' => 'Saa za Atlantiki (Thule)',
        'America/Thunder_Bay' => 'Saa za Mashariki (Thunder Bay)',
        'America/Tijuana' => 'Saa za Pasifiki (Tijuana)',
        'America/Toronto' => 'Saa za Mashariki (Toronto)',
        'America/Tortola' => 'Saa za Atlantiki (Tortola)',
        'America/Vancouver' => 'Saa za Pasifiki (Vancouver)',
        'America/Whitehorse' => 'Saa za Yukon (Whitehorse)',
        'America/Winnipeg' => 'Saa za Kati (Winnipeg)',
        'America/Yakutat' => 'Saa za Alaska (Yakutat)',
        'America/Yellowknife' => 'Saa za Mountain (Yellowknife)',
        'Antarctica/Casey' => 'Saa za Antaktiki (Casey)',
        'Antarctica/Davis' => 'Saa za Davis',
        'Antarctica/DumontDUrville' => 'Saa za Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Saa za Australia Mashariki (Macquarie)',
        'Antarctica/Mawson' => 'Saa za Mawson',
        'Antarctica/McMurdo' => 'Saa za New Zealand (McMurdo)',
        'Antarctica/Palmer' => 'Saa za Chile (Palmer)',
        'Antarctica/Rothera' => 'Saa za Rothera',
        'Antarctica/Syowa' => 'Saa za Syowa',
        'Antarctica/Troll' => 'Saa za Greenwich (Troll)',
        'Antarctica/Vostok' => 'Saa za Vostok',
        'Arctic/Longyearbyen' => 'Saa za Ulaya ya Kati (Longyearbyen)',
        'Asia/Aden' => 'Saa za Uarabuni (Aden)',
        'Asia/Almaty' => 'Saa za Kazakhstan Mashariki (Almaty)',
        'Asia/Amman' => 'Saa za Mashariki mwa Ulaya (Amman)',
        'Asia/Anadyr' => 'Saa za Anadyr',
        'Asia/Aqtau' => 'Saa za Kazakhstan Magharibi (Aqtau)',
        'Asia/Aqtobe' => 'Saa za Kazakhstan Magharibi (Aqtobe)',
        'Asia/Ashgabat' => 'Saa za Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Saa za Kazakhstan Magharibi (Atyrau)',
        'Asia/Baghdad' => 'Saa za Uarabuni (Baghdad)',
        'Asia/Bahrain' => 'Saa za Uarabuni (Bahrain)',
        'Asia/Baku' => 'Saa za Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Saa za Indochina (Bangkok)',
        'Asia/Barnaul' => 'Saa za Urusi (Barnaul)',
        'Asia/Beirut' => 'Saa za Mashariki mwa Ulaya (Beirut)',
        'Asia/Bishkek' => 'Saa za Kyrgystan (Bishkek)',
        'Asia/Brunei' => 'Saa za Brunei Darussalam',
        'Asia/Calcutta' => 'Saa za Wastani za India (Kolkata)',
        'Asia/Chita' => 'Saa za Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Saa za Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Saa za Wastani za India (Colombo)',
        'Asia/Damascus' => 'Saa za Mashariki mwa Ulaya (Damascus)',
        'Asia/Dhaka' => 'Saa za Bangladesh (Dhaka)',
        'Asia/Dili' => 'Saa za Timor Mashariki (Dili)',
        'Asia/Dubai' => 'Saa za Wastani za Gulf (Dubai)',
        'Asia/Dushanbe' => 'Saa za Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Saa za Mashariki mwa Ulaya (Famagusta)',
        'Asia/Gaza' => 'Saa za Mashariki mwa Ulaya (Gaza)',
        'Asia/Hebron' => 'Saa za Mashariki mwa Ulaya (Hebron)',
        'Asia/Hong_Kong' => 'Saa za Hong Kong',
        'Asia/Hovd' => 'Saa za Hovd',
        'Asia/Irkutsk' => 'Saa za Irkutsk',
        'Asia/Jakarta' => 'Saa za Magharibi mwa Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Saa za Mashariki mwa Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'Saa za Israeli (Jerusalem)',
        'Asia/Kabul' => 'Saa za Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Saa za Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Saa za Pakistan (Karachi)',
        'Asia/Katmandu' => 'Saa za Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Saa za Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Saa za Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Saa za Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Saa za Malaysia (Kuching)',
        'Asia/Kuwait' => 'Saa za Uarabuni (Kuwait)',
        'Asia/Macau' => 'Saa za Uchina (Macau)',
        'Asia/Magadan' => 'Saa za Magadan',
        'Asia/Makassar' => 'Saa za Indonesia ya Kati (Makassar)',
        'Asia/Manila' => 'Saa za Ufilipino (Manila)',
        'Asia/Muscat' => 'Saa za Wastani za Gulf (Muscat)',
        'Asia/Nicosia' => 'Saa za Mashariki mwa Ulaya (Nicosia)',
        'Asia/Novokuznetsk' => 'Saa za Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Saa za Novosibirsk',
        'Asia/Omsk' => 'Saa za Omsk',
        'Asia/Oral' => 'Saa za Kazakhstan Magharibi (Oral)',
        'Asia/Phnom_Penh' => 'Saa za Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Saa za Magharibi mwa Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'Saa za Korea (Pyongyang)',
        'Asia/Qatar' => 'Saa za Uarabuni (Qatar)',
        'Asia/Qostanay' => 'Saa za Kazakhstan Mashariki (Kostanay)',
        'Asia/Qyzylorda' => 'Saa za Kazakhstan Magharibi (Qyzylorda)',
        'Asia/Rangoon' => 'Saa za Myanmar (Rangoon)',
        'Asia/Riyadh' => 'Saa za Uarabuni (Riyadh)',
        'Asia/Saigon' => 'Saa za Indochina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Saa za Sakhalin',
        'Asia/Samarkand' => 'Saa za Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'Saa za Korea (Seoul)',
        'Asia/Shanghai' => 'Saa za Uchina (Shanghai)',
        'Asia/Singapore' => 'Saa za Wastani za Singapore',
        'Asia/Srednekolymsk' => 'Saa za Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Saa za Taipei',
        'Asia/Tashkent' => 'Saa za Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Saa za Jojia (Tbilisi)',
        'Asia/Tehran' => 'Saa za Iran (Tehran)',
        'Asia/Thimphu' => 'Saa za Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Saa za Japan (Tokyo)',
        'Asia/Tomsk' => 'Saa za Urusi (Tomsk)',
        'Asia/Ulaanbaatar' => 'Saa za Ulan Bator (Ulaanbaatar)',
        'Asia/Urumqi' => 'Saa za Uchina (Urumqi)',
        'Asia/Ust-Nera' => 'Saa za Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Saa za Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Saa za Vladivostok',
        'Asia/Yakutsk' => 'Saa za Yakutsk',
        'Asia/Yekaterinburg' => 'Saa za Yekaterinburg',
        'Asia/Yerevan' => 'Saa za Armenia (Yerevan)',
        'Atlantic/Azores' => 'Saa za Azores',
        'Atlantic/Bermuda' => 'Saa za Atlantiki (Bermuda)',
        'Atlantic/Canary' => 'Saa za Magharibi mwa Ulaya (Canary)',
        'Atlantic/Cape_Verde' => 'Saa za Cape Verde',
        'Atlantic/Faeroe' => 'Saa za Magharibi mwa Ulaya (Faroe)',
        'Atlantic/Madeira' => 'Saa za Magharibi mwa Ulaya (Madeira)',
        'Atlantic/Reykjavik' => 'Saa za Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Saa za Georgia Kusini',
        'Atlantic/St_Helena' => 'Saa za Greenwich (St. Helena)',
        'Atlantic/Stanley' => 'Saa za Visiwa vya Falkland (Stanley)',
        'Australia/Adelaide' => 'Saa za Australia ya Kati (Adelaide)',
        'Australia/Brisbane' => 'Saa za Australia Mashariki (Brisbane)',
        'Australia/Broken_Hill' => 'Saa za Australia ya Kati (Broken Hill)',
        'Australia/Currie' => 'Saa za Australia Mashariki (Currie)',
        'Australia/Darwin' => 'Saa za Australia ya Kati (Darwin)',
        'Australia/Eucla' => 'Saa za Magharibi ya Kati ya Australia (Eucla)',
        'Australia/Hobart' => 'Saa za Australia Mashariki (Hobart)',
        'Australia/Lindeman' => 'Saa za Australia Mashariki (Lindeman)',
        'Australia/Lord_Howe' => 'Saa za Lord Howe',
        'Australia/Melbourne' => 'Saa za Australia Mashariki (Melbourne)',
        'Australia/Perth' => 'Saa za Australia Magharibi (Perth)',
        'Australia/Sydney' => 'Saa za Australia Mashariki (Sydney)',
        'CST6CDT' => 'Saa za Kati',
        'EST5EDT' => 'Saa za Mashariki',
        'Etc/GMT' => 'Saa za Greenwich',
        'Etc/UTC' => 'Mfumo wa kuratibu saa ulimwenguni',
        'Europe/Amsterdam' => 'Saa za Ulaya ya Kati (Amsterdam)',
        'Europe/Andorra' => 'Saa za Ulaya ya Kati (Andorra)',
        'Europe/Astrakhan' => 'Saa za Moscow (Astrakhan)',
        'Europe/Athens' => 'Saa za Mashariki mwa Ulaya (Athens)',
        'Europe/Belgrade' => 'Saa za Ulaya ya Kati (Belgrade)',
        'Europe/Berlin' => 'Saa za Ulaya ya Kati (Berlin)',
        'Europe/Bratislava' => 'Saa za Ulaya ya Kati (Bratislava)',
        'Europe/Brussels' => 'Saa za Ulaya ya Kati (Brussels)',
        'Europe/Bucharest' => 'Saa za Mashariki mwa Ulaya (Bucharest)',
        'Europe/Budapest' => 'Saa za Ulaya ya Kati (Budapest)',
        'Europe/Busingen' => 'Saa za Ulaya ya Kati (Busingen)',
        'Europe/Chisinau' => 'Saa za Mashariki mwa Ulaya (Chisinau)',
        'Europe/Copenhagen' => 'Saa za Ulaya ya Kati (Copenhagen)',
        'Europe/Dublin' => 'Saa za Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Saa za Ulaya ya Kati (Gibraltar)',
        'Europe/Guernsey' => 'Saa za Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Saa za Mashariki mwa Ulaya (Helsinki)',
        'Europe/Isle_of_Man' => 'Saa za Greenwich (Isle of Man)',
        'Europe/Istanbul' => 'Saa za Uturuki (Istanbul)',
        'Europe/Jersey' => 'Saa za Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Saa za Mashariki mwa Ulaya (Kaliningrad)',
        'Europe/Kiev' => 'Saa za Mashariki mwa Ulaya (Kiev)',
        'Europe/Kirov' => 'Saa za Urusi (Kirov)',
        'Europe/Lisbon' => 'Saa za Magharibi mwa Ulaya (Lisbon)',
        'Europe/Ljubljana' => 'Saa za Ulaya ya Kati (Ljubljana)',
        'Europe/London' => 'Saa za Greenwich (London)',
        'Europe/Luxembourg' => 'Saa za Ulaya ya Kati (Luxembourg)',
        'Europe/Madrid' => 'Saa za Ulaya ya Kati (Madrid)',
        'Europe/Malta' => 'Saa za Ulaya ya Kati (Malta)',
        'Europe/Mariehamn' => 'Saa za Mashariki mwa Ulaya (Mariehamn)',
        'Europe/Minsk' => 'Saa za Moscow (Minsk)',
        'Europe/Monaco' => 'Saa za Ulaya ya Kati (Monaco)',
        'Europe/Moscow' => 'Saa za Moscow',
        'Europe/Oslo' => 'Saa za Ulaya ya Kati (Oslo)',
        'Europe/Paris' => 'Saa za Ulaya ya Kati (Paris)',
        'Europe/Podgorica' => 'Saa za Ulaya ya Kati (Podgorica)',
        'Europe/Prague' => 'Saa za Ulaya ya Kati (Prague)',
        'Europe/Riga' => 'Saa za Mashariki mwa Ulaya (Riga)',
        'Europe/Rome' => 'Saa za Ulaya ya Kati (Rome)',
        'Europe/Samara' => 'Saa za Samara',
        'Europe/San_Marino' => 'Saa za Ulaya ya Kati (San Marino)',
        'Europe/Sarajevo' => 'Saa za Ulaya ya Kati (Sarajevo)',
        'Europe/Saratov' => 'Saa za Moscow (Saratov)',
        'Europe/Simferopol' => 'Saa za Moscow (Simferopol)',
        'Europe/Skopje' => 'Saa za Ulaya ya Kati (Skopje)',
        'Europe/Sofia' => 'Saa za Mashariki mwa Ulaya (Sofia)',
        'Europe/Stockholm' => 'Saa za Ulaya ya Kati (Stockholm)',
        'Europe/Tallinn' => 'Saa za Mashariki mwa Ulaya (Tallinn)',
        'Europe/Tirane' => 'Saa za Ulaya ya Kati (Tirane)',
        'Europe/Ulyanovsk' => 'Saa za Moscow (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Saa za Mashariki mwa Ulaya (Uzhgorod)',
        'Europe/Vaduz' => 'Saa za Ulaya ya Kati (Vaduz)',
        'Europe/Vatican' => 'Saa za Ulaya ya Kati (Vatican)',
        'Europe/Vienna' => 'Saa za Ulaya ya Kati (Vienna)',
        'Europe/Vilnius' => 'Saa za Mashariki mwa Ulaya (Vilnius)',
        'Europe/Volgograd' => 'Saa za Volgograd',
        'Europe/Warsaw' => 'Saa za Ulaya ya Kati (Warsaw)',
        'Europe/Zagreb' => 'Saa za Ulaya ya Kati (Zagreb)',
        'Europe/Zaporozhye' => 'Saa za Mashariki mwa Ulaya (Zaporozhye)',
        'Europe/Zurich' => 'Saa za Ulaya ya Kati (Zurich)',
        'Indian/Antananarivo' => 'Saa za Afrika Mashariki (Antananarivo)',
        'Indian/Chagos' => 'Saa za Bahari Hindi (Chagos)',
        'Indian/Christmas' => 'Saa za Kisiwa cha Krismasi (Christmas)',
        'Indian/Cocos' => 'Saa za Visiwa vya Cocos',
        'Indian/Comoro' => 'Saa za Afrika Mashariki (Comoro)',
        'Indian/Kerguelen' => 'Saa za Kusini mwa Ufaransa na Antaktiki (Kerguelen)',
        'Indian/Mahe' => 'Saa za Ushelisheli (Mahe)',
        'Indian/Maldives' => 'Saa za Maldives',
        'Indian/Mauritius' => 'Saa za Morisi (Mauritius)',
        'Indian/Mayotte' => 'Saa za Afrika Mashariki (Mayotte)',
        'Indian/Reunion' => 'Saa za Reunion',
        'MST7MDT' => 'Saa za Mountain',
        'PST8PDT' => 'Saa za Pasifiki',
        'Pacific/Apia' => 'Saa za Apia',
        'Pacific/Auckland' => 'Saa za New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Saa za Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Saa za Chatham',
        'Pacific/Easter' => 'Saa za Kisiwa cha Easter',
        'Pacific/Efate' => 'Saa za Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Saa za Visiwa vya Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Saa za Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Saa za Fiji',
        'Pacific/Funafuti' => 'Saa za Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Saa za Galapagos',
        'Pacific/Gambier' => 'Saa za Gambier',
        'Pacific/Guadalcanal' => 'Saa za Visiwa vya Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Saa za Wastani za Chamorro (Guam)',
        'Pacific/Honolulu' => 'Saa za Hawaii-Aleutian (Honolulu)',
        'Pacific/Johnston' => 'Saa za Hawaii-Aleutian (Johnston)',
        'Pacific/Kiritimati' => 'Saa za Visiwa vya Line (Kiritimati)',
        'Pacific/Kosrae' => 'Saa za Kosrae',
        'Pacific/Kwajalein' => 'Saa za Visiwa vya Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Saa za Visiwa vya Marshall (Majuro)',
        'Pacific/Marquesas' => 'Saa za Marquesas',
        'Pacific/Midway' => 'Saa za Samoa (Midway)',
        'Pacific/Nauru' => 'Saa za Nauru',
        'Pacific/Niue' => 'Saa za Niue',
        'Pacific/Norfolk' => 'Saa za Kisiwa cha Norfolk',
        'Pacific/Noumea' => 'Saa za New Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'Saa za Samoa (Pago Pago)',
        'Pacific/Palau' => 'Saa za Palau',
        'Pacific/Pitcairn' => 'Saa za Pitcairn',
        'Pacific/Ponape' => 'Saa za Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Saa za Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Saa za Visiwa vya Cook (Rarotonga)',
        'Pacific/Saipan' => 'Saa za Wastani za Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Saa za Tahiti',
        'Pacific/Tarawa' => 'Saa za Visiwa vya Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Saa za Tonga (Tongatapu)',
        'Pacific/Truk' => 'Saa za Chuuk',
        'Pacific/Wake' => 'Saa za Kisiwa cha Wake',
        'Pacific/Wallis' => 'Saa za Wallis na Futuna',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT %s',
    ],
];
