<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Sameindu Emirríkini dirham',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afganistan afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albania lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armenia dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Niðurlonds Karibia gyllin',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angola kwanza',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentina peso',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Avstralskur dollari',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruba florin',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Aserbadjan manat',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnia-Hersegovina mark (kann vekslast)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados dollari',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladesj taka',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgarskur Lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Barein dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundi frankur',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda dollari',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunei dollari',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivia boliviano',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Brasilianskur real',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamaoyggjar dollari',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Butan ngultrum',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botsvana pula',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Hvítarussiskur Ruble',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Hvítarussland ruble (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belis dollari',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Kanadiskur dollari',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kongo frankur',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'sveisiskur frankur',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Kili peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'kinesiskur yuan (úr landi)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'kinesiskur yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolombia peso',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kosta Rika colón',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kuba peso (sum kann vekslast)',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kuba peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Grønhøvdaoyggjar escudo',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Kekkiskt Koruna',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djibuti frankur',
        ],
        'DKK' => [
            0 => 'kr',
            1 => 'donsk króna',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominika peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algeria dinar',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptaland pund',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrea nakfa',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Etiopia birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Evra',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fiji dollari',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falklandsoyggjar pund',
        ],
        'GBP' => [
            0 => '£',
            1 => 'bretsk pund',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgia lari',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Gana cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltar pund',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambia dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinea frankur',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemala quetzal',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Gujana dollari',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hong Kong dollari',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Honduras lempira',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatia kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haiti gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Ungarskur Forintur',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesia rupiah',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Ísrael new shekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'indiskir rupis',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Irak dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iranskir rials',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'íslendsk króna',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaika dollari',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordan dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'japanskur yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenjanskur skillingur',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgisia som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodja riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komoroyggjar frankur',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Norðurkorea won',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Suðurkorea won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuvait dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Caymanoyggjar dollari',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kasakstan tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laos kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libanon pund',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lanka rupi',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberia dollari',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libya dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokko dirham',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovanskur Leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Madagaskar ariary',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Makedónia denar',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmar (Burma) kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolia tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Makao pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Móritania ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Móritania ouguiya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Móritius rupi',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldivoyggjar rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malavi kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksiko peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malaisia ringgit',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mosambik metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibia dollari',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeria naira',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nikaragua córdoba',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'norsk króna',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepal rupi',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Nýsæland dollari',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Oman rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panama balboa',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peru sol',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua Nýguinea kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filipsoyggjar peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistan rupi',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Pólskur Zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguai guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katar rial',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Rumenia leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbia dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russland ruble',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Ruanda frankur',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudiarabia riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Salomonoyggjar dollari',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seyskelloyggjar rupi',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudan pund',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'svensk króna',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapor dollari',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'St. Helena pund',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra Leona leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalia skillingur',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinam dollari',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Suðursudan pund',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Sao Tome & Prinsipi dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Sao Tome & Prinsipi dobra',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Sýria pund',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Svasiland lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Tailand baht',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadsjikistan somoni',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistan manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunesia dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tonga paʻanga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkaland liri',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad & Tobago dollari',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Taivan new dollari',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tansania skillingur',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukraina hryvnia',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Uganda skillingur',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'US dollari',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguai peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Usbekistan som',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venesuela bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venesuela bolívar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vjetnam dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoa tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Miðafrika CFA frankur',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Eystur Karibia dollari',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Vesturafrika CFA frankur',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP frankur',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemen rial',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Suðurafrika rand',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Sambia kwacha',
        ],
    ],
];
