<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirhamka Isutaga Imaaraatka Carabta',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afgan Afgani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lekta Albaniya',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Daraamka Armeniya',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Galdarka Nadarlaan Antiliyaan',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kawansada Angola',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentine Austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Beesada Ley ee Arjentiin (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Beesada Ley ee Arjentiin (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Beesada Ley ee Arjentiin (1883–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Beesada Arjentiin',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Doolarka Astaraaliya',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Foloorinta Aruban',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manaata Asarbeyjan',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Diinaarka BBosnia-Hersogofina 1.00 konfatibal maakta Bosnia-Hersogofina 1 konfatibal maaka Bosnia-Hersogofina (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Konfatibal Maakta Bosnia-Hersogofina',
        ],
        'BBD' => [
            0 => 'DBB',
            1 => 'Doolarka Barbaadiyaan',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka Bangledesh',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Lefta Bulgariya',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinaarka Baxreyn',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Faranka Burundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Doolarka Barmuuda',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Doolarka Buruney',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolifiyanada Bolifiya',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Bolifiyaabka Bolifiyaano(1863–1963)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Realka Barasil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Doolarka Bahamaas',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Nugultaramta Butan',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Buulada Botswana',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rubalka Belarus',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Doolarka Beelisa',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Doolarka Kanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Faranka Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Faranka Iswiska',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Beesada Jili',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuwanta Shiinaha (Ofshoor)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuwanta Shiinaha',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Beesada Kolombiya',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kolonka Kosta Riika',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Beesada Konfatibal ee Kuuba',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Beesada Kuuba',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Eskudo Keyb Farde',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Korunada Jeek',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Faran Jabuuti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Koronka Danishka',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Beesada Dominiika',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinaarka Aljeriya',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Kroonka Estooniya',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Bowndka Masar',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfada Eritriya',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Birta Itoobbiya',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuuroo',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Markkada Fiinishka ah',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Doolarka Fiji',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Bowndka Faalklaan Aylaanis',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Bowndka Biritishka',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Laariga Joorjiya',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Sedida Gana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Bowndka Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasida Gambiya',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Faranka Gini',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Kuwestalka Guwatemala',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Doolarka Guyanes',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Doolarka Hoon Koon',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lembirada Honduras',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kunada Korooshiya',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Goordada Hiyati',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Forintiska Hangari',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rubiah Indonesiya',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'baawnka Ayrishka',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Niyuu Shekelka Israaiil',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rubiga Hindiya',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinaarka Ciraaq',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Riyaalka Iran',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Koronada Eysland',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Doolarka Jamayka',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinaarka Urdun',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yenta Jabaan',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shilingka Kenya',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Somta Kiyrgiystan',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riyf kambodiya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Faranka Komoros',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Wonka Waqooyiga Kuuriya',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Wonka Koonfur Kuuriya',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinaarka Kuweyt',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Doolarka Kayman Aylaanis',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tengeda Kasakhstan',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kib Laoti',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Bowndka Lubnaan',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rubiga Siri lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Doolarka Liberiya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesotho Loti',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Rubalka Latfiya',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinaarka Libya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirhamka Moroko',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leeyuuda Moldofa',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Arayrida Madagaskar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Denaarka Masedoniya',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kayatda Mayanmaar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrikta Mongoliya',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Bataka Makana',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Oogiya Mawritaniya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Oogiyada Mawritaaniya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rubiga Mowrishiya',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiyada Maldifiya',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kawajada Malawi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Beesada Meksiko',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringitda Malayshiya',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metikalka Mosambik',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Doolarka Namibiya',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nairada Neyjeeriya',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Kordobada Nikargow',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Koronka Norway',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rubiga Nebal',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Doolarka Niyuu Siyalaan',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Riyaalka Cumaan',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balbow Banama',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Solsha Beeru',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kinada Babua Niyuu Gini',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'Biso Filibin',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rubiga Bakistan',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Solotida Bolaan',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guranida Baraguway',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Riyaalka Qatar',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Liyuuda Romaniya',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinaarka Serbiya',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rubalka Ruushka',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Faranka Ruwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyaalka Sacuudiga',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Doolarka Solomon Aylaanis',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rubiga Siisalis',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Bowndka Suudaan',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Koronka Isweden',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Doolarka Singabuur',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Bowndka St Helen',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leonka Sira Leon',
        ],
        'SOS' => [
            0 => 'S',
            1 => 'Shilingka Soomaaliya',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Doolarka Surinamees',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Bowndka Koonfurta Suudaan',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra Sao Tome & Birinsibi',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Bowndka Suuriya',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeenida iswaasi',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Baatka Taylaan',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoonida Tajikistan',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manaata Turkmenistan',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinaarka Tunisiya',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Ba’angada Tonga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Liirada Turkiga',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Doolarka Tirinidad iyo Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Doolarka Taywaanta Cusub',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shilingka Tansaaniya',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Hirfiniyada Yukreeyn',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilingka Yugandha',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Doolarka Mareeykanka',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Beesada Urugway',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Somta Usbekistan',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolifar Fenesuala (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolifarada Fenesuwela',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dongta Fitnaam',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Fatu Fanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala Samao',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Faranka CFA ee Bartamaha Afrika',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Doolarka Iist Kaaribyan',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faranka CFA Galbeedka Afrika',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Faranka CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Riyaalka Yemen',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randka Koonfur Afrika',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kawajada Sambiya',
        ],
    ],
];
