<?php

return [
    'Names' => [
        'awa' => 'اودھی',
        'ckb' => 'سورانی کردی',
        'dje' => 'زرمہ',
        'hr' => 'کروشین',
        'jv' => 'جاوانیز',
        'ka' => 'جارجيائى',
        'kl' => 'کلالیسٹ',
        'kn' => 'کنڑ',
        'ku' => 'کرد',
        'mag' => 'مگہی',
        'zgh' => 'معیاری مراقشی تمازیقی',
    ],
    'LocalizedNames' => [
        'ar_001' => 'جدید معیاری عربی',
        'zh_Hans' => 'آسان چینی',
    ],
];
