<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arabek',
        'Armi' => 'arameek impalaerel',
        'Armn' => 'armenianek',
        'Avst' => 'avestek',
        'Bali' => 'balinek',
        'Bamu' => 'bamounek',
        'Batk' => 'batak',
        'Beng' => 'bengali',
        'Bopo' => 'bopomofo',
        'Brai' => 'Braille',
        'Bugi' => 'bougiek',
        'Cakm' => 'chakmaek',
        'Cans' => 'silabennaoueg engenidik unvan Kanada',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Copt' => 'koptek',
        'Cprt' => 'silabennaoueg kipriek',
        'Cyrl' => 'kirillek',
        'Cyrs' => 'kirillek henslavonek',
        'Deva' => 'devanagari',
        'Dupl' => 'berrskriverezh Duployé',
        'Egyp' => 'hieroglifoù egiptek',
        'Ethi' => 'etiopek',
        'Geor' => 'jorjianek',
        'Glag' => 'glagolitek',
        'Goth' => 'gotek',
        'Grek' => 'gresianek',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han gant bopomofo',
        'Hang' => 'hangeul',
        'Hani' => 'sinalunioù (han)',
        'Hans' => 'eeunaet',
        'Hant' => 'hengounel',
        'Hebr' => 'hebraek',
        'Hira' => 'hiragana',
        'Hluw' => 'hieroglifoù Anatolia',
        'Hrkt' => 'silabennaouegoù japanek',
        'Hung' => 'henhungarek',
        'Ital' => 'henitalek',
        'Jamo' => 'jamo',
        'Java' => 'javanek',
        'Jpan' => 'japanek',
        'Kana' => 'katakana',
        'Khmr' => 'khmer',
        'Knda' => 'kannada',
        'Kore' => 'koreanek',
        'Laoo' => 'laosek',
        'Latg' => 'latin gouezelek',
        'Latn' => 'latin',
        'Lyci' => 'likiek',
        'Lydi' => 'lidiek',
        'Mani' => 'manikeek',
        'Maya' => 'hieroglifoù mayaek',
        'Mlym' => 'malayalam',
        'Mong' => 'mongolek',
        'Mymr' => 'myanmar',
        'Narb' => 'henarabek an Norzh',
        'Ogam' => 'ogam',
        'Orya' => 'oriya',
        'Phnx' => 'fenikianek',
        'Runr' => 'runek',
        'Samr' => 'samaritek',
        'Sarb' => 'henarabek ar Su',
        'Sinh' => 'singhalek',
        'Sund' => 'sundanek',
        'Syrc' => 'siriek',
        'Syre' => 'siriek Estrangelā',
        'Syrj' => 'siriek ar C’hornôg',
        'Syrn' => 'siriek ar Reter',
        'Taml' => 'tamilek',
        'Telu' => 'telougou',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'thai',
        'Tibt' => 'tibetanek',
        'Ugar' => 'ougaritek',
        'Vaii' => 'vai',
        'Xpeo' => 'persek kozh',
        'Xsux' => 'gennheñvel',
        'Zinh' => 'hêrezh',
        'Zmth' => 'notadur jedoniel',
        'Zsye' => 'fromlunioù',
        'Zsym' => 'arouezioù',
        'Zxxx' => 'anskrivet',
        'Zyyy' => 'boutin',
    ],
];
