<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Waktu Min Greenwich (Abidjan)',
        'Africa/Accra' => 'Waktu Min Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Waktu Afrika Timur (Addis Ababa)',
        'Africa/Algiers' => 'Waktu Eropah Tengah (Algiers)',
        'Africa/Asmera' => 'Waktu Afrika Timur (Asmara)',
        'Africa/Bamako' => 'Waktu Min Greenwich (Bamako)',
        'Africa/Bangui' => 'Waktu Afrika Barat (Bangui)',
        'Africa/Banjul' => 'Waktu Min Greenwich (Banjul)',
        'Africa/Bissau' => 'Waktu Min Greenwich (Bissau)',
        'Africa/Blantyre' => 'Waktu Afrika Tengah (Blantyre)',
        'Africa/Brazzaville' => 'Waktu Afrika Barat (Brazzaville)',
        'Africa/Bujumbura' => 'Waktu Afrika Tengah (Bujumbura)',
        'Africa/Cairo' => 'Waktu Eropah Timur (Kaherah)',
        'Africa/Casablanca' => 'Waktu Eropah Barat (Casablanca)',
        'Africa/Ceuta' => 'Waktu Eropah Tengah (Ceuta)',
        'Africa/Conakry' => 'Waktu Min Greenwich (Conakry)',
        'Africa/Dakar' => 'Waktu Min Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Waktu Afrika Timur (Dar es Salaam)',
        'Africa/Djibouti' => 'Waktu Afrika Timur (Djibouti)',
        'Africa/Douala' => 'Waktu Afrika Barat (Douala)',
        'Africa/El_Aaiun' => 'Waktu Eropah Barat (El Aaiun)',
        'Africa/Freetown' => 'Waktu Min Greenwich (Freetown)',
        'Africa/Gaborone' => 'Waktu Afrika Tengah (Gaborone)',
        'Africa/Harare' => 'Waktu Afrika Tengah (Harare)',
        'Africa/Johannesburg' => 'Waktu Piawai Afrika Selatan (Johannesburg)',
        'Africa/Juba' => 'Waktu Afrika Tengah (Juba)',
        'Africa/Kampala' => 'Waktu Afrika Timur (Kampala)',
        'Africa/Khartoum' => 'Waktu Afrika Tengah (Khartoum)',
        'Africa/Kigali' => 'Waktu Afrika Tengah (Kigali)',
        'Africa/Kinshasa' => 'Waktu Afrika Barat (Kinshasa)',
        'Africa/Lagos' => 'Waktu Afrika Barat (Lagos)',
        'Africa/Libreville' => 'Waktu Afrika Barat (Libreville)',
        'Africa/Lome' => 'Waktu Min Greenwich (Lome)',
        'Africa/Luanda' => 'Waktu Afrika Barat (Luanda)',
        'Africa/Lubumbashi' => 'Waktu Afrika Tengah (Lubumbashi)',
        'Africa/Lusaka' => 'Waktu Afrika Tengah (Lusaka)',
        'Africa/Malabo' => 'Waktu Afrika Barat (Malabo)',
        'Africa/Maputo' => 'Waktu Afrika Tengah (Maputo)',
        'Africa/Maseru' => 'Waktu Piawai Afrika Selatan (Maseru)',
        'Africa/Mbabane' => 'Waktu Piawai Afrika Selatan (Mbabane)',
        'Africa/Mogadishu' => 'Waktu Afrika Timur (Mogadishu)',
        'Africa/Monrovia' => 'Waktu Min Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Waktu Afrika Timur (Nairobi)',
        'Africa/Ndjamena' => 'Waktu Afrika Barat (Ndjamena)',
        'Africa/Niamey' => 'Waktu Afrika Barat (Niamey)',
        'Africa/Nouakchott' => 'Waktu Min Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Waktu Min Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Waktu Afrika Barat (Porto-Novo)',
        'Africa/Sao_Tome' => 'Waktu Min Greenwich (Sao Tome)',
        'Africa/Tripoli' => 'Waktu Eropah Timur (Tripoli)',
        'Africa/Tunis' => 'Waktu Eropah Tengah (Tunis)',
        'Africa/Windhoek' => 'Waktu Afrika Tengah (Windhoek)',
        'America/Adak' => 'Waktu Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Waktu Alaska (Anchorage)',
        'America/Anguilla' => 'Waktu Atlantik (Anguilla)',
        'America/Antigua' => 'Waktu Atlantik (Antigua)',
        'America/Araguaina' => 'Waktu Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'Waktu Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Waktu Argentina (Rio Gallegos)',
        'America/Argentina/Salta' => 'Waktu Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Waktu Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Waktu Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Waktu Argentina (Tucuman)',
        'America/Argentina/Ushuaia' => 'Waktu Argentina (Ushuaia)',
        'America/Aruba' => 'Waktu Atlantik (Aruba)',
        'America/Asuncion' => 'Waktu Paraguay (Asuncion)',
        'America/Bahia' => 'Waktu Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Waktu Pusat (Bahia Banderas)',
        'America/Barbados' => 'Waktu Atlantik (Barbados)',
        'America/Belem' => 'Waktu Brasilia (Belem)',
        'America/Belize' => 'Waktu Pusat (Belize)',
        'America/Blanc-Sablon' => 'Waktu Atlantik (Blanc-Sablon)',
        'America/Boa_Vista' => 'Waktu Amazon (Boa Vista)',
        'America/Bogota' => 'Waktu Colombia (Bogota)',
        'America/Boise' => 'Waktu Pergunungan (Boise)',
        'America/Buenos_Aires' => 'Waktu Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Waktu Pergunungan (Teluk Cambridge)',
        'America/Campo_Grande' => 'Waktu Amazon (Campo Grande)',
        'America/Cancun' => 'Waktu Timur (Cancun)',
        'America/Caracas' => 'Waktu Venezuela (Caracas)',
        'America/Catamarca' => 'Waktu Argentina (Catamarca)',
        'America/Cayenne' => 'Waktu Guyana Perancis (Cayenne)',
        'America/Cayman' => 'Waktu Timur (Cayman)',
        'America/Chicago' => 'Waktu Pusat (Chicago)',
        'America/Chihuahua' => 'Waktu Pasifik Mexico (Chihuahua)',
        'America/Coral_Harbour' => 'Waktu Timur (Atikokan)',
        'America/Cordoba' => 'Waktu Argentina (Cordoba)',
        'America/Costa_Rica' => 'Waktu Pusat (Costa Rica)',
        'America/Creston' => 'Waktu Pergunungan (Creston)',
        'America/Cuiaba' => 'Waktu Amazon (Cuiaba)',
        'America/Curacao' => 'Waktu Atlantik (Curacao)',
        'America/Danmarkshavn' => 'Waktu Min Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Masa Yukon (Dawson)',
        'America/Dawson_Creek' => 'Waktu Pergunungan (Dawson Creek)',
        'America/Denver' => 'Waktu Pergunungan (Denver)',
        'America/Detroit' => 'Waktu Timur (Detroit)',
        'America/Dominica' => 'Waktu Atlantik (Dominica)',
        'America/Edmonton' => 'Waktu Pergunungan (Edmonton)',
        'America/Eirunepe' => 'Waktu Acre (Eirunepe)',
        'America/El_Salvador' => 'Waktu Pusat (El Salvador)',
        'America/Fort_Nelson' => 'Waktu Pergunungan (Fort Nelson)',
        'America/Fortaleza' => 'Waktu Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Waktu Atlantik (Teluk Glace)',
        'America/Godthab' => 'Waktu Greenland Barat (Nuuk)',
        'America/Goose_Bay' => 'Waktu Atlantik (Teluk Goose)',
        'America/Grand_Turk' => 'Waktu Timur (Grand Turk)',
        'America/Grenada' => 'Waktu Atlantik (Grenada)',
        'America/Guadeloupe' => 'Waktu Atlantik (Guadeloupe)',
        'America/Guatemala' => 'Waktu Pusat (Guatemala)',
        'America/Guayaquil' => 'Waktu Ecuador (Guayaquil)',
        'America/Guyana' => 'Waktu Guyana',
        'America/Halifax' => 'Waktu Atlantik (Halifax)',
        'America/Havana' => 'Waktu Cuba (Havana)',
        'America/Hermosillo' => 'Waktu Pasifik Mexico (Hermosillo)',
        'America/Indiana/Knox' => 'Waktu Pusat (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Waktu Timur (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Waktu Timur (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Waktu Pusat (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Waktu Timur (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Waktu Timur (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Waktu Timur (Winamac, Indiana)',
        'America/Indianapolis' => 'Waktu Timur (Indianapolis)',
        'America/Inuvik' => 'Waktu Pergunungan (Inuvik)',
        'America/Iqaluit' => 'Waktu Timur (Iqaluit)',
        'America/Jamaica' => 'Waktu Timur (Jamaica)',
        'America/Jujuy' => 'Waktu Argentina (Jujuy)',
        'America/Juneau' => 'Waktu Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Waktu Timur (Monticello, Kentucky)',
        'America/Kralendijk' => 'Waktu Atlantik (Kralendijk)',
        'America/La_Paz' => 'Waktu Bolivia (La Paz)',
        'America/Lima' => 'Waktu Peru (Lima)',
        'America/Los_Angeles' => 'Waktu Pasifik (Los Angeles)',
        'America/Louisville' => 'Waktu Timur (Louisville)',
        'America/Lower_Princes' => 'Waktu Atlantik (Lower Prince’s Quarter)',
        'America/Maceio' => 'Waktu Brasilia (Maceio)',
        'America/Managua' => 'Waktu Pusat (Managua)',
        'America/Manaus' => 'Waktu Amazon (Manaus)',
        'America/Marigot' => 'Waktu Atlantik (Marigot)',
        'America/Martinique' => 'Waktu Atlantik (Martinique)',
        'America/Matamoros' => 'Waktu Pusat (Matamoros)',
        'America/Mazatlan' => 'Waktu Pasifik Mexico (Mazatlan)',
        'America/Mendoza' => 'Waktu Argentina (Mendoza)',
        'America/Menominee' => 'Waktu Pusat (Menominee)',
        'America/Merida' => 'Waktu Pusat (Merida)',
        'America/Metlakatla' => 'Waktu Alaska (Metlakatla)',
        'America/Mexico_City' => 'Waktu Pusat (Mexico City)',
        'America/Miquelon' => 'Waktu Saint Pierre dan Miquelon',
        'America/Moncton' => 'Waktu Atlantik (Moncton)',
        'America/Monterrey' => 'Waktu Pusat (Monterrey)',
        'America/Montevideo' => 'Waktu Uruguay (Montevideo)',
        'America/Montreal' => 'Waktu Kanada (Montreal)',
        'America/Montserrat' => 'Waktu Atlantik (Montserrat)',
        'America/Nassau' => 'Waktu Timur (Nassau)',
        'America/New_York' => 'Waktu Timur (New York)',
        'America/Nipigon' => 'Waktu Timur (Nipigon)',
        'America/Nome' => 'Waktu Alaska (Nome)',
        'America/Noronha' => 'Waktu Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Waktu Pusat (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Waktu Pusat (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Waktu Pusat (New Salem, North Dakota)',
        'America/Ojinaga' => 'Waktu Pergunungan (Ojinaga)',
        'America/Panama' => 'Waktu Timur (Panama)',
        'America/Pangnirtung' => 'Waktu Timur (Pangnirtung)',
        'America/Paramaribo' => 'Waktu Suriname (Paramaribo)',
        'America/Phoenix' => 'Waktu Pergunungan (Phoenix)',
        'America/Port-au-Prince' => 'Waktu Timur (Port-au-Prince)',
        'America/Port_of_Spain' => 'Waktu Atlantik (Port of Spain)',
        'America/Porto_Velho' => 'Waktu Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'Waktu Atlantik (Puerto Rico)',
        'America/Punta_Arenas' => 'Waktu Chile (Punta Arenas)',
        'America/Rainy_River' => 'Waktu Pusat (Sungai Rainy)',
        'America/Rankin_Inlet' => 'Waktu Pusat (Rankin Inlet)',
        'America/Recife' => 'Waktu Brasilia (Recife)',
        'America/Regina' => 'Waktu Pusat (Regina)',
        'America/Resolute' => 'Waktu Pusat (Resolute)',
        'America/Rio_Branco' => 'Waktu Acre (Rio Branco)',
        'America/Santa_Isabel' => 'Waktu Barat Laut Mexico (Santa Isabel)',
        'America/Santarem' => 'Waktu Brasilia (Santarem)',
        'America/Santiago' => 'Waktu Chile (Santiago)',
        'America/Santo_Domingo' => 'Waktu Atlantik (Santo Domingo)',
        'America/Sao_Paulo' => 'Waktu Brasilia (Sao Paulo)',
        'America/Scoresbysund' => 'Waktu Greenland Timur (Ittoqqortoormiit)',
        'America/Sitka' => 'Waktu Alaska (Sitka)',
        'America/St_Barthelemy' => 'Waktu Atlantik (Saint Barthelemy)',
        'America/St_Johns' => 'Waktu Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Waktu Atlantik (St. Kitts)',
        'America/St_Lucia' => 'Waktu Atlantik (St. Lucia)',
        'America/St_Thomas' => 'Waktu Atlantik (St. Thomas)',
        'America/St_Vincent' => 'Waktu Atlantik (St. Vincent)',
        'America/Swift_Current' => 'Waktu Pusat (Swift Current)',
        'America/Tegucigalpa' => 'Waktu Pusat (Tegucigalpa)',
        'America/Thule' => 'Waktu Atlantik (Thule)',
        'America/Thunder_Bay' => 'Waktu Timur (Thunder Bay)',
        'America/Tijuana' => 'Waktu Pasifik (Tijuana)',
        'America/Toronto' => 'Waktu Timur (Toronto)',
        'America/Tortola' => 'Waktu Atlantik (Tortola)',
        'America/Vancouver' => 'Waktu Pasifik (Vancouver)',
        'America/Whitehorse' => 'Masa Yukon (Whitehorse)',
        'America/Winnipeg' => 'Waktu Pusat (Winnipeg)',
        'America/Yakutat' => 'Waktu Alaska (Yakutat)',
        'America/Yellowknife' => 'Waktu Pergunungan (Yellowknife)',
        'Antarctica/Casey' => 'Waktu Antartika (Casey)',
        'Antarctica/Davis' => 'Waktu Davis',
        'Antarctica/DumontDUrville' => 'Waktu Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Waktu Australia Timur (Macquarie)',
        'Antarctica/Mawson' => 'Waktu Mawson',
        'Antarctica/McMurdo' => 'Waktu New Zealand (McMurdo)',
        'Antarctica/Palmer' => 'Waktu Chile (Palmer)',
        'Antarctica/Rothera' => 'Waktu Rothera',
        'Antarctica/Syowa' => 'Waktu Syowa',
        'Antarctica/Troll' => 'Waktu Min Greenwich (Troll)',
        'Antarctica/Vostok' => 'Waktu Vostok',
        'Arctic/Longyearbyen' => 'Waktu Eropah Tengah (Longyearbyen)',
        'Asia/Aden' => 'Waktu Arab (Aden)',
        'Asia/Almaty' => 'Waktu Kazakhstan Timur (Almaty)',
        'Asia/Amman' => 'Waktu Eropah Timur (Amman)',
        'Asia/Anadyr' => 'Waktu Anadyr',
        'Asia/Aqtau' => 'Waktu Kazakhstan Barat (Aqtau)',
        'Asia/Aqtobe' => 'Waktu Kazakhstan Barat (Aqtobe)',
        'Asia/Ashgabat' => 'Waktu Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Waktu Kazakhstan Barat (Atyrau)',
        'Asia/Baghdad' => 'Waktu Arab (Baghdad)',
        'Asia/Bahrain' => 'Waktu Arab (Bahrain)',
        'Asia/Baku' => 'Waktu Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Waktu Indochina (Bangkok)',
        'Asia/Barnaul' => 'Waktu Rusia (Barnaul)',
        'Asia/Beirut' => 'Waktu Eropah Timur (Beirut)',
        'Asia/Bishkek' => 'Waktu Kyrgystan (Bishkek)',
        'Asia/Brunei' => 'Waktu Brunei Darussalam',
        'Asia/Calcutta' => 'Waktu Piawai India (Kolkata)',
        'Asia/Chita' => 'Waktu Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Waktu Ulan Bator (Choibalsan)',
        'Asia/Colombo' => 'Waktu Piawai India (Colombo)',
        'Asia/Damascus' => 'Waktu Eropah Timur (Damsyik)',
        'Asia/Dhaka' => 'Waktu Bangladesh (Dhaka)',
        'Asia/Dili' => 'Waktu Timor Timur (Dili)',
        'Asia/Dubai' => 'Waktu Piawai Teluk (Dubai)',
        'Asia/Dushanbe' => 'Waktu Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Waktu Eropah Timur (Famagusta)',
        'Asia/Gaza' => 'Waktu Eropah Timur (Gaza)',
        'Asia/Hebron' => 'Waktu Eropah Timur (Hebron)',
        'Asia/Hong_Kong' => 'Waktu Hong Kong',
        'Asia/Hovd' => 'Waktu Hovd',
        'Asia/Irkutsk' => 'Waktu Irkutsk',
        'Asia/Jakarta' => 'Waktu Indonesia Barat (Jakarta)',
        'Asia/Jayapura' => 'Waktu Indonesia Timur (Jayapura)',
        'Asia/Jerusalem' => 'Waktu Israel (Baitulmuqaddis)',
        'Asia/Kabul' => 'Waktu Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Waktu Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Waktu Pakistan (Karachi)',
        'Asia/Katmandu' => 'Waktu Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Waktu Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Waktu Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Waktu Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Waktu Malaysia (Kuching)',
        'Asia/Kuwait' => 'Waktu Arab (Kuwait)',
        'Asia/Macau' => 'Waktu China (Macau)',
        'Asia/Magadan' => 'Waktu Magadan',
        'Asia/Makassar' => 'Waktu Indonesia Tengah (Makassar)',
        'Asia/Manila' => 'Waktu Filipina (Manila)',
        'Asia/Muscat' => 'Waktu Piawai Teluk (Muscat)',
        'Asia/Nicosia' => 'Waktu Eropah Timur (Nicosia)',
        'Asia/Novokuznetsk' => 'Waktu Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Waktu Novosibirsk',
        'Asia/Omsk' => 'Waktu Omsk',
        'Asia/Oral' => 'Waktu Kazakhstan Barat (Oral)',
        'Asia/Phnom_Penh' => 'Waktu Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Waktu Indonesia Barat (Pontianak)',
        'Asia/Pyongyang' => 'Waktu Korea (Pyongyang)',
        'Asia/Qatar' => 'Waktu Arab (Qatar)',
        'Asia/Qostanay' => 'Waktu Kazakhstan Timur (Kostanay)',
        'Asia/Qyzylorda' => 'Waktu Kazakhstan Barat (Qyzylorda)',
        'Asia/Rangoon' => 'Waktu Myanmar (Yangon)',
        'Asia/Riyadh' => 'Waktu Arab (Riyadh)',
        'Asia/Saigon' => 'Waktu Indochina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Waktu Sakhalin',
        'Asia/Samarkand' => 'Waktu Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'Waktu Korea (Seoul)',
        'Asia/Shanghai' => 'Waktu China (Shanghai)',
        'Asia/Singapore' => 'Waktu Piawai Singapura',
        'Asia/Srednekolymsk' => 'Waktu Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Waktu Taipei',
        'Asia/Tashkent' => 'Waktu Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Waktu Georgia (Tbilisi)',
        'Asia/Tehran' => 'Waktu Iran (Tehran)',
        'Asia/Thimphu' => 'Waktu Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Waktu Jepun (Tokyo)',
        'Asia/Tomsk' => 'Waktu Rusia (Tomsk)',
        'Asia/Ulaanbaatar' => 'Waktu Ulan Bator (Ulaanbaatar)',
        'Asia/Urumqi' => 'Waktu China (Urumqi)',
        'Asia/Ust-Nera' => 'Waktu Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Waktu Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Waktu Vladivostok',
        'Asia/Yakutsk' => 'Waktu Yakutsk',
        'Asia/Yekaterinburg' => 'Waktu Yekaterinburg',
        'Asia/Yerevan' => 'Waktu Armenia (Yerevan)',
        'Atlantic/Azores' => 'Waktu Azores',
        'Atlantic/Bermuda' => 'Waktu Atlantik (Bermuda)',
        'Atlantic/Canary' => 'Waktu Eropah Barat (Canary)',
        'Atlantic/Cape_Verde' => 'Waktu Tanjung Verde (Cape Verde)',
        'Atlantic/Faeroe' => 'Waktu Eropah Barat (Faroe)',
        'Atlantic/Madeira' => 'Waktu Eropah Barat (Madeira)',
        'Atlantic/Reykjavik' => 'Waktu Min Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Waktu Georgia Selatan (South Georgia)',
        'Atlantic/St_Helena' => 'Waktu Min Greenwich (St. Helena)',
        'Atlantic/Stanley' => 'Waktu Kepulauan Falkland (Stanley)',
        'Australia/Adelaide' => 'Waktu Australia Tengah (Adelaide)',
        'Australia/Brisbane' => 'Waktu Australia Timur (Brisbane)',
        'Australia/Broken_Hill' => 'Waktu Australia Tengah (Broken Hill)',
        'Australia/Currie' => 'Waktu Australia Timur (Currie)',
        'Australia/Darwin' => 'Waktu Australia Tengah (Darwin)',
        'Australia/Eucla' => 'Waktu Barat Tengah Australia (Eucla)',
        'Australia/Hobart' => 'Waktu Australia Timur (Hobart)',
        'Australia/Lindeman' => 'Waktu Australia Timur (Lindeman)',
        'Australia/Lord_Howe' => 'Waktu Lord Howe',
        'Australia/Melbourne' => 'Waktu Australia Timur (Melbourne)',
        'Australia/Perth' => 'Waktu Australia Barat (Perth)',
        'Australia/Sydney' => 'Waktu Australia Timur (Sydney)',
        'CST6CDT' => 'Waktu Pusat',
        'EST5EDT' => 'Waktu Timur',
        'Etc/GMT' => 'Waktu Min Greenwich',
        'Etc/UTC' => 'Waktu Universal Selaras',
        'Europe/Amsterdam' => 'Waktu Eropah Tengah (Amsterdam)',
        'Europe/Andorra' => 'Waktu Eropah Tengah (Andorra)',
        'Europe/Astrakhan' => 'Waktu Moscow (Astrakhan)',
        'Europe/Athens' => 'Waktu Eropah Timur (Athens)',
        'Europe/Belgrade' => 'Waktu Eropah Tengah (Belgrade)',
        'Europe/Berlin' => 'Waktu Eropah Tengah (Berlin)',
        'Europe/Bratislava' => 'Waktu Eropah Tengah (Bratislava)',
        'Europe/Brussels' => 'Waktu Eropah Tengah (Brussels)',
        'Europe/Bucharest' => 'Waktu Eropah Timur (Bucharest)',
        'Europe/Budapest' => 'Waktu Eropah Tengah (Budapest)',
        'Europe/Busingen' => 'Waktu Eropah Tengah (Busingen)',
        'Europe/Chisinau' => 'Waktu Eropah Timur (Chisinau)',
        'Europe/Copenhagen' => 'Waktu Eropah Tengah (Copenhagen)',
        'Europe/Dublin' => 'Waktu Min Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Waktu Eropah Tengah (Gibraltar)',
        'Europe/Guernsey' => 'Waktu Min Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Waktu Eropah Timur (Helsinki)',
        'Europe/Isle_of_Man' => 'Waktu Min Greenwich (Isle of Man)',
        'Europe/Istanbul' => 'Waktu Turki (Istanbul)',
        'Europe/Jersey' => 'Waktu Min Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Waktu Eropah Timur (Kaliningrad)',
        'Europe/Kiev' => 'Waktu Eropah Timur (Kiev)',
        'Europe/Kirov' => 'Waktu Rusia (Kirov)',
        'Europe/Lisbon' => 'Waktu Eropah Barat (Lisbon)',
        'Europe/Ljubljana' => 'Waktu Eropah Tengah (Ljubljana)',
        'Europe/London' => 'Waktu Min Greenwich (London)',
        'Europe/Luxembourg' => 'Waktu Eropah Tengah (Luxembourg)',
        'Europe/Madrid' => 'Waktu Eropah Tengah (Madrid)',
        'Europe/Malta' => 'Waktu Eropah Tengah (Malta)',
        'Europe/Mariehamn' => 'Waktu Eropah Timur (Mariehamn)',
        'Europe/Minsk' => 'Waktu Moscow (Minsk)',
        'Europe/Monaco' => 'Waktu Eropah Tengah (Monaco)',
        'Europe/Moscow' => 'Waktu Moscow',
        'Europe/Oslo' => 'Waktu Eropah Tengah (Oslo)',
        'Europe/Paris' => 'Waktu Eropah Tengah (Paris)',
        'Europe/Podgorica' => 'Waktu Eropah Tengah (Podgorica)',
        'Europe/Prague' => 'Waktu Eropah Tengah (Prague)',
        'Europe/Riga' => 'Waktu Eropah Timur (Riga)',
        'Europe/Rome' => 'Waktu Eropah Tengah (Rome)',
        'Europe/Samara' => 'Waktu Samara',
        'Europe/San_Marino' => 'Waktu Eropah Tengah (San Marino)',
        'Europe/Sarajevo' => 'Waktu Eropah Tengah (Sarajevo)',
        'Europe/Saratov' => 'Waktu Moscow (Saratov)',
        'Europe/Simferopol' => 'Waktu Moscow (Simferopol)',
        'Europe/Skopje' => 'Waktu Eropah Tengah (Skopje)',
        'Europe/Sofia' => 'Waktu Eropah Timur (Sofia)',
        'Europe/Stockholm' => 'Waktu Eropah Tengah (Stockholm)',
        'Europe/Tallinn' => 'Waktu Eropah Timur (Tallinn)',
        'Europe/Tirane' => 'Waktu Eropah Tengah (Tirane)',
        'Europe/Ulyanovsk' => 'Waktu Moscow (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Waktu Eropah Timur (Uzhgorod)',
        'Europe/Vaduz' => 'Waktu Eropah Tengah (Vaduz)',
        'Europe/Vatican' => 'Waktu Eropah Tengah (Vatican)',
        'Europe/Vienna' => 'Waktu Eropah Tengah (Vienna)',
        'Europe/Vilnius' => 'Waktu Eropah Timur (Vilnius)',
        'Europe/Volgograd' => 'Waktu Volgograd',
        'Europe/Warsaw' => 'Waktu Eropah Tengah (Warsaw)',
        'Europe/Zagreb' => 'Waktu Eropah Tengah (Zagreb)',
        'Europe/Zaporozhye' => 'Waktu Eropah Timur (Zaporozhye)',
        'Europe/Zurich' => 'Waktu Eropah Tengah (Zurich)',
        'Indian/Antananarivo' => 'Waktu Afrika Timur (Antananarivo)',
        'Indian/Chagos' => 'Waktu Lautan Hindi (Chagos)',
        'Indian/Christmas' => 'Waktu Pulau Christmas',
        'Indian/Cocos' => 'Waktu Kepulauan Cocos',
        'Indian/Comoro' => 'Waktu Afrika Timur (Comoro)',
        'Indian/Kerguelen' => 'Waktu Perancis Selatan dan Antartika (Kerguelen)',
        'Indian/Mahe' => 'Waktu Seychelles (Mahe)',
        'Indian/Maldives' => 'Waktu Maldives',
        'Indian/Mauritius' => 'Waktu Mauritius',
        'Indian/Mayotte' => 'Waktu Afrika Timur (Mayotte)',
        'Indian/Reunion' => 'Waktu Reunion',
        'MST7MDT' => 'Waktu Pergunungan',
        'PST8PDT' => 'Waktu Pasifik',
        'Pacific/Apia' => 'Waktu Apia',
        'Pacific/Auckland' => 'Waktu New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Waktu Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Waktu Chatham',
        'Pacific/Easter' => 'Waktu Pulau Easter',
        'Pacific/Efate' => 'Waktu Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Waktu Kepulauan Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'Waktu Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Waktu Fiji',
        'Pacific/Funafuti' => 'Waktu Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Waktu Galapagos',
        'Pacific/Gambier' => 'Waktu Gambier',
        'Pacific/Guadalcanal' => 'Waktu Kepulauan Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Waktu Piawai Chamorro (Guam)',
        'Pacific/Honolulu' => 'Waktu Hawaii-Aleutian (Honolulu)',
        'Pacific/Johnston' => 'Waktu Hawaii-Aleutian (Johnston)',
        'Pacific/Kiritimati' => 'Waktu Kepulauan Line (Kiritimati)',
        'Pacific/Kosrae' => 'Waktu Kosrae',
        'Pacific/Kwajalein' => 'Waktu Kepulauan Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Waktu Kepulauan Marshall (Majuro)',
        'Pacific/Marquesas' => 'Waktu Marquesas',
        'Pacific/Midway' => 'Waktu Samoa (Midway)',
        'Pacific/Nauru' => 'Waktu Nauru',
        'Pacific/Niue' => 'Waktu Niue',
        'Pacific/Norfolk' => 'Waktu Kepulauan Norfolk',
        'Pacific/Noumea' => 'Waktu New Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'Waktu Samoa (Pago Pago)',
        'Pacific/Palau' => 'Waktu Palau',
        'Pacific/Pitcairn' => 'Waktu Pitcairn',
        'Pacific/Ponape' => 'Waktu Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Waktu Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Waktu Kepulauan Cook (Rarotonga)',
        'Pacific/Saipan' => 'Waktu Piawai Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Waktu Tahiti',
        'Pacific/Tarawa' => 'Waktu Kepulauan Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Waktu Tonga (Tongatapu)',
        'Pacific/Truk' => 'Waktu Chuuk',
        'Pacific/Wake' => 'Waktu Pulau Wake',
        'Pacific/Wallis' => 'Waktu Wallis dan Futuna',
    ],
    'Meta' => [
    ],
];
