<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abchazysk',
        'ace' => 'Atjeesk',
        'ach' => 'Akoli',
        'ada' => 'Adangme',
        'ady' => 'Adyghe',
        'ae' => 'Avestysk',
        'af' => 'Afrikaansk',
        'afh' => 'Afrihili',
        'agq' => 'Aghem',
        'ain' => 'Ainu',
        'ak' => 'Akan',
        'akk' => 'Akkadysk',
        'ale' => 'Aleut',
        'alt' => 'Sûd-Altaïsk',
        'am' => 'Amhaarsk',
        'an' => 'Aragoneesk',
        'ang' => 'âldingelsk',
        'anp' => 'Angika',
        'ar' => 'Arabysk',
        'arc' => 'Arameesk',
        'arn' => 'Araukaansk',
        'arp' => 'Arapaho',
        'arw' => 'Arawak',
        'as' => 'Assameesk',
        'asa' => 'Asu',
        'ast' => 'Asturysk',
        'av' => 'Avarysk',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Azerbeidzjaansk',
        'ba' => 'Basjkiersk',
        'bal' => 'Baloetsjysk',
        'ban' => 'Balineesk',
        'bas' => 'Basa',
        'bax' => 'Bamoun',
        'bbj' => 'Ghomala’',
        'be' => 'Wyt-Russysk',
        'bej' => 'Beja',
        'bem' => 'Bemba',
        'bez' => 'Bena',
        'bfd' => 'Bafut',
        'bg' => 'Bulgaarsk',
        'bho' => 'Bhojpuri',
        'bi' => 'Bislama',
        'bik' => 'Bikol',
        'bin' => 'Bini',
        'bkm' => 'Kom',
        'bla' => 'Siksika',
        'bm' => 'Bambara',
        'bn' => 'Bengaalsk',
        'bo' => 'Tibetaansk',
        'br' => 'Bretonsk',
        'bra' => 'Braj',
        'brx' => 'Bodo',
        'bs' => 'Bosnysk',
        'bss' => 'Akoose',
        'bua' => 'Buriat',
        'bug' => 'Bugineesk',
        'bum' => 'Bulu',
        'byn' => 'Blin',
        'byv' => 'Medumba',
        'ca' => 'Katalaansk',
        'cad' => 'Kaddo',
        'car' => 'Karibysk',
        'cay' => 'Cayuga',
        'cch' => 'Atsam',
        'ce' => 'Tsjetsjeensk',
        'ceb' => 'Cebuano',
        'cgg' => 'Chiga',
        'ch' => 'Chamorro',
        'chb' => 'Chibcha',
        'chg' => 'Chagatai',
        'chk' => 'Chuukeesk',
        'chm' => 'Mari',
        'chn' => 'Chinook-jargon',
        'cho' => 'Choctaw',
        'chp' => 'Chipewyan',
        'chr' => 'Cherokee',
        'chy' => 'Cheyenne',
        'ckb' => 'Soranî',
        'co' => 'Korsikaansk',
        'cop' => 'Koptysk',
        'cr' => 'Cree',
        'crh' => 'Krim-Tataarsk',
        'cs' => 'Tsjechysk',
        'csb' => 'Kasjoebysk',
        'cu' => 'Kerkslavysk',
        'cv' => 'Tsjoevasjysk',
        'cy' => 'Welsk',
        'da' => 'Deensk',
        'dak' => 'Dakota',
        'dar' => 'Dargwa',
        'dav' => 'Taita',
        'de' => 'Dútsk',
        'del' => 'Delaware',
        'den' => 'Slave',
        'dgr' => 'Dogrib',
        'din' => 'Dinka',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Nedersorbysk',
        'dua' => 'Duala',
        'dum' => 'Middelnederlânsk',
        'dv' => 'Divehi',
        'dyo' => 'Jola-Fonyi',
        'dyu' => 'Dyula',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embu',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'egy' => 'Aldegyptysk',
        'eka' => 'Ekajuk',
        'el' => 'Gryks',
        'elx' => 'Elamitysk',
        'en' => 'Ingelsk',
        'enm' => 'Middelingelsk',
        'eo' => 'Esperanto',
        'es' => 'Spaansk',
        'et' => 'Estlânsk',
        'eu' => 'Baskysk',
        'ewo' => 'Ewondo',
        'fa' => 'Perzysk',
        'fan' => 'Fang',
        'fat' => 'Fanti',
        'ff' => 'Fulah',
        'fi' => 'Finsk',
        'fil' => 'Filipynsk',
        'fj' => 'Fijysk',
        'fo' => 'Faeröersk',
        'fon' => 'Fon',
        'fr' => 'Frânsk',
        'frm' => 'Middelfrânsk',
        'fro' => 'Aldfrânsk',
        'frr' => 'Noard-Frysk',
        'frs' => 'East-Frysk',
        'fur' => 'Friulysk',
        'fy' => 'Frysk',
        'ga' => 'Iersk',
        'gaa' => 'Ga',
        'gay' => 'Gayo',
        'gba' => 'Gbaya',
        'gd' => 'Schotsk Gaelic',
        'gez' => 'Geez',
        'gil' => 'Gilberteesk',
        'gl' => 'Galisysk',
        'gmh' => 'Middelheechdútsk',
        'gn' => 'Guaraní',
        'goh' => 'Alsheechdútsk',
        'gon' => 'Gondi',
        'gor' => 'Gorontalo',
        'got' => 'Gothysk',
        'grb' => 'Grebo',
        'grc' => 'Aldgryks',
        'gsw' => 'Switsers Dútsk',
        'gu' => 'Gujarati',
        'guz' => 'Gusii',
        'gv' => 'Manks',
        'gwi' => 'Gwichʼin',
        'ha' => 'Hausa',
        'hai' => 'Haida',
        'haw' => 'Hawaïaansk',
        'he' => 'Hebreeuwsk',
        'hi' => 'Hindi',
        'hil' => 'Hiligaynon',
        'hit' => 'Hettitysk',
        'hmn' => 'Hmong',
        'ho' => 'Hiri Motu',
        'hr' => 'Kroatysk',
        'hsb' => 'Oppersorbysk',
        'ht' => 'Haïtiaansk',
        'hu' => 'Hongaarsk',
        'hup' => 'Hupa',
        'hy' => 'Armeensk',
        'hz' => 'Herero',
        'ia' => 'Interlingua',
        'iba' => 'Iban',
        'ibb' => 'Ibibio',
        'id' => 'Yndonezysk',
        'ie' => 'Interlingue',
        'ig' => 'Igbo',
        'ii' => 'Sichuan Yi',
        'ik' => 'Inupiaq',
        'ilo' => 'Iloko',
        'inh' => 'Ingoesj',
        'io' => 'Ido',
        'is' => 'Yslâns',
        'it' => 'Italiaansk',
        'iu' => 'Inuktitut',
        'ja' => 'Japans',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jpr' => 'Judeo-Perzysk',
        'jrb' => 'Judeo-Arabysk',
        'jv' => 'Javaansk',
        'ka' => 'Georgysk',
        'kaa' => 'Karakalpaks',
        'kab' => 'Kabyle',
        'kac' => 'Kachin',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kaw' => 'Kawi',
        'kbd' => 'Kabardysk',
        'kbl' => 'Kanembu',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kaapverdysk Creools',
        'kfo' => 'Koro',
        'kg' => 'Kongo',
        'kha' => 'Khasi',
        'kho' => 'Khotaneesk',
        'khq' => 'Koyra Chiini',
        'ki' => 'Kikuyu',
        'kj' => 'Kuanyama',
        'kk' => 'Kazachs',
        'kkj' => 'Kako',
        'kl' => 'Grienlâns',
        'kln' => 'Kalenjin',
        'km' => 'Khmer',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada',
        'ko' => 'Koreaansk',
        'kok' => 'Konkani',
        'kos' => 'Kosraeaansk',
        'kpe' => 'Kpelle',
        'kr' => 'Kanuri',
        'krc' => 'Karachay-Balkar',
        'krl' => 'Karelysk',
        'kru' => 'Kurukh',
        'ks' => 'Kasjmiri',
        'ksb' => 'Shambala',
        'ksf' => 'Bafia',
        'ksh' => 'Kölsch',
        'ku' => 'Koerdysk',
        'kum' => 'Koemuks',
        'kut' => 'Kutenai',
        'kv' => 'Komi',
        'kw' => 'Cornish',
        'ky' => 'Kirgizysk',
        'la' => 'Latyn',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lah' => 'Lahnda',
        'lam' => 'Lamba',
        'lb' => 'Luxemburgs',
        'lez' => 'Lezgysk',
        'lg' => 'Ganda',
        'li' => 'Limburgs',
        'lkt' => 'Lakota',
        'ln' => 'Lingala',
        'lo' => 'Laotiaansk',
        'lol' => 'Mongo',
        'loz' => 'Lozi',
        'lt' => 'Litouws',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lui' => 'Luiseno',
        'lun' => 'Lunda',
        'luo' => 'Luo',
        'lus' => 'Lushai',
        'luy' => 'Luyia',
        'lv' => 'Letlâns',
        'mad' => 'Madurees',
        'maf' => 'Mafa',
        'mag' => 'Magahi',
        'mai' => 'Maithili',
        'mak' => 'Makassaars',
        'man' => 'Mandingo',
        'mas' => 'Masai',
        'mde' => 'Maba',
        'mdf' => 'Moksha',
        'mdr' => 'Mandar',
        'men' => 'Mende',
        'mer' => 'Meru',
        'mfe' => 'Morisyen',
        'mg' => 'Malagasysk',
        'mga' => 'Middeliers',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marshallees',
        'mi' => 'Maori',
        'mic' => 'Mi’kmaq',
        'min' => 'Minangkabau',
        'mk' => 'Macedonysk',
        'ml' => 'Malayalam',
        'mn' => 'Mongools',
        'mnc' => 'Mantsjoe',
        'mni' => 'Manipoeri',
        'moh' => 'Mohawk',
        'mos' => 'Mossi',
        'mr' => 'Marathi',
        'ms' => 'Maleis',
        'mt' => 'Maltees',
        'mua' => 'Mundang',
        'mus' => 'Creek',
        'mwl' => 'Mirandees',
        'mwr' => 'Marwari',
        'my' => 'Birmees',
        'mye' => 'Myene',
        'myv' => 'Erzja',
        'na' => 'Nauruaansk',
        'nap' => 'Napolitaansk',
        'naq' => 'Nama',
        'nb' => 'Noors - Bokmål',
        'nd' => 'Noard-Ndbele',
        'nds' => 'Laagduits',
        'ne' => 'Nepalees',
        'new' => 'Newari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niueaansk',
        'nl' => 'Nederlânsk',
        'nmg' => 'Ngumba',
        'nn' => 'Noors - Nynorsk',
        'nnh' => 'Ngiemboon',
        'no' => 'Noors',
        'nog' => 'Nogai',
        'non' => 'Aldnoarsk',
        'nqo' => 'N’ko',
        'nr' => 'Sûd-Ndbele',
        'nso' => 'Noard-Sotho',
        'nus' => 'Nuer',
        'nv' => 'Navajo',
        'nwc' => 'Klassiek Newari',
        'ny' => 'Nyanja',
        'nym' => 'Nyamwezi',
        'nyn' => 'Nyankole',
        'nyo' => 'Nyoro',
        'nzi' => 'Nzima',
        'oc' => 'Occitaansk',
        'oj' => 'Ojibwa',
        'om' => 'Oromo',
        'or' => 'Odia',
        'os' => 'Ossetysk',
        'osa' => 'Osage',
        'ota' => 'Ottomaansk-Turks',
        'pa' => 'Punjabi',
        'pag' => 'Pangasinan',
        'pal' => 'Pahlavi',
        'pam' => 'Pampanga',
        'pap' => 'Papiaments',
        'pau' => 'Palauaansk',
        'peo' => 'Aldperzysk',
        'phn' => 'Foenisysk',
        'pi' => 'Pali',
        'pl' => 'Poalsk',
        'pon' => 'Pohnpeiaansk',
        'pro' => 'Aldprovençaals',
        'ps' => 'Pasjtoe',
        'pt' => 'Portugeesk',
        'qu' => 'Quechua',
        'raj' => 'Rajasthani',
        'rap' => 'Rapanui',
        'rar' => 'Rarotongan',
        'rm' => 'Reto-Romaansk',
        'rn' => 'Kirundi',
        'ro' => 'Roemeensk',
        'rof' => 'Rombo',
        'rom' => 'Romani',
        'ru' => 'Russysk',
        'rup' => 'Aromaniaansk',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sanskriet',
        'sad' => 'Sandawe',
        'sah' => 'Jakoets',
        'sam' => 'Samaritaansk-Arameesk',
        'saq' => 'Samburu',
        'sas' => 'Sasak',
        'sat' => 'Santali',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sardinysk',
        'scn' => 'Siciliaansk',
        'sco' => 'Schots',
        'sd' => 'Sindhi',
        'se' => 'Noard-Samysk',
        'see' => 'Seneca',
        'seh' => 'Sena',
        'sel' => 'Selkup',
        'ses' => 'Koyraboro Senni',
        'sg' => 'Sango',
        'sga' => 'Aldyrsk',
        'sh' => 'Servokroatysk',
        'shi' => 'Tashelhiyt',
        'shn' => 'Shan',
        'shu' => 'Tsjadysk Arabysk',
        'si' => 'Singalees',
        'sid' => 'Sidamo',
        'sk' => 'Slowaaks',
        'sl' => 'Sloveensk',
        'sm' => 'Samoaansk',
        'sma' => 'Sûd-Samysk',
        'smj' => 'Lule Sami',
        'smn' => 'Inari Sami',
        'sms' => 'Skolt Sami',
        'sn' => 'Shona',
        'snk' => 'Soninke',
        'so' => 'Somalysk',
        'sog' => 'Sogdysk',
        'sq' => 'Albaneesk',
        'sr' => 'Servysk',
        'srn' => 'Sranantongo',
        'srr' => 'Serer',
        'ss' => 'Swazi',
        'ssy' => 'Saho',
        'st' => 'Sûd-Sotho',
        'su' => 'Soendaneesk',
        'suk' => 'Sukuma',
        'sus' => 'Soesoe',
        'sux' => 'Soemerysk',
        'sv' => 'Zweeds',
        'sw' => 'Swahili',
        'swb' => 'Shimaore',
        'syc' => 'Klassiek Syrysk',
        'syr' => 'Syrysk',
        'ta' => 'Tamil',
        'te' => 'Telugu',
        'tem' => 'Timne',
        'teo' => 'Teso',
        'ter' => 'Tereno',
        'tet' => 'Tetun',
        'tg' => 'Tadzjieks',
        'th' => 'Thais',
        'ti' => 'Tigrinya',
        'tig' => 'Tigre',
        'tiv' => 'Tiv',
        'tk' => 'Turkmeens',
        'tkl' => 'Tokelaus',
        'tl' => 'Tagalog',
        'tlh' => 'Klingon',
        'tli' => 'Tlingit',
        'tmh' => 'Tamashek',
        'tn' => 'Tswana',
        'to' => 'Tongaansk',
        'tog' => 'Nyasa Tonga',
        'tpi' => 'Tok Pisin',
        'tr' => 'Turks',
        'trv' => 'Taroko',
        'ts' => 'Tsonga',
        'tsi' => 'Tsimshian',
        'tt' => 'Tataars',
        'tum' => 'Toemboeka',
        'tvl' => 'Tuvaluaansk',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahitysk',
        'tyv' => 'Tuvinysk',
        'tzm' => 'Tamazight (Sintraal-Marokko)',
        'udm' => 'Oedmoerts',
        'ug' => 'Oeigoers',
        'uga' => 'Oegaritysk',
        'uk' => 'Oekraïens',
        'umb' => 'Umbundu',
        'ur' => 'Urdu',
        'uz' => 'Oezbeeks',
        'vai' => 'Vai',
        've' => 'Venda',
        'vi' => 'Vietnamees',
        'vo' => 'Volapük',
        'vot' => 'Votysk',
        'vun' => 'Vunjo',
        'wa' => 'Waals',
        'wae' => 'Walser',
        'wal' => 'Walamo',
        'war' => 'Waray',
        'was' => 'Washo',
        'wo' => 'Wolof',
        'xal' => 'Kalmyk',
        'xh' => 'Xhosa',
        'xog' => 'Soga',
        'yao' => 'Yao',
        'yap' => 'Yapees',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Jiddysk',
        'yo' => 'Yoruba',
        'yue' => 'Kantoneesk',
        'za' => 'Zhuang',
        'zap' => 'Zapotec',
        'zbl' => 'Blissymbolen',
        'zen' => 'Zenaga',
        'zgh' => 'Standert Marokkaanske Tamazight',
        'zh' => 'Sineesk',
        'zu' => 'Zulu',
        'zun' => 'Zuni',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Modern standert Arabysk',
        'de_AT' => 'Eastenryks Dútsk',
        'de_CH' => 'Switsersk Heechdútsk',
        'en_AU' => 'Australysk Ingelsk',
        'en_CA' => 'Kanadeesk Ingelsk',
        'en_GB' => 'Britsk Ingelsk',
        'en_US' => 'Amerikaansk Ingelsk',
        'es_419' => 'Latynsk-Amerikaansk Spaansk',
        'es_ES' => 'Europeesk Spaansk',
        'es_MX' => 'Meksikaansk Spaansk',
        'fr_CA' => 'Kanadeesk Frânsk',
        'fr_CH' => 'Switserse Frânsk',
        'nl_BE' => 'Vlaams',
        'pt_BR' => 'Brazyljaansk Portugees',
        'pt_PT' => 'Europees Portugees',
        'ro_MD' => 'Moldavysk',
        'sw_CD' => 'Congo Swahili',
        'zh_Hans' => 'Ferienfâldich Sineesk',
        'zh_Hant' => 'Tradisjoneel Sineesk',
    ],
];
