<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ग्रीनविच मीन वख (عابِدجان)',
        'Africa/Accra' => 'ग्रीनविच मीन वख (اؠکرا)',
        'Africa/Algiers' => 'मरकज़ी यूरपी वख (اَلجیٖرِیا)',
        'Africa/Bamako' => 'ग्रीनविच मीन वख (بماکو)',
        'Africa/Banjul' => 'ग्रीनविच मीन वख (بَنجوٗل)',
        'Africa/Bissau' => 'ग्रीनविच मीन वख (بِساؤں)',
        'Africa/Cairo' => 'मशरिकी यूरपी वख (کَیرو)',
        'Africa/Casablanca' => 'मगरीबी यूरपी वख (کؠسابلؠنکا)',
        'Africa/Ceuta' => 'मरकज़ी यूरपी वख (کیوٗٹا)',
        'Africa/Conakry' => 'ग्रीनविच मीन वख (کوناکری)',
        'Africa/Dakar' => 'ग्रीनविच मीन वख (دَکار)',
        'Africa/El_Aaiun' => 'मगरीबी यूरपी वख (ال عیون)',
        'Africa/Freetown' => 'ग्रीनविच मीन वख (فری ٹاوُن)',
        'Africa/Lome' => 'ग्रीनविच मीन वख (لوم)',
        'Africa/Monrovia' => 'ग्रीनविच मीन वख (مونرووِیا)',
        'Africa/Nouakchott' => 'ग्रीनविच मीन वख (نوواکچھوت)',
        'Africa/Ouagadougou' => 'ग्रीनविच मीन वख (اوآگدوگو)',
        'Africa/Sao_Tome' => 'ग्रीनविच मीन वख (ساو ٹوم)',
        'Africa/Tripoli' => 'मशरिकी यूरपी वख (ترپولی)',
        'Africa/Tunis' => 'मरकज़ी यूरपी वख (ٹوٗنِس)',
        'America/Anguilla' => 'अटलांटिक वख (اؠنگِولا)',
        'America/Antigua' => 'अटलांटिक वख (اؠنٹِگُوا)',
        'America/Aruba' => 'अटलांटिक वख (اَروٗبا)',
        'America/Bahia_Banderas' => 'सेंट्रल वख (باہیا بندارس)',
        'America/Barbados' => 'अटलांटिक वख (بارباڈوس)',
        'America/Belize' => 'सेंट्रल वख (بؠلیٖز)',
        'America/Blanc-Sablon' => 'अटलांटिक वख (بلانک سؠبلَن)',
        'America/Boise' => 'माउंटेन वख (بویِس)',
        'America/Cambridge_Bay' => 'माउंटेन वख (کیمبرِج خلیٖج)',
        'America/Cancun' => 'मशरिकी वख (کینکَن)',
        'America/Cayman' => 'मशरिकी वख (کیمَن)',
        'America/Chicago' => 'सेंट्रल वख (شِکاگو)',
        'America/Coral_Harbour' => 'मशरिकी वख (اٹی کوکنٍ)',
        'America/Costa_Rica' => 'सेंट्रल वख (کوسٹا ریٖکا)',
        'America/Creston' => 'माउंटेन वख (کریسٹن)',
        'America/Curacao' => 'अटलांटिक वख (کیوٗراکااو)',
        'America/Danmarkshavn' => 'ग्रीनविच मीन वख (ڈنمارک شاون)',
        'America/Dawson_Creek' => 'माउंटेन वख (ڈواسَن کریٖک)',
        'America/Denver' => 'माउंटेन वख (ڈینوَر)',
        'America/Detroit' => 'मशरिकी वख (ڈیٹرایِٹ)',
        'America/Dominica' => 'अटलांटिक वख (ڈومِنِکا)',
        'America/Edmonton' => 'माउंटेन वख (اؠڈمَنٹَن)',
        'America/El_Salvador' => 'सेंट्रल वख (ایل سَلویدَر)',
        'America/Fort_Nelson' => 'माउंटेन वख (فورٹ نیلسن)',
        'America/Glace_Bay' => 'अटलांटिक वख (گلیس خلیٖج)',
        'America/Goose_Bay' => 'अटलांटिक वख (گوٗس خلیٖج)',
        'America/Grand_Turk' => 'मशरिकी वख (گرینڈ تٔرک)',
        'America/Grenada' => 'अटलांटिक वख (گریناڈا)',
        'America/Guadeloupe' => 'अटलांटिक वख (گوڑلوپ)',
        'America/Guatemala' => 'सेंट्रल वख (گواٹیمالا)',
        'America/Halifax' => 'अटलांटिक वख (حیلِفؠکس)',
        'America/Indiana/Knox' => 'सेंट्रल वख (نوکس)',
        'America/Indiana/Marengo' => 'मशरिकी वख (میرنگو، انڈیانا)',
        'America/Indiana/Petersburg' => 'मशरिकी वख (پِٹس بٔرگ، انڈیانا)',
        'America/Indiana/Tell_City' => 'सेंट्रल वख (ٹیل سِٹی، انڈیانا)',
        'America/Indiana/Vevay' => 'मशरिकी वख (ویویے، انڈیانا)',
        'America/Indiana/Vincennes' => 'मशरिकी वख (وِنسینیس، انڈیانا)',
        'America/Indiana/Winamac' => 'मशरिकी वख (وِنیمیک، انڈیانا)',
        'America/Indianapolis' => 'मशरिकी वख (اِنڈیَن پولِس)',
        'America/Inuvik' => 'माउंटेन वख (اِنوٗوِک)',
        'America/Iqaluit' => 'मशरिकी वख (اِقالیوٗیِت)',
        'America/Jamaica' => 'मशरिकी वख (جَمَیکا)',
        'America/Kentucky/Monticello' => 'मशरिकी वख (مونٹِسیلو، کینٹوکی)',
        'America/Kralendijk' => 'अटलांटिक वख (کرالینڈِک)',
        'America/Los_Angeles' => 'पेसिफिक वख (لاس اینجٕلز)',
        'America/Louisville' => 'मशरिकी वख (لوٗیِس وِل)',
        'America/Lower_Princes' => 'अटलांटिक वख (لوور پرنس کوارٹر)',
        'America/Managua' => 'सेंट्रल वख (مَناگوا)',
        'America/Marigot' => 'अटलांटिक वख (میریگوٹ)',
        'America/Martinique' => 'अटलांटिक वख (مارٹِنِک)',
        'America/Matamoros' => 'सेंट्रल वख (میٹاموروس)',
        'America/Menominee' => 'सेंट्रल वख (مینومِنی)',
        'America/Merida' => 'सेंट्रल वख (میرِڈا)',
        'America/Mexico_City' => 'सेंट्रल वख (میکسِکو سِٹی)',
        'America/Moncton' => 'अटलांटिक वख (مونکٹٕن)',
        'America/Monterrey' => 'सेंट्रल वख (موٹیری)',
        'America/Montreal' => 'کینیڈا वख (Montreal)',
        'America/Montserrat' => 'अटलांटिक वख (مونژیرات)',
        'America/Nassau' => 'मशरिकी वख (نساؤں)',
        'America/New_York' => 'मशरिकी वख (نِو یارک)',
        'America/Nipigon' => 'मशरिकी वख (نِپِگَن)',
        'America/North_Dakota/Beulah' => 'सेंट्रल वख (بیولاہ، شُمالی ڈیکوٹا)',
        'America/North_Dakota/Center' => 'सेंट्रल वख (مَرکزی جنوٗبی ڈکوٹا)',
        'America/North_Dakota/New_Salem' => 'सेंट्रल वख (نوو سیلٕم، شُمالی ڈیکوٹا)',
        'America/Ojinaga' => 'माउंटेन वख (اوجی ناگا)',
        'America/Panama' => 'मशरिकी वख (پَناما)',
        'America/Pangnirtung' => 'मशरिकी वख (پَنگنِرٹَنگ)',
        'America/Phoenix' => 'माउंटेन वख (پھِنِکس)',
        'America/Port-au-Prince' => 'मशरिकी वख (پوٹ آؤں پرِنس)',
        'America/Port_of_Spain' => 'अटलांटिक वख (پوٹ آف سپین)',
        'America/Puerto_Rico' => 'अटलांटिक वख (پیٖٹو رِکو)',
        'America/Rainy_River' => 'सेंट्रल वख (رینی رِوَر)',
        'America/Rankin_Inlet' => 'सेंट्रल वख (رینکِن اِنلؠٹ)',
        'America/Regina' => 'सेंट्रल वख (رؠجیٖنا)',
        'America/Resolute' => 'सेंट्रल वख (رِسولیوٗٹ)',
        'America/Santo_Domingo' => 'अटलांटिक वख (سؠنٹو ڑومِنگو)',
        'America/St_Barthelemy' => 'अटलांटिक वख (سینٹ بارتھیلمی)',
        'America/St_Kitts' => 'अटलांटिक वख (سینٹ کِٹس)',
        'America/St_Lucia' => 'अटलांटिक वख (سؠنٹ لوٗسِیا)',
        'America/St_Thomas' => 'अटलांटिक वख (سینٹ تھامَس)',
        'America/St_Vincent' => 'अटलांटिक वख (سینٹ وِنسینٹ)',
        'America/Swift_Current' => 'सेंट्रल वख (سٕوِفٹ کَرَنٹ)',
        'America/Tegucigalpa' => 'सेंट्रल वख (ٹیگوسی گالپا)',
        'America/Thule' => 'अटलांटिक वख (تھیوٗلے)',
        'America/Thunder_Bay' => 'मशरिकी वख (تھَنڈر خلیٖج)',
        'America/Tijuana' => 'पेसिफिक वख (تِجُوانا)',
        'America/Toronto' => 'मशरिकी वख (ٹورونٹو)',
        'America/Tortola' => 'अटलांटिक वख (ٹارٹولا)',
        'America/Vancouver' => 'पेसिफिक वख (وؠنکووَر)',
        'America/Winnipeg' => 'सेंट्रल वख (وِنِپؠگ)',
        'America/Yellowknife' => 'माउंटेन वख (یؠلو نایِف)',
        'Antarctica/Casey' => 'اینٹارٹِکا वख (کیسی)',
        'Antarctica/Troll' => 'ग्रीनविच मीन वख (Troll)',
        'Arctic/Longyearbyen' => 'मरकज़ी यूरपी वख (لونگ ییئر بئین)',
        'Asia/Amman' => 'मशरिकी यूरपी वख (اَمان)',
        'Asia/Barnaul' => 'रूस वख (برنول)',
        'Asia/Beirut' => 'मशरिकी यूरपी वख (بیرٹ)',
        'Asia/Damascus' => 'मशरिकी यूरपी वख (دَمَسکَس)',
        'Asia/Famagusta' => 'मशरिकी यूरपी वख (فاما گوسٹا)',
        'Asia/Gaza' => 'मशरिकी यूरपी वख (غزہ)',
        'Asia/Hebron' => 'मशरिकी यूरपी वख (ہیبرون)',
        'Asia/Nicosia' => 'मशरिकी यूरपी वख (نِکوسِیا)',
        'Asia/Tomsk' => 'रूस वख (ٹومسک)',
        'Asia/Urumqi' => 'चीन वख (اُرومقی)',
        'Atlantic/Bermuda' => 'अटलांटिक वख (برموٗڑا)',
        'Atlantic/Canary' => 'मगरीबी यूरपी वख (کؠنَری)',
        'Atlantic/Faeroe' => 'मगरीबी यूरपी वख (فؠرو)',
        'Atlantic/Madeira' => 'मगरीबी यूरपी वख (مَڈیٖرا)',
        'Atlantic/Reykjavik' => 'ग्रीनविच मीन वख (رؠکیاوِک)',
        'Atlantic/St_Helena' => 'ग्रीनविच मीन वख (سینٹ ہیلِنا)',
        'CST6CDT' => 'सेंट्रल वख',
        'EST5EDT' => 'मशरिकी वख',
        'Etc/GMT' => 'ग्रीनविच मीन वख',
        'Etc/UTC' => 'कोऑर्डनैटिड यूनवर्सल वख',
        'Europe/Amsterdam' => 'मरकज़ी यूरपी वख (ایمسٹَرڈیم)',
        'Europe/Andorra' => 'मरकज़ी यूरपी वख (اَنڈورا)',
        'Europe/Athens' => 'मशरिकी यूरपी वख (اؠتھٕنس)',
        'Europe/Belgrade' => 'मरकज़ी यूरपी वख (بیلگریڈ)',
        'Europe/Berlin' => 'मरकज़ी यूरपी वख (بٔرلِن)',
        'Europe/Bratislava' => 'मरकज़ी यूरपी वख (بریٹیسلاوا)',
        'Europe/Brussels' => 'मरकज़ी यूरपी वख (برسٕلس)',
        'Europe/Bucharest' => 'मशरिकी यूरपी वख (بَچاریسٹ)',
        'Europe/Budapest' => 'मरकज़ी यूरपी वख (بُڈاپیسٹ)',
        'Europe/Busingen' => 'मरकज़ी यूरपी वख (بوسِنگین)',
        'Europe/Chisinau' => 'मशरिकी यूरपी वख (چِسیٖنو)',
        'Europe/Copenhagen' => 'मरकज़ी यूरपी वख (کوپن ہیگن)',
        'Europe/Dublin' => 'ग्रीनविच मीन वख (ڈَبلِن)',
        'Europe/Gibraltar' => 'मरकज़ी यूरपी वख (گِبرالٹَر)',
        'Europe/Guernsey' => 'ग्रीनविच मीन वख (گویرنسے)',
        'Europe/Helsinki' => 'मशरिकी यूरपी वख (حؠلسِنکی)',
        'Europe/Isle_of_Man' => 'ग्रीनविच मीन वख (آئل آف مین)',
        'Europe/Istanbul' => 'تُرکی वख (اِستانبُل)',
        'Europe/Jersey' => 'ग्रीनविच मीन वख (جرسی)',
        'Europe/Kaliningrad' => 'मशरिकी यूरपी वख (کَلِناِنگرَد)',
        'Europe/Kiev' => 'मशरिकी यूरपी वख (کیٖو)',
        'Europe/Kirov' => 'रूस वख (کیرو)',
        'Europe/Lisbon' => 'मगरीबी यूरपी वख (لِسبَن)',
        'Europe/Ljubljana' => 'मरकज़ी यूरपी वख (لِیوٗب لِیانا)',
        'Europe/London' => 'ग्रीनविच मीन वख (لَندَن)',
        'Europe/Luxembourg' => 'मरकज़ी यूरपी वख (لَکزٕمبٔرگ)',
        'Europe/Madrid' => 'मरकज़ी यूरपी वख (میڈریڈ)',
        'Europe/Malta' => 'मरकज़ी यूरपी वख (مالٹا)',
        'Europe/Mariehamn' => 'मशरिकी यूरपी वख (میری ہیم)',
        'Europe/Monaco' => 'मरकज़ी यूरपी वख (موناکو)',
        'Europe/Oslo' => 'मरकज़ी यूरपी वख (اوسلو)',
        'Europe/Paris' => 'मरकज़ी यूरपी वख (پیرِس)',
        'Europe/Podgorica' => 'मरकज़ी यूरपी वख (پوڈگوریکا)',
        'Europe/Prague' => 'मरकज़ी यूरपी वख (پراگ)',
        'Europe/Riga' => 'मशरिकी यूरपी वख (رِگا)',
        'Europe/Rome' => 'मरकज़ी यूरपी वख (روم)',
        'Europe/San_Marino' => 'मरकज़ी यूरपी वख (سین مرینو)',
        'Europe/Sarajevo' => 'मरकज़ी यूरपी वख (سارا جیوو)',
        'Europe/Skopje' => 'मरकज़ी यूरपी वख (سِکوپیے)',
        'Europe/Sofia' => 'मशरिकी यूरपी वख (سوفِیا)',
        'Europe/Stockholm' => 'मरकज़ी यूरपी वख (سٹاک ہولم)',
        'Europe/Tallinn' => 'मशरिकी यूरपी वख (ٹؠلِن)',
        'Europe/Tirane' => 'मरकज़ी यूरपी वख (ٹِرین)',
        'Europe/Uzhgorod' => 'मशरिकी यूरपी वख (اُزگورود)',
        'Europe/Vaduz' => 'मरकज़ी यूरपी वख (وادُز)',
        'Europe/Vatican' => 'मरकज़ी यूरपी वख (ویٹیکن)',
        'Europe/Vienna' => 'मरकज़ी यूरपी वख (وِیَننا)',
        'Europe/Vilnius' => 'मशरिकी यूरपी वख (وِلِنِیَس)',
        'Europe/Warsaw' => 'मरकज़ी यूरपी वख (وارسا)',
        'Europe/Zagreb' => 'मरकज़ी यूरपी वख (زگریب)',
        'Europe/Zaporozhye' => 'मशरिकी यूरपी वख (زَپوروزَے)',
        'Europe/Zurich' => 'मरकज़ी यूरपी वख (زیوٗرِک)',
        'MST7MDT' => 'माउंटेन वख',
        'PST8PDT' => 'पेसिफिक वख',
        'Pacific/Apia' => 'سامو वख (آپِیا)',
    ],
    'Meta' => [
        'GmtFormat' => 'जी एम टी %s',
    ],
];
