<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Wā Toharite Kiriwīti (Abidjan)',
        'Africa/Accra' => 'Wā Toharite Kiriwīti (Accra)',
        'Africa/Addis_Ababa' => 'Etiopia Wā (Addis Ababa)',
        'Africa/Algiers' => 'Wā Uropi Waenga (Algiers)',
        'Africa/Asmera' => 'Eritēria Wā (Asmara)',
        'Africa/Bamako' => 'Wā Toharite Kiriwīti (Bamako)',
        'Africa/Bangui' => 'Te Puku o Āwherika Wā (Bangui)',
        'Africa/Banjul' => 'Wā Toharite Kiriwīti (Banjul)',
        'Africa/Bissau' => 'Wā Toharite Kiriwīti (Bissau)',
        'Africa/Blantyre' => 'Marāwi Wā (Blantyre)',
        'Africa/Brazzaville' => 'Kōngo - Parāwhe Wā (Brazzaville)',
        'Africa/Bujumbura' => 'Puruniti Wā (Bujumbura)',
        'Africa/Cairo' => 'Wā Uropi Rāwhiti (Cairo)',
        'Africa/Casablanca' => 'Wā Uropi Uru (Casablanca)',
        'Africa/Ceuta' => 'Wā Uropi Waenga (Ceuta)',
        'Africa/Conakry' => 'Wā Toharite Kiriwīti (Conakry)',
        'Africa/Dakar' => 'Wā Toharite Kiriwīti (Dakar)',
        'Africa/Dar_es_Salaam' => 'Tānahia Wā (Dar es Salaam)',
        'Africa/Djibouti' => 'Tipūti Wā (Djibouti)',
        'Africa/Douala' => 'Kamarūna Wā (Douala)',
        'Africa/El_Aaiun' => 'Wā Uropi Uru (El Aaiun)',
        'Africa/Freetown' => 'Wā Toharite Kiriwīti (Freetown)',
        'Africa/Gaborone' => 'Poriwana Wā (Gaborone)',
        'Africa/Harare' => 'Timuwawe Wā (Harare)',
        'Africa/Johannesburg' => 'Āwherika ki te Tonga Wā (Johannesburg)',
        'Africa/Juba' => 'Hūtāne ki te Tonga Wā (Juba)',
        'Africa/Kampala' => 'Ukāna Wā (Kampala)',
        'Africa/Khartoum' => 'Hūtāne Wā (Khartoum)',
        'Africa/Kigali' => 'Rāwana Wā (Kigali)',
        'Africa/Kinshasa' => 'Kōngo - Kingihāha Wā (Kinshasa)',
        'Africa/Lagos' => 'Ngāitiria Wā (Lagos)',
        'Africa/Libreville' => 'Kāpona Wā (Libreville)',
        'Africa/Lome' => 'Wā Toharite Kiriwīti (Lome)',
        'Africa/Luanda' => 'Anakora Wā (Luanda)',
        'Africa/Lubumbashi' => 'Kōngo - Kingihāha Wā (Lubumbashi)',
        'Africa/Lusaka' => 'Tāmipia Wā (Lusaka)',
        'Africa/Malabo' => 'Kini Ekuatoria Wā (Malabo)',
        'Africa/Maputo' => 'Mohapiki Wā (Maputo)',
        'Africa/Maseru' => 'Teroto Wā (Maseru)',
        'Africa/Mbabane' => 'Ewatini Wā (Mbabane)',
        'Africa/Mogadishu' => 'Hūmārie Wā (Mogadishu)',
        'Africa/Monrovia' => 'Wā Toharite Kiriwīti (Monrovia)',
        'Africa/Nairobi' => 'Kēnia Wā (Nairobi)',
        'Africa/Ndjamena' => 'Kāta Wā (Ndjamena)',
        'Africa/Niamey' => 'Ngāika Wā (Niamey)',
        'Africa/Nouakchott' => 'Wā Toharite Kiriwīti (Nouakchott)',
        'Africa/Ouagadougou' => 'Wā Toharite Kiriwīti (Ouagadougou)',
        'Africa/Porto-Novo' => 'Penīna Wā (Porto-Novo)',
        'Africa/Sao_Tome' => 'Wā Toharite Kiriwīti (Sao Tome)',
        'Africa/Tripoli' => 'Wā Uropi Rāwhiti (Tripoli)',
        'Africa/Tunis' => 'Wā Uropi Waenga (Tunis)',
        'Africa/Windhoek' => 'Namīpia Wā (Windhoek)',
        'America/Adak' => 'Hononga o Amerika Wā (Adak)',
        'America/Anchorage' => 'Hononga o Amerika Wā (Anchorage)',
        'America/Anguilla' => 'Wā Ranatiki (Anguilla)',
        'America/Antigua' => 'Wā Ranatiki (Antigua)',
        'America/Araguaina' => 'Parīhi Wā (Araguaina)',
        'America/Argentina/La_Rioja' => 'Āketina Wā (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Āketina Wā (Rio Gallegos)',
        'America/Argentina/Salta' => 'Āketina Wā (Salta)',
        'America/Argentina/San_Juan' => 'Āketina Wā (San Juan)',
        'America/Argentina/San_Luis' => 'Āketina Wā (San Luis)',
        'America/Argentina/Tucuman' => 'Āketina Wā (Tucuman)',
        'America/Argentina/Ushuaia' => 'Āketina Wā (Ushuaia)',
        'America/Aruba' => 'Wā Ranatiki (Aruba)',
        'America/Asuncion' => 'Parakai Wā (Asuncion)',
        'America/Bahia' => 'Parīhi Wā (Bahia)',
        'America/Bahia_Banderas' => 'Wā Waenga (Bahia Banderas)',
        'America/Barbados' => 'Wā Ranatiki (Barbados)',
        'America/Belem' => 'Parīhi Wā (Belem)',
        'America/Belize' => 'Wā Waenga (Belize)',
        'America/Blanc-Sablon' => 'Wā Ranatiki (Blanc-Sablon)',
        'America/Boa_Vista' => 'Parīhi Wā (Boa Vista)',
        'America/Bogota' => 'Koromōpia Wā (Bogota)',
        'America/Boise' => 'Wā Maunga (Boise)',
        'America/Buenos_Aires' => 'Āketina Wā (Buenos Aires)',
        'America/Cambridge_Bay' => 'Wā Maunga (Cambridge Bay)',
        'America/Campo_Grande' => 'Parīhi Wā (Campo Grande)',
        'America/Cancun' => 'Wā Rāwhiti (Cancun)',
        'America/Caracas' => 'Wenehūera Wā (Caracas)',
        'America/Catamarca' => 'Āketina Wā (Catamarca)',
        'America/Cayenne' => 'Kaiana Wīwī Wā (Cayenne)',
        'America/Cayman' => 'Wā Rāwhiti (Cayman)',
        'America/Chicago' => 'Wā Waenga (Chicago)',
        'America/Chihuahua' => 'Mēhiko Wā (Chihuahua)',
        'America/Coral_Harbour' => 'Wā Rāwhiti (Atikokan)',
        'America/Cordoba' => 'Āketina Wā (Cordoba)',
        'America/Costa_Rica' => 'Wā Waenga (Costa Rica)',
        'America/Creston' => 'Wā Maunga (Creston)',
        'America/Cuiaba' => 'Parīhi Wā (Cuiaba)',
        'America/Curacao' => 'Wā Ranatiki (Curacao)',
        'America/Danmarkshavn' => 'Wā Toharite Kiriwīti (Danmarkshavn)',
        'America/Dawson' => 'Kānata Wā (Dawson)',
        'America/Dawson_Creek' => 'Wā Maunga (Dawson Creek)',
        'America/Denver' => 'Wā Maunga (Denver)',
        'America/Detroit' => 'Wā Rāwhiti (Detroit)',
        'America/Dominica' => 'Wā Ranatiki (Dominica)',
        'America/Edmonton' => 'Wā Maunga (Edmonton)',
        'America/Eirunepe' => 'Parīhi Wā (Eirunepe)',
        'America/El_Salvador' => 'Wā Waenga (El Salvador)',
        'America/Fort_Nelson' => 'Wā Maunga (Fort Nelson)',
        'America/Fortaleza' => 'Parīhi Wā (Fortaleza)',
        'America/Glace_Bay' => 'Wā Ranatiki (Glace Bay)',
        'America/Godthab' => 'Kirīrangi Wā (Nuuk)',
        'America/Goose_Bay' => 'Wā Ranatiki (Goose Bay)',
        'America/Grand_Turk' => 'Wā Rāwhiti (Grand Turk)',
        'America/Grenada' => 'Wā Ranatiki (Grenada)',
        'America/Guadeloupe' => 'Wā Ranatiki (Guadeloupe)',
        'America/Guatemala' => 'Wā Waenga (Guatemala)',
        'America/Guayaquil' => 'Ekuatoa Wā (Guayaquil)',
        'America/Guyana' => 'Kaiana Wā (Guyana)',
        'America/Halifax' => 'Wā Ranatiki (Halifax)',
        'America/Havana' => 'Kiupa Wā (Havana)',
        'America/Hermosillo' => 'Mēhiko Wā (Hermosillo)',
        'America/Indiana/Knox' => 'Wā Waenga (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Wā Rāwhiti (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Wā Rāwhiti (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Wā Waenga (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Wā Rāwhiti (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Wā Rāwhiti (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Wā Rāwhiti (Winamac, Indiana)',
        'America/Indianapolis' => 'Wā Rāwhiti (Indianapolis)',
        'America/Inuvik' => 'Wā Maunga (Inuvik)',
        'America/Iqaluit' => 'Wā Rāwhiti (Iqaluit)',
        'America/Jamaica' => 'Wā Rāwhiti (Jamaica)',
        'America/Jujuy' => 'Āketina Wā (Jujuy)',
        'America/Juneau' => 'Hononga o Amerika Wā (Juneau)',
        'America/Kentucky/Monticello' => 'Wā Rāwhiti (Monticello, Kentucky)',
        'America/Kralendijk' => 'Wā Ranatiki (Kralendijk)',
        'America/La_Paz' => 'Poriwia Wā (La Paz)',
        'America/Lima' => 'Peru Wā (Lima)',
        'America/Los_Angeles' => 'Wā Kiwa (Los Angeles)',
        'America/Louisville' => 'Wā Rāwhiti (Louisville)',
        'America/Lower_Princes' => 'Wā Ranatiki (Lower Prince’s Quarter)',
        'America/Maceio' => 'Parīhi Wā (Maceio)',
        'America/Managua' => 'Wā Waenga (Managua)',
        'America/Manaus' => 'Parīhi Wā (Manaus)',
        'America/Marigot' => 'Wā Ranatiki (Marigot)',
        'America/Martinique' => 'Wā Ranatiki (Martinique)',
        'America/Matamoros' => 'Wā Waenga (Matamoros)',
        'America/Mazatlan' => 'Mēhiko Wā (Mazatlan)',
        'America/Mendoza' => 'Āketina Wā (Mendoza)',
        'America/Menominee' => 'Wā Waenga (Menominee)',
        'America/Merida' => 'Wā Waenga (Merida)',
        'America/Metlakatla' => 'Hononga o Amerika Wā (Metlakatla)',
        'America/Mexico_City' => 'Wā Waenga (Mexico City)',
        'America/Miquelon' => 'Hato Piere & Mikarona Wā (Miquelon)',
        'America/Moncton' => 'Wā Ranatiki (Moncton)',
        'America/Monterrey' => 'Wā Waenga (Monterrey)',
        'America/Montevideo' => 'Urukoi Wā (Montevideo)',
        'America/Montreal' => 'Kānata Wā (Montreal)',
        'America/Montserrat' => 'Wā Ranatiki (Montserrat)',
        'America/Nassau' => 'Wā Rāwhiti (Nassau)',
        'America/New_York' => 'Wā Rāwhiti (New York)',
        'America/Nipigon' => 'Wā Rāwhiti (Nipigon)',
        'America/Nome' => 'Hononga o Amerika Wā (Nome)',
        'America/Noronha' => 'Parīhi Wā (Noronha)',
        'America/North_Dakota/Beulah' => 'Wā Waenga (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Wā Waenga (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Wā Waenga (New Salem, North Dakota)',
        'America/Ojinaga' => 'Wā Maunga (Ojinaga)',
        'America/Panama' => 'Wā Rāwhiti (Panama)',
        'America/Pangnirtung' => 'Wā Rāwhiti (Pangnirtung)',
        'America/Paramaribo' => 'Hurināme Wā (Paramaribo)',
        'America/Phoenix' => 'Wā Maunga (Phoenix)',
        'America/Port-au-Prince' => 'Wā Rāwhiti (Port-au-Prince)',
        'America/Port_of_Spain' => 'Wā Ranatiki (Port of Spain)',
        'America/Porto_Velho' => 'Parīhi Wā (Porto Velho)',
        'America/Puerto_Rico' => 'Wā Ranatiki (Puerto Rico)',
        'America/Punta_Arenas' => 'Hiri Wā (Punta Arenas)',
        'America/Rainy_River' => 'Wā Waenga (Rainy River)',
        'America/Rankin_Inlet' => 'Wā Waenga (Rankin Inlet)',
        'America/Recife' => 'Parīhi Wā (Recife)',
        'America/Regina' => 'Wā Waenga (Regina)',
        'America/Resolute' => 'Wā Waenga (Resolute)',
        'America/Rio_Branco' => 'Parīhi Wā (Rio Branco)',
        'America/Santa_Isabel' => 'Mēhiko Wā (Santa Isabel)',
        'America/Santarem' => 'Parīhi Wā (Santarem)',
        'America/Santiago' => 'Hiri Wā (Santiago)',
        'America/Santo_Domingo' => 'Wā Ranatiki (Santo Domingo)',
        'America/Sao_Paulo' => 'Parīhi Wā (Sao Paulo)',
        'America/Scoresbysund' => 'Kirīrangi Wā (Ittoqqortoormiit)',
        'America/Sitka' => 'Hononga o Amerika Wā (Sitka)',
        'America/St_Barthelemy' => 'Wā Ranatiki (St. Barthelemy)',
        'America/St_Johns' => 'Kānata Wā (St. John’s)',
        'America/St_Kitts' => 'Wā Ranatiki (St. Kitts)',
        'America/St_Lucia' => 'Wā Ranatiki (St. Lucia)',
        'America/St_Thomas' => 'Wā Ranatiki (St. Thomas)',
        'America/St_Vincent' => 'Wā Ranatiki (St. Vincent)',
        'America/Swift_Current' => 'Wā Waenga (Swift Current)',
        'America/Tegucigalpa' => 'Wā Waenga (Tegucigalpa)',
        'America/Thule' => 'Wā Ranatiki (Thule)',
        'America/Thunder_Bay' => 'Wā Rāwhiti (Thunder Bay)',
        'America/Tijuana' => 'Wā Kiwa (Tijuana)',
        'America/Toronto' => 'Wā Rāwhiti (Toronto)',
        'America/Tortola' => 'Wā Ranatiki (Tortola)',
        'America/Vancouver' => 'Wā Kiwa (Vancouver)',
        'America/Whitehorse' => 'Kānata Wā (Whitehorse)',
        'America/Winnipeg' => 'Wā Waenga (Winnipeg)',
        'America/Yakutat' => 'Hononga o Amerika Wā (Yakutat)',
        'America/Yellowknife' => 'Wā Maunga (Yellowknife)',
        'Antarctica/Troll' => 'Wā Toharite Kiriwīti (Troll)',
        'Arctic/Longyearbyen' => 'Wā Uropi Waenga (Longyearbyen)',
        'Asia/Amman' => 'Wā Uropi Rāwhiti (Amman)',
        'Asia/Anadyr' => 'Rūhia Wā (Anadyr)',
        'Asia/Barnaul' => 'Rūhia Wā (Barnaul)',
        'Asia/Beirut' => 'Wā Uropi Rāwhiti (Beirut)',
        'Asia/Calcutta' => 'Inia Wā (Kolkata)',
        'Asia/Chita' => 'Rūhia Wā (Chita)',
        'Asia/Damascus' => 'Wā Uropi Rāwhiti (Damascus)',
        'Asia/Famagusta' => 'Wā Uropi Rāwhiti (Famagusta)',
        'Asia/Gaza' => 'Wā Uropi Rāwhiti (Gaza)',
        'Asia/Hebron' => 'Wā Uropi Rāwhiti (Hebron)',
        'Asia/Irkutsk' => 'Rūhia Wā (Irkutsk)',
        'Asia/Kamchatka' => 'Rūhia Wā (Kamchatka)',
        'Asia/Khandyga' => 'Rūhia Wā (Khandyga)',
        'Asia/Krasnoyarsk' => 'Rūhia Wā (Krasnoyarsk)',
        'Asia/Magadan' => 'Rūhia Wā (Magadan)',
        'Asia/Nicosia' => 'Wā Uropi Rāwhiti (Nicosia)',
        'Asia/Novokuznetsk' => 'Rūhia Wā (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Rūhia Wā (Novosibirsk)',
        'Asia/Omsk' => 'Rūhia Wā (Omsk)',
        'Asia/Sakhalin' => 'Rūhia Wā (Sakhalin)',
        'Asia/Shanghai' => 'Haina Wā (Shanghai)',
        'Asia/Srednekolymsk' => 'Rūhia Wā (Srednekolymsk)',
        'Asia/Tokyo' => 'Hapani Wā (Tokyo)',
        'Asia/Tomsk' => 'Rūhia Wā (Tomsk)',
        'Asia/Urumqi' => 'Haina Wā (Urumqi)',
        'Asia/Ust-Nera' => 'Rūhia Wā (Ust-Nera)',
        'Asia/Vladivostok' => 'Rūhia Wā (Vladivostok)',
        'Asia/Yakutsk' => 'Rūhia Wā (Yakutsk)',
        'Asia/Yekaterinburg' => 'Rūhia Wā (Yekaterinburg)',
        'Atlantic/Bermuda' => 'Wā Ranatiki (Bermuda)',
        'Atlantic/Canary' => 'Wā Uropi Uru (Canary)',
        'Atlantic/Cape_Verde' => 'Te Kūrae Matomato Wā (Cape Verde)',
        'Atlantic/Faeroe' => 'Wā Uropi Uru (Faroe)',
        'Atlantic/Madeira' => 'Wā Uropi Uru (Madeira)',
        'Atlantic/Reykjavik' => 'Wā Toharite Kiriwīti (Reykjavik)',
        'Atlantic/South_Georgia' => 'Hōria ki te Tonga me Motu Hanuwiti ki te Tonga Wā (South Georgia)',
        'Atlantic/St_Helena' => 'Wā Toharite Kiriwīti (St. Helena)',
        'Atlantic/Stanley' => 'Motu Whākarangi Wā (Stanley)',
        'CST6CDT' => 'Wā Waenga',
        'EST5EDT' => 'Wā Rāwhiti',
        'Etc/GMT' => 'Wā Toharite Kiriwīti',
        'Etc/UTC' => 'Wā Aonui Kōtuitui',
        'Europe/Amsterdam' => 'Wā Uropi Waenga (Amsterdam)',
        'Europe/Andorra' => 'Wā Uropi Waenga (Andorra)',
        'Europe/Astrakhan' => 'Rūhia Wā (Astrakhan)',
        'Europe/Athens' => 'Wā Uropi Rāwhiti (Athens)',
        'Europe/Belgrade' => 'Wā Uropi Waenga (Belgrade)',
        'Europe/Berlin' => 'Wā Uropi Waenga (Berlin)',
        'Europe/Bratislava' => 'Wā Uropi Waenga (Bratislava)',
        'Europe/Brussels' => 'Wā Uropi Waenga (Brussels)',
        'Europe/Bucharest' => 'Wā Uropi Rāwhiti (Bucharest)',
        'Europe/Budapest' => 'Wā Uropi Waenga (Budapest)',
        'Europe/Busingen' => 'Wā Uropi Waenga (Busingen)',
        'Europe/Chisinau' => 'Wā Uropi Rāwhiti (Chisinau)',
        'Europe/Copenhagen' => 'Wā Uropi Waenga (Copenhagen)',
        'Europe/Dublin' => 'Wā Toharite Kiriwīti (Dublin)',
        'Europe/Gibraltar' => 'Wā Uropi Waenga (Gibraltar)',
        'Europe/Guernsey' => 'Wā Toharite Kiriwīti (Guernsey)',
        'Europe/Helsinki' => 'Wā Uropi Rāwhiti (Helsinki)',
        'Europe/Isle_of_Man' => 'Wā Toharite Kiriwīti (Isle of Man)',
        'Europe/Jersey' => 'Wā Toharite Kiriwīti (Jersey)',
        'Europe/Kaliningrad' => 'Wā Uropi Rāwhiti (Kaliningrad)',
        'Europe/Kiev' => 'Wā Uropi Rāwhiti (Kyiv)',
        'Europe/Kirov' => 'Rūhia Wā (Kirov)',
        'Europe/Lisbon' => 'Wā Uropi Uru (Lisbon)',
        'Europe/Ljubljana' => 'Wā Uropi Waenga (Ljubljana)',
        'Europe/London' => 'Wā Toharite Kiriwīti (London)',
        'Europe/Luxembourg' => 'Wā Uropi Waenga (Luxembourg)',
        'Europe/Madrid' => 'Wā Uropi Waenga (Madrid)',
        'Europe/Malta' => 'Wā Uropi Waenga (Malta)',
        'Europe/Mariehamn' => 'Wā Uropi Rāwhiti (Mariehamn)',
        'Europe/Monaco' => 'Wā Uropi Waenga (Monaco)',
        'Europe/Moscow' => 'Rūhia Wā (Moscow)',
        'Europe/Oslo' => 'Wā Uropi Waenga (Oslo)',
        'Europe/Paris' => 'Wā Uropi Waenga (Paris)',
        'Europe/Podgorica' => 'Wā Uropi Waenga (Podgorica)',
        'Europe/Prague' => 'Wā Uropi Waenga (Prague)',
        'Europe/Riga' => 'Wā Uropi Rāwhiti (Riga)',
        'Europe/Rome' => 'Wā Uropi Waenga (Rome)',
        'Europe/Samara' => 'Rūhia Wā (Samara)',
        'Europe/San_Marino' => 'Wā Uropi Waenga (San Marino)',
        'Europe/Sarajevo' => 'Wā Uropi Waenga (Sarajevo)',
        'Europe/Saratov' => 'Rūhia Wā (Saratov)',
        'Europe/Skopje' => 'Wā Uropi Waenga (Skopje)',
        'Europe/Sofia' => 'Wā Uropi Rāwhiti (Sofia)',
        'Europe/Stockholm' => 'Wā Uropi Waenga (Stockholm)',
        'Europe/Tallinn' => 'Wā Uropi Rāwhiti (Tallinn)',
        'Europe/Tirane' => 'Wā Uropi Waenga (Tirane)',
        'Europe/Ulyanovsk' => 'Rūhia Wā (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Wā Uropi Rāwhiti (Uzhgorod)',
        'Europe/Vaduz' => 'Wā Uropi Waenga (Vaduz)',
        'Europe/Vatican' => 'Wā Uropi Waenga (Vatican)',
        'Europe/Vienna' => 'Wā Uropi Waenga (Vienna)',
        'Europe/Vilnius' => 'Wā Uropi Rāwhiti (Vilnius)',
        'Europe/Volgograd' => 'Rūhia Wā (Volgograd)',
        'Europe/Warsaw' => 'Wā Uropi Waenga (Warsaw)',
        'Europe/Zagreb' => 'Wā Uropi Waenga (Zagreb)',
        'Europe/Zaporozhye' => 'Wā Uropi Rāwhiti (Zaporozhye)',
        'Europe/Zurich' => 'Wā Uropi Waenga (Zurich)',
        'Indian/Antananarivo' => 'Marakāhia Wā (Antananarivo)',
        'Indian/Chagos' => 'Te Rohe o te Moana Īniana Piritihi Wā (Chagos)',
        'Indian/Comoro' => 'Komoro Wā (Comoro)',
        'Indian/Kerguelen' => 'Ngā Rohe o Wīwī ki te Tonga Wā (Kerguelen)',
        'Indian/Mahe' => 'Heihere Wā (Mahe)',
        'Indian/Mauritius' => 'Mōrihi Wā (Mauritius)',
        'Indian/Mayotte' => 'Maio Wā (Mayotte)',
        'Indian/Reunion' => 'Rēnio Wā (Reunion)',
        'MST7MDT' => 'Wā Maunga',
        'PST8PDT' => 'Wā Kiwa',
        'Pacific/Auckland' => 'Aotearoa Wā (Tāmaki Makaurau)',
        'Pacific/Chatham' => 'Aotearoa Wā (Rēkohu)',
        'Pacific/Easter' => 'Hiri Wā (Easter)',
        'Pacific/Galapagos' => 'Ekuatoa Wā (Galapagos)',
        'Pacific/Honolulu' => 'Hononga o Amerika Wā (Honolulu)',
    ],
    'Meta' => [
    ],
];
