<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'গ্ৰীণউইচ মান সময় (আবিডজান)',
        'Africa/Accra' => 'গ্ৰীণউইচ মান সময় (এক্ৰা)',
        'Africa/Addis_Ababa' => 'পূব আফ্ৰিকাৰ সময় (আদ্দিছ আবাবা)',
        'Africa/Algiers' => 'মধ্য ইউৰোপীয় সময় (আলজিয়াৰ্ছ)',
        'Africa/Asmera' => 'পূব আফ্ৰিকাৰ সময় (আস্মাৰা)',
        'Africa/Bamako' => 'গ্ৰীণউইচ মান সময় (বামাকো)',
        'Africa/Bangui' => 'পশ্চিম আফ্ৰিকাৰ সময় (বাংগুই)',
        'Africa/Banjul' => 'গ্ৰীণউইচ মান সময় (বেঞ্জুল)',
        'Africa/Bissau' => 'গ্ৰীণউইচ মান সময় (বিছাউ)',
        'Africa/Blantyre' => 'মধ্য আফ্ৰিকাৰ সময় (ব্লাণ্টায়াৰ)',
        'Africa/Brazzaville' => 'পশ্চিম আফ্ৰিকাৰ সময় (ব্ৰাজাভিলে)',
        'Africa/Bujumbura' => 'মধ্য আফ্ৰিকাৰ সময় (বুজুম্বুৰা)',
        'Africa/Cairo' => 'প্ৰাচ্য ইউৰোপীয় সময় (কাইৰো)',
        'Africa/Casablanca' => 'পাশ্চাত্য ইউৰোপীয় সময় (কাছাব্লাংকা)',
        'Africa/Ceuta' => 'মধ্য ইউৰোপীয় সময় (চেউটা)',
        'Africa/Conakry' => 'গ্ৰীণউইচ মান সময় (কোনাক্ৰী)',
        'Africa/Dakar' => 'গ্ৰীণউইচ মান সময় (ডাকাৰ)',
        'Africa/Dar_es_Salaam' => 'পূব আফ্ৰিকাৰ সময় (ডাৰ এছ ছালাম)',
        'Africa/Djibouti' => 'পূব আফ্ৰিকাৰ সময় (জিবুটি)',
        'Africa/Douala' => 'পশ্চিম আফ্ৰিকাৰ সময় (ডুৱালা)',
        'Africa/El_Aaiun' => 'পাশ্চাত্য ইউৰোপীয় সময় (এল আইয়ুন)',
        'Africa/Freetown' => 'গ্ৰীণউইচ মান সময় (ফ্ৰিটাউন)',
        'Africa/Gaborone' => 'মধ্য আফ্ৰিকাৰ সময় (গাবোৰোণ)',
        'Africa/Harare' => 'মধ্য আফ্ৰিকাৰ সময় (হাৰাৰে)',
        'Africa/Johannesburg' => 'দক্ষিণ আফ্ৰিকাৰ মান সময় (জোহান্সবাৰ্গ)',
        'Africa/Juba' => 'মধ্য আফ্ৰিকাৰ সময় (জুবা)',
        'Africa/Kampala' => 'পূব আফ্ৰিকাৰ সময় (কাম্পালা)',
        'Africa/Khartoum' => 'মধ্য আফ্ৰিকাৰ সময় (খাৰ্টুম)',
        'Africa/Kigali' => 'মধ্য আফ্ৰিকাৰ সময় (কিগালী)',
        'Africa/Kinshasa' => 'পশ্চিম আফ্ৰিকাৰ সময় (কিংচাছা)',
        'Africa/Lagos' => 'পশ্চিম আফ্ৰিকাৰ সময় (লাগোছ)',
        'Africa/Libreville' => 'পশ্চিম আফ্ৰিকাৰ সময় (লিব্ৰিভিলে)',
        'Africa/Lome' => 'গ্ৰীণউইচ মান সময় (লোম)',
        'Africa/Luanda' => 'পশ্চিম আফ্ৰিকাৰ সময় (লুৱাণ্ডা)',
        'Africa/Lubumbashi' => 'মধ্য আফ্ৰিকাৰ সময় (লুবুম্বাচি)',
        'Africa/Lusaka' => 'মধ্য আফ্ৰিকাৰ সময় (লুছাকা)',
        'Africa/Malabo' => 'পশ্চিম আফ্ৰিকাৰ সময় (মালাবো)',
        'Africa/Maputo' => 'মধ্য আফ্ৰিকাৰ সময় (মাপুটো)',
        'Africa/Maseru' => 'দক্ষিণ আফ্ৰিকাৰ মান সময় (মাছেৰু)',
        'Africa/Mbabane' => 'দক্ষিণ আফ্ৰিকাৰ মান সময় (এম্বাবেন)',
        'Africa/Mogadishu' => 'পূব আফ্ৰিকাৰ সময় (মোগাদিচু)',
        'Africa/Monrovia' => 'গ্ৰীণউইচ মান সময় (মোনৰোভিয়া)',
        'Africa/Nairobi' => 'পূব আফ্ৰিকাৰ সময় (নাইৰোবি)',
        'Africa/Ndjamena' => 'পশ্চিম আফ্ৰিকাৰ সময় (নেদজামেনা)',
        'Africa/Niamey' => 'পশ্চিম আফ্ৰিকাৰ সময় (নিয়ামী)',
        'Africa/Nouakchott' => 'গ্ৰীণউইচ মান সময় (নৌআকচোট)',
        'Africa/Ouagadougou' => 'গ্ৰীণউইচ মান সময় (ঔগাডোগো)',
        'Africa/Porto-Novo' => 'পশ্চিম আফ্ৰিকাৰ সময় (পোৰ্টো-নোভো)',
        'Africa/Sao_Tome' => 'গ্ৰীণউইচ মান সময় (চাও টোমে)',
        'Africa/Tripoli' => 'প্ৰাচ্য ইউৰোপীয় সময় (ত্ৰিপোলি)',
        'Africa/Tunis' => 'মধ্য ইউৰোপীয় সময় (টুনিছ)',
        'Africa/Windhoek' => 'মধ্য আফ্ৰিকাৰ সময় (ৱিণ্ডহোক)',
        'America/Adak' => 'হাৱাই-এলিউশ্বনৰ সময় (আডাক)',
        'America/Anchorage' => 'আলাস্কাৰ সময় (এংকোৰেজ)',
        'America/Anguilla' => 'আটলাণ্টিক সময় (এনগুইলা)',
        'America/Antigua' => 'আটলাণ্টিক সময় (এণ্টিগুৱা)',
        'America/Araguaina' => 'ব্ৰাজিলিয়াৰ সময় (আৰাগায়েনা)',
        'America/Argentina/La_Rioja' => 'আৰ্জেণ্টিনাৰ সময় (লা ৰিওজা)',
        'America/Argentina/Rio_Gallegos' => 'আৰ্জেণ্টিনাৰ সময় (ৰিঅ’ গালেগোছ)',
        'America/Argentina/Salta' => 'আৰ্জেণ্টিনাৰ সময় (ছাল্টা)',
        'America/Argentina/San_Juan' => 'আৰ্জেণ্টিনাৰ সময় (ছেন জুৱান)',
        'America/Argentina/San_Luis' => 'আৰ্জেণ্টিনাৰ সময় (ছেন লুইচ)',
        'America/Argentina/Tucuman' => 'আৰ্জেণ্টিনাৰ সময় (টুকুমন)',
        'America/Argentina/Ushuaia' => 'আৰ্জেণ্টিনাৰ সময় (উচুআইয়া)',
        'America/Aruba' => 'আটলাণ্টিক সময় (আৰুবা)',
        'America/Asuncion' => 'পাৰাগুৱেৰ সময় (আছুনচিয়ন)',
        'America/Bahia' => 'ব্ৰাজিলিয়াৰ সময় (বাহিয়া)',
        'America/Bahia_Banderas' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (বাহিয়া বান্দেৰাছ)',
        'America/Barbados' => 'আটলাণ্টিক সময় (বাৰ্বাডোচ)',
        'America/Belem' => 'ব্ৰাজিলিয়াৰ সময় (বেলেম)',
        'America/Belize' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (বেলিজ)',
        'America/Blanc-Sablon' => 'আটলাণ্টিক সময় (ব্লাংক-ছেবলোন)',
        'America/Boa_Vista' => 'আমাজনৰ সময় (বোৱা ভিষ্টা)',
        'America/Bogota' => 'কলম্বিয়াৰ সময় (বোগোটা)',
        'America/Boise' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ব’ইজে)',
        'America/Buenos_Aires' => 'আৰ্জেণ্টিনাৰ সময় (বুনছ আয়াৰ্ছ)',
        'America/Cambridge_Bay' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (কেমব্ৰিজ উপসাগৰ)',
        'America/Campo_Grande' => 'আমাজনৰ সময় (কেম্পো গ্ৰেণ্ডে)',
        'America/Cancun' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (কেনকুন)',
        'America/Caracas' => 'ভেনিজুৱেলাৰ সময় (কাৰাকাছ)',
        'America/Catamarca' => 'আৰ্জেণ্টিনাৰ সময় (কাটামাৰ্কা)',
        'America/Cayenne' => 'ফ্ৰান্স গয়ানাৰ সময় (কেয়েন)',
        'America/Cayman' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (কেইমেন)',
        'America/Chicago' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (চিকাগো)',
        'America/Chihuahua' => 'মেক্সিকোৰ প্ৰশান্ত সময় (চিহুআহুৱা)',
        'America/Coral_Harbour' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (আটিকোকান)',
        'America/Cordoba' => 'আৰ্জেণ্টিনাৰ সময় (কোৰ্ডোবা)',
        'America/Costa_Rica' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (কোষ্টা ৰিকা)',
        'America/Creston' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ক্ৰেষ্টন)',
        'America/Cuiaba' => 'আমাজনৰ সময় (কুইআবা)',
        'America/Curacao' => 'আটলাণ্টিক সময় (কুৰাকাও)',
        'America/Danmarkshavn' => 'গ্ৰীণউইচ মান সময় (ডেনমাৰ্কশ্বন)',
        'America/Dawson' => 'য়ুকোন সময় (ডাওছন)',
        'America/Dawson_Creek' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ডাওছন ক্ৰীক)',
        'America/Denver' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ডেনভাৰ)',
        'America/Detroit' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ডেট্ৰোইট)',
        'America/Dominica' => 'আটলাণ্টিক সময় (ডমিনিকা)',
        'America/Edmonton' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (এডমণ্টন)',
        'America/Eirunepe' => 'ব্ৰাজিল সময় (ইৰুনেপে)',
        'America/El_Salvador' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (এল ছেলভেড’ৰ)',
        'America/Fort_Nelson' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ফ’ৰ্ট নেলছন)',
        'America/Fortaleza' => 'ব্ৰাজিলিয়াৰ সময় (ফোৰ্টালেজা)',
        'America/Glace_Bay' => 'আটলাণ্টিক সময় (গ্লেচ উপসাগৰ)',
        'America/Godthab' => 'পশ্চিম গ্ৰীণলেণ্ডৰ সময় (নুক)',
        'America/Goose_Bay' => 'আটলাণ্টিক সময় (গুছ উপসাগৰ)',
        'America/Grand_Turk' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (গ্ৰেণ্ড টাৰ্ক)',
        'America/Grenada' => 'আটলাণ্টিক সময় (গ্ৰেনাডা)',
        'America/Guadeloupe' => 'আটলাণ্টিক সময় (গুৱাডেলুপ)',
        'America/Guatemala' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (গুৱাটেমালা)',
        'America/Guayaquil' => 'ইকুৱেডৰৰ সময় (গায়াকুইল)',
        'America/Guyana' => 'গায়ানাৰ সময়',
        'America/Halifax' => 'আটলাণ্টিক সময় (হেলিফেক্স)',
        'America/Havana' => 'কিউবাৰ সময় (হাভানা)',
        'America/Hermosillo' => 'মেক্সিকোৰ প্ৰশান্ত সময় (হাৰ্মোছিল্লো)',
        'America/Indiana/Knox' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (নক্স, ইণ্ডিয়ানা)',
        'America/Indiana/Marengo' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (মাৰেংগো, ইণ্ডিয়ানা)',
        'America/Indiana/Petersburg' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পিটাৰ্ছবাৰ্গ, ইণ্ডিয়ানা)',
        'America/Indiana/Tell_City' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (টেল চিটী, ইণ্ডিয়ানা)',
        'America/Indiana/Vevay' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ভেভে, ইণ্ডিয়ানা)',
        'America/Indiana/Vincennes' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ভিনচেনেছ, ইণ্ডিয়ানা)',
        'America/Indiana/Winamac' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (উইনামেক, ইণ্ডিয়ানা)',
        'America/Indianapolis' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ইণ্ডিয়ানাপ’লিছ)',
        'America/Inuvik' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ইনুভিক)',
        'America/Iqaluit' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ইকালুইট)',
        'America/Jamaica' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (জামাইকা)',
        'America/Jujuy' => 'আৰ্জেণ্টিনাৰ সময় (জুজুই)',
        'America/Juneau' => 'আলাস্কাৰ সময় (জুনেউ)',
        'America/Kentucky/Monticello' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (মণ্টিচেলো, কেণ্টুকী)',
        'America/Kralendijk' => 'আটলাণ্টিক সময় (ক্ৰালেণ্ডিজিক)',
        'America/La_Paz' => 'বলিভিয়াৰ সময় (লা পাজ)',
        'America/Lima' => 'পেৰুৰ সময় (লিমা)',
        'America/Los_Angeles' => 'উত্তৰ আমেৰিকাৰ প্ৰশান্ত সময় (লছ এঞ্জেলছ্)',
        'America/Louisville' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (লুইছভিলে)',
        'America/Lower_Princes' => 'আটলাণ্টিক সময় (ল’ৱাৰ প্ৰিন্সেছ কোৱাৰ্টাৰ)',
        'America/Maceio' => 'ব্ৰাজিলিয়াৰ সময় (মেচিও)',
        'America/Managua' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মানাগুৱা)',
        'America/Manaus' => 'আমাজনৰ সময় (মানাছ)',
        'America/Marigot' => 'আটলাণ্টিক সময় (মেৰিগোট)',
        'America/Martinique' => 'আটলাণ্টিক সময় (মাৰ্টিনিক)',
        'America/Matamoros' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মাটামোৰোছ)',
        'America/Mazatlan' => 'মেক্সিকোৰ প্ৰশান্ত সময় (মাজাট্‌লান)',
        'America/Mendoza' => 'আৰ্জেণ্টিনাৰ সময় (মেণ্ডোজা)',
        'America/Menominee' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মেনোমিনী)',
        'America/Merida' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মেৰিডা)',
        'America/Metlakatla' => 'আলাস্কাৰ সময় (মেটলাকাট্‌লা)',
        'America/Mexico_City' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মেক্সিকো চিটী)',
        'America/Miquelon' => 'ছেইণ্ট পিয়েৰে আৰু মিকিউৱেলনৰ সময়',
        'America/Moncton' => 'আটলাণ্টিক সময় (মন্‌কটন)',
        'America/Monterrey' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (মণ্টেৰেৰী)',
        'America/Montevideo' => 'উৰুগুৱেৰ সময় (মণ্টেভিডিঅ’)',
        'America/Montreal' => 'কানাডা সময় (Montreal)',
        'America/Montserrat' => 'আটলাণ্টিক সময় (মণ্টছেৰাট)',
        'America/Nassau' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নাছাউ)',
        'America/New_York' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নিউ ইয়ৰ্ক)',
        'America/Nipigon' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নিপিগন)',
        'America/Nome' => 'আলাস্কাৰ সময় (নোম)',
        'America/Noronha' => 'ফাৰ্নাণ্ডো ডে নোৰোন্‌হাৰ সময়',
        'America/North_Dakota/Beulah' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (বেউলাহ, উত্তৰ ডাকোটা)',
        'America/North_Dakota/Center' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (চেণ্টাৰ, উত্তৰ ডাকোটা)',
        'America/North_Dakota/New_Salem' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (নিউ ছালেম, উত্তৰ ডাকোটা)',
        'America/Ojinaga' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (অ’জিনাগা)',
        'America/Panama' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পানামা)',
        'America/Pangnirtung' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পাংনিৰ্টুংগ)',
        'America/Paramaribo' => 'ছুৰিনামৰ সময় (পাৰামাৰিবো)',
        'America/Phoenix' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ফিনিক্স)',
        'America/Port-au-Prince' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (প’ৰ্ট-ঔ-প্ৰিন্স)',
        'America/Port_of_Spain' => 'আটলাণ্টিক সময় (প’ৰ্ট অৱ স্পেইন)',
        'America/Porto_Velho' => 'আমাজনৰ সময় (পোৰ্টো ভেল্‌হো)',
        'America/Puerto_Rico' => 'আটলাণ্টিক সময় (পুৱেৰ্টো ৰিকো)',
        'America/Punta_Arenas' => 'চিলিৰ সময় (পুণ্টা এৰিনাছ)',
        'America/Rainy_River' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰেইনী নদী)',
        'America/Rankin_Inlet' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰেংকিন ইনলেট)',
        'America/Recife' => 'ব্ৰাজিলিয়াৰ সময় (ৰেচাইফ)',
        'America/Regina' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰেজিনা)',
        'America/Resolute' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰিজ’লিউট)',
        'America/Rio_Branco' => 'ব্ৰাজিল সময় (ৰিঅ’ ব্ৰাংকো)',
        'America/Santa_Isabel' => 'উত্তৰ-পশ্চিম মেক্সিকোৰ সময় (Santa Isabel)',
        'America/Santarem' => 'ব্ৰাজিলিয়াৰ সময় (ছেণ্টাৰেম)',
        'America/Santiago' => 'চিলিৰ সময় (ছেণ্টিয়াগো)',
        'America/Santo_Domingo' => 'আটলাণ্টিক সময় (ছাণ্টো ডোমিংগো)',
        'America/Sao_Paulo' => 'ব্ৰাজিলিয়াৰ সময় (ছাও পাউলো)',
        'America/Scoresbysund' => 'পূব গ্ৰীণলেণ্ডৰ সময় (ইটোকোৰ্টোৰমিট)',
        'America/Sitka' => 'আলাস্কাৰ সময় (ছিট্‌‌কা)',
        'America/St_Barthelemy' => 'আটলাণ্টিক সময় (ছেইণ্ট বাৰ্থলেমে)',
        'America/St_Johns' => 'নিউফাউণ্ডলেণ্ডৰ সময় (ছেইণ্ট জনচ্)',
        'America/St_Kitts' => 'আটলাণ্টিক সময় (ছেইণ্ট কিটছ)',
        'America/St_Lucia' => 'আটলাণ্টিক সময় (ছেইণ্ট লুচিয়া)',
        'America/St_Thomas' => 'আটলাণ্টিক সময় (ছেইণ্ট থমাছ)',
        'America/St_Vincent' => 'আটলাণ্টিক সময় (ছেইণ্ট ভিনচেণ্ট)',
        'America/Swift_Current' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ছুইফ্ট কাৰেণ্ট)',
        'America/Tegucigalpa' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (টেগুচিগাল্পা)',
        'America/Thule' => 'আটলাণ্টিক সময় (থ্যুলে)',
        'America/Thunder_Bay' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (থাণ্ডাৰ উপসাগৰ)',
        'America/Tijuana' => 'উত্তৰ আমেৰিকাৰ প্ৰশান্ত সময় (তিজুৱানা)',
        'America/Toronto' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ট’ৰ’ণ্টো)',
        'America/Tortola' => 'আটলাণ্টিক সময় (টোৰ্টোলা)',
        'America/Vancouver' => 'উত্তৰ আমেৰিকাৰ প্ৰশান্ত সময় (ভেনকুভেৰ)',
        'America/Whitehorse' => 'য়ুকোন সময় (হোৱাইটহৰ্চ)',
        'America/Winnipeg' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৱিনিপেগ)',
        'America/Yakutat' => 'আলাস্কাৰ সময় (য়াকুটাট)',
        'America/Yellowknife' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (য়েল্লোনাইফ)',
        'Antarctica/Casey' => 'এণ্টাৰ্কটিকা সময় (কেছী)',
        'Antarctica/Davis' => 'ডেভিছৰ সময়',
        'Antarctica/DumontDUrville' => 'ডুমোণ্ট-ডি আৰ্ভিলৰ সময়',
        'Antarctica/Macquarie' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (মেক্‌কুৱেৰী)',
        'Antarctica/Mawson' => 'মাউছনৰ সময়',
        'Antarctica/McMurdo' => 'নিউজিলেণ্ডৰ সময় (মেকমুৰ্ডু)',
        'Antarctica/Palmer' => 'চিলিৰ সময় (পামৰ)',
        'Antarctica/Rothera' => 'ৰোথেৰাৰ সময়',
        'Antarctica/Syowa' => 'স্বোৱা সময়',
        'Antarctica/Troll' => 'গ্ৰীণউইচ মান সময় (ট্ৰোল)',
        'Antarctica/Vostok' => 'ভোষ্টকৰ সময়',
        'Arctic/Longyearbyen' => 'মধ্য ইউৰোপীয় সময় (লংগেইৰবায়েন)',
        'Asia/Aden' => 'আৰবীয় সময় (আদেন)',
        'Asia/Almaty' => 'পূব কাজাখস্তানৰ সময় (আলমাটি)',
        'Asia/Amman' => 'প্ৰাচ্য ইউৰোপীয় সময় (আম্মান)',
        'Asia/Anadyr' => 'ৰাছিয়া সময় (আনাডিৰ)',
        'Asia/Aqtau' => 'পশ্চিম কাজাখস্তানৰ সময় (এক্যোট্যাও)',
        'Asia/Aqtobe' => 'পশ্চিম কাজাখস্তানৰ সময় (এক্যোটব)',
        'Asia/Ashgabat' => 'তুৰ্কমেনিস্তানৰ সময় (আশ্ব্গা‌বাট)',
        'Asia/Atyrau' => 'পশ্চিম কাজাখস্তানৰ সময় (এটৰাউ)',
        'Asia/Baghdad' => 'আৰবীয় সময় (বাগদাদ)',
        'Asia/Bahrain' => 'আৰবীয় সময় (বাহৰেইন)',
        'Asia/Baku' => 'আজেৰবাইজানৰ সময় (বাকু)',
        'Asia/Bangkok' => 'ইণ্ডোচাইনাৰ সময় (বেংকক)',
        'Asia/Barnaul' => 'ৰাছিয়া সময় (বাৰ্নুল)',
        'Asia/Beirut' => 'প্ৰাচ্য ইউৰোপীয় সময় (বেইৰুট)',
        'Asia/Bishkek' => 'কিৰ্গিজস্তানৰ সময় (বিশ্ব্‌কেক)',
        'Asia/Brunei' => 'ব্ৰুনেই ডাৰুছালেমৰ সময়',
        'Asia/Calcutta' => 'ভাৰতীয় মান সময় (কলকাতা)',
        'Asia/Chita' => 'য়াকুত্স্কৰ সময় (চিটা)',
        'Asia/Choibalsan' => 'উলানবাটাৰৰ সময় (কোইবাল্ছন)',
        'Asia/Colombo' => 'ভাৰতীয় মান সময় (কলম্বো)',
        'Asia/Damascus' => 'প্ৰাচ্য ইউৰোপীয় সময় (ডামাস্কাছ)',
        'Asia/Dhaka' => 'বাংলাদেশৰ সময় (ঢাকা)',
        'Asia/Dili' => 'পূব তিমোৰৰ সময় (ডিলি)',
        'Asia/Dubai' => 'উপসাগৰীয় মান সময় (ডুবাই)',
        'Asia/Dushanbe' => 'তাজিকিস্তানৰ সময় (ডুছানবে)',
        'Asia/Famagusta' => 'প্ৰাচ্য ইউৰোপীয় সময় (ফামাগুস্তা)',
        'Asia/Gaza' => 'প্ৰাচ্য ইউৰোপীয় সময় (গাজা)',
        'Asia/Hebron' => 'প্ৰাচ্য ইউৰোপীয় সময় (হেব্ৰোন)',
        'Asia/Hong_Kong' => 'হং কঙৰ সময় (হং কং)',
        'Asia/Hovd' => 'হোভ্‌ডৰ সময়',
        'Asia/Irkutsk' => 'ইৰ্কুটস্কৰ সময় (ইৰ্কুত্স্ক)',
        'Asia/Jakarta' => 'পাশ্চাত্য ইণ্ডোনেচিয়াৰ সময় (জাকাৰ্টা)',
        'Asia/Jayapura' => 'প্ৰাচ্য ইণ্ডোনেচিয়াৰ সময় (জায়াপুৰা)',
        'Asia/Jerusalem' => 'ইজৰাইলৰ সময় (জেৰুজালেম)',
        'Asia/Kabul' => 'আফগানিস্তানৰ সময় (কাবুল)',
        'Asia/Kamchatka' => 'ৰাছিয়া সময় (কামচত্কা)',
        'Asia/Karachi' => 'পাকিস্তানৰ সময় (কৰাচী)',
        'Asia/Katmandu' => 'নেপালৰ সময় (কাঠমাণ্ডু)',
        'Asia/Khandyga' => 'য়াকুত্স্কৰ সময় (খাণ্ডিগা)',
        'Asia/Krasnoyarsk' => 'ক্ৰাছনোয়াৰ্স্কৰ সময়',
        'Asia/Kuala_Lumpur' => 'মালয়েচিয়াৰ সময় (কুৱালালুমপুৰ)',
        'Asia/Kuching' => 'মালয়েচিয়াৰ সময় (কুচিং)',
        'Asia/Kuwait' => 'আৰবীয় সময় (কুৱেইট)',
        'Asia/Macau' => 'চীনৰ সময় (মাকাও)',
        'Asia/Magadan' => 'মাগাদানৰ সময়',
        'Asia/Makassar' => 'মধ্য ইণ্ডোনেচিয়াৰ সময় (মাকাছাৰ)',
        'Asia/Manila' => 'ফিলিপাইনৰ সময় (মানিলা)',
        'Asia/Muscat' => 'উপসাগৰীয় মান সময় (মুস্কেট)',
        'Asia/Nicosia' => 'প্ৰাচ্য ইউৰোপীয় সময় (নিকোছিয়া)',
        'Asia/Novokuznetsk' => 'ক্ৰাছনোয়াৰ্স্কৰ সময় (নোভোকুজনেত্স্ক)',
        'Asia/Novosibirsk' => 'নভোছিবিৰ্স্কৰ সময় (নোভোছিবিৰ্স্ক)',
        'Asia/Omsk' => 'ওমস্কৰ সময়',
        'Asia/Oral' => 'পশ্চিম কাজাখস্তানৰ সময় (অ’ৰেল)',
        'Asia/Phnom_Penh' => 'ইণ্ডোচাইনাৰ সময় (নোম পেন্‌হ)',
        'Asia/Pontianak' => 'পাশ্চাত্য ইণ্ডোনেচিয়াৰ সময় (পোণ্টিয়াংক)',
        'Asia/Pyongyang' => 'কোৰিয়াৰ সময় (প্যংয়াং)',
        'Asia/Qatar' => 'আৰবীয় সময় (কাটাৰ)',
        'Asia/Qostanay' => 'পূব কাজাখস্তানৰ সময় (ক’ষ্টেনী)',
        'Asia/Qyzylorda' => 'পশ্চিম কাজাখস্তানৰ সময় (কেজিলোৰ্ডা)',
        'Asia/Rangoon' => 'ম্যানমাৰৰ সময় (য়াঙোন)',
        'Asia/Riyadh' => 'আৰবীয় সময় (ৰিয়াধ)',
        'Asia/Saigon' => 'ইণ্ডোচাইনাৰ সময় (হো চি মিন চিটী)',
        'Asia/Sakhalin' => 'ছাখালিনৰ সময়',
        'Asia/Samarkand' => 'উজবেকিস্তানৰ সময় (ছামাৰকাণ্ড)',
        'Asia/Seoul' => 'কোৰিয়াৰ সময় (ছিউল)',
        'Asia/Shanghai' => 'চীনৰ সময় (ছাংহাই)',
        'Asia/Singapore' => 'ছিংগাপুৰৰ মান সময়',
        'Asia/Srednekolymsk' => 'মাগাদানৰ সময় (স্ৰেডনিকোলিমস্ক)',
        'Asia/Taipei' => 'টাইপেইৰ সময়',
        'Asia/Tashkent' => 'উজবেকিস্তানৰ সময় (তাছকেণ্ট)',
        'Asia/Tbilisi' => 'জৰ্জিয়াৰ সময় (টিবলিচি)',
        'Asia/Tehran' => 'ইৰানৰ সময় (তেহৰান)',
        'Asia/Thimphu' => 'ভুটানৰ সময় (থিম্ফু)',
        'Asia/Tokyo' => 'জাপানৰ সময় (টকিঅ’)',
        'Asia/Tomsk' => 'ৰাছিয়া সময় (তোম্‌স্ক)',
        'Asia/Ulaanbaatar' => 'উলানবাটাৰৰ সময়',
        'Asia/Urumqi' => 'চীন সময় (উৰুম্‌কি)',
        'Asia/Ust-Nera' => 'ভ্লাডিভোষ্টোকৰ সময় (উষ্ট-নেৰা)',
        'Asia/Vientiane' => 'ইণ্ডোচাইনাৰ সময় (ভিয়েণ্টিয়ান)',
        'Asia/Vladivostok' => 'ভ্লাডিভোষ্টোকৰ সময় (ভ্লাডিভোষ্টক)',
        'Asia/Yakutsk' => 'য়াকুত্স্কৰ সময়',
        'Asia/Yekaterinburg' => 'য়েকাটেৰিণবাৰ্গৰ সময়',
        'Asia/Yerevan' => 'আৰ্মেনিয়াৰ সময় (য়েৰেভান)',
        'Atlantic/Azores' => 'আজোৰেছ সময় (এজোৰেছ)',
        'Atlantic/Bermuda' => 'আটলাণ্টিক সময় (বাৰ্মুডা)',
        'Atlantic/Canary' => 'পাশ্চাত্য ইউৰোপীয় সময় (কেনেৰী)',
        'Atlantic/Cape_Verde' => 'কেপ ভাৰ্দেৰ সময়',
        'Atlantic/Faeroe' => 'পাশ্চাত্য ইউৰোপীয় সময় (ফাৰো)',
        'Atlantic/Madeira' => 'পাশ্চাত্য ইউৰোপীয় সময় (মাডেৰা)',
        'Atlantic/Reykjavik' => 'গ্ৰীণউইচ মান সময় (ৰেইকজাভিক)',
        'Atlantic/South_Georgia' => 'দক্ষিণ জৰ্জিয়াৰ সময়',
        'Atlantic/St_Helena' => 'গ্ৰীণউইচ মান সময় (ছেইণ্ট হেলেনা)',
        'Atlantic/Stanley' => 'ফকলেণ্ড দ্বীপপুঞ্জৰ সময় (ষ্টেন্‌লী)',
        'Australia/Adelaide' => 'মধ্য অষ্ট্ৰেলিয়াৰ সময় (এডিলেইড)',
        'Australia/Brisbane' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (ব্ৰিচবেন)',
        'Australia/Broken_Hill' => 'মধ্য অষ্ট্ৰেলিয়াৰ সময় (ব্ৰোকেন হিল)',
        'Australia/Currie' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (ক্যুৰি)',
        'Australia/Darwin' => 'মধ্য অষ্ট্ৰেলিয়াৰ সময় (ডাৰউইন)',
        'Australia/Eucla' => 'অষ্ট্ৰেলিয়াৰ কেন্দ্ৰীয় পাশ্চাত্য সময় (ইউক্লা)',
        'Australia/Hobart' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (হোবাৰ্ট)',
        'Australia/Lindeman' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (লিণ্ডমান)',
        'Australia/Lord_Howe' => 'লৰ্ড হাওৰ সময়',
        'Australia/Melbourne' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (মেলব’ৰ্ণ)',
        'Australia/Perth' => 'পাশ্চাত্য অষ্ট্ৰেলিয়াৰ সময় (পাৰ্থ)',
        'Australia/Sydney' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (চিডনী)',
        'CST6CDT' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময়',
        'EST5EDT' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময়',
        'Etc/GMT' => 'গ্ৰীণউইচ মান সময়',
        'Etc/UTC' => 'সমন্বিত সাৰ্বজনীন সময়',
        'Europe/Amsterdam' => 'মধ্য ইউৰোপীয় সময় (আমষ্টাৰডাম)',
        'Europe/Andorra' => 'মধ্য ইউৰোপীয় সময় (আন্দোৰা)',
        'Europe/Astrakhan' => 'মস্কোৰ সময় (আষ্ট্ৰাখান)',
        'Europe/Athens' => 'প্ৰাচ্য ইউৰোপীয় সময় (এথেন্স)',
        'Europe/Belgrade' => 'মধ্য ইউৰোপীয় সময় (বেলগ্ৰেড)',
        'Europe/Berlin' => 'মধ্য ইউৰোপীয় সময় (বাৰ্লিন)',
        'Europe/Bratislava' => 'মধ্য ইউৰোপীয় সময় (ব্ৰাটিছলাভা)',
        'Europe/Brussels' => 'মধ্য ইউৰোপীয় সময় (ব্ৰুছলেছ)',
        'Europe/Bucharest' => 'প্ৰাচ্য ইউৰোপীয় সময় (বুচাৰেষ্ট)',
        'Europe/Budapest' => 'মধ্য ইউৰোপীয় সময় (বুডাপেষ্ট)',
        'Europe/Busingen' => 'মধ্য ইউৰোপীয় সময় (বুছিনজেন)',
        'Europe/Chisinau' => 'প্ৰাচ্য ইউৰোপীয় সময় (চিছিনাউ)',
        'Europe/Copenhagen' => 'মধ্য ইউৰোপীয় সময় (কোপেনহাগেন)',
        'Europe/Dublin' => 'গ্ৰীণউইচ মান সময় (ডাবলিন)',
        'Europe/Gibraltar' => 'মধ্য ইউৰোপীয় সময় (জিব্ৰাল্টৰ)',
        'Europe/Guernsey' => 'গ্ৰীণউইচ মান সময় (গোৰেনচি)',
        'Europe/Helsinki' => 'প্ৰাচ্য ইউৰোপীয় সময় (হেলছিংকি)',
        'Europe/Isle_of_Man' => 'গ্ৰীণউইচ মান সময় (আইল অফ মেন)',
        'Europe/Istanbul' => 'তুৰ্কি সময় (ইস্তানবুল)',
        'Europe/Jersey' => 'গ্ৰীণউইচ মান সময় (জাৰ্চি)',
        'Europe/Kaliningrad' => 'প্ৰাচ্য ইউৰোপীয় সময় (কালিনিনগ্ৰাড)',
        'Europe/Kiev' => 'প্ৰাচ্য ইউৰোপীয় সময় (কিভ)',
        'Europe/Kirov' => 'ৰাছিয়া সময় (কিৰোভ)',
        'Europe/Lisbon' => 'পাশ্চাত্য ইউৰোপীয় সময় (লিছবন)',
        'Europe/Ljubljana' => 'মধ্য ইউৰোপীয় সময় (ল্যুবেলজানা)',
        'Europe/London' => 'গ্ৰীণউইচ মান সময় (লণ্ডন)',
        'Europe/Luxembourg' => 'মধ্য ইউৰোপীয় সময় (লাক্সেমবাৰ্গ)',
        'Europe/Madrid' => 'মধ্য ইউৰোপীয় সময় (মাদ্ৰিদ)',
        'Europe/Malta' => 'মধ্য ইউৰোপীয় সময় (মাল্টা)',
        'Europe/Mariehamn' => 'প্ৰাচ্য ইউৰোপীয় সময় (মাৰিয়াহেম)',
        'Europe/Minsk' => 'মস্কোৰ সময় (মিংস্ক)',
        'Europe/Monaco' => 'মধ্য ইউৰোপীয় সময় (মোনাকো)',
        'Europe/Moscow' => 'মস্কোৰ সময়',
        'Europe/Oslo' => 'মধ্য ইউৰোপীয় সময় (ওস্লো)',
        'Europe/Paris' => 'মধ্য ইউৰোপীয় সময় (পেৰিছ)',
        'Europe/Podgorica' => 'মধ্য ইউৰোপীয় সময় (পোডগোৰিকা)',
        'Europe/Prague' => 'মধ্য ইউৰোপীয় সময় (প্ৰাগ)',
        'Europe/Riga' => 'প্ৰাচ্য ইউৰোপীয় সময় (ৰিগা)',
        'Europe/Rome' => 'মধ্য ইউৰোপীয় সময় (ৰোম)',
        'Europe/Samara' => 'ৰাছিয়া সময় (ছামাৰা)',
        'Europe/San_Marino' => 'মধ্য ইউৰোপীয় সময় (চান মাৰিনো)',
        'Europe/Sarajevo' => 'মধ্য ইউৰোপীয় সময় (ছাৰাজেভো)',
        'Europe/Saratov' => 'মস্কোৰ সময় (ছাৰাটোভ)',
        'Europe/Simferopol' => 'মস্কোৰ সময় (ছিম্ফেৰোপোল)',
        'Europe/Skopje' => 'মধ্য ইউৰোপীয় সময় (স্কোপ্জে)',
        'Europe/Sofia' => 'প্ৰাচ্য ইউৰোপীয় সময় (ছোফিয়া)',
        'Europe/Stockholm' => 'মধ্য ইউৰোপীয় সময় (ষ্টকহোম)',
        'Europe/Tallinn' => 'প্ৰাচ্য ইউৰোপীয় সময় (তেলিন)',
        'Europe/Tirane' => 'মধ্য ইউৰোপীয় সময় (টাইৰেন)',
        'Europe/Ulyanovsk' => 'মস্কোৰ সময় (উল্যানোভ্‌স্ক)',
        'Europe/Uzhgorod' => 'প্ৰাচ্য ইউৰোপীয় সময় (উজ্গোৰোড)',
        'Europe/Vaduz' => 'মধ্য ইউৰোপীয় সময় (ভাদুজ)',
        'Europe/Vatican' => 'মধ্য ইউৰোপীয় সময় (ভেটিকান)',
        'Europe/Vienna' => 'মধ্য ইউৰোপীয় সময় (ভিয়েনা)',
        'Europe/Vilnius' => 'প্ৰাচ্য ইউৰোপীয় সময় (ভিলনিয়াছ)',
        'Europe/Volgograd' => 'ভোল্গোগ্ৰাডৰ সময়',
        'Europe/Warsaw' => 'মধ্য ইউৰোপীয় সময় (ৱাৰছাও)',
        'Europe/Zagreb' => 'মধ্য ইউৰোপীয় সময় (জাগ্ৰেব)',
        'Europe/Zaporozhye' => 'প্ৰাচ্য ইউৰোপীয় সময় (জাপোৰোজাই)',
        'Europe/Zurich' => 'মধ্য ইউৰোপীয় সময় (জুৰিখ)',
        'Indian/Antananarivo' => 'পূব আফ্ৰিকাৰ সময় (এণ্টানানাৰিভো)',
        'Indian/Chagos' => 'ভাৰত মহাসাগৰীয় সময় (চাগোছ)',
        'Indian/Christmas' => 'খ্ৰীষ্টমাছ দ্বীপৰ সময়',
        'Indian/Cocos' => 'কোকোছ দ্বীপপুঞ্জৰ সময়',
        'Indian/Comoro' => 'পূব আফ্ৰিকাৰ সময় (কোমোৰো)',
        'Indian/Kerguelen' => 'দক্ষিণ ফ্ৰান্স আৰু এণ্টাৰ্কটিক সময় (কেৰগুলেন)',
        'Indian/Mahe' => 'ছিচিলিছৰ সময় (মাহে)',
        'Indian/Maldives' => 'মালদ্বীপৰ সময়',
        'Indian/Mauritius' => 'মৰিছাছৰ সময়',
        'Indian/Mayotte' => 'পূব আফ্ৰিকাৰ সময় (মায়োট্টে)',
        'Indian/Reunion' => 'ৰিইউনিয়নৰ সময়',
        'MST7MDT' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময়',
        'PST8PDT' => 'উত্তৰ আমেৰিকাৰ প্ৰশান্ত সময়',
        'Pacific/Apia' => 'আপিয়াৰ সময়',
        'Pacific/Auckland' => 'নিউজিলেণ্ডৰ সময় (অকলেণ্ড)',
        'Pacific/Bougainville' => 'পাপুৱা নিউ গিনিৰ সময় (বোগেইনভিলে)',
        'Pacific/Chatham' => 'চাথামৰ সময়',
        'Pacific/Easter' => 'ইষ্টাৰ দ্বীপৰ সময়',
        'Pacific/Efate' => 'ভানাটুৰ সময় (এফেট)',
        'Pacific/Enderbury' => 'ফিনিক্স দ্বীপপুঞ্জৰ সময় (এণ্ডৰবাৰী)',
        'Pacific/Fakaofo' => 'টোকেলাউৰ সময় (ফাকাওফো)',
        'Pacific/Fiji' => 'ফিজিৰ সময়',
        'Pacific/Funafuti' => 'টুভালাউৰ সময় (ফুনাফুটি)',
        'Pacific/Galapagos' => 'গালাপাগোছৰ সময়',
        'Pacific/Gambier' => 'গেম্বিয়াৰ সময়',
        'Pacific/Guadalcanal' => 'চোলোমোন দ্বীপপুঞ্জৰ সময় (গুৱাডলকানাল)',
        'Pacific/Guam' => 'চামোৰোৰ মান সময় (গুৱাম)',
        'Pacific/Honolulu' => 'হাৱাই-এলিউশ্বনৰ সময় (Honolulu)',
        'Pacific/Johnston' => 'হাৱাই-এলিউশ্বনৰ সময় (জনষ্টন)',
        'Pacific/Kiritimati' => 'লাইন দ্বীপপুঞ্জৰ সময় (কিৰিটিমাটি)',
        'Pacific/Kosrae' => 'কোছৰায়ে সময়',
        'Pacific/Kwajalein' => 'মাৰ্শ্বাল দ্বীপপুঞ্জৰ সময় (কোৱাজালিন)',
        'Pacific/Majuro' => 'মাৰ্শ্বাল দ্বীপপুঞ্জৰ সময় (মাজুৰো)',
        'Pacific/Marquesas' => 'মাৰ্কছেছৰ সময় (মাৰ্কছাছ)',
        'Pacific/Midway' => 'ছামোৱাৰ সময় (মিডৱে)',
        'Pacific/Nauru' => 'নাউৰুৰ সময় (নাৰু)',
        'Pacific/Niue' => 'নিয়ুৰ সময় (নিয়ো)',
        'Pacific/Norfolk' => 'ন’ৰফ’ক দ্বীপৰ সময়',
        'Pacific/Noumea' => 'নিউ কেলিডোনিয়াৰ সময় (নউমিয়া)',
        'Pacific/Pago_Pago' => 'ছামোৱাৰ সময় (পাগো পাগো)',
        'Pacific/Palau' => 'পালাউৰ সময়',
        'Pacific/Pitcairn' => 'পিটকেইৰ্ণৰ সময়',
        'Pacific/Ponape' => 'পোনাপেৰ সময় (পোনপেই)',
        'Pacific/Port_Moresby' => 'পাপুৱা নিউ গিনিৰ সময় (প’ৰ্ট মোৰেছ্‌বি)',
        'Pacific/Rarotonga' => 'কুক দ্বীপপুঞ্জৰ সময় (ৰাৰোটোঙ্গা)',
        'Pacific/Saipan' => 'চামোৰোৰ মান সময় (ছাইপান)',
        'Pacific/Tahiti' => 'তাহিতিৰ সময়',
        'Pacific/Tarawa' => 'গিলবাৰ্ট দ্বীপপুঞ্জৰ সময় (তাৰাৱা)',
        'Pacific/Tongatapu' => 'টংগাৰ সময় (টংগাটাপু)',
        'Pacific/Truk' => 'চ্চুকৰ সময়',
        'Pacific/Wake' => 'ৱেক দ্বীপৰ সময়',
        'Pacific/Wallis' => 'ৱালিছ আৰু ফুটুনাৰ সময়',
    ],
    'Meta' => [
    ],
];
