<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'ئاندورران پېسېتاسى',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'ئەرەب بىرلەشمە خەلىپىلىكى دەرھەمى',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'ئافغان ئافغانى (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'ئافغان ئافغانى',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'ئالبانىيە لېكى (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'ئالبانىيە لېكى',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'ئەرمېنىيە دىرامى',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'گوللاندىيەگە قاراشلىق ئانتىللېن گۇلدېنى',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'ئانگولا كۇۋانزاسى',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'ئانگولا كۇۋانزاسى (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'ئانگولا يېڭى كۇۋانزاسى (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'ئانگولا قايتا تەڭشەلگەن كۇۋانزاسى (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'ئارگېنتىنا ئاۋسترالى',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'ئارگېنتىنا پېسو لېيى (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'ئارگېنتىنا پېسوسى (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'ئارگېنتىنا پېسوسى (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'ئارگېنتىنا پېسوسى',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'ئاۋسترىيە شىللىڭى',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'ئاۋسترالىيە دوللىرى',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'ئارۇبان فىلورۇنى',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'ئەزەربەيجان ماناتى (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'ئەزەربەيجان ماناتى',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'بوسنىيە-خېرتسېگوۋىنا دىنارى (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'بوسنىيە-خېرتسېگوۋىنا ئالماشتۇرۇشچان ماركى',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'بوسنىيە-خېرتسېگوۋىنا يېڭى دىنارى (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'باربادوس دوللىرى',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'باڭلادىش تاكاسى',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'بېلگىيە فرانكى (ئالماشتۇرۇشچان)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'بېلگىيە فرانكى',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'بېلگىيە فرانكى (پۇل–مۇئامىلە)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'بۇلغارىيە قاتتىق لېۋاسى',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'بۇلغارىيە ئىجتىمائىي لېۋاسى',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'بۇلغارىيە لېۋاسى',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'بۇلغارىيە لېۋاسى (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'بەھرەين دىنارى',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'بۇرۇندى فرانكى',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'بېرمۇدا دوللىرى',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'بىرۇنېي دوللىرى',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'بولىۋىيە بولىۋىيانوسى',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'بولىۋىيە بولىۋىيانوسى (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'بولىۋىيە پىسوسى',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'بولىۋىيە مۇدولى',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'بىرازىلىيە يېڭى كرۇزېروسى (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'بىرازىلىيە كرۇزادوسى (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'بىرازىلىيە يېڭى كرۇزېروسى (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'بىرازىلىيە رىيالى',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'بىرازىلىيە يېڭى كرۇزادوسى (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'بىرازىلىيە كرۇزېروسى (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'بىرازىلىيە كرۇزېروسى (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'باھاما دوللىرى',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'بۇتان نگۇلترۇمى',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'بىرما كىياتى',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'بوتسۋانا پۇلاسى',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'بېلارۇسىيە يېڭى رۇبلىسى (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'بېلارۇسىيە رۇبلىسى',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'بېلارۇسىيە رۇبلىسى (۲۰۰۰–۲۰۱۶)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'بېلىز دوللىرى',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'كانادا دوللىرى',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'كونگو فرانكى',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR ياۋرو',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'شىۋېتسىيە فرانكى',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR فرانكى',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'چىلى ئېسكۇدوسى',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'چىلى ھېسابات بىرلىكى (UF)',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'چىلى پېسوسى',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'جۇڭگو خەلق بانكىسى دوللىرى',
        ],
        'CNY' => [
            0 => '￥',
            1 => 'جۇڭگو يۈەنى',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'كولومبىيە پېسوسى',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'كولومبىيە ھەقىقىي قىممەت بىرلىكى',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'كوستارىكا كولونى',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'سېربىيە دىنارى (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'چېخسىلوۋاكىيە قاتتىق كورۇناسى',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'كۇبا ئالماشتۇرۇشچان پېسوسى',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'كۇبا پېسوسى',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'يېشىل تۇمشۇق ئېسكۇدوسى',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'سىپرۇس فوند ستېرلىڭى',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'چېخ جۇمھۇرىيىتى كورۇناسى',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'شەرقىي گېرمانىيە ماركى',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'گېرمانىيە ماركى',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'جىبۇتى فرانكى',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'دانىيە كرونى',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'دومىنىكا پېسوسى',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'ئالجىرىيە دىنارى',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'ئېكۋادور سۇكرېسى',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'ئېكۋادور تۇراقلىق قىممەت بىرلىكى',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'ئېستونىيە كرۇنى',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'مىسىر فوند سىتېرلىڭى',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'ئېرىترېيە ناكفاسى',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'ئىسپانىيە پېسېتاسى (A ھېسابات)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'ئىسپانىيە پېسېتاسى (ئالماشتۇرۇش ھېساباتى)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'ئىسپانىيە پېسېتاسى',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'ئېفىيوپىيە بىررى',
        ],
        'EUR' => [
            0 => '€',
            1 => 'ياۋرو',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'فىنلاندىيە مارككاسى',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'فىجى دوللىرى',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'فالكلاند ئاراللىرى فوند سىتېرلىڭى',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'فىرانسىيە فرانكى',
        ],
        'GBP' => [
            0 => '£',
            1 => 'ئەنگلىيە فوند سىتېرلىڭى',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'گىرۇزىيە كۇپون لارىتى',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'گىرۇزىيە لارىسى',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'گانا سېدىسى (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'گانا سېدىسى',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'جەبىلتارىق فوند سىتېرلىڭى',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'گامبىيە دالاسى',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'گىۋىنېيە فرانكى',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'گىۋىنېيە سىلىسى',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ئېكۋاتور گىۋىنېيە ئېكۋېلېسى',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'گىرېتسىيە دراخماسى',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'گىۋاتېمالا كۇۋېتزالى',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'پورتۇگالىيە گىۋىنېيە ئېسكۇدوسى',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'گىۋىنېيە-بىسسائۇ پېسوسى',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'گىۋىئانا دوللىرى',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'شياڭگاڭ دوللىرى',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'ھوندۇراس لېمپىراسى',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'كىرودىيە دىنارى',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'كىرودىيە كۇناسى',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'ھايتى گۇردېسى',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'ۋېنگىرىيە فورېنتى',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'ھىندونېزىيە رۇپىيەسى',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'ئىرېلاندىيە فوندستېرلىڭى',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'ئىسرائىلىيە فوندستېرلىڭى',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'ئىسرائىل شېكېلى (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'ئىسرائىل يېڭى شېكېلى',
        ],
        'INR' => [
            0 => '₹',
            1 => 'ھىندىستان رۇپىسى',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'ئىراق دىنارى',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'ئىران رىيالى',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'ئىسلاندىيە كروناسى (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'ئىسلاندىيە كروناسى',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'ئىتالىيە لىراسى',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'يامايكا دوللىرى',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'ئىيوردانىيە دىنارى',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'ياپونىيە يېنى',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'كېنىيە شىللىڭى',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'قىرغىزىستان سومى',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'كامبودژا رىئېلى',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'كومورو فرانكى',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'شىمالىي كورېيە ۋونى',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'جەنۇبىي كورېيە خۋانى (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'جەنۇبىي كورېيە ۋونى (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'جەنۇبىي كورېيە ۋونى',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'كۇۋەيت دىنارى',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'كايمان ئاراللىرى دوللىرى',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'قازاقىستان تەڭگىسى',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'لائوس كىپى',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'لىۋان فوند سىتېرلىڭى',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'سىرىلانكا رۇپىسى',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'لىبېرىيە دوللىرى',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'لېسوتو لوتىسى',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'لىتۋا لىتاسى',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'لىتۋا تالوناسى',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'ليۇكسېمبۇرگ ئالماشتۇرۇشچان پېسوسى',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'ليۇكسېمبۇرگ فرانكى',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'لىيۇكسېمبۇرگ پۇل-مۇئامىلە فرانكى',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'لاتۋىيە لاتى',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'لاتۋىيە رۇبلىسى',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'لىۋىيە دىنارى',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'ماراكەش دىرھەمى',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'ماراكەش فرانكى',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'موناكو فرانكى',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'مولدوۋا كۇپونى',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'مولدوۋا لېۋى',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ماداغاسقار ئارىئارىسى',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'ماداغاسقار فرانكى',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'ماكېدونىيە دىنارى',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'ماكېدونىيە دىنارى (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'مالى فرانكى',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'مىيانمار كىياتى',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'موڭغۇلىيە تۈگرىكى',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'ئاۋمېن پاتاكاسى',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ماۋرىتانىيە ئۇگىيەسى (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ماۋرىتانىيە ئۇگىيەسى',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'مالتا لىراسى',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'مالتا فوندستېرلىڭى',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'ماۋرىتىئۇس رۇپىسى',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'مالدىۋى رۇپىسى',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'مالدىۋى رۇفىياسى',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'مالاۋى كۋاچاسى',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'مېكسىكا پېسوسى',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'مېكسىكا كۈمۈش پېسوسى (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'مېكسىكا مەبلەغ بىرلىكى',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'مالايشىيا رىڭگىتى',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'موزامبىك ئېسكۇدوسى',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'موزامبىك مېتىكالى (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'موزامبىك مېتىكالى',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'نامىبىيە دوللىرى',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'نىگېرىيە نايراسى',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'نىگېرىيە كوردوباسى (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'نىگېرىيە كوردوباسى',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'گوللاندىيە گۈلدىنى',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'نورۋېگىيە كرونى',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'نېپال رۇپىسى',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'يېڭى زېلاندىيە دوللىرى',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'ئومان رىيالى',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'پاناما بالبوئاسى',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'پېرۇ ئىنتىسى',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'پېرۇ سولى',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'پېرۇ سولى (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'پاپۇئا يېڭى گىۋىنېيە كىناسى',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'فىلىپپىن پېسوسى',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'پاكىستان رۇپىسى',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'پولشا زىلوتى',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'پولشا زىلوتى (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'پورتۇگالىيە ئېسكۇدوسى',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'پاراگۋاي گۇئارانىسى',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'قاتار رىيالى',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'رودېزىيە دوللىرى',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'رۇمىنىيە لېيى (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'رۇمىنىيە لېيى',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'سېربىيە دىنارى',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'رۇسىيە رۇبلىسى',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'رۇسىيە رۇبلىسى (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'رۋاندا فرانكى',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'سەئۇدى رىيالى',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'سولومون ئاراللىرى دوللىرى',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'سېيشېل رۇپىسى',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'سۇدان دىنارى (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'سۇدان فوندستېرلىڭى',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'سۇدان فوندستېرلىڭى (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'شىۋېتسىيە كروناسى',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'سىنگاپور دوللىرى',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'ساينىت-ھېلېنا فوندستېرلىڭى',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'سىلوۋېنىيە تولارى',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'سىلوۋاكىيە كورۇناسى',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'سېررالېئون لېئونېسى',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'سومالى شىللىڭى',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'سۇرىنام دوللىرى',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'سۇرىنام گۈلدىنى',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'جەنۇبىي سۇدان فوندستېرلىڭى',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'سان-تومې ۋە پىرىنسىپى دوبراسى (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'سان-تومې ۋە پىرىنسىپى دوبراسى',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'سوۋىت رۇبلىسى',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'سالۋادور كولونى',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'سۈرىيە فوندستېرلىڭى',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'سىۋېزىلاند لىلانگېنى',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'تايلاند باختى',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'تاجىكىستان رۇبلىسى',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'تاجىكىستان سومونىسى',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'تۈركمەنىستان ماناتى (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'تۈركمەنىستان ماناتى',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'تۇنىس دىنارى',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'تونگا پائانگاسى',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'تىمور ئېسكۇدوسى',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'تۈركىيە لىراسى (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'تۈركىيە لىراسى',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'تىرىنىداد ۋە توباگو دوللىرى',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'يېڭى تەيۋەن دوللىرى',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'تانزانىيە شىللىڭى',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ئۇكرائىنا خرىۋناسى',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ئۇكرائىنا كاربوۋانېتسى',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'ئۇگاندا شىللىڭى (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ئۇگاندا شىللىڭى',
        ],
        'USD' => [
            0 => '$',
            1 => 'ئامېرىكا دوللىرى',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'ئامېرىكا دوللىرى (كېيىنكى كۈن)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'ئامېرىكا دوللىرى (ئوخشاش كۈن)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'ئۇرۇگۋاي پېسوسى (ئىندېكىسلاش بىرلىكى)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'ئۇرۇگۋاي پېسوسى (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'ئۇرۇگۋاي پېسوسى',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'ئۆزبېكىستان سومى',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'ۋېنېزۇئېلا بولىۋارى (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'ۋېنېزۇئېلا بولىۋارى (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'ۋېنېزۇئېلا بولىۋارى',
        ],
        'VND' => [
            0 => '₫',
            1 => 'ۋىيېتنام دوڭى',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'ۋىيېتنام دوڭى (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'ۋانۇئاتۇ ۋاتۇسى',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'ساموئا تالاسى',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'ئافرىقا قىتئەسى پۇل-مۇئامىلە ئىتتىپاقى فرانكى',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'شەرقىي كارىب دوللىرى',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'ياۋروپا پۇل بىرلىكى',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'فىرانسىيە ئالتۇن فرانكى',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'فىرانسىيە UIC فرانكى',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'ئافرىقا قىتئەسى پۇل-مۇئامىلە ئىتتىپاقى فرانكى (BCEAO)',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'تىنچ ئوكيان پۇل-مۇئامىلە ئورتاق گەۋدىسى فرانكى',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET فوندى',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'يەمەن دىنارى',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'يەمەن رىيالى',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'يۇگوسلاۋىيە قاتتىق دىنارى (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'يۇگوسلاۋىيە يېڭى دىنارى (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'يۇگوسلاۋىيە ئالماشتۇرۇشچان دىنارى (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'يۇگوسلاۋىيە ئىسلاھات دىنارى (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'جەنۇبىي ئافرىقا راندى (پۇل–مۇئامىلە)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'جەنۇبىي ئافرىقا راندى',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'زامبىيە كۋاچاسى (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'زامبىيە كۋاچاسى',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'زايىر يېڭى زايىرى (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'زايىر زايىرى (1971–1993)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'زىمبابۋې دوللىرى (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'زىمبابۋې دوللىرى (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'زىمبابۋې دوللىرى (2008)',
        ],
    ],
];
