<?php

return [
    'Names' => [
        'Africa/Abidjan' => '格林威治標準時間（阿比贊）',
        'Africa/Asmera' => '東非時間（阿斯馬拉）',
        'Africa/Bangui' => '西非時間（班基）',
        'Africa/Conakry' => '格林威治標準時間（科納克里）',
        'Africa/Dar_es_Salaam' => '東非時間（達累斯薩拉姆）',
        'Africa/Djibouti' => '東非時間（吉布提）',
        'Africa/Johannesburg' => '南非時間（約翰內斯堡）',
        'Africa/Kinshasa' => '西非時間（金沙薩）',
        'Africa/Lagos' => '西非時間（拉各斯）',
        'Africa/Libreville' => '西非時間（利布維）',
        'Africa/Luanda' => '西非時間（盧安達）',
        'Africa/Lusaka' => '中非時間（盧薩卡）',
        'Africa/Maseru' => '南非時間（馬塞魯）',
        'Africa/Mbabane' => '南非時間（墨巴本）',
        'Africa/Mogadishu' => '東非時間（摩加迪沙）',
        'Africa/Nairobi' => '東非時間（內羅畢）',
        'Africa/Nouakchott' => '格林威治標準時間（努瓦克肖特）',
        'Africa/Windhoek' => '中非時間（溫特和克）',
        'America/Adak' => '夏威夷-阿留申時間（埃達克）',
        'America/Anchorage' => '阿拉斯加時間（安克雷奇）',
        'America/Anguilla' => '大西洋時間（安圭拉）',
        'America/Antigua' => '大西洋時間（安提瓜）',
        'America/Araguaina' => '巴西利亞時間（阿拉瓜伊納）',
        'America/Argentina/La_Rioja' => '阿根廷時間（拉里奧哈）',
        'America/Aruba' => '大西洋時間（阿魯巴）',
        'America/Asuncion' => '巴拉圭時間（阿松森）',
        'America/Bahia' => '巴西利亞時間（巴希雅）',
        'America/Bahia_Banderas' => '北美中部時間（巴伊亞德班德拉斯）',
        'America/Barbados' => '大西洋時間（巴巴多斯）',
        'America/Belize' => '北美中部時間（伯利茲）',
        'America/Boa_Vista' => '亞馬遜時間（博阿維斯塔）',
        'America/Boise' => '北美山區時間（博伊西）',
        'America/Cambridge_Bay' => '北美山區時間（劍橋灣）',
        'America/Campo_Grande' => '亞馬遜時間（大坎普）',
        'America/Cancun' => '北美東部時間（坎昆）',
        'America/Caracas' => '委內瑞拉時間（加拉加斯）',
        'America/Cayenne' => '法屬圭亞那時間（卡宴）',
        'America/Cayman' => '北美東部時間（開曼群島）',
        'America/Chicago' => '北美中部時間（芝加哥）',
        'America/Chihuahua' => '墨西哥太平洋時間（芝娃娃）',
        'America/Coral_Harbour' => '北美東部時間（阿蒂科肯）',
        'America/Cordoba' => '阿根廷時間（科爾多瓦）',
        'America/Costa_Rica' => '北美中部時間（哥斯達黎加）',
        'America/Creston' => '北美山區時間（克雷斯頓）',
        'America/Cuiaba' => '亞馬遜時間（庫亞巴）',
        'America/Dawson_Creek' => '北美山區時間（道森灣）',
        'America/Denver' => '北美山區時間（丹佛）',
        'America/Detroit' => '北美東部時間（底特律）',
        'America/Edmonton' => '北美山區時間（愛民頓）',
        'America/El_Salvador' => '北美中部時間（薩爾瓦多）',
        'America/Fort_Nelson' => '北美山區時間（納爾遜堡）',
        'America/Fortaleza' => '巴西利亞時間（福塔萊薩）',
        'America/Glace_Bay' => '大西洋時間（格萊斯灣）',
        'America/Grand_Turk' => '北美東部時間（大特克島）',
        'America/Grenada' => '大西洋時間（格林納達）',
        'America/Guadeloupe' => '大西洋時間（瓜德羅普）',
        'America/Guatemala' => '北美中部時間（危地馬拉）',
        'America/Guayaquil' => '厄瓜多爾時間（瓜亞基爾）',
        'America/Guyana' => '圭亞那時間',
        'America/Halifax' => '大西洋時間（哈利法克斯）',
        'America/Havana' => '古巴時間（夏灣拿）',
        'America/Indiana/Knox' => '北美中部時間（印第安納州諾克斯）',
        'America/Indiana/Marengo' => '北美東部時間（印第安納州馬倫哥）',
        'America/Indiana/Petersburg' => '北美東部時間（印第安納州彼得堡）',
        'America/Indiana/Tell_City' => '北美中部時間（印第安納州特爾城）',
        'America/Indiana/Vevay' => '北美東部時間（印第安納州韋韋）',
        'America/Indiana/Vincennes' => '北美東部時間（印第安納州溫森斯）',
        'America/Indiana/Winamac' => '北美東部時間（印第安納州威納馬克）',
        'America/Indianapolis' => '北美東部時間（印第安納波利斯）',
        'America/Inuvik' => '北美山區時間（伊努維克）',
        'America/Iqaluit' => '北美東部時間（伊魁特）',
        'America/Jamaica' => '北美東部時間（牙買加）',
        'America/Kentucky/Monticello' => '北美東部時間（肯塔基州蒙地卻羅）',
        'America/Los_Angeles' => '北美太平洋時間（洛杉磯）',
        'America/Louisville' => '北美東部時間（路易維爾）',
        'America/Maceio' => '巴西利亞時間（馬塞約）',
        'America/Managua' => '北美中部時間（馬那瓜）',
        'America/Martinique' => '大西洋時間（馬提尼克）',
        'America/Matamoros' => '北美中部時間（馬塔莫羅斯）',
        'America/Menominee' => '北美中部時間（梅諾米尼）',
        'America/Merida' => '北美中部時間（梅里達）',
        'America/Mexico_City' => '北美中部時間（墨西哥城）',
        'America/Miquelon' => '聖皮埃與密克隆群島時間',
        'America/Monterrey' => '北美中部時間（蒙特雷）',
        'America/Montevideo' => '烏拉圭時間（蒙得維的亞）',
        'America/Montserrat' => '大西洋時間（蒙塞拉特島）',
        'America/Nassau' => '北美東部時間（拿騷）',
        'America/New_York' => '北美東部時間（紐約）',
        'America/Nipigon' => '北美東部時間（尼皮貢）',
        'America/Noronha' => '費爾南多迪諾羅尼亞時間',
        'America/North_Dakota/Beulah' => '北美中部時間（北達科他州比尤拉）',
        'America/North_Dakota/Center' => '北美中部時間（北達科他州中心市）',
        'America/North_Dakota/New_Salem' => '北美中部時間（北達科他州新薩勒姆）',
        'America/Ojinaga' => '北美山區時間（奧希納加）',
        'America/Panama' => '北美東部時間（巴拿馬）',
        'America/Pangnirtung' => '北美東部時間（潘尼爾東）',
        'America/Paramaribo' => '蘇里南時間（巴拉馬利波）',
        'America/Phoenix' => '北美山區時間（鳳凰城）',
        'America/Port-au-Prince' => '北美東部時間（太子港）',
        'America/Porto_Velho' => '亞馬遜時間（韋柳港）',
        'America/Rainy_River' => '北美中部時間（雨河鎮）',
        'America/Rankin_Inlet' => '北美中部時間（蘭今灣）',
        'America/Recife' => '巴西利亞時間（累西腓）',
        'America/Regina' => '北美中部時間（里賈納）',
        'America/Resolute' => '北美中部時間（羅斯魯特）',
        'America/Rio_Branco' => '艾克時間（里約布蘭科）',
        'America/Santiago' => '智利時間（聖地亞哥）',
        'America/Santo_Domingo' => '大西洋時間（聖多明各）',
        'America/St_Barthelemy' => '大西洋時間（聖巴泰勒米）',
        'America/St_Johns' => '紐芬蘭時間（聖約翰斯）',
        'America/St_Lucia' => '大西洋時間（聖盧西亞）',
        'America/St_Vincent' => '大西洋時間（聖文森特）',
        'America/Swift_Current' => '北美中部時間（斯威夫特卡倫特）',
        'America/Tegucigalpa' => '北美中部時間（特古西加爾巴）',
        'America/Thule' => '大西洋時間（圖勒）',
        'America/Thunder_Bay' => '北美東部時間（雷灣）',
        'America/Tijuana' => '北美太平洋時間（蒂華納）',
        'America/Toronto' => '北美東部時間（多倫多）',
        'America/Vancouver' => '北美太平洋時間（溫哥華）',
        'America/Whitehorse' => '育空地區時間（白馬市）',
        'America/Winnipeg' => '北美中部時間（溫尼伯）',
        'America/Yakutat' => '阿拉斯加時間（亞庫塔特）',
        'America/Yellowknife' => '北美山區時間（黃刀鎮）',
        'Antarctica/Davis' => '戴維斯時間（戴維斯站）',
        'Antarctica/DumontDUrville' => '迪蒙迪維爾時間（杜蒙迪維爾站）',
        'Antarctica/Macquarie' => '澳洲東部時間（麥夸里）',
        'Antarctica/Mawson' => '莫森時間（莫森站）',
        'Antarctica/McMurdo' => '紐西蘭時間（麥克默多站）',
        'Antarctica/Palmer' => '智利時間（帕爾默）',
        'Antarctica/Rothera' => '羅瑟拉時間（羅瑟拉站）',
        'Antarctica/Syowa' => '昭和基地時間（昭和站）',
        'Antarctica/Troll' => '格林威治標準時間（特羅爾站）',
        'Arctic/Longyearbyen' => '中歐時間（朗伊爾城）',
        'Asia/Anadyr' => '阿納德爾時間',
        'Asia/Ashgabat' => '土庫曼時間（阿什哈巴德）',
        'Asia/Baku' => '亞塞拜疆時間（巴庫）',
        'Asia/Bishkek' => '吉爾吉斯時間（比斯凱克）',
        'Asia/Calcutta' => '印度時間（加爾各答）',
        'Asia/Chita' => '雅庫茨克時間（赤塔）',
        'Asia/Colombo' => '印度時間（科倫坡）',
        'Asia/Dubai' => '波斯灣海域時間（杜拜）',
        'Asia/Dushanbe' => '塔吉克時間（杜尚別）',
        'Asia/Gaza' => '東歐時間（加沙）',
        'Asia/Hebron' => '東歐時間（希伯侖）',
        'Asia/Irkutsk' => '伊爾庫茨克時間',
        'Asia/Jayapura' => '印尼東部時間（查雅普拉）',
        'Asia/Karachi' => '巴基斯坦時間（卡拉奇）',
        'Asia/Khandyga' => '雅庫茨克時間（堪地加）',
        'Asia/Makassar' => '印尼中部時間（錫江）',
        'Asia/Muscat' => '波斯灣海域時間（馬斯喀特）',
        'Asia/Nicosia' => '東歐時間（尼科西亞）',
        'Asia/Qatar' => '阿拉伯時間（卡塔爾）',
        'Asia/Riyadh' => '阿拉伯時間（利雅得）',
        'Asia/Singapore' => '新加坡時間',
        'Asia/Tbilisi' => '格魯吉亞時間（第比利斯）',
        'Asia/Yakutsk' => '雅庫茨克時間',
        'Asia/Yekaterinburg' => '葉卡捷琳堡時間',
        'Asia/Yerevan' => '亞美尼亞時間（埃里温）',
        'Atlantic/Canary' => '西歐時間（加那利）',
        'Atlantic/Cape_Verde' => '佛得角時間',
        'Atlantic/Madeira' => '西歐時間（馬德拉島）',
        'Atlantic/Reykjavik' => '格林威治標準時間（雷克雅未克）',
        'Atlantic/Stanley' => '福克蘭群島時間（史丹利）',
        'Australia/Adelaide' => '澳洲中部時間（阿德萊德）',
        'Australia/Brisbane' => '澳洲東部時間（布里斯本）',
        'Australia/Currie' => '澳洲東部時間（卡里）',
        'Australia/Hobart' => '澳洲東部時間（荷伯特）',
        'Australia/Perth' => '澳洲西部時間（珀斯）',
        'Australia/Sydney' => '澳洲東部時間（悉尼）',
        'CST6CDT' => '北美中部時間',
        'EST5EDT' => '北美東部時間',
        'Europe/Belgrade' => '中歐時間（貝爾格萊德）',
        'Europe/Bratislava' => '中歐時間（伯拉第斯拉瓦）',
        'Europe/Chisinau' => '東歐時間（基希訥烏）',
        'Europe/Guernsey' => '格林威治標準時間（根西島）',
        'Europe/Isle_of_Man' => '格林威治標準時間（馬恩島）',
        'Europe/Ljubljana' => '中歐時間（盧布爾雅那）',
        'Europe/Malta' => '中歐時間（馬耳他）',
        'Europe/Podgorica' => '中歐時間（波德戈里察）',
        'Europe/Sarajevo' => '中歐時間（薩拉熱窩）',
        'Europe/Skopje' => '中歐時間（斯科普里）',
        'Europe/Uzhgorod' => '東歐時間（烏日哥羅德）',
        'Europe/Vaduz' => '中歐時間（華杜茲）',
        'Europe/Zagreb' => '中歐時間（薩格勒布）',
        'Indian/Antananarivo' => '東非時間（安塔那那利佛）',
        'Indian/Chagos' => '印度洋時間（查戈斯群島）',
        'Indian/Cocos' => '可可斯群島時間',
        'Indian/Comoro' => '東非時間（科摩羅）',
        'Indian/Kerguelen' => '法國南方及南極時間（凱爾蓋朗群島）',
        'Indian/Mahe' => '塞舌爾時間（馬埃島）',
        'Indian/Maldives' => '馬爾代夫時間',
        'Indian/Mauritius' => '毛里裘斯時間',
        'Indian/Mayotte' => '東非時間（馬約特）',
        'Indian/Reunion' => '留尼旺時間',
        'MST7MDT' => '北美山區時間',
        'PST8PDT' => '北美太平洋時間',
        'Pacific/Bougainville' => '巴布亞新畿內亞時間（布干維爾島）',
        'Pacific/Chatham' => '查坦群島時間（查塔姆）',
        'Pacific/Efate' => '瓦努阿圖時間（埃法特）',
        'Pacific/Enderbury' => '鳳凰群島時間（恩德伯里島）',
        'Pacific/Fakaofo' => '托克勞群島時間（法考福環礁）',
        'Pacific/Funafuti' => '圖瓦盧時間（富那富提）',
        'Pacific/Galapagos' => '加拉帕戈群島時間（加拉巴哥群島）',
        'Pacific/Guadalcanal' => '所羅門群島時間（瓜達爾卡納爾島）',
        'Pacific/Johnston' => '夏威夷-阿留申時間（約翰斯頓環礁）',
        'Pacific/Kosrae' => '科斯雷時間',
        'Pacific/Kwajalein' => '馬紹爾群島時間（瓜加林環礁）',
        'Pacific/Majuro' => '馬紹爾群島時間（馬久羅）',
        'Pacific/Marquesas' => '馬克薩斯時間（馬克薩斯群島）',
        'Pacific/Nauru' => '瑙魯時間',
        'Pacific/Noumea' => '新喀里多尼亞時間（努美阿）',
        'Pacific/Pago_Pago' => '薩摩亞時間（帕果帕果）',
        'Pacific/Pitcairn' => '皮特康時間（皮特康群島）',
        'Pacific/Port_Moresby' => '巴布亞新畿內亞時間（莫士比港）',
        'Pacific/Tongatapu' => '湯加時間（湯加塔布島）',
    ],
    'Meta' => [
    ],
];
