<?php

return [
    'Names' => [
        'aa' => 'ئافارچە',
        'ab' => 'ئابخازچە',
        'ace' => 'ئاتجېچە',
        'ach' => 'ئاچولىچە',
        'ada' => 'ئاداڭمېچە',
        'ady' => 'ئادىگېيچە',
        'ae' => 'ئاۋېستاچە',
        'af' => 'ئافرىكانچە',
        'afh' => 'ئافرىخىلىچە',
        'agq' => 'ئاگەمچە',
        'ain' => 'ئاينۇچە',
        'ak' => 'ئاكانچە',
        'akk' => 'ئاككادچە',
        'ale' => 'ئالېيۇتچە',
        'alt' => 'جەنۇبى ئالتاي تىللىرى',
        'am' => 'ئامھارچە',
        'an' => 'ئاراگونچە',
        'ang' => 'قەدىمكى ئىنگلىزچە',
        'anp' => 'ئانگىكاچە',
        'ar' => 'ئەرەبچە',
        'arc' => 'ئارامۇچە',
        'arn' => 'ماپۇدۇنگۇنچە',
        'arp' => 'ئاراپاخوچە',
        'arw' => 'ئاراۋاكچە',
        'as' => 'ئاسامچە',
        'asa' => 'ئاسۇچە',
        'ast' => 'ئاستۇرىيەچە',
        'av' => 'ئاۋارچە',
        'awa' => 'ئاۋادىچە',
        'ay' => 'ئايماراچە',
        'az' => 'ئەزەربەيجانچە',
        'ba' => 'باشقىرتچە',
        'bal' => 'بېلۇجىچە',
        'ban' => 'بالىچە',
        'bas' => 'باساچە',
        'bax' => 'بامۇنچە',
        'bbj' => 'گومالاچە',
        'be' => 'بېلارۇسچە',
        'bej' => 'بېجاچە',
        'bem' => 'بېمباچە',
        'bez' => 'بېناچە',
        'bfd' => 'بافۇتچە',
        'bg' => 'بۇلغارچە',
        'bho' => 'بوجپۇرىچە',
        'bi' => 'بىسلاماچە',
        'bik' => 'بىكولچە',
        'bin' => 'بىنىچە',
        'bkm' => 'كومچە',
        'bla' => 'سىكسىكاچە',
        'bm' => 'بامباراچە',
        'bn' => 'بېنگالچە',
        'bo' => 'تىبەتچە',
        'br' => 'بىرېتونچە',
        'bra' => 'بىراجچە',
        'brx' => 'بودوچە',
        'bs' => 'بوسىنچە',
        'bss' => 'ئاكۇسچە',
        'bua' => 'بۇرىياتچە',
        'bug' => 'بۇگىچە',
        'bum' => 'بۇلۇچە',
        'byn' => 'بىلىنچە',
        'byv' => 'مېدۇمباچە',
        'ca' => 'كاتالانچە',
        'cad' => 'كاددوچە',
        'car' => 'كارىبچە',
        'cay' => 'كايۇگاچە',
        'cch' => 'ئاتسامچە',
        'ce' => 'چېچىنچە',
        'ceb' => 'سېبۇچە',
        'cgg' => 'چىگاچە',
        'ch' => 'چامورروچە',
        'chb' => 'چىبچاچە',
        'chg' => 'چاغاتايچە',
        'chk' => 'چۇكچە',
        'chm' => 'مارىچە',
        'chn' => 'چىنۇك-ژارگونچە',
        'cho' => 'چوكتاۋچە',
        'chp' => 'چىپېۋيانچە',
        'chr' => 'چېروكىچە',
        'chy' => 'چېيېنچە',
        'ckb' => 'مەركىزىي كۇردچە',
        'co' => 'كورسۇچە',
        'cop' => 'كوپتىكچە',
        'cr' => 'كرىچە',
        'crh' => 'قىرىم تۈركچە',
        'cs' => 'چېخچە',
        'csb' => 'كاسزۇبىچە',
        'cu' => 'قەدىمكى سلاۋيانچە',
        'cv' => 'چۇۋاشچە',
        'cy' => 'ۋېلشچە',
        'da' => 'دانىشچە',
        'dak' => 'داكوتاچە',
        'dar' => 'دارگىۋاچە',
        'dav' => 'تايتاچە',
        'de' => 'گېرمانچە',
        'del' => 'دېلاۋارېچە',
        'den' => 'سلاۋچە',
        'dgr' => 'دوگرىبچە',
        'din' => 'دىنكاچە',
        'dje' => 'زارماچە',
        'doi' => 'دوگرىچە',
        'dsb' => 'تۆۋەن سوربچە',
        'dua' => 'دۇئالاچە',
        'dum' => 'ئوتتۇرا گوللاندىيەچە',
        'dv' => 'دىۋېخچە',
        'dyo' => 'جولاچە',
        'dyu' => 'دىيۇلاچە',
        'dz' => 'زوڭخاچە',
        'dzg' => 'دازاگاچە',
        'ebu' => 'ئېمبۇچە',
        'ee' => 'ئېۋېچە',
        'efi' => 'ئېفىكچە',
        'egy' => 'قەدىمكى مىسىرچە',
        'eka' => 'ئېكاجۇكچە',
        'el' => 'گىرېكچە',
        'elx' => 'ئېلامىتچە',
        'en' => 'ئىنگلىزچە',
        'enm' => 'ئوتتۇرا ئەسىر ئىنگلىزچە',
        'eo' => 'ئېسپرانتوچە',
        'es' => 'ئىسپانچە',
        'et' => 'ئېستونچە',
        'eu' => 'باسكىچە',
        'ewo' => 'ئېۋوندوچە',
        'fa' => 'پارسچە',
        'fan' => 'فاڭچە',
        'fat' => 'فانتىچە',
        'ff' => 'فۇلاھچە',
        'fi' => 'فىنچە',
        'fil' => 'فىلىپپىنچە',
        'fj' => 'فىجىچە',
        'fo' => 'فائېروچە',
        'fon' => 'فونچە',
        'fr' => 'فىرانسۇزچە',
        'frm' => 'ئوتتۇرا ئەسىر فىرانسۇزچە',
        'fro' => 'قەدىمكى فىرانسۇزچە',
        'frr' => 'شىمالى فىرىزيەچە',
        'frs' => 'شەرقى فىرىزيەچە',
        'fur' => 'فىرىئۇلىچە',
        'fy' => 'غەربىي فىرسچە',
        'ga' => 'ئىرېلاندچە',
        'gaa' => 'گاچە',
        'gay' => 'گايوچە',
        'gba' => 'گىباياچە',
        'gd' => 'شوتلاندىيە گايلچىسى',
        'gez' => 'گىزچە',
        'gil' => 'گىلبېرتچە',
        'gl' => 'گالىچە',
        'gmh' => 'ئوتتۇرا ئەسىر ئېگىزلىك گېرمانچە',
        'gn' => 'گۇئارانىچە',
        'goh' => 'قەدىمكى ئېگىزلىك گېرمانچە',
        'gon' => 'گوندىچە',
        'gor' => 'گورونتالوچە',
        'got' => 'گوتچە',
        'grb' => 'گرېبوچە',
        'grc' => 'قەدىمكى گىرېكچە',
        'gsw' => 'گېرمانچە شىۋىتسارىيە',
        'gu' => 'گۇجاراتچە',
        'guz' => 'گۇسىچە',
        'gv' => 'مانچە',
        'gwi' => 'گىۋىچىنچە',
        'ha' => 'خائۇساچە',
        'hai' => 'ھەيدەچە',
        'haw' => 'ھاۋايچە',
        'he' => 'ئىبرانىيچە',
        'hi' => 'ھىندىچە',
        'hil' => 'خىلىگاينونچە',
        'hit' => 'خىتتىتچە',
        'hmn' => 'مۆڭچە',
        'ho' => 'ھىرى موتۇچە',
        'hr' => 'كىرودىچە',
        'hsb' => 'ئۈستۈن سوربچە',
        'ht' => 'ھايتىچە',
        'hu' => 'ۋېنگىرچە',
        'hup' => 'خۇپاچە',
        'hy' => 'ئەرمېنچە',
        'hz' => 'خېرېروچە',
        'ia' => 'ئارىلىق تىل',
        'iba' => 'ئىبانچە',
        'ibb' => 'ئىبىبىئوچە',
        'id' => 'ھىندونېزچە',
        'ie' => 'ئىنتىرلىڭچە',
        'ig' => 'ئىگبوچە',
        'ii' => 'يىچە (سىچۈەن)',
        'ik' => 'ئىنۇپىكچە',
        'ilo' => 'ئىلوكانوچە',
        'inh' => 'ئىنگۇشچە',
        'io' => 'ئىدوچە',
        'is' => 'ئىسلاندچە',
        'it' => 'ئىتالىيانچە',
        'iu' => 'ئىنۇكتىتۇتچە',
        'ja' => 'ياپونچە',
        'jbo' => 'لوجبانچە',
        'jgo' => 'نگومباچە',
        'jmc' => 'ماچامچە',
        'jpr' => 'ئىبرانى پارسچە',
        'jrb' => 'ئىبرانى ئەرەبچە',
        'jv' => 'ياۋاچە',
        'ka' => 'گىرۇزچە',
        'kaa' => 'قارا-قالپاقچە',
        'kab' => 'كابىلېچە',
        'kac' => 'كاچىنچە',
        'kaj' => 'جۇچە',
        'kam' => 'كامباچە',
        'kaw' => 'كاۋىچە',
        'kbd' => 'كاباردەيچە',
        'kbl' => 'كانېمبۇچە',
        'kcg' => 'تياپچە',
        'kde' => 'ماكوندېچە',
        'kea' => 'كابۇۋېردىيانچە',
        'kfo' => 'كوروچە',
        'kg' => 'كونگوچە',
        'kha' => 'كاسىچە',
        'kho' => 'خوتەنچە',
        'khq' => 'كويرا چىنىچە',
        'ki' => 'كىكۇيۇچە',
        'kj' => 'كىۋانياماچە',
        'kk' => 'قازاقچە',
        'kkj' => 'كاكوچە',
        'kl' => 'گىرېنلاندچە',
        'kln' => 'كالېنجىنچە',
        'km' => 'كىمېرچە',
        'kmb' => 'كىمبۇندۇچە',
        'kn' => 'كانناداچە',
        'ko' => 'كورېيەچە',
        'kok' => 'كونكانچە',
        'kos' => 'كوسرايېچە',
        'kpe' => 'كىپەللېچە',
        'kr' => 'كانۇرچە',
        'krc' => 'قاراچاي-بالقارچە',
        'krl' => 'كارەلچە',
        'kru' => 'كۇرۇخچە',
        'ks' => 'كەشمىرچە',
        'ksb' => 'شامبالاچە',
        'ksf' => 'بافىياچە',
        'ksh' => 'كولىشچە',
        'ku' => 'كۇردچە',
        'kum' => 'قۇمۇقچە',
        'kut' => 'كۇتەنايچە',
        'kv' => 'كومىچە',
        'kw' => 'كورنىشچە',
        'ky' => 'قىرغىزچە',
        'la' => 'لاتىنچە',
        'lad' => 'لادىنوچە',
        'lag' => 'لانگىچە',
        'lah' => 'لانداچە',
        'lam' => 'لامباچە',
        'lb' => 'لىيۇكسېمبۇرگچە',
        'lez' => 'لېزگىنچە',
        'lg' => 'گانداچە',
        'li' => 'لىمبۇرگچە',
        'ln' => 'لىنگالاچە',
        'lo' => 'لائوسچە',
        'lol' => 'مونگوچە',
        'loz' => 'لوزىچە',
        'lt' => 'لىتۋانىچە',
        'lu' => 'لۇبا-كاتانگاچە',
        'lua' => 'لۇبا-لۇئاچە',
        'lui' => 'لۇيسېنگوچە',
        'lun' => 'لۇنداچە',
        'luo' => 'لۇئوچە',
        'lus' => 'مىزوچە',
        'luy' => 'لۇياچە',
        'lv' => 'لاتچە',
        'mad' => 'مادۇرېسچە',
        'maf' => 'مافاچە',
        'mag' => 'ماگاخىچە',
        'mai' => 'مايتىلىچە',
        'mak' => 'ماكاسارچە',
        'man' => 'ماندىنگوچە',
        'mas' => 'ماسايچە',
        'mde' => 'ماباچە',
        'mdf' => 'موكشاچە',
        'mdr' => 'ماندارچە',
        'men' => 'مېندېچە',
        'mer' => 'مېرۇچە',
        'mfe' => 'مورىسيېنچە',
        'mg' => 'مالاگاسچە',
        'mga' => 'ئوتتۇرا ئەسىر ئىرېلاندچە',
        'mgh' => 'ماكۇۋاچە',
        'mgo' => 'مېتاچە’',
        'mh' => 'مارشالچە',
        'mi' => 'ماۋرىچە',
        'mic' => 'مىكماكچە',
        'min' => 'مىناڭكابائۇچە',
        'mk' => 'ماكېدونچە',
        'ml' => 'مالايالامچە',
        'mn' => 'موڭغۇلچە',
        'mnc' => 'مانجۇچە',
        'mni' => 'مانىپۇرچە',
        'moh' => 'موخاۋكچە',
        'mos' => 'موسسىچە',
        'mr' => 'ماراتىچە',
        'ms' => 'مالايچە',
        'mt' => 'مالتاچە',
        'mua' => 'مۇنداڭچە',
        'mus' => 'كىرىكچە',
        'mwl' => 'مىراندېسچە',
        'mwr' => 'مارۋارىچە',
        'my' => 'بىرماچە',
        'mye' => 'ميېنېچە',
        'myv' => 'ئېرزاچە',
        'na' => 'ناۋرۇچە',
        'nap' => 'ناپولىچە',
        'naq' => 'ناماچە',
        'nb' => 'نورۋىگىيە بوكمالچە',
        'nd' => 'شىمالى ندەبەلەچە',
        'nds' => 'تۆۋەن گېرمانچە',
        'ne' => 'نېپالچە',
        'new' => 'نېۋارىچە',
        'ng' => 'ندونگاچە',
        'nia' => 'نىئاسچە',
        'niu' => 'نيۇئېچە',
        'nl' => 'گوللاندچە',
        'nmg' => 'كۋاسىيوچە',
        'nn' => 'يېڭى نورۋېگچە',
        'nnh' => 'نگېمبۇنچە',
        'no' => 'نورۋېگچە',
        'nog' => 'نوغايچە',
        'non' => 'قەدىمكى نورۋېگچە',
        'nqo' => 'نىكوچە',
        'nr' => 'جەنۇبى ندەبەلەچە',
        'nso' => 'شىمالىي سوتوچە',
        'nus' => 'مۇئېرچە',
        'nv' => 'ناۋاخوچە',
        'nwc' => 'نېۋارچە',
        'ny' => 'نىيانجاچە',
        'nym' => 'نيامۋېزىچە',
        'nyn' => 'نىيانكولېچە',
        'nyo' => 'نىئوروچە',
        'nzi' => 'نىزەماچە',
        'oc' => 'ئوكسىتچە',
        'oj' => 'ئوجىبۋاچە',
        'om' => 'ئوروموچە',
        'or' => 'ئودىياچە',
        'os' => 'ئوسسېتچەچە',
        'osa' => 'ئوساگېلارچە',
        'ota' => 'ئوسمان تۈركچە',
        'pa' => 'پەنجابچە',
        'pag' => 'پانگاسىنانچە',
        'pal' => 'پەھلەۋىچە',
        'pam' => 'پامپانگاچە',
        'pap' => 'پاپىيامېنتوچە',
        'pau' => 'پالاۋچە',
        'peo' => 'قەدىمكى پارىسچە',
        'phn' => 'فىنىكىيەچە',
        'pi' => 'پالىچە',
        'pl' => 'پولەكچە',
        'pon' => 'پوناپېئانچە',
        'pro' => 'قەدىمكى پروۋېنچالچە',
        'ps' => 'پۇشتۇچە',
        'pt' => 'پورتۇگالچە',
        'qu' => 'كېچىۋاچە',
        'raj' => 'راجاستانچە',
        'rap' => 'راپانىيچە',
        'rm' => 'رومانسچە',
        'rn' => 'رۇندىچە',
        'ro' => 'رومىنچە',
        'rof' => 'رومبوچە',
        'rom' => 'سىگانچە',
        'ru' => 'رۇسچە',
        'rup' => 'ئارومانچە',
        'rw' => 'كېنىيەرىۋانداچە',
        'rwk' => 'رىۋاچە',
        'sa' => 'سانسكرىتچە',
        'sad' => 'سانداۋېچە',
        'sah' => 'ساخاچە',
        'sam' => 'سامارىتانچە',
        'saq' => 'سامبۇرۇچە',
        'sas' => 'ساساكچە',
        'sat' => 'سانتالچە',
        'sba' => 'نگامبايچە',
        'sbp' => 'سانگۇچە',
        'sc' => 'ساردىنىيەچە',
        'scn' => 'سىتسىلىيەچە',
        'sco' => 'شوتلاندىيەچە',
        'sd' => 'سىندىچە',
        'se' => 'شىمالىي سامىچە',
        'see' => 'سېكنېكاچە',
        'seh' => 'سېناچە',
        'sel' => 'سېلكاپچە',
        'ses' => 'شەرقىي سوڭخايچە',
        'sg' => 'سانگوچە',
        'sga' => 'قەدىمكى ئىرېلاندچە',
        'sh' => 'سېرب-كرودىيەچە',
        'shi' => 'شىلخاچە',
        'shn' => 'شانچە',
        'shu' => 'چاد ئەرەبچە',
        'si' => 'سىنگالچە',
        'sid' => 'سىداموچە',
        'sk' => 'سىلوۋاكچە',
        'sl' => 'سىلوۋېنچە',
        'sm' => 'ساموئاچە',
        'sma' => 'جەنۇبىي سامىچە',
        'smj' => 'لۇلې سامىچە',
        'smn' => 'ئىنارى سامىچە',
        'sms' => 'سكولت سامىچە',
        'sn' => 'شوناچە',
        'snk' => 'سونىنكەچە',
        'so' => 'سومالىچە',
        'sog' => 'سوغدىچە',
        'sq' => 'ئالبانچە',
        'sr' => 'سېربچە',
        'srn' => 'سىرانان-توڭوچە',
        'srr' => 'سېرېرچە',
        'ss' => 'سىۋاتىچە',
        'ssy' => 'ساخوچە',
        'st' => 'سوتوچە',
        'su' => 'سۇنداچە',
        'suk' => 'سۇكۇماچە',
        'sus' => 'سۇسۇچە',
        'sux' => 'سۈمەرچە',
        'sv' => 'شىۋېدچە',
        'sw' => 'سىۋاھىلچە',
        'swb' => 'كومورىچە',
        'syc' => 'قەدىمىي سۇرىيەچە',
        'syr' => 'سۇرىيەچە',
        'ta' => 'تامىلچە',
        'te' => 'تېلۇگۇچە',
        'tem' => 'تېمنېچە',
        'teo' => 'تېسوچە',
        'ter' => 'تېرېناچە',
        'tet' => 'تېتۇمچە',
        'tg' => 'تاجىكچە',
        'th' => 'تايلاندچە',
        'ti' => 'تىگرىنياچە',
        'tig' => 'تىگرېچە',
        'tiv' => 'تىۋچە',
        'tk' => 'تۈركمەنچە',
        'tkl' => 'توكېلاۋچە',
        'tl' => 'تاگالوگچە',
        'tlh' => 'كىلىنگونچە',
        'tli' => 'تىلىنگىتچە',
        'tmh' => 'تاماشېكچە',
        'tn' => 'سىۋاناچە',
        'to' => 'تونگانچە',
        'tog' => 'نياسا توڭانچە',
        'tpi' => 'توك-پىسىنچە',
        'tr' => 'تۈركچە',
        'trv' => 'توروكوچە',
        'ts' => 'سونگاچە',
        'tsi' => 'سىمشيانچە',
        'tt' => 'تاتارچە',
        'tum' => 'تۇمبۇكاچە',
        'tvl' => 'تۇۋالۇچە',
        'tw' => 'تىۋىچە',
        'twq' => 'شىمالىي سوڭخايچە',
        'ty' => 'تاختىچە',
        'tyv' => 'توۋاچە',
        'tzm' => 'مەركىزىي ئاتلاس تامازايتچە',
        'udm' => 'ئۇدمۇرتچە',
        'ug' => 'ئۇيغۇرچە',
        'uga' => 'ئۇگارىتىكچە',
        'uk' => 'ئۇكرائىنچە',
        'umb' => 'ئۇمبۇندۇچە',
        'ur' => 'ئوردۇچە',
        'uz' => 'ئۆزبېكچە',
        'vai' => 'ۋايچە',
        've' => 'ۋېنداچە',
        'vi' => 'ۋىيېتنامچە',
        'vo' => 'ۋولاپۇكچە',
        'vot' => 'ۋوتېچە',
        'vun' => 'ۋۇنجوچە',
        'wa' => 'ۋاللۇنچە',
        'wae' => 'ۋالسېرچە',
        'wal' => 'ۋولايتاچە',
        'war' => 'ۋارايچە',
        'was' => 'ۋاشوچە',
        'wo' => 'ۋولوفچە',
        'xal' => 'قالماقچە',
        'xh' => 'خوساچە',
        'xog' => 'سوگاچە',
        'yao' => 'ياۋچە',
        'yap' => 'ياپچە',
        'yav' => 'ياڭبەنچە',
        'ybb' => 'يېمباچە',
        'yi' => 'يىددىشچە',
        'yo' => 'يورۇباچە',
        'yue' => 'گۇاڭدوڭچە',
        'za' => 'جۇاڭچە',
        'zap' => 'زاپوتېكچە',
        'zbl' => 'بىلىس بەلگىلىرى',
        'zen' => 'زېناگاچە',
        'zgh' => 'ئۆلچەملىك ماراكەش تامازىتچە',
        'zh' => 'خەنزۇچە',
        'zu' => 'زۇلۇچە',
        'zun' => 'زۇنىچە',
        'zza' => 'زازاچە',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ھازىرقى زامان ئۆلچەملىك ئەرەبچە',
        'de_AT' => 'ئاۋستىرىيە گېرمانچە',
        'de_CH' => 'شىۋىتسارىيە ئېگىزلىك گېرمانچە',
        'en_AU' => 'ئاۋسترالىيە ئىنگلىزچە',
        'en_CA' => 'كانادا ئىنگلىزچە',
        'en_GB' => 'ئەنگلىيە ئىنگلىزچە',
        'en_US' => 'ئامېرىكا ئىنگلىزچە',
        'es_419' => 'لاتىن ئامېرىكا ئىسپانچە',
        'es_ES' => 'ياۋروپا ئىسپانچە',
        'es_MX' => 'مېكسىكا ئىسپانچە',
        'fr_CA' => 'كانادا فىرانسۇزچە',
        'fr_CH' => 'شىۋىتسارىيە فىرانسۇزچە',
        'pt_BR' => 'بىرازىلىيە پورتۇگالچە',
        'pt_PT' => 'ياۋروپا پورتۇگالچە',
        'sw_CD' => 'كونگو سىۋالىچە',
        'zh_Hans' => 'ئاددىي خەنچە',
        'zh_Hant' => 'مۇرەككەپ خەنچە',
    ],
];
