<?php

return [
    'Names' => [
        'arn' => 'mapudungun',
        'be' => 'bjeloruski',
        'bm' => 'bamanankan',
        'bn' => 'bangla',
        'ff' => 'fulah',
        'ht' => 'haićanski kreolski',
        'lo' => 'laoški',
        'moh' => 'mohok',
        'nqo' => 'n’ko',
        'shi' => 'južni šilha',
        'tzm' => 'centralnoatlaski tamašek',
        'xh' => 'isikosa',
        'zgh' => 'standardni marokanski tamašek',
        'zu' => 'isizulu',
    ],
    'LocalizedNames' => [
    ],
];
