<?php

return [
    'Names' => [
        'GMD' => [
            0 => 'D',
            1 => '𞤁𞤢𞤤𞤢𞤧𞤭 𞤘𞤢𞤥𞤦𞤭𞤲𞤳𞤮',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => '𞤊𞤢𞤪𞤢𞤲 𞤘𞤭𞤲𞤫𞤲𞤳𞤮',
        ],
    ],
];
