<?php

return [
    'Names' => [
        'Arab' => 'арап',
        'Cyrl' => 'кириллица',
        'Hans' => 'ҫӑмӑллатнӑн китай',
        'Hant' => 'традициллӗн китай',
        'Jpan' => 'япони',
        'Kore' => 'корей',
        'Latn' => 'латин',
        'Zxxx' => 'ҫырусӑр',
    ],
];
