<?php

return [
    'Names' => [
        'aa' => 'afarščina',
        'ab' => 'abhaščina',
        'ace' => 'ačejščina',
        'ach' => 'ačolijščina',
        'ada' => 'adangmejščina',
        'ady' => 'adigejščina',
        'ae' => 'avestijščina',
        'af' => 'afrikanščina',
        'afh' => 'afrihili',
        'agq' => 'aghemščina',
        'ain' => 'ainujščina',
        'ak' => 'akanščina',
        'akk' => 'akadščina',
        'ale' => 'aleutščina',
        'alt' => 'južna altajščina',
        'am' => 'amharščina',
        'an' => 'aragonščina',
        'ang' => 'stara angleščina',
        'ann' => 'obolo',
        'anp' => 'angikaščina',
        'ar' => 'arabščina',
        'arc' => 'aramejščina',
        'arn' => 'mapudungunščina',
        'arp' => 'arapaščina',
        'ars' => 'nadždska arabščina',
        'arw' => 'aravaščina',
        'as' => 'asamščina',
        'asa' => 'asujščina',
        'ast' => 'asturijščina',
        'atj' => 'atikamekwščina',
        'av' => 'avarščina',
        'awa' => 'avadščina',
        'ay' => 'ajmarščina',
        'az' => 'azerbajdžanščina',
        'ba' => 'baškirščina',
        'bal' => 'beludžijščina',
        'ban' => 'balijščina',
        'bas' => 'basa',
        'be' => 'beloruščina',
        'bej' => 'bedža',
        'bem' => 'bemba',
        'bez' => 'benajščina',
        'bg' => 'bolgarščina',
        'bgn' => 'zahodnobalučijščina',
        'bho' => 'bodžpuri',
        'bi' => 'bislamščina',
        'bik' => 'bikolski jezik',
        'bin' => 'edo',
        'bla' => 'siksika',
        'bm' => 'bambarščina',
        'bn' => 'bengalščina',
        'bo' => 'tibetanščina',
        'br' => 'bretonščina',
        'bra' => 'bradžbakanščina',
        'brx' => 'bodojščina',
        'bs' => 'bosanščina',
        'bua' => 'burjatščina',
        'bug' => 'buginščina',
        'byn' => 'blinščina',
        'ca' => 'katalonščina',
        'cad' => 'kadoščina',
        'car' => 'karibski jezik',
        'cay' => 'kajuščina',
        'ccp' => 'chakma',
        'ce' => 'čečenščina',
        'ceb' => 'sebuanščina',
        'cgg' => 'čigajščina',
        'ch' => 'čamorščina',
        'chb' => 'čibčevščina',
        'chg' => 'čagatajščina',
        'chk' => 'trukeščina',
        'chm' => 'marijščina',
        'chn' => 'činuški žargon',
        'cho' => 'čoktavščina',
        'chp' => 'čipevščina',
        'chr' => 'čerokeščina',
        'chy' => 'čejenščina',
        'ckb' => 'soranska kurdščina',
        'clc' => 'čilkotinščina',
        'co' => 'korziščina',
        'cop' => 'koptščina',
        'cr' => 'krijščina',
        'crg' => 'mičifščina',
        'crh' => 'krimska tatarščina',
        'crj' => 'jugovzhodna krijščina',
        'crk' => 'nižinska krijščina',
        'crl' => 'severovzhodna krijščina',
        'crm' => 'moose-krijščina',
        'crr' => 'karolinska algonkinščina',
        'crs' => 'sejšelska francoska kreolščina',
        'cs' => 'češčina',
        'csb' => 'kašubščina',
        'csw' => 'močvirska krijščina',
        'cu' => 'stara cerkvena slovanščina',
        'cv' => 'čuvaščina',
        'cy' => 'valižanščina',
        'da' => 'danščina',
        'dak' => 'dakotščina',
        'dar' => 'darginščina',
        'dav' => 'taitajščina',
        'de' => 'nemščina',
        'del' => 'delavarščina',
        'den' => 'slavejščina',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarmajščina',
        'doi' => 'dogri',
        'dsb' => 'dolnja lužiška srbščina',
        'dua' => 'duala',
        'dum' => 'srednja nizozemščina',
        'dv' => 'diveščina',
        'dyo' => 'jola-fonjiščina',
        'dyu' => 'diula',
        'dz' => 'dzonka',
        'dzg' => 'dazaga',
        'ebu' => 'embujščina',
        'ee' => 'evenščina',
        'efi' => 'efiščina',
        'egy' => 'stara egipčanščina',
        'eka' => 'ekajuk',
        'el' => 'grščina',
        'elx' => 'elamščina',
        'en' => 'angleščina',
        'enm' => 'srednja angleščina',
        'eo' => 'esperanto',
        'es' => 'španščina',
        'et' => 'estonščina',
        'eu' => 'baskovščina',
        'ewo' => 'evondovščina',
        'fa' => 'perzijščina',
        'fan' => 'fangijščina',
        'fat' => 'fantijščina',
        'ff' => 'fulščina',
        'fi' => 'finščina',
        'fil' => 'filipinščina',
        'fj' => 'fidžijščina',
        'fo' => 'ferščina',
        'fon' => 'fonščina',
        'fr' => 'francoščina',
        'frc' => 'cajunska francoščina',
        'frm' => 'srednja francoščina',
        'fro' => 'stara francoščina',
        'frr' => 'severna frizijščina',
        'frs' => 'vzhodna frizijščina',
        'fur' => 'furlanščina',
        'fy' => 'zahodna frizijščina',
        'ga' => 'irščina',
        'gaa' => 'ga',
        'gag' => 'gagavščina',
        'gay' => 'gajščina',
        'gba' => 'gbajščina',
        'gd' => 'škotska gelščina',
        'gez' => 'etiopščina',
        'gil' => 'kiribatščina',
        'gl' => 'galicijščina',
        'gmh' => 'srednja visoka nemščina',
        'gn' => 'gvaranijščina',
        'goh' => 'stara visoka nemščina',
        'gon' => 'gondi',
        'gor' => 'gorontalščina',
        'got' => 'gotščina',
        'grb' => 'grebščina',
        'grc' => 'stara grščina',
        'gsw' => 'nemščina (Švica)',
        'gu' => 'gudžaratščina',
        'guz' => 'gusijščina',
        'gv' => 'manščina',
        'gwi' => 'gvičin',
        'ha' => 'havščina',
        'hai' => 'haidščina',
        'haw' => 'havajščina',
        'hax' => 'južna haidščina',
        'he' => 'hebrejščina',
        'hi' => 'hindijščina',
        'hil' => 'hiligajnonščina',
        'hit' => 'hetitščina',
        'hmn' => 'hmonščina',
        'ho' => 'hiri motu',
        'hr' => 'hrvaščina',
        'hsb' => 'gornja lužiška srbščina',
        'ht' => 'haitijska kreolščina',
        'hu' => 'madžarščina',
        'hup' => 'hupa',
        'hur' => 'halkomelenščina',
        'hy' => 'armenščina',
        'hz' => 'herero',
        'ia' => 'interlingva',
        'iba' => 'ibanščina',
        'ibb' => 'ibibijščina',
        'id' => 'indonezijščina',
        'ie' => 'interlingve',
        'ig' => 'igboščina',
        'ii' => 'sečuanska jiščina',
        'ik' => 'inupiaščina',
        'ikt' => 'zahodna kanadska inuktituščina',
        'ilo' => 'ilokanščina',
        'inh' => 'inguščina',
        'io' => 'ido',
        'is' => 'islandščina',
        'it' => 'italijanščina',
        'iu' => 'inuktitutščina',
        'ja' => 'japonščina',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'mačamejščina',
        'jpr' => 'judovska perzijščina',
        'jrb' => 'judovska arabščina',
        'jv' => 'javanščina',
        'ka' => 'gruzijščina',
        'kaa' => 'karakalpaščina',
        'kab' => 'kabilščina',
        'kac' => 'kačinščina',
        'kaj' => 'jju',
        'kam' => 'kambaščina',
        'kaw' => 'kavi',
        'kbd' => 'kabardinščina',
        'kcg' => 'tjapska nigerijščina',
        'kde' => 'makondščina',
        'kea' => 'zelenortskootoška kreolščina',
        'kfo' => 'koro',
        'kg' => 'kongovščina',
        'kgp' => 'kaingangščina',
        'kha' => 'kasi',
        'kho' => 'kotanščina',
        'khq' => 'koyra chiini',
        'ki' => 'kikujščina',
        'kj' => 'kvanjama',
        'kk' => 'kazaščina',
        'kkj' => 'kako',
        'kl' => 'grenlandščina',
        'kln' => 'kalenjinščina',
        'km' => 'kmerščina',
        'kmb' => 'kimbundu',
        'kn' => 'kanareščina',
        'ko' => 'korejščina',
        'koi' => 'komi-permjaščina',
        'kok' => 'konkanščina',
        'kos' => 'kosrajščina',
        'kpe' => 'kpelejščina',
        'kr' => 'kanurščina',
        'krc' => 'karačaj-balkarščina',
        'krl' => 'karelščina',
        'kru' => 'kuruk',
        'ks' => 'kašmirščina',
        'ksb' => 'šambala',
        'ksf' => 'bafia',
        'ksh' => 'kölnsko narečje',
        'ku' => 'kurdščina',
        'kum' => 'kumiščina',
        'kut' => 'kutenajščina',
        'kv' => 'komijščina',
        'kw' => 'kornijščina',
        'kwk' => 'kvakvala',
        'ky' => 'kirgiščina',
        'la' => 'latinščina',
        'lad' => 'ladinščina',
        'lag' => 'langijščina',
        'lah' => 'landa',
        'lam' => 'lamba',
        'lb' => 'luksemburščina',
        'lez' => 'lezginščina',
        'lg' => 'ganda',
        'li' => 'limburščina',
        'lil' => 'lilovetščina',
        'lkt' => 'lakotščina',
        'ln' => 'lingala',
        'lo' => 'laoščina',
        'lol' => 'mongo',
        'lou' => 'louisianska kreolščina',
        'loz' => 'lozi',
        'lrc' => 'severna lurijščina',
        'lsm' => 'saamijščina',
        'lt' => 'litovščina',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luisenščina',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizojščina',
        'luy' => 'luhijščina',
        'lv' => 'latvijščina',
        'mad' => 'madurščina',
        'mag' => 'magadščina',
        'mai' => 'maitili',
        'mak' => 'makasarščina',
        'man' => 'mandingo',
        'mas' => 'masajščina',
        'mdf' => 'mokšavščina',
        'mdr' => 'mandarščina',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisjenščina',
        'mg' => 'malgaščina',
        'mga' => 'srednja irščina',
        'mgh' => 'makuva-meto',
        'mgo' => 'meta',
        'mh' => 'marshallovščina',
        'mi' => 'maorščina',
        'mic' => 'mikmaščina',
        'min' => 'minangkabau',
        'mk' => 'makedonščina',
        'ml' => 'malajalamščina',
        'mn' => 'mongolščina',
        'mnc' => 'mandžurščina',
        'mni' => 'manipurščina',
        'moe' => 'inuaimunščina',
        'moh' => 'mohoščina',
        'mos' => 'mosijščina',
        'mr' => 'maratščina',
        'ms' => 'malajščina',
        'mt' => 'malteščina',
        'mua' => 'mundang',
        'mus' => 'creekovščina',
        'mwl' => 'mirandeščina',
        'mwr' => 'marvarščina',
        'my' => 'burmanščina',
        'myv' => 'erzjanščina',
        'mzn' => 'mazanderanščina',
        'na' => 'naurujščina',
        'nan' => 'min nan kitajščina',
        'nap' => 'napolitanščina',
        'naq' => 'khoekhoe',
        'nb' => 'knjižna norveščina',
        'nd' => 'severna ndebelščina',
        'nds' => 'nizka nemščina',
        'ne' => 'nepalščina',
        'new' => 'nevarščina',
        'ng' => 'ndonga',
        'nia' => 'niaščina',
        'niu' => 'niuejščina',
        'nl' => 'nizozemščina',
        'nmg' => 'kwasio',
        'nn' => 'novonorveščina',
        'nnh' => 'ngiemboonščina',
        'no' => 'norveščina',
        'nog' => 'nogajščina',
        'non' => 'stara nordijščina',
        'nqo' => 'n’ko',
        'nr' => 'južna ndebelščina',
        'nso' => 'severna sotščina',
        'nus' => 'nuerščina',
        'nv' => 'navajščina',
        'nwc' => 'klasična nevarščina',
        'ny' => 'njanščina',
        'nym' => 'njamveščina',
        'nyn' => 'njankole',
        'nyo' => 'njoro',
        'nzi' => 'nzima',
        'oc' => 'okcitanščina',
        'oj' => 'anašinabščina',
        'ojb' => 'severozahodna očipvejščina',
        'ojc' => 'osrednja očipvejščina',
        'ojs' => 'oči-krijščina',
        'ojw' => 'zahodna očipvejščina',
        'oka' => 'okanaganščina',
        'om' => 'oromo',
        'or' => 'odijščina',
        'os' => 'osetinščina',
        'osa' => 'osage',
        'ota' => 'otomanska turščina',
        'pa' => 'pandžabščina',
        'pag' => 'pangasinanščina',
        'pam' => 'pampanščina',
        'pap' => 'papiamentu',
        'pau' => 'palavanščina',
        'pcm' => 'nigerijski pidžin',
        'peo' => 'stara perzijščina',
        'phn' => 'feničanščina',
        'pi' => 'palijščina',
        'pis' => 'pidžin',
        'pl' => 'poljščina',
        'pon' => 'ponpejščina',
        'pqm' => 'maliseet-passamaquoddščina',
        'prg' => 'stara pruščina',
        'pro' => 'stara provansalščina',
        'ps' => 'paštunščina',
        'pt' => 'portugalščina',
        'qu' => 'kečuanščina',
        'quc' => 'quiche',
        'raj' => 'radžastanščina',
        'rap' => 'rapanujščina',
        'rar' => 'rarotongščina',
        'rhg' => 'rohinščina',
        'rm' => 'retoromanščina',
        'rn' => 'rundščina',
        'ro' => 'romunščina',
        'rof' => 'rombo',
        'rom' => 'romščina',
        'ru' => 'ruščina',
        'rup' => 'aromunščina',
        'rw' => 'ruandščina',
        'rwk' => 'rwa',
        'sa' => 'sanskrt',
        'sad' => 'sandavščina',
        'sah' => 'jakutščina',
        'sam' => 'samaritanska aramejščina',
        'saq' => 'samburščina',
        'sas' => 'sasaščina',
        'sat' => 'santalščina',
        'sba' => 'ngambajščina',
        'sbp' => 'sangujščina',
        'sc' => 'sardinščina',
        'scn' => 'sicilijanščina',
        'sco' => 'škotščina',
        'sd' => 'sindščina',
        'sdh' => 'južna kurdščina',
        'se' => 'severna samijščina',
        'seh' => 'sena',
        'sel' => 'selkupščina',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'stara irščina',
        'sh' => 'srbohrvaščina',
        'shi' => 'tahelitska berberščina',
        'shn' => 'šanščina',
        'si' => 'sinhalščina',
        'sid' => 'sidamščina',
        'sk' => 'slovaščina',
        'sl' => 'slovenščina',
        'slh' => 'južna lušucidščina',
        'sm' => 'samoanščina',
        'sma' => 'južna samijščina',
        'smj' => 'luleška samijščina',
        'smn' => 'inarska samijščina',
        'sms' => 'skoltska samijščina',
        'sn' => 'šonščina',
        'snk' => 'soninke',
        'so' => 'somalščina',
        'sq' => 'albanščina',
        'sr' => 'srbščina',
        'srn' => 'surinamska kreolščina',
        'srr' => 'sererščina',
        'ss' => 'svazijščina',
        'ssy' => 'saho',
        'st' => 'sesoto',
        'str' => 'ožinska sališčina',
        'su' => 'sundanščina',
        'suk' => 'sukuma',
        'sus' => 'susujščina',
        'sux' => 'sumerščina',
        'sv' => 'švedščina',
        'sw' => 'svahili',
        'swb' => 'šikomor',
        'syc' => 'klasična sirščina',
        'syr' => 'sirščina',
        'ta' => 'tamilščina',
        'tce' => 'južna tučonščina',
        'te' => 'telugijščina',
        'tem' => 'temnejščina',
        'teo' => 'teso',
        'tet' => 'tetumščina',
        'tg' => 'tadžiščina',
        'tgx' => 'tagiščina',
        'th' => 'tajščina',
        'tht' => 'taltanščina',
        'ti' => 'tigrajščina',
        'tig' => 'tigrejščina',
        'tiv' => 'tivščina',
        'tk' => 'turkmenščina',
        'tkl' => 'tokelavščina',
        'tl' => 'tagalogščina',
        'tlh' => 'klingonščina',
        'tli' => 'tlingitščina',
        'tmh' => 'tamajaščina',
        'tn' => 'cvanščina',
        'to' => 'tongščina',
        'tog' => 'malavijska tongščina',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turščina',
        'trv' => 'taroko',
        'ts' => 'congščina',
        'tsi' => 'tsimščina',
        'tt' => 'tatarščina',
        'ttm' => 'severna tučonščina',
        'tum' => 'tumbukščina',
        'tvl' => 'tuvalujščina',
        'tw' => 'tvi',
        'twq' => 'tasawaq',
        'ty' => 'tahitščina',
        'tyv' => 'tuvinščina',
        'tzm' => 'tamašek (Srednji Atlas)',
        'udm' => 'udmurtščina',
        'ug' => 'ujgurščina',
        'uga' => 'ugaritski jezik',
        'uk' => 'ukrajinščina',
        'umb' => 'umbundščina',
        'ur' => 'urdujščina',
        'uz' => 'uzbeščina',
        'vai' => 'vajščina',
        've' => 'venda',
        'vi' => 'vietnamščina',
        'vo' => 'volapik',
        'vot' => 'votjaščina',
        'vun' => 'vunjo',
        'wa' => 'valonščina',
        'wae' => 'walser',
        'wal' => 'valamščina',
        'war' => 'varajščina',
        'was' => 'vašajščina',
        'wbp' => 'varlpirščina',
        'wo' => 'volofščina',
        'wuu' => 'wu-kitajščina',
        'xal' => 'kalmiščina',
        'xh' => 'koščina',
        'xog' => 'sogščina',
        'yao' => 'jaojščina',
        'yap' => 'japščina',
        'yav' => 'jangben',
        'ybb' => 'jembajščina',
        'yi' => 'jidiš',
        'yo' => 'jorubščina',
        'yrl' => 'nheengatu',
        'yue' => 'kantonščina',
        'zap' => 'zapoteščina',
        'zbl' => 'znakovni jezik Bliss',
        'zen' => 'zenaščina',
        'zgh' => 'standardni maroški tamazig',
        'zh' => 'kitajščina',
        'zu' => 'zulujščina',
        'zun' => 'zunijščina',
        'zza' => 'zazajščina',
    ],
    'LocalizedNames' => [
        'ar_001' => 'sodobna standardna arabščina',
        'de_AT' => 'avstrijska nemščina',
        'de_CH' => 'visoka nemščina (Švica)',
        'en_AU' => 'avstralska angleščina',
        'en_CA' => 'kanadska angleščina',
        'en_GB' => 'britanska angleščina',
        'en_US' => 'ameriška angleščina',
        'es_419' => 'latinskoameriška španščina',
        'es_ES' => 'evropska španščina',
        'es_MX' => 'mehiška španščina',
        'fa_AF' => 'darijščina',
        'fr_CA' => 'kanadska francoščina',
        'fr_CH' => 'švicarska francoščina',
        'nds_NL' => 'nizka saščina',
        'nl_BE' => 'flamščina',
        'pt_BR' => 'brazilska portugalščina',
        'pt_PT' => 'evropska portugalščina',
        'ro_MD' => 'moldavščina',
        'sw_CD' => 'kongoški svahili',
        'zh_Hans' => 'poenostavljena kitajščina',
        'zh_Hant' => 'tradicionalna kitajščina',
    ],
];
