<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намибија)',
        'af_ZA' => 'африкаанс (Ҹәнуб Африка)',
        'ak' => 'акан',
        'ak_GH' => 'акан (Гана)',
        'am' => 'амһар',
        'am_ET' => 'амһар (Ефиопија)',
        'ar' => 'әрәб',
        'ar_001' => 'әрәб (Дүнја)',
        'ar_AE' => 'әрәб (Бирләшмиш Әрәб Әмирликләри)',
        'ar_BH' => 'әрәб (Бәһрејн)',
        'ar_DJ' => 'әрәб (Ҹибути)',
        'ar_DZ' => 'әрәб (Әлҹәзаир)',
        'ar_EG' => 'әрәб (Мисир)',
        'ar_EH' => 'әрәб (Qərbi Saxara)',
        'ar_ER' => 'әрәб (Еритреја)',
        'ar_IL' => 'әрәб (Исраил)',
        'ar_IQ' => 'әрәб (Ираг)',
        'ar_JO' => 'әрәб (Иорданија)',
        'ar_KM' => 'әрәб (Комор адалары)',
        'ar_KW' => 'әрәб (Күвејт)',
        'ar_LB' => 'әрәб (Ливан)',
        'ar_LY' => 'әрәб (Ливија)',
        'ar_MA' => 'әрәб (Мәракеш)',
        'ar_MR' => 'әрәб (Мавританија)',
        'ar_OM' => 'әрәб (Оман)',
        'ar_PS' => 'әрәб (Fələstin Əraziləri)',
        'ar_QA' => 'әрәб (Гәтәр)',
        'ar_SA' => 'әрәб (Сәудијјә Әрәбистаны)',
        'ar_SD' => 'әрәб (Судан)',
        'ar_SO' => 'әрәб (Сомали)',
        'ar_SS' => 'әрәб (Ҹәнуби Судан)',
        'ar_SY' => 'әрәб (Сурија)',
        'ar_TD' => 'әрәб (Чад)',
        'ar_TN' => 'әрәб (Тунис)',
        'ar_YE' => 'әрәб (Јәмән)',
        'as' => 'ассам',
        'as_IN' => 'ассам (Һиндистан)',
        'az' => 'азәрбајҹан',
        'az_AZ' => 'азәрбајҹан (Азәрбајҹан)',
        'az_Cyrl' => 'азәрбајҹан (Кирил)',
        'az_Cyrl_AZ' => 'азәрбајҹан (Кирил, Азәрбајҹан)',
        'az_Latn' => 'азәрбајҹан (latın)',
        'az_Latn_AZ' => 'азәрбајҹан (latın, Азәрбајҹан)',
        'be' => 'беларус',
        'be_BY' => 'беларус (Беларус)',
        'bg' => 'булгар',
        'bg_BG' => 'булгар (Болгарыстан)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Мали)',
        'bn' => 'бенгал',
        'bn_BD' => 'бенгал (Бангладеш)',
        'bn_IN' => 'бенгал (Һиндистан)',
        'bo' => 'тибет',
        'bo_CN' => 'тибет (Чин)',
        'bo_IN' => 'тибет (Һиндистан)',
        'br' => 'бретон',
        'br_FR' => 'бретон (Франса)',
        'bs' => 'босниак',
        'bs_BA' => 'босниак (Боснија вә Һерсеговина)',
        'bs_Cyrl' => 'босниак (Кирил)',
        'bs_Cyrl_BA' => 'босниак (Кирил, Боснија вә Һерсеговина)',
        'bs_Latn' => 'босниак (latın)',
        'bs_Latn_BA' => 'босниак (latın, Боснија вә Һерсеговина)',
        'ca' => 'каталан',
        'ca_AD' => 'каталан (Андорра)',
        'ca_ES' => 'каталан (Испанија)',
        'ca_FR' => 'каталан (Франса)',
        'ca_IT' => 'каталан (Италија)',
        'ce' => 'чечен',
        'ce_RU' => 'чечен (Русија)',
        'cs' => 'чех',
        'cs_CZ' => 'чех (Чехија)',
        'cv' => 'чуваш',
        'cv_RU' => 'чуваш (Русија)',
        'cy' => 'уелс',
        'cy_GB' => 'уелс (Бирләшмиш Краллыг)',
        'da' => 'данимарка',
        'da_DK' => 'данимарка (Данимарка)',
        'da_GL' => 'данимарка (Гренландија)',
        'de' => 'алман',
        'de_AT' => 'алман (Австрија)',
        'de_BE' => 'алман (Белчика)',
        'de_CH' => 'алман (Исвечрә)',
        'de_DE' => 'алман (Алманија)',
        'de_IT' => 'алман (Италија)',
        'de_LI' => 'алман (Лихтенштејн)',
        'de_LU' => 'алман (Лүксембург)',
        'dz' => 'дзонга',
        'dz_BT' => 'дзонга (Бутан)',
        'ee' => 'еве',
        'ee_GH' => 'еве (Гана)',
        'ee_TG' => 'еве (Того)',
        'el' => 'јунан',
        'el_CY' => 'јунан (Кипр)',
        'el_GR' => 'јунан (Јунаныстан)',
        'en' => 'инҝилис',
        'en_001' => 'инҝилис (Дүнја)',
        'en_150' => 'инҝилис (Авропа)',
        'en_AE' => 'инҝилис (Бирләшмиш Әрәб Әмирликләри)',
        'en_AG' => 'инҝилис (Антигуа вә Барбуда)',
        'en_AI' => 'инҝилис (Анҝилја)',
        'en_AS' => 'инҝилис (Америка Самоасы)',
        'en_AT' => 'инҝилис (Австрија)',
        'en_AU' => 'инҝилис (Австралија)',
        'en_BB' => 'инҝилис (Барбадос)',
        'en_BE' => 'инҝилис (Белчика)',
        'en_BI' => 'инҝилис (Бурунди)',
        'en_BM' => 'инҝилис (Бермуд адалары)',
        'en_BS' => 'инҝилис (Баһам адалары)',
        'en_BW' => 'инҝилис (Ботсвана)',
        'en_BZ' => 'инҝилис (Белиз)',
        'en_CA' => 'инҝилис (Канада)',
        'en_CC' => 'инҝилис (Кокос [Килинг] адалары)',
        'en_CH' => 'инҝилис (Исвечрә)',
        'en_CK' => 'инҝилис (Кук адалары)',
        'en_CM' => 'инҝилис (Камерун)',
        'en_CX' => 'инҝилис (Милад адасы)',
        'en_CY' => 'инҝилис (Кипр)',
        'en_DE' => 'инҝилис (Алманија)',
        'en_DK' => 'инҝилис (Данимарка)',
        'en_DM' => 'инҝилис (Доминика)',
        'en_ER' => 'инҝилис (Еритреја)',
        'en_FI' => 'инҝилис (Финландија)',
        'en_FJ' => 'инҝилис (Фиҹи)',
        'en_FK' => 'инҝилис (Фолкленд адалары)',
        'en_FM' => 'инҝилис (Микронезија)',
        'en_GB' => 'инҝилис (Бирләшмиш Краллыг)',
        'en_GD' => 'инҝилис (Гренада)',
        'en_GG' => 'инҝилис (Ҝернси)',
        'en_GH' => 'инҝилис (Гана)',
        'en_GI' => 'инҝилис (Ҹәбәллүтариг)',
        'en_GM' => 'инҝилис (Гамбија)',
        'en_GU' => 'инҝилис (Гуам)',
        'en_GY' => 'инҝилис (Гајана)',
        'en_HK' => 'инҝилис (Һонк Конг Хүсуси Инзибати Әрази Чин)',
        'en_IE' => 'инҝилис (Ирландија)',
        'en_IL' => 'инҝилис (Исраил)',
        'en_IM' => 'инҝилис (Мен адасы)',
        'en_IN' => 'инҝилис (Һиндистан)',
        'en_IO' => 'инҝилис (Британтјанын Һинд Океаны Әразиси)',
        'en_JE' => 'инҝилис (Ҹерси)',
        'en_JM' => 'инҝилис (Јамајка)',
        'en_KE' => 'инҝилис (Кенија)',
        'en_KI' => 'инҝилис (Кирибати)',
        'en_KN' => 'инҝилис (Сент-Китс вә Невис)',
        'en_KY' => 'инҝилис (Кајман адалары)',
        'en_LC' => 'инҝилис (Сент-Лусија)',
        'en_LR' => 'инҝилис (Либерија)',
        'en_LS' => 'инҝилис (Лесото)',
        'en_MG' => 'инҝилис (Мадагаскар)',
        'en_MH' => 'инҝилис (Маршал адалары)',
        'en_MO' => 'инҝилис (Макао Хүсуси Инзибати Әрази Чин)',
        'en_MP' => 'инҝилис (Шимали Мариан адалары)',
        'en_MS' => 'инҝилис (Монсерат)',
        'en_MT' => 'инҝилис (Малта)',
        'en_MU' => 'инҝилис (Маврики)',
        'en_MV' => 'инҝилис (Малдив адалары)',
        'en_MW' => 'инҝилис (Малави)',
        'en_MY' => 'инҝилис (Малајзија)',
        'en_NA' => 'инҝилис (Намибија)',
        'en_NF' => 'инҝилис (Норфолк адасы)',
        'en_NG' => 'инҝилис (Ниҝерија)',
        'en_NL' => 'инҝилис (Нидерланд)',
        'en_NR' => 'инҝилис (Науру)',
        'en_NU' => 'инҝилис (Ниуе)',
        'en_NZ' => 'инҝилис (Јени Зеландија)',
        'en_PG' => 'инҝилис (Папуа-Јени Гвинеја)',
        'en_PH' => 'инҝилис (Филиппин)',
        'en_PK' => 'инҝилис (Пакистан)',
        'en_PN' => 'инҝилис (Питкерн адалары)',
        'en_PR' => 'инҝилис (Пуерто Рико)',
        'en_PW' => 'инҝилис (Палау)',
        'en_RW' => 'инҝилис (Руанда)',
        'en_SB' => 'инҝилис (Соломон адалары)',
        'en_SC' => 'инҝилис (Сејшел адалары)',
        'en_SD' => 'инҝилис (Судан)',
        'en_SE' => 'инҝилис (Исвеч)',
        'en_SG' => 'инҝилис (Сингапур)',
        'en_SH' => 'инҝилис (Мүгәддәс Јелена)',
        'en_SI' => 'инҝилис (Словенија)',
        'en_SL' => 'инҝилис (Сјерра-Леоне)',
        'en_SS' => 'инҝилис (Ҹәнуби Судан)',
        'en_SX' => 'инҝилис (Синт-Мартен)',
        'en_SZ' => 'инҝилис (Свазиленд)',
        'en_TC' => 'инҝилис (Төркс вә Кајкос адалары)',
        'en_TK' => 'инҝилис (Токелау)',
        'en_TO' => 'инҝилис (Тонга)',
        'en_TT' => 'инҝилис (Тринидад вә Тобаго)',
        'en_TV' => 'инҝилис (Тувалу)',
        'en_TZ' => 'инҝилис (Танзанија)',
        'en_UG' => 'инҝилис (Уганда)',
        'en_UM' => 'инҝилис (АБШ-а бағлы кичик адаҹыглар)',
        'en_US' => 'инҝилис (Америка Бирләшмиш Штатлары)',
        'en_VC' => 'инҝилис (Сент-Винсент вә Гренадинләр)',
        'en_VG' => 'инҝилис (Британијанын Вирҝин адалары)',
        'en_VI' => 'инҝилис (АБШ Вирҝин адалары)',
        'en_VU' => 'инҝилис (Вануату)',
        'en_WS' => 'инҝилис (Самоа)',
        'en_ZA' => 'инҝилис (Ҹәнуб Африка)',
        'en_ZM' => 'инҝилис (Замбија)',
        'en_ZW' => 'инҝилис (Зимбабве)',
        'eo' => 'есперанто',
        'eo_001' => 'есперанто (Дүнја)',
        'es' => 'испан',
        'es_419' => 'испан (Латын Америкасы)',
        'es_AR' => 'испан (Арҝентина)',
        'es_BO' => 'испан (Боливија)',
        'es_BR' => 'испан (Бразилија)',
        'es_BZ' => 'испан (Белиз)',
        'es_CL' => 'испан (Чили)',
        'es_CO' => 'испан (Колумбија)',
        'es_CR' => 'испан (Коста Рика)',
        'es_CU' => 'испан (Куба)',
        'es_DO' => 'испан (Доминикан Республикасы)',
        'es_EC' => 'испан (Еквадор)',
        'es_ES' => 'испан (Испанија)',
        'es_GQ' => 'испан (Екваториал Гвинеја)',
        'es_GT' => 'испан (Гватемала)',
        'es_HN' => 'испан (Һондурас)',
        'es_MX' => 'испан (Мексика)',
        'es_NI' => 'испан (Никарагуа)',
        'es_PA' => 'испан (Панама)',
        'es_PE' => 'испан (Перу)',
        'es_PH' => 'испан (Филиппин)',
        'es_PR' => 'испан (Пуерто Рико)',
        'es_PY' => 'испан (Парагвај)',
        'es_SV' => 'испан (Салвадор)',
        'es_US' => 'испан (Америка Бирләшмиш Штатлары)',
        'es_UY' => 'испан (Уругвај)',
        'es_VE' => 'испан (Венесуела)',
        'et' => 'естон',
        'et_EE' => 'естон (Естонија)',
        'eu' => 'баск',
        'eu_ES' => 'баск (Испанија)',
        'fa' => 'фарс',
        'fa_AF' => 'фарс (Әфганыстан)',
        'fa_IR' => 'фарс (Иран)',
        'ff' => 'фула',
        'ff_Adlm' => 'фула (adlam)',
        'ff_Adlm_BF' => 'фула (adlam, Буркина Фасо)',
        'ff_Adlm_CM' => 'фула (adlam, Камерун)',
        'ff_Adlm_GH' => 'фула (adlam, Гана)',
        'ff_Adlm_GM' => 'фула (adlam, Гамбија)',
        'ff_Adlm_GN' => 'фула (adlam, Гвинеја)',
        'ff_Adlm_GW' => 'фула (adlam, Гвинеја-Бисау)',
        'ff_Adlm_LR' => 'фула (adlam, Либерија)',
        'ff_Adlm_MR' => 'фула (adlam, Мавританија)',
        'ff_Adlm_NE' => 'фула (adlam, Ниҝер)',
        'ff_Adlm_NG' => 'фула (adlam, Ниҝерија)',
        'ff_Adlm_SL' => 'фула (adlam, Сјерра-Леоне)',
        'ff_Adlm_SN' => 'фула (adlam, Сенегал)',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвинеја)',
        'ff_Latn' => 'фула (latın)',
        'ff_Latn_BF' => 'фула (latın, Буркина Фасо)',
        'ff_Latn_CM' => 'фула (latın, Камерун)',
        'ff_Latn_GH' => 'фула (latın, Гана)',
        'ff_Latn_GM' => 'фула (latın, Гамбија)',
        'ff_Latn_GN' => 'фула (latın, Гвинеја)',
        'ff_Latn_GW' => 'фула (latın, Гвинеја-Бисау)',
        'ff_Latn_LR' => 'фула (latın, Либерија)',
        'ff_Latn_MR' => 'фула (latın, Мавританија)',
        'ff_Latn_NE' => 'фула (latın, Ниҝер)',
        'ff_Latn_NG' => 'фула (latın, Ниҝерија)',
        'ff_Latn_SL' => 'фула (latın, Сјерра-Леоне)',
        'ff_Latn_SN' => 'фула (latın, Сенегал)',
        'ff_MR' => 'фула (Мавританија)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фин',
        'fi_FI' => 'фин (Финландија)',
        'fo' => 'фарер',
        'fo_DK' => 'фарер (Данимарка)',
        'fo_FO' => 'фарер (Фарер адалары)',
        'fr' => 'франсыз',
        'fr_BE' => 'франсыз (Белчика)',
        'fr_BF' => 'франсыз (Буркина Фасо)',
        'fr_BI' => 'франсыз (Бурунди)',
        'fr_BJ' => 'франсыз (Бенин)',
        'fr_BL' => 'франсыз (Сент-Бартелеми)',
        'fr_CA' => 'франсыз (Канада)',
        'fr_CD' => 'франсыз (Конго-Киншаса)',
        'fr_CF' => 'франсыз (Мәркәзи Африка Республикасы)',
        'fr_CG' => 'франсыз (Конго-Браззавил)',
        'fr_CH' => 'франсыз (Исвечрә)',
        'fr_CI' => 'франсыз (Котд’ивуар)',
        'fr_CM' => 'франсыз (Камерун)',
        'fr_DJ' => 'франсыз (Ҹибути)',
        'fr_DZ' => 'франсыз (Әлҹәзаир)',
        'fr_FR' => 'франсыз (Франса)',
        'fr_GA' => 'франсыз (Габон)',
        'fr_GF' => 'франсыз (Франса Гвианасы)',
        'fr_GN' => 'франсыз (Гвинеја)',
        'fr_GP' => 'франсыз (Гваделупа)',
        'fr_GQ' => 'франсыз (Екваториал Гвинеја)',
        'fr_HT' => 'франсыз (Һаити)',
        'fr_KM' => 'франсыз (Комор адалары)',
        'fr_LU' => 'франсыз (Лүксембург)',
        'fr_MA' => 'франсыз (Мәракеш)',
        'fr_MC' => 'франсыз (Монако)',
        'fr_MF' => 'франсыз (Сент Мартин)',
        'fr_MG' => 'франсыз (Мадагаскар)',
        'fr_ML' => 'франсыз (Мали)',
        'fr_MQ' => 'франсыз (Мартиник)',
        'fr_MR' => 'франсыз (Мавританија)',
        'fr_MU' => 'франсыз (Маврики)',
        'fr_NC' => 'франсыз (Јени Каледонија)',
        'fr_NE' => 'франсыз (Ниҝер)',
        'fr_PF' => 'франсыз (Франса Полинезијасы)',
        'fr_PM' => 'франсыз (Мүгәддәс Пјер вә Микелон)',
        'fr_RE' => 'франсыз (Рејунјон)',
        'fr_RW' => 'франсыз (Руанда)',
        'fr_SC' => 'франсыз (Сејшел адалары)',
        'fr_SN' => 'франсыз (Сенегал)',
        'fr_SY' => 'франсыз (Сурија)',
        'fr_TD' => 'франсыз (Чад)',
        'fr_TG' => 'франсыз (Того)',
        'fr_TN' => 'франсыз (Тунис)',
        'fr_VU' => 'франсыз (Вануату)',
        'fr_WF' => 'франсыз (Уоллис вә Футуна)',
        'fr_YT' => 'франсыз (Мајот)',
        'fy' => 'гәрби фриз',
        'fy_NL' => 'гәрби фриз (Нидерланд)',
        'ga' => 'ирланд',
        'ga_GB' => 'ирланд (Бирләшмиш Краллыг)',
        'ga_IE' => 'ирланд (Ирландија)',
        'gd' => 'шотланд келт',
        'gd_GB' => 'шотланд келт (Бирләшмиш Краллыг)',
        'gl' => 'галисија',
        'gl_ES' => 'галисија (Испанија)',
        'gu' => 'гуҹарат',
        'gu_IN' => 'гуҹарат (Һиндистан)',
        'gv' => 'манкс',
        'gv_IM' => 'манкс (Мен адасы)',
        'ha' => 'һауса',
        'ha_GH' => 'һауса (Гана)',
        'ha_NE' => 'һауса (Ниҝер)',
        'ha_NG' => 'һауса (Ниҝерија)',
        'he' => 'иврит',
        'he_IL' => 'иврит (Исраил)',
        'hi' => 'һинд',
        'hi_IN' => 'һинд (Һиндистан)',
        'hi_Latn' => 'һинд (latın)',
        'hi_Latn_IN' => 'һинд (latın, Һиндистан)',
        'hr' => 'хорват',
        'hr_BA' => 'хорват (Боснија вә Һерсеговина)',
        'hr_HR' => 'хорват (Хорватија)',
        'hu' => 'маҹар',
        'hu_HU' => 'маҹар (Маҹарыстан)',
        'hy' => 'ермәни',
        'hy_AM' => 'ермәни (Ермәнистан)',
        'ia' => 'интерлингве',
        'ia_001' => 'интерлингве (Дүнја)',
        'id' => 'индонезија',
        'id_ID' => 'индонезија (Индонезија)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Ниҝерија)',
        'ii_CN' => 'siçuan yi (Чин)',
        'is' => 'исланд',
        'is_IS' => 'исланд (Исландија)',
        'it' => 'италјан',
        'it_CH' => 'италјан (Исвечрә)',
        'it_IT' => 'италјан (Италија)',
        'it_SM' => 'италјан (Сан-Марино)',
        'it_VA' => 'италјан (Ватикан)',
        'ja' => 'јапон',
        'ja_JP' => 'јапон (Јапонија)',
        'jv' => 'јава',
        'jv_ID' => 'јава (Индонезија)',
        'ka' => 'ҝүрҹү',
        'ka_GE' => 'ҝүрҹү (Ҝүрҹүстан)',
        'ki' => 'кикују',
        'ki_KE' => 'кикују (Кенија)',
        'kk' => 'газах',
        'kk_KZ' => 'газах (Газахыстан)',
        'kl' => 'калааллисут',
        'kl_GL' => 'калааллисут (Гренландија)',
        'km' => 'кхмер',
        'km_KH' => 'кхмер (Камбоҹа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Һиндистан)',
        'ko' => 'кореја',
        'ko_KP' => 'кореја (Шимали Кореја)',
        'ko_KR' => 'кореја (Ҹәнуби Кореја)',
        'ks' => 'кәшмир',
        'ks_Arab' => 'кәшмир (ərəb)',
        'ks_Arab_IN' => 'кәшмир (ərəb, Һиндистан)',
        'ks_Deva' => 'кәшмир (devanaqari)',
        'ks_Deva_IN' => 'кәшмир (devanaqari, Һиндистан)',
        'ks_IN' => 'кәшмир (Һиндистан)',
        'ku' => 'күрд',
        'ku_TR' => 'күрд (Түркијә)',
        'kw' => 'корн',
        'kw_GB' => 'корн (Бирләшмиш Краллыг)',
        'ky' => 'гырғыз',
        'ky_KG' => 'гырғыз (Гырғызыстан)',
        'lb' => 'лүксембург',
        'lb_LU' => 'лүксембург (Лүксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лингала',
        'ln_AO' => 'лингала (Ангола)',
        'ln_CD' => 'лингала (Конго-Киншаса)',
        'ln_CF' => 'лингала (Мәркәзи Африка Республикасы)',
        'ln_CG' => 'лингала (Конго-Браззавил)',
        'lo' => 'лаос',
        'lo_LA' => 'лаос (Лаос)',
        'lt' => 'литва',
        'lt_LT' => 'литва (Литва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго-Киншаса)',
        'lv' => 'латыш',
        'lv_LV' => 'латыш (Латвија)',
        'mg' => 'малагас',
        'mg_MG' => 'малагас (Мадагаскар)',
        'mi' => 'маори',
        'mi_NZ' => 'маори (Јени Зеландија)',
        'mk' => 'македон',
        'mk_MK' => 'македон (Şimali Makedoniya)',
        'ml' => 'малајалам',
        'ml_IN' => 'малајалам (Һиндистан)',
        'mn' => 'монгол',
        'mn_MN' => 'монгол (Монголустан)',
        'mr' => 'маратһи',
        'mr_IN' => 'маратһи (Һиндистан)',
        'ms' => 'малај',
        'ms_BN' => 'малај (Брунеј)',
        'ms_ID' => 'малај (Индонезија)',
        'ms_MY' => 'малај (Малајзија)',
        'ms_SG' => 'малај (Сингапур)',
        'mt' => 'малта',
        'mt_MT' => 'малта (Малта)',
        'my' => 'бирман',
        'my_MM' => 'бирман (Мјанма)',
        'nb' => 'бокмал норвеч',
        'nb_NO' => 'бокмал норвеч (Норвеч)',
        'nb_SJ' => 'бокмал норвеч (Свалбард вә Јан-Мајен)',
        'nd' => 'шимали ндебеле',
        'nd_ZW' => 'шимали ндебеле (Зимбабве)',
        'ne' => 'непал',
        'ne_IN' => 'непал (Һиндистан)',
        'ne_NP' => 'непал (Непал)',
        'nl' => 'һолланд',
        'nl_AW' => 'һолланд (Аруба)',
        'nl_BE' => 'һолланд (Белчика)',
        'nl_BQ' => 'һолланд (Karib Niderlandı)',
        'nl_CW' => 'һолланд (Курасао)',
        'nl_NL' => 'һолланд (Нидерланд)',
        'nl_SR' => 'һолланд (Суринам)',
        'nl_SX' => 'һолланд (Синт-Мартен)',
        'nn' => 'нүнорск норвеч',
        'nn_NO' => 'нүнорск норвеч (Норвеч)',
        'no_NO' => 'norveç (Норвеч)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Ефиопија)',
        'om_KE' => 'оромо (Кенија)',
        'or' => 'одија',
        'or_IN' => 'одија (Һиндистан)',
        'os' => 'осетин',
        'os_GE' => 'осетин (Ҝүрҹүстан)',
        'os_RU' => 'осетин (Русија)',
        'pa' => 'пәнҹаб',
        'pa_Arab' => 'пәнҹаб (ərəb)',
        'pa_Arab_PK' => 'пәнҹаб (ərəb, Пакистан)',
        'pa_Guru' => 'пәнҹаб (qurmuxi)',
        'pa_Guru_IN' => 'пәнҹаб (qurmuxi, Һиндистан)',
        'pa_IN' => 'пәнҹаб (Һиндистан)',
        'pa_PK' => 'пәнҹаб (Пакистан)',
        'pl' => 'полјак',
        'pl_PL' => 'полјак (Полша)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Әфганыстан)',
        'ps_PK' => 'пушту (Пакистан)',
        'pt' => 'португал',
        'pt_AO' => 'португал (Ангола)',
        'pt_BR' => 'португал (Бразилија)',
        'pt_CH' => 'португал (Исвечрә)',
        'pt_CV' => 'португал (Кабо-Верде)',
        'pt_GQ' => 'португал (Екваториал Гвинеја)',
        'pt_GW' => 'португал (Гвинеја-Бисау)',
        'pt_LU' => 'португал (Лүксембург)',
        'pt_MO' => 'португал (Макао Хүсуси Инзибати Әрази Чин)',
        'pt_MZ' => 'португал (Мозамбик)',
        'pt_PT' => 'португал (Португалија)',
        'pt_ST' => 'португал (Сан-Томе вә Принсипи)',
        'pt_TL' => 'португал (Шәрги Тимор)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливија)',
        'qu_EC' => 'кечуа (Еквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'романш',
        'rm_CH' => 'романш (Исвечрә)',
        'rn' => 'рунди',
        'rn_BI' => 'рунди (Бурунди)',
        'ro' => 'румын',
        'ro_MD' => 'румын (Молдова)',
        'ro_RO' => 'румын (Румынија)',
        'ru' => 'рус',
        'ru_BY' => 'рус (Беларус)',
        'ru_KG' => 'рус (Гырғызыстан)',
        'ru_KZ' => 'рус (Газахыстан)',
        'ru_MD' => 'рус (Молдова)',
        'ru_RU' => 'рус (Русија)',
        'ru_UA' => 'рус (Украјна)',
        'rw' => 'кинјарванда',
        'rw_RW' => 'кинјарванда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Һиндистан)',
        'sc' => 'сардин',
        'sc_IT' => 'сардин (Италија)',
        'sd' => 'синдһи',
        'sd_Arab' => 'синдһи (ərəb)',
        'sd_Arab_PK' => 'синдһи (ərəb, Пакистан)',
        'sd_Deva' => 'синдһи (devanaqari)',
        'sd_Deva_IN' => 'синдһи (devanaqari, Һиндистан)',
        'sd_IN' => 'синдһи (Һиндистан)',
        'sd_PK' => 'синдһи (Пакистан)',
        'se' => 'шимали сами',
        'se_FI' => 'шимали сами (Финландија)',
        'se_NO' => 'шимали сами (Норвеч)',
        'se_SE' => 'шимали сами (Исвеч)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Мәркәзи Африка Республикасы)',
        'sh_BA' => 'serb-xorvat (Боснија вә Һерсеговина)',
        'si' => 'синһала',
        'si_LK' => 'синһала (Шри-Ланка)',
        'sk' => 'словак',
        'sk_SK' => 'словак (Словакија)',
        'sl' => 'словен',
        'sl_SI' => 'словен (Словенија)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомали',
        'so_DJ' => 'сомали (Ҹибути)',
        'so_ET' => 'сомали (Ефиопија)',
        'so_KE' => 'сомали (Кенија)',
        'so_SO' => 'сомали (Сомали)',
        'sq' => 'албан',
        'sq_AL' => 'албан (Албанија)',
        'sq_MK' => 'албан (Şimali Makedoniya)',
        'sr' => 'серб',
        'sr_BA' => 'серб (Боснија вә Һерсеговина)',
        'sr_Cyrl' => 'серб (Кирил)',
        'sr_Cyrl_BA' => 'серб (Кирил, Боснија вә Һерсеговина)',
        'sr_Cyrl_ME' => 'серб (Кирил, Монтенегро)',
        'sr_Cyrl_RS' => 'серб (Кирил, Сербија)',
        'sr_Latn' => 'серб (latın)',
        'sr_Latn_BA' => 'серб (latın, Боснија вә Һерсеговина)',
        'sr_Latn_ME' => 'серб (latın, Монтенегро)',
        'sr_Latn_RS' => 'серб (latın, Сербија)',
        'sr_ME' => 'серб (Монтенегро)',
        'sr_RS' => 'серб (Сербија)',
        'su' => 'сундан',
        'su_ID' => 'сундан (Индонезија)',
        'su_Latn' => 'сундан (latın)',
        'su_Latn_ID' => 'сундан (latın, Индонезија)',
        'sv' => 'исвеч',
        'sv_AX' => 'исвеч (Аланд адалары)',
        'sv_FI' => 'исвеч (Финландија)',
        'sv_SE' => 'исвеч (Исвеч)',
        'sw' => 'суаһили',
        'sw_CD' => 'суаһили (Конго-Киншаса)',
        'sw_KE' => 'суаһили (Кенија)',
        'sw_TZ' => 'суаһили (Танзанија)',
        'sw_UG' => 'суаһили (Уганда)',
        'ta' => 'тамил',
        'ta_IN' => 'тамил (Һиндистан)',
        'ta_LK' => 'тамил (Шри-Ланка)',
        'ta_MY' => 'тамил (Малајзија)',
        'ta_SG' => 'тамил (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Һиндистан)',
        'tg' => 'таҹик',
        'tg_TJ' => 'таҹик (Таҹикистан)',
        'th' => 'тај',
        'th_TH' => 'тај (Таиланд)',
        'ti' => 'тигрин',
        'ti_ER' => 'тигрин (Еритреја)',
        'ti_ET' => 'тигрин (Ефиопија)',
        'tk' => 'түркмән',
        'tk_TM' => 'түркмән (Түркмәнистан)',
        'tl_PH' => 'taqaloq (Филиппин)',
        'to' => 'тонган',
        'to_TO' => 'тонган (Тонга)',
        'tr' => 'түрк',
        'tr_CY' => 'түрк (Кипр)',
        'tr_TR' => 'түрк (Түркијә)',
        'tt' => 'татар',
        'tt_RU' => 'татар (Русија)',
        'ug' => 'ујғур',
        'ug_CN' => 'ујғур (Чин)',
        'uk' => 'украјна',
        'uk_UA' => 'украјна (Украјна)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Һиндистан)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'өзбәк',
        'uz_AF' => 'өзбәк (Әфганыстан)',
        'uz_Arab' => 'өзбәк (ərəb)',
        'uz_Arab_AF' => 'өзбәк (ərəb, Әфганыстан)',
        'uz_Cyrl' => 'өзбәк (Кирил)',
        'uz_Cyrl_UZ' => 'өзбәк (Кирил, Өзбәкистан)',
        'uz_Latn' => 'өзбәк (latın)',
        'uz_Latn_UZ' => 'өзбәк (latın, Өзбәкистан)',
        'uz_UZ' => 'өзбәк (Өзбәкистан)',
        'vi' => 'вјетнам',
        'vi_VN' => 'вјетнам (Вјетнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'xh' => 'хоса',
        'xh_ZA' => 'хоса (Ҹәнуб Африка)',
        'yi' => 'идиш',
        'yi_001' => 'идиш (Дүнја)',
        'yo' => 'јоруба',
        'yo_BJ' => 'јоруба (Бенин)',
        'yo_NG' => 'јоруба (Ниҝерија)',
        'zh' => 'чин',
        'zh_CN' => 'чин (Чин)',
        'zh_HK' => 'чин (Һонк Конг Хүсуси Инзибати Әрази Чин)',
        'zh_Hans' => 'чин (sadələşmiş)',
        'zh_Hans_CN' => 'чин (sadələşmiş, Чин)',
        'zh_Hans_HK' => 'чин (sadələşmiş, Һонк Конг Хүсуси Инзибати Әрази Чин)',
        'zh_Hans_MO' => 'чин (sadələşmiş, Макао Хүсуси Инзибати Әрази Чин)',
        'zh_Hans_SG' => 'чин (sadələşmiş, Сингапур)',
        'zh_Hant' => 'чин (ənənəvi)',
        'zh_Hant_HK' => 'чин (ənənəvi, Һонк Конг Хүсуси Инзибати Әрази Чин)',
        'zh_Hant_MO' => 'чин (ənənəvi, Макао Хүсуси Инзибати Әрази Чин)',
        'zh_Hant_TW' => 'чин (ənənəvi, Тајван)',
        'zh_MO' => 'чин (Макао Хүсуси Инзибати Әрази Чин)',
        'zh_SG' => 'чин (Сингапур)',
        'zh_TW' => 'чин (Тајван)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Ҹәнуб Африка)',
    ],
];
