<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'andorranske peseta',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afghani (1927–2002)',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'angolske kwanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'angolske nye kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'angolske kwanza reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'argentiske austral',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'argentinske peso (1983–1985)',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'austerrikske schilling',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'aserbaijanske manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'bosnisk-hercegovinske dinarar',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'belgiske franc (konvertibel)',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'belgiske franc (finansiell)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'bulgarsk hard lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahrainske dinarar',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'boliviske peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'boliviske mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'brasiliansk cruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'brasilianske cruzado',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'brasilianske cruzado novo',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'brasilianske cruzeiro',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'burmesisk kyat',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'kviterussiske nye rublar (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'nye kviterussiske rublar',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'kviterussiske rublar (2000–2016)',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'kolombianske pesos',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'unidad de valor real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'kostarikanske colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'gamle serbiske dinarer',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'kappverdiske escudo',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'austtyske mark',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'algeriske dinarar',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'britiske pund',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ghanesiske cedi (1979–2007)',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'greske drakme',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guinea-Bissau-peso',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'kroatiske dinar',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'ungarske forintar',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indonesiske rupiar',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'nye israelske sheklar',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'indiske rupiar',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'irakiske dinarar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iranske rial',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jordanske dinarar',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuwaitiske dinarar',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'srilankiske rupiar',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litauiske lita',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'litauiske talona',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'luxemburgske konvertibel franc',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'latviske lat',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'latviske rublar',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'libyske dinarar',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldovske leuar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'makedonske denarar',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mauritanske ouguiya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'mauritiske rupiar',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'meksikanske sølvpeso (1861–1992)',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'nicaraguanske cordoba',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepalske rupiar',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'nyzealandske dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'omanske rial',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistanske rupiar',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paraguayanske guaraní',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'qatarske rial',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'gamle rumenske leu',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'rumenske leuar',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'serbiske dinarar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'russiske rublar',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'russiske rublar (1991–1998)',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'saudiarabiske rial',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'seychelliske rupiar',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'gamle sudanske dinarer',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'gamle sudanske pund',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'sovjetiske rublar',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'eswatinisk lilangeni',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'tadsjikiske rublar',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'turkmensk manat (1993–2009)',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tunisiske dinarar',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'gamle tyrkiske lire',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'amerikanske dollar (same dag)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'uruguayanske peso en unidades indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'uruguayanske peso (1975–1993)',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'usbekiske sum',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuatuiske vatu',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'austkaribiske dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'europeiske valutaeiningar',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'jemenittiske dinarar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'jemenittiske rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'jugoslaviske dinarar (hard)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'jugoslaviske noviy-dinarar',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'jugoslaviske konvertibel dinarar',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'sørafrikanske rand (finansiell)',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zairisk ny zaire',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zairisk zaire',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'zimbabwisk dollar',
        ],
    ],
];
