<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Ndiriha wa Lemila alabu',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza wa Angola',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Ndola wa Ositali',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Ndina wa Bahrene',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Nfalanga wa Bulundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula wa Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Ndola wa Kanada',
        ],
        'CDF' => [
            0 => 'FC',
            1 => 'Nfalanga wa Kongu',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Nfalanga wa Swise',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuani Renminbi wa Shine',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Esikuludo wa Kapevere',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Nfalanga wa Dzibuti',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Ndina wa Alijeri',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Pauni wa Mushidi',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa wa Elitle',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Bira wa Etshiopi',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Iro',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Pauni wa Angeletele',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi wa Ngana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Ndalasi wa Ngambi',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Nfalanga wa Ngina',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupi wa Inde',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni wa Zapɔ',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Nshili wa Kenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Nfalanga wa Komoru',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Ndola wa Liberya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti wa Lesoto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Ndina wa Libi',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Ndiriha wa Maroke',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Nfalanga wa Madagasikare',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya wa Moritani (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya wa Moritani',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupia wa Morisi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwasha wa Malawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikali wa Mozambiki',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Ndola wa Namibi',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira wa Nizerya',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Nfalanga wa Rwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyale wa Alabu Nsawu',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupya wa Seshele',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Ndina wa Suda',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Pauni wa Suda',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Pauni wa Santu Elena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Nshili wa Somali',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra wa Sao Tome ne Presipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra wa Sao Tome ne Presipe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Ndina wa Tinizi',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Nshili wa Tanzani',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Nshili wa Uganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Ndola wa Ameriki',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Nfalanga CFA BEAC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Nfalanga CFA BCEAO',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rande wa Afrika wa Mwinshi',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwasha wa Zambi (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwasha wa Zambi',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Ndola wa Zimbabwe',
        ],
    ],
];
