<?php

return [
    'Names' => [
        'AX' => 'Islas Åland',
        'BA' => 'Bosnia-Herzegovina',
        'CG' => 'República del Congo',
        'CI' => 'Costa de Marfil',
        'UM' => 'Islas Ultramarinas de EE.UU.',
    ],
];
