<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Kuɗin Haɗaɗɗiyar Daular Larabawa',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghani na ƙasar Afghanistan',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Kuɗin Albania',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Kuɗin Armenia',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Antillean Guilder na ƙasar Netherlands',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kuɗin Angola',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Peso na ƙasar Argentina',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dalar Ostareliya',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Florin na yankin Aruba',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Kuɗin Azerbaijani',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Kuɗaɗen Bosnia da Herzegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dalar ƙasar Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka na ƙasar Bangladesh',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Kuɗin Bulgeria',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Kuɗin Baharan',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Kuɗin Burundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dalar ƙasar Bermuda',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dalar Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boloviano na ƙasar Bolivia',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Ril Kudin Birazil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dalar ƙasar Bahamas',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrum na ƙasar Bhutan',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Kuɗin Baswana',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Kuɗin Belarus',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dalar ƙasar Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dalar Kanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Kuɗin Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Kuɗin Suwizalan',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Peso na ƙasar Chile',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuwan na ƙasar Sin (na wajen ƙasa)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuwan na ƙasar Sin',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Peso na ƙasar Columbia',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Colón na ƙasar Costa Rica',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Peso mai fuska biyu na ƙasar Kuba',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Peso na ƙasar Kuba',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kuɗin Tsibiran Kap Barde',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Kuɗin Czech',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Kuɗin Jibuti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Krone na ƙasar Denmark',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Peso na jamhuriyar Dominica',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Kuɗin Aljeriya',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Fam kin Masar',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Kuɗin Eritireya',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Kuɗin Habasha',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dalar Fiji',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Fam na ƙasar Tsibirai na Falkland',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Fam na Ingila',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Kuɗin Georgia',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Cedi',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Sidi na Ghana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Kuɗin Gibraltal',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Kuɗin Gambiya',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Kuɗin Guinea',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Kuɗin Gini',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Quetzal na ƙasar Guatemala',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dalar Guyana',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dalar Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira na ƙasar Honduras',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuɗin Croatia',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gourde na ƙasar Haiti',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Kuɗin Hungary',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupiah na ƙasar Indonesia',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Sabbin Kuɗin Israʼila',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Kuɗin Indiya',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinarin Iraqi',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Riyal na ƙasar Iran',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Króna na ƙasar Iceland',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dalar Jamaica',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinarin Jordan',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'Yen na ƙasar Japan',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Sulen Kenya',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Som na ƙasar Kyrgystani',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riel na ƙasar Cambodia',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Kuɗin Kwamoras',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Won na ƙasar Koriya ta Arewa',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Won na Koriya ta Kudu',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinarin Kuwaiti',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dalar ƙasar Tsibirai na Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge na ƙasar Kazkhstan',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kuɗin Laos',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Kuɗin Lebanon',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rupee na ƙasar Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dalar Laberiya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Kuɗin Lesoto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Kuɗin Libiya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Kuɗin Maroko',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Kuɗaɗen Moldova',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Kuɗin Madagaskar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Dinarin Macedonia',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kuɗin Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrik na Mongolia',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataca na ƙasar Macao',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Kuɗin Moritaniya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Kuɗin Moritaniya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Kuɗin Moritus',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiyaa na ɓasar Maldives',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kuɗin Malawi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Peso na ƙasar Mekziko',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Kuɗin Malaysia',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Kuɗin Mozambik',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metical na ƙasar Mozambique',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dalar Namibiya',
        ],
        'NGN' => [
            0 => '₦',
            1 => 'Nairar Najeriya',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Córdoba na ƙasar Nicaragua',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Krone na ƙasar Norway',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupee na Nepal',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dalar New Zealand',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Riyal ɗin Oman',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa na ƙasar Panama',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Sol na ƙasar Peru',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina na ƙasar Papua Sabon Guinea',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'Kuɗin Philippine',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupee na ƙasar Pakistan',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Kuɗin Polan',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guarani na ƙasar Paraguay',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Riyal ɗin Qatar',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Kuɗin Romania',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinarin Serbia',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Ruble na ƙasar Rasha',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Kuɗin Ruwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dalar Tsibirai na Solomon',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Kuɗin Saishal',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Fam na Sudan',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Krona na ƙasar Sweden',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dalar Singapore',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Fam kin San Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Kuɗin Salewo',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Sulen Somaliya',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dalar ƙasar Suriname',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Fam na Kudancin Sudan',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Kuɗin Sawo Tome da Paransip (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Kuɗin Sawo Tome da Paransip',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Kuɗin Siriya',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Kuɗin Lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Baht na ƙasar Thailand',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni na ƙasar Tajikistan',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manat na ƙasar Turkmenistan',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Kuɗin Tunisiya',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Paʻanga na ƙasar Tonga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Kuɗin Turkiyya',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dalar ƙasar Trinidad da Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Sabuwar Dalar Taiwan',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Sulen Tanzaniya',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Kudin Ukrainian',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Sule Yuganda',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dalar Amurka',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso na ƙasar Uruguay',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Som na ƙasar Uzbekistan',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolívar na ƙasar Venezuela',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Kuɗin Vietnam',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatu da ƙasar Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala na ƙasar Samoa',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Kuɗin Sefa na Afirka Ta Tsakiya',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dalar Gabashin Karebiyan',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Kuɗin Sefa na Afirka Ta Yamma',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Kuɗin CFP franc',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Riyal ɗin Yemen',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Kuɗin Afirka Ta Kudu',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kuɗin Zambiya (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kuɗin Zambiya',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dalar zimbabuwe',
        ],
    ],
];
