<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گرین وچ کا اصل وقت (عابدجان)',
        'Africa/Accra' => 'گرین وچ کا اصل وقت (اکّرا)',
        'Africa/Addis_Ababa' => 'مشرقی افریقہ ٹائم (عدیس ابابا)',
        'Africa/Algiers' => 'وسط یورپ کا وقت (الجیئرس)',
        'Africa/Asmera' => 'مشرقی افریقہ ٹائم (اسمارا)',
        'Africa/Bamako' => 'گرین وچ کا اصل وقت (بماکو)',
        'Africa/Bangui' => 'مغربی افریقہ ٹائم (بنگوئی)',
        'Africa/Banjul' => 'گرین وچ کا اصل وقت (بنجول)',
        'Africa/Bissau' => 'گرین وچ کا اصل وقت (بِساؤ)',
        'Africa/Blantyre' => 'وسطی افریقہ ٹائم (بلینٹائر)',
        'Africa/Brazzaville' => 'مغربی افریقہ ٹائم (برازاویلے)',
        'Africa/Bujumbura' => 'وسطی افریقہ ٹائم (بجمبرا)',
        'Africa/Cairo' => 'مشرقی یورپ کا وقت (قاہرہ)',
        'Africa/Casablanca' => 'مغربی یورپ کا وقت (کیسا بلانکا)',
        'Africa/Ceuta' => 'وسط یورپ کا وقت (سیوٹا)',
        'Africa/Conakry' => 'گرین وچ کا اصل وقت (کونکری)',
        'Africa/Dakar' => 'گرین وچ کا اصل وقت (ڈکار)',
        'Africa/Dar_es_Salaam' => 'مشرقی افریقہ ٹائم (دار السلام)',
        'Africa/Djibouti' => 'مشرقی افریقہ ٹائم (جبوتی)',
        'Africa/Douala' => 'مغربی افریقہ ٹائم (ڈوآلا)',
        'Africa/El_Aaiun' => 'مغربی یورپ کا وقت (العیون)',
        'Africa/Freetown' => 'گرین وچ کا اصل وقت (فری ٹاؤن)',
        'Africa/Gaborone' => 'وسطی افریقہ ٹائم (گبرون)',
        'Africa/Harare' => 'وسطی افریقہ ٹائم (ہرارے)',
        'Africa/Johannesburg' => 'جنوبی افریقہ سٹینڈرڈ ٹائم (جوہانسبرگ)',
        'Africa/Juba' => 'وسطی افریقہ ٹائم (جوبا)',
        'Africa/Kampala' => 'مشرقی افریقہ ٹائم (کیمپالا)',
        'Africa/Khartoum' => 'وسطی افریقہ ٹائم (خرطوم)',
        'Africa/Kigali' => 'وسطی افریقہ ٹائم (کگالی)',
        'Africa/Kinshasa' => 'مغربی افریقہ ٹائم (کنشاسا)',
        'Africa/Lagos' => 'مغربی افریقہ ٹائم (لاگوس)',
        'Africa/Libreville' => 'مغربی افریقہ ٹائم (لبرے ویلے)',
        'Africa/Lome' => 'گرین وچ کا اصل وقت (لوم)',
        'Africa/Luanda' => 'مغربی افریقہ ٹائم (لوانڈا)',
        'Africa/Lubumbashi' => 'وسطی افریقہ ٹائم (لوبمباشی)',
        'Africa/Lusaka' => 'وسطی افریقہ ٹائم (لیوساکا)',
        'Africa/Malabo' => 'مغربی افریقہ ٹائم (ملابو)',
        'Africa/Maputo' => 'وسطی افریقہ ٹائم (مپوٹو)',
        'Africa/Maseru' => 'جنوبی افریقہ سٹینڈرڈ ٹائم (مسیرو)',
        'Africa/Mbabane' => 'جنوبی افریقہ سٹینڈرڈ ٹائم (مبابین)',
        'Africa/Mogadishu' => 'مشرقی افریقہ ٹائم (موگادیشو)',
        'Africa/Monrovia' => 'گرین وچ کا اصل وقت (مونروویا)',
        'Africa/Nairobi' => 'مشرقی افریقہ ٹائم (نیروبی)',
        'Africa/Ndjamena' => 'مغربی افریقہ ٹائم (اینجامینا)',
        'Africa/Niamey' => 'مغربی افریقہ ٹائم (نیامی)',
        'Africa/Nouakchott' => 'گرین وچ کا اصل وقت (نواکشوط)',
        'Africa/Ouagadougou' => 'گرین وچ کا اصل وقت (اؤگاڈؤگوو)',
        'Africa/Porto-Novo' => 'مغربی افریقہ ٹائم (پورٹو نووو)',
        'Africa/Sao_Tome' => 'گرین وچ کا اصل وقت (ساؤ ٹوم)',
        'Africa/Tripoli' => 'مشرقی یورپ کا وقت (ٹریپولی)',
        'Africa/Tunis' => 'وسط یورپ کا وقت (تیونس)',
        'Africa/Windhoek' => 'وسطی افریقہ ٹائم (ونڈہوک)',
        'America/Adak' => 'ہوائی الیوٹیئن ٹائم (اداک)',
        'America/Anchorage' => 'الاسکا ٹائم (اینکریج)',
        'America/Anguilla' => 'اٹلانٹک ٹائم (انگویلا)',
        'America/Antigua' => 'اٹلانٹک ٹائم (انٹیگوا)',
        'America/Araguaina' => 'برازیلیا ٹائم (اراگویانا)',
        'America/Argentina/La_Rioja' => 'ارجنٹینا کا وقت (لا ریئوجا)',
        'America/Argentina/Rio_Gallegos' => 'ارجنٹینا کا وقت (ریو گالیگوس)',
        'America/Argentina/Salta' => 'ارجنٹینا کا وقت (سالٹا)',
        'America/Argentina/San_Juan' => 'ارجنٹینا کا وقت (سان جوآن)',
        'America/Argentina/San_Luis' => 'ارجنٹینا کا وقت (سان لوئس)',
        'America/Argentina/Tucuman' => 'ارجنٹینا کا وقت (ٹوکومین)',
        'America/Argentina/Ushuaia' => 'ارجنٹینا کا وقت (اوشوآئیا)',
        'America/Aruba' => 'اٹلانٹک ٹائم (اروبا)',
        'America/Asuncion' => 'پیراگوئے کا وقت (اسنسیئن)',
        'America/Bahia' => 'برازیلیا ٹائم (باہیا)',
        'America/Bahia_Banderas' => 'سنٹرل ٹائم (بہیا بندراز)',
        'America/Barbados' => 'اٹلانٹک ٹائم (بارباڈوس)',
        'America/Belem' => 'برازیلیا ٹائم (بیلیم)',
        'America/Belize' => 'سنٹرل ٹائم (بیلائز)',
        'America/Blanc-Sablon' => 'اٹلانٹک ٹائم (بلانک سبلون)',
        'America/Boa_Vista' => 'امیزون ٹائم (بوآ وسٹا)',
        'America/Bogota' => 'کولمبیا ٹائم (بگوٹا)',
        'America/Boise' => 'ماؤنٹین ٹائم (بوائس)',
        'America/Buenos_Aires' => 'ارجنٹینا کا وقت (بیونس آئرس)',
        'America/Cambridge_Bay' => 'ماؤنٹین ٹائم (کیمبرج کی کھاڑی)',
        'America/Campo_Grande' => 'امیزون ٹائم (کیمپو گرینڈ)',
        'America/Cancun' => 'ایسٹرن ٹائم (کنکیون)',
        'America/Caracas' => 'وینزوئیلا کا وقت (کراکاس)',
        'America/Catamarca' => 'ارجنٹینا کا وقت (کیٹامارکا)',
        'America/Cayenne' => 'فرینچ گیانا کا وقت (کائین)',
        'America/Cayman' => 'ایسٹرن ٹائم (کیمین)',
        'America/Chicago' => 'سنٹرل ٹائم (شکاگو)',
        'America/Chihuahua' => 'میکسیکن پیسفک ٹائم (چیہوآہوآ)',
        'America/Coral_Harbour' => 'ایسٹرن ٹائم (اٹیکوکن)',
        'America/Cordoba' => 'ارجنٹینا کا وقت (کورڈوبا)',
        'America/Costa_Rica' => 'سنٹرل ٹائم (کوسٹا ریکا)',
        'America/Creston' => 'ماؤنٹین ٹائم (کریسٹون)',
        'America/Cuiaba' => 'امیزون ٹائم (کوئیابا)',
        'America/Curacao' => 'اٹلانٹک ٹائم (کیوراکاؤ)',
        'America/Danmarkshavn' => 'گرین وچ کا اصل وقت (ڈنمارک شاون)',
        'America/Dawson' => 'یوکون ٹائم (ڈاؤسن)',
        'America/Dawson_Creek' => 'ماؤنٹین ٹائم (ڈاؤسن کریک)',
        'America/Denver' => 'ماؤنٹین ٹائم (ڈینور)',
        'America/Detroit' => 'ایسٹرن ٹائم (ڈیٹرائٹ)',
        'America/Dominica' => 'اٹلانٹک ٹائم (ڈومنیکا)',
        'America/Edmonton' => 'ماؤنٹین ٹائم (ایڈمونٹن)',
        'America/Eirunepe' => 'برازیل وقت (ایرونیپ)',
        'America/El_Salvador' => 'سنٹرل ٹائم (ال سلواڈور)',
        'America/Fort_Nelson' => 'ماؤنٹین ٹائم (فورٹ نیلسن)',
        'America/Fortaleza' => 'برازیلیا ٹائم (فورٹالیزا)',
        'America/Glace_Bay' => 'اٹلانٹک ٹائم (گلیس کی کھاڑی)',
        'America/Godthab' => 'مغربی گرین لینڈ ٹائم (نوک)',
        'America/Goose_Bay' => 'اٹلانٹک ٹائم (گوس کی کھاڑی)',
        'America/Grand_Turk' => 'ایسٹرن ٹائم (عظیم ترک)',
        'America/Grenada' => 'اٹلانٹک ٹائم (غرناطہ)',
        'America/Guadeloupe' => 'اٹلانٹک ٹائم (گواڈیلوپ)',
        'America/Guatemala' => 'سنٹرل ٹائم (گواٹے مالا)',
        'America/Guayaquil' => 'ایکواڈور کا وقت (گوآیاکوئل)',
        'America/Guyana' => 'گیانا کا وقت',
        'America/Halifax' => 'اٹلانٹک ٹائم (ہیلیفیکس)',
        'America/Havana' => 'کیوبا ٹائم (ہوانا)',
        'America/Hermosillo' => 'میکسیکن پیسفک ٹائم (ہرموسیلو)',
        'America/Indiana/Knox' => 'سنٹرل ٹائم (کنوکس، انڈیانا)',
        'America/Indiana/Marengo' => 'ایسٹرن ٹائم (مرینگو، انڈیانا)',
        'America/Indiana/Petersburg' => 'ایسٹرن ٹائم (پیٹرزبرگ، انڈیانا)',
        'America/Indiana/Tell_City' => 'سنٹرل ٹائم (ٹیل سٹی، انڈیانا)',
        'America/Indiana/Vevay' => 'ایسٹرن ٹائم (ویوے، انڈیانا)',
        'America/Indiana/Vincennes' => 'ایسٹرن ٹائم (ونسینیز، انڈیانا)',
        'America/Indiana/Winamac' => 'ایسٹرن ٹائم (وینامیک، انڈیانا)',
        'America/Indianapolis' => 'ایسٹرن ٹائم (انڈیاناپولس)',
        'America/Inuvik' => 'ماؤنٹین ٹائم (انووِک)',
        'America/Iqaluit' => 'ایسٹرن ٹائم (ایکالوئٹ)',
        'America/Jamaica' => 'ایسٹرن ٹائم (جمائیکا)',
        'America/Jujuy' => 'ارجنٹینا کا وقت (جوجوئی)',
        'America/Juneau' => 'الاسکا ٹائم (جونیئو)',
        'America/Kentucky/Monticello' => 'ایسٹرن ٹائم (مونٹیسیلو، کینٹوکی)',
        'America/Kralendijk' => 'اٹلانٹک ٹائم (کرالینڈیجک)',
        'America/La_Paz' => 'بولیویا کا وقت (لا پاز)',
        'America/Lima' => 'پیرو کا وقت (لیما)',
        'America/Los_Angeles' => 'پیسفک ٹائم (لاس اینجلس)',
        'America/Louisville' => 'ایسٹرن ٹائم (لوئس ویلے)',
        'America/Lower_Princes' => 'اٹلانٹک ٹائم (لوور پرنسس کوارٹر)',
        'America/Maceio' => 'برازیلیا ٹائم (میسیئو)',
        'America/Managua' => 'سنٹرل ٹائم (مناگوآ)',
        'America/Manaus' => 'امیزون ٹائم (مناؤس)',
        'America/Marigot' => 'اٹلانٹک ٹائم (میریگوٹ)',
        'America/Martinique' => 'اٹلانٹک ٹائم (مارٹینک)',
        'America/Matamoros' => 'سنٹرل ٹائم (میٹاموروس)',
        'America/Mazatlan' => 'میکسیکن پیسفک ٹائم (میزٹلان)',
        'America/Mendoza' => 'ارجنٹینا کا وقت (مینڈوزا)',
        'America/Menominee' => 'سنٹرل ٹائم (مینومینی)',
        'America/Merida' => 'سنٹرل ٹائم (میریڈا)',
        'America/Metlakatla' => 'الاسکا ٹائم (میٹلا کاٹلا)',
        'America/Mexico_City' => 'سنٹرل ٹائم (میکسیکو سٹی)',
        'America/Miquelon' => 'سینٹ پیئر اور مکلیئون ٹائم (میکلیئون)',
        'America/Moncton' => 'اٹلانٹک ٹائم (مونکٹن)',
        'America/Monterrey' => 'سنٹرل ٹائم (مونٹیری)',
        'America/Montevideo' => 'یوروگوئے کا وقت (مونٹی ویڈیو)',
        'America/Montreal' => 'کینیڈا وقت (Montreal)',
        'America/Montserrat' => 'اٹلانٹک ٹائم (مونٹسیراٹ)',
        'America/Nassau' => 'ایسٹرن ٹائم (نساؤ)',
        'America/New_York' => 'ایسٹرن ٹائم (نیو یارک)',
        'America/Nipigon' => 'ایسٹرن ٹائم (نپیگون)',
        'America/Nome' => 'الاسکا ٹائم (نوم)',
        'America/Noronha' => 'فرنانڈو ڈی نورنہا کا وقت (نورونہا)',
        'America/North_Dakota/Beulah' => 'سنٹرل ٹائم (بیولاہ، شمالی ڈکوٹا)',
        'America/North_Dakota/Center' => 'سنٹرل ٹائم (وسط، شمالی ڈکوٹا)',
        'America/North_Dakota/New_Salem' => 'سنٹرل ٹائم (نیو سلیم، شمالی ڈکوٹا)',
        'America/Ojinaga' => 'ماؤنٹین ٹائم (اوجیناگا)',
        'America/Panama' => 'ایسٹرن ٹائم (پنامہ)',
        'America/Pangnirtung' => 'ایسٹرن ٹائم (پینگنِرٹنگ)',
        'America/Paramaribo' => 'سورینام کا وقت (پراماریبو)',
        'America/Phoenix' => 'ماؤنٹین ٹائم (فینکس)',
        'America/Port-au-Prince' => 'ایسٹرن ٹائم (پورٹ او پرنس)',
        'America/Port_of_Spain' => 'اٹلانٹک ٹائم (پورٹ آف اسپین)',
        'America/Porto_Velho' => 'امیزون ٹائم (پورٹو ویلہو)',
        'America/Puerto_Rico' => 'اٹلانٹک ٹائم (پیورٹو ریکو)',
        'America/Punta_Arenas' => 'چلی کا وقت (پنٹا اریناس)',
        'America/Rainy_River' => 'سنٹرل ٹائم (رینی ریور)',
        'America/Rankin_Inlet' => 'سنٹرل ٹائم (رینکن انلیٹ)',
        'America/Recife' => 'برازیلیا ٹائم (ریسائف)',
        'America/Regina' => 'سنٹرل ٹائم (ریجینا)',
        'America/Resolute' => 'سنٹرل ٹائم (ریزولیوٹ)',
        'America/Rio_Branco' => 'برازیل وقت (ریئو برینکو)',
        'America/Santa_Isabel' => 'شمال مغربی میکسیکو ٹائم (سانتا ایزابیل)',
        'America/Santarem' => 'برازیلیا ٹائم (سنٹارین)',
        'America/Santiago' => 'چلی کا وقت (سنٹیاگو)',
        'America/Santo_Domingo' => 'اٹلانٹک ٹائم (سانتو ڈومنگو)',
        'America/Sao_Paulo' => 'برازیلیا ٹائم (ساؤ پالو)',
        'America/Scoresbysund' => 'مشرقی گرین لینڈ ٹائم (اسکورز بائی سنڈ)',
        'America/Sitka' => 'الاسکا ٹائم (سیٹکا)',
        'America/St_Barthelemy' => 'اٹلانٹک ٹائم (سینٹ برتھیلمی)',
        'America/St_Johns' => 'نیو فاؤنڈ لینڈ ٹائم (سینٹ جانز)',
        'America/St_Kitts' => 'اٹلانٹک ٹائم (سینٹ کٹس)',
        'America/St_Lucia' => 'اٹلانٹک ٹائم (سینٹ لوسیا)',
        'America/St_Thomas' => 'اٹلانٹک ٹائم (سینٹ تھامس)',
        'America/St_Vincent' => 'اٹلانٹک ٹائم (سینٹ ونسنٹ)',
        'America/Swift_Current' => 'سنٹرل ٹائم (سوِفٹ کرنٹ)',
        'America/Tegucigalpa' => 'سنٹرل ٹائم (ٹیگوسیگالپے)',
        'America/Thule' => 'اٹلانٹک ٹائم (تھولو)',
        'America/Thunder_Bay' => 'ایسٹرن ٹائم (تھنڈر بے)',
        'America/Tijuana' => 'پیسفک ٹائم (تیجوآنا)',
        'America/Toronto' => 'ایسٹرن ٹائم (ٹورنٹو)',
        'America/Tortola' => 'اٹلانٹک ٹائم (ٹورٹولا)',
        'America/Vancouver' => 'پیسفک ٹائم (وینکوور)',
        'America/Whitehorse' => 'یوکون ٹائم (وہائٹ ہارس)',
        'America/Winnipeg' => 'سنٹرل ٹائم (ونّیپیگ)',
        'America/Yakutat' => 'الاسکا ٹائم (یکوٹیٹ)',
        'America/Yellowknife' => 'ماؤنٹین ٹائم (ایلو نائف)',
        'Antarctica/Casey' => 'انٹارکٹیکا وقت (کیسی)',
        'Antarctica/Davis' => 'ڈیوس ٹائم',
        'Antarctica/DumontDUrville' => 'ڈومونٹ-ڈی’ارویلے ٹائم (ڈومونٹ ڈی ارویلے)',
        'Antarctica/Macquarie' => 'ایسٹرن آسٹریلیا ٹائم (میکواری)',
        'Antarctica/Mawson' => 'ماؤسن ٹائم',
        'Antarctica/McMurdo' => 'نیوزی لینڈ کا وقت (میک مرڈو)',
        'Antarctica/Palmer' => 'چلی کا وقت (پلمیر)',
        'Antarctica/Rothera' => 'روتھیرا کا وقت',
        'Antarctica/Syowa' => 'سیووا ٹائم',
        'Antarctica/Troll' => 'گرین وچ کا اصل وقت (ٹرول)',
        'Antarctica/Vostok' => 'ووسٹاک کا وقت (ووستوک)',
        'Arctic/Longyearbyen' => 'وسط یورپ کا وقت (لانگ ایئر بین)',
        'Asia/Aden' => 'عرب کا وقت (عدن)',
        'Asia/Almaty' => 'مشرقی قزاخستان کا وقت (الماٹی)',
        'Asia/Amman' => 'مشرقی یورپ کا وقت (امّان)',
        'Asia/Anadyr' => 'انیدر ٹائم',
        'Asia/Aqtau' => 'مغربی قزاخستان کا وقت (اکتاؤ)',
        'Asia/Aqtobe' => 'مغربی قزاخستان کا وقت (اکٹوب)',
        'Asia/Ashgabat' => 'ترکمانستان کا وقت (اشغبت)',
        'Asia/Atyrau' => 'مغربی قزاخستان کا وقت (آتیراؤ)',
        'Asia/Baghdad' => 'عرب کا وقت (بغداد)',
        'Asia/Bahrain' => 'عرب کا وقت (بحرین)',
        'Asia/Baku' => 'آذربائیجان کا وقت (باکو)',
        'Asia/Bangkok' => 'ہند چین ٹائم (بنکاک)',
        'Asia/Barnaul' => 'روس وقت (برنال)',
        'Asia/Beirut' => 'مشرقی یورپ کا وقت (بیروت)',
        'Asia/Bishkek' => 'کرغستان کا وقت (بشکیک)',
        'Asia/Brunei' => 'برونئی دارالسلام ٹائم',
        'Asia/Calcutta' => 'ہندوستان کا معیاری وقت (کولکاتا)',
        'Asia/Chita' => 'یکوتسک ٹائم (چیتا)',
        'Asia/Choibalsan' => 'یولان بیتور ٹائم (چوئبالسان)',
        'Asia/Colombo' => 'ہندوستان کا معیاری وقت (کولمبو)',
        'Asia/Damascus' => 'مشرقی یورپ کا وقت (دمشق)',
        'Asia/Dhaka' => 'بنگلہ دیش کا وقت (ڈھاکہ)',
        'Asia/Dili' => 'مشرقی تیمور ٹائم (ڈلی)',
        'Asia/Dubai' => 'خلیج کا معیاری وقت (دبئی)',
        'Asia/Dushanbe' => 'تاجکستان کا وقت (دوشانبے)',
        'Asia/Famagusta' => 'مشرقی یورپ کا وقت (فاماگوسٹا)',
        'Asia/Gaza' => 'مشرقی یورپ کا وقت (غزہ)',
        'Asia/Hebron' => 'مشرقی یورپ کا وقت (ہیبرون)',
        'Asia/Hong_Kong' => 'ہانگ کانگ ٹائم',
        'Asia/Hovd' => 'ہووڈ ٹائم (ہووارڈ)',
        'Asia/Irkutsk' => 'ارکتسک ٹائم',
        'Asia/Jakarta' => 'مغربی انڈونیشیا ٹائم (جکارتہ)',
        'Asia/Jayapura' => 'مشرقی انڈونیشیا ٹائم (جے پورہ)',
        'Asia/Jerusalem' => 'اسرائیل کا وقت (یروشلم)',
        'Asia/Kabul' => 'افغانستان کا وقت (کابل)',
        'Asia/Kamchatka' => 'پیٹروپاؤلووسک-کیمچسکی ٹائم (کیمچٹکا)',
        'Asia/Karachi' => 'پاکستان کا وقت (کراچی)',
        'Asia/Katmandu' => 'نیپال کا وقت (کاٹھمنڈو)',
        'Asia/Khandyga' => 'یکوتسک ٹائم (خندیگا)',
        'Asia/Krasnoyarsk' => 'کریسنویارسک ٹائم',
        'Asia/Kuala_Lumpur' => 'ملیشیا ٹائم (کوالا لمپور)',
        'Asia/Kuching' => 'ملیشیا ٹائم (کیوچنگ)',
        'Asia/Kuwait' => 'عرب کا وقت (کویت)',
        'Asia/Macau' => 'چین کا وقت (مکاؤ)',
        'Asia/Magadan' => 'میگیدن ٹائم',
        'Asia/Makassar' => 'وسطی انڈونیشیا ٹائم (مکاسر)',
        'Asia/Manila' => 'فلپائن ٹائم (منیلا)',
        'Asia/Muscat' => 'خلیج کا معیاری وقت (مسقط)',
        'Asia/Nicosia' => 'مشرقی یورپ کا وقت (نکوسیا)',
        'Asia/Novokuznetsk' => 'کریسنویارسک ٹائم (نوووکیوزنیسک)',
        'Asia/Novosibirsk' => 'نوووسیبرسک ٹائم (نوووسِبِرسک)',
        'Asia/Omsk' => 'اومسک ٹائم',
        'Asia/Oral' => 'مغربی قزاخستان کا وقت (اورال)',
        'Asia/Phnom_Penh' => 'ہند چین ٹائم (پنوم پن)',
        'Asia/Pontianak' => 'مغربی انڈونیشیا ٹائم (پونٹیانک)',
        'Asia/Pyongyang' => 'کوریا ٹائم (پیونگ یانگ)',
        'Asia/Qatar' => 'عرب کا وقت (قطر)',
        'Asia/Qostanay' => 'مشرقی قزاخستان کا وقت (کوستانے)',
        'Asia/Qyzylorda' => 'مغربی قزاخستان کا وقت (کیزیلورڈا)',
        'Asia/Rangoon' => 'میانمار ٹائم (رنگون)',
        'Asia/Riyadh' => 'عرب کا وقت (ریاض)',
        'Asia/Saigon' => 'ہند چین ٹائم (ہو چی منہ سٹی)',
        'Asia/Sakhalin' => 'سخالین ٹائم',
        'Asia/Samarkand' => 'ازبکستان کا وقت (سمرقند)',
        'Asia/Seoul' => 'کوریا ٹائم (سیئول)',
        'Asia/Shanghai' => 'چین کا وقت (شنگھائی)',
        'Asia/Singapore' => 'سنگاپور سٹینڈرڈ ٹائم',
        'Asia/Srednekolymsk' => 'میگیدن ٹائم (سرہدنیکولیمسک)',
        'Asia/Taipei' => 'تائی پیئی ٹائم (تائپے)',
        'Asia/Tashkent' => 'ازبکستان کا وقت (تاشقند)',
        'Asia/Tbilisi' => 'جارجیا کا وقت (طبلیسی)',
        'Asia/Tehran' => 'ایران کا وقت (تہران)',
        'Asia/Thimphu' => 'بھوٹان کا وقت (تھمپو)',
        'Asia/Tokyo' => 'جاپان ٹائم (ٹوکیو)',
        'Asia/Tomsk' => 'روس وقت (ٹامسک)',
        'Asia/Ulaanbaatar' => 'یولان بیتور ٹائم (اولان باتار)',
        'Asia/Urumqi' => 'چین وقت (یورومکی)',
        'Asia/Ust-Nera' => 'ولادی ووستک ٹائم (اوست-نیرا)',
        'Asia/Vientiane' => 'ہند چین ٹائم (وینٹیانا)',
        'Asia/Vladivostok' => 'ولادی ووستک ٹائم',
        'Asia/Yakutsk' => 'یکوتسک ٹائم',
        'Asia/Yekaterinburg' => 'یکاٹیرِنبرگ ٹائم',
        'Asia/Yerevan' => 'آرمینیا کا وقت (یریوان)',
        'Atlantic/Azores' => 'ازوریس کا وقت',
        'Atlantic/Bermuda' => 'اٹلانٹک ٹائم (برمودا)',
        'Atlantic/Canary' => 'مغربی یورپ کا وقت (کینری)',
        'Atlantic/Cape_Verde' => 'کیپ ورڈی ٹائم',
        'Atlantic/Faeroe' => 'مغربی یورپ کا وقت (فارو)',
        'Atlantic/Madeira' => 'مغربی یورپ کا وقت (مڈیئرا)',
        'Atlantic/Reykjavik' => 'گرین وچ کا اصل وقت (ریکجاوک)',
        'Atlantic/South_Georgia' => 'جنوبی جارجیا ٹائم',
        'Atlantic/St_Helena' => 'گرین وچ کا اصل وقت (سینٹ ہیلینا)',
        'Atlantic/Stanley' => 'فاک لینڈ آئلینڈز کا وقت (اسٹینلے)',
        'Australia/Adelaide' => 'سنٹرل آسٹریلیا ٹائم (ایڈیلیڈ)',
        'Australia/Brisbane' => 'ایسٹرن آسٹریلیا ٹائم (برسبین)',
        'Australia/Broken_Hill' => 'سنٹرل آسٹریلیا ٹائم (بروکن ہِل)',
        'Australia/Currie' => 'ایسٹرن آسٹریلیا ٹائم (کیوری)',
        'Australia/Darwin' => 'سنٹرل آسٹریلیا ٹائم (ڈارون)',
        'Australia/Eucla' => 'آسٹریلین سنٹرل ویسٹرن ٹائم (ایوکلا)',
        'Australia/Hobart' => 'ایسٹرن آسٹریلیا ٹائم (ہوبارٹ)',
        'Australia/Lindeman' => 'ایسٹرن آسٹریلیا ٹائم (لِنڈمین)',
        'Australia/Lord_Howe' => 'لارڈ ہووے ٹائم',
        'Australia/Melbourne' => 'ایسٹرن آسٹریلیا ٹائم (ملبورن)',
        'Australia/Perth' => 'ویسٹرن آسٹریلیا ٹائم (پرتھ)',
        'Australia/Sydney' => 'ایسٹرن آسٹریلیا ٹائم (سڈنی)',
        'CST6CDT' => 'سنٹرل ٹائم',
        'EST5EDT' => 'ایسٹرن ٹائم',
        'Etc/GMT' => 'گرین وچ کا اصل وقت',
        'Etc/UTC' => 'کوآرڈینیٹڈ یونیورسل ٹائم',
        'Europe/Amsterdam' => 'وسط یورپ کا وقت (ایمسٹرڈم)',
        'Europe/Andorra' => 'وسط یورپ کا وقت (انڈورا)',
        'Europe/Astrakhan' => 'ماسکو ٹائم (استراخان)',
        'Europe/Athens' => 'مشرقی یورپ کا وقت (ایتھنز)',
        'Europe/Belgrade' => 'وسط یورپ کا وقت (بلغراد)',
        'Europe/Berlin' => 'وسط یورپ کا وقت (برلن)',
        'Europe/Bratislava' => 'وسط یورپ کا وقت (بریٹِسلاوا)',
        'Europe/Brussels' => 'وسط یورپ کا وقت (برسلز)',
        'Europe/Bucharest' => 'مشرقی یورپ کا وقت (بخارسٹ)',
        'Europe/Budapest' => 'وسط یورپ کا وقت (بڈاپسٹ)',
        'Europe/Busingen' => 'وسط یورپ کا وقت (بزنجن)',
        'Europe/Chisinau' => 'مشرقی یورپ کا وقت (چیسیناؤ)',
        'Europe/Copenhagen' => 'وسط یورپ کا وقت (کوپن ہیگن)',
        'Europe/Dublin' => 'گرین وچ کا اصل وقت (ڈبلن)',
        'Europe/Gibraltar' => 'وسط یورپ کا وقت (جبل الطارق)',
        'Europe/Guernsey' => 'گرین وچ کا اصل وقت (گرنزی)',
        'Europe/Helsinki' => 'مشرقی یورپ کا وقت (ہیلسنکی)',
        'Europe/Isle_of_Man' => 'گرین وچ کا اصل وقت (آئل آف مین)',
        'Europe/Istanbul' => 'ترکی وقت (استنبول)',
        'Europe/Jersey' => 'گرین وچ کا اصل وقت (جرسی)',
        'Europe/Kaliningrad' => 'مشرقی یورپ کا وقت (کالينينغراد)',
        'Europe/Kiev' => 'مشرقی یورپ کا وقت (کیو)',
        'Europe/Kirov' => 'روس وقت (کیروف)',
        'Europe/Lisbon' => 'مغربی یورپ کا وقت (لسبن)',
        'Europe/Ljubljana' => 'وسط یورپ کا وقت (لیوبلیانا)',
        'Europe/London' => 'گرین وچ کا اصل وقت (لندن)',
        'Europe/Luxembourg' => 'وسط یورپ کا وقت (لگژمبرگ)',
        'Europe/Madrid' => 'وسط یورپ کا وقت (میڈرڈ)',
        'Europe/Malta' => 'وسط یورپ کا وقت (مالٹا)',
        'Europe/Mariehamn' => 'مشرقی یورپ کا وقت (میریہام)',
        'Europe/Minsk' => 'ماسکو ٹائم (مِنسک)',
        'Europe/Monaco' => 'وسط یورپ کا وقت (موناکو)',
        'Europe/Moscow' => 'ماسکو ٹائم',
        'Europe/Oslo' => 'وسط یورپ کا وقت (اوسلو)',
        'Europe/Paris' => 'وسط یورپ کا وقت (پیرس)',
        'Europe/Podgorica' => 'وسط یورپ کا وقت (پوڈگورسیا)',
        'Europe/Prague' => 'وسط یورپ کا وقت (پراگ)',
        'Europe/Riga' => 'مشرقی یورپ کا وقت (ریگا)',
        'Europe/Rome' => 'وسط یورپ کا وقت (روم)',
        'Europe/Samara' => 'سمارا ٹائم',
        'Europe/San_Marino' => 'وسط یورپ کا وقت (سان ماریانو)',
        'Europe/Sarajevo' => 'وسط یورپ کا وقت (سراجیوو)',
        'Europe/Saratov' => 'ماسکو ٹائم (سیراٹو)',
        'Europe/Simferopol' => 'ماسکو ٹائم (سمفروپول)',
        'Europe/Skopje' => 'وسط یورپ کا وقت (اسکوپجے)',
        'Europe/Sofia' => 'مشرقی یورپ کا وقت (صوفیہ)',
        'Europe/Stockholm' => 'وسط یورپ کا وقت (اسٹاک ہوم)',
        'Europe/Tallinn' => 'مشرقی یورپ کا وقت (ٹالن)',
        'Europe/Tirane' => 'وسط یورپ کا وقت (ٹیرانی)',
        'Europe/Ulyanovsk' => 'ماسکو ٹائم (الیانوسک)',
        'Europe/Uzhgorod' => 'مشرقی یورپ کا وقت (ازہوراڈ)',
        'Europe/Vaduz' => 'وسط یورپ کا وقت (ویڈوز)',
        'Europe/Vatican' => 'وسط یورپ کا وقت (واٹیکن)',
        'Europe/Vienna' => 'وسط یورپ کا وقت (ویانا)',
        'Europe/Vilnius' => 'مشرقی یورپ کا وقت (وِلنیئس)',
        'Europe/Volgograd' => 'وولگوگراد ٹائم',
        'Europe/Warsaw' => 'وسط یورپ کا وقت (وارسا)',
        'Europe/Zagreb' => 'وسط یورپ کا وقت (زیگریب)',
        'Europe/Zaporozhye' => 'مشرقی یورپ کا وقت (زیپوروزائی)',
        'Europe/Zurich' => 'وسط یورپ کا وقت (زیورخ)',
        'Indian/Antananarivo' => 'مشرقی افریقہ ٹائم (انٹاناناریوو)',
        'Indian/Chagos' => 'بحر ہند ٹائم (چاگوس)',
        'Indian/Christmas' => 'کرسمس آئلینڈ ٹائم',
        'Indian/Cocos' => 'کوکوس آئلینڈز ٹائم',
        'Indian/Comoro' => 'مشرقی افریقہ ٹائم (کومورو)',
        'Indian/Kerguelen' => 'فرینچ جنوبی اور انٹارکٹک ٹائم (کرگیولین)',
        'Indian/Mahe' => 'سیشلیز ٹائم (ماہی)',
        'Indian/Maldives' => 'مالدیپ کا وقت',
        'Indian/Mauritius' => 'ماریشس ٹائم',
        'Indian/Mayotte' => 'مشرقی افریقہ ٹائم (مایوٹ)',
        'Indian/Reunion' => 'ری یونین ٹائم',
        'MST7MDT' => 'ماؤنٹین ٹائم',
        'PST8PDT' => 'پیسفک ٹائم',
        'Pacific/Apia' => 'ایپیا ٹائم (اپیا)',
        'Pacific/Auckland' => 'نیوزی لینڈ کا وقت (آکلینڈ)',
        'Pacific/Bougainville' => 'پاپوآ نیو گنی ٹائم (بوگینولے)',
        'Pacific/Chatham' => 'چیتھم ٹائم',
        'Pacific/Easter' => 'ایسٹر آئلینڈ کا وقت',
        'Pacific/Efate' => 'وانوآٹو ٹائم (ایفیٹ)',
        'Pacific/Enderbury' => 'فینکس آئلینڈز ٹائم (اینڈربری)',
        'Pacific/Fakaofo' => 'ٹوکیلاؤ ٹائم (فکاؤفو)',
        'Pacific/Fiji' => 'فجی ٹائم',
        'Pacific/Funafuti' => 'ٹوالو ٹائم (فیونافیوٹی)',
        'Pacific/Galapagos' => 'گالاپاگوز کا وقت (گیلاپیگوس)',
        'Pacific/Gambier' => 'گیمبیئر ٹائم (گامبیئر)',
        'Pacific/Guadalcanal' => 'سولمن آئلینڈز ٹائم (گواڈل کینال)',
        'Pacific/Guam' => 'چامورو سٹینڈرڈ ٹائم (گوآم)',
        'Pacific/Honolulu' => 'ہوائی الیوٹیئن ٹائم (ہونولولو)',
        'Pacific/Johnston' => 'ہوائی الیوٹیئن ٹائم (جانسٹن)',
        'Pacific/Kiritimati' => 'لائن آئلینڈز ٹائم (کریتیماٹی)',
        'Pacific/Kosrae' => 'کوسرے ٹائم (کوسرائی)',
        'Pacific/Kwajalein' => 'مارشل آئلینڈز ٹائم (کواجیلین)',
        'Pacific/Majuro' => 'مارشل آئلینڈز ٹائم (مجورو)',
        'Pacific/Marquesas' => 'مارکیسس ٹائم (مارکیساس)',
        'Pacific/Midway' => 'ساموآ ٹائم (مڈوے)',
        'Pacific/Nauru' => 'ناؤرو ٹائم',
        'Pacific/Niue' => 'نیئو ٹائم',
        'Pacific/Norfolk' => 'نارفوک آئلینڈ کا وقت (نورفوک)',
        'Pacific/Noumea' => 'نیو کیلیڈونیا ٹائم (نؤمیا)',
        'Pacific/Pago_Pago' => 'ساموآ ٹائم (پاگو پاگو)',
        'Pacific/Palau' => 'پلاؤ ٹائم',
        'Pacific/Pitcairn' => 'پٹکائرن ٹائم',
        'Pacific/Ponape' => 'پوناپے ٹائم (پونپیئی)',
        'Pacific/Port_Moresby' => 'پاپوآ نیو گنی ٹائم (پورٹ موریسبی)',
        'Pacific/Rarotonga' => 'کک آئلینڈز ٹائم (راروٹونگا)',
        'Pacific/Saipan' => 'چامورو سٹینڈرڈ ٹائم (سائپین)',
        'Pacific/Tahiti' => 'تاہیتی ٹائم',
        'Pacific/Tarawa' => 'جلبرٹ آئلینڈز ٹائم (ٹراوا)',
        'Pacific/Tongatapu' => 'ٹونگا ٹائم (ٹونگاٹاپو)',
        'Pacific/Truk' => 'چوک ٹائم (چیوک)',
        'Pacific/Wake' => 'ویک آئلینڈ ٹائم',
        'Pacific/Wallis' => 'والیز اور فٹونا ٹائم (ولّیس)',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT %s',
    ],
];
