<?php

return [
    'Names' => [
        'af' => 'Affricâneg',
        'af_NA' => 'Affricâneg (Namibia)',
        'af_ZA' => 'Affricâneg (De Affrica)',
        'ak' => 'Acaneg',
        'ak_GH' => 'Acaneg (Ghana)',
        'am' => 'Amhareg',
        'am_ET' => 'Amhareg (Ethiopia)',
        'ar' => 'Arabeg',
        'ar_001' => 'Arabeg (Y Byd)',
        'ar_AE' => 'Arabeg (Emiradau Arabaidd Unedig)',
        'ar_BH' => 'Arabeg (Bahrain)',
        'ar_DJ' => 'Arabeg (Djibouti)',
        'ar_DZ' => 'Arabeg (Algeria)',
        'ar_EG' => 'Arabeg (Yr Aifft)',
        'ar_EH' => 'Arabeg (Gorllewin Sahara)',
        'ar_ER' => 'Arabeg (Eritrea)',
        'ar_IL' => 'Arabeg (Israel)',
        'ar_IQ' => 'Arabeg (Irac)',
        'ar_JO' => 'Arabeg (Gwlad Iorddonen)',
        'ar_KM' => 'Arabeg (Comoros)',
        'ar_KW' => 'Arabeg (Kuwait)',
        'ar_LB' => 'Arabeg (Libanus)',
        'ar_LY' => 'Arabeg (Libya)',
        'ar_MA' => 'Arabeg (Moroco)',
        'ar_MR' => 'Arabeg (Mauritania)',
        'ar_OM' => 'Arabeg (Oman)',
        'ar_PS' => 'Arabeg (Tiriogaethau Palesteinaidd)',
        'ar_QA' => 'Arabeg (Qatar)',
        'ar_SA' => 'Arabeg (Saudi Arabia)',
        'ar_SD' => 'Arabeg (Swdan)',
        'ar_SO' => 'Arabeg (Somalia)',
        'ar_SS' => 'Arabeg (De Swdan)',
        'ar_SY' => 'Arabeg (Syria)',
        'ar_TD' => 'Arabeg (Tsiad)',
        'ar_TN' => 'Arabeg (Tiwnisia)',
        'ar_YE' => 'Arabeg (Yemen)',
        'as' => 'Asameg',
        'as_IN' => 'Asameg (India)',
        'az' => 'Aserbaijaneg',
        'az_AZ' => 'Aserbaijaneg (Aserbaijan)',
        'az_Cyrl' => 'Aserbaijaneg (Cyrilig)',
        'az_Cyrl_AZ' => 'Aserbaijaneg (Cyrilig, Aserbaijan)',
        'az_Latn' => 'Aserbaijaneg (Lladin)',
        'az_Latn_AZ' => 'Aserbaijaneg (Lladin, Aserbaijan)',
        'be' => 'Belarwseg',
        'be_BY' => 'Belarwseg (Belarws)',
        'bg' => 'Bwlgareg',
        'bg_BG' => 'Bwlgareg (Bwlgaria)',
        'bm' => 'Bambareg',
        'bm_ML' => 'Bambareg (Mali)',
        'bn' => 'Bengaleg',
        'bn_BD' => 'Bengaleg (Bangladesh)',
        'bn_IN' => 'Bengaleg (India)',
        'bo' => 'Tibeteg',
        'bo_CN' => 'Tibeteg (Tsieina)',
        'bo_IN' => 'Tibeteg (India)',
        'br' => 'Llydaweg',
        'br_FR' => 'Llydaweg (Ffrainc)',
        'bs' => 'Bosnieg',
        'bs_BA' => 'Bosnieg (Bosnia a Herzegovina)',
        'bs_Cyrl' => 'Bosnieg (Cyrilig)',
        'bs_Cyrl_BA' => 'Bosnieg (Cyrilig, Bosnia a Herzegovina)',
        'bs_Latn' => 'Bosnieg (Lladin)',
        'bs_Latn_BA' => 'Bosnieg (Lladin, Bosnia a Herzegovina)',
        'ca' => 'Catalaneg',
        'ca_AD' => 'Catalaneg (Andorra)',
        'ca_ES' => 'Catalaneg (Sbaen)',
        'ca_FR' => 'Catalaneg (Ffrainc)',
        'ca_IT' => 'Catalaneg (Yr Eidal)',
        'ce' => 'Tsietsieneg',
        'ce_RU' => 'Tsietsieneg (Rwsia)',
        'cs' => 'Tsieceg',
        'cs_CZ' => 'Tsieceg (Tsiecia)',
        'cv' => 'Tshwfasheg',
        'cv_RU' => 'Tshwfasheg (Rwsia)',
        'cy' => 'Cymraeg',
        'cy_GB' => 'Cymraeg (Y Deyrnas Unedig)',
        'da' => 'Daneg',
        'da_DK' => 'Daneg (Denmarc)',
        'da_GL' => 'Daneg (Yr Ynys Las)',
        'de' => 'Almaeneg',
        'de_AT' => 'Almaeneg (Awstria)',
        'de_BE' => 'Almaeneg (Gwlad Belg)',
        'de_CH' => 'Almaeneg (Y Swistir)',
        'de_DE' => 'Almaeneg (Yr Almaen)',
        'de_IT' => 'Almaeneg (Yr Eidal)',
        'de_LI' => 'Almaeneg (Liechtenstein)',
        'de_LU' => 'Almaeneg (Lwcsembwrg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Groeg',
        'el_CY' => 'Groeg (Cyprus)',
        'el_GR' => 'Groeg (Gwlad Groeg)',
        'en' => 'Saesneg',
        'en_001' => 'Saesneg (Y Byd)',
        'en_150' => 'Saesneg (Ewrop)',
        'en_AE' => 'Saesneg (Emiradau Arabaidd Unedig)',
        'en_AG' => 'Saesneg (Antigua a Barbuda)',
        'en_AI' => 'Saesneg (Anguilla)',
        'en_AS' => 'Saesneg (Samoa America)',
        'en_AT' => 'Saesneg (Awstria)',
        'en_AU' => 'Saesneg (Awstralia)',
        'en_BB' => 'Saesneg (Barbados)',
        'en_BE' => 'Saesneg (Gwlad Belg)',
        'en_BI' => 'Saesneg (Burundi)',
        'en_BM' => 'Saesneg (Bermuda)',
        'en_BS' => 'Saesneg (Y Bahamas)',
        'en_BW' => 'Saesneg (Botswana)',
        'en_BZ' => 'Saesneg (Belize)',
        'en_CA' => 'Saesneg (Canada)',
        'en_CC' => 'Saesneg (Ynysoedd Cocos [Keeling])',
        'en_CH' => 'Saesneg (Y Swistir)',
        'en_CK' => 'Saesneg (Ynysoedd Cook)',
        'en_CM' => 'Saesneg (Camerŵn)',
        'en_CX' => 'Saesneg (Ynys y Nadolig)',
        'en_CY' => 'Saesneg (Cyprus)',
        'en_DE' => 'Saesneg (Yr Almaen)',
        'en_DK' => 'Saesneg (Denmarc)',
        'en_DM' => 'Saesneg (Dominica)',
        'en_ER' => 'Saesneg (Eritrea)',
        'en_FI' => 'Saesneg (Y Ffindir)',
        'en_FJ' => 'Saesneg (Fiji)',
        'en_FK' => 'Saesneg (Ynysoedd y Falkland/Malvinas)',
        'en_FM' => 'Saesneg (Micronesia)',
        'en_GB' => 'Saesneg (Y Deyrnas Unedig)',
        'en_GD' => 'Saesneg (Grenada)',
        'en_GG' => 'Saesneg (Ynys y Garn)',
        'en_GH' => 'Saesneg (Ghana)',
        'en_GI' => 'Saesneg (Gibraltar)',
        'en_GM' => 'Saesneg (Gambia)',
        'en_GU' => 'Saesneg (Guam)',
        'en_GY' => 'Saesneg (Guyana)',
        'en_HK' => 'Saesneg (Hong Kong SAR Tsieina)',
        'en_IE' => 'Saesneg (Iwerddon)',
        'en_IL' => 'Saesneg (Israel)',
        'en_IM' => 'Saesneg (Ynys Manaw)',
        'en_IN' => 'Saesneg (India)',
        'en_IO' => 'Saesneg (Tiriogaeth Brydeinig Cefnfor India)',
        'en_JE' => 'Saesneg (Jersey)',
        'en_JM' => 'Saesneg (Jamaica)',
        'en_KE' => 'Saesneg (Kenya)',
        'en_KI' => 'Saesneg (Kiribati)',
        'en_KN' => 'Saesneg (Saint Kitts a Nevis)',
        'en_KY' => 'Saesneg (Ynysoedd Cayman)',
        'en_LC' => 'Saesneg (Saint Lucia)',
        'en_LR' => 'Saesneg (Liberia)',
        'en_LS' => 'Saesneg (Lesotho)',
        'en_MG' => 'Saesneg (Madagascar)',
        'en_MH' => 'Saesneg (Ynysoedd Marshall)',
        'en_MO' => 'Saesneg (Macau SAR Tsieina)',
        'en_MP' => 'Saesneg (Ynysoedd Gogledd Mariana)',
        'en_MS' => 'Saesneg (Montserrat)',
        'en_MT' => 'Saesneg (Malta)',
        'en_MU' => 'Saesneg (Mauritius)',
        'en_MV' => 'Saesneg (Y Maldives)',
        'en_MW' => 'Saesneg (Malawi)',
        'en_MY' => 'Saesneg (Malaysia)',
        'en_NA' => 'Saesneg (Namibia)',
        'en_NF' => 'Saesneg (Ynys Norfolk)',
        'en_NG' => 'Saesneg (Nigeria)',
        'en_NL' => 'Saesneg (Yr Iseldiroedd)',
        'en_NR' => 'Saesneg (Nauru)',
        'en_NU' => 'Saesneg (Niue)',
        'en_NZ' => 'Saesneg (Seland Newydd)',
        'en_PG' => 'Saesneg (Papua Guinea Newydd)',
        'en_PH' => 'Saesneg (Y Philipinau)',
        'en_PK' => 'Saesneg (Pakistan)',
        'en_PN' => 'Saesneg (Ynysoedd Pitcairn)',
        'en_PR' => 'Saesneg (Puerto Rico)',
        'en_PW' => 'Saesneg (Palau)',
        'en_RW' => 'Saesneg (Rwanda)',
        'en_SB' => 'Saesneg (Ynysoedd Solomon)',
        'en_SC' => 'Saesneg (Seychelles)',
        'en_SD' => 'Saesneg (Swdan)',
        'en_SE' => 'Saesneg (Sweden)',
        'en_SG' => 'Saesneg (Singapore)',
        'en_SH' => 'Saesneg (Saint Helena)',
        'en_SI' => 'Saesneg (Slofenia)',
        'en_SL' => 'Saesneg (Sierra Leone)',
        'en_SS' => 'Saesneg (De Swdan)',
        'en_SX' => 'Saesneg (Sint Maarten)',
        'en_SZ' => 'Saesneg (Eswatini)',
        'en_TC' => 'Saesneg (Ynysoedd Turks a Caicos)',
        'en_TK' => 'Saesneg (Tokelau)',
        'en_TO' => 'Saesneg (Tonga)',
        'en_TT' => 'Saesneg (Trinidad a Tobago)',
        'en_TV' => 'Saesneg (Tuvalu)',
        'en_TZ' => 'Saesneg (Tanzania)',
        'en_UG' => 'Saesneg (Uganda)',
        'en_UM' => 'Saesneg (Ynysoedd Pellennig UDA)',
        'en_US' => 'Saesneg (Yr Unol Daleithiau)',
        'en_VC' => 'Saesneg (Saint Vincent a’r Grenadines)',
        'en_VG' => 'Saesneg (Ynysoedd Gwyryf Prydain)',
        'en_VI' => 'Saesneg (Ynysoedd Gwyryf yr Unol Daleithiau)',
        'en_VU' => 'Saesneg (Vanuatu)',
        'en_WS' => 'Saesneg (Samoa)',
        'en_ZA' => 'Saesneg (De Affrica)',
        'en_ZM' => 'Saesneg (Zambia)',
        'en_ZW' => 'Saesneg (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Y Byd)',
        'es' => 'Sbaeneg',
        'es_419' => 'Sbaeneg (America Ladin)',
        'es_AR' => 'Sbaeneg (Yr Ariannin)',
        'es_BO' => 'Sbaeneg (Bolifia)',
        'es_BR' => 'Sbaeneg (Brasil)',
        'es_BZ' => 'Sbaeneg (Belize)',
        'es_CL' => 'Sbaeneg (Chile)',
        'es_CO' => 'Sbaeneg (Colombia)',
        'es_CR' => 'Sbaeneg (Costa Rica)',
        'es_CU' => 'Sbaeneg (Ciwba)',
        'es_DO' => 'Sbaeneg (Gweriniaeth Dominica)',
        'es_EC' => 'Sbaeneg (Ecuador)',
        'es_ES' => 'Sbaeneg (Sbaen)',
        'es_GQ' => 'Sbaeneg (Gini Gyhydeddol)',
        'es_GT' => 'Sbaeneg (Guatemala)',
        'es_HN' => 'Sbaeneg (Honduras)',
        'es_MX' => 'Sbaeneg (Mecsico)',
        'es_NI' => 'Sbaeneg (Nicaragua)',
        'es_PA' => 'Sbaeneg (Panama)',
        'es_PE' => 'Sbaeneg (Periw)',
        'es_PH' => 'Sbaeneg (Y Philipinau)',
        'es_PR' => 'Sbaeneg (Puerto Rico)',
        'es_PY' => 'Sbaeneg (Paraguay)',
        'es_SV' => 'Sbaeneg (El Salvador)',
        'es_US' => 'Sbaeneg (Yr Unol Daleithiau)',
        'es_UY' => 'Sbaeneg (Uruguay)',
        'es_VE' => 'Sbaeneg (Venezuela)',
        'et' => 'Estoneg',
        'et_EE' => 'Estoneg (Estonia)',
        'eu' => 'Basgeg',
        'eu_ES' => 'Basgeg (Sbaen)',
        'fa' => 'Perseg',
        'fa_AF' => 'Perseg (Afghanistan)',
        'fa_IR' => 'Perseg (Iran)',
        'ff' => 'Ffwla',
        'ff_Adlm' => 'Ffwla (Adlam)',
        'ff_Adlm_BF' => 'Ffwla (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Ffwla (Adlam, Camerŵn)',
        'ff_Adlm_GH' => 'Ffwla (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Ffwla (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Ffwla (Adlam, Gini)',
        'ff_Adlm_GW' => 'Ffwla (Adlam, Guiné-Bissau)',
        'ff_Adlm_LR' => 'Ffwla (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Ffwla (Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Ffwla (Adlam, Niger)',
        'ff_Adlm_NG' => 'Ffwla (Adlam, Nigeria)',
        'ff_Adlm_SL' => 'Ffwla (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Ffwla (Adlam, Senegal)',
        'ff_CM' => 'Ffwla (Camerŵn)',
        'ff_GN' => 'Ffwla (Gini)',
        'ff_Latn' => 'Ffwla (Lladin)',
        'ff_Latn_BF' => 'Ffwla (Lladin, Burkina Faso)',
        'ff_Latn_CM' => 'Ffwla (Lladin, Camerŵn)',
        'ff_Latn_GH' => 'Ffwla (Lladin, Ghana)',
        'ff_Latn_GM' => 'Ffwla (Lladin, Gambia)',
        'ff_Latn_GN' => 'Ffwla (Lladin, Gini)',
        'ff_Latn_GW' => 'Ffwla (Lladin, Guiné-Bissau)',
        'ff_Latn_LR' => 'Ffwla (Lladin, Liberia)',
        'ff_Latn_MR' => 'Ffwla (Lladin, Mauritania)',
        'ff_Latn_NE' => 'Ffwla (Lladin, Niger)',
        'ff_Latn_NG' => 'Ffwla (Lladin, Nigeria)',
        'ff_Latn_SL' => 'Ffwla (Lladin, Sierra Leone)',
        'ff_Latn_SN' => 'Ffwla (Lladin, Senegal)',
        'ff_MR' => 'Ffwla (Mauritania)',
        'ff_SN' => 'Ffwla (Senegal)',
        'fi' => 'Ffinneg',
        'fi_FI' => 'Ffinneg (Y Ffindir)',
        'fo' => 'Ffaröeg',
        'fo_DK' => 'Ffaröeg (Denmarc)',
        'fo_FO' => 'Ffaröeg (Ynysoedd Ffaro)',
        'fr' => 'Ffrangeg',
        'fr_BE' => 'Ffrangeg (Gwlad Belg)',
        'fr_BF' => 'Ffrangeg (Burkina Faso)',
        'fr_BI' => 'Ffrangeg (Burundi)',
        'fr_BJ' => 'Ffrangeg (Benin)',
        'fr_BL' => 'Ffrangeg (Saint Barthélemy)',
        'fr_CA' => 'Ffrangeg (Canada)',
        'fr_CD' => 'Ffrangeg (Y Congo - Kinshasa)',
        'fr_CF' => 'Ffrangeg (Gweriniaeth Canolbarth Affrica)',
        'fr_CG' => 'Ffrangeg (Y Congo - Brazzaville)',
        'fr_CH' => 'Ffrangeg (Y Swistir)',
        'fr_CI' => 'Ffrangeg (Côte d’Ivoire)',
        'fr_CM' => 'Ffrangeg (Camerŵn)',
        'fr_DJ' => 'Ffrangeg (Djibouti)',
        'fr_DZ' => 'Ffrangeg (Algeria)',
        'fr_FR' => 'Ffrangeg (Ffrainc)',
        'fr_GA' => 'Ffrangeg (Gabon)',
        'fr_GF' => 'Ffrangeg (Guyane Ffrengig)',
        'fr_GN' => 'Ffrangeg (Gini)',
        'fr_GP' => 'Ffrangeg (Guadeloupe)',
        'fr_GQ' => 'Ffrangeg (Gini Gyhydeddol)',
        'fr_HT' => 'Ffrangeg (Haiti)',
        'fr_KM' => 'Ffrangeg (Comoros)',
        'fr_LU' => 'Ffrangeg (Lwcsembwrg)',
        'fr_MA' => 'Ffrangeg (Moroco)',
        'fr_MC' => 'Ffrangeg (Monaco)',
        'fr_MF' => 'Ffrangeg (Saint Martin)',
        'fr_MG' => 'Ffrangeg (Madagascar)',
        'fr_ML' => 'Ffrangeg (Mali)',
        'fr_MQ' => 'Ffrangeg (Martinique)',
        'fr_MR' => 'Ffrangeg (Mauritania)',
        'fr_MU' => 'Ffrangeg (Mauritius)',
        'fr_NC' => 'Ffrangeg (Caledonia Newydd)',
        'fr_NE' => 'Ffrangeg (Niger)',
        'fr_PF' => 'Ffrangeg (Polynesia Ffrengig)',
        'fr_PM' => 'Ffrangeg (Saint-Pierre-et-Miquelon)',
        'fr_RE' => 'Ffrangeg (Réunion)',
        'fr_RW' => 'Ffrangeg (Rwanda)',
        'fr_SC' => 'Ffrangeg (Seychelles)',
        'fr_SN' => 'Ffrangeg (Senegal)',
        'fr_SY' => 'Ffrangeg (Syria)',
        'fr_TD' => 'Ffrangeg (Tsiad)',
        'fr_TG' => 'Ffrangeg (Togo)',
        'fr_TN' => 'Ffrangeg (Tiwnisia)',
        'fr_VU' => 'Ffrangeg (Vanuatu)',
        'fr_WF' => 'Ffrangeg (Wallis a Futuna)',
        'fr_YT' => 'Ffrangeg (Mayotte)',
        'fy' => 'Ffriseg y Gorllewin',
        'fy_NL' => 'Ffriseg y Gorllewin (Yr Iseldiroedd)',
        'ga' => 'Gwyddeleg',
        'ga_GB' => 'Gwyddeleg (Y Deyrnas Unedig)',
        'ga_IE' => 'Gwyddeleg (Iwerddon)',
        'gd' => 'Gaeleg yr Alban',
        'gd_GB' => 'Gaeleg yr Alban (Y Deyrnas Unedig)',
        'gl' => 'Galisieg',
        'gl_ES' => 'Galisieg (Sbaen)',
        'gu' => 'Gwjarati',
        'gu_IN' => 'Gwjarati (India)',
        'gv' => 'Manaweg',
        'gv_IM' => 'Manaweg (Ynys Manaw)',
        'ha' => 'Hawsa',
        'ha_GH' => 'Hawsa (Ghana)',
        'ha_NE' => 'Hawsa (Niger)',
        'ha_NG' => 'Hawsa (Nigeria)',
        'he' => 'Hebraeg',
        'he_IL' => 'Hebraeg (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Lladin)',
        'hi_Latn_IN' => 'Hindi (Lladin, India)',
        'hr' => 'Croateg',
        'hr_BA' => 'Croateg (Bosnia a Herzegovina)',
        'hr_HR' => 'Croateg (Croatia)',
        'hu' => 'Hwngareg',
        'hu_HU' => 'Hwngareg (Hwngari)',
        'hy' => 'Armeneg',
        'hy_AM' => 'Armeneg (Armenia)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Y Byd)',
        'id' => 'Indoneseg',
        'id_ID' => 'Indoneseg (Indonesia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigeria)',
        'ii' => 'Nwosw',
        'ii_CN' => 'Nwosw (Tsieina)',
        'is' => 'Islandeg',
        'is_IS' => 'Islandeg (Gwlad yr Iâ)',
        'it' => 'Eidaleg',
        'it_CH' => 'Eidaleg (Y Swistir)',
        'it_IT' => 'Eidaleg (Yr Eidal)',
        'it_SM' => 'Eidaleg (San Marino)',
        'it_VA' => 'Eidaleg (Y Fatican)',
        'ja' => 'Japaneeg',
        'ja_JP' => 'Japaneeg (Japan)',
        'jv' => 'Jafanaeg',
        'jv_ID' => 'Jafanaeg (Indonesia)',
        'ka' => 'Georgeg',
        'ka_GE' => 'Georgeg (Georgia)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenya)',
        'kk' => 'Casacheg',
        'kk_KZ' => 'Casacheg (Kazakhstan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Yr Ynys Las)',
        'km' => 'Chmereg',
        'km_KH' => 'Chmereg (Cambodia)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (India)',
        'ko' => 'Coreeg',
        'ko_KP' => 'Coreeg (Gogledd Corea)',
        'ko_KR' => 'Coreeg (De Corea)',
        'ks' => 'Cashmireg',
        'ks_Arab' => 'Cashmireg (Arabaidd)',
        'ks_Arab_IN' => 'Cashmireg (Arabaidd, India)',
        'ks_Deva' => 'Cashmireg (Devanagari)',
        'ks_Deva_IN' => 'Cashmireg (Devanagari, India)',
        'ks_IN' => 'Cashmireg (India)',
        'ku' => 'Cwrdeg',
        'ku_TR' => 'Cwrdeg (Twrci)',
        'kw' => 'Cernyweg',
        'kw_GB' => 'Cernyweg (Y Deyrnas Unedig)',
        'ky' => 'Cirgiseg',
        'ky_KG' => 'Cirgiseg (Kyrgyzstan)',
        'lb' => 'Lwcsembwrgeg',
        'lb_LU' => 'Lwcsembwrgeg (Lwcsembwrg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Y Congo - Kinshasa)',
        'ln_CF' => 'Lingala (Gweriniaeth Canolbarth Affrica)',
        'ln_CG' => 'Lingala (Y Congo - Brazzaville)',
        'lo' => 'Laoeg',
        'lo_LA' => 'Laoeg (Laos)',
        'lt' => 'Lithwaneg',
        'lt_LT' => 'Lithwaneg (Lithwania)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Y Congo - Kinshasa)',
        'lv' => 'Latfieg',
        'lv_LV' => 'Latfieg (Latfia)',
        'mg' => 'Malagaseg',
        'mg_MG' => 'Malagaseg (Madagascar)',
        'mi' => 'Māori',
        'mi_NZ' => 'Māori (Seland Newydd)',
        'mk' => 'Macedoneg',
        'mk_MK' => 'Macedoneg (Gogledd Macedonia)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mongoleg',
        'mn_MN' => 'Mongoleg (Mongolia)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (India)',
        'ms' => 'Maleieg',
        'ms_BN' => 'Maleieg (Brunei)',
        'ms_ID' => 'Maleieg (Indonesia)',
        'ms_MY' => 'Maleieg (Malaysia)',
        'ms_SG' => 'Maleieg (Singapore)',
        'mt' => 'Malteg',
        'mt_MT' => 'Malteg (Malta)',
        'my' => 'Byrmaneg',
        'my_MM' => 'Byrmaneg (Myanmar [Burma])',
        'nb' => 'Norwyeg Bokmål',
        'nb_NO' => 'Norwyeg Bokmål (Norwy)',
        'nb_SJ' => 'Norwyeg Bokmål (Svalbard a Jan Mayen)',
        'nd' => 'Ndebele Gogleddol',
        'nd_ZW' => 'Ndebele Gogleddol (Zimbabwe)',
        'ne' => 'Nepaleg',
        'ne_IN' => 'Nepaleg (India)',
        'ne_NP' => 'Nepaleg (Nepal)',
        'nl' => 'Iseldireg',
        'nl_AW' => 'Iseldireg (Aruba)',
        'nl_BE' => 'Iseldireg (Gwlad Belg)',
        'nl_BQ' => 'Iseldireg (Antilles yr Iseldiroedd)',
        'nl_CW' => 'Iseldireg (Curaçao)',
        'nl_NL' => 'Iseldireg (Yr Iseldiroedd)',
        'nl_SR' => 'Iseldireg (Suriname)',
        'nl_SX' => 'Iseldireg (Sint Maarten)',
        'nn' => 'Norwyeg Nynorsk',
        'nn_NO' => 'Norwyeg Nynorsk (Norwy)',
        'no' => 'Norwyeg',
        'no_NO' => 'Norwyeg (Norwy)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Ethiopia)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Odia',
        'or_IN' => 'Odia (India)',
        'os' => 'Oseteg',
        'os_GE' => 'Oseteg (Georgia)',
        'os_RU' => 'Oseteg (Rwsia)',
        'pa' => 'Pwnjabeg',
        'pa_Arab' => 'Pwnjabeg (Arabaidd)',
        'pa_Arab_PK' => 'Pwnjabeg (Arabaidd, Pakistan)',
        'pa_Guru' => 'Pwnjabeg (Gwrmwci)',
        'pa_Guru_IN' => 'Pwnjabeg (Gwrmwci, India)',
        'pa_IN' => 'Pwnjabeg (India)',
        'pa_PK' => 'Pwnjabeg (Pakistan)',
        'pl' => 'Pwyleg',
        'pl_PL' => 'Pwyleg (Gwlad Pwyl)',
        'ps' => 'Pashto',
        'ps_AF' => 'Pashto (Afghanistan)',
        'ps_PK' => 'Pashto (Pakistan)',
        'pt' => 'Portiwgaleg',
        'pt_AO' => 'Portiwgaleg (Angola)',
        'pt_BR' => 'Portiwgaleg (Brasil)',
        'pt_CH' => 'Portiwgaleg (Y Swistir)',
        'pt_CV' => 'Portiwgaleg (Cabo Verde)',
        'pt_GQ' => 'Portiwgaleg (Gini Gyhydeddol)',
        'pt_GW' => 'Portiwgaleg (Guiné-Bissau)',
        'pt_LU' => 'Portiwgaleg (Lwcsembwrg)',
        'pt_MO' => 'Portiwgaleg (Macau SAR Tsieina)',
        'pt_MZ' => 'Portiwgaleg (Mozambique)',
        'pt_PT' => 'Portiwgaleg (Portiwgal)',
        'pt_ST' => 'Portiwgaleg (São Tomé a Príncipe)',
        'pt_TL' => 'Portiwgaleg (Timor-Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolifia)',
        'qu_EC' => 'Quechua (Ecuador)',
        'qu_PE' => 'Quechua (Periw)',
        'rm' => 'Románsh',
        'rm_CH' => 'Románsh (Y Swistir)',
        'rn' => 'Rwndi',
        'rn_BI' => 'Rwndi (Burundi)',
        'ro' => 'Rwmaneg',
        'ro_MD' => 'Rwmaneg (Moldofa)',
        'ro_RO' => 'Rwmaneg (Rwmania)',
        'ru' => 'Rwseg',
        'ru_BY' => 'Rwseg (Belarws)',
        'ru_KG' => 'Rwseg (Kyrgyzstan)',
        'ru_KZ' => 'Rwseg (Kazakhstan)',
        'ru_MD' => 'Rwseg (Moldofa)',
        'ru_RU' => 'Rwseg (Rwsia)',
        'ru_UA' => 'Rwseg (Wcráin)',
        'rw' => 'Ciniarŵandeg',
        'rw_RW' => 'Ciniarŵandeg (Rwanda)',
        'sa' => 'Sansgrit',
        'sa_IN' => 'Sansgrit (India)',
        'sc' => 'Sardeg',
        'sc_IT' => 'Sardeg (Yr Eidal)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arabaidd)',
        'sd_Arab_PK' => 'Sindhi (Arabaidd, Pakistan)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
        'sd_IN' => 'Sindhi (India)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Sami Gogleddol',
        'se_FI' => 'Sami Gogleddol (Y Ffindir)',
        'se_NO' => 'Sami Gogleddol (Norwy)',
        'se_SE' => 'Sami Gogleddol (Sweden)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Gweriniaeth Canolbarth Affrica)',
        'sh' => 'Serbo-Croateg',
        'sh_BA' => 'Serbo-Croateg (Bosnia a Herzegovina)',
        'si' => 'Sinhaleg',
        'si_LK' => 'Sinhaleg (Sri Lanka)',
        'sk' => 'Slofaceg',
        'sk_SK' => 'Slofaceg (Slofacia)',
        'sl' => 'Slofeneg',
        'sl_SI' => 'Slofeneg (Slofenia)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somaleg',
        'so_DJ' => 'Somaleg (Djibouti)',
        'so_ET' => 'Somaleg (Ethiopia)',
        'so_KE' => 'Somaleg (Kenya)',
        'so_SO' => 'Somaleg (Somalia)',
        'sq' => 'Albaneg',
        'sq_AL' => 'Albaneg (Albania)',
        'sq_MK' => 'Albaneg (Gogledd Macedonia)',
        'sr' => 'Serbeg',
        'sr_BA' => 'Serbeg (Bosnia a Herzegovina)',
        'sr_Cyrl' => 'Serbeg (Cyrilig)',
        'sr_Cyrl_BA' => 'Serbeg (Cyrilig, Bosnia a Herzegovina)',
        'sr_Cyrl_ME' => 'Serbeg (Cyrilig, Montenegro)',
        'sr_Cyrl_RS' => 'Serbeg (Cyrilig, Serbia)',
        'sr_Latn' => 'Serbeg (Lladin)',
        'sr_Latn_BA' => 'Serbeg (Lladin, Bosnia a Herzegovina)',
        'sr_Latn_ME' => 'Serbeg (Lladin, Montenegro)',
        'sr_Latn_RS' => 'Serbeg (Lladin, Serbia)',
        'sr_ME' => 'Serbeg (Montenegro)',
        'sr_RS' => 'Serbeg (Serbia)',
        'su' => 'Swndaneg',
        'su_ID' => 'Swndaneg (Indonesia)',
        'su_Latn' => 'Swndaneg (Lladin)',
        'su_Latn_ID' => 'Swndaneg (Lladin, Indonesia)',
        'sv' => 'Swedeg',
        'sv_AX' => 'Swedeg (Ynysoedd Åland)',
        'sv_FI' => 'Swedeg (Y Ffindir)',
        'sv_SE' => 'Swedeg (Sweden)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Y Congo - Kinshasa)',
        'sw_KE' => 'Swahili (Kenya)',
        'sw_TZ' => 'Swahili (Tanzania)',
        'sw_UG' => 'Swahili (Uganda)',
        'ta' => 'Tamileg',
        'ta_IN' => 'Tamileg (India)',
        'ta_LK' => 'Tamileg (Sri Lanka)',
        'ta_MY' => 'Tamileg (Malaysia)',
        'ta_SG' => 'Tamileg (Singapore)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tajiceg',
        'tg_TJ' => 'Tajiceg (Tajicistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Gwlad Thai)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Ethiopia)',
        'tk' => 'Tyrcmeneg',
        'tk_TM' => 'Tyrcmeneg (Tyrcmenistan)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (Y Philipinau)',
        'to' => 'Tongeg',
        'to_TO' => 'Tongeg (Tonga)',
        'tr' => 'Tyrceg',
        'tr_CY' => 'Tyrceg (Cyprus)',
        'tr_TR' => 'Tyrceg (Twrci)',
        'tt' => 'Tatareg',
        'tt_RU' => 'Tatareg (Rwsia)',
        'ug' => 'Uighur',
        'ug_CN' => 'Uighur (Tsieina)',
        'uk' => 'Wcreineg',
        'uk_UA' => 'Wcreineg (Wcráin)',
        'ur' => 'Wrdw',
        'ur_IN' => 'Wrdw (India)',
        'ur_PK' => 'Wrdw (Pakistan)',
        'uz' => 'Wsbeceg',
        'uz_AF' => 'Wsbeceg (Afghanistan)',
        'uz_Arab' => 'Wsbeceg (Arabaidd)',
        'uz_Arab_AF' => 'Wsbeceg (Arabaidd, Afghanistan)',
        'uz_Cyrl' => 'Wsbeceg (Cyrilig)',
        'uz_Cyrl_UZ' => 'Wsbeceg (Cyrilig, Uzbekistan)',
        'uz_Latn' => 'Wsbeceg (Lladin)',
        'uz_Latn_UZ' => 'Wsbeceg (Lladin, Uzbekistan)',
        'uz_UZ' => 'Wsbeceg (Uzbekistan)',
        'vi' => 'Fietnameg',
        'vi_VN' => 'Fietnameg (Fietnam)',
        'wo' => 'Woloff',
        'wo_SN' => 'Woloff (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (De Affrica)',
        'yi' => 'Iddew-Almaeneg',
        'yi_001' => 'Iddew-Almaeneg (Y Byd)',
        'yo' => 'Iorwba',
        'yo_BJ' => 'Iorwba (Benin)',
        'yo_NG' => 'Iorwba (Nigeria)',
        'zh' => 'Tsieinëeg',
        'zh_CN' => 'Tsieinëeg (Tsieina)',
        'zh_HK' => 'Tsieinëeg (Hong Kong SAR Tsieina)',
        'zh_Hans' => 'Tsieinëeg (Symledig)',
        'zh_Hans_CN' => 'Tsieinëeg (Symledig, Tsieina)',
        'zh_Hans_HK' => 'Tsieinëeg (Symledig, Hong Kong SAR Tsieina)',
        'zh_Hans_MO' => 'Tsieinëeg (Symledig, Macau SAR Tsieina)',
        'zh_Hans_SG' => 'Tsieinëeg (Symledig, Singapore)',
        'zh_Hant' => 'Tsieinëeg (Traddodiadol)',
        'zh_Hant_HK' => 'Tsieinëeg (Traddodiadol, Hong Kong SAR Tsieina)',
        'zh_Hant_MO' => 'Tsieinëeg (Traddodiadol, Macau SAR Tsieina)',
        'zh_Hant_TW' => 'Tsieinëeg (Traddodiadol, Taiwan)',
        'zh_MO' => 'Tsieinëeg (Macau SAR Tsieina)',
        'zh_SG' => 'Tsieinëeg (Singapore)',
        'zh_TW' => 'Tsieinëeg (Taiwan)',
        'zu' => 'Swlw',
        'zu_ZA' => 'Swlw (De Affrica)',
    ],
];
