<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwichtid (Abidjan)',
        'Africa/Accra' => 'Greenwichtid (Accra)',
        'Africa/Addis_Ababa' => 'östafrikansk tid (Addis Abeba)',
        'Africa/Algiers' => 'centraleuropeisk tid (Alger)',
        'Africa/Asmera' => 'östafrikansk tid (Asmara)',
        'Africa/Bamako' => 'Greenwichtid (Bamako)',
        'Africa/Bangui' => 'västafrikansk tid (Bangui)',
        'Africa/Banjul' => 'Greenwichtid (Banjul)',
        'Africa/Bissau' => 'Greenwichtid (Bissau)',
        'Africa/Blantyre' => 'centralafrikansk tid (Blantyre)',
        'Africa/Brazzaville' => 'västafrikansk tid (Brazzaville)',
        'Africa/Bujumbura' => 'centralafrikansk tid (Bujumbura)',
        'Africa/Cairo' => 'östeuropeisk tid (Kairo)',
        'Africa/Casablanca' => 'västeuropeisk tid (Casablanca)',
        'Africa/Ceuta' => 'centraleuropeisk tid (Ceuta)',
        'Africa/Conakry' => 'Greenwichtid (Conakry)',
        'Africa/Dakar' => 'Greenwichtid (Dakar)',
        'Africa/Dar_es_Salaam' => 'östafrikansk tid (Dar es-Salaam)',
        'Africa/Djibouti' => 'östafrikansk tid (Djibouti)',
        'Africa/Douala' => 'västafrikansk tid (Douala)',
        'Africa/El_Aaiun' => 'västeuropeisk tid (El-Aaiún)',
        'Africa/Freetown' => 'Greenwichtid (Freetown)',
        'Africa/Gaborone' => 'centralafrikansk tid (Gaborone)',
        'Africa/Harare' => 'centralafrikansk tid (Harare)',
        'Africa/Johannesburg' => 'sydafrikansk tid (Johannesburg)',
        'Africa/Juba' => 'centralafrikansk tid (Juba)',
        'Africa/Kampala' => 'östafrikansk tid (Kampala)',
        'Africa/Khartoum' => 'centralafrikansk tid (Khartoum)',
        'Africa/Kigali' => 'centralafrikansk tid (Kigali)',
        'Africa/Kinshasa' => 'västafrikansk tid (Kinshasa)',
        'Africa/Lagos' => 'västafrikansk tid (Lagos)',
        'Africa/Libreville' => 'västafrikansk tid (Libreville)',
        'Africa/Lome' => 'Greenwichtid (Lomé)',
        'Africa/Luanda' => 'västafrikansk tid (Luanda)',
        'Africa/Lubumbashi' => 'centralafrikansk tid (Lubumbashi)',
        'Africa/Lusaka' => 'centralafrikansk tid (Lusaka)',
        'Africa/Malabo' => 'västafrikansk tid (Malabo)',
        'Africa/Maputo' => 'centralafrikansk tid (Maputo)',
        'Africa/Maseru' => 'sydafrikansk tid (Maseru)',
        'Africa/Mbabane' => 'sydafrikansk tid (Mbabane)',
        'Africa/Mogadishu' => 'östafrikansk tid (Mogadishu)',
        'Africa/Monrovia' => 'Greenwichtid (Monrovia)',
        'Africa/Nairobi' => 'östafrikansk tid (Nairobi)',
        'Africa/Ndjamena' => 'västafrikansk tid (N’Djamena)',
        'Africa/Niamey' => 'västafrikansk tid (Niamey)',
        'Africa/Nouakchott' => 'Greenwichtid (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwichtid (Ouagadougou)',
        'Africa/Porto-Novo' => 'västafrikansk tid (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwichtid (São Tomé)',
        'Africa/Tripoli' => 'östeuropeisk tid (Tripoli)',
        'Africa/Tunis' => 'centraleuropeisk tid (Tunis)',
        'Africa/Windhoek' => 'centralafrikansk tid (Windhoek)',
        'America/Adak' => 'Honolulutid (Adak)',
        'America/Anchorage' => 'Alaskatid (Anchorage)',
        'America/Anguilla' => 'nordamerikansk atlanttid (Anguilla)',
        'America/Antigua' => 'nordamerikansk atlanttid (Antigua)',
        'America/Araguaina' => 'Brasiliatid (Araguaína)',
        'America/Argentina/La_Rioja' => 'östargentinsk tid (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'östargentinsk tid (Río Gallegos)',
        'America/Argentina/Salta' => 'östargentinsk tid (Salta)',
        'America/Argentina/San_Juan' => 'östargentinsk tid (San Juan)',
        'America/Argentina/San_Luis' => 'östargentinsk tid (San Luis)',
        'America/Argentina/Tucuman' => 'östargentinsk tid (Tucumán)',
        'America/Argentina/Ushuaia' => 'östargentinsk tid (Ushuaia)',
        'America/Aruba' => 'nordamerikansk atlanttid (Aruba)',
        'America/Asuncion' => 'paraguayansk tid (Asunción)',
        'America/Bahia' => 'Brasiliatid (Bahia)',
        'America/Bahia_Banderas' => 'centralnordamerikansk tid (Bahía de Banderas)',
        'America/Barbados' => 'nordamerikansk atlanttid (Barbados)',
        'America/Belem' => 'Brasiliatid (Belém)',
        'America/Belize' => 'centralnordamerikansk tid (Belize)',
        'America/Blanc-Sablon' => 'nordamerikansk atlanttid (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazonastid (Boa Vista)',
        'America/Bogota' => 'colombiansk tid (Bogotá)',
        'America/Boise' => 'Klippiga bergentid (Boise)',
        'America/Buenos_Aires' => 'östargentinsk tid (Buenos Aires)',
        'America/Cambridge_Bay' => 'Klippiga bergentid (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazonastid (Campo Grande)',
        'America/Cancun' => 'östnordamerikansk tid (Cancún)',
        'America/Caracas' => 'venezuelansk tid (Caracas)',
        'America/Catamarca' => 'östargentinsk tid (Catamarca)',
        'America/Cayenne' => 'Franska Guyanatid (Cayenne)',
        'America/Cayman' => 'östnordamerikansk tid (Caymanöarna)',
        'America/Chicago' => 'centralnordamerikansk tid (Chicago)',
        'America/Chihuahua' => 'mexikansk stillahavstid (Chihuahua)',
        'America/Coral_Harbour' => 'östnordamerikansk tid (Atikokan)',
        'America/Cordoba' => 'östargentinsk tid (Córdoba)',
        'America/Costa_Rica' => 'centralnordamerikansk tid (Costa Rica)',
        'America/Creston' => 'Klippiga bergentid (Creston)',
        'America/Cuiaba' => 'Amazonastid (Cuiabá)',
        'America/Curacao' => 'nordamerikansk atlanttid (Curaçao)',
        'America/Danmarkshavn' => 'Greenwichtid (Danmarkshavn)',
        'America/Dawson' => 'Yukontid (Dawson)',
        'America/Dawson_Creek' => 'Klippiga bergentid (Dawson Creek)',
        'America/Denver' => 'Klippiga bergentid (Denver)',
        'America/Detroit' => 'östnordamerikansk tid (Detroit)',
        'America/Dominica' => 'nordamerikansk atlanttid (Dominica)',
        'America/Edmonton' => 'Klippiga bergentid (Edmonton)',
        'America/Eirunepe' => 'västbrasiliansk tid (Eirunepé)',
        'America/El_Salvador' => 'centralnordamerikansk tid (El Salvador)',
        'America/Fort_Nelson' => 'Klippiga bergentid (Fort Nelson)',
        'America/Fortaleza' => 'Brasiliatid (Fortaleza)',
        'America/Glace_Bay' => 'nordamerikansk atlanttid (Glace Bay)',
        'America/Godthab' => 'västgrönländsk tid (Nuuk)',
        'America/Goose_Bay' => 'nordamerikansk atlanttid (Goose Bay)',
        'America/Grand_Turk' => 'östnordamerikansk tid (Grand Turk)',
        'America/Grenada' => 'nordamerikansk atlanttid (Grenada)',
        'America/Guadeloupe' => 'nordamerikansk atlanttid (Guadeloupe)',
        'America/Guatemala' => 'centralnordamerikansk tid (Guatemala)',
        'America/Guayaquil' => 'ecuadoriansk tid (Guayaquil)',
        'America/Guyana' => 'Guyanatid',
        'America/Halifax' => 'nordamerikansk atlanttid (Halifax)',
        'America/Havana' => 'kubansk tid (Havanna)',
        'America/Hermosillo' => 'mexikansk stillahavstid (Hermosillo)',
        'America/Indiana/Knox' => 'centralnordamerikansk tid (Knox, Indiana)',
        'America/Indiana/Marengo' => 'östnordamerikansk tid (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'östnordamerikansk tid (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'centralnordamerikansk tid (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'östnordamerikansk tid (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'östnordamerikansk tid (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'östnordamerikansk tid (Winamac, Indiana)',
        'America/Indianapolis' => 'östnordamerikansk tid (Indianapolis)',
        'America/Inuvik' => 'Klippiga bergentid (Inuvik)',
        'America/Iqaluit' => 'östnordamerikansk tid (Iqaluit)',
        'America/Jamaica' => 'östnordamerikansk tid (Jamaica)',
        'America/Jujuy' => 'östargentinsk tid (San Salvador de Jujuy)',
        'America/Juneau' => 'Alaskatid (Juneau)',
        'America/Kentucky/Monticello' => 'östnordamerikansk tid (Monticello, Kentucky)',
        'America/Kralendijk' => 'nordamerikansk atlanttid (Kralendijk)',
        'America/La_Paz' => 'boliviansk tid (La Paz)',
        'America/Lima' => 'peruansk tid (Lima)',
        'America/Los_Angeles' => 'västnordamerikansk tid (Los Angeles)',
        'America/Louisville' => 'östnordamerikansk tid (Louisville)',
        'America/Lower_Princes' => 'nordamerikansk atlanttid (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasiliatid (Maceió)',
        'America/Managua' => 'centralnordamerikansk tid (Managua)',
        'America/Manaus' => 'Amazonastid (Manaus)',
        'America/Marigot' => 'nordamerikansk atlanttid (Marigot)',
        'America/Martinique' => 'nordamerikansk atlanttid (Martinique)',
        'America/Matamoros' => 'centralnordamerikansk tid (Matamoros)',
        'America/Mazatlan' => 'mexikansk stillahavstid (Mazatlán)',
        'America/Mendoza' => 'östargentinsk tid (Mendoza)',
        'America/Menominee' => 'centralnordamerikansk tid (Menominee)',
        'America/Merida' => 'centralnordamerikansk tid (Mérida)',
        'America/Metlakatla' => 'Alaskatid (Metlakatla)',
        'America/Mexico_City' => 'centralnordamerikansk tid (Mexiko City)',
        'America/Miquelon' => 'S:t Pierre och Miquelontid',
        'America/Moncton' => 'nordamerikansk atlanttid (Moncton)',
        'America/Monterrey' => 'centralnordamerikansk tid (Monterrey)',
        'America/Montevideo' => 'uruguayansk tid (Montevideo)',
        'America/Montreal' => 'Kanadatid (Montreal)',
        'America/Montserrat' => 'nordamerikansk atlanttid (Montserrat)',
        'America/Nassau' => 'östnordamerikansk tid (Nassau)',
        'America/New_York' => 'östnordamerikansk tid (New York)',
        'America/Nipigon' => 'östnordamerikansk tid (Nipigon)',
        'America/Nome' => 'Alaskatid (Nome)',
        'America/Noronha' => 'Fernando de Noronhatid',
        'America/North_Dakota/Beulah' => 'centralnordamerikansk tid (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'centralnordamerikansk tid (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'centralnordamerikansk tid (New Salem, North Dakota)',
        'America/Ojinaga' => 'Klippiga bergentid (Ojinaga)',
        'America/Panama' => 'östnordamerikansk tid (Panama)',
        'America/Pangnirtung' => 'östnordamerikansk tid (Pangnirtung)',
        'America/Paramaribo' => 'Surinamtid (Paramaribo)',
        'America/Phoenix' => 'Klippiga bergentid (Phoenix)',
        'America/Port-au-Prince' => 'östnordamerikansk tid (Port-au-Prince)',
        'America/Port_of_Spain' => 'nordamerikansk atlanttid (Port of Spain)',
        'America/Porto_Velho' => 'Amazonastid (Porto Velho)',
        'America/Puerto_Rico' => 'nordamerikansk atlanttid (Puerto Rico)',
        'America/Punta_Arenas' => 'chilensk tid (Punta Arenas)',
        'America/Rainy_River' => 'centralnordamerikansk tid (Rainy River)',
        'America/Rankin_Inlet' => 'centralnordamerikansk tid (Rankin Inlet)',
        'America/Recife' => 'Brasiliatid (Recife)',
        'America/Regina' => 'centralnordamerikansk tid (Regina)',
        'America/Resolute' => 'centralnordamerikansk tid (Resolute)',
        'America/Rio_Branco' => 'västbrasiliansk tid (Rio Branco)',
        'America/Santa_Isabel' => 'nordvästmexikansk tid (Santa Isabel)',
        'America/Santarem' => 'Brasiliatid (Santarém)',
        'America/Santiago' => 'chilensk tid (Santiago)',
        'America/Santo_Domingo' => 'nordamerikansk atlanttid (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasiliatid (São Paulo)',
        'America/Scoresbysund' => 'östgrönländsk tid (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaskatid (Sitka)',
        'America/St_Barthelemy' => 'nordamerikansk atlanttid (S:t Barthélemy)',
        'America/St_Johns' => 'Newfoundlandtid (S:t Johns)',
        'America/St_Kitts' => 'nordamerikansk atlanttid (S:t Kitts)',
        'America/St_Lucia' => 'nordamerikansk atlanttid (S:t Lucia)',
        'America/St_Thomas' => 'nordamerikansk atlanttid (S:t Thomas)',
        'America/St_Vincent' => 'nordamerikansk atlanttid (S:t Vincent)',
        'America/Swift_Current' => 'centralnordamerikansk tid (Swift Current)',
        'America/Tegucigalpa' => 'centralnordamerikansk tid (Tegucigalpa)',
        'America/Thule' => 'nordamerikansk atlanttid (Qaanaaq)',
        'America/Thunder_Bay' => 'östnordamerikansk tid (Thunder Bay)',
        'America/Tijuana' => 'västnordamerikansk tid (Tijuana)',
        'America/Toronto' => 'östnordamerikansk tid (Toronto)',
        'America/Tortola' => 'nordamerikansk atlanttid (Tortola)',
        'America/Vancouver' => 'västnordamerikansk tid (Vancouver)',
        'America/Whitehorse' => 'Yukontid (Whitehorse)',
        'America/Winnipeg' => 'centralnordamerikansk tid (Winnipeg)',
        'America/Yakutat' => 'Alaskatid (Yakutat)',
        'America/Yellowknife' => 'Klippiga bergentid (Yellowknife)',
        'Antarctica/Casey' => 'Caseytid',
        'Antarctica/Davis' => 'Davistid',
        'Antarctica/DumontDUrville' => 'Dumont d’Urville-tid',
        'Antarctica/Macquarie' => 'östaustralisk tid (Macquarie)',
        'Antarctica/Mawson' => 'Mawsontid',
        'Antarctica/McMurdo' => 'nyzeeländsk tid (McMurdo)',
        'Antarctica/Palmer' => 'chilensk tid (Palmer)',
        'Antarctica/Rothera' => 'Rotheratid',
        'Antarctica/Syowa' => 'Syowatid',
        'Antarctica/Troll' => 'Greenwichtid (Troll)',
        'Antarctica/Vostok' => 'Vostoktid',
        'Arctic/Longyearbyen' => 'centraleuropeisk tid (Longyearbyen)',
        'Asia/Aden' => 'saudiarabisk tid (Aden)',
        'Asia/Almaty' => 'östkazakstansk tid (Almaty)',
        'Asia/Amman' => 'östeuropeisk tid (Amman)',
        'Asia/Anadyr' => 'Anadyrtid',
        'Asia/Aqtau' => 'västkazakstansk tid (Aktau)',
        'Asia/Aqtobe' => 'västkazakstansk tid (Aqtöbe)',
        'Asia/Ashgabat' => 'turkmensk tid (Asjchabad)',
        'Asia/Atyrau' => 'västkazakstansk tid (Atyrau)',
        'Asia/Baghdad' => 'saudiarabisk tid (Bagdad)',
        'Asia/Bahrain' => 'saudiarabisk tid (Bahrain)',
        'Asia/Baku' => 'azerbajdzjansk tid (Baku)',
        'Asia/Bangkok' => 'indokinesisk tid (Bangkok)',
        'Asia/Barnaul' => 'Rysslandtid (Barnaul)',
        'Asia/Beirut' => 'östeuropeisk tid (Beirut)',
        'Asia/Bishkek' => 'kirgizisk tid (Bisjkek)',
        'Asia/Brunei' => 'Bruneitid',
        'Asia/Calcutta' => 'indisk tid (Kolkata)',
        'Asia/Chita' => 'Jakutsktid (Tjita)',
        'Asia/Choibalsan' => 'Ulaanbaatartid (Tjojbalsan)',
        'Asia/Colombo' => 'indisk tid (Colombo)',
        'Asia/Damascus' => 'östeuropeisk tid (Damaskus)',
        'Asia/Dhaka' => 'bangladeshisk tid (Dhaka)',
        'Asia/Dili' => 'östtimorisk tid (Dili)',
        'Asia/Dubai' => 'Persiska vikentid (Dubai)',
        'Asia/Dushanbe' => 'Tadzjikistantid (Dusjanbe)',
        'Asia/Famagusta' => 'östeuropeisk tid (Famagusta)',
        'Asia/Gaza' => 'östeuropeisk tid (Gaza)',
        'Asia/Hebron' => 'östeuropeisk tid (Hebron)',
        'Asia/Hong_Kong' => 'Hongkongtid',
        'Asia/Hovd' => 'Chovdtid',
        'Asia/Irkutsk' => 'Irkutsktid',
        'Asia/Jakarta' => 'västindonesisk tid (Jakarta)',
        'Asia/Jayapura' => 'östindonesisk tid (Jayapura)',
        'Asia/Jerusalem' => 'israelisk tid (Jerusalem)',
        'Asia/Kabul' => 'afghansk tid (Kabul)',
        'Asia/Kamchatka' => 'Kamtjatkatid',
        'Asia/Karachi' => 'pakistansk tid (Karachi)',
        'Asia/Katmandu' => 'nepalesisk tid (Katmandu)',
        'Asia/Khandyga' => 'Jakutsktid (Chandyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsktid',
        'Asia/Kuala_Lumpur' => 'malaysisk tid (Kuala Lumpur)',
        'Asia/Kuching' => 'malaysisk tid (Kuching)',
        'Asia/Kuwait' => 'saudiarabisk tid (Kuwait)',
        'Asia/Macau' => 'kinesisk tid (Macao)',
        'Asia/Magadan' => 'Magadantid',
        'Asia/Makassar' => 'centralindonesisk tid (Makassar)',
        'Asia/Manila' => 'filippinsk tid (Manilla)',
        'Asia/Muscat' => 'Persiska vikentid (Muskat)',
        'Asia/Nicosia' => 'östeuropeisk tid (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnojarsktid (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Novosibirsktid',
        'Asia/Omsk' => 'Omsktid',
        'Asia/Oral' => 'västkazakstansk tid (Oral)',
        'Asia/Phnom_Penh' => 'indokinesisk tid (Phnom Penh)',
        'Asia/Pontianak' => 'västindonesisk tid (Pontianak)',
        'Asia/Pyongyang' => 'koreansk tid (Pyongyang)',
        'Asia/Qatar' => 'saudiarabisk tid (Qatar)',
        'Asia/Qostanay' => 'östkazakstansk tid (Kostanaj)',
        'Asia/Qyzylorda' => 'västkazakstansk tid (Qyzylorda)',
        'Asia/Rangoon' => 'burmesisk tid (Rangoon)',
        'Asia/Riyadh' => 'saudiarabisk tid (Riyadh)',
        'Asia/Saigon' => 'indokinesisk tid (Ho Chi Minh-staden)',
        'Asia/Sakhalin' => 'Sachalintid',
        'Asia/Samarkand' => 'uzbekisk tid (Samarkand)',
        'Asia/Seoul' => 'koreansk tid (Söul)',
        'Asia/Shanghai' => 'kinesisk tid (Shanghai)',
        'Asia/Singapore' => 'Singaporetid',
        'Asia/Srednekolymsk' => 'Magadantid (Srednekolymsk)',
        'Asia/Taipei' => 'Taipeitid',
        'Asia/Tashkent' => 'uzbekisk tid (Tasjkent)',
        'Asia/Tbilisi' => 'georgisk tid (Tbilisi)',
        'Asia/Tehran' => 'iransk tid (Teheran)',
        'Asia/Thimphu' => 'bhutansk tid (Thimphu)',
        'Asia/Tokyo' => 'japansk tid (Tokyo)',
        'Asia/Tomsk' => 'Rysslandtid (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatartid',
        'Asia/Urumqi' => 'Kinatid (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostoktid (Ust-Nera)',
        'Asia/Vientiane' => 'indokinesisk tid (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostoktid',
        'Asia/Yakutsk' => 'Jakutsktid',
        'Asia/Yekaterinburg' => 'Jekaterinburgtid',
        'Asia/Yerevan' => 'armenisk tid (Jerevan)',
        'Atlantic/Azores' => 'azorisk tid (Azorerna)',
        'Atlantic/Bermuda' => 'nordamerikansk atlanttid (Bermuda)',
        'Atlantic/Canary' => 'västeuropeisk tid (Kanarieöarna)',
        'Atlantic/Cape_Verde' => 'Kap Verdetid',
        'Atlantic/Faeroe' => 'västeuropeisk tid (Torshamn)',
        'Atlantic/Madeira' => 'västeuropeisk tid (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwichtid (Reykjavik)',
        'Atlantic/South_Georgia' => 'sydgeorgisk tid (Sydgeorgien)',
        'Atlantic/St_Helena' => 'Greenwichtid (S:t Helena)',
        'Atlantic/Stanley' => 'Falklandsöarnas tid (Stanley)',
        'Australia/Adelaide' => 'centralaustralisk tid (Adelaide)',
        'Australia/Brisbane' => 'östaustralisk tid (Brisbane)',
        'Australia/Broken_Hill' => 'centralaustralisk tid (Broken Hill)',
        'Australia/Currie' => 'östaustralisk tid (Currie)',
        'Australia/Darwin' => 'centralaustralisk tid (Darwin)',
        'Australia/Eucla' => 'västcentralaustralisk tid (Eucla)',
        'Australia/Hobart' => 'östaustralisk tid (Hobart)',
        'Australia/Lindeman' => 'östaustralisk tid (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howetid',
        'Australia/Melbourne' => 'östaustralisk tid (Melbourne)',
        'Australia/Perth' => 'västaustralisk tid (Perth)',
        'Australia/Sydney' => 'östaustralisk tid (Sydney)',
        'CST6CDT' => 'centralnordamerikansk tid',
        'EST5EDT' => 'östnordamerikansk tid',
        'Etc/GMT' => 'Greenwichtid',
        'Etc/UTC' => 'koordinerad universell tid',
        'Europe/Amsterdam' => 'centraleuropeisk tid (Amsterdam)',
        'Europe/Andorra' => 'centraleuropeisk tid (Andorra)',
        'Europe/Astrakhan' => 'Moskvatid (Astrakhan)',
        'Europe/Athens' => 'östeuropeisk tid (Aten)',
        'Europe/Belgrade' => 'centraleuropeisk tid (Belgrad)',
        'Europe/Berlin' => 'centraleuropeisk tid (Berlin)',
        'Europe/Bratislava' => 'centraleuropeisk tid (Bratislava)',
        'Europe/Brussels' => 'centraleuropeisk tid (Bryssel)',
        'Europe/Bucharest' => 'östeuropeisk tid (Bukarest)',
        'Europe/Budapest' => 'centraleuropeisk tid (Budapest)',
        'Europe/Busingen' => 'centraleuropeisk tid (Büsingen am Hochrhein)',
        'Europe/Chisinau' => 'östeuropeisk tid (Chișinău)',
        'Europe/Copenhagen' => 'centraleuropeisk tid (Köpenhamn)',
        'Europe/Dublin' => 'Greenwichtid (Dublin)',
        'Europe/Gibraltar' => 'centraleuropeisk tid (Gibraltar)',
        'Europe/Guernsey' => 'Greenwichtid (Guernsey)',
        'Europe/Helsinki' => 'östeuropeisk tid (Helsingfors)',
        'Europe/Isle_of_Man' => 'Greenwichtid (Isle of Man)',
        'Europe/Istanbul' => 'Turkiettid (Istanbul)',
        'Europe/Jersey' => 'Greenwichtid (Jersey)',
        'Europe/Kaliningrad' => 'östeuropeisk tid (Kaliningrad)',
        'Europe/Kiev' => 'östeuropeisk tid (Kiev)',
        'Europe/Kirov' => 'Rysslandtid (Kirov)',
        'Europe/Lisbon' => 'västeuropeisk tid (Lissabon)',
        'Europe/Ljubljana' => 'centraleuropeisk tid (Ljubljana)',
        'Europe/London' => 'Greenwichtid (London)',
        'Europe/Luxembourg' => 'centraleuropeisk tid (Luxemburg)',
        'Europe/Madrid' => 'centraleuropeisk tid (Madrid)',
        'Europe/Malta' => 'centraleuropeisk tid (Malta)',
        'Europe/Mariehamn' => 'östeuropeisk tid (Mariehamn)',
        'Europe/Minsk' => 'Moskvatid (Minsk)',
        'Europe/Monaco' => 'centraleuropeisk tid (Monaco)',
        'Europe/Moscow' => 'Moskvatid',
        'Europe/Oslo' => 'centraleuropeisk tid (Oslo)',
        'Europe/Paris' => 'centraleuropeisk tid (Paris)',
        'Europe/Podgorica' => 'centraleuropeisk tid (Podgorica)',
        'Europe/Prague' => 'centraleuropeisk tid (Prag)',
        'Europe/Riga' => 'östeuropeisk tid (Riga)',
        'Europe/Rome' => 'centraleuropeisk tid (Rom)',
        'Europe/Samara' => 'Samaratid',
        'Europe/San_Marino' => 'centraleuropeisk tid (San Marino)',
        'Europe/Sarajevo' => 'centraleuropeisk tid (Sarajevo)',
        'Europe/Saratov' => 'Moskvatid (Saratov)',
        'Europe/Simferopol' => 'Moskvatid (Simferopol)',
        'Europe/Skopje' => 'centraleuropeisk tid (Skopje)',
        'Europe/Sofia' => 'östeuropeisk tid (Sofia)',
        'Europe/Stockholm' => 'centraleuropeisk tid (Stockholm)',
        'Europe/Tallinn' => 'östeuropeisk tid (Tallinn)',
        'Europe/Tirane' => 'centraleuropeisk tid (Tirana)',
        'Europe/Ulyanovsk' => 'Moskvatid (Uljanovsk)',
        'Europe/Uzhgorod' => 'östeuropeisk tid (Uzjhorod)',
        'Europe/Vaduz' => 'centraleuropeisk tid (Vaduz)',
        'Europe/Vatican' => 'centraleuropeisk tid (Vatikanen)',
        'Europe/Vienna' => 'centraleuropeisk tid (Wien)',
        'Europe/Vilnius' => 'östeuropeisk tid (Vilnius)',
        'Europe/Volgograd' => 'Volgogradtid',
        'Europe/Warsaw' => 'centraleuropeisk tid (Warszawa)',
        'Europe/Zagreb' => 'centraleuropeisk tid (Zagreb)',
        'Europe/Zaporozhye' => 'östeuropeisk tid (Zaporizjzja)',
        'Europe/Zurich' => 'centraleuropeisk tid (Zürich)',
        'Indian/Antananarivo' => 'östafrikansk tid (Antananarivo)',
        'Indian/Chagos' => 'Brittiska Indiska oceanöarnas tid (Chagosöarna)',
        'Indian/Christmas' => 'Julöns tid',
        'Indian/Cocos' => 'Keelingöarnas tid (Kokosöarna)',
        'Indian/Comoro' => 'östafrikansk tid (Komorerna)',
        'Indian/Kerguelen' => 'Franska Sydterritoriernas tid (Kerguelenöarna)',
        'Indian/Mahe' => 'Seychellernatid (Mahé)',
        'Indian/Maldives' => 'Maldivernatid',
        'Indian/Mauritius' => 'Mauritiustid',
        'Indian/Mayotte' => 'östafrikansk tid (Mayotte)',
        'Indian/Reunion' => 'Réuniontid',
        'MST7MDT' => 'Klippiga bergentid',
        'PST8PDT' => 'västnordamerikansk tid',
        'Pacific/Apia' => 'Apiatid',
        'Pacific/Auckland' => 'nyzeeländsk tid (Auckland)',
        'Pacific/Bougainville' => 'Papua Nya Guineas tid (Bougainville)',
        'Pacific/Chatham' => 'Chathamtid',
        'Pacific/Easter' => 'Påskötid (Påskön)',
        'Pacific/Efate' => 'Vanuatutid (Efate)',
        'Pacific/Enderbury' => 'Enderburytid',
        'Pacific/Fakaofo' => 'Tokelautid (Fakaofo)',
        'Pacific/Fiji' => 'Fijitid',
        'Pacific/Funafuti' => 'Tuvalutid (Funafuti)',
        'Pacific/Galapagos' => 'Galápagostid',
        'Pacific/Gambier' => 'Gambiertid (Gambieröarna)',
        'Pacific/Guadalcanal' => 'Salomonöarnas tid (Guadalcanal)',
        'Pacific/Guam' => 'Chamorrotid (Guam)',
        'Pacific/Honolulu' => 'Honolulutid',
        'Pacific/Johnston' => 'Honolulutid (Johnstonatollen)',
        'Pacific/Kiritimati' => 'Lineöarnas tid (Kiritimati)',
        'Pacific/Kosrae' => 'Kosraetid',
        'Pacific/Kwajalein' => 'Marshallöarnas tid (Kwajalein)',
        'Pacific/Majuro' => 'Marshallöarnas tid (Majuro)',
        'Pacific/Marquesas' => 'Marquesastid (Marquesasöarna)',
        'Pacific/Midway' => 'samoansk tid (Midwayöarna)',
        'Pacific/Nauru' => 'Naurutid',
        'Pacific/Niue' => 'Niuetid',
        'Pacific/Norfolk' => 'Norfolköns tid',
        'Pacific/Noumea' => 'Nya Kaledonientid (Nouméa)',
        'Pacific/Pago_Pago' => 'samoansk tid (Pago Pago)',
        'Pacific/Palau' => 'Palautid',
        'Pacific/Pitcairn' => 'Pitcairntid (Pitcairnöarna)',
        'Pacific/Ponape' => 'Ponapetid (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua Nya Guineas tid (Port Moresby)',
        'Pacific/Rarotonga' => 'Cooköarnas tid (Rarotonga)',
        'Pacific/Saipan' => 'Chamorrotid (Saipan)',
        'Pacific/Tahiti' => 'Tahititid',
        'Pacific/Tarawa' => 'Kiribatitid (Tarawa)',
        'Pacific/Tongatapu' => 'Tongatid (Tongatapu)',
        'Pacific/Truk' => 'Chuuktid',
        'Pacific/Wake' => 'Wakeöarnas tid',
        'Pacific/Wallis' => 'Wallis- och Futunaöarnas tid (Wallisön)',
    ],
    'Meta' => [
        'HourFormatNeg' => '−%02d:%02d',
    ],
];
