<?php

return [
    'Names' => [
        'af' => 'اَفریٖکانز',
        'af_NA' => 'اَفریٖکانز (نامِبِیا)',
        'af_ZA' => 'اَفریٖکانز (جنوبی افریقہ)',
        'ak' => 'اَکان',
        'ak_GH' => 'اَکان (گانا)',
        'am' => 'اَمہاری',
        'am_ET' => 'اَمہاری (اِتھوپِیا)',
        'ar' => 'عربی',
        'ar_001' => 'عربی (دُنیا)',
        'ar_AE' => 'عربی (مُتحدہ عرَب امارات)',
        'ar_BH' => 'عربی (بحریٖن)',
        'ar_DJ' => 'عربی (جِبوٗتی)',
        'ar_DZ' => 'عربی (اؠلجیرِیا)',
        'ar_EG' => 'عربی (مصر)',
        'ar_EH' => 'عربی (مشرِقی سَہارا)',
        'ar_ER' => 'عربی (اِرٕٹِیا)',
        'ar_IL' => 'عربی (اسرا ییل)',
        'ar_IQ' => 'عربی (ایٖراق)',
        'ar_JO' => 'عربی (جورڈن)',
        'ar_KM' => 'عربی (کَمورَس)',
        'ar_KW' => 'عربی (کُویت)',
        'ar_LB' => 'عربی (لؠبنان)',
        'ar_LY' => 'عربی (لِبیا)',
        'ar_MA' => 'عربی (موروکو)',
        'ar_MR' => 'عربی (مارٕٹانِیا)',
        'ar_OM' => 'عربی (اومان)',
        'ar_PS' => 'عربی (فلسطینی علاقٕہ)',
        'ar_QA' => 'عربی (قَطِر)',
        'ar_SA' => 'عربی (سعودی عرب)',
        'ar_SD' => 'عربی (سوٗڈان)',
        'ar_SO' => 'عربی (سومالِیا)',
        'ar_SS' => 'عربی (جنوبی سوڈان)',
        'ar_SY' => 'عربی (شام)',
        'ar_TD' => 'عربی (چاڑ)',
        'ar_TN' => 'عربی (ٹونیشِیا)',
        'ar_YE' => 'عربی (یَمَن)',
        'as' => 'اسٲمۍ',
        'as_IN' => 'اسٲمۍ (ہِندوستان)',
        'az' => 'اَزَربیجانی',
        'az_AZ' => 'اَزَربیجانی (آذربائیجان)',
        'az_Cyrl' => 'اَزَربیجانی (سَیرِلِک)',
        'az_Cyrl_AZ' => 'اَزَربیجانی (سَیرِلِک, آذربائیجان)',
        'az_Latn' => 'اَزَربیجانی (لاطیٖنی)',
        'az_Latn_AZ' => 'اَزَربیجانی (لاطیٖنی, آذربائیجان)',
        'be' => 'بیلَروٗشیَن',
        'be_BY' => 'بیلَروٗشیَن (بیلاروٗس)',
        'bg' => 'بینا',
        'bg_BG' => 'بینا (بَلجیرِیا)',
        'bm' => 'بَمبارا',
        'bm_ML' => 'بَمبارا (مالی)',
        'bn' => 'بَنگٲلۍ',
        'bn_BD' => 'بَنگٲلۍ (بَنگلادیش)',
        'bn_IN' => 'بَنگٲلۍ (ہِندوستان)',
        'bo' => 'تِبتی',
        'bo_CN' => 'تِبتی (چیٖن)',
        'bo_IN' => 'تِبتی (ہِندوستان)',
        'br' => 'بریٹَن',
        'br_FR' => 'بریٹَن (فرانس)',
        'bs' => 'بوسنِیَن',
        'bs_BA' => 'بوسنِیَن (بوسنِیا تہٕ ہَرزِگووِنا)',
        'bs_Cyrl' => 'بوسنِیَن (سَیرِلِک)',
        'bs_Cyrl_BA' => 'بوسنِیَن (سَیرِلِک, بوسنِیا تہٕ ہَرزِگووِنا)',
        'bs_Latn' => 'بوسنِیَن (لاطیٖنی)',
        'bs_Latn_BA' => 'بوسنِیَن (لاطیٖنی, بوسنِیا تہٕ ہَرزِگووِنا)',
        'ca' => 'کَتلان',
        'ca_AD' => 'کَتلان (اینڈورا)',
        'ca_ES' => 'کَتلان (سٕپین)',
        'ca_FR' => 'کَتلان (فرانس)',
        'ca_IT' => 'کَتلان (اِٹلی)',
        'ce' => 'چیچَن',
        'ce_RU' => 'چیچَن (روٗس)',
        'cs' => 'چیک',
        'cs_CZ' => 'چیک (چیکیا)',
        'cv' => 'چُواش',
        'cv_RU' => 'چُواش (روٗس)',
        'cy' => 'ویلش',
        'cy_GB' => 'ویلش (متحدہ مملِکت)',
        'da' => 'ڈینِش',
        'da_DK' => 'ڈینِش (ڈینمارٕک)',
        'da_GL' => 'ڈینِش (گرین لینڈ)',
        'de' => 'جٔرمَن',
        'de_AT' => 'جٔرمَن (آسٹریا)',
        'de_BE' => 'جٔرمَن (بیلجِیَم)',
        'de_CH' => 'جٔرمَن (سُوِزَرلینڑ)',
        'de_DE' => 'جٔرمَن (جرمٔنی)',
        'de_IT' => 'جٔرمَن (اِٹلی)',
        'de_LI' => 'جٔرمَن (لِکٹیسٹیٖن)',
        'de_LU' => 'جٔرمَن (لَکسَمبٔرٕگ)',
        'dz' => 'زونگکھا',
        'dz_BT' => 'زونگکھا (بوٗٹان)',
        'ee' => 'ایٖو',
        'ee_GH' => 'ایٖو (گانا)',
        'ee_TG' => 'ایٖو (ٹوگو)',
        'el' => 'یوٗنٲنی',
        'el_CY' => 'یوٗنٲنی (سائپرس)',
        'el_GR' => 'یوٗنٲنی (گریٖس)',
        'en' => 'اَنگیٖزۍ',
        'en_001' => 'اَنگیٖزۍ (دُنیا)',
        'en_150' => 'اَنگیٖزۍ (یوٗرَپ)',
        'en_AE' => 'اَنگیٖزۍ (مُتحدہ عرَب امارات)',
        'en_AG' => 'اَنگیٖزۍ (اؠنٹِگُوا تہٕ باربوڑا)',
        'en_AI' => 'اَنگیٖزۍ (انگوئیلا)',
        'en_AS' => 'اَنگیٖزۍ (اَمریٖکَن سَموا)',
        'en_AT' => 'اَنگیٖزۍ (آسٹریا)',
        'en_AU' => 'اَنگیٖزۍ (آسٹریلِیا)',
        'en_BB' => 'اَنگیٖزۍ (باربیڈوس)',
        'en_BE' => 'اَنگیٖزۍ (بیلجِیَم)',
        'en_BI' => 'اَنگیٖزۍ (بورَنڈِ)',
        'en_BM' => 'اَنگیٖزۍ (برمودا)',
        'en_BS' => 'اَنگیٖزۍ (بَہامَس)',
        'en_BW' => 'اَنگیٖزۍ (بوتَسوانا)',
        'en_BZ' => 'اَنگیٖزۍ (بیلز)',
        'en_CA' => 'اَنگیٖزۍ (کینیڈا)',
        'en_CC' => 'اَنگیٖزۍ (کوکَس [کیٖلِنگ] جٔزیٖرٕ)',
        'en_CH' => 'اَنگیٖزۍ (سُوِزَرلینڑ)',
        'en_CK' => 'اَنگیٖزۍ (کُک جٔزیٖرٕ)',
        'en_CM' => 'اَنگیٖزۍ (کیمِروٗن)',
        'en_CX' => 'اَنگیٖزۍ (کرِسمَس جٔزیٖرٕ)',
        'en_CY' => 'اَنگیٖزۍ (سائپرس)',
        'en_DE' => 'اَنگیٖزۍ (جرمٔنی)',
        'en_DK' => 'اَنگیٖزۍ (ڈینمارٕک)',
        'en_DM' => 'اَنگیٖزۍ (ڈومِنِکا)',
        'en_ER' => 'اَنگیٖزۍ (اِرٕٹِیا)',
        'en_FI' => 'اَنگیٖزۍ (فِن لینڈ)',
        'en_FJ' => 'اَنگیٖزۍ (فِجی)',
        'en_FK' => 'اَنگیٖزۍ (فٕلاکلینڑ جٔزیٖرٕ)',
        'en_FM' => 'اَنگیٖزۍ (مائیکرونیشیا)',
        'en_GB' => 'اَنگیٖزۍ (متحدہ مملِکت)',
        'en_GD' => 'اَنگیٖزۍ (گرینیڈا)',
        'en_GG' => 'اَنگیٖزۍ (گورنسے)',
        'en_GH' => 'اَنگیٖزۍ (گانا)',
        'en_GI' => 'اَنگیٖزۍ (جِبرالٹَر)',
        'en_GM' => 'اَنگیٖزۍ (گَمبِیا)',
        'en_GU' => 'اَنگیٖزۍ (گُوام)',
        'en_GY' => 'اَنگیٖزۍ (گُیانا)',
        'en_HK' => 'اَنگیٖزۍ (ہانگ کانگ ایس اے آر چیٖن)',
        'en_IE' => 'اَنگیٖزۍ (اَیَرلینڑ)',
        'en_IL' => 'اَنگیٖزۍ (اسرا ییل)',
        'en_IM' => 'اَنگیٖزۍ (آیِل آف مین)',
        'en_IN' => 'اَنگیٖزۍ (ہِندوستان)',
        'en_IO' => 'اَنگیٖزۍ (برطانوی بحرِ ہِندۍ علاقہٕ)',
        'en_JE' => 'اَنگیٖزۍ (جٔرسی)',
        'en_JM' => 'اَنگیٖزۍ (جَمایکا)',
        'en_KE' => 'اَنگیٖزۍ (کِنیا)',
        'en_KI' => 'اَنگیٖزۍ (کِرٕباتی)',
        'en_KN' => 'اَنگیٖزۍ (سینٹ کِٹَس تہٕ نیوِس)',
        'en_KY' => 'اَنگیٖزۍ (کیمَن جٔزیٖرٕ)',
        'en_LC' => 'اَنگیٖزۍ (سینٹ لوٗسِیا)',
        'en_LR' => 'اَنگیٖزۍ (لایبیرِیا)',
        'en_LS' => 'اَنگیٖزۍ (لیسوتھو)',
        'en_MG' => 'اَنگیٖزۍ (میڈاگاسکار)',
        'en_MH' => 'اَنگیٖزۍ (مارشَل جٔزیٖرٕ)',
        'en_MO' => 'اَنگیٖزۍ (مَکاوو ایس اے آر چیٖن)',
        'en_MP' => 'اَنگیٖزۍ (شُمٲلی مارِیانا جٔزیٖرٕ)',
        'en_MS' => 'اَنگیٖزۍ (مانٹسیراٹ)',
        'en_MT' => 'اَنگیٖزۍ (مالٹا)',
        'en_MU' => 'اَنگیٖزۍ (مورِشَس)',
        'en_MV' => 'اَنگیٖزۍ (مالدیٖو)',
        'en_MW' => 'اَنگیٖزۍ (ملاوی)',
        'en_MY' => 'اَنگیٖزۍ (مَلیشِیا)',
        'en_NA' => 'اَنگیٖزۍ (نامِبِیا)',
        'en_NF' => 'اَنگیٖزۍ (نارفاک جٔزیٖرٕ)',
        'en_NG' => 'اَنگیٖزۍ (نایجیرِیا)',
        'en_NL' => 'اَنگیٖزۍ (نیٖدَرلینڑ)',
        'en_NR' => 'اَنگیٖزۍ (نارووٗ)',
        'en_NU' => 'اَنگیٖزۍ (نیوٗ)',
        'en_NZ' => 'اَنگیٖزۍ (نیوزی لینڈ)',
        'en_PG' => 'اَنگیٖزۍ (پاپُوا نیوٗ گیٖنی)',
        'en_PH' => 'اَنگیٖزۍ (فلپائن)',
        'en_PK' => 'اَنگیٖزۍ (پاکِستان)',
        'en_PN' => 'اَنگیٖزۍ (پِٹکیرٕنۍ جٔزیٖرٕ)',
        'en_PR' => 'اَنگیٖزۍ (پٔرٹو رِکو)',
        'en_PW' => 'اَنگیٖزۍ (پَلاو)',
        'en_RW' => 'اَنگیٖزۍ (روٗوانڈا)',
        'en_SB' => 'اَنگیٖزۍ (سولامان جٔزیٖرٕ)',
        'en_SC' => 'اَنگیٖزۍ (سیشَلِس)',
        'en_SD' => 'اَنگیٖزۍ (سوٗڈان)',
        'en_SE' => 'اَنگیٖزۍ (سویڈن)',
        'en_SG' => 'اَنگیٖزۍ (سِنگاپوٗر)',
        'en_SH' => 'اَنگیٖزۍ (سینٹ ہؠلِنا)',
        'en_SI' => 'اَنگیٖزۍ (سَلووینِیا)',
        'en_SL' => 'اَنگیٖزۍ (سیرا لیون)',
        'en_SS' => 'اَنگیٖزۍ (جنوبی سوڈان)',
        'en_SX' => 'اَنگیٖزۍ (سِنٹ مارٹِن)',
        'en_SZ' => 'اَنگیٖزۍ (ایسواتنی)',
        'en_TC' => 'اَنگیٖزۍ (تُرکس تٕہ کیکو جزیرٕ)',
        'en_TK' => 'اَنگیٖزۍ (ٹوکلو)',
        'en_TO' => 'اَنگیٖزۍ (ٹونگا)',
        'en_TT' => 'اَنگیٖزۍ (ٹرنِنداد تہٕ ٹوبیگو)',
        'en_TV' => 'اَنگیٖزۍ (توٗوالوٗ)',
        'en_TZ' => 'اَنگیٖزۍ (تَنجانِیا)',
        'en_UG' => 'اَنگیٖزۍ (یوٗگانڑا)',
        'en_UM' => 'اَنگیٖزۍ (یوٗنایٹِڑ سِٹیٹِس ماینَر آوُٹلییِنگ جٔزیٖرٕ)',
        'en_US' => 'اَنگیٖزۍ (یوٗنایٹِڑ سِٹیٹِس)',
        'en_VC' => 'اَنگیٖزۍ (سینٹ وینسؠٹ تہٕ گریناڑاینٕز)',
        'en_VG' => 'اَنگیٖزۍ (بَرطانوی ؤرجِن جٔزیٖرٕ)',
        'en_VI' => 'اَنگیٖزۍ (یوٗ ایس ؤرجِن جٔزیٖرٕ)',
        'en_VU' => 'اَنگیٖزۍ (وانوٗتوٗ)',
        'en_WS' => 'اَنگیٖزۍ (سامو)',
        'en_ZA' => 'اَنگیٖزۍ (جنوبی افریقہ)',
        'en_ZM' => 'اَنگیٖزۍ (زیمبیا)',
        'en_ZW' => 'اَنگیٖزۍ (زِمبابے)',
        'eo' => 'ایسپَرینٹو',
        'eo_001' => 'ایسپَرینٹو (دُنیا)',
        'es' => 'ہسپانوی',
        'es_419' => 'ہسپانوی (لاطیٖنی اَمریٖکا)',
        'es_AR' => 'ہسپانوی (أرجَنٹینا)',
        'es_BO' => 'ہسپانوی (بولِوِیا)',
        'es_BR' => 'ہسپانوی (برازِل)',
        'es_BZ' => 'ہسپانوی (بیلز)',
        'es_CL' => 'ہسپانوی (چِلی)',
        'es_CO' => 'ہسپانوی (کولَمبِیا)',
        'es_CR' => 'ہسپانوی (کوسٹا ریکا)',
        'es_CU' => 'ہسپانوی (کیوٗبا)',
        'es_DO' => 'ہسپانوی (ڈومِنِکَن جموٗرِیَت)',
        'es_EC' => 'ہسپانوی (اِکواڑور)',
        'es_ES' => 'ہسپانوی (سٕپین)',
        'es_GQ' => 'ہسپانوی (اِکوِٹورِیَل گِنی)',
        'es_GT' => 'ہسپانوی (گواٹمالا)',
        'es_HN' => 'ہسپانوی (ہونڈورس)',
        'es_MX' => 'ہسپانوی (مؠکسِکو)',
        'es_NI' => 'ہسپانوی (ناکاراگُوا)',
        'es_PA' => 'ہسپانوی (پَناما)',
        'es_PE' => 'ہسپانوی (پیٖروٗ)',
        'es_PH' => 'ہسپانوی (فلپائن)',
        'es_PR' => 'ہسپانوی (پٔرٹو رِکو)',
        'es_PY' => 'ہسپانوی (پَراگُے)',
        'es_SV' => 'ہسپانوی (ایل سلویڈر)',
        'es_US' => 'ہسپانوی (یوٗنایٹِڑ سِٹیٹِس)',
        'es_UY' => 'ہسپانوی (یوٗروگے)',
        'es_VE' => 'ہسپانوی (وینازوٗلا)',
        'et' => 'ایسٹونیَن',
        'et_EE' => 'ایسٹونیَن (ایسٹونِیا)',
        'eu' => 'باسک',
        'eu_ES' => 'باسک (سٕپین)',
        'fa' => 'فارسی',
        'fa_AF' => 'فارسی (اَفغانَستان)',
        'fa_IR' => 'فارسی (ایٖران)',
        'ff' => 'فُلاہ',
        'ff_CM' => 'فُلاہ (کیمِروٗن)',
        'ff_GN' => 'فُلاہ (گِنی)',
        'ff_Latn' => 'فُلاہ (لاطیٖنی)',
        'ff_Latn_BF' => 'فُلاہ (لاطیٖنی, بُرکِنا فیسو)',
        'ff_Latn_CM' => 'فُلاہ (لاطیٖنی, کیمِروٗن)',
        'ff_Latn_GH' => 'فُلاہ (لاطیٖنی, گانا)',
        'ff_Latn_GM' => 'فُلاہ (لاطیٖنی, گَمبِیا)',
        'ff_Latn_GN' => 'فُلاہ (لاطیٖنی, گِنی)',
        'ff_Latn_GW' => 'فُلاہ (لاطیٖنی, گیٖنی بِساو)',
        'ff_Latn_LR' => 'فُلاہ (لاطیٖنی, لایبیرِیا)',
        'ff_Latn_MR' => 'فُلاہ (لاطیٖنی, مارٕٹانِیا)',
        'ff_Latn_NE' => 'فُلاہ (لاطیٖنی, نایجَر)',
        'ff_Latn_NG' => 'فُلاہ (لاطیٖنی, نایجیرِیا)',
        'ff_Latn_SL' => 'فُلاہ (لاطیٖنی, سیرا لیون)',
        'ff_Latn_SN' => 'فُلاہ (لاطیٖنی, سینیگَل)',
        'ff_MR' => 'فُلاہ (مارٕٹانِیا)',
        'ff_SN' => 'فُلاہ (سینیگَل)',
        'fi' => 'فِنِش',
        'fi_FI' => 'فِنِش (فِن لینڈ)',
        'fo' => 'فَروس',
        'fo_DK' => 'فَروس (ڈینمارٕک)',
        'fo_FO' => 'فَروس (فارو جزیرہ)',
        'fr' => 'فرانسیسی',
        'fr_BE' => 'فرانسیسی (بیلجِیَم)',
        'fr_BF' => 'فرانسیسی (بُرکِنا فیسو)',
        'fr_BI' => 'فرانسیسی (بورَنڈِ)',
        'fr_BJ' => 'فرانسیسی (بِنِن)',
        'fr_BL' => 'فرانسیسی (سینٹ بارتَھیلمی)',
        'fr_CA' => 'فرانسیسی (کینیڈا)',
        'fr_CD' => 'فرانسیسی (کونگو کِنشاسا)',
        'fr_CF' => 'فرانسیسی (مرکٔزی اَفریٖکی جموٗریَت)',
        'fr_CG' => 'فرانسیسی (کونگو بٔرزاوِلی)',
        'fr_CH' => 'فرانسیسی (سُوِزَرلینڑ)',
        'fr_CI' => 'فرانسیسی (کوٹ ڈلوائر)',
        'fr_CM' => 'فرانسیسی (کیمِروٗن)',
        'fr_DJ' => 'فرانسیسی (جِبوٗتی)',
        'fr_DZ' => 'فرانسیسی (اؠلجیرِیا)',
        'fr_FR' => 'فرانسیسی (فرانس)',
        'fr_GA' => 'فرانسیسی (گیبان)',
        'fr_GF' => 'فرانسیسی (فرانسِسی گِانا)',
        'fr_GN' => 'فرانسیسی (گِنی)',
        'fr_GP' => 'فرانسیسی (گواڈلوپ)',
        'fr_GQ' => 'فرانسیسی (اِکوِٹورِیَل گِنی)',
        'fr_HT' => 'فرانسیسی (ہیتی)',
        'fr_KM' => 'فرانسیسی (کَمورَس)',
        'fr_LU' => 'فرانسیسی (لَکسَمبٔرٕگ)',
        'fr_MA' => 'فرانسیسی (موروکو)',
        'fr_MC' => 'فرانسیسی (مونیکو)',
        'fr_MF' => 'فرانسیسی (سینٹ مارٹِن)',
        'fr_MG' => 'فرانسیسی (میڈاگاسکار)',
        'fr_ML' => 'فرانسیسی (مالی)',
        'fr_MQ' => 'فرانسیسی (مارٹِنِک)',
        'fr_MR' => 'فرانسیسی (مارٕٹانِیا)',
        'fr_MU' => 'فرانسیسی (مورِشَس)',
        'fr_NC' => 'فرانسیسی (نِو کیلِڑونِیا)',
        'fr_NE' => 'فرانسیسی (نایجَر)',
        'fr_PF' => 'فرانسیسی (فرانسی پولِنیشِیا)',
        'fr_PM' => 'فرانسیسی (سینٹ پیٖری تہٕ موکیلِیَن)',
        'fr_RE' => 'فرانسیسی (رِیوٗنِیَن)',
        'fr_RW' => 'فرانسیسی (روٗوانڈا)',
        'fr_SC' => 'فرانسیسی (سیشَلِس)',
        'fr_SN' => 'فرانسیسی (سینیگَل)',
        'fr_SY' => 'فرانسیسی (شام)',
        'fr_TD' => 'فرانسیسی (چاڑ)',
        'fr_TG' => 'فرانسیسی (ٹوگو)',
        'fr_TN' => 'فرانسیسی (ٹونیشِیا)',
        'fr_VU' => 'فرانسیسی (وانوٗتوٗ)',
        'fr_WF' => 'فرانسیسی (والِس تہٕ فیوٗچوٗنا)',
        'fr_YT' => 'فرانسیسی (مَییٹ)',
        'fy' => 'مغربی فرِشیَن',
        'fy_NL' => 'مغربی فرِشیَن (نیٖدَرلینڑ)',
        'ga' => 'اَیرِش',
        'ga_GB' => 'اَیرِش (متحدہ مملِکت)',
        'ga_IE' => 'اَیرِش (اَیَرلینڑ)',
        'gd' => 'سکوٹِش گیےلِک',
        'gd_GB' => 'سکوٹِش گیےلِک (متحدہ مملِکت)',
        'gl' => 'گیلِشِیَن',
        'gl_ES' => 'گیلِشِیَن (سٕپین)',
        'gu' => 'گُجرٲتی',
        'gu_IN' => 'گُجرٲتی (ہِندوستان)',
        'gv' => 'مینکس',
        'gv_IM' => 'مینکس (آیِل آف مین)',
        'ha' => 'ہاوسا',
        'ha_GH' => 'ہاوسا (گانا)',
        'ha_NE' => 'ہاوسا (نایجَر)',
        'ha_NG' => 'ہاوسا (نایجیرِیا)',
        'he' => 'عبرٲنۍ',
        'he_IL' => 'عبرٲنۍ (اسرا ییل)',
        'hi' => 'ہِندی',
        'hi_IN' => 'ہِندی (ہِندوستان)',
        'hi_Latn' => 'ہِندی (لاطیٖنی)',
        'hi_Latn_IN' => 'ہِندی (لاطیٖنی, ہِندوستان)',
        'hr' => 'کروشِیَن',
        'hr_BA' => 'کروشِیَن (بوسنِیا تہٕ ہَرزِگووِنا)',
        'hr_HR' => 'کروشِیَن (کروشِیا)',
        'hu' => 'ہَنگیریَن',
        'hu_HU' => 'ہَنگیریَن (ہَنگری)',
        'hy' => 'اَرمینیَن',
        'hy_AM' => 'اَرمینیَن (اَرمانِیا)',
        'ia' => 'اِنٹَرلِنگوا',
        'ia_001' => 'اِنٹَرلِنگوا (دُنیا)',
        'id' => 'اِنڈونیشیا',
        'id_ID' => 'اِنڈونیشیا (انڈونیشیا)',
        'ig' => 'اِگبو',
        'ig_NG' => 'اِگبو (نایجیرِیا)',
        'ii' => 'سِچوان یٖی',
        'ii_CN' => 'سِچوان یٖی (چیٖن)',
        'is' => 'آیِسلینڈِک',
        'is_IS' => 'آیِسلینڈِک (اَیِسلینڑ)',
        'it' => 'اِطالوی',
        'it_CH' => 'اِطالوی (سُوِزَرلینڑ)',
        'it_IT' => 'اِطالوی (اِٹلی)',
        'it_SM' => 'اِطالوی (سین میرِنو)',
        'it_VA' => 'اِطالوی (ویٹِکَن سِٹی)',
        'ja' => 'جاپٲنۍ',
        'ja_JP' => 'جاپٲنۍ (جاپان)',
        'jv' => 'جَوَنیٖز',
        'jv_ID' => 'جَوَنیٖز (انڈونیشیا)',
        'ka' => 'جارجِیَن',
        'ka_GE' => 'جارجِیَن (جارجِیا)',
        'ki' => 'کِکُیوٗ',
        'ki_KE' => 'کِکُیوٗ (کِنیا)',
        'kk' => 'کازَخ',
        'kk_KZ' => 'کازَخ (قازقستان)',
        'kl' => 'کَلالِسُت',
        'kl_GL' => 'کَلالِسُت (گرین لینڈ)',
        'km' => 'خَمیر',
        'km_KH' => 'خَمیر (کَمبوڑِیا)',
        'kn' => 'کَنَڑ',
        'kn_IN' => 'کَنَڑ (ہِندوستان)',
        'ko' => 'کوریَن',
        'ko_KP' => 'کوریَن (شُمٲلی کورِیا)',
        'ko_KR' => 'کوریَن (جنوٗبی کورِیا)',
        'ks' => 'کٲشُر',
        'ks_Arab' => 'کٲشُر (عربی)',
        'ks_Arab_IN' => 'کٲشُر (عربی, ہِندوستان)',
        'ks_Deva' => 'کٲشُر (دیوناگری)',
        'ks_Deva_IN' => 'کٲشُر (دیوناگری, ہِندوستان)',
        'ks_IN' => 'کٲشُر (ہِندوستان)',
        'ku' => 'کُردِش',
        'ku_TR' => 'کُردِش (تُرکی)',
        'kw' => 'کورنِش',
        'kw_GB' => 'کورنِش (متحدہ مملِکت)',
        'ky' => 'کِرگِز',
        'ky_KG' => 'کِرگِز (کرغزستان)',
        'lb' => 'لُکھزیمبورگِش',
        'lb_LU' => 'لُکھزیمبورگِش (لَکسَمبٔرٕگ)',
        'lg' => 'گاندا',
        'lg_UG' => 'گاندا (یوٗگانڑا)',
        'ln' => 'لِنگالا',
        'ln_AO' => 'لِنگالا (انگولا)',
        'ln_CD' => 'لِنگالا (کونگو کِنشاسا)',
        'ln_CF' => 'لِنگالا (مرکٔزی اَفریٖکی جموٗریَت)',
        'ln_CG' => 'لِنگالا (کونگو بٔرزاوِلی)',
        'lo' => 'لاو',
        'lo_LA' => 'لاو (لاس)',
        'lt' => 'لِتھوانِیَن',
        'lt_LT' => 'لِتھوانِیَن (لِتھُوانِیا)',
        'lu' => 'لوُبا کَتَنگا',
        'lu_CD' => 'لوُبا کَتَنگا (کونگو کِنشاسا)',
        'lv' => 'لَتوِیَن',
        'lv_LV' => 'لَتوِیَن (لیٹوِیا)',
        'mg' => 'مَلاگَسی',
        'mg_MG' => 'مَلاگَسی (میڈاگاسکار)',
        'mi' => 'ماوری',
        'mi_NZ' => 'ماوری (نیوزی لینڈ)',
        'mk' => 'میکَڈونیَن',
        'mk_MK' => 'میکَڈونیَن (شُمالی میسڈونیا)',
        'ml' => 'مٔلیالَم',
        'ml_IN' => 'مٔلیالَم (ہِندوستان)',
        'mn' => 'مَنگولی',
        'mn_MN' => 'مَنگولی (مَنگولِیا)',
        'mr' => 'مَرٲٹھۍ',
        'mr_IN' => 'مَرٲٹھۍ (ہِندوستان)',
        'ms' => 'مَلَے',
        'ms_BN' => 'مَلَے (برونے)',
        'ms_ID' => 'مَلَے (انڈونیشیا)',
        'ms_MY' => 'مَلَے (مَلیشِیا)',
        'ms_SG' => 'مَلَے (سِنگاپوٗر)',
        'mt' => 'مَلتیٖس',
        'mt_MT' => 'مَلتیٖس (مالٹا)',
        'my' => 'بٔمیٖز',
        'my_MM' => 'بٔمیٖز (میانمار [برما])',
        'nb' => 'ناروییَن بوکمال',
        'nb_NO' => 'ناروییَن بوکمال (ناروے)',
        'nb_SJ' => 'ناروییَن بوکمال (سَوالبریڑ تہٕ جان ماییڑ)',
        'nd' => 'شُمال ڈَبیل',
        'nd_ZW' => 'شُمال ڈَبیل (زِمبابے)',
        'ne' => 'نیپٲلۍ',
        'ne_IN' => 'نیپٲلۍ (ہِندوستان)',
        'ne_NP' => 'نیپٲلۍ (نیپال)',
        'nl' => 'ڈَچ',
        'nl_AW' => 'ڈَچ (اَروٗبا)',
        'nl_BE' => 'ڈَچ (بیلجِیَم)',
        'nl_BQ' => 'ڈَچ (کیریبین نیدرلینڈس)',
        'nl_CW' => 'ڈَچ (کیوراکو)',
        'nl_NL' => 'ڈَچ (نیٖدَرلینڑ)',
        'nl_SR' => 'ڈَچ (سُرِنام)',
        'nl_SX' => 'ڈَچ (سِنٹ مارٹِن)',
        'nn' => 'ناروییَن نَے نورسک',
        'nn_NO' => 'ناروییَن نَے نورسک (ناروے)',
        'no' => 'ناروییَن',
        'no_NO' => 'ناروییَن (ناروے)',
        'om' => 'اۆرومو',
        'om_ET' => 'اۆرومو (اِتھوپِیا)',
        'om_KE' => 'اۆرومو (کِنیا)',
        'or' => 'اۆرِیا',
        'or_IN' => 'اۆرِیا (ہِندوستان)',
        'os' => 'اۆسیٹِک',
        'os_GE' => 'اۆسیٹِک (جارجِیا)',
        'os_RU' => 'اۆسیٹِک (روٗس)',
        'pa' => 'پَنجٲبۍ',
        'pa_Arab' => 'پَنجٲبۍ (عربی)',
        'pa_Arab_PK' => 'پَنجٲبۍ (عربی, پاکِستان)',
        'pa_Guru' => 'پَنجٲبۍ (گُجرٲتۍ)',
        'pa_Guru_IN' => 'پَنجٲبۍ (گُجرٲتۍ, ہِندوستان)',
        'pa_IN' => 'پَنجٲبۍ (ہِندوستان)',
        'pa_PK' => 'پَنجٲبۍ (پاکِستان)',
        'pl' => 'پالِش',
        'pl_PL' => 'پالِش (پولینڈ)',
        'ps' => 'پَشتوٗ',
        'ps_AF' => 'پَشتوٗ (اَفغانَستان)',
        'ps_PK' => 'پَشتوٗ (پاکِستان)',
        'pt' => 'پُرتَگیٖز',
        'pt_AO' => 'پُرتَگیٖز (انگولا)',
        'pt_BR' => 'پُرتَگیٖز (برازِل)',
        'pt_CH' => 'پُرتَگیٖز (سُوِزَرلینڑ)',
        'pt_CV' => 'پُرتَگیٖز (کیپ ؤرڑی)',
        'pt_GQ' => 'پُرتَگیٖز (اِکوِٹورِیَل گِنی)',
        'pt_GW' => 'پُرتَگیٖز (گیٖنی بِساو)',
        'pt_LU' => 'پُرتَگیٖز (لَکسَمبٔرٕگ)',
        'pt_MO' => 'پُرتَگیٖز (مَکاوو ایس اے آر چیٖن)',
        'pt_MZ' => 'پُرتَگیٖز (موزَمبِک)',
        'pt_PT' => 'پُرتَگیٖز (پُرتِگال)',
        'pt_ST' => 'پُرتَگیٖز (ساو توم تہٕ پرنسِپی)',
        'pt_TL' => 'پُرتَگیٖز (تیمور-لیسٹ)',
        'qu' => 'کُویشُوا',
        'qu_BO' => 'کُویشُوا (بولِوِیا)',
        'qu_EC' => 'کُویشُوا (اِکواڑور)',
        'qu_PE' => 'کُویشُوا (پیٖروٗ)',
        'rm' => 'رومانش',
        'rm_CH' => 'رومانش (سُوِزَرلینڑ)',
        'rn' => 'رُندی',
        'rn_BI' => 'رُندی (بورَنڈِ)',
        'ro' => 'رومٲنی',
        'ro_MD' => 'رومٲنی (مولڈووا)',
        'ro_RO' => 'رومٲنی (رومانِیا)',
        'ru' => 'روٗسی',
        'ru_BY' => 'روٗسی (بیلاروٗس)',
        'ru_KG' => 'روٗسی (کرغزستان)',
        'ru_KZ' => 'روٗسی (قازقستان)',
        'ru_MD' => 'روٗسی (مولڈووا)',
        'ru_RU' => 'روٗسی (روٗس)',
        'ru_UA' => 'روٗسی (یوٗرِکین)',
        'rw' => 'کِنیاوِندا',
        'rw_RW' => 'کِنیاوِندا (روٗوانڈا)',
        'sa' => 'سَنسکرٕت',
        'sa_IN' => 'سَنسکرٕت (ہِندوستان)',
        'sc' => 'سراڈیٖنی',
        'sc_IT' => 'سراڈیٖنی (اِٹلی)',
        'sd' => 'سِندی',
        'sd_Arab' => 'سِندی (عربی)',
        'sd_Arab_PK' => 'سِندی (عربی, پاکِستان)',
        'sd_Deva' => 'سِندی (دیوناگری)',
        'sd_Deva_IN' => 'سِندی (دیوناگری, ہِندوستان)',
        'sd_IN' => 'سِندی (ہِندوستان)',
        'sd_PK' => 'سِندی (پاکِستان)',
        'se' => 'شُمٲلی سَمی',
        'se_FI' => 'شُمٲلی سَمی (فِن لینڈ)',
        'se_NO' => 'شُمٲلی سَمی (ناروے)',
        'se_SE' => 'شُمٲلی سَمی (سویڈن)',
        'sg' => 'سَنگو',
        'sg_CF' => 'سَنگو (مرکٔزی اَفریٖکی جموٗریَت)',
        'sh' => 'سیربو کروشِیَن',
        'sh_BA' => 'سیربو کروشِیَن (بوسنِیا تہٕ ہَرزِگووِنا)',
        'si' => 'سِنہالا',
        'si_LK' => 'سِنہالا (سری لنکا)',
        'sk' => 'سلووَک',
        'sk_SK' => 'سلووَک (سَلوواکِیا)',
        'sl' => 'سلووینیَن',
        'sl_SI' => 'سلووینیَن (سَلووینِیا)',
        'sn' => 'شونا',
        'sn_ZW' => 'شونا (زِمبابے)',
        'so' => 'سومٲلی',
        'so_DJ' => 'سومٲلی (جِبوٗتی)',
        'so_ET' => 'سومٲلی (اِتھوپِیا)',
        'so_KE' => 'سومٲلی (کِنیا)',
        'so_SO' => 'سومٲلی (سومالِیا)',
        'sq' => 'البانِیَن',
        'sq_AL' => 'البانِیَن (البانیا)',
        'sq_MK' => 'البانِیَن (شُمالی میسڈونیا)',
        'sr' => 'سٔربِیَن',
        'sr_BA' => 'سٔربِیَن (بوسنِیا تہٕ ہَرزِگووِنا)',
        'sr_Cyrl' => 'سٔربِیَن (سَیرِلِک)',
        'sr_Cyrl_BA' => 'سٔربِیَن (سَیرِلِک, بوسنِیا تہٕ ہَرزِگووِنا)',
        'sr_Cyrl_ME' => 'سٔربِیَن (سَیرِلِک, موٹونیگِریو)',
        'sr_Cyrl_RS' => 'سٔربِیَن (سَیرِلِک, سَربِیا)',
        'sr_Latn' => 'سٔربِیَن (لاطیٖنی)',
        'sr_Latn_BA' => 'سٔربِیَن (لاطیٖنی, بوسنِیا تہٕ ہَرزِگووِنا)',
        'sr_Latn_ME' => 'سٔربِیَن (لاطیٖنی, موٹونیگِریو)',
        'sr_Latn_RS' => 'سٔربِیَن (لاطیٖنی, سَربِیا)',
        'sr_ME' => 'سٔربِیَن (موٹونیگِریو)',
        'sr_RS' => 'سٔربِیَن (سَربِیا)',
        'su' => 'سَنڈَنیٖز',
        'su_ID' => 'سَنڈَنیٖز (انڈونیشیا)',
        'su_Latn' => 'سَنڈَنیٖز (لاطیٖنی)',
        'su_Latn_ID' => 'سَنڈَنیٖز (لاطیٖنی, انڈونیشیا)',
        'sv' => 'سویٖڈِش',
        'sv_AX' => 'سویٖڈِش (ایلینڑ جٔزیٖرٕ)',
        'sv_FI' => 'سویٖڈِش (فِن لینڈ)',
        'sv_SE' => 'سویٖڈِش (سویڈن)',
        'sw' => 'سواہِلی',
        'sw_CD' => 'سواہِلی (کونگو کِنشاسا)',
        'sw_KE' => 'سواہِلی (کِنیا)',
        'sw_TZ' => 'سواہِلی (تَنجانِیا)',
        'sw_UG' => 'سواہِلی (یوٗگانڑا)',
        'ta' => 'تَمِل',
        'ta_IN' => 'تَمِل (ہِندوستان)',
        'ta_LK' => 'تَمِل (سری لنکا)',
        'ta_MY' => 'تَمِل (مَلیشِیا)',
        'ta_SG' => 'تَمِل (سِنگاپوٗر)',
        'te' => 'تیلگوٗ',
        'te_IN' => 'تیلگوٗ (ہِندوستان)',
        'tg' => 'تاجِک',
        'tg_TJ' => 'تاجِک (تاجکِستان)',
        'th' => 'تھاے',
        'th_TH' => 'تھاے (تھائی لینڈ)',
        'ti' => 'ٹِگرِنیا',
        'ti_ER' => 'ٹِگرِنیا (اِرٕٹِیا)',
        'ti_ET' => 'ٹِگرِنیا (اِتھوپِیا)',
        'tk' => 'تُرکمین',
        'tk_TM' => 'تُرکمین (تُرکمنستان)',
        'tl' => 'تَماشیک',
        'tl_PH' => 'تَماشیک (فلپائن)',
        'to' => 'ٹونگا',
        'to_TO' => 'ٹونگا (ٹونگا)',
        'tr' => 'تُرکِش',
        'tr_CY' => 'تُرکِش (سائپرس)',
        'tr_TR' => 'تُرکِش (تُرکی)',
        'tt' => 'تَتار',
        'tt_RU' => 'تَتار (روٗس)',
        'uk' => 'یوٗکرینیٲیی',
        'uk_UA' => 'یوٗکرینیٲیی (یوٗرِکین)',
        'ur' => 'اُردوٗ',
        'ur_IN' => 'اُردوٗ (ہِندوستان)',
        'ur_PK' => 'اُردوٗ (پاکِستان)',
        'uz' => 'اُزبیک',
        'uz_AF' => 'اُزبیک (اَفغانَستان)',
        'uz_Arab' => 'اُزبیک (عربی)',
        'uz_Arab_AF' => 'اُزبیک (عربی, اَفغانَستان)',
        'uz_Cyrl' => 'اُزبیک (سَیرِلِک)',
        'uz_Cyrl_UZ' => 'اُزبیک (سَیرِلِک, اُزبِکِستان)',
        'uz_Latn' => 'اُزبیک (لاطیٖنی)',
        'uz_Latn_UZ' => 'اُزبیک (لاطیٖنی, اُزبِکِستان)',
        'uz_UZ' => 'اُزبیک (اُزبِکِستان)',
        'vi' => 'وِیَتنَمیٖز',
        'vi_VN' => 'وِیَتنَمیٖز (ویتنام)',
        'wo' => 'وولوف',
        'wo_SN' => 'وولوف (سینیگَل)',
        'xh' => 'کھوسا',
        'xh_ZA' => 'کھوسا (جنوبی افریقہ)',
        'yi' => 'یِدِش',
        'yi_001' => 'یِدِش (دُنیا)',
        'yo' => 'یورُبا',
        'yo_BJ' => 'یورُبا (بِنِن)',
        'yo_NG' => 'یورُبا (نایجیرِیا)',
        'zh' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾',
        'zh_CN' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (چیٖن)',
        'zh_HK' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (ہانگ کانگ ایس اے آر چیٖن)',
        'zh_Hans' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سَہل ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾)',
        'zh_Hans_CN' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سَہل ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, چیٖن)',
        'zh_Hans_HK' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سَہل ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, ہانگ کانگ ایس اے آر چیٖن)',
        'zh_Hans_MO' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سَہل ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, مَکاوو ایس اے آر چیٖن)',
        'zh_Hans_SG' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سَہل ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, سِنگاپوٗر)',
        'zh_Hant' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (رِوٲجی ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾)',
        'zh_Hant_HK' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (رِوٲجی ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, ہانگ کانگ ایس اے آر چیٖن)',
        'zh_Hant_MO' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (رِوٲجی ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, مَکاوو ایس اے آر چیٖن)',
        'zh_Hant_TW' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (رِوٲجی ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتۍ اِستعمال یِوان کرنٕہ۔﴾, تایوان)',
        'zh_MO' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (مَکاوو ایس اے آر چیٖن)',
        'zh_SG' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (سِنگاپوٗر)',
        'zh_TW' => 'چیٖنی ﴿ترجمع اِشارٕ: خاص طور، مینڈارن چیٖنی۔﴾ (تایوان)',
        'zu' => 'زُلوٗ',
        'zu_ZA' => 'زُلوٗ (جنوبی افریقہ)',
    ],
];
