<?php

return [
    'Names' => [
        'af' => 'afríkanska',
        'af_NA' => 'afríkanska (Namibía)',
        'af_ZA' => 'afríkanska (Suður-Afríka)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Gana)',
        'am' => 'amharíska',
        'am_ET' => 'amharíska (Eþíópía)',
        'ar' => 'arabíska',
        'ar_001' => 'arabíska (Heimurinn)',
        'ar_AE' => 'arabíska (Sameinuðu arabísku furstadæmin)',
        'ar_BH' => 'arabíska (Barein)',
        'ar_DJ' => 'arabíska (Djíbútí)',
        'ar_DZ' => 'arabíska (Alsír)',
        'ar_EG' => 'arabíska (Egyptaland)',
        'ar_EH' => 'arabíska (Vestur-Sahara)',
        'ar_ER' => 'arabíska (Erítrea)',
        'ar_IL' => 'arabíska (Ísrael)',
        'ar_IQ' => 'arabíska (Írak)',
        'ar_JO' => 'arabíska (Jórdanía)',
        'ar_KM' => 'arabíska (Kómoreyjar)',
        'ar_KW' => 'arabíska (Kúveit)',
        'ar_LB' => 'arabíska (Líbanon)',
        'ar_LY' => 'arabíska (Líbía)',
        'ar_MA' => 'arabíska (Marokkó)',
        'ar_MR' => 'arabíska (Máritanía)',
        'ar_OM' => 'arabíska (Óman)',
        'ar_PS' => 'arabíska (Heimastjórnarsvæði Palestínumanna)',
        'ar_QA' => 'arabíska (Katar)',
        'ar_SA' => 'arabíska (Sádi-Arabía)',
        'ar_SD' => 'arabíska (Súdan)',
        'ar_SO' => 'arabíska (Sómalía)',
        'ar_SS' => 'arabíska (Suður-Súdan)',
        'ar_SY' => 'arabíska (Sýrland)',
        'ar_TD' => 'arabíska (Tsjad)',
        'ar_TN' => 'arabíska (Túnis)',
        'ar_YE' => 'arabíska (Jemen)',
        'as' => 'assamska',
        'as_IN' => 'assamska (Indland)',
        'az' => 'aserska',
        'az_AZ' => 'aserska (Aserbaídsjan)',
        'az_Cyrl' => 'aserska (kyrillískt)',
        'az_Cyrl_AZ' => 'aserska (kyrillískt, Aserbaídsjan)',
        'az_Latn' => 'aserska (latneskt)',
        'az_Latn_AZ' => 'aserska (latneskt, Aserbaídsjan)',
        'be' => 'hvítrússneska',
        'be_BY' => 'hvítrússneska (Hvíta-Rússland)',
        'bg' => 'búlgarska',
        'bg_BG' => 'búlgarska (Búlgaría)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Malí)',
        'bn' => 'bengalska',
        'bn_BD' => 'bengalska (Bangladess)',
        'bn_IN' => 'bengalska (Indland)',
        'bo' => 'tíbeska',
        'bo_CN' => 'tíbeska (Kína)',
        'bo_IN' => 'tíbeska (Indland)',
        'br' => 'bretónska',
        'br_FR' => 'bretónska (Frakkland)',
        'bs' => 'bosníska',
        'bs_BA' => 'bosníska (Bosnía og Hersegóvína)',
        'bs_Cyrl' => 'bosníska (kyrillískt)',
        'bs_Cyrl_BA' => 'bosníska (kyrillískt, Bosnía og Hersegóvína)',
        'bs_Latn' => 'bosníska (latneskt)',
        'bs_Latn_BA' => 'bosníska (latneskt, Bosnía og Hersegóvína)',
        'ca' => 'katalónska',
        'ca_AD' => 'katalónska (Andorra)',
        'ca_ES' => 'katalónska (Spánn)',
        'ca_FR' => 'katalónska (Frakkland)',
        'ca_IT' => 'katalónska (Ítalía)',
        'ce' => 'tsjetsjenska',
        'ce_RU' => 'tsjetsjenska (Rússland)',
        'cs' => 'tékkneska',
        'cs_CZ' => 'tékkneska (Tékkland)',
        'cv' => 'sjúvas',
        'cv_RU' => 'sjúvas (Rússland)',
        'cy' => 'velska',
        'cy_GB' => 'velska (Bretland)',
        'da' => 'danska',
        'da_DK' => 'danska (Danmörk)',
        'da_GL' => 'danska (Grænland)',
        'de' => 'þýska',
        'de_AT' => 'þýska (Austurríki)',
        'de_BE' => 'þýska (Belgía)',
        'de_CH' => 'þýska (Sviss)',
        'de_DE' => 'þýska (Þýskaland)',
        'de_IT' => 'þýska (Ítalía)',
        'de_LI' => 'þýska (Liechtenstein)',
        'de_LU' => 'þýska (Lúxemborg)',
        'dz' => 'dsongka',
        'dz_BT' => 'dsongka (Bútan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Gana)',
        'ee_TG' => 'ewe (Tógó)',
        'el' => 'gríska',
        'el_CY' => 'gríska (Kýpur)',
        'el_GR' => 'gríska (Grikkland)',
        'en' => 'enska',
        'en_001' => 'enska (Heimurinn)',
        'en_150' => 'enska (Evrópa)',
        'en_AE' => 'enska (Sameinuðu arabísku furstadæmin)',
        'en_AG' => 'enska (Antígva og Barbúda)',
        'en_AI' => 'enska (Angvilla)',
        'en_AS' => 'enska (Bandaríska Samóa)',
        'en_AT' => 'enska (Austurríki)',
        'en_AU' => 'enska (Ástralía)',
        'en_BB' => 'enska (Barbados)',
        'en_BE' => 'enska (Belgía)',
        'en_BI' => 'enska (Búrúndí)',
        'en_BM' => 'enska (Bermúdaeyjar)',
        'en_BS' => 'enska (Bahamaeyjar)',
        'en_BW' => 'enska (Botsvana)',
        'en_BZ' => 'enska (Belís)',
        'en_CA' => 'enska (Kanada)',
        'en_CC' => 'enska (Kókoseyjar [Keeling])',
        'en_CH' => 'enska (Sviss)',
        'en_CK' => 'enska (Cooks-eyjar)',
        'en_CM' => 'enska (Kamerún)',
        'en_CX' => 'enska (Jólaey)',
        'en_CY' => 'enska (Kýpur)',
        'en_DE' => 'enska (Þýskaland)',
        'en_DK' => 'enska (Danmörk)',
        'en_DM' => 'enska (Dóminíka)',
        'en_ER' => 'enska (Erítrea)',
        'en_FI' => 'enska (Finnland)',
        'en_FJ' => 'enska (Fídjíeyjar)',
        'en_FK' => 'enska (Falklandseyjar)',
        'en_FM' => 'enska (Míkrónesía)',
        'en_GB' => 'enska (Bretland)',
        'en_GD' => 'enska (Grenada)',
        'en_GG' => 'enska (Guernsey)',
        'en_GH' => 'enska (Gana)',
        'en_GI' => 'enska (Gíbraltar)',
        'en_GM' => 'enska (Gambía)',
        'en_GU' => 'enska (Gvam)',
        'en_GY' => 'enska (Gvæjana)',
        'en_HK' => 'enska (sérstjórnarsvæðið Hong Kong)',
        'en_IE' => 'enska (Írland)',
        'en_IL' => 'enska (Ísrael)',
        'en_IM' => 'enska (Mön)',
        'en_IN' => 'enska (Indland)',
        'en_IO' => 'enska (Bresku Indlandshafseyjar)',
        'en_JE' => 'enska (Jersey)',
        'en_JM' => 'enska (Jamaíka)',
        'en_KE' => 'enska (Kenía)',
        'en_KI' => 'enska (Kíribatí)',
        'en_KN' => 'enska (Sankti Kitts og Nevis)',
        'en_KY' => 'enska (Caymaneyjar)',
        'en_LC' => 'enska (Sankti Lúsía)',
        'en_LR' => 'enska (Líbería)',
        'en_LS' => 'enska (Lesótó)',
        'en_MG' => 'enska (Madagaskar)',
        'en_MH' => 'enska (Marshalleyjar)',
        'en_MO' => 'enska (sérstjórnarsvæðið Makaó)',
        'en_MP' => 'enska (Norður-Maríanaeyjar)',
        'en_MS' => 'enska (Montserrat)',
        'en_MT' => 'enska (Malta)',
        'en_MU' => 'enska (Máritíus)',
        'en_MV' => 'enska (Maldíveyjar)',
        'en_MW' => 'enska (Malaví)',
        'en_MY' => 'enska (Malasía)',
        'en_NA' => 'enska (Namibía)',
        'en_NF' => 'enska (Norfolkeyja)',
        'en_NG' => 'enska (Nígería)',
        'en_NL' => 'enska (Holland)',
        'en_NR' => 'enska (Nárú)',
        'en_NU' => 'enska (Niue)',
        'en_NZ' => 'enska (Nýja-Sjáland)',
        'en_PG' => 'enska (Papúa Nýja-Gínea)',
        'en_PH' => 'enska (Filippseyjar)',
        'en_PK' => 'enska (Pakistan)',
        'en_PN' => 'enska (Pitcairn-eyjar)',
        'en_PR' => 'enska (Púertó Ríkó)',
        'en_PW' => 'enska (Palá)',
        'en_RW' => 'enska (Rúanda)',
        'en_SB' => 'enska (Salómonseyjar)',
        'en_SC' => 'enska (Seychelles-eyjar)',
        'en_SD' => 'enska (Súdan)',
        'en_SE' => 'enska (Svíþjóð)',
        'en_SG' => 'enska (Singapúr)',
        'en_SH' => 'enska (Sankti Helena)',
        'en_SI' => 'enska (Slóvenía)',
        'en_SL' => 'enska (Síerra Leóne)',
        'en_SS' => 'enska (Suður-Súdan)',
        'en_SX' => 'enska (Sint Maarten)',
        'en_SZ' => 'enska (Svasíland)',
        'en_TC' => 'enska (Turks- og Caicoseyjar)',
        'en_TK' => 'enska (Tókelá)',
        'en_TO' => 'enska (Tonga)',
        'en_TT' => 'enska (Trínidad og Tóbagó)',
        'en_TV' => 'enska (Túvalú)',
        'en_TZ' => 'enska (Tansanía)',
        'en_UG' => 'enska (Úganda)',
        'en_UM' => 'enska (Smáeyjar Bandaríkjanna)',
        'en_US' => 'enska (Bandaríkin)',
        'en_VC' => 'enska (Sankti Vinsent og Grenadíneyjar)',
        'en_VG' => 'enska (Bresku Jómfrúaeyjar)',
        'en_VI' => 'enska (Bandarísku Jómfrúaeyjar)',
        'en_VU' => 'enska (Vanúatú)',
        'en_WS' => 'enska (Samóa)',
        'en_ZA' => 'enska (Suður-Afríka)',
        'en_ZM' => 'enska (Sambía)',
        'en_ZW' => 'enska (Simbabve)',
        'eo' => 'esperantó',
        'eo_001' => 'esperantó (Heimurinn)',
        'es' => 'spænska',
        'es_419' => 'spænska (Rómanska Ameríka)',
        'es_AR' => 'spænska (Argentína)',
        'es_BO' => 'spænska (Bólivía)',
        'es_BR' => 'spænska (Brasilía)',
        'es_BZ' => 'spænska (Belís)',
        'es_CL' => 'spænska (Síle)',
        'es_CO' => 'spænska (Kólumbía)',
        'es_CR' => 'spænska (Kostaríka)',
        'es_CU' => 'spænska (Kúba)',
        'es_DO' => 'spænska (Dóminíska lýðveldið)',
        'es_EC' => 'spænska (Ekvador)',
        'es_ES' => 'spænska (Spánn)',
        'es_GQ' => 'spænska (Miðbaugs-Gínea)',
        'es_GT' => 'spænska (Gvatemala)',
        'es_HN' => 'spænska (Hondúras)',
        'es_MX' => 'spænska (Mexíkó)',
        'es_NI' => 'spænska (Níkaragva)',
        'es_PA' => 'spænska (Panama)',
        'es_PE' => 'spænska (Perú)',
        'es_PH' => 'spænska (Filippseyjar)',
        'es_PR' => 'spænska (Púertó Ríkó)',
        'es_PY' => 'spænska (Paragvæ)',
        'es_SV' => 'spænska (El Salvador)',
        'es_US' => 'spænska (Bandaríkin)',
        'es_UY' => 'spænska (Úrúgvæ)',
        'es_VE' => 'spænska (Venesúela)',
        'et' => 'eistneska',
        'et_EE' => 'eistneska (Eistland)',
        'eu' => 'baskneska',
        'eu_ES' => 'baskneska (Spánn)',
        'fa' => 'persneska',
        'fa_AF' => 'persneska (Afganistan)',
        'fa_IR' => 'persneska (Íran)',
        'ff' => 'fúla',
        'ff_Adlm' => 'fúla (adlam)',
        'ff_Adlm_BF' => 'fúla (adlam, Búrkína Fasó)',
        'ff_Adlm_CM' => 'fúla (adlam, Kamerún)',
        'ff_Adlm_GH' => 'fúla (adlam, Gana)',
        'ff_Adlm_GM' => 'fúla (adlam, Gambía)',
        'ff_Adlm_GN' => 'fúla (adlam, Gínea)',
        'ff_Adlm_GW' => 'fúla (adlam, Gínea-Bissá)',
        'ff_Adlm_LR' => 'fúla (adlam, Líbería)',
        'ff_Adlm_MR' => 'fúla (adlam, Máritanía)',
        'ff_Adlm_NE' => 'fúla (adlam, Níger)',
        'ff_Adlm_NG' => 'fúla (adlam, Nígería)',
        'ff_Adlm_SL' => 'fúla (adlam, Síerra Leóne)',
        'ff_Adlm_SN' => 'fúla (adlam, Senegal)',
        'ff_CM' => 'fúla (Kamerún)',
        'ff_GN' => 'fúla (Gínea)',
        'ff_Latn' => 'fúla (latneskt)',
        'ff_Latn_BF' => 'fúla (latneskt, Búrkína Fasó)',
        'ff_Latn_CM' => 'fúla (latneskt, Kamerún)',
        'ff_Latn_GH' => 'fúla (latneskt, Gana)',
        'ff_Latn_GM' => 'fúla (latneskt, Gambía)',
        'ff_Latn_GN' => 'fúla (latneskt, Gínea)',
        'ff_Latn_GW' => 'fúla (latneskt, Gínea-Bissá)',
        'ff_Latn_LR' => 'fúla (latneskt, Líbería)',
        'ff_Latn_MR' => 'fúla (latneskt, Máritanía)',
        'ff_Latn_NE' => 'fúla (latneskt, Níger)',
        'ff_Latn_NG' => 'fúla (latneskt, Nígería)',
        'ff_Latn_SL' => 'fúla (latneskt, Síerra Leóne)',
        'ff_Latn_SN' => 'fúla (latneskt, Senegal)',
        'ff_MR' => 'fúla (Máritanía)',
        'ff_SN' => 'fúla (Senegal)',
        'fi' => 'finnska',
        'fi_FI' => 'finnska (Finnland)',
        'fo' => 'færeyska',
        'fo_DK' => 'færeyska (Danmörk)',
        'fo_FO' => 'færeyska (Færeyjar)',
        'fr' => 'franska',
        'fr_BE' => 'franska (Belgía)',
        'fr_BF' => 'franska (Búrkína Fasó)',
        'fr_BI' => 'franska (Búrúndí)',
        'fr_BJ' => 'franska (Benín)',
        'fr_BL' => 'franska (Sankti Bartólómeusareyjar)',
        'fr_CA' => 'franska (Kanada)',
        'fr_CD' => 'franska (Kongó-Kinshasa)',
        'fr_CF' => 'franska (Mið-Afríkulýðveldið)',
        'fr_CG' => 'franska (Kongó-Brazzaville)',
        'fr_CH' => 'franska (Sviss)',
        'fr_CI' => 'franska (Fílabeinsströndin)',
        'fr_CM' => 'franska (Kamerún)',
        'fr_DJ' => 'franska (Djíbútí)',
        'fr_DZ' => 'franska (Alsír)',
        'fr_FR' => 'franska (Frakkland)',
        'fr_GA' => 'franska (Gabon)',
        'fr_GF' => 'franska (Franska Gvæjana)',
        'fr_GN' => 'franska (Gínea)',
        'fr_GP' => 'franska (Gvadelúpeyjar)',
        'fr_GQ' => 'franska (Miðbaugs-Gínea)',
        'fr_HT' => 'franska (Haítí)',
        'fr_KM' => 'franska (Kómoreyjar)',
        'fr_LU' => 'franska (Lúxemborg)',
        'fr_MA' => 'franska (Marokkó)',
        'fr_MC' => 'franska (Mónakó)',
        'fr_MF' => 'franska (Saint-Martin)',
        'fr_MG' => 'franska (Madagaskar)',
        'fr_ML' => 'franska (Malí)',
        'fr_MQ' => 'franska (Martiník)',
        'fr_MR' => 'franska (Máritanía)',
        'fr_MU' => 'franska (Máritíus)',
        'fr_NC' => 'franska (Nýja-Kaledónía)',
        'fr_NE' => 'franska (Níger)',
        'fr_PF' => 'franska (Franska Pólýnesía)',
        'fr_PM' => 'franska (Sankti Pierre og Miquelon)',
        'fr_RE' => 'franska (Réunion)',
        'fr_RW' => 'franska (Rúanda)',
        'fr_SC' => 'franska (Seychelles-eyjar)',
        'fr_SN' => 'franska (Senegal)',
        'fr_SY' => 'franska (Sýrland)',
        'fr_TD' => 'franska (Tsjad)',
        'fr_TG' => 'franska (Tógó)',
        'fr_TN' => 'franska (Túnis)',
        'fr_VU' => 'franska (Vanúatú)',
        'fr_WF' => 'franska (Wallis- og Fútúnaeyjar)',
        'fr_YT' => 'franska (Mayotte)',
        'fy' => 'vesturfrísneska',
        'fy_NL' => 'vesturfrísneska (Holland)',
        'ga' => 'írska',
        'ga_GB' => 'írska (Bretland)',
        'ga_IE' => 'írska (Írland)',
        'gd' => 'skosk gelíska',
        'gd_GB' => 'skosk gelíska (Bretland)',
        'gl' => 'galisíska',
        'gl_ES' => 'galisíska (Spánn)',
        'gu' => 'gújaratí',
        'gu_IN' => 'gújaratí (Indland)',
        'gv' => 'manska',
        'gv_IM' => 'manska (Mön)',
        'ha' => 'hása',
        'ha_GH' => 'hása (Gana)',
        'ha_NE' => 'hása (Níger)',
        'ha_NG' => 'hása (Nígería)',
        'he' => 'hebreska',
        'he_IL' => 'hebreska (Ísrael)',
        'hi' => 'hindí',
        'hi_IN' => 'hindí (Indland)',
        'hi_Latn' => 'hindí (latneskt)',
        'hi_Latn_IN' => 'hindí (latneskt, Indland)',
        'hr' => 'króatíska',
        'hr_BA' => 'króatíska (Bosnía og Hersegóvína)',
        'hr_HR' => 'króatíska (Króatía)',
        'hu' => 'ungverska',
        'hu_HU' => 'ungverska (Ungverjaland)',
        'hy' => 'armenska',
        'hy_AM' => 'armenska (Armenía)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Heimurinn)',
        'id' => 'indónesíska',
        'id_ID' => 'indónesíska (Indónesía)',
        'ig' => 'ígbó',
        'ig_NG' => 'ígbó (Nígería)',
        'ii' => 'sísúanjí',
        'ii_CN' => 'sísúanjí (Kína)',
        'is' => 'íslenska',
        'is_IS' => 'íslenska (Ísland)',
        'it' => 'ítalska',
        'it_CH' => 'ítalska (Sviss)',
        'it_IT' => 'ítalska (Ítalía)',
        'it_SM' => 'ítalska (San Marínó)',
        'it_VA' => 'ítalska (Vatíkanið)',
        'ja' => 'japanska',
        'ja_JP' => 'japanska (Japan)',
        'jv' => 'javanska',
        'jv_ID' => 'javanska (Indónesía)',
        'ka' => 'georgíska',
        'ka_GE' => 'georgíska (Georgía)',
        'ki' => 'kíkújú',
        'ki_KE' => 'kíkújú (Kenía)',
        'kk' => 'kasakska',
        'kk_KZ' => 'kasakska (Kasakstan)',
        'kl' => 'grænlenska',
        'kl_GL' => 'grænlenska (Grænland)',
        'km' => 'kmer',
        'km_KH' => 'kmer (Kambódía)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Indland)',
        'ko' => 'kóreska',
        'ko_KP' => 'kóreska (Norður-Kórea)',
        'ko_KR' => 'kóreska (Suður-Kórea)',
        'ks' => 'kasmírska',
        'ks_Arab' => 'kasmírska (arabískt)',
        'ks_Arab_IN' => 'kasmírska (arabískt, Indland)',
        'ks_Deva' => 'kasmírska (devanagari)',
        'ks_Deva_IN' => 'kasmírska (devanagari, Indland)',
        'ks_IN' => 'kasmírska (Indland)',
        'ku' => 'kúrdíska',
        'ku_TR' => 'kúrdíska (Tyrkland)',
        'kw' => 'kornbreska',
        'kw_GB' => 'kornbreska (Bretland)',
        'ky' => 'kirgiska',
        'ky_KG' => 'kirgiska (Kirgistan)',
        'lb' => 'lúxemborgíska',
        'lb_LU' => 'lúxemborgíska (Lúxemborg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Úganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angóla)',
        'ln_CD' => 'lingala (Kongó-Kinshasa)',
        'ln_CF' => 'lingala (Mið-Afríkulýðveldið)',
        'ln_CG' => 'lingala (Kongó-Brazzaville)',
        'lo' => 'laó',
        'lo_LA' => 'laó (Laos)',
        'lt' => 'litháíska',
        'lt_LT' => 'litháíska (Litháen)',
        'lu' => 'lúbakatanga',
        'lu_CD' => 'lúbakatanga (Kongó-Kinshasa)',
        'lv' => 'lettneska',
        'lv_LV' => 'lettneska (Lettland)',
        'mg' => 'malagasíska',
        'mg_MG' => 'malagasíska (Madagaskar)',
        'mi' => 'maorí',
        'mi_NZ' => 'maorí (Nýja-Sjáland)',
        'mk' => 'makedónska',
        'mk_MK' => 'makedónska (Norður-Makedónía)',
        'ml' => 'malajalam',
        'ml_IN' => 'malajalam (Indland)',
        'mn' => 'mongólska',
        'mn_MN' => 'mongólska (Mongólía)',
        'mr' => 'maratí',
        'mr_IN' => 'maratí (Indland)',
        'ms' => 'malaíska',
        'ms_BN' => 'malaíska (Brúnei)',
        'ms_ID' => 'malaíska (Indónesía)',
        'ms_MY' => 'malaíska (Malasía)',
        'ms_SG' => 'malaíska (Singapúr)',
        'mt' => 'maltneska',
        'mt_MT' => 'maltneska (Malta)',
        'my' => 'búrmneska',
        'my_MM' => 'búrmneska (Mjanmar [Búrma])',
        'nb' => 'norskt bókmál',
        'nb_NO' => 'norskt bókmál (Noregur)',
        'nb_SJ' => 'norskt bókmál (Svalbarði og Jan Mayen)',
        'nd' => 'norður-ndebele',
        'nd_ZW' => 'norður-ndebele (Simbabve)',
        'ne' => 'nepalska',
        'ne_IN' => 'nepalska (Indland)',
        'ne_NP' => 'nepalska (Nepal)',
        'nl' => 'hollenska',
        'nl_AW' => 'hollenska (Arúba)',
        'nl_BE' => 'hollenska (Belgía)',
        'nl_BQ' => 'hollenska (Karíbahafshluti Hollands)',
        'nl_CW' => 'hollenska (Curacao)',
        'nl_NL' => 'hollenska (Holland)',
        'nl_SR' => 'hollenska (Súrínam)',
        'nl_SX' => 'hollenska (Sint Maarten)',
        'nn' => 'nýnorska',
        'nn_NO' => 'nýnorska (Noregur)',
        'no' => 'norska',
        'no_NO' => 'norska (Noregur)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Eþíópía)',
        'om_KE' => 'oromo (Kenía)',
        'or' => 'óría',
        'or_IN' => 'óría (Indland)',
        'os' => 'ossetíska',
        'os_GE' => 'ossetíska (Georgía)',
        'os_RU' => 'ossetíska (Rússland)',
        'pa' => 'púnjabí',
        'pa_Arab' => 'púnjabí (arabískt)',
        'pa_Arab_PK' => 'púnjabí (arabískt, Pakistan)',
        'pa_Guru' => 'púnjabí (gurmukhi)',
        'pa_Guru_IN' => 'púnjabí (gurmukhi, Indland)',
        'pa_IN' => 'púnjabí (Indland)',
        'pa_PK' => 'púnjabí (Pakistan)',
        'pl' => 'pólska',
        'pl_PL' => 'pólska (Pólland)',
        'ps' => 'pastú',
        'ps_AF' => 'pastú (Afganistan)',
        'ps_PK' => 'pastú (Pakistan)',
        'pt' => 'portúgalska',
        'pt_AO' => 'portúgalska (Angóla)',
        'pt_BR' => 'portúgalska (Brasilía)',
        'pt_CH' => 'portúgalska (Sviss)',
        'pt_CV' => 'portúgalska (Grænhöfðaeyjar)',
        'pt_GQ' => 'portúgalska (Miðbaugs-Gínea)',
        'pt_GW' => 'portúgalska (Gínea-Bissá)',
        'pt_LU' => 'portúgalska (Lúxemborg)',
        'pt_MO' => 'portúgalska (sérstjórnarsvæðið Makaó)',
        'pt_MZ' => 'portúgalska (Mósambík)',
        'pt_PT' => 'portúgalska (Portúgal)',
        'pt_ST' => 'portúgalska (Saó Tóme og Prinsípe)',
        'pt_TL' => 'portúgalska (Tímor-Leste)',
        'qu' => 'kvesjúa',
        'qu_BO' => 'kvesjúa (Bólivía)',
        'qu_EC' => 'kvesjúa (Ekvador)',
        'qu_PE' => 'kvesjúa (Perú)',
        'rm' => 'rómanska',
        'rm_CH' => 'rómanska (Sviss)',
        'rn' => 'rúndí',
        'rn_BI' => 'rúndí (Búrúndí)',
        'ro' => 'rúmenska',
        'ro_MD' => 'rúmenska (Moldóva)',
        'ro_RO' => 'rúmenska (Rúmenía)',
        'ru' => 'rússneska',
        'ru_BY' => 'rússneska (Hvíta-Rússland)',
        'ru_KG' => 'rússneska (Kirgistan)',
        'ru_KZ' => 'rússneska (Kasakstan)',
        'ru_MD' => 'rússneska (Moldóva)',
        'ru_RU' => 'rússneska (Rússland)',
        'ru_UA' => 'rússneska (Úkraína)',
        'rw' => 'kínjarvanda',
        'rw_RW' => 'kínjarvanda (Rúanda)',
        'sa' => 'sanskrít',
        'sa_IN' => 'sanskrít (Indland)',
        'sc' => 'sardínska',
        'sc_IT' => 'sardínska (Ítalía)',
        'sd' => 'sindí',
        'sd_Arab' => 'sindí (arabískt)',
        'sd_Arab_PK' => 'sindí (arabískt, Pakistan)',
        'sd_Deva' => 'sindí (devanagari)',
        'sd_Deva_IN' => 'sindí (devanagari, Indland)',
        'sd_IN' => 'sindí (Indland)',
        'sd_PK' => 'sindí (Pakistan)',
        'se' => 'norðursamíska',
        'se_FI' => 'norðursamíska (Finnland)',
        'se_NO' => 'norðursamíska (Noregur)',
        'se_SE' => 'norðursamíska (Svíþjóð)',
        'sg' => 'sangó',
        'sg_CF' => 'sangó (Mið-Afríkulýðveldið)',
        'sh' => 'serbókróatíska',
        'sh_BA' => 'serbókróatíska (Bosnía og Hersegóvína)',
        'si' => 'singalíska',
        'si_LK' => 'singalíska (Srí Lanka)',
        'sk' => 'slóvakíska',
        'sk_SK' => 'slóvakíska (Slóvakía)',
        'sl' => 'slóvenska',
        'sl_SI' => 'slóvenska (Slóvenía)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Simbabve)',
        'so' => 'sómalska',
        'so_DJ' => 'sómalska (Djíbútí)',
        'so_ET' => 'sómalska (Eþíópía)',
        'so_KE' => 'sómalska (Kenía)',
        'so_SO' => 'sómalska (Sómalía)',
        'sq' => 'albanska',
        'sq_AL' => 'albanska (Albanía)',
        'sq_MK' => 'albanska (Norður-Makedónía)',
        'sr' => 'serbneska',
        'sr_BA' => 'serbneska (Bosnía og Hersegóvína)',
        'sr_Cyrl' => 'serbneska (kyrillískt)',
        'sr_Cyrl_BA' => 'serbneska (kyrillískt, Bosnía og Hersegóvína)',
        'sr_Cyrl_ME' => 'serbneska (kyrillískt, Svartfjallaland)',
        'sr_Cyrl_RS' => 'serbneska (kyrillískt, Serbía)',
        'sr_Latn' => 'serbneska (latneskt)',
        'sr_Latn_BA' => 'serbneska (latneskt, Bosnía og Hersegóvína)',
        'sr_Latn_ME' => 'serbneska (latneskt, Svartfjallaland)',
        'sr_Latn_RS' => 'serbneska (latneskt, Serbía)',
        'sr_ME' => 'serbneska (Svartfjallaland)',
        'sr_RS' => 'serbneska (Serbía)',
        'su' => 'súndanska',
        'su_ID' => 'súndanska (Indónesía)',
        'su_Latn' => 'súndanska (latneskt)',
        'su_Latn_ID' => 'súndanska (latneskt, Indónesía)',
        'sv' => 'sænska',
        'sv_AX' => 'sænska (Álandseyjar)',
        'sv_FI' => 'sænska (Finnland)',
        'sv_SE' => 'sænska (Svíþjóð)',
        'sw' => 'svahílí',
        'sw_CD' => 'svahílí (Kongó-Kinshasa)',
        'sw_KE' => 'svahílí (Kenía)',
        'sw_TZ' => 'svahílí (Tansanía)',
        'sw_UG' => 'svahílí (Úganda)',
        'ta' => 'tamílska',
        'ta_IN' => 'tamílska (Indland)',
        'ta_LK' => 'tamílska (Srí Lanka)',
        'ta_MY' => 'tamílska (Malasía)',
        'ta_SG' => 'tamílska (Singapúr)',
        'te' => 'telúgú',
        'te_IN' => 'telúgú (Indland)',
        'tg' => 'tadsjikska',
        'tg_TJ' => 'tadsjikska (Tadsíkistan)',
        'th' => 'taílenska',
        'th_TH' => 'taílenska (Taíland)',
        'ti' => 'tígrinja',
        'ti_ER' => 'tígrinja (Erítrea)',
        'ti_ET' => 'tígrinja (Eþíópía)',
        'tk' => 'túrkmenska',
        'tk_TM' => 'túrkmenska (Túrkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filippseyjar)',
        'to' => 'tongverska',
        'to_TO' => 'tongverska (Tonga)',
        'tr' => 'tyrkneska',
        'tr_CY' => 'tyrkneska (Kýpur)',
        'tr_TR' => 'tyrkneska (Tyrkland)',
        'tt' => 'tatarska',
        'tt_RU' => 'tatarska (Rússland)',
        'ug' => 'úígúr',
        'ug_CN' => 'úígúr (Kína)',
        'uk' => 'úkraínska',
        'uk_UA' => 'úkraínska (Úkraína)',
        'ur' => 'úrdú',
        'ur_IN' => 'úrdú (Indland)',
        'ur_PK' => 'úrdú (Pakistan)',
        'uz' => 'úsbekska',
        'uz_AF' => 'úsbekska (Afganistan)',
        'uz_Arab' => 'úsbekska (arabískt)',
        'uz_Arab_AF' => 'úsbekska (arabískt, Afganistan)',
        'uz_Cyrl' => 'úsbekska (kyrillískt)',
        'uz_Cyrl_UZ' => 'úsbekska (kyrillískt, Úsbekistan)',
        'uz_Latn' => 'úsbekska (latneskt)',
        'uz_Latn_UZ' => 'úsbekska (latneskt, Úsbekistan)',
        'uz_UZ' => 'úsbekska (Úsbekistan)',
        'vi' => 'víetnamska',
        'vi_VN' => 'víetnamska (Víetnam)',
        'wo' => 'volof',
        'wo_SN' => 'volof (Senegal)',
        'xh' => 'sósa',
        'xh_ZA' => 'sósa (Suður-Afríka)',
        'yi' => 'jiddíska',
        'yi_001' => 'jiddíska (Heimurinn)',
        'yo' => 'jórúba',
        'yo_BJ' => 'jórúba (Benín)',
        'yo_NG' => 'jórúba (Nígería)',
        'zh' => 'kínverska',
        'zh_CN' => 'kínverska (Kína)',
        'zh_HK' => 'kínverska (sérstjórnarsvæðið Hong Kong)',
        'zh_Hans' => 'kínverska (einfaldað)',
        'zh_Hans_CN' => 'kínverska (einfaldað, Kína)',
        'zh_Hans_HK' => 'kínverska (einfaldað, sérstjórnarsvæðið Hong Kong)',
        'zh_Hans_MO' => 'kínverska (einfaldað, sérstjórnarsvæðið Makaó)',
        'zh_Hans_SG' => 'kínverska (einfaldað, Singapúr)',
        'zh_Hant' => 'kínverska (hefðbundið)',
        'zh_Hant_HK' => 'kínverska (hefðbundið, sérstjórnarsvæðið Hong Kong)',
        'zh_Hant_MO' => 'kínverska (hefðbundið, sérstjórnarsvæðið Makaó)',
        'zh_Hant_TW' => 'kínverska (hefðbundið, Taívan)',
        'zh_MO' => 'kínverska (sérstjórnarsvæðið Makaó)',
        'zh_SG' => 'kínverska (Singapúr)',
        'zh_TW' => 'kínverska (Taívan)',
        'zu' => 'súlú',
        'zu_ZA' => 'súlú (Suður-Afríka)',
    ],
];
