<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Griničko vrijeme (Abidjan)',
        'Africa/Accra' => 'Griničko vrijeme (Accra)',
        'Africa/Addis_Ababa' => 'Istočnoafričko vrijeme (Addis Ababa)',
        'Africa/Algiers' => 'Centralnoevropsko vrijeme (Algiers)',
        'Africa/Asmera' => 'Istočnoafričko vrijeme (Asmara)',
        'Africa/Bamako' => 'Griničko vrijeme (Bamako)',
        'Africa/Bangui' => 'Zapadnoafričko vrijeme (Bangui)',
        'Africa/Banjul' => 'Griničko vrijeme (Banjul)',
        'Africa/Bissau' => 'Griničko vrijeme (Bissau)',
        'Africa/Blantyre' => 'Centralnoafričko vrijeme (Blantyre)',
        'Africa/Brazzaville' => 'Zapadnoafričko vrijeme (Brazzaville)',
        'Africa/Bujumbura' => 'Centralnoafričko vrijeme (Bujumbura)',
        'Africa/Cairo' => 'Istočnoevropsko vrijeme (Kairo)',
        'Africa/Casablanca' => 'Zapadnoevropsko vrijeme (Kazablanka)',
        'Africa/Ceuta' => 'Centralnoevropsko vrijeme (Ceuta)',
        'Africa/Conakry' => 'Griničko vrijeme (Conakry)',
        'Africa/Dakar' => 'Griničko vrijeme (Dakar)',
        'Africa/Dar_es_Salaam' => 'Istočnoafričko vrijeme (Dar es Salaam)',
        'Africa/Djibouti' => 'Istočnoafričko vrijeme (Džibuti)',
        'Africa/Douala' => 'Zapadnoafričko vrijeme (Douala)',
        'Africa/El_Aaiun' => 'Zapadnoevropsko vrijeme (El Aaiun)',
        'Africa/Freetown' => 'Griničko vrijeme (Freetown)',
        'Africa/Gaborone' => 'Centralnoafričko vrijeme (Gaborone)',
        'Africa/Harare' => 'Centralnoafričko vrijeme (Harare)',
        'Africa/Johannesburg' => 'Južnoafričko standardno vrijeme (Johannesburg)',
        'Africa/Juba' => 'Centralnoafričko vrijeme (Juba)',
        'Africa/Kampala' => 'Istočnoafričko vrijeme (Kampala)',
        'Africa/Khartoum' => 'Centralnoafričko vrijeme (Kartum)',
        'Africa/Kigali' => 'Centralnoafričko vrijeme (Kigali)',
        'Africa/Kinshasa' => 'Zapadnoafričko vrijeme (Kinshasa)',
        'Africa/Lagos' => 'Zapadnoafričko vrijeme (Lagos)',
        'Africa/Libreville' => 'Zapadnoafričko vrijeme (Libreville)',
        'Africa/Lome' => 'Griničko vrijeme (Lome)',
        'Africa/Luanda' => 'Zapadnoafričko vrijeme (Luanda)',
        'Africa/Lubumbashi' => 'Centralnoafričko vrijeme (Lubumbashi)',
        'Africa/Lusaka' => 'Centralnoafričko vrijeme (Lusaka)',
        'Africa/Malabo' => 'Zapadnoafričko vrijeme (Malabo)',
        'Africa/Maputo' => 'Centralnoafričko vrijeme (Maputo)',
        'Africa/Maseru' => 'Južnoafričko standardno vrijeme (Maseru)',
        'Africa/Mbabane' => 'Južnoafričko standardno vrijeme (Mbabane)',
        'Africa/Mogadishu' => 'Istočnoafričko vrijeme (Mogadiš)',
        'Africa/Monrovia' => 'Griničko vrijeme (Monrovia)',
        'Africa/Nairobi' => 'Istočnoafričko vrijeme (Nairobi)',
        'Africa/Ndjamena' => 'Zapadnoafričko vrijeme (Ndjamena)',
        'Africa/Niamey' => 'Zapadnoafričko vrijeme (Niamey)',
        'Africa/Nouakchott' => 'Griničko vrijeme (Nouakchott)',
        'Africa/Ouagadougou' => 'Griničko vrijeme (Ouagadougou)',
        'Africa/Porto-Novo' => 'Zapadnoafričko vrijeme (Porto-Novo)',
        'Africa/Sao_Tome' => 'Griničko vrijeme (Sao Tome)',
        'Africa/Tripoli' => 'Istočnoevropsko vrijeme (Tripoli)',
        'Africa/Tunis' => 'Centralnoevropsko vrijeme (Tunis)',
        'Africa/Windhoek' => 'Centralnoafričko vrijeme (Windhoek)',
        'America/Adak' => 'Havajsko-aleućansko vrijeme (Adak)',
        'America/Anchorage' => 'Aljaskansko vrijeme (Anchorage)',
        'America/Anguilla' => 'Sjevernoameričko atlantsko vrijeme (Angvila)',
        'America/Antigua' => 'Sjevernoameričko atlantsko vrijeme (Antigva)',
        'America/Araguaina' => 'Brazilijsko vrijeme (Araguaina)',
        'America/Argentina/La_Rioja' => 'Argentinsko vrijeme (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentinsko vrijeme (Rio Gallegos)',
        'America/Argentina/Salta' => 'Argentinsko vrijeme (Salta)',
        'America/Argentina/San_Juan' => 'Argentinsko vrijeme (San Juan)',
        'America/Argentina/San_Luis' => 'Argentinsko vrijeme (San Luis)',
        'America/Argentina/Tucuman' => 'Argentinsko vrijeme (Tucuman)',
        'America/Argentina/Ushuaia' => 'Argentinsko vrijeme (Ushuaia)',
        'America/Aruba' => 'Sjevernoameričko atlantsko vrijeme (Aruba)',
        'America/Asuncion' => 'Paragvajsko vrijeme (Asuncion)',
        'America/Bahia' => 'Brazilijsko vrijeme (Bahia)',
        'America/Bahia_Banderas' => 'Sjevernoameričko centralno vrijeme (Bahia Banderas)',
        'America/Barbados' => 'Sjevernoameričko atlantsko vrijeme (Barbados)',
        'America/Belem' => 'Brazilijsko vrijeme (Belem)',
        'America/Belize' => 'Sjevernoameričko centralno vrijeme (Belize)',
        'America/Blanc-Sablon' => 'Sjevernoameričko atlantsko vrijeme (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazonsko vrijeme (Boa Vista)',
        'America/Bogota' => 'Kolumbijsko vrijeme (Bogota)',
        'America/Boise' => 'Sjevernoameričko planinsko vrijeme (Boise)',
        'America/Buenos_Aires' => 'Argentinsko vrijeme (Buenos Aires)',
        'America/Cambridge_Bay' => 'Sjevernoameričko planinsko vrijeme (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazonsko vrijeme (Campo Grande)',
        'America/Cancun' => 'Sjevernoameričko istočno vrijeme (Cancun)',
        'America/Caracas' => 'Venecuelansko vrijeme (Caracas)',
        'America/Catamarca' => 'Argentinsko vrijeme (Catamarca)',
        'America/Cayenne' => 'Francuskogvajansko vrijeme (Cayenne)',
        'America/Cayman' => 'Sjevernoameričko istočno vrijeme (Kajman)',
        'America/Chicago' => 'Sjevernoameričko centralno vrijeme (Chicago)',
        'America/Chihuahua' => 'Meksičko pacifičko vrijeme (Chihuahua)',
        'America/Coral_Harbour' => 'Sjevernoameričko istočno vrijeme (Atikokan)',
        'America/Cordoba' => 'Argentinsko vrijeme (Cordoba)',
        'America/Costa_Rica' => 'Sjevernoameričko centralno vrijeme (Kostarika)',
        'America/Creston' => 'Sjevernoameričko planinsko vrijeme (Creston)',
        'America/Cuiaba' => 'Amazonsko vrijeme (Cuiaba)',
        'America/Curacao' => 'Sjevernoameričko atlantsko vrijeme (Kurasao)',
        'America/Danmarkshavn' => 'Griničko vrijeme (Danmarkshavn)',
        'America/Dawson' => 'Jukonsko vrijeme (Dawson)',
        'America/Dawson_Creek' => 'Sjevernoameričko planinsko vrijeme (Dawson Creek)',
        'America/Denver' => 'Sjevernoameričko planinsko vrijeme (Denver)',
        'America/Detroit' => 'Sjevernoameričko istočno vrijeme (Detroit)',
        'America/Dominica' => 'Sjevernoameričko atlantsko vrijeme (Dominika)',
        'America/Edmonton' => 'Sjevernoameričko planinsko vrijeme (Edmonton)',
        'America/Eirunepe' => 'Acre vreme (Eirunepe)',
        'America/El_Salvador' => 'Sjevernoameričko centralno vrijeme (Salvador)',
        'America/Fort_Nelson' => 'Sjevernoameričko planinsko vrijeme (Fort Nelson)',
        'America/Fortaleza' => 'Brazilijsko vrijeme (Fortaleza)',
        'America/Glace_Bay' => 'Sjevernoameričko atlantsko vrijeme (Glace Bay)',
        'America/Godthab' => 'Zapadnogrenlandsko vrijeme (Nuuk)',
        'America/Goose_Bay' => 'Sjevernoameričko atlantsko vrijeme (Goose Bay)',
        'America/Grand_Turk' => 'Sjevernoameričko istočno vrijeme (Grand Turk)',
        'America/Grenada' => 'Sjevernoameričko atlantsko vrijeme (Grenada)',
        'America/Guadeloupe' => 'Sjevernoameričko atlantsko vrijeme (Gvadalupe)',
        'America/Guatemala' => 'Sjevernoameričko centralno vrijeme (Gvatemala)',
        'America/Guayaquil' => 'Ekvadorsko vrijeme (Guayaquil)',
        'America/Guyana' => 'Gvajansko vrijeme (Guyana)',
        'America/Halifax' => 'Sjevernoameričko atlantsko vrijeme (Halifax)',
        'America/Havana' => 'Kubansko vrijeme (Havana)',
        'America/Hermosillo' => 'Meksičko pacifičko vrijeme (Hermosillo)',
        'America/Indiana/Knox' => 'Sjevernoameričko centralno vrijeme (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Sjevernoameričko istočno vrijeme (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Sjevernoameričko istočno vrijeme (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Sjevernoameričko centralno vrijeme (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Sjevernoameričko istočno vrijeme (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Sjevernoameričko istočno vrijeme (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Sjevernoameričko istočno vrijeme (Winamac, Indiana)',
        'America/Indianapolis' => 'Sjevernoameričko istočno vrijeme (Indianapolis)',
        'America/Inuvik' => 'Sjevernoameričko planinsko vrijeme (Inuvik)',
        'America/Iqaluit' => 'Sjevernoameričko istočno vrijeme (Iqaluit)',
        'America/Jamaica' => 'Sjevernoameričko istočno vrijeme (Jamajka)',
        'America/Jujuy' => 'Argentinsko vrijeme (Jujuy)',
        'America/Juneau' => 'Aljaskansko vrijeme (Juneau)',
        'America/Kentucky/Monticello' => 'Sjevernoameričko istočno vrijeme (Monticello, Kentucky)',
        'America/Kralendijk' => 'Sjevernoameričko atlantsko vrijeme (Kralendijk)',
        'America/La_Paz' => 'Bolivijsko vrijeme (La Paz)',
        'America/Lima' => 'Peruansko vrijeme (Lima)',
        'America/Los_Angeles' => 'Sjevernoameričko pacifičko vrijeme (Los Angeles)',
        'America/Louisville' => 'Sjevernoameričko istočno vrijeme (Louisville)',
        'America/Lower_Princes' => 'Sjevernoameričko atlantsko vrijeme (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brazilijsko vrijeme (Maceio)',
        'America/Managua' => 'Sjevernoameričko centralno vrijeme (Managua)',
        'America/Manaus' => 'Amazonsko vrijeme (Manaus)',
        'America/Marigot' => 'Sjevernoameričko atlantsko vrijeme (Marigot)',
        'America/Martinique' => 'Sjevernoameričko atlantsko vrijeme (Martinique)',
        'America/Matamoros' => 'Sjevernoameričko centralno vrijeme (Matamoros)',
        'America/Mazatlan' => 'Meksičko pacifičko vrijeme (Mazatlan)',
        'America/Mendoza' => 'Argentinsko vrijeme (Mendoza)',
        'America/Menominee' => 'Sjevernoameričko centralno vrijeme (Menominee)',
        'America/Merida' => 'Sjevernoameričko centralno vrijeme (Merida)',
        'America/Metlakatla' => 'Aljaskansko vrijeme (Metlakatla)',
        'America/Mexico_City' => 'Sjevernoameričko centralno vrijeme (Mexico City)',
        'America/Miquelon' => 'Vrijeme na Ostrvima Sveti Petar i Mikelon (Miquelon)',
        'America/Moncton' => 'Sjevernoameričko atlantsko vrijeme (Moncton)',
        'America/Monterrey' => 'Sjevernoameričko centralno vrijeme (Monterrey)',
        'America/Montevideo' => 'Urugvajsko vrijeme (Montevideo)',
        'America/Montreal' => 'Kanada (Montreal)',
        'America/Montserrat' => 'Sjevernoameričko atlantsko vrijeme (Montserrat)',
        'America/Nassau' => 'Sjevernoameričko istočno vrijeme (Nassau)',
        'America/New_York' => 'Sjevernoameričko istočno vrijeme (New York)',
        'America/Nipigon' => 'Sjevernoameričko istočno vrijeme (Nipigon)',
        'America/Nome' => 'Aljaskansko vrijeme (Nome)',
        'America/Noronha' => 'Vrijeme na ostrvu Fernando di Noronja (Noronha)',
        'America/North_Dakota/Beulah' => 'Sjevernoameričko centralno vrijeme (Beulah, Sjeverna Dakota)',
        'America/North_Dakota/Center' => 'Sjevernoameričko centralno vrijeme (Center, Sjeverna Dakota)',
        'America/North_Dakota/New_Salem' => 'Sjevernoameričko centralno vrijeme (New Salem, Sjeverna Dakota)',
        'America/Ojinaga' => 'Sjevernoameričko planinsko vrijeme (Ojinaga)',
        'America/Panama' => 'Sjevernoameričko istočno vrijeme (Panama)',
        'America/Pangnirtung' => 'Sjevernoameričko istočno vrijeme (Pangnirtung)',
        'America/Paramaribo' => 'Surinamsko vrijeme (Paramaribo)',
        'America/Phoenix' => 'Sjevernoameričko planinsko vrijeme (Phoenix)',
        'America/Port-au-Prince' => 'Sjevernoameričko istočno vrijeme (Port-au-Prince)',
        'America/Port_of_Spain' => 'Sjevernoameričko atlantsko vrijeme (Port of Spain)',
        'America/Porto_Velho' => 'Amazonsko vrijeme (Porto Velho)',
        'America/Puerto_Rico' => 'Sjevernoameričko atlantsko vrijeme (Portoriko)',
        'America/Punta_Arenas' => 'Čileansko vrijeme (Punta Arenas)',
        'America/Rainy_River' => 'Sjevernoameričko centralno vrijeme (Rainy River)',
        'America/Rankin_Inlet' => 'Sjevernoameričko centralno vrijeme (Rankin Inlet)',
        'America/Recife' => 'Brazilijsko vrijeme (Recife)',
        'America/Regina' => 'Sjevernoameričko centralno vrijeme (Regina)',
        'America/Resolute' => 'Sjevernoameričko centralno vrijeme (Resolute)',
        'America/Rio_Branco' => 'Acre vreme (Rio Branco)',
        'America/Santa_Isabel' => 'Sjeverozapadno meksičko vrijeme (Santa Isabel)',
        'America/Santarem' => 'Brazilijsko vrijeme (Santarem)',
        'America/Santiago' => 'Čileansko vrijeme (Santiago)',
        'America/Santo_Domingo' => 'Sjevernoameričko atlantsko vrijeme (Santo Domingo)',
        'America/Sao_Paulo' => 'Brazilijsko vrijeme (Sao Paulo)',
        'America/Scoresbysund' => 'Istočnogrenlandsko vrijeme (Ittoqqortoormiit)',
        'America/Sitka' => 'Aljaskansko vrijeme (Sitka)',
        'America/St_Barthelemy' => 'Sjevernoameričko atlantsko vrijeme (St. Barthelemy)',
        'America/St_Johns' => 'Njufaundlendsko vrijeme (St. John’s)',
        'America/St_Kitts' => 'Sjevernoameričko atlantsko vrijeme (St. Kitts)',
        'America/St_Lucia' => 'Sjevernoameričko atlantsko vrijeme (St. Lucia)',
        'America/St_Thomas' => 'Sjevernoameričko atlantsko vrijeme (St. Thomas)',
        'America/St_Vincent' => 'Sjevernoameričko atlantsko vrijeme (St. Vincent)',
        'America/Swift_Current' => 'Sjevernoameričko centralno vrijeme (Swift Current)',
        'America/Tegucigalpa' => 'Sjevernoameričko centralno vrijeme (Tegucigalpa)',
        'America/Thule' => 'Sjevernoameričko atlantsko vrijeme (Thule)',
        'America/Thunder_Bay' => 'Sjevernoameričko istočno vrijeme (Thunder Bay)',
        'America/Tijuana' => 'Sjevernoameričko pacifičko vrijeme (Tijuana)',
        'America/Toronto' => 'Sjevernoameričko istočno vrijeme (Toronto)',
        'America/Tortola' => 'Sjevernoameričko atlantsko vrijeme (Tortola)',
        'America/Vancouver' => 'Sjevernoameričko pacifičko vrijeme (Vancouver)',
        'America/Whitehorse' => 'Jukonsko vrijeme (Whitehorse)',
        'America/Winnipeg' => 'Sjevernoameričko centralno vrijeme (Winnipeg)',
        'America/Yakutat' => 'Aljaskansko vrijeme (Yakutat)',
        'America/Yellowknife' => 'Sjevernoameričko planinsko vrijeme (Yellowknife)',
        'Antarctica/Casey' => 'Antarktika (Casey)',
        'Antarctica/Davis' => 'Vrijeme stanice Davis',
        'Antarctica/DumontDUrville' => 'Vrijeme stanice Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Istočnoaustralijsko vrijeme (Macquarie)',
        'Antarctica/Mawson' => 'Vrijeme stanice Mawson',
        'Antarctica/McMurdo' => 'Novozelandsko vrijeme (McMurdo)',
        'Antarctica/Palmer' => 'Čileansko vrijeme (Palmer)',
        'Antarctica/Rothera' => 'Vrijeme stanice Rothera',
        'Antarctica/Syowa' => 'Vrijeme stanice Syowa',
        'Antarctica/Troll' => 'Griničko vrijeme (Troll)',
        'Antarctica/Vostok' => 'Vrijeme stanice Vostok',
        'Arctic/Longyearbyen' => 'Centralnoevropsko vrijeme (Longyearbyen)',
        'Asia/Aden' => 'Arabijsko vrijeme (Aden)',
        'Asia/Almaty' => 'Istočnokazahstansko vrijeme (Almati)',
        'Asia/Amman' => 'Istočnoevropsko vrijeme (Aman)',
        'Asia/Anadyr' => 'Anadir vreme',
        'Asia/Aqtau' => 'Zapadnokazahstansko vrijeme (Aktau)',
        'Asia/Aqtobe' => 'Zapadnokazahstansko vrijeme (Akutobe)',
        'Asia/Ashgabat' => 'Turkmenistansko vrijeme (Ašhabad)',
        'Asia/Atyrau' => 'Zapadnokazahstansko vrijeme (Atiraj)',
        'Asia/Baghdad' => 'Arabijsko vrijeme (Bagdad)',
        'Asia/Bahrain' => 'Arabijsko vrijeme (Bahrein)',
        'Asia/Baku' => 'Azerbejdžansko vrijeme (Baku)',
        'Asia/Bangkok' => 'Indokinesko vrijeme (Bangkok)',
        'Asia/Barnaul' => 'Rusija (Barnaul)',
        'Asia/Beirut' => 'Istočnoevropsko vrijeme (Bejrut)',
        'Asia/Bishkek' => 'Kirgistansko vrijeme (Biškek)',
        'Asia/Brunei' => 'Brunejsko vrijeme (Bruneji)',
        'Asia/Calcutta' => 'Indijsko standardno vrijeme (Kolkata)',
        'Asia/Chita' => 'Jakutsko vrijeme (Chita)',
        'Asia/Choibalsan' => 'Ulanbatorsko vrijeme (Čojbalsan)',
        'Asia/Colombo' => 'Indijsko standardno vrijeme (Kolombo)',
        'Asia/Damascus' => 'Istočnoevropsko vrijeme (Damask)',
        'Asia/Dhaka' => 'Bangladeško vrijeme (Daka)',
        'Asia/Dili' => 'Istočnotimorsko vrijeme (Dili)',
        'Asia/Dubai' => 'Zalivsko standardno vrijeme (Dubai)',
        'Asia/Dushanbe' => 'Tadžikistansko vrijeme (Dušanbe)',
        'Asia/Famagusta' => 'Istočnoevropsko vrijeme (Famagusta)',
        'Asia/Gaza' => 'Istočnoevropsko vrijeme (Gaza)',
        'Asia/Hebron' => 'Istočnoevropsko vrijeme (Hebron)',
        'Asia/Hong_Kong' => 'Hongkonško vrijeme (Hong Kong)',
        'Asia/Hovd' => 'Hovdsko vrijeme',
        'Asia/Irkutsk' => 'Irkutsko vrijeme',
        'Asia/Jakarta' => 'Zapadnoindonezijsko vrijeme (Džakarta)',
        'Asia/Jayapura' => 'Istočnoindonezijsko vrijeme (Džajapura)',
        'Asia/Jerusalem' => 'Izraelsko vrijeme (Jeruzalem)',
        'Asia/Kabul' => 'Afganistansko vrijeme (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamčatski vreme (Kamčatka)',
        'Asia/Karachi' => 'Pakistansko vrijeme (Karači)',
        'Asia/Katmandu' => 'Nepalsko vrijeme (Katmandu)',
        'Asia/Khandyga' => 'Jakutsko vrijeme (Handiga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsko vrijeme',
        'Asia/Kuala_Lumpur' => 'Malezijsko vrijeme (Kuala Lumpur)',
        'Asia/Kuching' => 'Malezijsko vrijeme (Kučing)',
        'Asia/Kuwait' => 'Arabijsko vrijeme (Kuvajt)',
        'Asia/Macau' => 'Kinesko vrijeme (Makau)',
        'Asia/Magadan' => 'Magadansko vrijeme',
        'Asia/Makassar' => 'Centralnoindonezijsko vrijeme (Makasar)',
        'Asia/Manila' => 'Filipinsko vrijeme (Manila)',
        'Asia/Muscat' => 'Zalivsko standardno vrijeme (Muskat)',
        'Asia/Nicosia' => 'Istočnoevropsko vrijeme (Nikozija)',
        'Asia/Novokuznetsk' => 'Krasnojarsko vrijeme (Novokuznjeck)',
        'Asia/Novosibirsk' => 'Novosibirsko vrijeme',
        'Asia/Omsk' => 'Omsko vrijeme',
        'Asia/Oral' => 'Zapadnokazahstansko vrijeme (Oral)',
        'Asia/Phnom_Penh' => 'Indokinesko vrijeme (Pnom Pen)',
        'Asia/Pontianak' => 'Zapadnoindonezijsko vrijeme (Pontianak)',
        'Asia/Pyongyang' => 'Korejsko vrijeme (Pjongjang)',
        'Asia/Qatar' => 'Arabijsko vrijeme (Katar)',
        'Asia/Qostanay' => 'Istočnokazahstansko vrijeme (Kostanaj)',
        'Asia/Qyzylorda' => 'Zapadnokazahstansko vrijeme (Kizilorda)',
        'Asia/Rangoon' => 'Mijanmarsko vrijeme (Rangun)',
        'Asia/Riyadh' => 'Arabijsko vrijeme (Rijad)',
        'Asia/Saigon' => 'Indokinesko vrijeme (Ho Ši Min)',
        'Asia/Sakhalin' => 'Sahalinsko vrijeme',
        'Asia/Samarkand' => 'Uzbekistansko vrijeme (Samarkand)',
        'Asia/Seoul' => 'Korejsko vrijeme (Seul)',
        'Asia/Shanghai' => 'Kinesko vrijeme (Šangaj)',
        'Asia/Singapore' => 'Singapursko standardno vrijeme',
        'Asia/Srednekolymsk' => 'Magadansko vrijeme (Srednekolymsk)',
        'Asia/Taipei' => 'Tajpejsko vrijeme',
        'Asia/Tashkent' => 'Uzbekistansko vrijeme (Taškent)',
        'Asia/Tbilisi' => 'Gruzijsko vrijeme (Tbilisi)',
        'Asia/Tehran' => 'Iransko vrijeme (Teheran)',
        'Asia/Thimphu' => 'Butansko vrijeme (Thimphu)',
        'Asia/Tokyo' => 'Japansko vrijeme (Tokio)',
        'Asia/Tomsk' => 'Rusija (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulanbatorsko vrijeme (Ulan Bator)',
        'Asia/Urumqi' => 'Kina (Urumči)',
        'Asia/Ust-Nera' => 'Vladivostočko vrijeme (Ust-Nera)',
        'Asia/Vientiane' => 'Indokinesko vrijeme (Vijentijan)',
        'Asia/Vladivostok' => 'Vladivostočko vrijeme (Vladivostok)',
        'Asia/Yakutsk' => 'Jakutsko vrijeme',
        'Asia/Yekaterinburg' => 'Jekaterinburško vrijeme (Jekaterinburg)',
        'Asia/Yerevan' => 'Armensko vrijeme (Jerevan)',
        'Atlantic/Azores' => 'Azorsko vrijeme (Azori)',
        'Atlantic/Bermuda' => 'Sjevernoameričko atlantsko vrijeme (Bermuda)',
        'Atlantic/Canary' => 'Zapadnoevropsko vrijeme (Kanari)',
        'Atlantic/Cape_Verde' => 'Zelenortsko vrijeme (Kape Verde)',
        'Atlantic/Faeroe' => 'Zapadnoevropsko vrijeme (Faroe)',
        'Atlantic/Madeira' => 'Zapadnoevropsko vrijeme (Madeira)',
        'Atlantic/Reykjavik' => 'Griničko vrijeme (Rejkjavik)',
        'Atlantic/South_Georgia' => 'Južnodžordžijsko vrijeme (South Georgia)',
        'Atlantic/St_Helena' => 'Griničko vrijeme (Sveta Helena)',
        'Atlantic/Stanley' => 'Folklandsko vrijeme (Stanley)',
        'Australia/Adelaide' => 'Centralnoaustralijsko vrijeme (Adelaide)',
        'Australia/Brisbane' => 'Istočnoaustralijsko vrijeme (Brisbane)',
        'Australia/Broken_Hill' => 'Centralnoaustralijsko vrijeme (Broken Hill)',
        'Australia/Currie' => 'Istočnoaustralijsko vrijeme (Currie)',
        'Australia/Darwin' => 'Centralnoaustralijsko vrijeme (Darwin)',
        'Australia/Eucla' => 'Australijsko centralno zapadno vrijeme (Eucla)',
        'Australia/Hobart' => 'Istočnoaustralijsko vrijeme (Hobart)',
        'Australia/Lindeman' => 'Istočnoaustralijsko vrijeme (Lindeman)',
        'Australia/Lord_Howe' => 'Vrijeme na Ostrvu Lord Hau',
        'Australia/Melbourne' => 'Istočnoaustralijsko vrijeme (Melburn)',
        'Australia/Perth' => 'Zapadnoaustralijsko vrijeme (Pert)',
        'Australia/Sydney' => 'Istočnoaustralijsko vrijeme (Sidnej)',
        'CST6CDT' => 'Sjevernoameričko centralno vrijeme',
        'EST5EDT' => 'Sjevernoameričko istočno vrijeme',
        'Etc/GMT' => 'Griničko vrijeme',
        'Etc/UTC' => 'Koordinirano svjetsko vrijeme',
        'Europe/Amsterdam' => 'Centralnoevropsko vrijeme (Amsterdam)',
        'Europe/Andorra' => 'Centralnoevropsko vrijeme (Andora)',
        'Europe/Astrakhan' => 'Moskovsko vrijeme (Astrahan)',
        'Europe/Athens' => 'Istočnoevropsko vrijeme (Atina)',
        'Europe/Belgrade' => 'Centralnoevropsko vrijeme (Beograd)',
        'Europe/Berlin' => 'Centralnoevropsko vrijeme (Berlin)',
        'Europe/Bratislava' => 'Centralnoevropsko vrijeme (Bratislava)',
        'Europe/Brussels' => 'Centralnoevropsko vrijeme (Brisel)',
        'Europe/Bucharest' => 'Istočnoevropsko vrijeme (Bukurešt)',
        'Europe/Budapest' => 'Centralnoevropsko vrijeme (Budimpešta)',
        'Europe/Busingen' => 'Centralnoevropsko vrijeme (Busingen)',
        'Europe/Chisinau' => 'Istočnoevropsko vrijeme (Kišinjev)',
        'Europe/Copenhagen' => 'Centralnoevropsko vrijeme (Kopenhagen)',
        'Europe/Dublin' => 'Griničko vrijeme (Dablin)',
        'Europe/Gibraltar' => 'Centralnoevropsko vrijeme (Gibraltar)',
        'Europe/Guernsey' => 'Griničko vrijeme (Gernzi)',
        'Europe/Helsinki' => 'Istočnoevropsko vrijeme (Helsinki)',
        'Europe/Isle_of_Man' => 'Griničko vrijeme (Ostrvo Man)',
        'Europe/Istanbul' => 'Turska (Istanbul)',
        'Europe/Jersey' => 'Griničko vrijeme (Jersey)',
        'Europe/Kaliningrad' => 'Istočnoevropsko vrijeme (Kalinjingrad)',
        'Europe/Kiev' => 'Istočnoevropsko vrijeme (Kijev)',
        'Europe/Kirov' => 'Rusija (Kirov)',
        'Europe/Lisbon' => 'Zapadnoevropsko vrijeme (Lisabon)',
        'Europe/Ljubljana' => 'Centralnoevropsko vrijeme (Ljubljana)',
        'Europe/London' => 'Griničko vrijeme (London)',
        'Europe/Luxembourg' => 'Centralnoevropsko vrijeme (Luksemburg)',
        'Europe/Madrid' => 'Centralnoevropsko vrijeme (Madrid)',
        'Europe/Malta' => 'Centralnoevropsko vrijeme (Malta)',
        'Europe/Mariehamn' => 'Istočnoevropsko vrijeme (Mariehamn)',
        'Europe/Minsk' => 'Moskovsko vrijeme (Minsk)',
        'Europe/Monaco' => 'Centralnoevropsko vrijeme (Monako)',
        'Europe/Moscow' => 'Moskovsko vrijeme (Moskva)',
        'Europe/Oslo' => 'Centralnoevropsko vrijeme (Oslo)',
        'Europe/Paris' => 'Centralnoevropsko vrijeme (Pariz)',
        'Europe/Podgorica' => 'Centralnoevropsko vrijeme (Podgorica)',
        'Europe/Prague' => 'Centralnoevropsko vrijeme (Prag)',
        'Europe/Riga' => 'Istočnoevropsko vrijeme (Riga)',
        'Europe/Rome' => 'Centralnoevropsko vrijeme (Rim)',
        'Europe/Samara' => 'Samara vreme',
        'Europe/San_Marino' => 'Centralnoevropsko vrijeme (San Marino)',
        'Europe/Sarajevo' => 'Centralnoevropsko vrijeme (Sarajevo)',
        'Europe/Saratov' => 'Moskovsko vrijeme (Saratov)',
        'Europe/Simferopol' => 'Moskovsko vrijeme (Simferopolj)',
        'Europe/Skopje' => 'Centralnoevropsko vrijeme (Skoplje)',
        'Europe/Sofia' => 'Istočnoevropsko vrijeme (Sofija)',
        'Europe/Stockholm' => 'Centralnoevropsko vrijeme (Štokholm)',
        'Europe/Tallinn' => 'Istočnoevropsko vrijeme (Talin)',
        'Europe/Tirane' => 'Centralnoevropsko vrijeme (Tirana)',
        'Europe/Ulyanovsk' => 'Moskovsko vrijeme (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Istočnoevropsko vrijeme (Užgorod)',
        'Europe/Vaduz' => 'Centralnoevropsko vrijeme (Vaduz)',
        'Europe/Vatican' => 'Centralnoevropsko vrijeme (Vatikan)',
        'Europe/Vienna' => 'Centralnoevropsko vrijeme (Beč)',
        'Europe/Vilnius' => 'Istočnoevropsko vrijeme (Vilnius)',
        'Europe/Volgograd' => 'Volgogradsko vrijeme',
        'Europe/Warsaw' => 'Centralnoevropsko vrijeme (Varšava)',
        'Europe/Zagreb' => 'Centralnoevropsko vrijeme (Zagreb)',
        'Europe/Zaporozhye' => 'Istočnoevropsko vrijeme (Zaporožje)',
        'Europe/Zurich' => 'Centralnoevropsko vrijeme (Cirih)',
        'Indian/Antananarivo' => 'Istočnoafričko vrijeme (Antananarivo)',
        'Indian/Chagos' => 'Vrijeme na Indijskom okeanu (Chagos)',
        'Indian/Christmas' => 'Vrijeme na Božićnom Ostrvu (Božićno ostrvo)',
        'Indian/Cocos' => 'Vrijeme na Ostrvima Kokos (Kokosova ostrva)',
        'Indian/Comoro' => 'Istočnoafričko vrijeme (Comoro)',
        'Indian/Kerguelen' => 'Vrijeme na Francuskoj Južnoj Teritoriji i Antarktiku (Kerguelen)',
        'Indian/Mahe' => 'Sejšelsko vrijeme (Mahe)',
        'Indian/Maldives' => 'Maldivsko vrijeme (Maldivi)',
        'Indian/Mauritius' => 'Mauricijsko vrijeme (Mauricijus)',
        'Indian/Mayotte' => 'Istočnoafričko vrijeme (Mayotte)',
        'Indian/Reunion' => 'Reunionsko vrijeme',
        'MST7MDT' => 'Sjevernoameričko planinsko vrijeme',
        'PST8PDT' => 'Sjevernoameričko pacifičko vrijeme',
        'Pacific/Apia' => 'Apijsko vrijeme (Apia)',
        'Pacific/Auckland' => 'Novozelandsko vrijeme (Auckland)',
        'Pacific/Bougainville' => 'Vrijeme na Papui Novoj Gvineji (Bougainville)',
        'Pacific/Chatham' => 'Čatamsko vrijeme (Chatham)',
        'Pacific/Easter' => 'Uskršnjeostrvsko vrijeme (Easter)',
        'Pacific/Efate' => 'Vanuatuansko vrijeme (Efate)',
        'Pacific/Enderbury' => 'Vrijeme na Ostrvima Finiks (Enderbury)',
        'Pacific/Fakaofo' => 'Vrijeme na Ostrvu Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Vrijeme na Fidžiju',
        'Pacific/Funafuti' => 'Tuvaluansko vrijeme (Funafuti)',
        'Pacific/Galapagos' => 'Galapagosko vrijeme',
        'Pacific/Gambier' => 'Gambijersko vrijeme (Gambier)',
        'Pacific/Guadalcanal' => 'Vrijeme na Solomonskim ostrvima (Guadalcanal)',
        'Pacific/Guam' => 'Čamorsko standardno vrijeme (Guam)',
        'Pacific/Honolulu' => 'Havajsko-aleućansko vrijeme (Honolulu)',
        'Pacific/Johnston' => 'Havajsko-aleućansko vrijeme (Johnston)',
        'Pacific/Kiritimati' => 'Vrijeme na Ostrvima Lajn (Kiritimati)',
        'Pacific/Kosrae' => 'Vrijeme na Ostrvu Kosrae',
        'Pacific/Kwajalein' => 'Vrijeme na Maršalovim ostrvima (Kwajalein)',
        'Pacific/Majuro' => 'Vrijeme na Maršalovim ostrvima (Majuro)',
        'Pacific/Marquesas' => 'Vrijeme na Ostrvima Markiz (Marquesas)',
        'Pacific/Midway' => 'Samoansko vrijeme (Midway)',
        'Pacific/Nauru' => 'Vrijeme na Ostrvu Nauru',
        'Pacific/Niue' => 'Vrijeme na Ostrvu Niue',
        'Pacific/Norfolk' => 'Norfolško vrijeme (Norfolk)',
        'Pacific/Noumea' => 'Novokaledonijsko vrijeme (Noumea)',
        'Pacific/Pago_Pago' => 'Samoansko vrijeme (Pago Pago)',
        'Pacific/Palau' => 'Vrijeme na Ostrvu Palau',
        'Pacific/Pitcairn' => 'Vrijeme na Ostrvima Pitkern',
        'Pacific/Ponape' => 'Vrijeme na Ostrvu Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Vrijeme na Papui Novoj Gvineji (Port Moresby)',
        'Pacific/Rarotonga' => 'Vrijeme na Kukovim ostrvima (Rarotonga)',
        'Pacific/Saipan' => 'Čamorsko standardno vrijeme (Saipan)',
        'Pacific/Tahiti' => 'Tahićansko vrijeme (Tahiti)',
        'Pacific/Tarawa' => 'Vrijeme na Gilbertovim ostrvima (Tarawa)',
        'Pacific/Tongatapu' => 'Tongansko vrijeme (Tongatapu)',
        'Pacific/Truk' => 'Čučko vrijeme (Chuuk)',
        'Pacific/Wake' => 'Vrijeme na Ostrvu Vejk (Wake)',
        'Pacific/Wallis' => 'Vrijeme na Ostrvima Valis i Futuna',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT %s',
        'HourFormatNeg' => ' -%02d:%02d',
    ],
];
