<?php

/**
 * Turkish PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Elçin Özel
 * @author Can Yılmaz
 * @author Mehmet Benlioğlu
 * @author @yasinaydin
 * @author Ogün Karakuş
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP Hatası: Oturum açılamadı.';
$PHPMAILER_LANG['buggy_php']            = 'PHP sürümünüz iletilerin bozulmasına neden olabilecek bir hatadan etkileniyor. Bunu düzeltmek için, SMTP kullanarak göndermeye geçin, mail.add_x_header seçeneğini devre dışı bırakın php.ini dosyanızdaki mail.add_x_header seçeneğini devre dışı bırakın, MacOS veya Linux geçin veya PHP sürümünü 7.0.17+ veya 7.1.3+ sürümüne yükseltin,';
$PHPMAILER_LANG['connect_host']         = 'SMTP Hatası: SMTP sunucusuna bağlanılamadı.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP Hatası: Veri kabul edilmedi.';
$PHPMAILER_LANG['empty_message']        = 'Mesajın içeriği boş';
$PHPMAILER_LANG['encoding']             = 'Bilinmeyen karakter kodlama: ';
$PHPMAILER_LANG['execute']              = 'Çalıştırılamadı: ';
$PHPMAILER_LANG['extension_missing']    = 'Eklenti bulunamadı: ';
$PHPMAILER_LANG['file_access']          = 'Dosyaya erişilemedi: ';
$PHPMAILER_LANG['file_open']            = 'Dosya Hatası: Dosya açılamadı: ';
$PHPMAILER_LANG['from_failed']          = 'Belirtilen adreslere gönderme başarısız: ';
$PHPMAILER_LANG['instantiate']          = 'Örnek e-posta fonksiyonu oluşturulamadı.';
$PHPMAILER_LANG['invalid_address']      = 'Geçersiz e-posta adresi: ';
$PHPMAILER_LANG['invalid_header']       = 'Geçersiz başlık adı veya değeri: ';
$PHPMAILER_LANG['invalid_hostentry']    = 'Geçersiz ana bilgisayar girişi: ';
$PHPMAILER_LANG['invalid_host']         = 'Geçersiz ana bilgisayar: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' e-posta kütüphanesi desteklenmiyor.';
$PHPMAILER_LANG['provide_address']      = 'En az bir alıcı e-posta adresi belirtmelisiniz.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP Hatası: Belirtilen alıcılara ulaşılamadı: ';
$PHPMAILER_LANG['signing']              = 'İmzalama hatası: ';
$PHPMAILER_LANG['smtp_code']            = 'SMTP kodu: ';
$PHPMAILER_LANG['smtp_code_ex']         = 'ek SMTP bilgileri: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP connect() fonksiyonu başarısız.';
$PHPMAILER_LANG['smtp_detail']          = 'SMTP SMTP Detayı: ';
$PHPMAILER_LANG['smtp_error']           = 'SMTP sunucu hatası: ';
$PHPMAILER_LANG['variable_set']         = 'Değişken ayarlanamadı ya da sıfırlanamadı: ';
