<?php

declare(strict_types=1);

namespace SAML2\XML\mdrpi;

/**
 * Common definitions for the mdrpi metadata extension.
 *
 * @link: http://docs.oasis-open.org/security/saml/Post2.0/saml-metadata-rpi/v1.0/saml-metadata-rpi-v1.0.pdf
 * @package SimpleSAMLphp
 */
class Common
{
    const NS_MDRPI = 'urn:oasis:names:tc:SAML:metadata:rpi';
}
