<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (South Africa)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amariikị',
        'am_ET' => 'Amariikị (Ethiopia)',
        'ar' => 'Arabiikị',
        'ar_001' => 'Arabiikị (Uwa)',
        'ar_AE' => 'Arabiikị (United Arab Emirates)',
        'ar_BH' => 'Arabiikị (Bahrain)',
        'ar_DJ' => 'Arabiikị (Djibouti)',
        'ar_DZ' => 'Arabiikị (Algeria)',
        'ar_EG' => 'Arabiikị (Egypt)',
        'ar_EH' => 'Arabiikị (Ọdịda Anyanwụ Sahara)',
        'ar_ER' => 'Arabiikị (Eritrea)',
        'ar_IL' => 'Arabiikị (Israel)',
        'ar_IQ' => 'Arabiikị (Iraq)',
        'ar_JO' => 'Arabiikị (Jordan)',
        'ar_KM' => 'Arabiikị (Comorosu)',
        'ar_KW' => 'Arabiikị (Kuwait)',
        'ar_LB' => 'Arabiikị (Lebanon)',
        'ar_LY' => 'Arabiikị (Libia)',
        'ar_MA' => 'Arabiikị (Morocco)',
        'ar_MR' => 'Arabiikị (Mauritania)',
        'ar_OM' => 'Arabiikị (Oman)',
        'ar_PS' => 'Arabiikị (Palestinian Territories)',
        'ar_QA' => 'Arabiikị (Qatar)',
        'ar_SA' => 'Arabiikị (Saudi Arabia)',
        'ar_SD' => 'Arabiikị (Sudan)',
        'ar_SO' => 'Arabiikị (Somalia)',
        'ar_SS' => 'Arabiikị (South Sudan)',
        'ar_SY' => 'Arabiikị (Syria)',
        'ar_TD' => 'Arabiikị (Chad)',
        'ar_TN' => 'Arabiikị (Tunisia)',
        'ar_YE' => 'Arabiikị (Yemen)',
        'as' => 'Asamisị',
        'as_IN' => 'Asamisị (India)',
        'az' => 'Azerbajanị',
        'az_AZ' => 'Azerbajanị (Azerbaijan)',
        'az_Cyrl' => 'Azerbajanị (Mkpụrụ Okwu Cyrillic)',
        'az_Cyrl_AZ' => 'Azerbajanị (Mkpụrụ Okwu Cyrillic, Azerbaijan)',
        'az_Latn' => 'Azerbajanị (Latin)',
        'az_Latn_AZ' => 'Azerbajanị (Latin, Azerbaijan)',
        'be' => 'Belarusianụ',
        'be_BY' => 'Belarusianụ (Belarus)',
        'bg' => 'Bọlụgarịa',
        'bg_BG' => 'Bọlụgarịa (Bulgaria)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (Bangladesh)',
        'bn_IN' => 'Bengali (India)',
        'bo' => 'Tibetan',
        'bo_CN' => 'Tibetan (China)',
        'bo_IN' => 'Tibetan (India)',
        'br' => 'Breton',
        'br_FR' => 'Breton (France)',
        'bs' => 'Bosnia',
        'bs_BA' => 'Bosnia (Bosnia & Herzegovina)',
        'bs_Cyrl' => 'Bosnia (Mkpụrụ Okwu Cyrillic)',
        'bs_Cyrl_BA' => 'Bosnia (Mkpụrụ Okwu Cyrillic, Bosnia & Herzegovina)',
        'bs_Latn' => 'Bosnia (Latin)',
        'bs_Latn_BA' => 'Bosnia (Latin, Bosnia & Herzegovina)',
        'ca' => 'Catalan',
        'ca_AD' => 'Catalan (Andorra)',
        'ca_ES' => 'Catalan (Spain)',
        'ca_FR' => 'Catalan (France)',
        'ca_IT' => 'Catalan (Italy)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (Rụssịa)',
        'cs' => 'Cheekị',
        'cs_CZ' => 'Cheekị (Czechia)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Rụssịa)',
        'cy' => 'Wesh',
        'cy_GB' => 'Wesh (United Kingdom)',
        'da' => 'Danịsh',
        'da_DK' => 'Danịsh (Denmark)',
        'da_GL' => 'Danịsh (Greenland)',
        'de' => 'Jamanị',
        'de_AT' => 'Jamanị (Austria)',
        'de_BE' => 'Jamanị (Belgium)',
        'de_CH' => 'Jamanị (Switzerland)',
        'de_DE' => 'Jamanị (Jamanị)',
        'de_IT' => 'Jamanị (Italy)',
        'de_LI' => 'Jamanị (Liechtenstein)',
        'de_LU' => 'Jamanị (Luxembourg)',
        'dz' => 'Dọzngọka',
        'dz_BT' => 'Dọzngọka (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Giriikị',
        'el_CY' => 'Giriikị (Cyprus)',
        'el_GR' => 'Giriikị (Greece)',
        'en' => 'Bekee',
        'en_001' => 'Bekee (Uwa)',
        'en_150' => 'Bekee (Europe)',
        'en_AE' => 'Bekee (United Arab Emirates)',
        'en_AG' => 'Bekee (Antigua na Barbuda)',
        'en_AI' => 'Bekee (Anguilla)',
        'en_AS' => 'Bekee (American Samoa)',
        'en_AT' => 'Bekee (Austria)',
        'en_AU' => 'Bekee (Australia)',
        'en_BB' => 'Bekee (Barbados)',
        'en_BE' => 'Bekee (Belgium)',
        'en_BI' => 'Bekee (Burundi)',
        'en_BM' => 'Bekee (Bemuda)',
        'en_BS' => 'Bekee (Bahamas)',
        'en_BW' => 'Bekee (Botswana)',
        'en_BZ' => 'Bekee (Belize)',
        'en_CA' => 'Bekee (Kanada)',
        'en_CC' => 'Bekee (Agwaetiti Cocos [Keeling])',
        'en_CH' => 'Bekee (Switzerland)',
        'en_CK' => 'Bekee (Agwaetiti Cook)',
        'en_CM' => 'Bekee (Cameroon)',
        'en_CX' => 'Bekee (Agwaetiti Christmas)',
        'en_CY' => 'Bekee (Cyprus)',
        'en_DE' => 'Bekee (Jamanị)',
        'en_DK' => 'Bekee (Denmark)',
        'en_DM' => 'Bekee (Dominika)',
        'en_ER' => 'Bekee (Eritrea)',
        'en_FI' => 'Bekee (Finland)',
        'en_FJ' => 'Bekee (Fiji)',
        'en_FK' => 'Bekee (Agwaetiti Falkland)',
        'en_FM' => 'Bekee (Micronesia)',
        'en_GB' => 'Bekee (United Kingdom)',
        'en_GD' => 'Bekee (Grenada)',
        'en_GG' => 'Bekee (Guernsey)',
        'en_GH' => 'Bekee (Ghana)',
        'en_GI' => 'Bekee (Gibraltar)',
        'en_GM' => 'Bekee (Gambia)',
        'en_GU' => 'Bekee (Guam)',
        'en_GY' => 'Bekee (Guyana)',
        'en_HK' => 'Bekee (Hong Kong SAR China)',
        'en_IE' => 'Bekee (Ireland)',
        'en_IL' => 'Bekee (Israel)',
        'en_IM' => 'Bekee (Isle of Man)',
        'en_IN' => 'Bekee (India)',
        'en_IO' => 'Bekee (British Indian Ocean Territory)',
        'en_JE' => 'Bekee (Jersey)',
        'en_JM' => 'Bekee (Jamaika)',
        'en_KE' => 'Bekee (Kenya)',
        'en_KI' => 'Bekee (Kiribati)',
        'en_KN' => 'Bekee (Kitts na Nevis Dị nsọ)',
        'en_KY' => 'Bekee (Agwaetiti Cayman)',
        'en_LC' => 'Bekee (Lucia Dị nsọ)',
        'en_LR' => 'Bekee (Liberia)',
        'en_LS' => 'Bekee (Lesotho)',
        'en_MG' => 'Bekee (Madagaskar)',
        'en_MH' => 'Bekee (Agwaetiti Marshall)',
        'en_MO' => 'Bekee (Macao SAR China)',
        'en_MP' => 'Bekee (Agwaetiti Northern Mariana)',
        'en_MS' => 'Bekee (Montserrat)',
        'en_MT' => 'Bekee (Malta)',
        'en_MU' => 'Bekee (Mauritius)',
        'en_MV' => 'Bekee (Maldivesa)',
        'en_MW' => 'Bekee (Malawi)',
        'en_MY' => 'Bekee (Malaysia)',
        'en_NA' => 'Bekee (Namibia)',
        'en_NF' => 'Bekee (Agwaetiti Norfolk)',
        'en_NG' => 'Bekee (Naịjịrịa)',
        'en_NL' => 'Bekee (Netherlands)',
        'en_NR' => 'Bekee (Nauru)',
        'en_NU' => 'Bekee (Niue)',
        'en_NZ' => 'Bekee (New Zealand)',
        'en_PG' => 'Bekee (Papua New Guinea)',
        'en_PH' => 'Bekee (Philippines)',
        'en_PK' => 'Bekee (Pakistan)',
        'en_PN' => 'Bekee (Agwaetiti Pitcairn)',
        'en_PR' => 'Bekee (Puerto Rico)',
        'en_PW' => 'Bekee (Palau)',
        'en_RW' => 'Bekee (Rwanda)',
        'en_SB' => 'Bekee (Agwaetiti Solomon)',
        'en_SC' => 'Bekee (Seychelles)',
        'en_SD' => 'Bekee (Sudan)',
        'en_SE' => 'Bekee (Sweden)',
        'en_SG' => 'Bekee (Singapore)',
        'en_SH' => 'Bekee (St. Helena)',
        'en_SI' => 'Bekee (Slovenia)',
        'en_SL' => 'Bekee (Sierra Leone)',
        'en_SS' => 'Bekee (South Sudan)',
        'en_SX' => 'Bekee (Sint Maarten)',
        'en_SZ' => 'Bekee (Eswatini)',
        'en_TC' => 'Bekee (Agwaetiti Turks na Caicos)',
        'en_TK' => 'Bekee (Tokelau)',
        'en_TO' => 'Bekee (Tonga)',
        'en_TT' => 'Bekee (Trinidad na Tobago)',
        'en_TV' => 'Bekee (Tuvalu)',
        'en_TZ' => 'Bekee (Tanzania)',
        'en_UG' => 'Bekee (Uganda)',
        'en_UM' => 'Bekee (Obere Agwaetiti Dị Na Mpụga U.S)',
        'en_US' => 'Bekee (United States)',
        'en_VC' => 'Bekee (Vincent na Grenadines Dị nsọ)',
        'en_VG' => 'Bekee (Agwaetiti British Virgin)',
        'en_VI' => 'Bekee (Agwaetiti Virgin nke US)',
        'en_VU' => 'Bekee (Vanuatu)',
        'en_WS' => 'Bekee (Samoa)',
        'en_ZA' => 'Bekee (South Africa)',
        'en_ZM' => 'Bekee (Zambia)',
        'en_ZW' => 'Bekee (Zimbabwe)',
        'eo' => 'Ndị Esperantọ',
        'eo_001' => 'Ndị Esperantọ (Uwa)',
        'es' => 'Spanishi',
        'es_419' => 'Spanishi (Latin America)',
        'es_AR' => 'Spanishi (Argentina)',
        'es_BO' => 'Spanishi (Bolivia)',
        'es_BR' => 'Spanishi (Brazil)',
        'es_BZ' => 'Spanishi (Belize)',
        'es_CL' => 'Spanishi (Chile)',
        'es_CO' => 'Spanishi (Colombia)',
        'es_CR' => 'Spanishi (Kosta Rika)',
        'es_CU' => 'Spanishi (Cuba)',
        'es_DO' => 'Spanishi (Dominican Republik)',
        'es_EC' => 'Spanishi (Ecuador)',
        'es_ES' => 'Spanishi (Spain)',
        'es_GQ' => 'Spanishi (Equatorial Guinea)',
        'es_GT' => 'Spanishi (Guatemala)',
        'es_HN' => 'Spanishi (Honduras)',
        'es_MX' => 'Spanishi (Mexico)',
        'es_NI' => 'Spanishi (Nicaragua)',
        'es_PA' => 'Spanishi (Panama)',
        'es_PE' => 'Spanishi (Peru)',
        'es_PH' => 'Spanishi (Philippines)',
        'es_PR' => 'Spanishi (Puerto Rico)',
        'es_PY' => 'Spanishi (Paraguay)',
        'es_SV' => 'Spanishi (El Salvador)',
        'es_US' => 'Spanishi (United States)',
        'es_UY' => 'Spanishi (Uruguay)',
        'es_VE' => 'Spanishi (Venezuela)',
        'et' => 'Ndị Estọnịa',
        'et_EE' => 'Ndị Estọnịa (Estonia)',
        'eu' => 'Baskwe',
        'eu_ES' => 'Baskwe (Spain)',
        'fa' => 'Peshianụ',
        'fa_AF' => 'Peshianụ (Afghanistan)',
        'fa_IR' => 'Peshianụ (Iran)',
        'ff' => 'Fula',
        'ff_Adlm' => 'Fula (Adlam)',
        'ff_Adlm_BF' => 'Fula (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fula (Adlam, Cameroon)',
        'ff_Adlm_GH' => 'Fula (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Fula (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Fula (Adlam, Guinea)',
        'ff_Adlm_GW' => 'Fula (Adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'Fula (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Fula (Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Fula (Adlam, Niger)',
        'ff_Adlm_NG' => 'Fula (Adlam, Naịjịrịa)',
        'ff_Adlm_SL' => 'Fula (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fula (Adlam, Senegal)',
        'ff_CM' => 'Fula (Cameroon)',
        'ff_GN' => 'Fula (Guinea)',
        'ff_Latn' => 'Fula (Latin)',
        'ff_Latn_BF' => 'Fula (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fula (Latin, Cameroon)',
        'ff_Latn_GH' => 'Fula (Latin, Ghana)',
        'ff_Latn_GM' => 'Fula (Latin, Gambia)',
        'ff_Latn_GN' => 'Fula (Latin, Guinea)',
        'ff_Latn_GW' => 'Fula (Latin, Guinea-Bissau)',
        'ff_Latn_LR' => 'Fula (Latin, Liberia)',
        'ff_Latn_MR' => 'Fula (Latin, Mauritania)',
        'ff_Latn_NE' => 'Fula (Latin, Niger)',
        'ff_Latn_NG' => 'Fula (Latin, Naịjịrịa)',
        'ff_Latn_SL' => 'Fula (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fula (Latin, Senegal)',
        'ff_MR' => 'Fula (Mauritania)',
        'ff_SN' => 'Fula (Senegal)',
        'fi' => 'Fịnịsh',
        'fi_FI' => 'Fịnịsh (Finland)',
        'fo' => 'Farọse',
        'fo_DK' => 'Farọse (Denmark)',
        'fo_FO' => 'Farọse (Agwaetiti Faroe)',
        'fr' => 'Fụrenchị',
        'fr_BE' => 'Fụrenchị (Belgium)',
        'fr_BF' => 'Fụrenchị (Burkina Faso)',
        'fr_BI' => 'Fụrenchị (Burundi)',
        'fr_BJ' => 'Fụrenchị (Binin)',
        'fr_BL' => 'Fụrenchị (Barthélemy Dị nsọ)',
        'fr_CA' => 'Fụrenchị (Kanada)',
        'fr_CD' => 'Fụrenchị (Congo - Kinshasa)',
        'fr_CF' => 'Fụrenchị (Central African Republik)',
        'fr_CG' => 'Fụrenchị (Congo)',
        'fr_CH' => 'Fụrenchị (Switzerland)',
        'fr_CI' => 'Fụrenchị (Côte d’Ivoire)',
        'fr_CM' => 'Fụrenchị (Cameroon)',
        'fr_DJ' => 'Fụrenchị (Djibouti)',
        'fr_DZ' => 'Fụrenchị (Algeria)',
        'fr_FR' => 'Fụrenchị (France)',
        'fr_GA' => 'Fụrenchị (Gabon)',
        'fr_GF' => 'Fụrenchị (Frenchi Guiana)',
        'fr_GN' => 'Fụrenchị (Guinea)',
        'fr_GP' => 'Fụrenchị (Guadeloupe)',
        'fr_GQ' => 'Fụrenchị (Equatorial Guinea)',
        'fr_HT' => 'Fụrenchị (Hati)',
        'fr_KM' => 'Fụrenchị (Comorosu)',
        'fr_LU' => 'Fụrenchị (Luxembourg)',
        'fr_MA' => 'Fụrenchị (Morocco)',
        'fr_MC' => 'Fụrenchị (Monaco)',
        'fr_MF' => 'Fụrenchị (Martin Dị nsọ)',
        'fr_MG' => 'Fụrenchị (Madagaskar)',
        'fr_ML' => 'Fụrenchị (Mali)',
        'fr_MQ' => 'Fụrenchị (Martinique)',
        'fr_MR' => 'Fụrenchị (Mauritania)',
        'fr_MU' => 'Fụrenchị (Mauritius)',
        'fr_NC' => 'Fụrenchị (New Caledonia)',
        'fr_NE' => 'Fụrenchị (Niger)',
        'fr_PF' => 'Fụrenchị (Frenchi Polynesia)',
        'fr_PM' => 'Fụrenchị (Pierre na Miquelon Dị nsọ)',
        'fr_RE' => 'Fụrenchị (Réunion)',
        'fr_RW' => 'Fụrenchị (Rwanda)',
        'fr_SC' => 'Fụrenchị (Seychelles)',
        'fr_SN' => 'Fụrenchị (Senegal)',
        'fr_SY' => 'Fụrenchị (Syria)',
        'fr_TD' => 'Fụrenchị (Chad)',
        'fr_TG' => 'Fụrenchị (Togo)',
        'fr_TN' => 'Fụrenchị (Tunisia)',
        'fr_VU' => 'Fụrenchị (Vanuatu)',
        'fr_WF' => 'Fụrenchị (Wallis & Futuna)',
        'fr_YT' => 'Fụrenchị (Mayotte)',
        'fy' => 'Westan Frịsịan',
        'fy_NL' => 'Westan Frịsịan (Netherlands)',
        'ga' => 'Ịrịsh',
        'ga_GB' => 'Ịrịsh (United Kingdom)',
        'ga_IE' => 'Ịrịsh (Ireland)',
        'gd' => 'Sụkọtịs Gelị',
        'gd_GB' => 'Sụkọtịs Gelị (United Kingdom)',
        'gl' => 'Galịcịan',
        'gl_ES' => 'Galịcịan (Spain)',
        'gu' => 'Gụaratị',
        'gu_IN' => 'Gụaratị (India)',
        'gv' => 'Mansị',
        'gv_IM' => 'Mansị (Isle of Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Naịjịrịa)',
        'he' => 'Hebrew',
        'he_IL' => 'Hebrew (Israel)',
        'hi' => 'Hindị',
        'hi_IN' => 'Hindị (India)',
        'hi_Latn' => 'Hindị (Latin)',
        'hi_Latn_IN' => 'Hindị (Latin, India)',
        'hr' => 'Kọrọtịan',
        'hr_BA' => 'Kọrọtịan (Bosnia & Herzegovina)',
        'hr_HR' => 'Kọrọtịan (Croatia)',
        'hu' => 'Hụngarian',
        'hu_HU' => 'Hụngarian (Hungary)',
        'hy' => 'Armenianị',
        'hy_AM' => 'Armenianị (Armenia)',
        'ia' => 'Intalịgụa',
        'ia_001' => 'Intalịgụa (Uwa)',
        'id' => 'Indonisia',
        'id_ID' => 'Indonisia (Indonesia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Naịjịrịa)',
        'ii' => 'Sịchụayị',
        'ii_CN' => 'Sịchụayị (China)',
        'is' => 'Icịlandịk',
        'is_IS' => 'Icịlandịk (Iceland)',
        'it' => 'Italịanu',
        'it_CH' => 'Italịanu (Switzerland)',
        'it_IT' => 'Italịanu (Italy)',
        'it_SM' => 'Italịanu (San Marino)',
        'it_VA' => 'Italịanu (Vatican City)',
        'ja' => 'Japaniisi',
        'ja_JP' => 'Japaniisi (Japan)',
        'jv' => 'Java',
        'jv_ID' => 'Java (Indonesia)',
        'ka' => 'Geọjịan',
        'ka_GE' => 'Geọjịan (Georgia)',
        'ki' => 'Kịkụyụ',
        'ki_KE' => 'Kịkụyụ (Kenya)',
        'kk' => 'Kazak',
        'kk_KZ' => 'Kazak (Kazakhstan)',
        'kl' => 'Kalaalịsụt',
        'kl_GL' => 'Kalaalịsụt (Greenland)',
        'km' => 'Keme',
        'km_KH' => 'Keme (Cambodia)',
        'kn' => 'Kanhada',
        'kn_IN' => 'Kanhada (India)',
        'ko' => 'Korịa',
        'ko_KP' => 'Korịa (Ugwu Korea)',
        'ko_KR' => 'Korịa (South Korea)',
        'ks' => 'Kashmịrị',
        'ks_Arab' => 'Kashmịrị (Mkpụrụ Okwu Arabic)',
        'ks_Arab_IN' => 'Kashmịrị (Mkpụrụ Okwu Arabic, India)',
        'ks_Deva' => 'Kashmịrị (Mkpụrụ ọkwụ Devangarị)',
        'ks_Deva_IN' => 'Kashmịrị (Mkpụrụ ọkwụ Devangarị, India)',
        'ks_IN' => 'Kashmịrị (India)',
        'ku' => 'Ndị Kụrdịsh',
        'ku_TR' => 'Ndị Kụrdịsh (Turkey)',
        'kw' => 'Kọnịsh',
        'kw_GB' => 'Kọnịsh (United Kingdom)',
        'ky' => 'Kyrayz',
        'ky_KG' => 'Kyrayz (Kyrgyzstan)',
        'lb' => 'Lụxenbọụgịsh',
        'lb_LU' => 'Lụxenbọụgịsh (Luxembourg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lịngala',
        'ln_AO' => 'Lịngala (Angola)',
        'ln_CD' => 'Lịngala (Congo - Kinshasa)',
        'ln_CF' => 'Lịngala (Central African Republik)',
        'ln_CG' => 'Lịngala (Congo)',
        'lo' => 'Laọ',
        'lo_LA' => 'Laọ (Laos)',
        'lt' => 'Lituanian',
        'lt_LT' => 'Lituanian (Lithuania)',
        'lu' => 'Lịba-Katanga',
        'lu_CD' => 'Lịba-Katanga (Congo - Kinshasa)',
        'lv' => 'Latviani',
        'lv_LV' => 'Latviani (Latvia)',
        'mg' => 'Malagasị',
        'mg_MG' => 'Malagasị (Madagaskar)',
        'mi' => 'Maọrị',
        'mi_NZ' => 'Maọrị (New Zealand)',
        'mk' => 'Masedọnịa',
        'mk_MK' => 'Masedọnịa (North Macedonia)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mọngolịan',
        'mn_MN' => 'Mọngolịan (Mongolia)',
        'mr' => 'Maratị',
        'mr_IN' => 'Maratị (India)',
        'ms' => 'Maleyi',
        'ms_BN' => 'Maleyi (Brunei)',
        'ms_ID' => 'Maleyi (Indonesia)',
        'ms_MY' => 'Maleyi (Malaysia)',
        'ms_SG' => 'Maleyi (Singapore)',
        'mt' => 'Matịse',
        'mt_MT' => 'Matịse (Malta)',
        'my' => 'Bụrmese',
        'my_MM' => 'Bụrmese (Myanmar [Burma])',
        'nb' => 'Nọrweyịan Bọkmal',
        'nb_NO' => 'Nọrweyịan Bọkmal (Norway)',
        'nb_SJ' => 'Nọrweyịan Bọkmal (Svalbard & Jan Mayen)',
        'nd' => 'Nọrtụ Ndabede',
        'nd_ZW' => 'Nọrtụ Ndabede (Zimbabwe)',
        'ne' => 'Nepali',
        'ne_IN' => 'Nepali (India)',
        'ne_NP' => 'Nepali (Nepal)',
        'nl' => 'Dọchị',
        'nl_AW' => 'Dọchị (Aruba)',
        'nl_BE' => 'Dọchị (Belgium)',
        'nl_BQ' => 'Dọchị (Caribbean Netherlands)',
        'nl_CW' => 'Dọchị (Kurakao)',
        'nl_NL' => 'Dọchị (Netherlands)',
        'nl_SR' => 'Dọchị (Suriname)',
        'nl_SX' => 'Dọchị (Sint Maarten)',
        'nn' => 'Nọrweyịan Nynersk',
        'nn_NO' => 'Nọrweyịan Nynersk (Norway)',
        'no' => 'Nọrweyịan',
        'no_NO' => 'Nọrweyịan (Norway)',
        'om' => 'Ọromo',
        'om_ET' => 'Ọromo (Ethiopia)',
        'om_KE' => 'Ọromo (Kenya)',
        'or' => 'Ọdịa',
        'or_IN' => 'Ọdịa (India)',
        'os' => 'Osetik',
        'os_GE' => 'Osetik (Georgia)',
        'os_RU' => 'Osetik (Rụssịa)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Mkpụrụ Okwu Arabic)',
        'pa_Arab_PK' => 'Punjabi (Mkpụrụ Okwu Arabic, Pakistan)',
        'pa_Guru' => 'Punjabi (Mkpụrụ ọkwụ Gụrmụkị)',
        'pa_Guru_IN' => 'Punjabi (Mkpụrụ ọkwụ Gụrmụkị, India)',
        'pa_IN' => 'Punjabi (India)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Poliishi',
        'pl_PL' => 'Poliishi (Poland)',
        'ps' => 'Pashọ',
        'ps_AF' => 'Pashọ (Afghanistan)',
        'ps_PK' => 'Pashọ (Pakistan)',
        'pt' => 'Pọrtụgụese',
        'pt_AO' => 'Pọrtụgụese (Angola)',
        'pt_BR' => 'Pọrtụgụese (Brazil)',
        'pt_CH' => 'Pọrtụgụese (Switzerland)',
        'pt_CV' => 'Pọrtụgụese (Cape Verde)',
        'pt_GQ' => 'Pọrtụgụese (Equatorial Guinea)',
        'pt_GW' => 'Pọrtụgụese (Guinea-Bissau)',
        'pt_LU' => 'Pọrtụgụese (Luxembourg)',
        'pt_MO' => 'Pọrtụgụese (Macao SAR China)',
        'pt_MZ' => 'Pọrtụgụese (Mozambik)',
        'pt_PT' => 'Pọrtụgụese (Portugal)',
        'pt_ST' => 'Pọrtụgụese (São Tomé & Príncipe)',
        'pt_TL' => 'Pọrtụgụese (Timor-Leste)',
        'qu' => 'Qụechụa',
        'qu_BO' => 'Qụechụa (Bolivia)',
        'qu_EC' => 'Qụechụa (Ecuador)',
        'qu_PE' => 'Qụechụa (Peru)',
        'rm' => 'Rọmansị',
        'rm_CH' => 'Rọmansị (Switzerland)',
        'rn' => 'Rụndị',
        'rn_BI' => 'Rụndị (Burundi)',
        'ro' => 'Romania',
        'ro_MD' => 'Romania (Moldova)',
        'ro_RO' => 'Romania (Romania)',
        'ru' => 'Rọshian',
        'ru_BY' => 'Rọshian (Belarus)',
        'ru_KG' => 'Rọshian (Kyrgyzstan)',
        'ru_KZ' => 'Rọshian (Kazakhstan)',
        'ru_MD' => 'Rọshian (Moldova)',
        'ru_RU' => 'Rọshian (Rụssịa)',
        'ru_UA' => 'Rọshian (Ukraine)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Sansịkịt',
        'sa_IN' => 'Sansịkịt (India)',
        'sc' => 'Sardinian',
        'sc_IT' => 'Sardinian (Italy)',
        'sd' => 'Sịndh',
        'sd_Arab' => 'Sịndh (Mkpụrụ Okwu Arabic)',
        'sd_Arab_PK' => 'Sịndh (Mkpụrụ Okwu Arabic, Pakistan)',
        'sd_Deva' => 'Sịndh (Mkpụrụ ọkwụ Devangarị)',
        'sd_Deva_IN' => 'Sịndh (Mkpụrụ ọkwụ Devangarị, India)',
        'sd_IN' => 'Sịndh (India)',
        'sd_PK' => 'Sịndh (Pakistan)',
        'se' => 'Nọrtan Samị',
        'se_FI' => 'Nọrtan Samị (Finland)',
        'se_NO' => 'Nọrtan Samị (Norway)',
        'se_SE' => 'Nọrtan Samị (Sweden)',
        'sg' => 'Sangọ',
        'sg_CF' => 'Sangọ (Central African Republik)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Slova',
        'sk_SK' => 'Slova (Slovakia)',
        'sl' => 'Slovịan',
        'sl_SI' => 'Slovịan (Slovenia)',
        'sn' => 'Shọna',
        'sn_ZW' => 'Shọna (Zimbabwe)',
        'so' => 'Somali',
        'so_DJ' => 'Somali (Djibouti)',
        'so_ET' => 'Somali (Ethiopia)',
        'so_KE' => 'Somali (Kenya)',
        'so_SO' => 'Somali (Somalia)',
        'sq' => 'Albanianị',
        'sq_AL' => 'Albanianị (Albania)',
        'sq_MK' => 'Albanianị (North Macedonia)',
        'sr' => 'Sebịan',
        'sr_BA' => 'Sebịan (Bosnia & Herzegovina)',
        'sr_Cyrl' => 'Sebịan (Mkpụrụ Okwu Cyrillic)',
        'sr_Cyrl_BA' => 'Sebịan (Mkpụrụ Okwu Cyrillic, Bosnia & Herzegovina)',
        'sr_Cyrl_ME' => 'Sebịan (Mkpụrụ Okwu Cyrillic, Montenegro)',
        'sr_Cyrl_RS' => 'Sebịan (Mkpụrụ Okwu Cyrillic, Serbia)',
        'sr_Latn' => 'Sebịan (Latin)',
        'sr_Latn_BA' => 'Sebịan (Latin, Bosnia & Herzegovina)',
        'sr_Latn_ME' => 'Sebịan (Latin, Montenegro)',
        'sr_Latn_RS' => 'Sebịan (Latin, Serbia)',
        'sr_ME' => 'Sebịan (Montenegro)',
        'sr_RS' => 'Sebịan (Serbia)',
        'su' => 'Sudanese',
        'su_ID' => 'Sudanese (Indonesia)',
        'su_Latn' => 'Sudanese (Latin)',
        'su_Latn_ID' => 'Sudanese (Latin, Indonesia)',
        'sv' => 'Sụwidiishi',
        'sv_AX' => 'Sụwidiishi (Agwaetiti Aland)',
        'sv_FI' => 'Sụwidiishi (Finland)',
        'sv_SE' => 'Sụwidiishi (Sweden)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Congo - Kinshasa)',
        'sw_KE' => 'Swahili (Kenya)',
        'sw_TZ' => 'Swahili (Tanzania)',
        'sw_UG' => 'Swahili (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (India)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Malaysia)',
        'ta_SG' => 'Tamil (Singapore)',
        'te' => 'Telụgụ',
        'te_IN' => 'Telụgụ (India)',
        'tg' => 'Tajịk',
        'tg_TJ' => 'Tajịk (Tajikistan)',
        'th' => 'Taị',
        'th_TH' => 'Taị (Thailand)',
        'ti' => 'Tịgrịnya',
        'ti_ER' => 'Tịgrịnya (Eritrea)',
        'ti_ET' => 'Tịgrịnya (Ethiopia)',
        'tk' => 'Turkịs',
        'tk_TM' => 'Turkịs (Turkmenistan)',
        'to' => 'Tọngan',
        'to_TO' => 'Tọngan (Tonga)',
        'tr' => 'Tọkiishi',
        'tr_CY' => 'Tọkiishi (Cyprus)',
        'tr_TR' => 'Tọkiishi (Turkey)',
        'tt' => 'Tata',
        'tt_RU' => 'Tata (Rụssịa)',
        'ug' => 'Ụyghụr',
        'ug_CN' => 'Ụyghụr (China)',
        'uk' => 'Ukureenị',
        'uk_UA' => 'Ukureenị (Ukraine)',
        'ur' => 'Urdụ',
        'ur_IN' => 'Urdụ (India)',
        'ur_PK' => 'Urdụ (Pakistan)',
        'uz' => 'Ụzbek',
        'uz_AF' => 'Ụzbek (Afghanistan)',
        'uz_Arab' => 'Ụzbek (Mkpụrụ Okwu Arabic)',
        'uz_Arab_AF' => 'Ụzbek (Mkpụrụ Okwu Arabic, Afghanistan)',
        'uz_Cyrl' => 'Ụzbek (Mkpụrụ Okwu Cyrillic)',
        'uz_Cyrl_UZ' => 'Ụzbek (Mkpụrụ Okwu Cyrillic, Uzbekistan)',
        'uz_Latn' => 'Ụzbek (Latin)',
        'uz_Latn_UZ' => 'Ụzbek (Latin, Uzbekistan)',
        'uz_UZ' => 'Ụzbek (Uzbekistan)',
        'vi' => 'Vietnamisi',
        'vi_VN' => 'Vietnamisi (Vietnam)',
        'wo' => 'Wolọf',
        'wo_SN' => 'Wolọf (Senegal)',
        'xh' => 'Xhọsa',
        'xh_ZA' => 'Xhọsa (South Africa)',
        'yi' => 'Yịdịsh',
        'yi_001' => 'Yịdịsh (Uwa)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Binin)',
        'yo_NG' => 'Yoruba (Naịjịrịa)',
        'zh' => 'Chainisi',
        'zh_CN' => 'Chainisi (China)',
        'zh_HK' => 'Chainisi (Hong Kong SAR China)',
        'zh_Hans' => 'Chainisi (Nke dị mfe)',
        'zh_Hans_CN' => 'Chainisi (Nke dị mfe, China)',
        'zh_Hans_HK' => 'Chainisi (Nke dị mfe, Hong Kong SAR China)',
        'zh_Hans_MO' => 'Chainisi (Nke dị mfe, Macao SAR China)',
        'zh_Hans_SG' => 'Chainisi (Nke dị mfe, Singapore)',
        'zh_Hant' => 'Chainisi (Izugbe)',
        'zh_Hant_HK' => 'Chainisi (Izugbe, Hong Kong SAR China)',
        'zh_Hant_MO' => 'Chainisi (Izugbe, Macao SAR China)',
        'zh_Hant_TW' => 'Chainisi (Izugbe, Taiwan)',
        'zh_MO' => 'Chainisi (Macao SAR China)',
        'zh_SG' => 'Chainisi (Singapore)',
        'zh_TW' => 'Chainisi (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (South Africa)',
    ],
];
