<?php

return [
    'Names' => [
        'ak' => 'Kiakan',
        'am' => 'Kiamhari',
        'ar' => 'Kĩarabu',
        'be' => 'Kibelarusi',
        'bg' => 'Kibulgaria',
        'bn' => 'Kibangla',
        'cs' => 'Kichecki',
        'de' => 'Kĩnjeremani',
        'el' => 'Kigiriki',
        'en' => 'Gĩthungũ',
        'es' => 'Kihispania',
        'fa' => 'Kiajemi',
        'fr' => 'Kĩbaranja',
        'ha' => 'Kihausa',
        'hi' => 'Kĩhĩndĩ',
        'hu' => 'Kihungari',
        'id' => 'Kiindonesia',
        'ig' => 'Kiigbo',
        'it' => 'Kĩtaliano',
        'ja' => 'Kĩnjabani',
        'jv' => 'Kijava',
        'ki' => 'Gikuyu',
        'km' => 'Kikambodia',
        'ko' => 'Kikorea',
        'ms' => 'Kimalesia',
        'my' => 'Kiburma',
        'ne' => 'Kinepali',
        'nl' => 'Kiholanzi',
        'pa' => 'Kipunjabi',
        'pl' => 'Kipolandi',
        'pt' => 'Kireno',
        'ro' => 'Kiromania',
        'ru' => 'Kĩracia',
        'rw' => 'Kinyarwanda',
        'so' => 'Kĩcumarĩ',
        'sv' => 'Kiswidi',
        'ta' => 'Kitamil',
        'th' => 'Kitailandi',
        'tr' => 'Kituruki',
        'uk' => 'Kiukrania',
        'ur' => 'Kiurdu',
        'vi' => 'Kivietinamu',
        'yo' => 'Kiyoruba',
        'zh' => 'Kĩcaina',
        'zu' => 'Kizulu',
    ],
    'LocalizedNames' => [
    ],
];
