<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Diami ti Awon Orílɛ́ède Arabu',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lɛ́ɛ̀kì Àlìbáníà',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dírààmù Àmɛ́níà',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Pɛ́sò Agɛntínà',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dɔla ti Orílɛ́ède Ástràlìá',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dɔ́là Bábádɔ̀ɔ̀sì',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Tákà Báńgíládɛ̀ɛ̀shì',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Owó Lɛ́fì Bɔ̀lìgéríà',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dina ti Orílɛ́ède Báránì',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dɔ́là Bɛ̀múdà',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dɔ́là Bùrùnéì',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bɔlifiánò Bɔ̀lífíà',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Owó ti Orílɛ̀-èdè Brazil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dɔ́là Bàhámà',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ìngɔ́tírɔ̀mù Bútàànì',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula Bɔ̀tìsúwánà',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rɔ́bù Bɛ̀lárùùsì',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dɔ́là Bɛ̀lísè',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dɔ́là Kánádà',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Pɛ́sò Shílè',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Reminibi ti Orílɛ́ède sháínà',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Pɛ́sò Kòlóḿbíà',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kólɔ́ɔ̀nì Kosita Ríkà',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Pɛ́sò Yíyípadà Kúbà',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Pɛ́sò Kúbà',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna Shɛ́ɛ̀kì',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Kírónì Dáníshì',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Pɛ́sò Dòníníkà',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dina ti Orílɛ́ède Àlùgèríánì',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'pɔɔn ti Orílɛ́ède Egipiti',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dɔ́là Fíjì',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Pɔ́n-ùn Erékùsù Falkland',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Pɔ́n-ùn ti Orilɛ̀-èdè Gɛ̀ɛ́sì',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lárì Jɔ́jíà',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'shidi ti Orílɛ́ède Gana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Pɔ́n-ùn Gibúrátà',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Faransi ti Orílɛ́ède Gini',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Kúɛ́tísààlì Guatimílà',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dɔ́là Gùyánà',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dɔ́là Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lɛmipírà Ɔ́ńdúrà',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kúnà Kúróshíà',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gɔ́dì Àítì',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Fɔ́ríǹtì Hɔ̀ngérí',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Shékélì Tuntun Ísírɛ̀ɛ̀lì',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupi ti Orílɛ́ède Indina',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dɔ́là Jàmáíkà',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dínárì Jɔ́dàànì',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni ti Orílɛ́ède Japani',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shiili Kenya',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Ráyò Kàm̀bɔ́díà',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Wɔ́ɔ̀nù Àríwá Kòríà',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Wɔ́ɔ̀nù Gúúsù Kòríà',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dɔ́là Erékùsù Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tɛngé Kasakísítàànì',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Pɔ́n-ùn Lebanese',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dɔla Liberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ti Orílɛ́ède Lesoto',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Dɛ́nà Masidóníà',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya ti Orílɛ́ède Maritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya ti Orílɛ́ède Maritania',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rúfìyá Mɔ̀lìdífà',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Pɛ́sò Mɛ́síkò',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ríngìtì Màléshíà',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metika ti Orílɛ́ède Mosamibiki',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mɛ́tíkààlì Mòsáḿbíìkì',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dɔla Namibíà',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Kɔ̀dóbà Naikarágúà',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'kórónì Nɔ́wè',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rúpìì Nɛ̵́pààlì',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dɔ́là New Zealand',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Sílɔ̀tì Pɔ́líshì',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'Owó ruble ti ilɛ̀ Rɔ́shíà',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riya ti Orílɛ́ède Saudi',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dɔ́là Erékùsù Sɔ́lómɔ́nì',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Pɔ́n-ùn Sùdáànì',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Pɔɔun ti Orílɛ́ède Sudani',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dɔ́là Síngápɔ̀',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Pɔ́n-un Elena',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shílè Somali',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dɔ́là Súrínámì',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Pɔ́n-un Gúúsù Sùdáànì',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobira ti Orílɛ́ède Sao tome Ati Pirisipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dɔbíra Sao tome àti Pirisipi',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Pɔ́n-ùn Sírìà',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Mánààtì Tɔkimɛnístàànì',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dínà Tunishíà',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lírà Tɔ́kì',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dɔ́là Trinidad & Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dɔ́là Tàìwánì Tuntun',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ɔrifiníyà Yukiréníà',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shile Uganda',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dɔ́là',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Pɛ́sò Úrúgúwè',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Sómú Usibɛkísítàànì',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bɔ̀lífà Fɛnɛsuɛ́là',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dɔ́là Ilà Oòrùn Karíbíà',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faransì ìwɔ̀-oorùn Afíríkà',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Ráyò Yɛ́mɛ̀nì',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kawasha ti Orílɛ́ède Saabia (1968–2012)',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dɔla ti Orílɛ́ède Siibabuwe',
        ],
    ],
];
