<?php

return [
    'Names' => [
        'Arab' => 'Araab',
        'Cyrl' => 'Sirilik',
        'Hans' => 'Buñ woyofal',
        'Hant' => 'Cosaan',
        'Latn' => 'Latin',
        'Zxxx' => 'Luñ bindul',
    ],
];
