<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'peseta andorrana',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham dals Emirats Arabs Unids',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afgani afgan (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afgani afgan',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'lek albanais (1947–1961)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albanais',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'dram armen',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'flurin da las Antillas Ollandaisas',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolan',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'kwanza angolan (1977–1991)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'nov kwanza angolan (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'kwanza angolan reagiustà (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'austral argentin',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'peso argentin ley',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'peso argentin moneda nacional',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'peso argentin (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'peso argentin',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'schilling austriac',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'dollar australian',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'flurin da l’Aruba',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'manat aserbaidschan (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat aserbaidschan',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'dinar da la Bosnia-Erzegovina (1992–1994)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'marc convertibel da la Bosnia-Erzegovina',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'nov dinar da la Bosnia-Erzegovina (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dollar da Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'taka bangladais',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'franc beltg (convertibel)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'franc beltg',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'franc beltg (finanzial)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'lev bulgar dir',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'lev bulgar socialistic',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lev bulgar',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'lev bulgar (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinar dal Bahrain',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'franc dal Burundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dollar da las Bermudas',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'dollar dal Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviano bolivian',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'vegl boliviano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'peso bolivian',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'mvdol bolivian',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'cruzeiro novo brasilian (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'cruzado brasilian',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'cruzeiro brasilian (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'real brasilian',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'cruzado novo brasilian',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'cruzeiro brasilian',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'vegl cruzeiro brasilian',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dollar da las Bahamas',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ngultrum butanais',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'kyat burmais',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula da la Botswana',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'rubel bieloruss (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rubel bieloruss',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'rubel bieloruss (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dollar dal Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'dollar canadais',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'franc congolais',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'euro WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'franc svizzer',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'franc WIR',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'escudo chilen',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'unidades de fomento chilenas',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso chilen',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'yuan chinais (offshore)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'yuan chinais',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso columbian',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'unidad de valor real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colon da la Costa Rica',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'dinar serb (2002–2006)',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'cruna tschecoslovaca',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso cuban convertibel',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso cuban',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo dal Cap Verd',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'glivra cipriota',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'cruna tscheca',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'marc da la Germania da l’Ost',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'marc tudestg',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'franc dal Dschibuti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'cruna danaisa',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominican',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinar algerian',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'sucre equadorian',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'unitad da scuntrada da l’Ecuador',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'cruna estona',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'glivra egipziana',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nakfa eritreic',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'peseta spagnola (conto A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'peseta spagnola (conto convertibel)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'peseta spagnola',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr etiopic',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'marc finlandais',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dollar dal Fidschi',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'glivra dal Falkland',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'franc franzos',
        ],
        'GBP' => [
            0 => '£',
            1 => 'glivra britannica',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'kupon larit georgian',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'lari georgian',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'cedi ghanais (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cedi ghanais',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'glivra da Gibraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambic',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'franc da la Guinea',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'syli da la Guinea',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekwele da la Guinea Equatoriala',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'drachma greca',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal da la Guatemala',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'escudo da la Guinea Portugaisa',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'peso da la Guinea-Bissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dollar da la Guyana',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'dollar da Hongkong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira hondurian',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'dinar croat',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna croata',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haitian',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'forint ungarais',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'rupia indonaisa',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'glivra indonaisa',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'glivra israeliana',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'schekel israelian (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'nov schekel israelian',
        ],
        'INR' => [
            0 => '₹',
            1 => 'rupia indica',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'dinar iracais',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'rial iranais',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'veglia cruna islandaisa',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'cruna islandaisa',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'lira taliana',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dollar giamaican',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'dinar jordanic',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'yen giapunais',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'schilling kenian',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'som kirgis',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'riel cambodschan',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'franc comorian',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'won da la Corea dal Nord',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'hwan da la Corea dal Sid (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'won da la Corea dal Sid (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'won da la Corea dal Sid',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'dinar dal Kuwait',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dollar da las Inslas Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'tenge kasac',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip laot',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'glivra libanaisa',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'rupia da la Sri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dollar liberian',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti dal Lesotho',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litas lituan',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'talonas lituan',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'franc convertibel luxemburgais',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'franc luxemburgais',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'franc finanzial luxemburgais',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'lats letton',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'rubel letton',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinar libic',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marocan',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'franc marocan',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'franc monegass',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'cupon moldav',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'leu moldav',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary madagasc',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'franc madagasc',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'dinar macedon',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'dinar macedon (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'franc dal Mali',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'kyat dal Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'tugrik mongolic',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'pataca dal Macao',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'ouguiya da la Mauretania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ouguiya da la Mauretania',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'lira maltaisa',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'glivra maltaisa',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupia dal Mauritius',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'rupia da las Maledivas (1947–1981)',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'rufiyaa da las Maledivas',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha dal Malawi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'peso mexican',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'peso d’argient mexican (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'unidad de inversion mexicana (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'ringgit malaisic',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'escudo dal Mosambic',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'metical dal Mosambic (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical dal Mosambic',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dollar namibian',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nigeriana',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'cordoba nicaraguan',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'córdoba nicaraguan',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'flurin ollandais',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'cruna norvegiaisa',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'rupia nepalaisa',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'dollar da la Nova Zelanda',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'rial da l’Oman',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa dal Panama',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'inti peruan',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol peruan',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'sol peruan (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina da la Papua Nova Guinea',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'peso filippin',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'rupia pakistana',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'zloty polac',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'zloty polac (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'escudo portugais',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guarani paraguaian',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'rial da Katar',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'dollar rodesian',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'leu rumen (1952–2006)',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'leu rumen',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinar serb',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rubel russ',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'rubel russ (vegl)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'franc ruandais',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'riyal saudit',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dollar da las Inslas da Salomon',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupia da las Seychellas',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'dinar sudanais (1992–2007)',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'glivra sudanaisa',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'glivra sudanaisa (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'cruna svedaisa',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'dollar dal Singapur',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'glivra da Sontg’Elena',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'tolar sloven',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'cruna slovaca',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone da la Sierra Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'schilling somalian',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dollar surinam',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'flurin surinam',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'glivra sidsudanaisa',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra da São Tomé e Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra da São Tomé e Principe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'rubel sovietic',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'colon da l’El Salvador',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'glivra siriana',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni dal Swaziland',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'baht tailandais',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'rubel tadschic',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'somoni tadschic',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'manat turkmen (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'manat turkmen',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinar tunesian',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'paʻanga da Tonga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'escudo dal Timor',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'lira tirca (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'lira tirca',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dollar da Trinidad e Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'nov dollar taiwanais',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'schilling tansanian',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'hryvnia ucranaisa',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'karbovanets ucranais',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'schilling ugandais (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'schilling ugandais',
        ],
        'USD' => [
            0 => '$',
            1 => 'dollar da l’USA',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'dollar dals Stadis Unids da l’America (proxim di)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'dollar dals Stadis Unids da l’America (medem di)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'peso da l’Uruguay (unidades indexadas)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'nov peso da l’Uruguay (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso da l’Uruguay',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'som usbec',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'bolivar venezuelan (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'bolivar venezuelan (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'bolívar venezuelan',
        ],
        'VND' => [
            0 => '₫',
            1 => 'dong vietnamais',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'dong vietnamais (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu dal Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala da la Samoa',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'franc CFA da l’Africa Centrala',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'dollar da la Caribica Orientala',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'franc d’aur franzos',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'franc UIC franzos',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'franc CFA da l’Africa dal Vest',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'franc CFP',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'fonds RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'dinar jemenit',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'rial jemenit',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'dinar jugoslav dir (1966–1990)',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'nov dinar jugoslav (1994–2002)',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'dinar jugoslav convertibel (1990–1992)',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'dinar jugoslav refurmà (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'rand sidafrican (finanzial)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand sidafrican',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'kwacha da la Sambia (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha da la sambia',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'nov zaire dal Zaire (1993–1998)',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zaire dal Zaire',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'dollar dal Simbabwe (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'dollar dal Simbabwe (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'dollar dal Simbabwe (2008)',
        ],
    ],
];
