<?php

return [
    'Names' => [
        'ar_SA' => 'árabe (Arabia Saudita)',
        'en_GG' => 'inglés (Guernsey)',
        'en_SZ' => 'inglés (Eswatini)',
        'ro_RO' => 'rumano (Rumania)',
    ],
];
