<?php

return [
    'Names' => [
        'ar_001' => 'Kiarabu (dunia)',
        'ar_JO' => 'Kiarabu (Yordani)',
        'ar_LB' => 'Kiarabu (Lebanoni)',
        'ar_MA' => 'Kiarabu (Moroko)',
        'ar_OM' => 'Kiarabu (Omani)',
        'ar_PS' => 'Kiarabu (Himaya za Palestina)',
        'ar_QA' => 'Kiarabu (Katari)',
        'ar_SY' => 'Kiarabu (Shamu)',
        'ar_TD' => 'Kiarabu (Chadi)',
        'az' => 'Kiazabaijani',
        'az_AZ' => 'Kiazabaijani (Azabajani)',
        'az_Cyrl' => 'Kiazabaijani (Kikrili)',
        'az_Cyrl_AZ' => 'Kiazabaijani (Kikrili, Azabajani)',
        'az_Latn' => 'Kiazabaijani (Kilatini)',
        'az_Latn_AZ' => 'Kiazabaijani (Kilatini, Azabajani)',
        'be_BY' => 'Kibelarusi (Belarusi)',
        'bn' => 'Kibangla',
        'bn_BD' => 'Kibangla (Bangladeshi)',
        'bn_IN' => 'Kibangla (India)',
        'bs_Cyrl' => 'Kibosnia (Kikrili)',
        'bs_Cyrl_BA' => 'Kibosnia (Kikrili, Bosnia na Hezegovina)',
        'ce' => 'Kichechen',
        'ce_RU' => 'Kichechen (Urusi)',
        'cy' => 'Kiwels',
        'cy_GB' => 'Kiwels (Ufalme wa Muungano)',
        'de_LI' => 'Kijerumani (Lishenteni)',
        'de_LU' => 'Kijerumani (Lasembagi)',
        'dz_BT' => 'Kizongkha (Bhutani)',
        'en_001' => 'Kiingereza (dunia)',
        'en_AG' => 'Kiingereza (Antigua na Babuda)',
        'en_AI' => 'Kiingereza (Anguila)',
        'en_BB' => 'Kiingereza (Babados)',
        'en_BS' => 'Kiingereza (Bahamas)',
        'en_CC' => 'Kiingereza (Visiwa vya Kokos [Keeling])',
        'en_GU' => 'Kiingereza (Guami)',
        'en_IO' => 'Kiingereza (Himaya ya Uingereza katika Bahari Hindi)',
        'en_LS' => 'Kiingereza (Lesotho)',
        'en_MS' => 'Kiingereza (Montserati)',
        'en_PG' => 'Kiingereza (Papua Guinea Mpya)',
        'en_PR' => 'Kiingereza (Pwetoriko)',
        'en_SG' => 'Kiingereza (Singapuri)',
        'en_VG' => 'Kiingereza (Visiwa vya Virgin vya Uingereza)',
        'en_VI' => 'Kiingereza (Visiwa vya Virgin vya Marekani)',
        'eo_001' => 'Kiesperanto (dunia)',
        'es_EC' => 'Kihispania (Ekwado)',
        'es_GT' => 'Kihispania (Gwatemala)',
        'es_PR' => 'Kihispania (Pwetoriko)',
        'es_PY' => 'Kihispania (Paragwai)',
        'es_SV' => 'Kihispania (Elsalvado)',
        'es_UY' => 'Kihispania (Urugwai)',
        'fa_AF' => 'Kiajemi (Afghanistani)',
        'ff' => 'Kifula',
        'ff_Adlm' => 'Kifula (Kiadlamu)',
        'ff_Adlm_BF' => 'Kifula (Kiadlamu, Bukinafaso)',
        'ff_Adlm_CM' => 'Kifula (Kiadlamu, Kameruni)',
        'ff_Adlm_GH' => 'Kifula (Kiadlamu, Ghana)',
        'ff_Adlm_GM' => 'Kifula (Kiadlamu, Gambia)',
        'ff_Adlm_GN' => 'Kifula (Kiadlamu, Gine)',
        'ff_Adlm_GW' => 'Kifula (Kiadlamu, Ginebisau)',
        'ff_Adlm_LR' => 'Kifula (Kiadlamu, Liberia)',
        'ff_Adlm_MR' => 'Kifula (Kiadlamu, Moritania)',
        'ff_Adlm_NE' => 'Kifula (Kiadlamu, Nijeri)',
        'ff_Adlm_NG' => 'Kifula (Kiadlamu, Nigeria)',
        'ff_Adlm_SL' => 'Kifula (Kiadlamu, Siera Leoni)',
        'ff_Adlm_SN' => 'Kifula (Kiadlamu, Senegali)',
        'ff_CM' => 'Kifula (Kameruni)',
        'ff_GN' => 'Kifula (Gine)',
        'ff_Latn' => 'Kifula (Kilatini)',
        'ff_Latn_BF' => 'Kifula (Kilatini, Bukinafaso)',
        'ff_Latn_CM' => 'Kifula (Kilatini, Kameruni)',
        'ff_Latn_GH' => 'Kifula (Kilatini, Ghana)',
        'ff_Latn_GM' => 'Kifula (Kilatini, Gambia)',
        'ff_Latn_GN' => 'Kifula (Kilatini, Gine)',
        'ff_Latn_GW' => 'Kifula (Kilatini, Ginebisau)',
        'ff_Latn_LR' => 'Kifula (Kilatini, Liberia)',
        'ff_Latn_MR' => 'Kifula (Kilatini, Moritania)',
        'ff_Latn_NE' => 'Kifula (Kilatini, Nijeri)',
        'ff_Latn_NG' => 'Kifula (Kilatini, Nigeria)',
        'ff_Latn_SL' => 'Kifula (Kilatini, Siera Leoni)',
        'ff_Latn_SN' => 'Kifula (Kilatini, Senegali)',
        'ff_MR' => 'Kifula (Moritania)',
        'ff_SN' => 'Kifula (Senegali)',
        'fo' => 'Kifaro',
        'fo_DK' => 'Kifaro (Denmaki)',
        'fo_FO' => 'Kifaro (Visiwa vya Faroe)',
        'fr_BJ' => 'Kifaransa (Benini)',
        'fr_CD' => 'Kifaransa (Kongo - Kinshasa)',
        'fr_GA' => 'Kifaransa (Gaboni)',
        'fr_GP' => 'Kifaransa (Gwadelupe)',
        'fr_LU' => 'Kifaransa (Lasembagi)',
        'fr_MA' => 'Kifaransa (Moroko)',
        'fr_MC' => 'Kifaransa (Monako)',
        'fr_NC' => 'Kifaransa (Nyukaledonia)',
        'fr_NE' => 'Kifaransa (Nijeri)',
        'fr_PF' => 'Kifaransa (Polinesia ya Ufaransa)',
        'fr_PM' => 'Kifaransa (St. Pierre na Miquelon)',
        'fr_SY' => 'Kifaransa (Shamu)',
        'fr_TD' => 'Kifaransa (Chadi)',
        'fr_YT' => 'Kifaransa (Mayote)',
        'fy' => 'Kifrisi cha Magharibi',
        'fy_NL' => 'Kifrisi cha Magharibi (Uholanzi)',
        'gv' => 'Kimaniksi',
        'gv_IM' => 'Kimaniksi (Kisiwa cha Man)',
        'ha_NE' => 'Kihausa (Nijeri)',
        'hr' => 'Kikroeshia',
        'hr_BA' => 'Kikroeshia (Bosnia na Hezegovina)',
        'hr_HR' => 'Kikroeshia (Kroashia)',
        'ia' => 'Lugha ya kimataifa',
        'ia_001' => 'Lugha ya kimataifa (dunia)',
        'ig' => 'Kiibo',
        'ig_NG' => 'Kiibo (Nigeria)',
        'ii' => 'Kiiyi cha Sichuan',
        'ii_CN' => 'Kiiyi cha Sichuan (Uchina)',
        'is' => 'Kiaisilandi',
        'is_IS' => 'Kiaisilandi (Aisilandi)',
        'it_VA' => 'Kiitaliano (Mji wa Vatikani)',
        'kk' => 'Kikazaki',
        'kk_KZ' => 'Kikazaki (Kazakistani)',
        'km' => 'Kikhema',
        'km_KH' => 'Kikhema (Kambodia)',
        'kw' => 'Kikoni',
        'kw_GB' => 'Kikoni (Ufalme wa Muungano)',
        'ky' => 'Kikirigizi',
        'ky_KG' => 'Kikirigizi (Kirigizistani)',
        'lb_LU' => 'Kilasembagi (Lasembagi)',
        'ln_CD' => 'Kilingala (Kongo - Kinshasa)',
        'lo_LA' => 'Kilaosi (Laosi)',
        'lu_CD' => 'Kiluba-Katanga (Kongo - Kinshasa)',
        'lv_LV' => 'Kilatvia (Lativia)',
        'mk' => 'Kimasedonia',
        'mk_MK' => 'Kimasedonia (Masedonia)',
        'ml' => 'Kimalayalam',
        'ml_IN' => 'Kimalayalam (India)',
        'ms_SG' => 'Kimalei (Singapuri)',
        'my' => 'Kibama',
        'my_MM' => 'Kibama (Myama [Burma])',
        'nb_NO' => 'Kinorwe cha Bokmal (Norwe)',
        'ne_NP' => 'Kinepali (Nepali)',
        'nl_CW' => 'Kiholanzi (Kurakao)',
        'nn_NO' => 'Kinorwe cha Nynorsk (Norwe)',
        'no_NO' => 'Kinorwe (Norwe)',
        'or' => 'Kiodia',
        'or_IN' => 'Kiodia (India)',
        'pl_PL' => 'Kipolandi (Polandi)',
        'ps_AF' => 'Kipashto (Afghanistani)',
        'pt_CV' => 'Kireno (Kepuvede)',
        'pt_LU' => 'Kireno (Lasembagi)',
        'pt_ST' => 'Kireno (Sao Tome na Prinsipe)',
        'qu_EC' => 'Kikechua (Ekwado)',
        'rm' => 'Kirumi',
        'rm_CH' => 'Kirumi (Uswisi)',
        'ru_BY' => 'Kirusi (Belarusi)',
        'ru_UA' => 'Kirusi (Ukreni)',
        'sc' => 'Kisadini',
        'sc_IT' => 'Kisadini (Italia)',
        'se_NO' => 'Kisami cha Kaskazini (Norwe)',
        'sq_MK' => 'Kialbania (Masedonia)',
        'sr_Cyrl' => 'Kiserbia (Kikrili)',
        'sr_Cyrl_BA' => 'Kiserbia (Kikrili, Bosnia na Hezegovina)',
        'sr_Cyrl_ME' => 'Kiserbia (Kikrili, Montenegro)',
        'sr_Cyrl_RS' => 'Kiserbia (Kikrili, Serbia)',
        'su' => 'Kisundani',
        'su_ID' => 'Kisundani (Indonesia)',
        'su_Latn' => 'Kisundani (Kilatini)',
        'su_Latn_ID' => 'Kisundani (Kilatini, Indonesia)',
        'sw_CD' => 'Kiswahili (Kongo - Kinshasa)',
        'ta_SG' => 'Kitamili (Singapuri)',
        'th_TH' => 'Kithai (Thailandi)',
        'tk_TM' => 'Kiturukimeni (Turukimenstani)',
        'ug' => 'Kiuiguri',
        'ug_CN' => 'Kiuiguri (Uchina)',
        'uk' => 'Kiukreni',
        'uk_UA' => 'Kiukreni (Ukreni)',
        'uz_AF' => 'Kiuzbeki (Afghanistani)',
        'uz_Arab_AF' => 'Kiuzbeki (Kiarabu, Afghanistani)',
        'uz_Cyrl' => 'Kiuzbeki (Kikrili)',
        'uz_Cyrl_UZ' => 'Kiuzbeki (Kikrili, Uzibekistani)',
        'wo' => 'Kiwolof',
        'wo_SN' => 'Kiwolof (Senegali)',
        'xh' => 'Kikhosa',
        'xh_ZA' => 'Kikhosa (Afrika Kusini)',
        'yi' => 'Kiyidi',
        'yi_001' => 'Kiyidi (dunia)',
        'yo_BJ' => 'Kiyoruba (Benini)',
        'zh_Hans' => 'Kichina (Kilichorahisishwa)',
        'zh_Hans_CN' => 'Kichina (Kilichorahisishwa, Uchina)',
        'zh_Hans_HK' => 'Kichina (Kilichorahisishwa, Hong Kong SAR China)',
        'zh_Hans_MO' => 'Kichina (Kilichorahisishwa, Makau SAR China)',
        'zh_Hans_SG' => 'Kichina (Kilichorahisishwa, Singapuri)',
        'zh_Hant_TW' => 'Kichina (Cha jadi, Taiwani)',
        'zh_SG' => 'Kichina (Singapuri)',
        'zh_TW' => 'Kichina (Taiwani)',
    ],
];
