<?php

return [
    'Names' => [
        'AD' => 'انڈورا',
        'AE' => 'متحدہ عرب امارات',
        'AF' => 'افغانستان',
        'AG' => 'انٹیگوا اور باربودا',
        'AI' => 'انگوئیلا',
        'AL' => 'البانیہ',
        'AM' => 'آرمینیا',
        'AO' => 'انگولا',
        'AQ' => 'انٹارکٹیکا',
        'AR' => 'ارجنٹینا',
        'AS' => 'امریکی ساموآ',
        'AT' => 'آسٹریا',
        'AU' => 'آسٹریلیا',
        'AW' => 'اروبا',
        'AX' => 'آلینڈ آئلینڈز',
        'AZ' => 'آذربائیجان',
        'BA' => 'بوسنیا اور ہرزیگووینا',
        'BB' => 'بارباڈوس',
        'BD' => 'بنگلہ دیش',
        'BE' => 'بیلجیم',
        'BF' => 'برکینا فاسو',
        'BG' => 'بلغاریہ',
        'BH' => 'بحرین',
        'BI' => 'برونڈی',
        'BJ' => 'بینن',
        'BL' => 'سینٹ برتھلیمی',
        'BM' => 'برمودا',
        'BN' => 'برونائی',
        'BO' => 'بولیویا',
        'BQ' => 'کریبیائی نیدرلینڈز',
        'BR' => 'برازیل',
        'BS' => 'بہاماس',
        'BT' => 'بھوٹان',
        'BV' => 'بؤویٹ آئلینڈ',
        'BW' => 'بوتسوانا',
        'BY' => 'بیلاروس',
        'BZ' => 'بیلائز',
        'CA' => 'کینیڈا',
        'CC' => 'کوکوس (کیلنگ) جزائر',
        'CD' => 'کانگو - کنشاسا',
        'CF' => 'وسط افریقی جمہوریہ',
        'CG' => 'کانگو - برازاویلے',
        'CH' => 'سوئٹزر لینڈ',
        'CI' => 'کوٹ ڈی آئیوری',
        'CK' => 'کک آئلینڈز',
        'CL' => 'چلی',
        'CM' => 'کیمرون',
        'CN' => 'چین',
        'CO' => 'کولمبیا',
        'CR' => 'کوسٹا ریکا',
        'CU' => 'کیوبا',
        'CV' => 'کیپ ورڈی',
        'CW' => 'کیوراکاؤ',
        'CX' => 'جزیرہ کرسمس',
        'CY' => 'قبرص',
        'CZ' => 'چیکیا',
        'DE' => 'جرمنی',
        'DJ' => 'جبوتی',
        'DK' => 'ڈنمارک',
        'DM' => 'ڈومنیکا',
        'DO' => 'جمہوریہ ڈومينيکن',
        'DZ' => 'الجیریا',
        'EC' => 'ایکواڈور',
        'EE' => 'اسٹونیا',
        'EG' => 'مصر',
        'EH' => 'مغربی صحارا',
        'ER' => 'اریٹیریا',
        'ES' => 'ہسپانیہ',
        'ET' => 'ایتھوپیا',
        'FI' => 'فن لینڈ',
        'FJ' => 'فجی',
        'FK' => 'فاکلینڈ جزائر',
        'FM' => 'مائکرونیشیا',
        'FO' => 'جزائر فارو',
        'FR' => 'فرانس',
        'GA' => 'گیبون',
        'GB' => 'سلطنت متحدہ',
        'GD' => 'گریناڈا',
        'GE' => 'جارجیا',
        'GF' => 'فرینچ گیانا',
        'GG' => 'گوئرنسی',
        'GH' => 'گھانا',
        'GI' => 'جبل الطارق',
        'GL' => 'گرین لینڈ',
        'GM' => 'گیمبیا',
        'GN' => 'گنی',
        'GP' => 'گواڈیلوپ',
        'GQ' => 'استوائی گیانا',
        'GR' => 'یونان',
        'GS' => 'جنوبی جارجیا اور جنوبی سینڈوچ جزائر',
        'GT' => 'گواٹے مالا',
        'GU' => 'گوام',
        'GW' => 'گنی بساؤ',
        'GY' => 'گیانا',
        'HK' => 'ہانگ کانگ SAR چین',
        'HM' => 'ہیرڈ جزیرہ و میکڈولینڈ جزائر',
        'HN' => 'ہونڈاروس',
        'HR' => 'کروشیا',
        'HT' => 'ہیٹی',
        'HU' => 'ہنگری',
        'ID' => 'انڈونیشیا',
        'IE' => 'آئرلینڈ',
        'IL' => 'اسرائیل',
        'IM' => 'آئل آف مین',
        'IN' => 'بھارت',
        'IO' => 'برطانوی بحر ہند کا علاقہ',
        'IQ' => 'عراق',
        'IR' => 'ایران',
        'IS' => 'آئس لینڈ',
        'IT' => 'اٹلی',
        'JE' => 'جرسی',
        'JM' => 'جمائیکا',
        'JO' => 'اردن',
        'JP' => 'جاپان',
        'KE' => 'کینیا',
        'KG' => 'کرغزستان',
        'KH' => 'کمبوڈیا',
        'KI' => 'کریباتی',
        'KM' => 'کوموروس',
        'KN' => 'سینٹ کٹس اور نیویس',
        'KP' => 'شمالی کوریا',
        'KR' => 'جنوبی کوریا',
        'KW' => 'کویت',
        'KY' => 'کیمین آئلینڈز',
        'KZ' => 'قزاخستان',
        'LA' => 'لاؤس',
        'LB' => 'لبنان',
        'LC' => 'سینٹ لوسیا',
        'LI' => 'لیشٹنسٹائن',
        'LK' => 'سری لنکا',
        'LR' => 'لائبیریا',
        'LS' => 'لیسوتھو',
        'LT' => 'لیتھونیا',
        'LU' => 'لکسمبرگ',
        'LV' => 'لٹویا',
        'LY' => 'لیبیا',
        'MA' => 'مراکش',
        'MC' => 'موناکو',
        'MD' => 'مالدووا',
        'ME' => 'مونٹے نیگرو',
        'MF' => 'سینٹ مارٹن',
        'MG' => 'مڈغاسکر',
        'MH' => 'مارشل آئلینڈز',
        'MK' => 'شمالی مقدونیہ',
        'ML' => 'مالی',
        'MM' => 'میانمار (برما)',
        'MN' => 'منگولیا',
        'MO' => 'مکاؤ SAR چین',
        'MP' => 'شمالی ماریانا آئلینڈز',
        'MQ' => 'مارٹینک',
        'MR' => 'موریطانیہ',
        'MS' => 'مونٹسیراٹ',
        'MT' => 'مالٹا',
        'MU' => 'ماریشس',
        'MV' => 'مالدیپ',
        'MW' => 'ملاوی',
        'MX' => 'میکسیکو',
        'MY' => 'ملائشیا',
        'MZ' => 'موزمبیق',
        'NA' => 'نامیبیا',
        'NC' => 'نیو کلیڈونیا',
        'NE' => 'نائجر',
        'NF' => 'نارفوک آئلینڈ',
        'NG' => 'نائجیریا',
        'NI' => 'نکاراگووا',
        'NL' => 'نیدر لینڈز',
        'NO' => 'ناروے',
        'NP' => 'نیپال',
        'NR' => 'نؤرو',
        'NU' => 'نیئو',
        'NZ' => 'نیوزی لینڈ',
        'OM' => 'عمان',
        'PA' => 'پانامہ',
        'PE' => 'پیرو',
        'PF' => 'فرانسیسی پولینیشیا',
        'PG' => 'پاپوآ نیو گنی',
        'PH' => 'فلپائن',
        'PK' => 'پاکستان',
        'PL' => 'پولینڈ',
        'PM' => 'سینٹ پیئر اور میکلیئون',
        'PN' => 'پٹکائرن جزائر',
        'PR' => 'پیورٹو ریکو',
        'PS' => 'فلسطینی خطے',
        'PT' => 'پرتگال',
        'PW' => 'پلاؤ',
        'PY' => 'پیراگوئے',
        'QA' => 'قطر',
        'RE' => 'ری یونین',
        'RO' => 'رومانیہ',
        'RS' => 'سربیا',
        'RU' => 'روس',
        'RW' => 'روانڈا',
        'SA' => 'سعودی عرب',
        'SB' => 'سولومن آئلینڈز',
        'SC' => 'سشلیز',
        'SD' => 'سوڈان',
        'SE' => 'سویڈن',
        'SG' => 'سنگاپور',
        'SH' => 'سینٹ ہیلینا',
        'SI' => 'سلووینیا',
        'SJ' => 'سوالبرڈ اور جان ماین',
        'SK' => 'سلوواکیہ',
        'SL' => 'سیرالیون',
        'SM' => 'سان مارینو',
        'SN' => 'سینیگل',
        'SO' => 'صومالیہ',
        'SR' => 'سورینام',
        'SS' => 'جنوبی سوڈان',
        'ST' => 'ساؤ ٹومے اور پرنسپے',
        'SV' => 'ال سلواڈور',
        'SX' => 'سنٹ مارٹن',
        'SY' => 'شام',
        'SZ' => 'سواتنی',
        'TC' => 'ٹرکس اور کیکوس جزائر',
        'TD' => 'چاڈ',
        'TF' => 'فرانسیسی جنوبی خطے',
        'TG' => 'ٹوگو',
        'TH' => 'تھائی لینڈ',
        'TJ' => 'تاجکستان',
        'TK' => 'ٹوکیلاؤ',
        'TL' => 'تیمور لیسٹ',
        'TM' => 'ترکمانستان',
        'TN' => 'تونس',
        'TO' => 'ٹونگا',
        'TR' => 'ترکی',
        'TT' => 'ترینیداد اور ٹوباگو',
        'TV' => 'ٹووالو',
        'TW' => 'تائیوان',
        'TZ' => 'تنزانیہ',
        'UA' => 'یوکرین',
        'UG' => 'یوگنڈا',
        'UM' => 'امریکہ سے باہر کے چھوٹے جزائز',
        'US' => 'ریاست ہائے متحدہ امریکہ',
        'UY' => 'یوروگوئے',
        'UZ' => 'ازبکستان',
        'VA' => 'ویٹیکن سٹی',
        'VC' => 'سینٹ ونسنٹ اور گرینیڈائنز',
        'VE' => 'وینزوئیلا',
        'VG' => 'برٹش ورجن آئلینڈز',
        'VI' => 'امریکی ورجن آئلینڈز',
        'VN' => 'ویتنام',
        'VU' => 'وینوآٹو',
        'WF' => 'ویلیز اور فیوٹیونا',
        'WS' => 'ساموآ',
        'YE' => 'یمن',
        'YT' => 'مایوٹ',
        'ZA' => 'جنوبی افریقہ',
        'ZM' => 'زامبیا',
        'ZW' => 'زمبابوے',
    ],
];
