<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirham ya Falme za Kiarabu',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza ya Angola',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dola ya Australia',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinari ya Bahareni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Faranga ya Burundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula ya Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Ndora ya Kananda',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Faranga ya Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Faranga ya Uswisi',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan Renminbi ya China',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Eskudo ya Kepuvede',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Faranga ya Jibuti',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinari ya Aljeria',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Pauni ya Misri',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa ya Eritrea',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Bir ya Uhabeshi',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuro',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Mbauini cia Ngeretha',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi ya Ghana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi ya Gambia',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Faranga ya Gine',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rubia rwa India',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Sarafu ya Kijapani',
        ],
        'KES' => [
            0 => 'Ksh',
            1 => 'Ciringi ya Kenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Faranga ya Komoro',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dola ya Liberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ya Lesoto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinari ya Libya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham ya Moroko',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Ariary ya Bukini',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya ya Moritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya ya Moritania',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupia ya Morisi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha ya Malawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikali ya Msumbiji',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dola ya Namibia',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira ya Nijeria',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Faranga ya Rwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal ya Saudia',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupia ya Shelisheli',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Pauni ya Sudani',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Pauni ya Santahelena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leoni',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'ciringi cia cumarĩ',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra ya Sao Tome na Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra ya Sao Tome na Principe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinari ya Tunisia',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'ciringi cia Tanizania',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ciringi cia Ũganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Ndora cia Amerika',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Faranga CFA BEAC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faranga CFA BCEAO',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randi ya Afrika Kusini',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha ya Zambia (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha ya Zambia',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dola ya Zimbabwe',
        ],
    ],
];
