<?php
$attributemap = [
    'urn:mace:dir:attribute-def:aRecord'                          => 'urn:oid:0.9.2342.19200300.100.1.26',
    'urn:mace:dir:attribute-def:aliasedEntryName'                 => 'urn:oid:2.5.4.1',
    'urn:mace:dir:attribute-def:aliasedObjectName'                => 'urn:oid:2.5.4.1',
    'urn:mace:dir:attribute-def:associatedDomain'                 => 'urn:oid:0.9.2342.19200300.100.1.37',
    'urn:mace:dir:attribute-def:associatedName'                   => 'urn:oid:0.9.2342.19200300.100.1.38',
    'urn:mace:dir:attribute-def:audio'                            => 'urn:oid:0.9.2342.19200300.100.1.55',
    'urn:mace:dir:attribute-def:authorityRevocationList'          => 'urn:oid:2.5.4.38',
    'urn:mace:dir:attribute-def:buildingName'                     => 'urn:oid:0.9.2342.19200300.100.1.48',
    'urn:mace:dir:attribute-def:businessCategory'                 => 'urn:oid:2.5.4.15',
    'urn:mace:dir:attribute-def:c'                                => 'urn:oid:2.5.4.6',
    'urn:mace:dir:attribute-def:cACertificate'                    => 'urn:oid:2.5.4.37',
    'urn:mace:dir:attribute-def:cNAMERecord'                      => 'urn:oid:0.9.2342.19200300.100.1.31',
    'urn:mace:dir:attribute-def:carLicense'                       => 'urn:oid:2.16.840.1.113730.3.1.1',
    'urn:mace:dir:attribute-def:certificateRevocationList'        => 'urn:oid:2.5.4.39',
    'urn:mace:dir:attribute-def:cn'                               => 'urn:oid:2.5.4.3',
    'urn:mace:dir:attribute-def:co'                               => 'urn:oid:0.9.2342.19200300.100.1.43',
    'urn:mace:dir:attribute-def:commonName'                       => 'urn:oid:2.5.4.3',
    'urn:mace:dir:attribute-def:countryName'                      => 'urn:oid:2.5.4.6',
    'urn:mace:dir:attribute-def:crossCertificatePair'             => 'urn:oid:2.5.4.40',
    'urn:mace:dir:attribute-def:dITRedirect'                      => 'urn:oid:0.9.2342.19200300.100.1.54',
    'urn:mace:dir:attribute-def:dSAQuality'                       => 'urn:oid:0.9.2342.19200300.100.1.49',
    'urn:mace:dir:attribute-def:dc'                               => 'urn:oid:0.9.2342.19200300.100.1.25',
    'urn:mace:dir:attribute-def:deltaRevocationList'              => 'urn:oid:2.5.4.53',
    'urn:mace:dir:attribute-def:departmentNumber'                 => 'urn:oid:2.16.840.1.113730.3.1.2',
    'urn:mace:dir:attribute-def:description'                      => 'urn:oid:2.5.4.13',
    'urn:mace:dir:attribute-def:destinationIndicator'             => 'urn:oid:2.5.4.27',
    'urn:mace:dir:attribute-def:displayName'                      => 'urn:oid:2.16.840.1.113730.3.1.241',
    'urn:mace:dir:attribute-def:distinguishedName'                => 'urn:oid:2.5.4.49',
    'urn:mace:dir:attribute-def:dmdName'                          => 'urn:oid:2.5.4.54',
    'urn:mace:dir:attribute-def:dnQualifier'                      => 'urn:oid:2.5.4.46',
    'urn:mace:dir:attribute-def:documentAuthor'                   => 'urn:oid:0.9.2342.19200300.100.1.14',
    'urn:mace:dir:attribute-def:documentIdentifier'               => 'urn:oid:0.9.2342.19200300.100.1.11',
    'urn:mace:dir:attribute-def:documentLocation'                 => 'urn:oid:0.9.2342.19200300.100.1.15',
    'urn:mace:dir:attribute-def:documentPublisher'                => 'urn:oid:0.9.2342.19200300.100.1.56',
    'urn:mace:dir:attribute-def:documentTitle'                    => 'urn:oid:0.9.2342.19200300.100.1.12',
    'urn:mace:dir:attribute-def:documentVersion'                  => 'urn:oid:0.9.2342.19200300.100.1.13',
    'urn:mace:dir:attribute-def:domainComponent'                  => 'urn:oid:0.9.2342.19200300.100.1.25',
    'urn:mace:dir:attribute-def:drink'                            => 'urn:oid:0.9.2342.19200300.100.1.5',
    'urn:mace:dir:attribute-def:eduOrgHomePageURI'                => 'urn:oid:1.3.6.1.4.1.5923.1.2.1.2',
    'urn:mace:dir:attribute-def:eduOrgIdentityAuthNPolicyURI'     => 'urn:oid:1.3.6.1.4.1.5923.1.2.1.3',
    'urn:mace:dir:attribute-def:eduOrgLegalName'                  => 'urn:oid:1.3.6.1.4.1.5923.1.2.1.4',
    'urn:mace:dir:attribute-def:eduOrgSuperiorURI'                => 'urn:oid:1.3.6.1.4.1.5923.1.2.1.5',
    'urn:mace:dir:attribute-def:eduOrgWhitePagesURI'              => 'urn:oid:1.3.6.1.4.1.5923.1.2.1.6',
    'urn:mace:dir:attribute-def:eduPersonAffiliation'             => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.1',
    'urn:mace:dir:attribute-def:eduPersonAssurance'               => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.11',
    'urn:mace:dir:attribute-def:eduPersonEntitlement'             => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.7',
    'urn:mace:dir:attribute-def:eduPersonNickname'                => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.2',
    'urn:mace:dir:attribute-def:eduPersonOrgDN'                   => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.3',
    'urn:mace:dir:attribute-def:eduPersonOrgUnitDN'               => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.4',
    'urn:mace:dir:attribute-def:eduPersonPrimaryAffiliation'      => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.5',
    'urn:mace:dir:attribute-def:eduPersonPrimaryOrgUnitDN'        => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.8',
    'urn:mace:dir:attribute-def:eduPersonPrincipalName'           => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.6',
    'urn:mace:dir:attribute-def:eduPersonScopedAffiliation'       => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.9',
    'urn:mace:dir:attribute-def:eduPersonTargetedID'              => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.10',
    'urn:mace:dir:attribute-def:eduPersonUniqueId'                => 'urn:oid:1.3.6.1.4.1.5923.1.1.1.13',
    'urn:mace:dir:attribute-def:email'                            => 'urn:oid:1.2.840.113549.1.9.1',
    'urn:mace:dir:attribute-def:emailAddress'                     => 'urn:oid:1.2.840.113549.1.9.1',
    'urn:mace:dir:attribute-def:employeeNumber'                   => 'urn:oid:2.16.840.1.113730.3.1.3',
    'urn:mace:dir:attribute-def:employeeType'                     => 'urn:oid:2.16.840.1.113730.3.1.4',
    'urn:mace:dir:attribute-def:enhancedSearchGuide'              => 'urn:oid:2.5.4.47',
    'urn:mace:dir:attribute-def:facsimileTelephoneNumber'         => 'urn:oid:2.5.4.23',
    'urn:mace:dir:attribute-def:favouriteDrink'                   => 'urn:oid:0.9.2342.19200300.100.1.5',
    'urn:mace:dir:attribute-def:fax'                              => 'urn:oid:2.5.4.23',
    'urn:mace:dir:attribute-def:federationFeideSchemaVersion'     => 'urn:oid:1.3.6.1.4.1.2428.90.1.9',
    'urn:mace:dir:attribute-def:friendlyCountryName'              => 'urn:oid:0.9.2342.19200300.100.1.43',
    'urn:mace:dir:attribute-def:generationQualifier'              => 'urn:oid:2.5.4.44',
    'urn:mace:dir:attribute-def:givenName'                        => 'urn:oid:2.5.4.42',
    'urn:mace:dir:attribute-def:gn'                               => 'urn:oid:2.5.4.42',
    'urn:mace:dir:attribute-def:homePhone'                        => 'urn:oid:0.9.2342.19200300.100.1.20',
    'urn:mace:dir:attribute-def:homePostalAddress'                => 'urn:oid:0.9.2342.19200300.100.1.39',
    'urn:mace:dir:attribute-def:homeTelephoneNumber'              => 'urn:oid:0.9.2342.19200300.100.1.20',
    'urn:mace:dir:attribute-def:host'                             => 'urn:oid:0.9.2342.19200300.100.1.9',
    'urn:mace:dir:attribute-def:houseIdentifier'                  => 'urn:oid:2.5.4.51',
    'urn:mace:dir:attribute-def:info'                             => 'urn:oid:0.9.2342.19200300.100.1.4',
    'urn:mace:dir:attribute-def:initials'                         => 'urn:oid:2.5.4.43',
    'urn:mace:dir:attribute-def:internationaliSDNNumber'          => 'urn:oid:2.5.4.25',
    'urn:mace:dir:attribute-def:janetMailbox'                     => 'urn:oid:0.9.2342.19200300.100.1.46',
    'urn:mace:dir:attribute-def:jpegPhoto'                        => 'urn:oid:0.9.2342.19200300.100.1.60',
    'urn:mace:dir:attribute-def:knowledgeInformation'             => 'urn:oid:2.5.4.2',
    'urn:mace:dir:attribute-def:l'                                => 'urn:oid:2.5.4.7',
    'urn:mace:dir:attribute-def:labeledURI'                       => 'urn:oid:1.3.6.1.4.1.250.1.57',
    'urn:mace:dir:attribute-def:localityName'                     => 'urn:oid:2.5.4.7',
    'urn:mace:dir:attribute-def:mDRecord'                         => 'urn:oid:0.9.2342.19200300.100.1.27',
    'urn:mace:dir:attribute-def:mXRecord'                         => 'urn:oid:0.9.2342.19200300.100.1.28',
    'urn:mace:dir:attribute-def:mail'                             => 'urn:oid:0.9.2342.19200300.100.1.3',
    'urn:mace:dir:attribute-def:mailPreferenceOption'             => 'urn:oid:0.9.2342.19200300.100.1.47',
    'urn:mace:dir:attribute-def:manager'                          => 'urn:oid:0.9.2342.19200300.100.1.10',
    'urn:mace:dir:attribute-def:member'                           => 'urn:oid:2.5.4.31',
    'urn:mace:dir:attribute-def:mobile'                           => 'urn:oid:0.9.2342.19200300.100.1.41',
    'urn:mace:dir:attribute-def:mobileTelephoneNumber'            => 'urn:oid:0.9.2342.19200300.100.1.41',
    'urn:mace:dir:attribute-def:nSRecord'                         => 'urn:oid:0.9.2342.19200300.100.1.29',
    'urn:mace:dir:attribute-def:name'                             => 'urn:oid:2.5.4.41',
    'urn:mace:dir:attribute-def:norEduOrgAcronym'                 => 'urn:oid:1.3.6.1.4.1.2428.90.1.6',
    'urn:mace:dir:attribute-def:norEduOrgNIN'                     => 'urn:oid:1.3.6.1.4.1.2428.90.1.12',
    'urn:mace:dir:attribute-def:norEduOrgSchemaVersion'           => 'urn:oid:1.3.6.1.4.1.2428.90.1.11',
    'urn:mace:dir:attribute-def:norEduOrgUniqueIdentifier'        => 'urn:oid:1.3.6.1.4.1.2428.90.1.7',
    'urn:mace:dir:attribute-def:norEduOrgUniqueNumber'            => 'urn:oid:1.3.6.1.4.1.2428.90.1.1',
    'urn:mace:dir:attribute-def:norEduOrgUnitUniqueIdentifier'    => 'urn:oid:1.3.6.1.4.1.2428.90.1.8',
    'urn:mace:dir:attribute-def:norEduOrgUnitUniqueNumber'        => 'urn:oid:1.3.6.1.4.1.2428.90.1.2',
    'urn:mace:dir:attribute-def:norEduPersonBirthDate'            => 'urn:oid:1.3.6.1.4.1.2428.90.1.3',
    'urn:mace:dir:attribute-def:norEduPersonLIN'                  => 'urn:oid:1.3.6.1.4.1.2428.90.1.4',
    'urn:mace:dir:attribute-def:norEduPersonNIN'                  => 'urn:oid:1.3.6.1.4.1.2428.90.1.5',
    'urn:mace:dir:attribute-def:o'                                => 'urn:oid:2.5.4.10',
    'urn:mace:dir:attribute-def:objectClass'                      => 'urn:oid:2.5.4.0',
    'urn:mace:dir:attribute-def:organizationName'                 => 'urn:oid:2.5.4.10',
    'urn:mace:dir:attribute-def:organizationalStatus'             => 'urn:oid:0.9.2342.19200300.100.1.45',
    'urn:mace:dir:attribute-def:organizationalUnitName'           => 'urn:oid:2.5.4.11',
    'urn:mace:dir:attribute-def:otherMailbox'                     => 'urn:oid:0.9.2342.19200300.100.1.22',
    'urn:mace:dir:attribute-def:ou'                               => 'urn:oid:2.5.4.11',
    'urn:mace:dir:attribute-def:owner'                            => 'urn:oid:2.5.4.32',
    'urn:mace:dir:attribute-def:pager'                            => 'urn:oid:0.9.2342.19200300.100.1.42',
    'urn:mace:dir:attribute-def:pagerTelephoneNumber'             => 'urn:oid:0.9.2342.19200300.100.1.42',
    'urn:mace:dir:attribute-def:personalSignature'                => 'urn:oid:0.9.2342.19200300.100.1.53',
    'urn:mace:dir:attribute-def:personalTitle'                    => 'urn:oid:0.9.2342.19200300.100.1.40',
    'urn:mace:dir:attribute-def:photo'                            => 'urn:oid:0.9.2342.19200300.100.1.7',
    'urn:mace:dir:attribute-def:physicalDeliveryOfficeName'       => 'urn:oid:2.5.4.19',
    'urn:mace:dir:attribute-def:pkcs9email'                       => 'urn:oid:1.2.840.113549.1.9.1',
    'urn:mace:dir:attribute-def:postOfficeBox'                    => 'urn:oid:2.5.4.18',
    'urn:mace:dir:attribute-def:postalAddress'                    => 'urn:oid:2.5.4.16',
    'urn:mace:dir:attribute-def:postalCode'                       => 'urn:oid:2.5.4.17',
    'urn:mace:dir:attribute-def:preferredDeliveryMethod'          => 'urn:oid:2.5.4.28',
    'urn:mace:dir:attribute-def:preferredLanguage'                => 'urn:oid:2.16.840.1.113730.3.1.39',
    'urn:mace:dir:attribute-def:presentationAddress'              => 'urn:oid:2.5.4.29',
    'urn:mace:dir:attribute-def:protocolInformation'              => 'urn:oid:2.5.4.48',
    'urn:mace:dir:attribute-def:pseudonym'                        => 'urn:oid:2.5.4.65',
    'urn:mace:dir:attribute-def:registeredAddress'                => 'urn:oid:2.5.4.26',
    'urn:mace:dir:attribute-def:rfc822Mailbox'                    => 'urn:oid:0.9.2342.19200300.100.1.3',
    'urn:mace:dir:attribute-def:roleOccupant'                     => 'urn:oid:2.5.4.33',
    'urn:mace:dir:attribute-def:roomNumber'                       => 'urn:oid:0.9.2342.19200300.100.1.6',
    'urn:mace:dir:attribute-def:sOARecord'                        => 'urn:oid:0.9.2342.19200300.100.1.30',
    'urn:mace:dir:attribute-def:searchGuide'                      => 'urn:oid:2.5.4.14',
    'urn:mace:dir:attribute-def:secretary'                        => 'urn:oid:0.9.2342.19200300.100.1.21',
    'urn:mace:dir:attribute-def:seeAlso'                          => 'urn:oid:2.5.4.34',
    'urn:mace:dir:attribute-def:serialNumber'                     => 'urn:oid:2.5.4.5',
    'urn:mace:dir:attribute-def:singleLevelQuality'               => 'urn:oid:0.9.2342.19200300.100.1.50',
    'urn:mace:dir:attribute-def:sisSchoolGrade'                   => 'urn:oid:1.2.752.194.10.2.2',
    'urn:mace:dir:attribute-def:sisLegalGuardianFor'              => 'urn:oid:1.2.752.194.10.2.1',
    'urn:mace:dir:attribute-def:sisOrgDepartment'                 => 'urn:oid:1.2.752.194.10.3',
    'urn:mace:dir:attribute-def:sisSchoolUnitCode'                => 'urn:oid:1.2.752.194.10.2.4',
    'urn:mace:dir:attribute-def:sn'                               => 'urn:oid:2.5.4.4',
    'urn:mace:dir:attribute-def:st'                               => 'urn:oid:2.5.4.8',
    'urn:mace:dir:attribute-def:stateOrProvinceName'              => 'urn:oid:2.5.4.8',
    'urn:mace:dir:attribute-def:street'                           => 'urn:oid:2.5.4.9',
    'urn:mace:dir:attribute-def:streetAddress'                    => 'urn:oid:2.5.4.9',
    'urn:mace:dir:attribute-def:subtreeMaximumQuality'            => 'urn:oid:0.9.2342.19200300.100.1.52',
    'urn:mace:dir:attribute-def:subtreeMinimumQuality'            => 'urn:oid:0.9.2342.19200300.100.1.51',
    'urn:mace:dir:attribute-def:supportedAlgorithms'              => 'urn:oid:2.5.4.52',
    'urn:mace:dir:attribute-def:supportedApplicationContext'      => 'urn:oid:2.5.4.30',
    'urn:mace:dir:attribute-def:surname'                          => 'urn:oid:2.5.4.4',
    'urn:mace:dir:attribute-def:telephoneNumber'                  => 'urn:oid:2.5.4.20',
    'urn:mace:dir:attribute-def:teletexTerminalIdentifier'        => 'urn:oid:2.5.4.22',
    'urn:mace:dir:attribute-def:telexNumber'                      => 'urn:oid:2.5.4.21',
    'urn:mace:dir:attribute-def:textEncodedORAddress'             => 'urn:oid:0.9.2342.19200300.100.1.2',
    'urn:mace:dir:attribute-def:title'                            => 'urn:oid:2.5.4.12',
    'urn:mace:dir:attribute-def:uid'                              => 'urn:oid:0.9.2342.19200300.100.1.1',
    'urn:mace:dir:attribute-def:uniqueIdentifier'                 => 'urn:oid:0.9.2342.19200300.100.1.44',
    'urn:mace:dir:attribute-def:uniqueMember'                     => 'urn:oid:2.5.4.50',
    'urn:mace:dir:attribute-def:userCertificate'                  => 'urn:oid:2.5.4.36',
    'urn:mace:dir:attribute-def:userClass'                        => 'urn:oid:0.9.2342.19200300.100.1.8',
    'urn:mace:dir:attribute-def:userPKCS12'                       => 'urn:oid:2.16.840.1.113730.3.1.216',
    'urn:mace:dir:attribute-def:userPassword'                     => 'urn:oid:2.5.4.35',
    'urn:mace:dir:attribute-def:userSMIMECertificate'             => 'urn:oid:2.16.840.1.113730.3.1.40',
    'urn:mace:dir:attribute-def:userid'                           => 'urn:oid:0.9.2342.19200300.100.1.1',
    'urn:mace:dir:attribute-def:x121Address'                      => 'urn:oid:2.5.4.24',
    'urn:mace:dir:attribute-def:x500UniqueIdentifier'             => 'urn:oid:2.5.4.45',
    'urn:mace:terena.org:attribute-def:schacCountryOfCitizenship' => 'urn:oid:1.3.6.1.4.1.25178.1.2.5',
    'urn:mace:terena.org:attribute-def:schacCountryOfResidence'   => 'urn:oid:1.3.6.1.4.1.25178.1.2.11',
    'urn:mace:terena.org:attribute-def:schacDateOfBirth'          => 'urn:oid:1.3.6.1.4.1.25178.1.2.3',
    'urn:mace:terena.org:attribute-def:schacExpiryDate'           => 'urn:oid:1.3.6.1.4.1.25178.1.2.17',
    'urn:mace:terena.org:attribute-def:schacGender'               => 'urn:oid:1.3.6.1.4.1.25178.1.2.2',
    'urn:mace:terena.org:attribute-def:schacHomeOrganization'     => 'urn:oid:1.3.6.1.4.1.25178.1.2.9',
    'urn:mace:terena.org:attribute-def:schacHomeOrganizationType' => 'urn:oid:1.3.6.1.4.1.25178.1.2.10',
    'urn:mace:terena.org:attribute-def:schacMotherTongue'         => 'urn:oid:1.3.6.1.4.1.25178.1.2.1',
    'urn:mace:terena.org:attribute-def:schacPersonalPosition'     => 'urn:oid:1.3.6.1.4.1.25178.1.2.13',
    'urn:mace:terena.org:attribute-def:schacPersonalTitle'        => 'urn:oid:1.3.6.1.4.1.25178.1.2.8',
    'urn:mace:terena.org:attribute-def:schacPersonalUniqueCode'   => 'urn:oid:1.3.6.1.4.1.25178.1.2.14',
    'urn:mace:terena.org:attribute-def:schacPersonalUniqueID'     => 'urn:oid:1.3.6.1.4.1.25178.1.2.15',
    'urn:mace:terena.org:attribute-def:schacPlaceOfBirth'         => 'urn:oid:1.3.6.1.4.1.25178.1.2.4',
    'urn:mace:terena.org:attribute-def:schacProjectMembership'    => 'urn:oid:1.3.6.1.4.1.25178.1.2.20',
    'urn:mace:terena.org:attribute-def:schacProjectSpecificRole'  => 'urn:oid:1.3.6.1.4.1.25178.1.2.21',
    'urn:mace:terena.org:attribute-def:schacSn1'                  => 'urn:oid:1.3.6.1.4.1.25178.1.2.6',
    'urn:mace:terena.org:attribute-def:schacSn2'                  => 'urn:oid:1.3.6.1.4.1.25178.1.2.7',
    'urn:mace:terena.org:attribute-def:schacUserPresenceID'       => 'urn:oid:1.3.6.1.4.1.25178.1.2.12',
    'urn:mace:terena.org:attribute-def:schacUserPrivateAttribute' => 'urn:oid:1.3.6.1.4.1.25178.1.2.18',
    'urn:mace:terena.org:attribute-def:schacUserStatus'           => 'urn:oid:1.3.6.1.4.1.25178.1.2.19',
    'urn:mace:terena.org:attribute-def:schacYearOfBirth'          => 'urn:oid:1.3.6.1.4.1.25178.1.0.2.3',
];
