<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Srednje vreme po Griniču (Abidžan)',
        'Africa/Accra' => 'Srednje vreme po Griniču (Akra)',
        'Africa/Addis_Ababa' => 'Istočno-afričko vreme (Adis Abeba)',
        'Africa/Algiers' => 'Srednjeevropsko vreme (Alžir)',
        'Africa/Asmera' => 'Istočno-afričko vreme (Asmera)',
        'Africa/Bamako' => 'Srednje vreme po Griniču (Bamako)',
        'Africa/Bangui' => 'Zapadno-afričko vreme (Bangui)',
        'Africa/Banjul' => 'Srednje vreme po Griniču (Banžul)',
        'Africa/Bissau' => 'Srednje vreme po Griniču (Bisao)',
        'Africa/Blantyre' => 'Centralno-afričko vreme (Blantir)',
        'Africa/Brazzaville' => 'Zapadno-afričko vreme (Brazavil)',
        'Africa/Bujumbura' => 'Centralno-afričko vreme (Budžumbura)',
        'Africa/Cairo' => 'Istočnoevropsko vreme (Kairo)',
        'Africa/Casablanca' => 'Zapadnoevropsko vreme (Kazablanka)',
        'Africa/Ceuta' => 'Srednjeevropsko vreme (Seuta)',
        'Africa/Conakry' => 'Srednje vreme po Griniču (Konakri)',
        'Africa/Dakar' => 'Srednje vreme po Griniču (Dakar)',
        'Africa/Dar_es_Salaam' => 'Istočno-afričko vreme (Dar-es-Salam)',
        'Africa/Djibouti' => 'Istočno-afričko vreme (Džibuti)',
        'Africa/Douala' => 'Zapadno-afričko vreme (Duala)',
        'Africa/El_Aaiun' => 'Zapadnoevropsko vreme (El Ajun)',
        'Africa/Freetown' => 'Srednje vreme po Griniču (Fritaun)',
        'Africa/Gaborone' => 'Centralno-afričko vreme (Gaboron)',
        'Africa/Harare' => 'Centralno-afričko vreme (Harare)',
        'Africa/Johannesburg' => 'Južno-afričko vreme (Johanesburg)',
        'Africa/Juba' => 'Centralno-afričko vreme (Džuba)',
        'Africa/Kampala' => 'Istočno-afričko vreme (Kampala)',
        'Africa/Khartoum' => 'Centralno-afričko vreme (Kartum)',
        'Africa/Kigali' => 'Centralno-afričko vreme (Kigali)',
        'Africa/Kinshasa' => 'Zapadno-afričko vreme (Kinšasa)',
        'Africa/Lagos' => 'Zapadno-afričko vreme (Lagos)',
        'Africa/Libreville' => 'Zapadno-afričko vreme (Librevil)',
        'Africa/Lome' => 'Srednje vreme po Griniču (Lome)',
        'Africa/Luanda' => 'Zapadno-afričko vreme (Luanda)',
        'Africa/Lubumbashi' => 'Centralno-afričko vreme (Lubumbaši)',
        'Africa/Lusaka' => 'Centralno-afričko vreme (Lusaka)',
        'Africa/Malabo' => 'Zapadno-afričko vreme (Malabo)',
        'Africa/Maputo' => 'Centralno-afričko vreme (Maputo)',
        'Africa/Maseru' => 'Južno-afričko vreme (Maseru)',
        'Africa/Mbabane' => 'Južno-afričko vreme (Mbabane)',
        'Africa/Mogadishu' => 'Istočno-afričko vreme (Mogadiš)',
        'Africa/Monrovia' => 'Srednje vreme po Griniču (Monrovija)',
        'Africa/Nairobi' => 'Istočno-afričko vreme (Najrobi)',
        'Africa/Ndjamena' => 'Zapadno-afričko vreme (Ndžamena)',
        'Africa/Niamey' => 'Zapadno-afričko vreme (Nijamej)',
        'Africa/Nouakchott' => 'Srednje vreme po Griniču (Nuakšot)',
        'Africa/Ouagadougou' => 'Srednje vreme po Griniču (Uagadugu)',
        'Africa/Porto-Novo' => 'Zapadno-afričko vreme (Porto Novo)',
        'Africa/Sao_Tome' => 'Srednje vreme po Griniču (Sao Tome)',
        'Africa/Tripoli' => 'Istočnoevropsko vreme (Tripoli)',
        'Africa/Tunis' => 'Srednjeevropsko vreme (Tunis)',
        'Africa/Windhoek' => 'Centralno-afričko vreme (Vindhuk)',
        'America/Adak' => 'Havajsko-aleutsko vreme (Adak)',
        'America/Anchorage' => 'Aljaska (Enkoridž)',
        'America/Anguilla' => 'Atlantsko vreme (Angvila)',
        'America/Antigua' => 'Atlantsko vreme (Antigva)',
        'America/Araguaina' => 'Brazilija vreme (Aragvajana)',
        'America/Argentina/La_Rioja' => 'Argentina vreme (La Rioha)',
        'America/Argentina/Rio_Gallegos' => 'Argentina vreme (Rio Galjegos)',
        'America/Argentina/Salta' => 'Argentina vreme (Salta)',
        'America/Argentina/San_Juan' => 'Argentina vreme (San Huan)',
        'America/Argentina/San_Luis' => 'Argentina vreme (San Lui)',
        'America/Argentina/Tucuman' => 'Argentina vreme (Tukuman)',
        'America/Argentina/Ushuaia' => 'Argentina vreme (Ušuaija)',
        'America/Aruba' => 'Atlantsko vreme (Aruba)',
        'America/Asuncion' => 'Paragvaj vreme (Asunsion)',
        'America/Bahia' => 'Brazilija vreme (Baija)',
        'America/Bahia_Banderas' => 'Severnoameričko centralno vreme (Baija Banderas)',
        'America/Barbados' => 'Atlantsko vreme (Barbados)',
        'America/Belem' => 'Brazilija vreme (Belem)',
        'America/Belize' => 'Severnoameričko centralno vreme (Belize)',
        'America/Blanc-Sablon' => 'Atlantsko vreme (Blank-Sejblon)',
        'America/Boa_Vista' => 'Amazon vreme (Boa Vista)',
        'America/Bogota' => 'Kolumbija vreme (Bogota)',
        'America/Boise' => 'Severnoameričko planinsko vreme (Bojzi)',
        'America/Buenos_Aires' => 'Argentina vreme (Buenos Ajres)',
        'America/Cambridge_Bay' => 'Severnoameričko planinsko vreme (Kembridž Bej)',
        'America/Campo_Grande' => 'Amazon vreme (Kampo Grande)',
        'America/Cancun' => 'Severnoameričko istočno vreme (Kankun)',
        'America/Caracas' => 'Venecuela vreme (Karakas)',
        'America/Catamarca' => 'Argentina vreme (Katamarka)',
        'America/Cayenne' => 'Francuska Gvajana vreme (Kajen)',
        'America/Cayman' => 'Severnoameričko istočno vreme (Kajmanska Ostrva)',
        'America/Chicago' => 'Severnoameričko centralno vreme (Čikago)',
        'America/Chihuahua' => 'Meksički Pacifik (Čihuahua)',
        'America/Coral_Harbour' => 'Severnoameričko istočno vreme (Koral Harbur)',
        'America/Cordoba' => 'Argentina vreme (Kordoba)',
        'America/Costa_Rica' => 'Severnoameričko centralno vreme (Kostarika)',
        'America/Creston' => 'Severnoameričko planinsko vreme (Kreston)',
        'America/Cuiaba' => 'Amazon vreme (Kuiaba)',
        'America/Curacao' => 'Atlantsko vreme (Kurasao)',
        'America/Danmarkshavn' => 'Srednje vreme po Griniču (Danmarkshagen)',
        'America/Dawson' => 'Jukon (Doson)',
        'America/Dawson_Creek' => 'Severnoameričko planinsko vreme (Doson Krik)',
        'America/Denver' => 'Severnoameričko planinsko vreme (Denver)',
        'America/Detroit' => 'Severnoameričko istočno vreme (Detroit)',
        'America/Dominica' => 'Atlantsko vreme (Dominika)',
        'America/Edmonton' => 'Severnoameričko planinsko vreme (Edmonton)',
        'America/Eirunepe' => 'Akre vreme (Eirunepe)',
        'America/El_Salvador' => 'Severnoameričko centralno vreme (Salvador)',
        'America/Fort_Nelson' => 'Severnoameričko planinsko vreme (Fort Nelson)',
        'America/Fortaleza' => 'Brazilija vreme (Fortaleza)',
        'America/Glace_Bay' => 'Atlantsko vreme (Glejs Bej)',
        'America/Godthab' => 'Zapadni Grenland (Gothab)',
        'America/Goose_Bay' => 'Atlantsko vreme (Gus Bej)',
        'America/Grand_Turk' => 'Severnoameričko istočno vreme (Grand Turk)',
        'America/Grenada' => 'Atlantsko vreme (Grenada)',
        'America/Guadeloupe' => 'Atlantsko vreme (Gvadalupe)',
        'America/Guatemala' => 'Severnoameričko centralno vreme (Gvatemala)',
        'America/Guayaquil' => 'Ekvador vreme (Gvajakil)',
        'America/Guyana' => 'Gvajana vreme',
        'America/Halifax' => 'Atlantsko vreme (Halifaks)',
        'America/Havana' => 'Kuba (Havana)',
        'America/Hermosillo' => 'Meksički Pacifik (Hermosiljo)',
        'America/Indiana/Knox' => 'Severnoameričko centralno vreme (Noks, Indijana)',
        'America/Indiana/Marengo' => 'Severnoameričko istočno vreme (Marengo, Indijana)',
        'America/Indiana/Petersburg' => 'Severnoameričko istočno vreme (Pitersburg, Indijana)',
        'America/Indiana/Tell_City' => 'Severnoameričko centralno vreme (Tel Siti, Indijana)',
        'America/Indiana/Vevay' => 'Severnoameričko istočno vreme (Vevaj, Indijana)',
        'America/Indiana/Vincennes' => 'Severnoameričko istočno vreme (Vincenes, Indijana)',
        'America/Indiana/Winamac' => 'Severnoameričko istočno vreme (Vinamak, Indijana)',
        'America/Indianapolis' => 'Severnoameričko istočno vreme (Indianapolis)',
        'America/Inuvik' => 'Severnoameričko planinsko vreme (Inuvik)',
        'America/Iqaluit' => 'Severnoameričko istočno vreme (Ikvaluit)',
        'America/Jamaica' => 'Severnoameričko istočno vreme (Jamajka)',
        'America/Jujuy' => 'Argentina vreme (Žužui)',
        'America/Juneau' => 'Aljaska (Žuno)',
        'America/Kentucky/Monticello' => 'Severnoameričko istočno vreme (Montičelo, Kentaki)',
        'America/Kralendijk' => 'Atlantsko vreme (Kralendajk)',
        'America/La_Paz' => 'Bolivija vreme (La Paz)',
        'America/Lima' => 'Peru vreme (Lima)',
        'America/Los_Angeles' => 'Severnoameričko pacifičko vreme (Los Anđeles)',
        'America/Louisville' => 'Severnoameričko istočno vreme (Luivile)',
        'America/Lower_Princes' => 'Atlantsko vreme (Louer Prinsiz Kvorter)',
        'America/Maceio' => 'Brazilija vreme (Masejo)',
        'America/Managua' => 'Severnoameričko centralno vreme (Managva)',
        'America/Manaus' => 'Amazon vreme (Manaus)',
        'America/Marigot' => 'Atlantsko vreme (Marigo)',
        'America/Martinique' => 'Atlantsko vreme (Martinik)',
        'America/Matamoros' => 'Severnoameričko centralno vreme (Matamoros)',
        'America/Mazatlan' => 'Meksički Pacifik (Mazatlan)',
        'America/Mendoza' => 'Argentina vreme (Mendosa)',
        'America/Menominee' => 'Severnoameričko centralno vreme (Menomini)',
        'America/Merida' => 'Severnoameričko centralno vreme (Merida)',
        'America/Metlakatla' => 'Aljaska (Metlakatla)',
        'America/Mexico_City' => 'Severnoameričko centralno vreme (Meksiko Siti)',
        'America/Miquelon' => 'Sen Pjer i Mikelon',
        'America/Moncton' => 'Atlantsko vreme (Monkton)',
        'America/Monterrey' => 'Severnoameričko centralno vreme (Monterej)',
        'America/Montevideo' => 'Urugvaj vreme (Montevideo)',
        'America/Montreal' => 'Kanada (Montreal)',
        'America/Montserrat' => 'Atlantsko vreme (Montserat)',
        'America/Nassau' => 'Severnoameričko istočno vreme (Nasau)',
        'America/New_York' => 'Severnoameričko istočno vreme (Njujork)',
        'America/Nipigon' => 'Severnoameričko istočno vreme (Nipigon)',
        'America/Nome' => 'Aljaska (Nom)',
        'America/Noronha' => 'Fernando de Noronja vreme',
        'America/North_Dakota/Beulah' => 'Severnoameričko centralno vreme (Bijula, Severna Dakota)',
        'America/North_Dakota/Center' => 'Severnoameričko centralno vreme (Centar, Severna Dakota)',
        'America/North_Dakota/New_Salem' => 'Severnoameričko centralno vreme (Novi Salem, Severna Dakota)',
        'America/Ojinaga' => 'Severnoameričko planinsko vreme (Ohinaga)',
        'America/Panama' => 'Severnoameričko istočno vreme (Panama)',
        'America/Pangnirtung' => 'Severnoameričko istočno vreme (Pangnirtung)',
        'America/Paramaribo' => 'Surinam vreme (Paramaribo)',
        'America/Phoenix' => 'Severnoameričko planinsko vreme (Finiks)',
        'America/Port-au-Prince' => 'Severnoameričko istočno vreme (Port o Prens)',
        'America/Port_of_Spain' => 'Atlantsko vreme (Port of Spejn)',
        'America/Porto_Velho' => 'Amazon vreme (Porto Veljo)',
        'America/Puerto_Rico' => 'Atlantsko vreme (Porto Riko)',
        'America/Punta_Arenas' => 'Čile vreme (Punta Arenas)',
        'America/Rainy_River' => 'Severnoameričko centralno vreme (Rejni River)',
        'America/Rankin_Inlet' => 'Severnoameričko centralno vreme (Rankin Inlet)',
        'America/Recife' => 'Brazilija vreme (Resife)',
        'America/Regina' => 'Severnoameričko centralno vreme (Regina)',
        'America/Resolute' => 'Severnoameričko centralno vreme (Resolut)',
        'America/Rio_Branco' => 'Akre vreme (Rio Branko)',
        'America/Santa_Isabel' => 'Severozapadni Meksiko (Santa Izabel)',
        'America/Santarem' => 'Brazilija vreme (Santarem)',
        'America/Santiago' => 'Čile vreme (Santjago)',
        'America/Santo_Domingo' => 'Atlantsko vreme (Santo Domingo)',
        'America/Sao_Paulo' => 'Brazilija vreme (Sao Paolo)',
        'America/Scoresbysund' => 'Istočni Grenland (Skorezbisund)',
        'America/Sitka' => 'Aljaska (Sitka)',
        'America/St_Barthelemy' => 'Atlantsko vreme (Sv. Bartolomej)',
        'America/St_Johns' => 'Njufaundlend (Sv. Džon)',
        'America/St_Kitts' => 'Atlantsko vreme (Sent Kits)',
        'America/St_Lucia' => 'Atlantsko vreme (Sv. Lucija)',
        'America/St_Thomas' => 'Atlantsko vreme (Sv. Toma)',
        'America/St_Vincent' => 'Atlantsko vreme (Sent Vinsent)',
        'America/Swift_Current' => 'Severnoameričko centralno vreme (Svift Kurent)',
        'America/Tegucigalpa' => 'Severnoameričko centralno vreme (Tegusigalpa)',
        'America/Thule' => 'Atlantsko vreme (Tul)',
        'America/Thunder_Bay' => 'Severnoameričko istočno vreme (Tander Bej)',
        'America/Tijuana' => 'Severnoameričko pacifičko vreme (Tihuana)',
        'America/Toronto' => 'Severnoameričko istočno vreme (Toronto)',
        'America/Tortola' => 'Atlantsko vreme (Tortola)',
        'America/Vancouver' => 'Severnoameričko pacifičko vreme (Vankuver)',
        'America/Whitehorse' => 'Jukon (Vajthors)',
        'America/Winnipeg' => 'Severnoameričko centralno vreme (Vinipeg)',
        'America/Yakutat' => 'Aljaska (Jakutat)',
        'America/Yellowknife' => 'Severnoameričko planinsko vreme (Jelounajf)',
        'Antarctica/Casey' => 'Antarktik (Kejsi)',
        'Antarctica/Davis' => 'Dejvis vreme',
        'Antarctica/DumontDUrville' => 'Dimon d’Urvil vreme',
        'Antarctica/Macquarie' => 'Australijsko istočno vreme (Mekvori)',
        'Antarctica/Mawson' => 'Moson vreme',
        'Antarctica/McMurdo' => 'Novi Zeland vreme (Makmurdo)',
        'Antarctica/Palmer' => 'Čile vreme (Palmer)',
        'Antarctica/Rothera' => 'Rotera vreme',
        'Antarctica/Syowa' => 'Šova vreme',
        'Antarctica/Troll' => 'Srednje vreme po Griniču (Trol)',
        'Antarctica/Vostok' => 'Vostok vreme',
        'Arctic/Longyearbyen' => 'Srednjeevropsko vreme (Longjerbjen)',
        'Asia/Aden' => 'Arabijsko vreme (Aden)',
        'Asia/Almaty' => 'Istočno-kazahstansko vreme (Almati)',
        'Asia/Amman' => 'Istočnoevropsko vreme (Aman)',
        'Asia/Anadyr' => 'Anadir vreme',
        'Asia/Aqtau' => 'Zapadno-kazahstansko vreme (Aktau)',
        'Asia/Aqtobe' => 'Zapadno-kazahstansko vreme (Akutobe)',
        'Asia/Ashgabat' => 'Turkmenistan vreme (Ašhabad)',
        'Asia/Atyrau' => 'Zapadno-kazahstansko vreme (Atirau)',
        'Asia/Baghdad' => 'Arabijsko vreme (Bagdad)',
        'Asia/Bahrain' => 'Arabijsko vreme (Bahrein)',
        'Asia/Baku' => 'Azerbejdžan vreme (Baku)',
        'Asia/Bangkok' => 'Indokina vreme (Bangkok)',
        'Asia/Barnaul' => 'Rusija (Barnaul)',
        'Asia/Beirut' => 'Istočnoevropsko vreme (Bejrut)',
        'Asia/Bishkek' => 'Kirgistan vreme (Biškek)',
        'Asia/Brunei' => 'Brunej Darusalum vreme',
        'Asia/Calcutta' => 'Indijsko standardno vreme (Kalkuta)',
        'Asia/Chita' => 'Jakutsk vreme (Čita)',
        'Asia/Choibalsan' => 'Ulan Bator vreme (Čojbalsan)',
        'Asia/Colombo' => 'Indijsko standardno vreme (Kolombo)',
        'Asia/Damascus' => 'Istočnoevropsko vreme (Damask)',
        'Asia/Dhaka' => 'Bangladeš vreme (Daka)',
        'Asia/Dili' => 'Istočni timor vreme (Dili)',
        'Asia/Dubai' => 'Zalivsko vreme (Dubai)',
        'Asia/Dushanbe' => 'Tadžikistan vreme (Dušanbe)',
        'Asia/Famagusta' => 'Istočnoevropsko vreme (Famagusta)',
        'Asia/Gaza' => 'Istočnoevropsko vreme (Gaza)',
        'Asia/Hebron' => 'Istočnoevropsko vreme (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kong vreme (Hongkong)',
        'Asia/Hovd' => 'Hovd vreme',
        'Asia/Irkutsk' => 'Irkuck vreme',
        'Asia/Jakarta' => 'Zapadno-indonezijsko vreme (Džakarta)',
        'Asia/Jayapura' => 'Istočno-indonezijsko vreme (Džajapura)',
        'Asia/Jerusalem' => 'Izraelsko vreme (Jerusalim)',
        'Asia/Kabul' => 'Avganistan vreme (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsko-kamčatsko vreme (Kamčatka)',
        'Asia/Karachi' => 'Pakistan vreme (Karači)',
        'Asia/Katmandu' => 'Nepal vreme (Katmandu)',
        'Asia/Khandyga' => 'Jakutsk vreme (Handiga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsk vreme',
        'Asia/Kuala_Lumpur' => 'Malezija vreme (Kuala Lumpur)',
        'Asia/Kuching' => 'Malezija vreme (Kučing)',
        'Asia/Kuwait' => 'Arabijsko vreme (Kuvajt)',
        'Asia/Macau' => 'Kina vreme (Makao)',
        'Asia/Magadan' => 'Magadan vreme',
        'Asia/Makassar' => 'Centralno-indonezijsko vreme (Makasar)',
        'Asia/Manila' => 'Filipini vreme (Manila)',
        'Asia/Muscat' => 'Zalivsko vreme (Muskat)',
        'Asia/Nicosia' => 'Istočnoevropsko vreme (Nikozija)',
        'Asia/Novokuznetsk' => 'Krasnojarsk vreme (Novokuznjeck)',
        'Asia/Novosibirsk' => 'Novosibirsk vreme',
        'Asia/Omsk' => 'Omsk vreme',
        'Asia/Oral' => 'Zapadno-kazahstansko vreme (Oral)',
        'Asia/Phnom_Penh' => 'Indokina vreme (Pnom Pen)',
        'Asia/Pontianak' => 'Zapadno-indonezijsko vreme (Pontijanak)',
        'Asia/Pyongyang' => 'Korejsko vreme (Pjongjang)',
        'Asia/Qatar' => 'Arabijsko vreme (Katar)',
        'Asia/Qostanay' => 'Istočno-kazahstansko vreme (Kostanaj)',
        'Asia/Qyzylorda' => 'Zapadno-kazahstansko vreme (Kizilorda)',
        'Asia/Rangoon' => 'Mijanmar vreme (Rangun)',
        'Asia/Riyadh' => 'Arabijsko vreme (Rijad)',
        'Asia/Saigon' => 'Indokina vreme (Ho Ši Min)',
        'Asia/Sakhalin' => 'Sahalin vreme',
        'Asia/Samarkand' => 'Uzbekistan vreme (Samarkand)',
        'Asia/Seoul' => 'Korejsko vreme (Seul)',
        'Asia/Shanghai' => 'Kina vreme (Šangaj)',
        'Asia/Singapore' => 'Singapur, standardno vreme',
        'Asia/Srednekolymsk' => 'Magadan vreme (Srednjekolimsk)',
        'Asia/Taipei' => 'Tajpej vreme',
        'Asia/Tashkent' => 'Uzbekistan vreme (Taškent)',
        'Asia/Tbilisi' => 'Gruzija vreme (Tbilisi)',
        'Asia/Tehran' => 'Iran vreme (Teheran)',
        'Asia/Thimphu' => 'Butan vreme (Timpu)',
        'Asia/Tokyo' => 'Japansko vreme (Tokio)',
        'Asia/Tomsk' => 'Rusija (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Bator vreme',
        'Asia/Urumqi' => 'Kina (Urumći)',
        'Asia/Ust-Nera' => 'Vladivostok vreme (Ust-Nera)',
        'Asia/Vientiane' => 'Indokina vreme (Vijentijan)',
        'Asia/Vladivostok' => 'Vladivostok vreme',
        'Asia/Yakutsk' => 'Jakutsk vreme',
        'Asia/Yekaterinburg' => 'Jekaterinburg vreme',
        'Asia/Yerevan' => 'Jermenija vreme (Jerevan)',
        'Atlantic/Azores' => 'Azori vreme',
        'Atlantic/Bermuda' => 'Atlantsko vreme (Bermuda)',
        'Atlantic/Canary' => 'Zapadnoevropsko vreme (Kanarska ostrva)',
        'Atlantic/Cape_Verde' => 'Zelenortska Ostrva vreme',
        'Atlantic/Faeroe' => 'Zapadnoevropsko vreme (Farska Ostrva)',
        'Atlantic/Madeira' => 'Zapadnoevropsko vreme (Madeira)',
        'Atlantic/Reykjavik' => 'Srednje vreme po Griniču (Rejkjavik)',
        'Atlantic/South_Georgia' => 'Južna Džordžija vreme',
        'Atlantic/St_Helena' => 'Srednje vreme po Griniču (Sveta Jelena)',
        'Atlantic/Stanley' => 'Folklandska Ostrva vreme (Stenli)',
        'Australia/Adelaide' => 'Australijsko centralno vreme (Adelejd)',
        'Australia/Brisbane' => 'Australijsko istočno vreme (Brizbejn)',
        'Australia/Broken_Hill' => 'Australijsko centralno vreme (Broken Hil)',
        'Australia/Currie' => 'Australijsko istočno vreme (Kari)',
        'Australia/Darwin' => 'Australijsko centralno vreme (Darvin)',
        'Australia/Eucla' => 'Australijsko centralno zapadno vreme (Iukla)',
        'Australia/Hobart' => 'Australijsko istočno vreme (Hobart)',
        'Australia/Lindeman' => 'Australijsko istočno vreme (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Hov vreme (Lord Hau)',
        'Australia/Melbourne' => 'Australijsko istočno vreme (Melburn)',
        'Australia/Perth' => 'Australijsko zapadno vreme (Pert)',
        'Australia/Sydney' => 'Australijsko istočno vreme (Sidnej)',
        'CST6CDT' => 'Severnoameričko centralno vreme',
        'EST5EDT' => 'Severnoameričko istočno vreme',
        'Etc/GMT' => 'Srednje vreme po Griniču',
        'Etc/UTC' => 'Koordinisano univerzalno vreme',
        'Europe/Amsterdam' => 'Srednjeevropsko vreme (Amsterdam)',
        'Europe/Andorra' => 'Srednjeevropsko vreme (Andora)',
        'Europe/Astrakhan' => 'Moskva vreme (Astrakan)',
        'Europe/Athens' => 'Istočnoevropsko vreme (Atina)',
        'Europe/Belgrade' => 'Srednjeevropsko vreme (Beograd)',
        'Europe/Berlin' => 'Srednjeevropsko vreme (Berlin)',
        'Europe/Bratislava' => 'Srednjeevropsko vreme (Bratislava)',
        'Europe/Brussels' => 'Srednjeevropsko vreme (Brisel)',
        'Europe/Bucharest' => 'Istočnoevropsko vreme (Bukurešt)',
        'Europe/Budapest' => 'Srednjeevropsko vreme (Budimpešta)',
        'Europe/Busingen' => 'Srednjeevropsko vreme (Bisingen)',
        'Europe/Chisinau' => 'Istočnoevropsko vreme (Kišinjev)',
        'Europe/Copenhagen' => 'Srednjeevropsko vreme (Kopenhagen)',
        'Europe/Dublin' => 'Srednje vreme po Griniču (Dablin)',
        'Europe/Gibraltar' => 'Srednjeevropsko vreme (Gibraltar)',
        'Europe/Guernsey' => 'Srednje vreme po Griniču (Gernzi)',
        'Europe/Helsinki' => 'Istočnoevropsko vreme (Helsinki)',
        'Europe/Isle_of_Man' => 'Srednje vreme po Griniču (Ostrvo Man)',
        'Europe/Istanbul' => 'Turska (Istanbul)',
        'Europe/Jersey' => 'Srednje vreme po Griniču (Džerzi)',
        'Europe/Kaliningrad' => 'Istočnoevropsko vreme (Kalinjingrad)',
        'Europe/Kiev' => 'Istočnoevropsko vreme (Kijev)',
        'Europe/Kirov' => 'Rusija (Kirov)',
        'Europe/Lisbon' => 'Zapadnoevropsko vreme (Lisabon)',
        'Europe/Ljubljana' => 'Srednjeevropsko vreme (Ljubljana)',
        'Europe/London' => 'Srednje vreme po Griniču (London)',
        'Europe/Luxembourg' => 'Srednjeevropsko vreme (Luksemburg)',
        'Europe/Madrid' => 'Srednjeevropsko vreme (Madrid)',
        'Europe/Malta' => 'Srednjeevropsko vreme (Malta)',
        'Europe/Mariehamn' => 'Istočnoevropsko vreme (Marihamn)',
        'Europe/Minsk' => 'Moskva vreme (Minsk)',
        'Europe/Monaco' => 'Srednjeevropsko vreme (Monako)',
        'Europe/Moscow' => 'Moskva vreme',
        'Europe/Oslo' => 'Srednjeevropsko vreme (Oslo)',
        'Europe/Paris' => 'Srednjeevropsko vreme (Pariz)',
        'Europe/Podgorica' => 'Srednjeevropsko vreme (Podgorica)',
        'Europe/Prague' => 'Srednjeevropsko vreme (Prag)',
        'Europe/Riga' => 'Istočnoevropsko vreme (Riga)',
        'Europe/Rome' => 'Srednjeevropsko vreme (Rim)',
        'Europe/Samara' => 'Samara vreme',
        'Europe/San_Marino' => 'Srednjeevropsko vreme (San Marino)',
        'Europe/Sarajevo' => 'Srednjeevropsko vreme (Sarajevo)',
        'Europe/Saratov' => 'Moskva vreme (Saratov)',
        'Europe/Simferopol' => 'Moskva vreme (Simferopolj)',
        'Europe/Skopje' => 'Srednjeevropsko vreme (Skoplje)',
        'Europe/Sofia' => 'Istočnoevropsko vreme (Sofija)',
        'Europe/Stockholm' => 'Srednjeevropsko vreme (Stokholm)',
        'Europe/Tallinn' => 'Istočnoevropsko vreme (Talin)',
        'Europe/Tirane' => 'Srednjeevropsko vreme (Tirana)',
        'Europe/Ulyanovsk' => 'Moskva vreme (Uljanovsk)',
        'Europe/Uzhgorod' => 'Istočnoevropsko vreme (Užgorod)',
        'Europe/Vaduz' => 'Srednjeevropsko vreme (Vaduz)',
        'Europe/Vatican' => 'Srednjeevropsko vreme (Vatikan)',
        'Europe/Vienna' => 'Srednjeevropsko vreme (Beč)',
        'Europe/Vilnius' => 'Istočnoevropsko vreme (Vilnjus)',
        'Europe/Volgograd' => 'Volgograd vreme',
        'Europe/Warsaw' => 'Srednjeevropsko vreme (Varšava)',
        'Europe/Zagreb' => 'Srednjeevropsko vreme (Zagreb)',
        'Europe/Zaporozhye' => 'Istočnoevropsko vreme (Zaporožje)',
        'Europe/Zurich' => 'Srednjeevropsko vreme (Cirih)',
        'Indian/Antananarivo' => 'Istočno-afričko vreme (Antananarivo)',
        'Indian/Chagos' => 'Indijsko okeansko vreme (Čagos)',
        'Indian/Christmas' => 'Božićno ostrvo vreme',
        'Indian/Cocos' => 'Kokos (Keling) Ostrva vreme',
        'Indian/Comoro' => 'Istočno-afričko vreme (Komoro)',
        'Indian/Kerguelen' => 'Francusko južno i antarktičko vreme (Kergelen)',
        'Indian/Mahe' => 'Sejšeli vreme (Mahe)',
        'Indian/Maldives' => 'Maldivi vreme',
        'Indian/Mauritius' => 'Mauricijus vreme',
        'Indian/Mayotte' => 'Istočno-afričko vreme (Majot)',
        'Indian/Reunion' => 'Reinion vreme (Reunion)',
        'MST7MDT' => 'Severnoameričko planinsko vreme',
        'PST8PDT' => 'Severnoameričko pacifičko vreme',
        'Pacific/Apia' => 'Apija vreme',
        'Pacific/Auckland' => 'Novi Zeland vreme (Okland)',
        'Pacific/Bougainville' => 'Papua Nova Gvineja vreme (Buganvil)',
        'Pacific/Chatham' => 'Čatam vreme',
        'Pacific/Easter' => 'Uskršnja ostrva vreme (Uskršnje ostrvo)',
        'Pacific/Efate' => 'Vanuatu vreme (Efat)',
        'Pacific/Enderbury' => 'Feniks ostrva vreme (Enderberi)',
        'Pacific/Fakaofo' => 'Tokelau vreme (Fakaofo)',
        'Pacific/Fiji' => 'Fidži vreme',
        'Pacific/Funafuti' => 'Tuvalu vreme (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos vreme',
        'Pacific/Gambier' => 'Gambije vreme',
        'Pacific/Guadalcanal' => 'Solomonska Ostrva vreme (Gvadalkanal)',
        'Pacific/Guam' => 'Čamoro vreme (Guam)',
        'Pacific/Honolulu' => 'Havajsko-aleutsko vreme (Honolulu)',
        'Pacific/Johnston' => 'Havajsko-aleutsko vreme (Džonston)',
        'Pacific/Kiritimati' => 'Ostrva Lajn vreme (Kiritimati)',
        'Pacific/Kosrae' => 'Košre vreme',
        'Pacific/Kwajalein' => 'Maršalska Ostrva vreme (Kvadžalejin)',
        'Pacific/Majuro' => 'Maršalska Ostrva vreme (Majuro)',
        'Pacific/Marquesas' => 'Markiz vreme',
        'Pacific/Midway' => 'Samoa vreme (Midvej)',
        'Pacific/Nauru' => 'Nauru vreme',
        'Pacific/Niue' => 'Niue vreme',
        'Pacific/Norfolk' => 'Norfolk Ostrvo vreme',
        'Pacific/Noumea' => 'Nova Kaledonija vreme (Numea)',
        'Pacific/Pago_Pago' => 'Samoa vreme (Pago Pago)',
        'Pacific/Palau' => 'Palau vreme',
        'Pacific/Pitcairn' => 'Pitkern vreme',
        'Pacific/Ponape' => 'Ponpej vreme (Ponape)',
        'Pacific/Port_Moresby' => 'Papua Nova Gvineja vreme (Port Morzbi)',
        'Pacific/Rarotonga' => 'Kukova ostrva vreme (Rarotonga)',
        'Pacific/Saipan' => 'Čamoro vreme (Sajpan)',
        'Pacific/Tahiti' => 'Tahiti vreme',
        'Pacific/Tarawa' => 'Gilbert ostrva vreme (Tarava)',
        'Pacific/Tongatapu' => 'Tonga vreme (Tongatapu)',
        'Pacific/Truk' => 'Čuuk vreme (Truk)',
        'Pacific/Wake' => 'Vejk ostrvo vreme',
        'Pacific/Wallis' => 'Valis i Futuna Ostrva vreme',
    ],
    'Meta' => [
    ],
];
