<?php

return [
    'Names' => [
        'Africa/Abidjan' => '그리니치 표준시(아비장)',
        'Africa/Accra' => '그리니치 표준시(아크라)',
        'Africa/Addis_Ababa' => '동아프리카 시간(아디스아바바)',
        'Africa/Algiers' => '중부유럽 시간(알제)',
        'Africa/Asmera' => '동아프리카 시간(아스메라)',
        'Africa/Bamako' => '그리니치 표준시(바마코)',
        'Africa/Bangui' => '서아프리카 시간(방기)',
        'Africa/Banjul' => '그리니치 표준시(반줄)',
        'Africa/Bissau' => '그리니치 표준시(비사우)',
        'Africa/Blantyre' => '중앙아프리카 시간(블랜타이어)',
        'Africa/Brazzaville' => '서아프리카 시간(브라자빌)',
        'Africa/Bujumbura' => '중앙아프리카 시간(부줌부라)',
        'Africa/Cairo' => '동유럽 시간(카이로)',
        'Africa/Casablanca' => '서유럽 시간(카사블랑카)',
        'Africa/Ceuta' => '중부유럽 시간(세우타)',
        'Africa/Conakry' => '그리니치 표준시(코나크리)',
        'Africa/Dakar' => '그리니치 표준시(다카르)',
        'Africa/Dar_es_Salaam' => '동아프리카 시간(다르에스살람)',
        'Africa/Djibouti' => '동아프리카 시간(지부티)',
        'Africa/Douala' => '서아프리카 시간(두알라)',
        'Africa/El_Aaiun' => '서유럽 시간(엘아이운)',
        'Africa/Freetown' => '그리니치 표준시(프리타운)',
        'Africa/Gaborone' => '중앙아프리카 시간(가보로네)',
        'Africa/Harare' => '중앙아프리카 시간(하라레)',
        'Africa/Johannesburg' => '남아프리카 시간(요하네스버그)',
        'Africa/Juba' => '중앙아프리카 시간(주바)',
        'Africa/Kampala' => '동아프리카 시간(캄팔라)',
        'Africa/Khartoum' => '중앙아프리카 시간(카르툼)',
        'Africa/Kigali' => '중앙아프리카 시간(키갈리)',
        'Africa/Kinshasa' => '서아프리카 시간(킨샤사)',
        'Africa/Lagos' => '서아프리카 시간(라고스)',
        'Africa/Libreville' => '서아프리카 시간(리브르빌)',
        'Africa/Lome' => '그리니치 표준시(로메)',
        'Africa/Luanda' => '서아프리카 시간(루안다)',
        'Africa/Lubumbashi' => '중앙아프리카 시간(루붐바시)',
        'Africa/Lusaka' => '중앙아프리카 시간(루사카)',
        'Africa/Malabo' => '서아프리카 시간(말라보)',
        'Africa/Maputo' => '중앙아프리카 시간(마푸토)',
        'Africa/Maseru' => '남아프리카 시간(마세루)',
        'Africa/Mbabane' => '남아프리카 시간(음바바네)',
        'Africa/Mogadishu' => '동아프리카 시간(모가디슈)',
        'Africa/Monrovia' => '그리니치 표준시(몬로비아)',
        'Africa/Nairobi' => '동아프리카 시간(나이로비)',
        'Africa/Ndjamena' => '서아프리카 시간(엔자메나)',
        'Africa/Niamey' => '서아프리카 시간(니아메)',
        'Africa/Nouakchott' => '그리니치 표준시(누악쇼트)',
        'Africa/Ouagadougou' => '그리니치 표준시(와가두구)',
        'Africa/Porto-Novo' => '서아프리카 시간(포르토노보)',
        'Africa/Sao_Tome' => '그리니치 표준시(상투메)',
        'Africa/Tripoli' => '동유럽 시간(트리폴리)',
        'Africa/Tunis' => '중부유럽 시간(튀니스)',
        'Africa/Windhoek' => '중앙아프리카 시간(빈트후크)',
        'America/Adak' => '하와이 알류샨 시간(에이닥)',
        'America/Anchorage' => '알래스카 시간(앵커리지)',
        'America/Anguilla' => '대서양 시간(앙귈라)',
        'America/Antigua' => '대서양 시간(안티과)',
        'America/Araguaina' => '브라질리아 시간(아라과이나)',
        'America/Argentina/La_Rioja' => '아르헨티나 시간(라 리오하)',
        'America/Argentina/Rio_Gallegos' => '아르헨티나 시간(리오 가예고스)',
        'America/Argentina/Salta' => '아르헨티나 시간(살타)',
        'America/Argentina/San_Juan' => '아르헨티나 시간(산후안)',
        'America/Argentina/San_Luis' => '아르헨티나 시간(산루이스)',
        'America/Argentina/Tucuman' => '아르헨티나 시간(투쿠만)',
        'America/Argentina/Ushuaia' => '아르헨티나 시간(우수아이아)',
        'America/Aruba' => '대서양 시간(아루바)',
        'America/Asuncion' => '파라과이 시간(아순시온)',
        'America/Bahia' => '브라질리아 시간(바히아)',
        'America/Bahia_Banderas' => '미 중부 시간(바이아 반데라스)',
        'America/Barbados' => '대서양 시간(바베이도스)',
        'America/Belem' => '브라질리아 시간(벨렘)',
        'America/Belize' => '미 중부 시간(벨리즈)',
        'America/Blanc-Sablon' => '대서양 시간(블랑 사블롱)',
        'America/Boa_Vista' => '아마존 시간(보아 비스타)',
        'America/Bogota' => '콜롬비아 시간(보고타)',
        'America/Boise' => '미 산지 시간(보이시)',
        'America/Buenos_Aires' => '아르헨티나 시간(부에노스 아이레스)',
        'America/Cambridge_Bay' => '미 산지 시간(케임브리지 베이)',
        'America/Campo_Grande' => '아마존 시간(캄포 그란데)',
        'America/Cancun' => '미 동부 시간(칸쿤)',
        'America/Caracas' => '베네수엘라 시간(카라카스)',
        'America/Catamarca' => '아르헨티나 시간(카타마르카)',
        'America/Cayenne' => '프랑스령 가이아나 시간(카옌)',
        'America/Cayman' => '미 동부 시간(케이맨)',
        'America/Chicago' => '미 중부 시간(시카고)',
        'America/Chihuahua' => '멕시코 태평양 시간(치와와)',
        'America/Coral_Harbour' => '미 동부 시간(코랄하버)',
        'America/Cordoba' => '아르헨티나 시간(코르도바)',
        'America/Costa_Rica' => '미 중부 시간(코스타리카)',
        'America/Creston' => '미 산지 시간(크레스톤)',
        'America/Cuiaba' => '아마존 시간(쿠이아바)',
        'America/Curacao' => '대서양 시간(퀴라소)',
        'America/Danmarkshavn' => '그리니치 표준시(덴마크샤븐)',
        'America/Dawson' => '유콘 시간(도슨)',
        'America/Dawson_Creek' => '미 산지 시간(도슨크릭)',
        'America/Denver' => '미 산지 시간(덴버)',
        'America/Detroit' => '미 동부 시간(디트로이트)',
        'America/Dominica' => '대서양 시간(도미니카)',
        'America/Edmonton' => '미 산지 시간(에드먼턴)',
        'America/Eirunepe' => '아크레 시간(아이루네페)',
        'America/El_Salvador' => '미 중부 시간(엘살바도르)',
        'America/Fort_Nelson' => '미 산지 시간(포트 넬슨)',
        'America/Fortaleza' => '브라질리아 시간(포르탈레자)',
        'America/Glace_Bay' => '대서양 시간(글라스베이)',
        'America/Godthab' => '그린란드 서부 시간(고드호프)',
        'America/Goose_Bay' => '대서양 시간(구즈베이)',
        'America/Grand_Turk' => '미 동부 시간(그랜드 터크)',
        'America/Grenada' => '대서양 시간(그레나다)',
        'America/Guadeloupe' => '대서양 시간(과들루프)',
        'America/Guatemala' => '미 중부 시간(과테말라)',
        'America/Guayaquil' => '에콰도르 시간(과야킬)',
        'America/Guyana' => '가이아나 시간',
        'America/Halifax' => '대서양 시간(핼리팩스)',
        'America/Havana' => '쿠바 시간(하바나)',
        'America/Hermosillo' => '멕시코 태평양 시간(에르모시요)',
        'America/Indiana/Knox' => '미 중부 시간(인디애나주, 녹스)',
        'America/Indiana/Marengo' => '미 동부 시간(인디애나주, 머렝고)',
        'America/Indiana/Petersburg' => '미 동부 시간(인디애나주, 피츠버그)',
        'America/Indiana/Tell_City' => '미 중부 시간(인디애나주, 텔시티)',
        'America/Indiana/Vevay' => '미 동부 시간(인디애나주, 비비)',
        'America/Indiana/Vincennes' => '미 동부 시간(인디애나주, 빈센스)',
        'America/Indiana/Winamac' => '미 동부 시간(인디애나주, 위너맥)',
        'America/Indianapolis' => '미 동부 시간(인디애나폴리스)',
        'America/Inuvik' => '미 산지 시간(이누빅)',
        'America/Iqaluit' => '미 동부 시간(이칼루이트)',
        'America/Jamaica' => '미 동부 시간(자메이카)',
        'America/Jujuy' => '아르헨티나 시간(후후이)',
        'America/Juneau' => '알래스카 시간(주노)',
        'America/Kentucky/Monticello' => '미 동부 시간(켄터키주, 몬티첼로)',
        'America/Kralendijk' => '대서양 시간(크라렌디즈크)',
        'America/La_Paz' => '볼리비아 시간(라파스)',
        'America/Lima' => '페루 시간(리마)',
        'America/Los_Angeles' => '미 태평양 시간(로스앤젤레스)',
        'America/Louisville' => '미 동부 시간(루이빌)',
        'America/Lower_Princes' => '대서양 시간(로워 프린스 쿼터)',
        'America/Maceio' => '브라질리아 시간(마세이오)',
        'America/Managua' => '미 중부 시간(마나과)',
        'America/Manaus' => '아마존 시간(마나우스)',
        'America/Marigot' => '대서양 시간(마리곳)',
        'America/Martinique' => '대서양 시간(마티니크)',
        'America/Matamoros' => '미 중부 시간(마타모로스)',
        'America/Mazatlan' => '멕시코 태평양 시간(마사틀란)',
        'America/Mendoza' => '아르헨티나 시간(멘도사)',
        'America/Menominee' => '미 중부 시간(메노미니)',
        'America/Merida' => '미 중부 시간(메리다)',
        'America/Metlakatla' => '알래스카 시간(메틀라카틀라)',
        'America/Mexico_City' => '미 중부 시간(멕시코 시티)',
        'America/Miquelon' => '세인트피에르 미클롱 시간',
        'America/Moncton' => '대서양 시간(몽턴)',
        'America/Monterrey' => '미 중부 시간(몬테레이)',
        'America/Montevideo' => '우루과이 시간(몬테비데오)',
        'America/Montreal' => '캐나다 시간(Montreal)',
        'America/Montserrat' => '대서양 시간(몬세라트)',
        'America/Nassau' => '미 동부 시간(나소)',
        'America/New_York' => '미 동부 시간(뉴욕)',
        'America/Nipigon' => '미 동부 시간(니피곤)',
        'America/Nome' => '알래스카 시간(놈)',
        'America/Noronha' => '페르난도 데 노로냐 시간(노롱야)',
        'America/North_Dakota/Beulah' => '미 중부 시간(노스다코타주, 베라)',
        'America/North_Dakota/Center' => '미 중부 시간(중부, 노스다코타)',
        'America/North_Dakota/New_Salem' => '미 중부 시간(노스다코타주, 뉴살렘)',
        'America/Ojinaga' => '미 산지 시간(오히나가)',
        'America/Panama' => '미 동부 시간(파나마)',
        'America/Pangnirtung' => '미 동부 시간(팡니르퉁)',
        'America/Paramaribo' => '수리남 시간(파라마리보)',
        'America/Phoenix' => '미 산지 시간(피닉스)',
        'America/Port-au-Prince' => '미 동부 시간(포르토프랭스)',
        'America/Port_of_Spain' => '대서양 시간(포트오브스페인)',
        'America/Porto_Velho' => '아마존 시간(포르토벨료)',
        'America/Puerto_Rico' => '대서양 시간(푸에르토리코)',
        'America/Punta_Arenas' => '칠레 시간(푼타아레나스)',
        'America/Rainy_River' => '미 중부 시간(레이니강)',
        'America/Rankin_Inlet' => '미 중부 시간(랭킹 인렛)',
        'America/Recife' => '브라질리아 시간(레시페)',
        'America/Regina' => '미 중부 시간(리자이나)',
        'America/Resolute' => '미 중부 시간(리졸루트)',
        'America/Rio_Branco' => '아크레 시간(히우 브랑쿠)',
        'America/Santa_Isabel' => '멕시코 북서부 시간(산타 이사벨)',
        'America/Santarem' => '브라질리아 시간(산타렘)',
        'America/Santiago' => '칠레 시간(산티아고)',
        'America/Santo_Domingo' => '대서양 시간(산토도밍고)',
        'America/Sao_Paulo' => '브라질리아 시간(상파울루)',
        'America/Scoresbysund' => '그린란드 동부 시간(스코레스바이선드)',
        'America/Sitka' => '알래스카 시간(싯카)',
        'America/St_Barthelemy' => '대서양 시간(생바르텔레미)',
        'America/St_Johns' => '뉴펀들랜드 시간(세인트존스)',
        'America/St_Kitts' => '대서양 시간(세인트키츠)',
        'America/St_Lucia' => '대서양 시간(세인트루시아)',
        'America/St_Thomas' => '대서양 시간(세인트토마스)',
        'America/St_Vincent' => '대서양 시간(세인트빈센트)',
        'America/Swift_Current' => '미 중부 시간(스위프트커런트)',
        'America/Tegucigalpa' => '미 중부 시간(테구시갈파)',
        'America/Thule' => '대서양 시간(툴레)',
        'America/Thunder_Bay' => '미 동부 시간(선더베이)',
        'America/Tijuana' => '미 태평양 시간(티후아나)',
        'America/Toronto' => '미 동부 시간(토론토)',
        'America/Tortola' => '대서양 시간(토르톨라)',
        'America/Vancouver' => '미 태평양 시간(벤쿠버)',
        'America/Whitehorse' => '유콘 시간(화이트호스)',
        'America/Winnipeg' => '미 중부 시간(위니펙)',
        'America/Yakutat' => '알래스카 시간(야쿠타트)',
        'America/Yellowknife' => '미 산지 시간(옐로나이프)',
        'Antarctica/Casey' => '케이시 시간',
        'Antarctica/Davis' => '데이비스 시간',
        'Antarctica/DumontDUrville' => '뒤몽뒤르빌 시간(뒤몽 뒤르빌)',
        'Antarctica/Macquarie' => '오스트레일리아 동부 시간(맥쿼리)',
        'Antarctica/Mawson' => '모슨 시간',
        'Antarctica/McMurdo' => '뉴질랜드 시간(맥머도)',
        'Antarctica/Palmer' => '칠레 시간(파머)',
        'Antarctica/Rothera' => '로데라 시간',
        'Antarctica/Syowa' => '쇼와 시간',
        'Antarctica/Troll' => '그리니치 표준시(트롤)',
        'Antarctica/Vostok' => '보스톡 시간(보스토크)',
        'Arctic/Longyearbyen' => '중부유럽 시간(롱이어비엔)',
        'Asia/Aden' => '아라비아 시간(아덴)',
        'Asia/Almaty' => '동부 카자흐스탄 시간(알마티)',
        'Asia/Amman' => '동유럽 시간(암만)',
        'Asia/Anadyr' => '아나디리 시간',
        'Asia/Aqtau' => '서부 카자흐스탄 시간(아크타우)',
        'Asia/Aqtobe' => '서부 카자흐스탄 시간(악토브)',
        'Asia/Ashgabat' => '투르크메니스탄 시간(아슈하바트)',
        'Asia/Atyrau' => '서부 카자흐스탄 시간(아티라우)',
        'Asia/Baghdad' => '아라비아 시간(바그다드)',
        'Asia/Bahrain' => '아라비아 시간(바레인)',
        'Asia/Baku' => '아제르바이잔 시간(바쿠)',
        'Asia/Bangkok' => '인도차이나 시간(방콕)',
        'Asia/Barnaul' => '러시아 시간(바르나울)',
        'Asia/Beirut' => '동유럽 시간(베이루트)',
        'Asia/Bishkek' => '키르기스스탄 시간(비슈케크)',
        'Asia/Brunei' => '브루나이 시간',
        'Asia/Calcutta' => '인도 표준시(콜카타)',
        'Asia/Chita' => '야쿠츠크 시간(치타)',
        'Asia/Choibalsan' => '울란바토르 시간(초이발산)',
        'Asia/Colombo' => '인도 표준시(콜롬보)',
        'Asia/Damascus' => '동유럽 시간(다마스쿠스)',
        'Asia/Dhaka' => '방글라데시 시간(다카)',
        'Asia/Dili' => '동티모르 시간(딜리)',
        'Asia/Dubai' => '걸프만 표준시(두바이)',
        'Asia/Dushanbe' => '타지키스탄 시간(두샨베)',
        'Asia/Famagusta' => '동유럽 시간(파마구스타)',
        'Asia/Gaza' => '동유럽 시간(가자)',
        'Asia/Hebron' => '동유럽 시간(헤브론)',
        'Asia/Hong_Kong' => '홍콩 시간',
        'Asia/Hovd' => '호브드 시간',
        'Asia/Irkutsk' => '이르쿠츠크 시간',
        'Asia/Jakarta' => '서부 인도네시아 시간(자카르타)',
        'Asia/Jayapura' => '동부 인도네시아 시간(자야푸라)',
        'Asia/Jerusalem' => '이스라엘 시간(예루살렘)',
        'Asia/Kabul' => '아프가니스탄 시간(카불)',
        'Asia/Kamchatka' => '페트로파블롭스크-캄차츠키 시간(캄차카)',
        'Asia/Karachi' => '파키스탄 시간(카라치)',
        'Asia/Katmandu' => '네팔 시간(카트만두)',
        'Asia/Khandyga' => '야쿠츠크 시간(한디가)',
        'Asia/Krasnoyarsk' => '크라스노야르스크 시간',
        'Asia/Kuala_Lumpur' => '말레이시아 시간(쿠알라룸푸르)',
        'Asia/Kuching' => '말레이시아 시간(쿠칭)',
        'Asia/Kuwait' => '아라비아 시간(쿠웨이트)',
        'Asia/Macau' => '중국 시간(마카오)',
        'Asia/Magadan' => '마가단 시간',
        'Asia/Makassar' => '중부 인도네시아 시간(마카사르)',
        'Asia/Manila' => '필리핀 시간(마닐라)',
        'Asia/Muscat' => '걸프만 표준시(무스카트)',
        'Asia/Nicosia' => '동유럽 시간(니코시아)',
        'Asia/Novokuznetsk' => '크라스노야르스크 시간(노보쿠즈네츠크)',
        'Asia/Novosibirsk' => '노보시비르스크 시간',
        'Asia/Omsk' => '옴스크 시간',
        'Asia/Oral' => '서부 카자흐스탄 시간(오랄)',
        'Asia/Phnom_Penh' => '인도차이나 시간(프놈펜)',
        'Asia/Pontianak' => '서부 인도네시아 시간(폰티아나크)',
        'Asia/Pyongyang' => '대한민국 시간(평양)',
        'Asia/Qatar' => '아라비아 시간(카타르)',
        'Asia/Qostanay' => '동부 카자흐스탄 시간(코스타나이)',
        'Asia/Qyzylorda' => '서부 카자흐스탄 시간(키질로르다)',
        'Asia/Rangoon' => '미얀마 시간(랑군)',
        'Asia/Riyadh' => '아라비아 시간(리야드)',
        'Asia/Saigon' => '인도차이나 시간(사이공)',
        'Asia/Sakhalin' => '사할린 시간',
        'Asia/Samarkand' => '우즈베키스탄 시간(사마르칸트)',
        'Asia/Seoul' => '대한민국 시간(서울)',
        'Asia/Shanghai' => '중국 시간(상하이)',
        'Asia/Singapore' => '싱가포르 표준시',
        'Asia/Srednekolymsk' => '마가단 시간(스레드네콜림스크)',
        'Asia/Taipei' => '대만 시간(타이베이)',
        'Asia/Tashkent' => '우즈베키스탄 시간(타슈켄트)',
        'Asia/Tbilisi' => '조지아 시간(트빌리시)',
        'Asia/Tehran' => '이란 시간(테헤란)',
        'Asia/Thimphu' => '부탄 시간(팀부)',
        'Asia/Tokyo' => '일본 시간(도쿄)',
        'Asia/Tomsk' => '러시아 시간(톰스크)',
        'Asia/Ulaanbaatar' => '울란바토르 시간',
        'Asia/Urumqi' => '중국 시간(우루무치)',
        'Asia/Ust-Nera' => '블라디보스토크 시간(우스티네라)',
        'Asia/Vientiane' => '인도차이나 시간(비엔티안)',
        'Asia/Vladivostok' => '블라디보스토크 시간',
        'Asia/Yakutsk' => '야쿠츠크 시간',
        'Asia/Yekaterinburg' => '예카테린부르크 시간',
        'Asia/Yerevan' => '아르메니아 시간(예레반)',
        'Atlantic/Azores' => '아조레스 시간',
        'Atlantic/Bermuda' => '대서양 시간(버뮤다)',
        'Atlantic/Canary' => '서유럽 시간(카나리아 제도)',
        'Atlantic/Cape_Verde' => '카보 베르데 시간',
        'Atlantic/Faeroe' => '서유럽 시간(페로 제도)',
        'Atlantic/Madeira' => '서유럽 시간(마데이라)',
        'Atlantic/Reykjavik' => '그리니치 표준시(레이캬비크)',
        'Atlantic/South_Georgia' => '사우스 조지아 시간(사우스조지아)',
        'Atlantic/St_Helena' => '그리니치 표준시(세인트 헬레나)',
        'Atlantic/Stanley' => '포클랜드 제도 시간(스탠리)',
        'Australia/Adelaide' => '오스트레일리아 중부 시간(애들레이드)',
        'Australia/Brisbane' => '오스트레일리아 동부 시간(브리스베인)',
        'Australia/Broken_Hill' => '오스트레일리아 중부 시간(브로컨힐)',
        'Australia/Currie' => '오스트레일리아 동부 시간(퀴리)',
        'Australia/Darwin' => '오스트레일리아 중부 시간(다윈)',
        'Australia/Eucla' => '오스트레일리아 중서부 시간(유클라)',
        'Australia/Hobart' => '오스트레일리아 동부 시간(호바트)',
        'Australia/Lindeman' => '오스트레일리아 동부 시간(린데만)',
        'Australia/Lord_Howe' => '로드 하우 시간',
        'Australia/Melbourne' => '오스트레일리아 동부 시간(멜버른)',
        'Australia/Perth' => '오스트레일리아 서부 시간(퍼스)',
        'Australia/Sydney' => '오스트레일리아 동부 시간(시드니)',
        'CST6CDT' => '미 중부 시간',
        'EST5EDT' => '미 동부 시간',
        'Etc/GMT' => '그리니치 표준시',
        'Etc/UTC' => '협정 세계시',
        'Europe/Amsterdam' => '중부유럽 시간(암스테르담)',
        'Europe/Andorra' => '중부유럽 시간(안도라)',
        'Europe/Astrakhan' => '모스크바 시간(아스트라한)',
        'Europe/Athens' => '동유럽 시간(아테네)',
        'Europe/Belgrade' => '중부유럽 시간(베오그라드)',
        'Europe/Berlin' => '중부유럽 시간(베를린)',
        'Europe/Bratislava' => '중부유럽 시간(브라티슬라바)',
        'Europe/Brussels' => '중부유럽 시간(브뤼셀)',
        'Europe/Bucharest' => '동유럽 시간(부쿠레슈티)',
        'Europe/Budapest' => '중부유럽 시간(부다페스트)',
        'Europe/Busingen' => '중부유럽 시간(뷔지겐)',
        'Europe/Chisinau' => '동유럽 시간(키시나우)',
        'Europe/Copenhagen' => '중부유럽 시간(코펜하겐)',
        'Europe/Dublin' => '그리니치 표준시(더블린)',
        'Europe/Gibraltar' => '중부유럽 시간(지브롤터)',
        'Europe/Guernsey' => '그리니치 표준시(건지)',
        'Europe/Helsinki' => '동유럽 시간(헬싱키)',
        'Europe/Isle_of_Man' => '그리니치 표준시(맨섬)',
        'Europe/Istanbul' => '터키 시간(이스탄불)',
        'Europe/Jersey' => '그리니치 표준시(저지)',
        'Europe/Kaliningrad' => '동유럽 시간(칼리닌그라드)',
        'Europe/Kiev' => '동유럽 시간(키예프)',
        'Europe/Kirov' => '러시아 시간(키로프)',
        'Europe/Lisbon' => '서유럽 시간(리스본)',
        'Europe/Ljubljana' => '중부유럽 시간(류블랴나)',
        'Europe/London' => '그리니치 표준시(런던)',
        'Europe/Luxembourg' => '중부유럽 시간(룩셈부르크)',
        'Europe/Madrid' => '중부유럽 시간(마드리드)',
        'Europe/Malta' => '중부유럽 시간(몰타)',
        'Europe/Mariehamn' => '동유럽 시간(마리에함)',
        'Europe/Minsk' => '모스크바 시간(민스크)',
        'Europe/Monaco' => '중부유럽 시간(모나코)',
        'Europe/Moscow' => '모스크바 시간',
        'Europe/Oslo' => '중부유럽 시간(오슬로)',
        'Europe/Paris' => '중부유럽 시간(파리)',
        'Europe/Podgorica' => '중부유럽 시간(포드고리차)',
        'Europe/Prague' => '중부유럽 시간(프라하)',
        'Europe/Riga' => '동유럽 시간(리가)',
        'Europe/Rome' => '중부유럽 시간(로마)',
        'Europe/Samara' => '사마라 시간',
        'Europe/San_Marino' => '중부유럽 시간(산마리노)',
        'Europe/Sarajevo' => '중부유럽 시간(사라예보)',
        'Europe/Saratov' => '모스크바 시간(사라토프)',
        'Europe/Simferopol' => '모스크바 시간(심페로폴)',
        'Europe/Skopje' => '중부유럽 시간(스코페)',
        'Europe/Sofia' => '동유럽 시간(소피아)',
        'Europe/Stockholm' => '중부유럽 시간(스톡홀름)',
        'Europe/Tallinn' => '동유럽 시간(탈린)',
        'Europe/Tirane' => '중부유럽 시간(티라나)',
        'Europe/Ulyanovsk' => '모스크바 시간(울리야노프스크)',
        'Europe/Uzhgorod' => '동유럽 시간(우주고로트)',
        'Europe/Vaduz' => '중부유럽 시간(파두츠)',
        'Europe/Vatican' => '중부유럽 시간(바티칸)',
        'Europe/Vienna' => '중부유럽 시간(비엔나)',
        'Europe/Vilnius' => '동유럽 시간(빌니우스)',
        'Europe/Volgograd' => '볼고그라드 시간(볼고그라트)',
        'Europe/Warsaw' => '중부유럽 시간(바르샤바)',
        'Europe/Zagreb' => '중부유럽 시간(자그레브)',
        'Europe/Zaporozhye' => '동유럽 시간(자포로지예)',
        'Europe/Zurich' => '중부유럽 시간(취리히)',
        'Indian/Antananarivo' => '동아프리카 시간(안타나나리보)',
        'Indian/Chagos' => '인도양 시간(차고스)',
        'Indian/Christmas' => '크리스마스섬 시간',
        'Indian/Cocos' => '코코스 제도 시간',
        'Indian/Comoro' => '동아프리카 시간(코모로)',
        'Indian/Kerguelen' => '프랑스령 남부 식민지 및 남극 시간(케르켈렌)',
        'Indian/Mahe' => '세이셸 시간(마헤)',
        'Indian/Maldives' => '몰디브 시간',
        'Indian/Mauritius' => '모리셔스 시간',
        'Indian/Mayotte' => '동아프리카 시간(메요트)',
        'Indian/Reunion' => '레위니옹 시간',
        'MST7MDT' => '미 산지 시간',
        'PST8PDT' => '미 태평양 시간',
        'Pacific/Apia' => '아피아 시간',
        'Pacific/Auckland' => '뉴질랜드 시간(오클랜드)',
        'Pacific/Bougainville' => '파푸아뉴기니 시간(부갱빌)',
        'Pacific/Chatham' => '채텀 시간',
        'Pacific/Easter' => '이스터섬 시간(이스터 섬)',
        'Pacific/Efate' => '바누아투 시간(에파테)',
        'Pacific/Enderbury' => '피닉스 제도 시간(엔더베리)',
        'Pacific/Fakaofo' => '토켈라우 시간(파카오푸)',
        'Pacific/Fiji' => '피지 시간',
        'Pacific/Funafuti' => '투발루 시간(푸나푸티)',
        'Pacific/Galapagos' => '갈라파고스 시간',
        'Pacific/Gambier' => '감비에 시간(감비어)',
        'Pacific/Guadalcanal' => '솔로몬 제도 시간(과달카날)',
        'Pacific/Guam' => '차모로 시간(괌)',
        'Pacific/Honolulu' => '하와이 알류샨 시간(호놀룰루)',
        'Pacific/Johnston' => '하와이 알류샨 시간(존스톤)',
        'Pacific/Kiritimati' => '라인 제도 시간(키리티마티)',
        'Pacific/Kosrae' => '코스라에섬 시간(코스레)',
        'Pacific/Kwajalein' => '마셜 제도 시간(콰잘렌)',
        'Pacific/Majuro' => '마셜 제도 시간(마주로)',
        'Pacific/Marquesas' => '마르키즈 제도 시간(마퀘사스)',
        'Pacific/Midway' => '사모아 시간(미드웨이)',
        'Pacific/Nauru' => '나우루 시간',
        'Pacific/Niue' => '니우에 시간',
        'Pacific/Norfolk' => '노퍽섬 시간',
        'Pacific/Noumea' => '뉴칼레도니아 시간(누메아)',
        'Pacific/Pago_Pago' => '사모아 시간(파고파고)',
        'Pacific/Palau' => '팔라우 시간',
        'Pacific/Pitcairn' => '핏케언 시간',
        'Pacific/Ponape' => '포나페 시간',
        'Pacific/Port_Moresby' => '파푸아뉴기니 시간(포트모르즈비)',
        'Pacific/Rarotonga' => '쿡 제도 시간(라로통가)',
        'Pacific/Saipan' => '차모로 시간(사이판)',
        'Pacific/Tahiti' => '타히티 시간',
        'Pacific/Tarawa' => '길버트 제도 시간(타라와)',
        'Pacific/Tongatapu' => '통가 시간(통가타푸)',
        'Pacific/Truk' => '추크 시간(트루크)',
        'Pacific/Wake' => '웨이크섬 시간',
        'Pacific/Wallis' => '월리스푸투나 제도 시간',
    ],
    'Meta' => [
    ],
];
