<?php

return [
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'l-Emirati Għarab Magħquda',
        'AF' => 'l-Afganistan',
        'AG' => 'Antigua u Barbuda',
        'AI' => 'Anguilla',
        'AL' => 'l-Albanija',
        'AM' => 'l-Armenja',
        'AO' => 'l-Angola',
        'AQ' => 'l-Antartika',
        'AR' => 'l-Arġentina',
        'AS' => 'is-Samoa Amerikana',
        'AT' => 'l-Awstrija',
        'AU' => 'l-Awstralja',
        'AW' => 'Aruba',
        'AX' => 'il-Gżejjer Aland',
        'AZ' => 'l-Ażerbajġan',
        'BA' => 'il-Bożnija-Ħerzegovina',
        'BB' => 'Barbados',
        'BD' => 'il-Bangladesh',
        'BE' => 'il-Belġju',
        'BF' => 'il-Burkina Faso',
        'BG' => 'il-Bulgarija',
        'BH' => 'il-Bahrain',
        'BI' => 'il-Burundi',
        'BJ' => 'il-Benin',
        'BL' => 'Saint Barthélemy',
        'BM' => 'Bermuda',
        'BN' => 'il-Brunei',
        'BO' => 'il-Bolivja',
        'BQ' => 'in-Netherlands tal-Karibew',
        'BR' => 'Il-Brażil',
        'BS' => 'il-Bahamas',
        'BT' => 'il-Bhutan',
        'BV' => 'Gżira Bouvet',
        'BW' => 'il-Botswana',
        'BY' => 'il-Belarussja',
        'BZ' => 'il-Belize',
        'CA' => 'il-Kanada',
        'CC' => 'Gżejjer Cocos (Keeling)',
        'CD' => 'ir-Repubblika Demokratika tal-Kongo',
        'CF' => 'ir-Repubblika Ċentru-Afrikana',
        'CG' => 'il-Kongo - Brazzaville',
        'CH' => 'l-Iżvizzera',
        'CI' => 'il-Kosta tal-Avorju',
        'CK' => 'Gżejjer Cook',
        'CL' => 'iċ-Ċili',
        'CM' => 'il-Kamerun',
        'CN' => 'iċ-Ċina',
        'CO' => 'il-Kolombja',
        'CR' => 'il-Costa Rica',
        'CU' => 'Kuba',
        'CV' => 'Cape Verde',
        'CW' => 'Curaçao',
        'CX' => 'il-Gżira Christmas',
        'CY' => 'Ċipru',
        'CZ' => 'ir-Repubblika Ċeka',
        'DE' => 'il-Ġermanja',
        'DJ' => 'il-Djibouti',
        'DK' => 'id-Danimarka',
        'DM' => 'Dominica',
        'DO' => 'ir-Repubblika Dominicana',
        'DZ' => 'l-Alġerija',
        'EC' => 'l-Ekwador',
        'EE' => 'l-Estonja',
        'EG' => 'l-Eġittu',
        'EH' => 'is-Saħara tal-Punent',
        'ER' => 'l-Eritrea',
        'ES' => 'Spanja',
        'ET' => 'l-Etjopja',
        'FI' => 'il-Finlandja',
        'FJ' => 'Fiġi',
        'FK' => 'il-Gżejjer Falkland',
        'FM' => 'il-Mikroneżja',
        'FO' => 'il-Gżejjer Faeroe',
        'FR' => 'Franza',
        'GA' => 'il-Gabon',
        'GB' => 'ir-Renju Unit',
        'GD' => 'Grenada',
        'GE' => 'il-Georgia',
        'GF' => 'il-Guyana Franċiża',
        'GG' => 'Guernsey',
        'GH' => 'il-Ghana',
        'GI' => 'Ġibiltà',
        'GL' => 'Greenland',
        'GM' => 'il-Gambja',
        'GN' => 'il-Guinea',
        'GP' => 'Guadeloupe',
        'GQ' => 'il-Guinea Ekwatorjali',
        'GR' => 'il-Greċja',
        'GS' => 'il-Georgia tan-Nofsinhar u l-Gżejjer Sandwich tan-Nofsinhar',
        'GT' => 'il-Gwatemala',
        'GU' => 'Guam',
        'GW' => 'il-Guinea-Bissau',
        'GY' => 'il-Guyana',
        'HK' => 'ir-Reġjun Amministrattiv Speċjali ta’ Hong Kong tar-Repubblika tal-Poplu taċ-Ċina',
        'HM' => 'il-Gżejjer Heard u l-Gżejjer McDonald',
        'HN' => 'il-Honduras',
        'HR' => 'il-Kroazja',
        'HT' => 'il-Haiti',
        'HU' => 'l-Ungerija',
        'ID' => 'l-Indoneżja',
        'IE' => 'l-Irlanda',
        'IL' => 'Iżrael',
        'IM' => 'Isle of Man',
        'IN' => 'l-Indja',
        'IO' => 'Territorju Brittaniku tal-Oċean Indjan',
        'IQ' => 'l-Iraq',
        'IR' => 'l-Iran',
        'IS' => 'l-Iżlanda',
        'IT' => 'l-Italja',
        'JE' => 'Jersey',
        'JM' => 'il-Ġamajka',
        'JO' => 'il-Ġordan',
        'JP' => 'il-Ġappun',
        'KE' => 'il-Kenja',
        'KG' => 'il-Kirgiżistan',
        'KH' => 'il-Kambodja',
        'KI' => 'Kiribati',
        'KM' => 'Comoros',
        'KN' => 'Saint Kitts u Nevis',
        'KP' => 'il-Korea ta’ Fuq',
        'KR' => 'il-Korea t’Isfel',
        'KW' => 'il-Kuwajt',
        'KY' => 'il-Gżejjer Cayman',
        'KZ' => 'il-Każakistan',
        'LA' => 'il-Laos',
        'LB' => 'il-Libanu',
        'LC' => 'Saint Lucia',
        'LI' => 'il-Liechtenstein',
        'LK' => 'is-Sri Lanka',
        'LR' => 'il-Liberja',
        'LS' => 'il-Lesoto',
        'LT' => 'il-Litwanja',
        'LU' => 'il-Lussemburgu',
        'LV' => 'il-Latvja',
        'LY' => 'il-Libja',
        'MA' => 'il-Marokk',
        'MC' => 'Monaco',
        'MD' => 'il-Moldova',
        'ME' => 'il-Montenegro',
        'MF' => 'Saint Martin',
        'MG' => 'Madagascar',
        'MH' => 'Gżejjer Marshall',
        'MK' => 'il-Maċedonja ta’ Fuq',
        'ML' => 'il-Mali',
        'MM' => 'il-Myanmar/Burma',
        'MN' => 'il-Mongolja',
        'MO' => 'ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina',
        'MP' => 'Ġżejjer Mariana tat-Tramuntana',
        'MQ' => 'Martinique',
        'MR' => 'il-Mauritania',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauritius',
        'MV' => 'il-Maldivi',
        'MW' => 'il-Malawi',
        'MX' => 'il-Messiku',
        'MY' => 'il-Malasja',
        'MZ' => 'il-Mozambique',
        'NA' => 'in-Namibja',
        'NC' => 'New Caledonia',
        'NE' => 'in-Niġer',
        'NF' => 'Gżira Norfolk',
        'NG' => 'in-Niġerja',
        'NI' => 'in-Nikaragwa',
        'NL' => 'in-Netherlands',
        'NO' => 'in-Norveġja',
        'NP' => 'in-Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'New Zealand',
        'OM' => 'l-Oman',
        'PA' => 'il-Panama',
        'PE' => 'il-Perù',
        'PF' => 'Polineżja Franċiża',
        'PG' => 'Papua New Guinea',
        'PH' => 'il-Filippini',
        'PK' => 'il-Pakistan',
        'PL' => 'il-Polonja',
        'PM' => 'Saint Pierre u Miquelon',
        'PN' => 'Gżejjer Pitcairn',
        'PR' => 'Puerto Rico',
        'PS' => 'it-Territorji Palestinjani',
        'PT' => 'il-Portugall',
        'PW' => 'Palau',
        'PY' => 'il-Paragwaj',
        'QA' => 'il-Qatar',
        'RE' => 'Réunion',
        'RO' => 'ir-Rumanija',
        'RS' => 'is-Serbja',
        'RU' => 'ir-Russja',
        'RW' => 'ir-Rwanda',
        'SA' => 'l-Arabja Sawdija',
        'SB' => 'il-Gżejjer Solomon',
        'SC' => 'is-Seychelles',
        'SD' => 'is-Sudan',
        'SE' => 'l-Iżvezja',
        'SG' => 'Singapore',
        'SH' => 'Saint Helena',
        'SI' => 'is-Slovenja',
        'SJ' => 'Svalbard u Jan Mayen',
        'SK' => 'is-Slovakkja',
        'SL' => 'Sierra Leone',
        'SM' => 'San Marino',
        'SN' => 'is-Senegal',
        'SO' => 'is-Somalja',
        'SR' => 'is-Suriname',
        'SS' => 'is-Sudan t’Isfel',
        'ST' => 'São Tomé u Príncipe',
        'SV' => 'El Salvador',
        'SX' => 'Sint Maarten',
        'SY' => 'is-Sirja',
        'SZ' => 'l-Eswatini',
        'TC' => 'il-Gżejjer Turks u Caicos',
        'TD' => 'iċ-Chad',
        'TF' => 'It-Territorji Franċiżi tan-Nofsinhar',
        'TG' => 'it-Togo',
        'TH' => 'it-Tajlandja',
        'TJ' => 'it-Taġikistan',
        'TK' => 'it-Tokelau',
        'TL' => 'Timor Leste',
        'TM' => 'it-Turkmenistan',
        'TN' => 'it-Tuneżija',
        'TO' => 'Tonga',
        'TR' => 'it-Turkija',
        'TT' => 'Trinidad u Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'it-Tajwan',
        'TZ' => 'it-Tanzanija',
        'UA' => 'l-Ukrajna',
        'UG' => 'l-Uganda',
        'UM' => 'Il-Gżejjer Minuri Mbiegħda tal-Istati Uniti',
        'US' => 'l-Istati Uniti',
        'UY' => 'l-Urugwaj',
        'UZ' => 'l-Użbekistan',
        'VA' => 'l-Istat tal-Belt tal-Vatikan',
        'VC' => 'Saint Vincent u l-Grenadini',
        'VE' => 'il-Venezwela',
        'VG' => 'il-Gżejjer Verġni Brittaniċi',
        'VI' => 'il-Gżejjer Verġni tal-Istati Uniti',
        'VN' => 'il-Vjetnam',
        'VU' => 'Vanuatu',
        'WF' => 'Wallis u Futuna',
        'WS' => 'Samoa',
        'YE' => 'il-Jemen',
        'YT' => 'Mayotte',
        'ZA' => 'l-Afrika t’Isfel',
        'ZM' => 'iż-Żambja',
        'ZW' => 'iż-Żimbabwe',
    ],
];
