<?php

return [
    'Names' => [
        'af' => 'Afirkanci',
        'af_NA' => 'Afirkanci (Namibiya)',
        'af_ZA' => 'Afirkanci (Afirka Ta Kudu)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Gana)',
        'am' => 'Amharik',
        'am_ET' => 'Amharik (Habasha)',
        'ar' => 'Larabci',
        'ar_001' => 'Larabci (Duniya)',
        'ar_AE' => 'Larabci (Haɗaɗɗiyar Daular Larabawa)',
        'ar_BH' => 'Larabci (Baharan)',
        'ar_DJ' => 'Larabci (Jibuti)',
        'ar_DZ' => 'Larabci (Aljeriya)',
        'ar_EG' => 'Larabci (Misira)',
        'ar_EH' => 'Larabci (Yammacin Sahara)',
        'ar_ER' => 'Larabci (Eritireya)',
        'ar_IL' => 'Larabci (Israʼila)',
        'ar_IQ' => 'Larabci (Iraƙi)',
        'ar_JO' => 'Larabci (Jordan)',
        'ar_KM' => 'Larabci (Kwamoras)',
        'ar_KW' => 'Larabci (Kwiyat)',
        'ar_LB' => 'Larabci (Labanan)',
        'ar_LY' => 'Larabci (Libiya)',
        'ar_MA' => 'Larabci (Maroko)',
        'ar_MR' => 'Larabci (Moritaniya)',
        'ar_OM' => 'Larabci (Oman)',
        'ar_PS' => 'Larabci (Yankunan Palasɗinu)',
        'ar_QA' => 'Larabci (Katar)',
        'ar_SA' => 'Larabci (Saudiyya)',
        'ar_SD' => 'Larabci (Sudan)',
        'ar_SO' => 'Larabci (Somaliya)',
        'ar_SS' => 'Larabci (Sudan ta Kudu)',
        'ar_SY' => 'Larabci (Sham, Siriya)',
        'ar_TD' => 'Larabci (Cadi)',
        'ar_TN' => 'Larabci (Tunisiya)',
        'ar_YE' => 'Larabci (Yamal)',
        'as' => 'Asamisanci',
        'as_IN' => 'Asamisanci (Indiya)',
        'az' => 'Azerbaijanci',
        'az_AZ' => 'Azerbaijanci (Azarbaijan)',
        'az_Cyrl' => 'Azerbaijanci (Cyrillic)',
        'az_Cyrl_AZ' => 'Azerbaijanci (Cyrillic, Azarbaijan)',
        'az_Latn' => 'Azerbaijanci (Latin)',
        'az_Latn_AZ' => 'Azerbaijanci (Latin, Azarbaijan)',
        'be' => 'Belarusanci',
        'be_BY' => 'Belarusanci (Belarus)',
        'bg' => 'Bulgariyanci',
        'bg_BG' => 'Bulgariyanci (Bulgariya)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (Bangiladas)',
        'bn_IN' => 'Bengali (Indiya)',
        'bo' => 'Tibetan',
        'bo_CN' => 'Tibetan (Sin)',
        'bo_IN' => 'Tibetan (Indiya)',
        'br' => 'Buretananci',
        'br_FR' => 'Buretananci (Faransa)',
        'bs' => 'Bosniyanci',
        'bs_BA' => 'Bosniyanci (Bosniya da Harzagobina)',
        'bs_Cyrl' => 'Bosniyanci (Cyrillic)',
        'bs_Cyrl_BA' => 'Bosniyanci (Cyrillic, Bosniya da Harzagobina)',
        'bs_Latn' => 'Bosniyanci (Latin)',
        'bs_Latn_BA' => 'Bosniyanci (Latin, Bosniya da Harzagobina)',
        'ca' => 'Kataloniyanci',
        'ca_AD' => 'Kataloniyanci (Andora)',
        'ca_ES' => 'Kataloniyanci (Sipen)',
        'ca_FR' => 'Kataloniyanci (Faransa)',
        'ca_IT' => 'Kataloniyanci (Italiya)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (Rasha)',
        'cs' => 'Cek',
        'cs_CZ' => 'Cek (Jamhuriyar Cak)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Rasha)',
        'cy' => 'Welsh',
        'cy_GB' => 'Welsh (Biritaniya)',
        'da' => 'Danish',
        'da_DK' => 'Danish (Danmark)',
        'da_GL' => 'Danish (Grinlan)',
        'de' => 'Jamusanci',
        'de_AT' => 'Jamusanci (Ostiriya)',
        'de_BE' => 'Jamusanci (Belgiyom)',
        'de_CH' => 'Jamusanci (Suwizalan)',
        'de_DE' => 'Jamusanci (Jamus)',
        'de_IT' => 'Jamusanci (Italiya)',
        'de_LI' => 'Jamusanci (Licansitan)',
        'de_LU' => 'Jamusanci (Lukusambur)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Butan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Gana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Girkanci',
        'el_CY' => 'Girkanci (Sifurus)',
        'el_GR' => 'Girkanci (Girka)',
        'en' => 'Turanci',
        'en_001' => 'Turanci (Duniya)',
        'en_150' => 'Turanci (Turai)',
        'en_AE' => 'Turanci (Haɗaɗɗiyar Daular Larabawa)',
        'en_AG' => 'Turanci (Antigua da Barbuda)',
        'en_AI' => 'Turanci (Angila)',
        'en_AS' => 'Turanci (Samowa Ta Amurka)',
        'en_AT' => 'Turanci (Ostiriya)',
        'en_AU' => 'Turanci (Ostareliya)',
        'en_BB' => 'Turanci (Barbadas)',
        'en_BE' => 'Turanci (Belgiyom)',
        'en_BI' => 'Turanci (Burundi)',
        'en_BM' => 'Turanci (Barmuda)',
        'en_BS' => 'Turanci (Bahamas)',
        'en_BW' => 'Turanci (Baswana)',
        'en_BZ' => 'Turanci (Beliz)',
        'en_CA' => 'Turanci (Kanada)',
        'en_CC' => 'Turanci (Tsibirai Cocos [Keeling])',
        'en_CH' => 'Turanci (Suwizalan)',
        'en_CK' => 'Turanci (Tsibiran Kuku)',
        'en_CM' => 'Turanci (Kamaru)',
        'en_CX' => 'Turanci (Tsibirin Kirsmati)',
        'en_CY' => 'Turanci (Sifurus)',
        'en_DE' => 'Turanci (Jamus)',
        'en_DK' => 'Turanci (Danmark)',
        'en_DM' => 'Turanci (Dominika)',
        'en_ER' => 'Turanci (Eritireya)',
        'en_FI' => 'Turanci (Finlan)',
        'en_FJ' => 'Turanci (Fiji)',
        'en_FK' => 'Turanci (Tsibiran Falkilan)',
        'en_FM' => 'Turanci (Mikuronesiya)',
        'en_GB' => 'Turanci (Biritaniya)',
        'en_GD' => 'Turanci (Girnada)',
        'en_GG' => 'Turanci (Yankin Guernsey)',
        'en_GH' => 'Turanci (Gana)',
        'en_GI' => 'Turanci (Jibaraltar)',
        'en_GM' => 'Turanci (Gambiya)',
        'en_GU' => 'Turanci (Gwam)',
        'en_GY' => 'Turanci (Guyana)',
        'en_HK' => 'Turanci (Babban Yankin Mulkin Hong Kong na Ƙasar Sin)',
        'en_IE' => 'Turanci (Ayalan)',
        'en_IL' => 'Turanci (Israʼila)',
        'en_IM' => 'Turanci (Isle na Mutum)',
        'en_IN' => 'Turanci (Indiya)',
        'en_IO' => 'Turanci (Yankin Birtaniya Na Tekun Indiya)',
        'en_JE' => 'Turanci (Kasar Jersey)',
        'en_JM' => 'Turanci (Jamaika)',
        'en_KE' => 'Turanci (Kenya)',
        'en_KI' => 'Turanci (Kiribati)',
        'en_KN' => 'Turanci (San Kiti Da Nebis)',
        'en_KY' => 'Turanci (Tsibiran Kaiman)',
        'en_LC' => 'Turanci (San Lusiya)',
        'en_LR' => 'Turanci (Laberiya)',
        'en_LS' => 'Turanci (Lesoto)',
        'en_MG' => 'Turanci (Madagaskar)',
        'en_MH' => 'Turanci (Tsibiran Marshal)',
        'en_MO' => 'Turanci (Babban Yankin Mulkin Macao na Ƙasar Sin)',
        'en_MP' => 'Turanci (Tsibiran Mariyana Na Arewa)',
        'en_MS' => 'Turanci (Manserati)',
        'en_MT' => 'Turanci (Malta)',
        'en_MU' => 'Turanci (Moritus)',
        'en_MV' => 'Turanci (Maldibi)',
        'en_MW' => 'Turanci (Malawi)',
        'en_MY' => 'Turanci (Malaisiya)',
        'en_NA' => 'Turanci (Namibiya)',
        'en_NF' => 'Turanci (Tsibirin Narfalk)',
        'en_NG' => 'Turanci (Nijeriya)',
        'en_NL' => 'Turanci (Holan)',
        'en_NR' => 'Turanci (Nauru)',
        'en_NU' => 'Turanci (Niyu)',
        'en_NZ' => 'Turanci (Nuzilan)',
        'en_PG' => 'Turanci (Papuwa Nugini)',
        'en_PH' => 'Turanci (Filipin)',
        'en_PK' => 'Turanci (Pakistan)',
        'en_PN' => 'Turanci (Pitakarin)',
        'en_PR' => 'Turanci (Porto Riko)',
        'en_PW' => 'Turanci (Palau)',
        'en_RW' => 'Turanci (Ruwanda)',
        'en_SB' => 'Turanci (Tsibiran Salaman)',
        'en_SC' => 'Turanci (Seychelles)',
        'en_SD' => 'Turanci (Sudan)',
        'en_SE' => 'Turanci (Suwedan)',
        'en_SG' => 'Turanci (Singapur)',
        'en_SH' => 'Turanci (San Helena)',
        'en_SI' => 'Turanci (Sulobeniya)',
        'en_SL' => 'Turanci (Salewo)',
        'en_SS' => 'Turanci (Sudan ta Kudu)',
        'en_SX' => 'Turanci (San Maarten)',
        'en_SZ' => 'Turanci (Eswatini)',
        'en_TC' => 'Turanci (Turkis Da Tsibiran Kaikwas)',
        'en_TK' => 'Turanci (Takelau)',
        'en_TO' => 'Turanci (Tonga)',
        'en_TT' => 'Turanci (Tirinidad Da Tobago)',
        'en_TV' => 'Turanci (Tubalu)',
        'en_TZ' => 'Turanci (Tanzaniya)',
        'en_UG' => 'Turanci (Yuganda)',
        'en_UM' => 'Turanci (Rukunin Tsibirin U.S)',
        'en_US' => 'Turanci (Amurka)',
        'en_VC' => 'Turanci (San Binsan Da Girnadin)',
        'en_VG' => 'Turanci (Tsibirin Birjin Na Birtaniya)',
        'en_VI' => 'Turanci (Tsibiran Birjin Ta Amurka)',
        'en_VU' => 'Turanci (Banuwatu)',
        'en_WS' => 'Turanci (Samoa)',
        'en_ZA' => 'Turanci (Afirka Ta Kudu)',
        'en_ZM' => 'Turanci (Zambiya)',
        'en_ZW' => 'Turanci (Zimbabuwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Duniya)',
        'es' => 'Sifaniyanci',
        'es_419' => 'Sifaniyanci (Latin Amurka)',
        'es_AR' => 'Sifaniyanci (Arjantiniya)',
        'es_BO' => 'Sifaniyanci (Bolibiya)',
        'es_BR' => 'Sifaniyanci (Birazil)',
        'es_BZ' => 'Sifaniyanci (Beliz)',
        'es_CL' => 'Sifaniyanci (Cayile)',
        'es_CO' => 'Sifaniyanci (Kolambiya)',
        'es_CR' => 'Sifaniyanci (Kwasta Rika)',
        'es_CU' => 'Sifaniyanci (Kyuba)',
        'es_DO' => 'Sifaniyanci (Jamhuriyar Dominika)',
        'es_EC' => 'Sifaniyanci (Ekwador)',
        'es_ES' => 'Sifaniyanci (Sipen)',
        'es_GQ' => 'Sifaniyanci (Gini Ta Ikwaita)',
        'es_GT' => 'Sifaniyanci (Gwatamala)',
        'es_HN' => 'Sifaniyanci (Yankin Honduras)',
        'es_MX' => 'Sifaniyanci (Mesiko)',
        'es_NI' => 'Sifaniyanci (Nikaraguwa)',
        'es_PA' => 'Sifaniyanci (Panama)',
        'es_PE' => 'Sifaniyanci (Feru)',
        'es_PH' => 'Sifaniyanci (Filipin)',
        'es_PR' => 'Sifaniyanci (Porto Riko)',
        'es_PY' => 'Sifaniyanci (Faragwai)',
        'es_SV' => 'Sifaniyanci (El Salbador)',
        'es_US' => 'Sifaniyanci (Amurka)',
        'es_UY' => 'Sifaniyanci (Yurigwai)',
        'es_VE' => 'Sifaniyanci (Benezuwela)',
        'et' => 'Istoniyanci',
        'et_EE' => 'Istoniyanci (Estoniya)',
        'eu' => 'Basque',
        'eu_ES' => 'Basque (Sipen)',
        'fa' => 'Farisa',
        'fa_AF' => 'Farisa (Afaganistan)',
        'fa_IR' => 'Farisa (Iran)',
        'ff' => 'Fulah',
        'ff_Adlm' => 'Fulah (Adlam)',
        'ff_Adlm_BF' => 'Fulah (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fulah (Adlam, Kamaru)',
        'ff_Adlm_GH' => 'Fulah (Adlam, Gana)',
        'ff_Adlm_GM' => 'Fulah (Adlam, Gambiya)',
        'ff_Adlm_GN' => 'Fulah (Adlam, Gini)',
        'ff_Adlm_GW' => 'Fulah (Adlam, Gini Bisau)',
        'ff_Adlm_LR' => 'Fulah (Adlam, Laberiya)',
        'ff_Adlm_MR' => 'Fulah (Adlam, Moritaniya)',
        'ff_Adlm_NE' => 'Fulah (Adlam, Nijar)',
        'ff_Adlm_NG' => 'Fulah (Adlam, Nijeriya)',
        'ff_Adlm_SL' => 'Fulah (Adlam, Salewo)',
        'ff_Adlm_SN' => 'Fulah (Adlam, Sanigal)',
        'ff_CM' => 'Fulah (Kamaru)',
        'ff_GN' => 'Fulah (Gini)',
        'ff_Latn' => 'Fulah (Latin)',
        'ff_Latn_BF' => 'Fulah (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fulah (Latin, Kamaru)',
        'ff_Latn_GH' => 'Fulah (Latin, Gana)',
        'ff_Latn_GM' => 'Fulah (Latin, Gambiya)',
        'ff_Latn_GN' => 'Fulah (Latin, Gini)',
        'ff_Latn_GW' => 'Fulah (Latin, Gini Bisau)',
        'ff_Latn_LR' => 'Fulah (Latin, Laberiya)',
        'ff_Latn_MR' => 'Fulah (Latin, Moritaniya)',
        'ff_Latn_NE' => 'Fulah (Latin, Nijar)',
        'ff_Latn_NG' => 'Fulah (Latin, Nijeriya)',
        'ff_Latn_SL' => 'Fulah (Latin, Salewo)',
        'ff_Latn_SN' => 'Fulah (Latin, Sanigal)',
        'ff_MR' => 'Fulah (Moritaniya)',
        'ff_SN' => 'Fulah (Sanigal)',
        'fi' => 'Yaren mutanen Finland',
        'fi_FI' => 'Yaren mutanen Finland (Finlan)',
        'fo' => 'Faroese',
        'fo_DK' => 'Faroese (Danmark)',
        'fo_FO' => 'Faroese (Tsibirai na Faroe)',
        'fr' => 'Faransanci',
        'fr_BE' => 'Faransanci (Belgiyom)',
        'fr_BF' => 'Faransanci (Burkina Faso)',
        'fr_BI' => 'Faransanci (Burundi)',
        'fr_BJ' => 'Faransanci (Binin)',
        'fr_BL' => 'Faransanci (San Barthélemy)',
        'fr_CA' => 'Faransanci (Kanada)',
        'fr_CD' => 'Faransanci (Jamhuriyar Dimokuraɗiyyar Kongo)',
        'fr_CF' => 'Faransanci (Jamhuriyar Afirka Ta Tsakiya)',
        'fr_CG' => 'Faransanci (Kongo)',
        'fr_CH' => 'Faransanci (Suwizalan)',
        'fr_CI' => 'Faransanci (Aibari Kwas)',
        'fr_CM' => 'Faransanci (Kamaru)',
        'fr_DJ' => 'Faransanci (Jibuti)',
        'fr_DZ' => 'Faransanci (Aljeriya)',
        'fr_FR' => 'Faransanci (Faransa)',
        'fr_GA' => 'Faransanci (Gabon)',
        'fr_GF' => 'Faransanci (Gini Ta Faransa)',
        'fr_GN' => 'Faransanci (Gini)',
        'fr_GP' => 'Faransanci (Gwadaluf)',
        'fr_GQ' => 'Faransanci (Gini Ta Ikwaita)',
        'fr_HT' => 'Faransanci (Haiti)',
        'fr_KM' => 'Faransanci (Kwamoras)',
        'fr_LU' => 'Faransanci (Lukusambur)',
        'fr_MA' => 'Faransanci (Maroko)',
        'fr_MC' => 'Faransanci (Monako)',
        'fr_MF' => 'Faransanci (San Martin)',
        'fr_MG' => 'Faransanci (Madagaskar)',
        'fr_ML' => 'Faransanci (Mali)',
        'fr_MQ' => 'Faransanci (Martinik)',
        'fr_MR' => 'Faransanci (Moritaniya)',
        'fr_MU' => 'Faransanci (Moritus)',
        'fr_NC' => 'Faransanci (Kaledoniya Sabuwa)',
        'fr_NE' => 'Faransanci (Nijar)',
        'fr_PF' => 'Faransanci (Folinesiya Ta Faransa)',
        'fr_PM' => 'Faransanci (San Piyar da Mikelan)',
        'fr_RE' => 'Faransanci (Rawuniyan)',
        'fr_RW' => 'Faransanci (Ruwanda)',
        'fr_SC' => 'Faransanci (Seychelles)',
        'fr_SN' => 'Faransanci (Sanigal)',
        'fr_SY' => 'Faransanci (Sham, Siriya)',
        'fr_TD' => 'Faransanci (Cadi)',
        'fr_TG' => 'Faransanci (Togo)',
        'fr_TN' => 'Faransanci (Tunisiya)',
        'fr_VU' => 'Faransanci (Banuwatu)',
        'fr_WF' => 'Faransanci (Walis Da Futuna)',
        'fr_YT' => 'Faransanci (Mayoti)',
        'fy' => 'Frisian ta Yamma',
        'fy_NL' => 'Frisian ta Yamma (Holan)',
        'ga' => 'Dan Irish',
        'ga_GB' => 'Dan Irish (Biritaniya)',
        'ga_IE' => 'Dan Irish (Ayalan)',
        'gd' => 'Kʼabilan Scots Gaelic',
        'gd_GB' => 'Kʼabilan Scots Gaelic (Biritaniya)',
        'gl' => 'Bagalike',
        'gl_ES' => 'Bagalike (Sipen)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (Indiya)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Isle na Mutum)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Gana)',
        'ha_NE' => 'Hausa (Nijar)',
        'ha_NG' => 'Hausa (Nijeriya)',
        'he' => 'Ibrananci',
        'he_IL' => 'Ibrananci (Israʼila)',
        'hi' => 'Harshen Hindi',
        'hi_IN' => 'Harshen Hindi (Indiya)',
        'hi_Latn' => 'Harshen Hindi (Latin)',
        'hi_Latn_IN' => 'Harshen Hindi (Latin, Indiya)',
        'hr' => 'Kuroshiyan',
        'hr_BA' => 'Kuroshiyan (Bosniya da Harzagobina)',
        'hr_HR' => 'Kuroshiyan (Kurowaishiya)',
        'hu' => 'Harshen Hungari',
        'hu_HU' => 'Harshen Hungari (Hungari)',
        'hy' => 'Armeniyanci',
        'hy_AM' => 'Armeniyanci (Armeniya)',
        'ia' => 'Yare Tsakanin Kasashe',
        'ia_001' => 'Yare Tsakanin Kasashe (Duniya)',
        'id' => 'Harshen Indunusiya',
        'id_ID' => 'Harshen Indunusiya (Indunusiya)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nijeriya)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (Sin)',
        'is' => 'Yaren mutanen Iceland',
        'is_IS' => 'Yaren mutanen Iceland (Aisalan)',
        'it' => 'Italiyanci',
        'it_CH' => 'Italiyanci (Suwizalan)',
        'it_IT' => 'Italiyanci (Italiya)',
        'it_SM' => 'Italiyanci (San Marino)',
        'it_VA' => 'Italiyanci (Batikan)',
        'ja' => 'Japananci',
        'ja_JP' => 'Japananci (Japan)',
        'jv' => 'Jafananci',
        'jv_ID' => 'Jafananci (Indunusiya)',
        'ka' => 'Jojiyanci',
        'ka_GE' => 'Jojiyanci (Jiwarjiya)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenya)',
        'kk' => 'Kazakh',
        'kk_KZ' => 'Kazakh (Kazakistan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Grinlan)',
        'km' => 'Harshen Kimar',
        'km_KH' => 'Harshen Kimar (Kambodiya)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (Indiya)',
        'ko' => 'Harshen Koreya',
        'ko_KP' => 'Harshen Koreya (Koriya Ta Arewa)',
        'ko_KR' => 'Harshen Koreya (Koriya Ta Kudu)',
        'ks' => 'Kashmiri',
        'ks_Arab' => 'Kashmiri (Larabci)',
        'ks_Arab_IN' => 'Kashmiri (Larabci, Indiya)',
        'ks_Deva' => 'Kashmiri (Devanagari)',
        'ks_Deva_IN' => 'Kashmiri (Devanagari, Indiya)',
        'ks_IN' => 'Kashmiri (Indiya)',
        'ku' => 'Kurdanci',
        'ku_TR' => 'Kurdanci (Turkiyya)',
        'kw' => 'Cornish',
        'kw_GB' => 'Cornish (Biritaniya)',
        'ky' => 'Kirgizanci',
        'ky_KG' => 'Kirgizanci (Kirgizistan)',
        'lb' => 'Luxembourgish',
        'lb_LU' => 'Luxembourgish (Lukusambur)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Yuganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Jamhuriyar Dimokuraɗiyyar Kongo)',
        'ln_CF' => 'Lingala (Jamhuriyar Afirka Ta Tsakiya)',
        'ln_CG' => 'Lingala (Kongo)',
        'lo' => 'Lao',
        'lo_LA' => 'Lao (Lawas)',
        'lt' => 'Lituweniyanci',
        'lt_LT' => 'Lituweniyanci (Lituweniya)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Jamhuriyar Dimokuraɗiyyar Kongo)',
        'lv' => 'Latbiyanci',
        'lv_LV' => 'Latbiyanci (Litibiya)',
        'mg' => 'Malagasi',
        'mg_MG' => 'Malagasi (Madagaskar)',
        'mi' => 'Maori',
        'mi_NZ' => 'Maori (Nuzilan)',
        'mk' => 'Dan Masedoniya',
        'mk_MK' => 'Dan Masedoniya (Macedonia ta Arewa)',
        'ml' => 'Malayalamci',
        'ml_IN' => 'Malayalamci (Indiya)',
        'mn' => 'Mongoliyanci',
        'mn_MN' => 'Mongoliyanci (Mangoliya)',
        'mr' => 'Maratinci',
        'mr_IN' => 'Maratinci (Indiya)',
        'ms' => 'Harshen Malai',
        'ms_BN' => 'Harshen Malai (Burune)',
        'ms_ID' => 'Harshen Malai (Indunusiya)',
        'ms_MY' => 'Harshen Malai (Malaisiya)',
        'ms_SG' => 'Harshen Malai (Singapur)',
        'mt' => 'Harshen Maltis',
        'mt_MT' => 'Harshen Maltis (Malta)',
        'my' => 'Burmanci',
        'my_MM' => 'Burmanci (Burma, Miyamar)',
        'nb' => 'Norwegian Bokmål',
        'nb_NO' => 'Norwegian Bokmål (Norwe)',
        'nb_SJ' => 'Norwegian Bokmål (Svalbard da Jan Mayen)',
        'nd' => 'North Ndebele',
        'nd_ZW' => 'North Ndebele (Zimbabuwe)',
        'ne' => 'Nepali',
        'ne_IN' => 'Nepali (Indiya)',
        'ne_NP' => 'Nepali (Nefal)',
        'nl' => 'Holanci',
        'nl_AW' => 'Holanci (Aruba)',
        'nl_BE' => 'Holanci (Belgiyom)',
        'nl_BQ' => 'Holanci (Caribbean Netherlands)',
        'nl_CW' => 'Holanci (Ƙasar Curaçao)',
        'nl_NL' => 'Holanci (Holan)',
        'nl_SR' => 'Holanci (Suriname)',
        'nl_SX' => 'Holanci (San Maarten)',
        'nn' => 'Norwegian Nynorsk',
        'nn_NO' => 'Norwegian Nynorsk (Norwe)',
        'no' => 'Harhsen Norway',
        'no_NO' => 'Harhsen Norway (Norwe)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Habasha)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Odiya',
        'or_IN' => 'Odiya (Indiya)',
        'os' => 'Ossetic',
        'os_GE' => 'Ossetic (Jiwarjiya)',
        'os_RU' => 'Ossetic (Rasha)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Larabci)',
        'pa_Arab_PK' => 'Punjabi (Larabci, Pakistan)',
        'pa_Guru' => 'Punjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Punjabi (Gurmukhi, Indiya)',
        'pa_IN' => 'Punjabi (Indiya)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Harshen Polan',
        'pl_PL' => 'Harshen Polan (Polan)',
        'ps' => 'Pashtanci',
        'ps_AF' => 'Pashtanci (Afaganistan)',
        'ps_PK' => 'Pashtanci (Pakistan)',
        'pt' => 'Harshen Potugis',
        'pt_AO' => 'Harshen Potugis (Angola)',
        'pt_BR' => 'Harshen Potugis (Birazil)',
        'pt_CH' => 'Harshen Potugis (Suwizalan)',
        'pt_CV' => 'Harshen Potugis (Tsibiran Kap Barde)',
        'pt_GQ' => 'Harshen Potugis (Gini Ta Ikwaita)',
        'pt_GW' => 'Harshen Potugis (Gini Bisau)',
        'pt_LU' => 'Harshen Potugis (Lukusambur)',
        'pt_MO' => 'Harshen Potugis (Babban Yankin Mulkin Macao na Ƙasar Sin)',
        'pt_MZ' => 'Harshen Potugis (Mozambik)',
        'pt_PT' => 'Harshen Potugis (Portugal)',
        'pt_ST' => 'Harshen Potugis (Sawo Tome Da Paransip)',
        'pt_TL' => 'Harshen Potugis (Timor Ta Gabas)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolibiya)',
        'qu_EC' => 'Quechua (Ekwador)',
        'qu_PE' => 'Quechua (Feru)',
        'rm' => 'Romansh',
        'rm_CH' => 'Romansh (Suwizalan)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Romaniyanci',
        'ro_MD' => 'Romaniyanci (Maldoba)',
        'ro_RO' => 'Romaniyanci (Romaniya)',
        'ru' => 'Rashanci',
        'ru_BY' => 'Rashanci (Belarus)',
        'ru_KG' => 'Rashanci (Kirgizistan)',
        'ru_KZ' => 'Rashanci (Kazakistan)',
        'ru_MD' => 'Rashanci (Maldoba)',
        'ru_RU' => 'Rashanci (Rasha)',
        'ru_UA' => 'Rashanci (Yukaran)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Ruwanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (Indiya)',
        'sc' => 'Sardiniyanci',
        'sc_IT' => 'Sardiniyanci (Italiya)',
        'sd' => 'Sindiyanci',
        'sd_Arab' => 'Sindiyanci (Larabci)',
        'sd_Arab_PK' => 'Sindiyanci (Larabci, Pakistan)',
        'sd_Deva' => 'Sindiyanci (Devanagari)',
        'sd_Deva_IN' => 'Sindiyanci (Devanagari, Indiya)',
        'sd_IN' => 'Sindiyanci (Indiya)',
        'sd_PK' => 'Sindiyanci (Pakistan)',
        'se' => 'Sami ta Arewa',
        'se_FI' => 'Sami ta Arewa (Finlan)',
        'se_NO' => 'Sami ta Arewa (Norwe)',
        'se_SE' => 'Sami ta Arewa (Suwedan)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Jamhuriyar Afirka Ta Tsakiya)',
        'sh' => 'Kuroweshiyancin-Sabiya',
        'sh_BA' => 'Kuroweshiyancin-Sabiya (Bosniya da Harzagobina)',
        'si' => 'Sinhalanci',
        'si_LK' => 'Sinhalanci (Siri Lanka)',
        'sk' => 'Basulke',
        'sk_SK' => 'Basulke (Sulobakiya)',
        'sl' => 'Basulabe',
        'sl_SI' => 'Basulabe (Sulobeniya)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabuwe)',
        'so' => 'Somalianci',
        'so_DJ' => 'Somalianci (Jibuti)',
        'so_ET' => 'Somalianci (Habasha)',
        'so_KE' => 'Somalianci (Kenya)',
        'so_SO' => 'Somalianci (Somaliya)',
        'sq' => 'Albaniyanci',
        'sq_AL' => 'Albaniyanci (Albaniya)',
        'sq_MK' => 'Albaniyanci (Macedonia ta Arewa)',
        'sr' => 'Sabiyan',
        'sr_BA' => 'Sabiyan (Bosniya da Harzagobina)',
        'sr_Cyrl' => 'Sabiyan (Cyrillic)',
        'sr_Cyrl_BA' => 'Sabiyan (Cyrillic, Bosniya da Harzagobina)',
        'sr_Cyrl_ME' => 'Sabiyan (Cyrillic, Mantanegara)',
        'sr_Cyrl_RS' => 'Sabiyan (Cyrillic, Sabiya)',
        'sr_Latn' => 'Sabiyan (Latin)',
        'sr_Latn_BA' => 'Sabiyan (Latin, Bosniya da Harzagobina)',
        'sr_Latn_ME' => 'Sabiyan (Latin, Mantanegara)',
        'sr_Latn_RS' => 'Sabiyan (Latin, Sabiya)',
        'sr_ME' => 'Sabiyan (Mantanegara)',
        'sr_RS' => 'Sabiyan (Sabiya)',
        'su' => 'Harshen Sundanese',
        'su_ID' => 'Harshen Sundanese (Indunusiya)',
        'su_Latn' => 'Harshen Sundanese (Latin)',
        'su_Latn_ID' => 'Harshen Sundanese (Latin, Indunusiya)',
        'sv' => 'Harshen Suwedan',
        'sv_AX' => 'Harshen Suwedan (Tsibirai na Åland)',
        'sv_FI' => 'Harshen Suwedan (Finlan)',
        'sv_SE' => 'Harshen Suwedan (Suwedan)',
        'sw' => 'Harshen Suwahili',
        'sw_CD' => 'Harshen Suwahili (Jamhuriyar Dimokuraɗiyyar Kongo)',
        'sw_KE' => 'Harshen Suwahili (Kenya)',
        'sw_TZ' => 'Harshen Suwahili (Tanzaniya)',
        'sw_UG' => 'Harshen Suwahili (Yuganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (Indiya)',
        'ta_LK' => 'Tamil (Siri Lanka)',
        'ta_MY' => 'Tamil (Malaisiya)',
        'ta_SG' => 'Tamil (Singapur)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (Indiya)',
        'tg' => 'Tajik',
        'tg_TJ' => 'Tajik (Tajikistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Tailan)',
        'ti' => 'Tigrinyanci',
        'ti_ER' => 'Tigrinyanci (Eritireya)',
        'ti_ET' => 'Tigrinyanci (Habasha)',
        'tk' => 'Tukmenistanci',
        'tk_TM' => 'Tukmenistanci (Turkumenistan)',
        'to' => 'Tonganci',
        'to_TO' => 'Tonganci (Tonga)',
        'tr' => 'Harshen Turkiyya',
        'tr_CY' => 'Harshen Turkiyya (Sifurus)',
        'tr_TR' => 'Harshen Turkiyya (Turkiyya)',
        'tt' => 'Tatar',
        'tt_RU' => 'Tatar (Rasha)',
        'ug' => 'Ugiranci',
        'ug_CN' => 'Ugiranci (Sin)',
        'uk' => 'Harshen Yukuren',
        'uk_UA' => 'Harshen Yukuren (Yukaran)',
        'ur' => 'Urdanci',
        'ur_IN' => 'Urdanci (Indiya)',
        'ur_PK' => 'Urdanci (Pakistan)',
        'uz' => 'Uzbek',
        'uz_AF' => 'Uzbek (Afaganistan)',
        'uz_Arab' => 'Uzbek (Larabci)',
        'uz_Arab_AF' => 'Uzbek (Larabci, Afaganistan)',
        'uz_Cyrl' => 'Uzbek (Cyrillic)',
        'uz_Cyrl_UZ' => 'Uzbek (Cyrillic, Uzubekistan)',
        'uz_Latn' => 'Uzbek (Latin)',
        'uz_Latn_UZ' => 'Uzbek (Latin, Uzubekistan)',
        'uz_UZ' => 'Uzbek (Uzubekistan)',
        'vi' => 'Harshen Biyetinam',
        'vi_VN' => 'Harshen Biyetinam (Biyetinam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Sanigal)',
        'xh' => 'Bazosa',
        'xh_ZA' => 'Bazosa (Afirka Ta Kudu)',
        'yi' => 'Yaren Yiddish',
        'yi_001' => 'Yaren Yiddish (Duniya)',
        'yo' => 'Yarbanci',
        'yo_BJ' => 'Yarbanci (Binin)',
        'yo_NG' => 'Yarbanci (Nijeriya)',
        'zh' => 'Harshen Sinanci',
        'zh_CN' => 'Harshen Sinanci (Sin)',
        'zh_HK' => 'Harshen Sinanci (Babban Yankin Mulkin Hong Kong na Ƙasar Sin)',
        'zh_Hans' => 'Harshen Sinanci (Sauƙaƙaƙƙen)',
        'zh_Hans_CN' => 'Harshen Sinanci (Sauƙaƙaƙƙen, Sin)',
        'zh_Hans_HK' => 'Harshen Sinanci (Sauƙaƙaƙƙen, Babban Yankin Mulkin Hong Kong na Ƙasar Sin)',
        'zh_Hans_MO' => 'Harshen Sinanci (Sauƙaƙaƙƙen, Babban Yankin Mulkin Macao na Ƙasar Sin)',
        'zh_Hans_SG' => 'Harshen Sinanci (Sauƙaƙaƙƙen, Singapur)',
        'zh_Hant' => 'Harshen Sinanci (Na gargajiya)',
        'zh_Hant_HK' => 'Harshen Sinanci (Na gargajiya, Babban Yankin Mulkin Hong Kong na Ƙasar Sin)',
        'zh_Hant_MO' => 'Harshen Sinanci (Na gargajiya, Babban Yankin Mulkin Macao na Ƙasar Sin)',
        'zh_Hant_TW' => 'Harshen Sinanci (Na gargajiya, Taiwan)',
        'zh_MO' => 'Harshen Sinanci (Babban Yankin Mulkin Macao na Ƙasar Sin)',
        'zh_SG' => 'Harshen Sinanci (Singapur)',
        'zh_TW' => 'Harshen Sinanci (Taiwan)',
        'zu' => 'Harshen Zulu',
        'zu_ZA' => 'Harshen Zulu (Afirka Ta Kudu)',
    ],
];
