<?php

return [
    'Names' => [
        'ar' => 'арап',
        'bn' => 'бенгал',
        'cv' => 'чӑваш',
        'de' => 'нимӗҫ',
        'en' => 'акӑлчан',
        'es' => 'испани',
        'fr' => 'франци',
        'hi' => 'хинди',
        'id' => 'индонези',
        'it' => 'итали',
        'ja' => 'япони',
        'ko' => 'корей',
        'nl' => 'голланди',
        'pl' => 'поляк',
        'pt' => 'португали',
        'ru' => 'вырӑс',
        'th' => 'тай',
        'tr' => 'турккӑ',
        'zh' => 'китай',
    ],
    'LocalizedNames' => [
        'ar_001' => 'арап литератури',
        'de_AT' => 'австрин нимӗҫ',
        'de_CH' => 'швейцарин нимӗҫ',
        'en_AU' => 'австралин акӑлчан',
        'en_CA' => 'канадӑн акӑлчан',
        'en_GB' => 'британин акӑлчан',
        'en_US' => 'америкӑн акӑлчан',
        'es_419' => 'латинла америкӑн испани',
        'es_ES' => 'европӑн испани',
        'es_MX' => 'мексикӑн испани',
        'fr_CA' => 'канадӑн франци',
        'fr_CH' => 'швейцарӗн франци',
        'nl_BE' => 'фламанди',
        'pt_BR' => 'бразилин португали',
        'pt_PT' => 'европӑн португали',
        'zh_Hans' => 'китай, ҫӑмӑллатнӑ ҫыру',
        'zh_Hant' => 'китай, традициллӗ ҫыру',
    ],
];
