<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abchaziska',
        'ace' => 'acehnesiska',
        'ach' => 'acholi',
        'ada' => 'adangme',
        'ady' => 'adygeiska',
        'ae' => 'avestiska',
        'aeb' => 'tunisisk arabiska',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'akkadiska',
        'akz' => 'Alabama-muskogee',
        'ale' => 'aleutiska',
        'aln' => 'gegiska',
        'alt' => 'sydaltaiska',
        'am' => 'amhariska',
        'an' => 'aragonesiska',
        'ang' => 'fornengelska',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabiska',
        'arc' => 'arameiska',
        'arn' => 'mapudungun',
        'aro' => 'araoniska',
        'arp' => 'arapaho',
        'arq' => 'algerisk arabiska',
        'ars' => 'najdiarabiska',
        'arw' => 'arawakiska',
        'ary' => 'marockansk arabiska',
        'arz' => 'egyptisk arabiska',
        'as' => 'assamesiska',
        'asa' => 'asu',
        'ase' => 'amerikanskt teckenspråk',
        'ast' => 'asturiska',
        'atj' => 'atikamekw',
        'av' => 'avariska',
        'avk' => 'kotava',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'azerbajdzjanska',
        'ba' => 'basjkiriska',
        'bal' => 'baluchiska',
        'ban' => 'balinesiska',
        'bar' => 'bayerska',
        'bas' => 'basa',
        'bax' => 'bamunska',
        'bbc' => 'batak-toba',
        'bbj' => 'ghomala',
        'be' => 'vitryska',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bew' => 'betawiska',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bfq' => 'bagada',
        'bg' => 'bulgariska',
        'bgn' => 'västbaluchiska',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bjn' => 'banjariska',
        'bkm' => 'bamekon',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bengali',
        'bo' => 'tibetanska',
        'bpy' => 'bishnupriya',
        'bqi' => 'bakhtiari',
        'br' => 'bretonska',
        'bra' => 'braj',
        'brh' => 'brahuiska',
        'brx' => 'bodo',
        'bs' => 'bosniska',
        'bss' => 'bakossi',
        'bua' => 'burjätiska',
        'bug' => 'buginesiska',
        'bum' => 'boulou',
        'byn' => 'blin',
        'byv' => 'bagangte',
        'ca' => 'katalanska',
        'cad' => 'caddo',
        'car' => 'karibiska',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'tjetjenska',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'chibcha',
        'chg' => 'chagatai',
        'chk' => 'chuukesiska',
        'chm' => 'mariska',
        'chn' => 'chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokesiska',
        'chy' => 'cheyenne',
        'ckb' => 'soranisk kurdiska',
        'clc' => 'chilcotin',
        'co' => 'korsikanska',
        'cop' => 'koptiska',
        'cps' => 'kapisnon',
        'cr' => 'cree',
        'crg' => 'michif',
        'crh' => 'krimtatariska',
        'crj' => 'sydostcree',
        'crk' => 'slättcree',
        'crl' => 'nordost-cree',
        'crm' => 'moose cree',
        'crr' => 'Carolina-algonkinska',
        'crs' => 'seychellisk kreol',
        'cs' => 'tjeckiska',
        'csb' => 'kasjubiska',
        'csw' => 'träskcree',
        'cu' => 'kyrkslaviska',
        'cv' => 'tjuvasjiska',
        'cy' => 'walesiska',
        'da' => 'danska',
        'dak' => 'dakota',
        'dar' => 'darginska',
        'dav' => 'taita',
        'de' => 'tyska',
        'del' => 'delaware',
        'den' => 'slavej',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'lågsorbiska',
        'dtp' => 'centraldusun',
        'dua' => 'duala',
        'dum' => 'medelnederländska',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dyu' => 'dyula',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egl' => 'emiliska',
        'egy' => 'fornegyptiska',
        'eka' => 'ekajuk',
        'el' => 'grekiska',
        'elx' => 'elamitiska',
        'en' => 'engelska',
        'enm' => 'medelengelska',
        'eo' => 'esperanto',
        'es' => 'spanska',
        'esu' => 'centralalaskisk jupiska',
        'et' => 'estniska',
        'eu' => 'baskiska',
        'ewo' => 'ewondo',
        'ext' => 'extremaduriska',
        'fa' => 'persiska',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulani',
        'fi' => 'finska',
        'fil' => 'filippinska',
        'fit' => 'meänkieli',
        'fj' => 'fijianska',
        'fo' => 'färöiska',
        'fon' => 'fonspråket',
        'fr' => 'franska',
        'frc' => 'cajun-franska',
        'frm' => 'medelfranska',
        'fro' => 'fornfranska',
        'frp' => 'frankoprovensalska',
        'frr' => 'nordfrisiska',
        'frs' => 'östfrisiska',
        'fur' => 'friulianska',
        'fy' => 'västfrisiska',
        'ga' => 'iriska',
        'gaa' => 'gã',
        'gag' => 'gagauziska',
        'gan' => 'gan',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gbz' => 'zoroastrisk dari',
        'gd' => 'skotsk gäliska',
        'gez' => 'etiopiska',
        'gil' => 'gilbertiska',
        'gl' => 'galiciska',
        'glk' => 'gilaki',
        'gmh' => 'medelhögtyska',
        'gn' => 'guaraní',
        'goh' => 'fornhögtyska',
        'gom' => 'Goa-konkani',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gotiska',
        'grb' => 'grebo',
        'grc' => 'forngrekiska',
        'gsw' => 'schweizertyska',
        'gu' => 'gujarati',
        'guc' => 'wayuu',
        'gur' => 'farefare',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwichin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'hak' => 'hakka',
        'haw' => 'hawaiiska',
        'hax' => 'sydhaida',
        'he' => 'hebreiska',
        'hi' => 'hindi',
        'hif' => 'Fiji-hindi',
        'hil' => 'hiligaynon',
        'hit' => 'hettitiska',
        'hmn' => 'hmongspråk',
        'ho' => 'hirimotu',
        'hr' => 'kroatiska',
        'hsb' => 'högsorbiska',
        'hsn' => 'xiang',
        'ht' => 'haitiska',
        'hu' => 'ungerska',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armeniska',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'ibanska',
        'ibb' => 'ibibio',
        'id' => 'indonesiska',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'szezuan i',
        'ik' => 'inupiak',
        'ikt' => 'inuktun',
        'ilo' => 'iloko',
        'inh' => 'ingusjiska',
        'io' => 'ido',
        'is' => 'isländska',
        'it' => 'italienska',
        'iu' => 'inuktitut',
        'izh' => 'ingriska',
        'ja' => 'japanska',
        'jam' => 'jamaikansk engelsk kreol',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'kimashami',
        'jpr' => 'judisk persiska',
        'jrb' => 'judisk arabiska',
        'jut' => 'jylländska',
        'jv' => 'javanesiska',
        'ka' => 'georgiska',
        'kaa' => 'karakalpakiska',
        'kab' => 'kabyliska',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardinska',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kapverdiska',
        'ken' => 'kenjang',
        'kfo' => 'koro',
        'kg' => 'kikongo',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'kho' => 'khotanesiska',
        'khq' => 'Timbuktu-songhai',
        'khw' => 'khowar',
        'ki' => 'kikuyu',
        'kiu' => 'kirmanjki',
        'kj' => 'kuanyama',
        'kk' => 'kazakiska',
        'kkj' => 'mkako',
        'kl' => 'grönländska',
        'kln' => 'kalenjin',
        'km' => 'kambodjanska',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreanska',
        'koi' => 'komi-permjakiska',
        'kok' => 'konkani',
        'kos' => 'kosreanska',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karachay-balkar',
        'kri' => 'krio',
        'krj' => 'kinaray-a',
        'krl' => 'karelska',
        'kru' => 'kurukh',
        'ks' => 'kashmiriska',
        'ksb' => 'kisambaa',
        'ksf' => 'bafia',
        'ksh' => 'kölniska',
        'ku' => 'kurdiska',
        'kum' => 'kumykiska',
        'kut' => 'kutenaj',
        'kv' => 'kome',
        'kw' => 'korniska',
        'kwk' => 'kwakʼwala',
        'ky' => 'kirgiziska',
        'la' => 'latin',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxemburgiska',
        'lez' => 'lezghien',
        'lfn' => 'lingua franca nova',
        'lg' => 'luganda',
        'li' => 'limburgiska',
        'lij' => 'liguriska',
        'lil' => 'lillooet',
        'liv' => 'livoniska',
        'lkt' => 'lakota',
        'lmo' => 'lombardiska',
        'ln' => 'lingala',
        'lo' => 'laotiska',
        'lol' => 'mongo',
        'lou' => 'louisiana-kreol',
        'loz' => 'lozi',
        'lrc' => 'nordluri',
        'lsm' => 'saamia',
        'lt' => 'litauiska',
        'ltg' => 'lettgalliska',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseño',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'lushai',
        'luy' => 'luhya',
        'lv' => 'lettiska',
        'lzh' => 'litterär kineiska',
        'lzz' => 'laziska',
        'mad' => 'maduresiska',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'man' => 'mande',
        'mas' => 'massajiska',
        'mde' => 'maba',
        'mdf' => 'moksja',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'mauritansk kreol',
        'mg' => 'malagassiska',
        'mga' => 'medeliriska',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshalliska',
        'mi' => 'maori',
        'mic' => 'mi’kmaq',
        'min' => 'minangkabau',
        'mk' => 'makedonska',
        'ml' => 'malayalam',
        'mn' => 'mongoliska',
        'mnc' => 'manchuriska',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'mrj' => 'västmariska',
        'ms' => 'malajiska',
        'mt' => 'maltesiska',
        'mua' => 'mundang',
        'mus' => 'muskogee',
        'mwl' => 'mirandesiska',
        'mwr' => 'marwari',
        'mwv' => 'mentawai',
        'my' => 'burmesiska',
        'mye' => 'myene',
        'myv' => 'erjya',
        'mzn' => 'mazanderani',
        'na' => 'nauruanska',
        'nan' => 'min nan',
        'nap' => 'napolitanska',
        'naq' => 'nama',
        'nb' => 'norskt bokmål',
        'nd' => 'nordndebele',
        'nds' => 'lågtyska',
        'ne' => 'nepalesiska',
        'new' => 'newariska',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niueanska',
        'njo' => 'ao-naga',
        'nl' => 'nederländska',
        'nmg' => 'kwasio',
        'nn' => 'nynorska',
        'nnh' => 'bamileké-ngiemboon',
        'no' => 'norska',
        'nog' => 'nogai',
        'non' => 'fornnordiska',
        'nov' => 'novial',
        'nqo' => 'n-kå',
        'nr' => 'sydndebele',
        'nso' => 'nordsotho',
        'nus' => 'nuer',
        'nv' => 'navaho',
        'nwc' => 'klassisk newariska',
        'ny' => 'nyanja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'occitanska',
        'oj' => 'odjibwa',
        'ojb' => 'nordvästojibwa',
        'ojc' => 'ojibwa',
        'ojs' => 'oji-cree',
        'ojw' => 'västojibwe',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'oriya',
        'os' => 'ossetiska',
        'osa' => 'osage',
        'ota' => 'ottomanska',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pal' => 'medelpersiska',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palau',
        'pcd' => 'pikardiska',
        'pcm' => 'nigeriansk pidgin',
        'pdc' => 'Pennsylvaniatyska',
        'pdt' => 'mennonitisk lågtyska',
        'peo' => 'fornpersiska',
        'pfl' => 'Pfalz-tyska',
        'phn' => 'feniciska',
        'pi' => 'pali',
        'pis' => 'pidginspråk',
        'pl' => 'polska',
        'pms' => 'piemontesiska',
        'pnt' => 'pontiska',
        'pon' => 'pohnpeiska',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'fornpreussiska',
        'pro' => 'fornprovensalska',
        'ps' => 'afghanska',
        'pt' => 'portugisiska',
        'qu' => 'quechua',
        'quc' => 'quiché',
        'qug' => 'Chimborazo-höglandskichwa',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotonganska',
        'rgn' => 'romagnol',
        'rhg' => 'ruáingga',
        'rif' => 'riffianska',
        'rm' => 'rätoromanska',
        'rn' => 'rundi',
        'ro' => 'rumänska',
        'rof' => 'rombo',
        'rom' => 'romani',
        'rtm' => 'rotumänska',
        'ru' => 'ryska',
        'rue' => 'rusyn',
        'rug' => 'rovianska',
        'rup' => 'arumänska',
        'rw' => 'kinjarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanskrit',
        'sad' => 'sandawe',
        'sah' => 'jakutiska',
        'sam' => 'samaritanska',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'saz' => 'saurashtra',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardinska',
        'scn' => 'sicilianska',
        'sco' => 'skotska',
        'sd' => 'sindhi',
        'sdc' => 'sassaresisk sardiska',
        'sdh' => 'sydkurdiska',
        'se' => 'nordsamiska',
        'see' => 'seneca',
        'seh' => 'sena',
        'sei' => 'seri',
        'sel' => 'selkup',
        'ses' => 'songhai',
        'sg' => 'sango',
        'sga' => 'forniriska',
        'sgs' => 'samogitiska',
        'sh' => 'serbokroatiska',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'shu' => 'Tchad-arabiska',
        'si' => 'singalesiska',
        'sid' => 'sidamo',
        'sk' => 'slovakiska',
        'sl' => 'slovenska',
        'slh' => 'sydlushootseed',
        'sli' => 'lågsilesiska',
        'sly' => 'selayar',
        'sm' => 'samoanska',
        'sma' => 'sydsamiska',
        'smj' => 'lulesamiska',
        'smn' => 'enaresamiska',
        'sms' => 'skoltsamiska',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somaliska',
        'sog' => 'sogdiska',
        'sq' => 'albanska',
        'sr' => 'serbiska',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'swati',
        'ssy' => 'saho',
        'st' => 'sydsotho',
        'stq' => 'saterfrisiska',
        'str' => 'sundsalishanska',
        'su' => 'sundanesiska',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumeriska',
        'sv' => 'svenska',
        'sw' => 'swahili',
        'swb' => 'shimaoré',
        'syc' => 'klassisk syriska',
        'syr' => 'syriska',
        'szl' => 'silesiska',
        'ta' => 'tamil',
        'tce' => 'sydtutchone',
        'tcy' => 'tulu',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tadzjikiska',
        'tgx' => 'tagish',
        'th' => 'thailändska',
        'tht' => 'tahltan',
        'ti' => 'tigrinja',
        'tig' => 'tigré',
        'tiv' => 'tivi',
        'tk' => 'turkmeniska',
        'tkl' => 'tokelauiska',
        'tkr' => 'tsakhur',
        'tl' => 'tagalog',
        'tlh' => 'klingonska',
        'tli' => 'tlingit',
        'tly' => 'talysh',
        'tmh' => 'tamashek',
        'tn' => 'tswana',
        'to' => 'tonganska',
        'tog' => 'nyasatonganska',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turkiska',
        'tru' => 'turoyo',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsd' => 'tsakodiska',
        'tsi' => 'tsimshian',
        'tt' => 'tatariska',
        'ttm' => 'nordtutchone',
        'ttt' => 'muslimsk tatariska',
        'tum' => 'tumbuka',
        'tvl' => 'tuvaluanska',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitiska',
        'tyv' => 'tuviniska',
        'tzm' => 'centralmarockansk tamazight',
        'udm' => 'udmurtiska',
        'ug' => 'uiguriska',
        'uga' => 'ugaritiska',
        'uk' => 'ukrainska',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbekiska',
        'vai' => 'vaj',
        've' => 'venda',
        'vec' => 'venetianska',
        'vep' => 'veps',
        'vi' => 'vietnamesiska',
        'vls' => 'västflamländska',
        'vmf' => 'Main-frankiska',
        'vo' => 'volapük',
        'vot' => 'votiska',
        'vro' => 'võru',
        'vun' => 'vunjo',
        'wa' => 'vallonska',
        'wae' => 'walsertyska',
        'wal' => 'walamo',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'wolof',
        'wuu' => 'wu',
        'xal' => 'kalmuckiska',
        'xh' => 'xhosa',
        'xmf' => 'mingrelianska',
        'xog' => 'lusoga',
        'yao' => 'kiyao',
        'yap' => 'japetiska',
        'yav' => 'yangben',
        'ybb' => 'bamileké-jemba',
        'yi' => 'jiddisch',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'kantonesiska',
        'za' => 'zhuang',
        'zap' => 'zapotek',
        'zbl' => 'blissymboler',
        'zea' => 'zeeländska',
        'zen' => 'zenaga',
        'zgh' => 'marockansk standard-tamazight',
        'zh' => 'kinesiska',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zazaiska',
    ],
    'LocalizedNames' => [
        'ar_001' => 'modern standardarabiska',
        'de_AT' => 'österrikisk tyska',
        'de_CH' => 'schweizisk högtyska',
        'en_AU' => 'australisk engelska',
        'en_CA' => 'kanadensisk engelska',
        'en_GB' => 'brittisk engelska',
        'en_US' => 'amerikansk engelska',
        'es_419' => 'latinamerikansk spanska',
        'es_ES' => 'europeisk spanska',
        'es_MX' => 'mexikansk spanska',
        'fa_AF' => 'dari',
        'fr_CA' => 'kanadensisk franska',
        'fr_CH' => 'schweizisk franska',
        'hi_Latn' => 'hindi (latinsk)',
        'nds_NL' => 'lågsaxiska',
        'nl_BE' => 'flamländska',
        'pt_BR' => 'brasiliansk portugisiska',
        'pt_PT' => 'europeisk portugisiska',
        'ro_MD' => 'moldaviska',
        'sw_CD' => 'Kongo-swahili',
        'zh_Hans' => 'förenklad kinesiska',
        'zh_Hant' => 'traditionell kinesiska',
    ],
];
