<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'peseta andorrana',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham dos Emiratos Árabes Unidos',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afgani afgán',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'lek albanés',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'dram armenio',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'florín das Antillas Neerlandesas',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kwanza angolano',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Peso arxentino (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'peso arxentino',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'dólar australiano',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'florín de Aruba',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'manat acerbaixano',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'marco convertible de Bosnia e Hercegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'dólar de Barbados',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'taka de Bangladesh',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Franco belga (convertible)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Franco belga',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Franco belga (financeiro)',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'lev búlgaro',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'dinar de Bahrain',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'franco burundiano',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'dólar bermudano',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'dólar de Brunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'boliviano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Peso boliviano',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'MVDOL boliviano',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Cruzeiro novo brasileiro (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Cruzado brasileiro',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Cruzeiro brasileiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'real brasileiro',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Cruzado novo brasileiro',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Cruzeiro brasileiro',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'dólar bahamés',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'ngultrum butanés',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'pula botswaniano',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'rublo belaruso',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Rublo bielorruso (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'dólar belizense',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'dólar canadense',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'franco congolés',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'franco suízo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Unidades de fomento chilenas',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'peso chileno',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'iuán chinés (extracontinental)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'iuán chinés',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'peso colombiano',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'colón costarriqueño',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'peso cubano convertible',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'peso cubano',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'escudo caboverdiano',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'coroa checa',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Marco alemán',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'franco djibutiano',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'coroa dinamarquesa',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'peso dominicano',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'dinar alxeriano',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Sucre ecuatoriano',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Unidade de valor constante ecuatoriana',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'libra exipcia',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'nakfa eritreo',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Peseta española (conta A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Peseta española (conta convertible)',
        ],
        'ESP' => [
            0 => '₧',
            1 => 'Peseta española',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'birr etíope',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'dólar fixiano',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'libra das Illas Malvinas',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franco francés',
        ],
        'GBP' => [
            0 => '£',
            1 => 'libra esterlina',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'lari xeorxiano',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'cedi ghanés',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'libra xibraltareña',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'dalasi gambiano',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'franco guineano',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Syli guineano',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Ekwele guineana',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Dracma grego',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'quetzal guatemalteco',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'dólar güianés',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'dólar de Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'lempira hondureño',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'kuna croata',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'gourde haitiana',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'florín húngaro',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'rupia indonesia',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Libra irlandesa',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'novo shequel israelí',
        ],
        'INR' => [
            0 => '₹',
            1 => 'rupia india',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'dinar iraquí',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'rial iraniano',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'coroa islandesa',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Lira italiana',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'dólar xamaicano',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'dinar xordano',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'ien xaponés',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'xilin kenyano',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'som kirguiz',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'riel camboxano',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'franco comoriano',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'won norcoreano',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'won surcoreano',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'dinar kuwaití',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'dólar das Illas Caimán',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'tenge kazako',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'kip laosiano',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'libra libanesa',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'rupia srilankesa',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'dólar liberiano',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'loti de Lesoto',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litas lituana',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Franco convertible luxemburgués',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Franco luxemburgués',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Franco financeiro luxemburgués',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lats letón',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'dinar libio',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'dirham marroquí',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Franco marroquí',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'leu moldavo',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'ariary malgaxe',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'dinar macedonio',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'kyat birmano',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'tugrik mongol',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'pataca macaense',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya mauritano (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'ouguiya mauritano',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'rupia mauriciana',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'rupia maldivana',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'kwacha de Malawi',
        ],
        'MXN' => [
            0 => '$MX',
            1 => 'peso mexicano',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Peso de prata mexicano (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Unidade de inversión mexicana',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'ringgit malaio',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'metical mozambicano',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'dólar namibio',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'naira nixeriano',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Córdoba nicaragüense',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'córdoba nicaraguano',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Florín holandés',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'coroa norueguesa',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'rupia nepalesa',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'dólar neozelandés',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'rial omaní',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'balboa panameño',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Inti peruano',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'sol peruano',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Sol peruano (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina de Papúa-Nova Guinea',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'peso filipino',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'rupia paquistaní',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'zloty polaco',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Escudo portugués',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'guaraní paraguaio',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'rial qatarí',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'leu romanés',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'dinar serbio',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'rublo ruso',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Rublo ruso (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'franco ruandés',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'rial saudita',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'dólar das Illas Salomón',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'rupia de Seychelles',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'libra sudanesa',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'coroa sueca',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'dólar de Singapur',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'libra de Santa Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'leone de Serra Leoa',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'xilin somalí',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'dólar surinamés',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'libra sursudanesa',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra de São Tomé e Príncipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra de San Tomé e Príncipe',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Rublo soviético',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Colón salvadoreño',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'libra siria',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'lilangeni de Swazilandia',
        ],
        'THB' => [
            0 => '฿',
            1 => 'baht tailandés',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'somoni taxiquistano',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'manat turkmeno',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'dinar tunisiano',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'paʻanga tongano',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'lira turca',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dólar trinitense',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'novo dólar taiwanés',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'xilin tanzano',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'hrivna ucraína',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'xilin ugandés',
        ],
        'USD' => [
            0 => '$',
            1 => 'dólar estadounidense',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Peso en unidades indexadas uruguaio',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Peso uruguaio (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'peso uruguaio',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'som uzbeko',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Bolívar venezolano (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolívar venezolano (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'bolívar venezolano',
        ],
        'VND' => [
            0 => '₫',
            1 => 'dong vietnamita',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vatu vanuatiano',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'tala samoano',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'franco CFA (BEAC)',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'dólar do Caribe Oriental',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'franco CFA (BCEAO)',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'franco CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'rial iemení',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'rand surafricano',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha zambiano (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'kwacha zambiano',
        ],
    ],
];
