<?php

return [
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'Verenigde Arabiese Emirate',
        'AF' => 'Afganistan',
        'AG' => 'Antigua en Barbuda',
        'AI' => 'Anguilla',
        'AL' => 'Albanië',
        'AM' => 'Armenië',
        'AO' => 'Angola',
        'AQ' => 'Antarktika',
        'AR' => 'Argentinië',
        'AS' => 'Amerikaanse Samoa',
        'AT' => 'Oostenryk',
        'AU' => 'Australië',
        'AW' => 'Aruba',
        'AX' => 'Ålandeilande',
        'AZ' => 'Azerbeidjan',
        'BA' => 'Bosnië en Herzegowina',
        'BB' => 'Barbados',
        'BD' => 'Bangladesj',
        'BE' => 'België',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgarye',
        'BH' => 'Bahrein',
        'BI' => 'Burundi',
        'BJ' => 'Benin',
        'BL' => 'Sint Barthélemy',
        'BM' => 'Bermuda',
        'BN' => 'Broenei',
        'BO' => 'Bolivië',
        'BQ' => 'Karibiese Nederland',
        'BR' => 'Brasilië',
        'BS' => 'Bahamas',
        'BT' => 'Bhoetan',
        'BV' => 'Bouvet-eiland',
        'BW' => 'Botswana',
        'BY' => 'Belarus',
        'BZ' => 'Belize',
        'CA' => 'Kanada',
        'CC' => 'Kokoseilande',
        'CD' => 'Demokratiese Republiek van die Kongo',
        'CF' => 'Sentraal-Afrikaanse Republiek',
        'CG' => 'Kongo - Brazzaville',
        'CH' => 'Switserland',
        'CI' => 'Ivoorkus',
        'CK' => 'Cookeilande',
        'CL' => 'Chili',
        'CM' => 'Kameroen',
        'CN' => 'China',
        'CO' => 'Colombië',
        'CR' => 'Costa Rica',
        'CU' => 'Kuba',
        'CV' => 'Kaap Verde',
        'CW' => 'Curaçao',
        'CX' => 'Kerseiland',
        'CY' => 'Siprus',
        'CZ' => 'Tsjeggië',
        'DE' => 'Duitsland',
        'DJ' => 'Djiboeti',
        'DK' => 'Denemarke',
        'DM' => 'Dominica',
        'DO' => 'Dominikaanse Republiek',
        'DZ' => 'Algerië',
        'EC' => 'Ecuador',
        'EE' => 'Estland',
        'EG' => 'Egipte',
        'EH' => 'Wes-Sahara',
        'ER' => 'Eritrea',
        'ES' => 'Spanje',
        'ET' => 'Ethiopië',
        'FI' => 'Finland',
        'FJ' => 'Fidji',
        'FK' => 'Falklandeilande',
        'FM' => 'Mikronesië',
        'FO' => 'Faroëreilande',
        'FR' => 'Frankryk',
        'GA' => 'Gaboen',
        'GB' => 'Verenigde Koninkryk',
        'GD' => 'Grenada',
        'GE' => 'Georgië',
        'GF' => 'Frans-Guyana',
        'GG' => 'Guernsey',
        'GH' => 'Ghana',
        'GI' => 'Gibraltar',
        'GL' => 'Groenland',
        'GM' => 'Gambië',
        'GN' => 'Guinee',
        'GP' => 'Guadeloupe',
        'GQ' => 'Ekwatoriaal-Guinee',
        'GR' => 'Griekeland',
        'GS' => 'Suid-Georgië en die Suidelike Sandwicheilande',
        'GT' => 'Guatemala',
        'GU' => 'Guam',
        'GW' => 'Guinee-Bissau',
        'GY' => 'Guyana',
        'HK' => 'Hongkong SAS China',
        'HM' => 'Heardeiland en McDonaldeilande',
        'HN' => 'Honduras',
        'HR' => 'Kroasië',
        'HT' => 'Haïti',
        'HU' => 'Hongarye',
        'ID' => 'Indonesië',
        'IE' => 'Ierland',
        'IL' => 'Israel',
        'IM' => 'Eiland Man',
        'IN' => 'Indië',
        'IO' => 'Brits-Indiese Oseaangebied',
        'IQ' => 'Irak',
        'IR' => 'Iran',
        'IS' => 'Ysland',
        'IT' => 'Italië',
        'JE' => 'Jersey',
        'JM' => 'Jamaika',
        'JO' => 'Jordanië',
        'JP' => 'Japan',
        'KE' => 'Kenia',
        'KG' => 'Kirgistan',
        'KH' => 'Kambodja',
        'KI' => 'Kiribati',
        'KM' => 'Comore',
        'KN' => 'Sint Kitts en Nevis',
        'KP' => 'Noord-Korea',
        'KR' => 'Suid-Korea',
        'KW' => 'Koeweit',
        'KY' => 'Kaaimanseilande',
        'KZ' => 'Kazakstan',
        'LA' => 'Laos',
        'LB' => 'Libanon',
        'LC' => 'Sint Lucia',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri Lanka',
        'LR' => 'Liberië',
        'LS' => 'Lesotho',
        'LT' => 'Litaue',
        'LU' => 'Luxemburg',
        'LV' => 'Letland',
        'LY' => 'Libië',
        'MA' => 'Marokko',
        'MC' => 'Monaco',
        'MD' => 'Moldowa',
        'ME' => 'Montenegro',
        'MF' => 'Sint Martin',
        'MG' => 'Madagaskar',
        'MH' => 'Marshalleilande',
        'MK' => 'Noord-Macedonië',
        'ML' => 'Mali',
        'MM' => 'Mianmar (Birma)',
        'MN' => 'Mongolië',
        'MO' => 'Macau SAS China',
        'MP' => 'Noord-Mariane-eilande',
        'MQ' => 'Martinique',
        'MR' => 'Mauritanië',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauritius',
        'MV' => 'Maledive',
        'MW' => 'Malawi',
        'MX' => 'Meksiko',
        'MY' => 'Maleisië',
        'MZ' => 'Mosambiek',
        'NA' => 'Namibië',
        'NC' => 'Nieu-Kaledonië',
        'NE' => 'Niger',
        'NF' => 'Norfolkeiland',
        'NG' => 'Nigerië',
        'NI' => 'Nicaragua',
        'NL' => 'Nederland',
        'NO' => 'Noorweë',
        'NP' => 'Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Nieu-Seeland',
        'OM' => 'Oman',
        'PA' => 'Panama',
        'PE' => 'Peru',
        'PF' => 'Frans-Polinesië',
        'PG' => 'Papoea-Nieu-Guinee',
        'PH' => 'Filippyne',
        'PK' => 'Pakistan',
        'PL' => 'Pole',
        'PM' => 'Sint Pierre en Miquelon',
        'PN' => 'Pitcairneilande',
        'PR' => 'Puerto Rico',
        'PS' => 'Palestynse Grondgebiede',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Paraguay',
        'QA' => 'Katar',
        'RE' => 'Réunion',
        'RO' => 'Roemenië',
        'RS' => 'Serwië',
        'RU' => 'Rusland',
        'RW' => 'Rwanda',
        'SA' => 'Saoedi-Arabië',
        'SB' => 'Salomonseilande',
        'SC' => 'Seychelle',
        'SD' => 'Soedan',
        'SE' => 'Swede',
        'SG' => 'Singapoer',
        'SH' => 'Sint Helena',
        'SI' => 'Slowenië',
        'SJ' => 'Spitsbergen en Jan Mayen',
        'SK' => 'Slowakye',
        'SL' => 'Sierra Leone',
        'SM' => 'San Marino',
        'SN' => 'Senegal',
        'SO' => 'Somalië',
        'SR' => 'Suriname',
        'SS' => 'Suid-Soedan',
        'ST' => 'São Tomé en Príncipe',
        'SV' => 'El Salvador',
        'SX' => 'Sint Maarten',
        'SY' => 'Sirië',
        'SZ' => 'Eswatini',
        'TC' => 'Turks- en Caicoseilande',
        'TD' => 'Tsjad',
        'TF' => 'Franse Suidelike Gebiede',
        'TG' => 'Togo',
        'TH' => 'Thailand',
        'TJ' => 'Tadjikistan',
        'TK' => 'Tokelau',
        'TL' => 'Oos-Timor',
        'TM' => 'Turkmenistan',
        'TN' => 'Tunisië',
        'TO' => 'Tonga',
        'TR' => 'Turkye',
        'TT' => 'Trinidad en Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'Taiwan',
        'TZ' => 'Tanzanië',
        'UA' => 'Oekraïne',
        'UG' => 'Uganda',
        'UM' => 'Klein afgeleë eilande van die VSA',
        'US' => 'Verenigde State van Amerika',
        'UY' => 'Uruguay',
        'UZ' => 'Oesbekistan',
        'VA' => 'Vatikaanstad',
        'VC' => 'Sint Vincent en die Grenadine',
        'VE' => 'Venezuela',
        'VG' => 'Britse Maagde-eilande',
        'VI' => 'VSA se Maagde-eilande',
        'VN' => 'Viëtnam',
        'VU' => 'Vanuatu',
        'WF' => 'Wallis en Futuna',
        'WS' => 'Samoa',
        'YE' => 'Jemen',
        'YT' => 'Mayotte',
        'ZA' => 'Suid-Afrika',
        'ZM' => 'Zambië',
        'ZW' => 'Zimbabwe',
    ],
];
