<?php

return [
    'Names' => [
        'aa' => 'афар',
        'ab' => 'абхаз',
        'ace' => 'акин',
        'ada' => 'адангме',
        'ady' => 'адуҝе',
        'af' => 'африкаанс',
        'agq' => 'агһем',
        'ain' => 'ајну',
        'ak' => 'акан',
        'ale' => 'алеут',
        'alt' => 'ҹәнуби алтај',
        'am' => 'амһар',
        'an' => 'арагон',
        'anp' => 'анҝика',
        'ar' => 'әрәб',
        'arn' => 'арауканҹа',
        'arp' => 'арапаһо',
        'as' => 'ассам',
        'asa' => 'асу',
        'ast' => 'астурија',
        'av' => 'авар',
        'awa' => 'авадһи',
        'ay' => 'ајмара',
        'az' => 'азәрбајҹан',
        'ba' => 'башгырд',
        'ban' => 'балли',
        'bas' => 'баса',
        'be' => 'беларус',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bg' => 'булгар',
        'bho' => 'бхочпури',
        'bi' => 'бислама',
        'bin' => 'бини',
        'bla' => 'сиксикә',
        'bm' => 'бамбара',
        'bn' => 'бенгал',
        'bo' => 'тибет',
        'br' => 'бретон',
        'brx' => 'бодо',
        'bs' => 'босниак',
        'bug' => 'буҝин',
        'byn' => 'блин',
        'ca' => 'каталан',
        'ce' => 'чечен',
        'ceb' => 'себуан',
        'cgg' => 'чига',
        'ch' => 'чаморо',
        'chk' => 'чукиз',
        'chm' => 'мари',
        'cho' => 'чоктау',
        'chr' => 'чероки',
        'chy' => 'чејен',
        'ckb' => 'соран',
        'co' => 'корсика',
        'crs' => 'сејшел креолу',
        'cs' => 'чех',
        'cu' => 'славјан',
        'cv' => 'чуваш',
        'cy' => 'уелс',
        'da' => 'данимарка',
        'dak' => 'дакота',
        'dar' => 'даргва',
        'dav' => 'таита',
        'de' => 'алман',
        'dgr' => 'догриб',
        'dje' => 'зарма',
        'dsb' => 'ашағы сорб',
        'dua' => 'дуала',
        'dv' => 'малдив',
        'dyo' => 'диола',
        'dz' => 'дзонга',
        'dzg' => 'дазага',
        'ebu' => 'ембу',
        'ee' => 'еве',
        'efi' => 'ефик',
        'eka' => 'екаҹук',
        'el' => 'јунан',
        'en' => 'инҝилис',
        'eo' => 'есперанто',
        'es' => 'испан',
        'et' => 'естон',
        'eu' => 'баск',
        'ewo' => 'евондо',
        'fa' => 'фарс',
        'ff' => 'фула',
        'fi' => 'фин',
        'fil' => 'филиппин',
        'fj' => 'фиҹи',
        'fo' => 'фарер',
        'fon' => 'фон',
        'fr' => 'франсыз',
        'fur' => 'фриул',
        'fy' => 'гәрби фриз',
        'ga' => 'ирланд',
        'gaa' => 'га',
        'gd' => 'шотланд келт',
        'gez' => 'гез',
        'gil' => 'гилберт',
        'gl' => 'галисија',
        'gn' => 'гуарани',
        'gor' => 'горонтало',
        'gsw' => 'Исвечрә алманҹасы',
        'gu' => 'гуҹарат',
        'guz' => 'гуси',
        'gv' => 'манкс',
        'gwi' => 'гвичин',
        'ha' => 'һауса',
        'haw' => 'һавај',
        'he' => 'иврит',
        'hi' => 'һинд',
        'hil' => 'һилигајнон',
        'hmn' => 'монг',
        'hr' => 'хорват',
        'hsb' => 'јухары сорб',
        'ht' => 'һаити креол',
        'hu' => 'маҹар',
        'hup' => 'һупа',
        'hy' => 'ермәни',
        'hz' => 'һереро',
        'ia' => 'интерлингве',
        'iba' => 'ибан',
        'ibb' => 'ибибио',
        'id' => 'индонезија',
        'ig' => 'игбо',
        'ilo' => 'илоко',
        'inh' => 'ингуш',
        'io' => 'идо',
        'is' => 'исланд',
        'it' => 'италјан',
        'iu' => 'инуктитут',
        'ja' => 'јапон',
        'jbo' => 'лоғбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачам',
        'jv' => 'јава',
        'ka' => 'ҝүрҹү',
        'kab' => 'кабиле',
        'kac' => 'качин',
        'kaj' => 'жу',
        'kam' => 'камба',
        'kbd' => 'кабарда-чәркәз',
        'kcg' => 'тви',
        'kde' => 'маконде',
        'kea' => 'кабувердиан',
        'kfo' => 'коро',
        'kha' => 'хази',
        'khq' => 'којра чиини',
        'ki' => 'кикују',
        'kj' => 'куанјама',
        'kk' => 'газах',
        'kkj' => 'како',
        'kl' => 'калааллисут',
        'kln' => 'каленҹин',
        'km' => 'кхмер',
        'kmb' => 'кимбунду',
        'kn' => 'каннада',
        'ko' => 'кореја',
        'kok' => 'конкани',
        'kpe' => 'кпелле',
        'kr' => 'канури',
        'krc' => 'гарачај-балкар',
        'krl' => 'карел',
        'kru' => 'курух',
        'ks' => 'кәшмир',
        'ksb' => 'шамбала',
        'ksf' => 'бафиа',
        'ksh' => 'көлн',
        'ku' => 'күрд',
        'kum' => 'кумык',
        'kv' => 'коми',
        'kw' => 'корн',
        'ky' => 'гырғыз',
        'la' => 'латын',
        'lad' => 'сефард',
        'lag' => 'ланҝи',
        'lb' => 'лүксембург',
        'lez' => 'ләзҝи',
        'lg' => 'ганда',
        'li' => 'лимбург',
        'lkt' => 'лакота',
        'ln' => 'лингала',
        'lo' => 'лаос',
        'loz' => 'лози',
        'lrc' => 'шимали лури',
        'lt' => 'литва',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'мизо',
        'luy' => 'лујиа',
        'lv' => 'латыш',
        'mad' => 'мадуриз',
        'mag' => 'магаһи',
        'mai' => 'маитили',
        'mak' => 'макасар',
        'mas' => 'масај',
        'mdf' => 'мокша',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'морисиен',
        'mg' => 'малагас',
        'mgh' => 'махува-меетто',
        'mgo' => 'метаʼ',
        'mh' => 'маршал',
        'mi' => 'маори',
        'mic' => 'микмак',
        'min' => 'минангкабан',
        'mk' => 'македон',
        'ml' => 'малајалам',
        'mn' => 'монгол',
        'mni' => 'манипүри',
        'moh' => 'моһавк',
        'mos' => 'моси',
        'mr' => 'маратһи',
        'ms' => 'малај',
        'mt' => 'малта',
        'mua' => 'мунданг',
        'mus' => 'крик',
        'mwl' => 'миранд',
        'my' => 'бирман',
        'myv' => 'ерзја',
        'mzn' => 'мазандаран',
        'na' => 'науру',
        'nap' => 'неаполитан',
        'naq' => 'нама',
        'nb' => 'бокмал норвеч',
        'nd' => 'шимали ндебеле',
        'ne' => 'непал',
        'new' => 'невари',
        'ng' => 'ндонга',
        'nia' => 'ниас',
        'niu' => 'нијуан',
        'nl' => 'һолланд',
        'nmg' => 'квасио',
        'nn' => 'нүнорск норвеч',
        'nnh' => 'нҝиембоон',
        'nog' => 'ногај',
        'nqo' => 'нго',
        'nr' => 'ҹәнуби ндебеле',
        'nso' => 'шимали сото',
        'nus' => 'нуер',
        'nv' => 'навајо',
        'ny' => 'нјанҹа',
        'nyn' => 'нјанкол',
        'oc' => 'окситан',
        'om' => 'оромо',
        'or' => 'одија',
        'os' => 'осетин',
        'pa' => 'пәнҹаб',
        'pag' => 'пангасинан',
        'pam' => 'пампанга',
        'pap' => 'папјаменто',
        'pau' => 'палајан',
        'pcm' => 'ниҝер креол',
        'pl' => 'полјак',
        'prg' => 'прусс',
        'ps' => 'пушту',
        'pt' => 'португал',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'rap' => 'рапануи',
        'rar' => 'раротонган',
        'rm' => 'романш',
        'rn' => 'рунди',
        'ro' => 'румын',
        'rof' => 'ромбо',
        'ru' => 'рус',
        'rup' => 'ароман',
        'rw' => 'кинјарванда',
        'rwk' => 'руа',
        'sa' => 'санскрит',
        'sad' => 'сандаве',
        'sah' => 'саха',
        'saq' => 'самбуру',
        'sat' => 'сантал',
        'sba' => 'нгамбај',
        'sbp' => 'сангу',
        'sc' => 'сардин',
        'scn' => 'сиҹилија',
        'sco' => 'скотс',
        'sd' => 'синдһи',
        'se' => 'шимали сами',
        'seh' => 'сена',
        'ses' => 'којраборо сенни',
        'sg' => 'санго',
        'shi' => 'тачелит',
        'shn' => 'шан',
        'si' => 'синһала',
        'sk' => 'словак',
        'sl' => 'словен',
        'sm' => 'самоа',
        'sma' => 'ҹәнуби сами',
        'smj' => 'луле сами',
        'smn' => 'инари сами',
        'sms' => 'сколт сами',
        'sn' => 'шона',
        'snk' => 'сонинке',
        'so' => 'сомали',
        'sq' => 'албан',
        'sr' => 'серб',
        'srn' => 'сранан тонго',
        'ss' => 'свати',
        'ssy' => 'саһо',
        'st' => 'сесото',
        'su' => 'сундан',
        'suk' => 'сукума',
        'sv' => 'исвеч',
        'sw' => 'суаһили',
        'swb' => 'комор',
        'syr' => 'сурија',
        'ta' => 'тамил',
        'te' => 'телугу',
        'tem' => 'тимне',
        'teo' => 'тесо',
        'tet' => 'тетум',
        'tg' => 'таҹик',
        'th' => 'тај',
        'ti' => 'тигрин',
        'tig' => 'тигре',
        'tk' => 'түркмән',
        'tlh' => 'клингон',
        'tn' => 'свана',
        'to' => 'тонган',
        'tpi' => 'ток писин',
        'tr' => 'түрк',
        'trv' => 'тароко',
        'ts' => 'сонга',
        'tt' => 'татар',
        'tum' => 'тумбука',
        'tvl' => 'тувалу',
        'twq' => 'тасаваг',
        'ty' => 'тахити',
        'tyv' => 'тувинјан',
        'tzm' => 'Мәркәзи Атлас тамазиҹәси',
        'udm' => 'удмурт',
        'ug' => 'ујғур',
        'uk' => 'украјна',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'өзбәк',
        'vai' => 'ваи',
        've' => 'венда',
        'vi' => 'вјетнам',
        'vo' => 'волапүк',
        'vun' => 'вунјо',
        'wa' => 'валун',
        'wae' => 'валлес',
        'wal' => 'валамо',
        'war' => 'варај',
        'wo' => 'волоф',
        'xal' => 'калмык',
        'xh' => 'хоса',
        'xog' => 'сога',
        'yav' => 'јангбен',
        'ybb' => 'јемба',
        'yi' => 'идиш',
        'yo' => 'јоруба',
        'yue' => 'кантон',
        'zgh' => 'тамази',
        'zh' => 'чин',
        'zu' => 'зулу',
        'zun' => 'зуни',
        'zza' => 'заза',
    ],
    'LocalizedNames' => [
        'ar_001' => 'мүасир стандарт әрәб',
        'de_AT' => 'Австрија алманҹасы',
        'de_CH' => 'Исвечрә јүксәк алманҹасы',
        'en_AU' => 'Австралија инҝилисҹәси',
        'en_CA' => 'Канада инҝилисҹәси',
        'en_GB' => 'Британија инҝилисҹәси',
        'en_US' => 'Америка инҝилисҹәси',
        'es_419' => 'Латын Америкасы испанҹасы',
        'es_ES' => 'Кастилија испанҹасы',
        'es_MX' => 'Мексика испанҹасы',
        'fr_CA' => 'Канада франсызҹасы',
        'fr_CH' => 'Исвечрә франсызҹасы',
        'nds_NL' => 'ашағы саксон',
        'nl_BE' => 'фламанд',
        'pt_BR' => 'Бразилија португалҹасы',
        'pt_PT' => 'Португалија португалҹасы',
        'sw_CD' => 'Конго суаһилиҹәси',
        'zh_Hans' => 'садәләшмиш чин',
        'zh_Hant' => 'әнәнәви чин',
    ],
];
