<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abkhaz',
        'ace' => 'Aceh',
        'ach' => 'Acoli',
        'ada' => 'Adangme',
        'ady' => 'Adygei',
        'ae' => 'Avesta',
        'aeb' => 'Arab Tunisia',
        'af' => 'Afrikaans',
        'afh' => 'Afrihili',
        'agq' => 'Aghem',
        'ain' => 'Ainu',
        'ak' => 'Akan',
        'akk' => 'Akkadia',
        'akz' => 'Alabama',
        'ale' => 'Aleut',
        'alt' => 'Altai Selatan',
        'am' => 'Amharik',
        'an' => 'Aragon',
        'ang' => 'Inggris Kuno',
        'ann' => 'Obolo',
        'anp' => 'Angika',
        'ar' => 'Arab',
        'arc' => 'Aram',
        'arn' => 'Mapuche',
        'arp' => 'Arapaho',
        'arq' => 'Arab Aljazair',
        'ars' => 'Arab Najdi',
        'arw' => 'Arawak',
        'ary' => 'Arab Maroko',
        'arz' => 'Arab Mesir',
        'as' => 'Assam',
        'asa' => 'Asu',
        'ase' => 'Bahasa Isyarat Amerika',
        'ast' => 'Asturia',
        'atj' => 'Atikamekw',
        'av' => 'Avar',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Azerbaijani',
        'ba' => 'Bashkir',
        'bal' => 'Baluchi',
        'ban' => 'Bali',
        'bar' => 'Bavaria',
        'bas' => 'Basa',
        'bax' => 'Bamun',
        'bbc' => 'Batak Toba',
        'bbj' => 'Ghomala',
        'be' => 'Belarusia',
        'bej' => 'Beja',
        'bem' => 'Bemba',
        'bew' => 'Betawi',
        'bez' => 'Bena',
        'bfd' => 'Bafut',
        'bg' => 'Bulgaria',
        'bgn' => 'Balochi Barat',
        'bho' => 'Bhojpuri',
        'bi' => 'Bislama',
        'bik' => 'Bikol',
        'bin' => 'Bini',
        'bjn' => 'Banjar',
        'bkm' => 'Kom',
        'bla' => 'Siksika',
        'bm' => 'Bambara',
        'bn' => 'Bengali',
        'bo' => 'Tibet',
        'br' => 'Breton',
        'bra' => 'Braj',
        'brx' => 'Bodo',
        'bs' => 'Bosnia',
        'bss' => 'Akoose',
        'bua' => 'Buriat',
        'bug' => 'Bugis',
        'bum' => 'Bulu',
        'byn' => 'Blin',
        'byv' => 'Medumba',
        'ca' => 'Katalan',
        'cad' => 'Kado',
        'car' => 'Karibia',
        'cay' => 'Cayuga',
        'cch' => 'Atsam',
        'ccp' => 'Chakma',
        'ce' => 'Chechen',
        'ceb' => 'Cebuano',
        'cgg' => 'Kiga',
        'ch' => 'Chamorro',
        'chb' => 'Chibcha',
        'chg' => 'Chagatai',
        'chk' => 'Chuuke',
        'chm' => 'Mari',
        'chn' => 'Jargon Chinook',
        'cho' => 'Koktaw',
        'chp' => 'Chipewyan',
        'chr' => 'Cherokee',
        'chy' => 'Cheyenne',
        'ckb' => 'Kurdi Sorani',
        'clc' => 'Chilcotin',
        'co' => 'Korsika',
        'cop' => 'Koptik',
        'cr' => 'Kree',
        'crg' => 'Michif',
        'crh' => 'Tatar Krimea',
        'crj' => 'East Cree Selatan',
        'crk' => 'Cree Dataran',
        'crl' => 'East Cree Utara',
        'crm' => 'Moose Cree',
        'crr' => 'Carolina Algonquian',
        'crs' => 'Seselwa Kreol Prancis',
        'cs' => 'Cheska',
        'csb' => 'Kashubia',
        'csw' => 'Cree Rawa',
        'cu' => 'Bahasa Gereja Slavonia',
        'cv' => 'Chuvash',
        'cy' => 'Welsh',
        'da' => 'Dansk',
        'dak' => 'Dakota',
        'dar' => 'Dargwa',
        'dav' => 'Taita',
        'de' => 'Jerman',
        'del' => 'Delaware',
        'den' => 'Slave',
        'dgr' => 'Dogrib',
        'din' => 'Dinka',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Sorbia Hilir',
        'dua' => 'Duala',
        'dum' => 'Belanda Abad Pertengahan',
        'dv' => 'Divehi',
        'dyo' => 'Jola-Fonyi',
        'dyu' => 'Dyula',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embu',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'egy' => 'Mesir Kuno',
        'eka' => 'Ekajuk',
        'el' => 'Yunani',
        'elx' => 'Elam',
        'en' => 'Inggris',
        'enm' => 'Inggris Abad Pertengahan',
        'eo' => 'Esperanto',
        'es' => 'Spanyol',
        'et' => 'Esti',
        'eu' => 'Basque',
        'ewo' => 'Ewondo',
        'fa' => 'Persia',
        'fan' => 'Fang',
        'fat' => 'Fanti',
        'ff' => 'Fula',
        'fi' => 'Suomi',
        'fil' => 'Filipino',
        'fj' => 'Fiji',
        'fo' => 'Faroe',
        'fon' => 'Fon',
        'fr' => 'Prancis',
        'frc' => 'Prancis Cajun',
        'frm' => 'Prancis Abad Pertengahan',
        'fro' => 'Prancis Kuno',
        'frp' => 'Arpitan',
        'frr' => 'Frisia Utara',
        'frs' => 'Frisia Timur',
        'fur' => 'Friuli',
        'fy' => 'Frisia Barat',
        'ga' => 'Irlandia',
        'gaa' => 'Ga',
        'gag' => 'Gagauz',
        'gay' => 'Gayo',
        'gba' => 'Gbaya',
        'gd' => 'Gaelik Skotlandia',
        'gez' => 'Geez',
        'gil' => 'Gilbert',
        'gl' => 'Galisia',
        'glk' => 'Gilaki',
        'gmh' => 'Jerman Abad Pertengahan',
        'gn' => 'Guarani',
        'goh' => 'Jerman Kuno',
        'gon' => 'Gondi',
        'gor' => 'Gorontalo',
        'got' => 'Gotik',
        'grb' => 'Grebo',
        'grc' => 'Yunani Kuno',
        'gsw' => 'Jerman (Swiss)',
        'gu' => 'Gujarat',
        'guz' => 'Gusii',
        'gv' => 'Manx',
        'gwi' => 'Gwich’in',
        'ha' => 'Hausa',
        'hai' => 'Haida',
        'haw' => 'Hawaii',
        'hax' => 'Haida Selatan',
        'he' => 'Ibrani',
        'hi' => 'Hindi',
        'hif' => 'Hindi Fiji',
        'hil' => 'Hiligaynon',
        'hit' => 'Hitit',
        'hmn' => 'Hmong',
        'ho' => 'Hiri Motu',
        'hr' => 'Kroasia',
        'hsb' => 'Sorbia Hulu',
        'ht' => 'Kreol Haiti',
        'hu' => 'Hungaria',
        'hup' => 'Hupa',
        'hur' => 'Halkomelem',
        'hy' => 'Armenia',
        'hz' => 'Herero',
        'ia' => 'Interlingua',
        'iba' => 'Iban',
        'ibb' => 'Ibibio',
        'id' => 'Indonesia',
        'ie' => 'Interlingue',
        'ig' => 'Igbo',
        'ii' => 'Sichuan Yi',
        'ik' => 'Inupiak',
        'ikt' => 'Inuktitut Kanada Barat',
        'ilo' => 'Iloko',
        'inh' => 'Ingushetia',
        'io' => 'Ido',
        'is' => 'Islandia',
        'it' => 'Italia',
        'iu' => 'Inuktitut',
        'ja' => 'Jepang',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jpr' => 'Ibrani-Persia',
        'jrb' => 'Ibrani-Arab',
        'jv' => 'Jawa',
        'ka' => 'Georgia',
        'kaa' => 'Kara-Kalpak',
        'kab' => 'Kabyle',
        'kac' => 'Kachin',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kaw' => 'Kawi',
        'kbd' => 'Kabardi',
        'kbl' => 'Kanembu',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kabuverdianu',
        'ken' => 'Kenyang',
        'kfo' => 'Koro',
        'kg' => 'Kongo',
        'kgp' => 'Kaingang',
        'kha' => 'Khasi',
        'kho' => 'Khotan',
        'khq' => 'Koyra Chiini',
        'ki' => 'Kikuyu',
        'kj' => 'Kuanyama',
        'kk' => 'Kazakh',
        'kkj' => 'Kako',
        'kl' => 'Kalaallisut',
        'kln' => 'Kalenjin',
        'km' => 'Khmer',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada',
        'ko' => 'Korea',
        'koi' => 'Komi-Permyak',
        'kok' => 'Konkani',
        'kos' => 'Kosre',
        'kpe' => 'Kpelle',
        'kr' => 'Kanuri',
        'krc' => 'Karachai Balkar',
        'kri' => 'Krio',
        'krl' => 'Karelia',
        'kru' => 'Kuruk',
        'ks' => 'Kashmir',
        'ksb' => 'Shambala',
        'ksf' => 'Bafia',
        'ksh' => 'Dialek Kolsch',
        'ku' => 'Kurdi',
        'kum' => 'Kumyk',
        'kut' => 'Kutenai',
        'kv' => 'Komi',
        'kw' => 'Kornish',
        'kwk' => 'Kwakʼwala',
        'ky' => 'Kirgiz',
        'la' => 'Latin',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lah' => 'Lahnda',
        'lam' => 'Lamba',
        'lb' => 'Luksemburg',
        'lez' => 'Lezghia',
        'lg' => 'Ganda',
        'li' => 'Limburgia',
        'lij' => 'Liguria',
        'lil' => 'Lillooet',
        'lkt' => 'Lakota',
        'ln' => 'Lingala',
        'lo' => 'Lao',
        'lol' => 'Mongo',
        'lou' => 'Kreol Louisiana',
        'loz' => 'Lozi',
        'lrc' => 'Luri Utara',
        'lsm' => 'Saamia',
        'lt' => 'Lituavi',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lui' => 'Luiseno',
        'lun' => 'Lunda',
        'luo' => 'Luo',
        'lus' => 'Mizo',
        'luy' => 'Luyia',
        'lv' => 'Latvi',
        'lzz' => 'Laz',
        'mad' => 'Madura',
        'maf' => 'Mafa',
        'mag' => 'Magahi',
        'mai' => 'Maithili',
        'mak' => 'Makasar',
        'man' => 'Mandingo',
        'mas' => 'Masai',
        'mde' => 'Maba',
        'mdf' => 'Moksha',
        'mdr' => 'Mandar',
        'men' => 'Mende',
        'mer' => 'Meru',
        'mfe' => 'Morisien',
        'mg' => 'Malagasi',
        'mga' => 'Irlandia Abad Pertengahan',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marshall',
        'mi' => 'Maori',
        'mic' => 'Mikmak',
        'min' => 'Minangkabau',
        'mk' => 'Makedonia',
        'ml' => 'Malayalam',
        'mn' => 'Mongolia',
        'mnc' => 'Manchuria',
        'mni' => 'Manipuri',
        'moe' => 'Innu-aimun',
        'moh' => 'Mohawk',
        'mos' => 'Mossi',
        'mr' => 'Marathi',
        'ms' => 'Melayu',
        'mt' => 'Malta',
        'mua' => 'Mundang',
        'mus' => 'Bahasa Muskogee',
        'mwl' => 'Miranda',
        'mwr' => 'Marwari',
        'mwv' => 'Mentawai',
        'my' => 'Burma',
        'mye' => 'Myene',
        'myv' => 'Eryza',
        'mzn' => 'Mazanderani',
        'na' => 'Nauru',
        'nap' => 'Neapolitan',
        'naq' => 'Nama',
        'nb' => 'Bokmål Norwegia',
        'nd' => 'Ndebele Utara',
        'nds' => 'Jerman Rendah',
        'ne' => 'Nepali',
        'new' => 'Newari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niuea',
        'nl' => 'Belanda',
        'nmg' => 'Kwasio',
        'nn' => 'Nynorsk Norwegia',
        'nnh' => 'Ngiemboon',
        'no' => 'Norwegia',
        'nog' => 'Nogai',
        'non' => 'Norse Kuno',
        'nqo' => 'N’Ko',
        'nr' => 'Ndebele Selatan',
        'nso' => 'Sotho Utara',
        'nus' => 'Nuer',
        'nv' => 'Navajo',
        'nwc' => 'Newari Klasik',
        'ny' => 'Nyanja',
        'nym' => 'Nyamwezi',
        'nyn' => 'Nyankole',
        'nyo' => 'Nyoro',
        'nzi' => 'Nzima',
        'oc' => 'Ositania',
        'oj' => 'Ojibwa',
        'ojb' => 'Ojibwe Barat Laut',
        'ojc' => 'Ojibwe Tengah',
        'ojs' => 'Oji-Cree',
        'ojw' => 'Ojibwe Barat',
        'oka' => 'Okanagan',
        'om' => 'Oromo',
        'or' => 'Oriya',
        'os' => 'Ossetia',
        'osa' => 'Osage',
        'ota' => 'Turki Osmani',
        'pa' => 'Punjabi',
        'pag' => 'Pangasina',
        'pal' => 'Pahlevi',
        'pam' => 'Pampanga',
        'pap' => 'Papiamento',
        'pau' => 'Palau',
        'pcm' => 'Pidgin Nigeria',
        'pdc' => 'Jerman Pennsylvania',
        'peo' => 'Persia Kuno',
        'phn' => 'Funisia',
        'pi' => 'Pali',
        'pis' => 'Pijin',
        'pl' => 'Polski',
        'pon' => 'Pohnpeia',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'Prusia',
        'pro' => 'Provencal Lama',
        'ps' => 'Pashto',
        'pt' => 'Portugis',
        'qu' => 'Quechua',
        'quc' => 'Kʼicheʼ',
        'raj' => 'Rajasthani',
        'rap' => 'Rapanui',
        'rar' => 'Rarotonga',
        'rhg' => 'Rohingya',
        'rm' => 'Reto-Roman',
        'rn' => 'Rundi',
        'ro' => 'Rumania',
        'rof' => 'Rombo',
        'rom' => 'Romani',
        'rtm' => 'Rotuma',
        'ru' => 'Rusia',
        'rup' => 'Aromania',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sanskerta',
        'sad' => 'Sandawe',
        'sah' => 'Sakha',
        'sam' => 'Aram Samaria',
        'saq' => 'Samburu',
        'sas' => 'Sasak',
        'sat' => 'Santali',
        'sba' => 'Ngambai',
        'sbp' => 'Sangu',
        'sc' => 'Sardinia',
        'scn' => 'Sisilia',
        'sco' => 'Skotlandia',
        'sd' => 'Sindhi',
        'sdh' => 'Kurdi Selatan',
        'se' => 'Sami Utara',
        'see' => 'Seneca',
        'seh' => 'Sena',
        'sei' => 'Seri',
        'sel' => 'Selkup',
        'ses' => 'Koyraboro Senni',
        'sg' => 'Sango',
        'sga' => 'Irlandia Kuno',
        'sh' => 'Serbo-Kroasia',
        'shi' => 'Tachelhit',
        'shn' => 'Shan',
        'shu' => 'Arab Suwa',
        'si' => 'Sinhala',
        'sid' => 'Sidamo',
        'sk' => 'Slovak',
        'sl' => 'Sloven',
        'slh' => 'Lushootseed Selatan',
        'sli' => 'Silesia Rendah',
        'sly' => 'Selayar',
        'sm' => 'Samoa',
        'sma' => 'Sami Selatan',
        'smj' => 'Lule Sami',
        'smn' => 'Inari Sami',
        'sms' => 'Skolt Sami',
        'sn' => 'Shona',
        'snk' => 'Soninke',
        'so' => 'Somalia',
        'sog' => 'Sogdien',
        'sq' => 'Albania',
        'sr' => 'Serbia',
        'srn' => 'Sranan Tongo',
        'srr' => 'Serer',
        'ss' => 'Swati',
        'ssy' => 'Saho',
        'st' => 'Sotho Selatan',
        'str' => 'Salish Selat',
        'su' => 'Sunda',
        'suk' => 'Sukuma',
        'sus' => 'Susu',
        'sux' => 'Sumeria',
        'sv' => 'Swedia',
        'sw' => 'Swahili',
        'swb' => 'Komoria',
        'syc' => 'Suriah Klasik',
        'syr' => 'Suriah',
        'szl' => 'Silesia',
        'ta' => 'Tamil',
        'tce' => 'Tutchone Selatan',
        'tcy' => 'Tulu',
        'te' => 'Telugu',
        'tem' => 'Timne',
        'teo' => 'Teso',
        'ter' => 'Tereno',
        'tet' => 'Tetun',
        'tg' => 'Tajik',
        'tgx' => 'Tagish',
        'th' => 'Thai',
        'tht' => 'Tahltan',
        'ti' => 'Tigrinya',
        'tig' => 'Tigre',
        'tiv' => 'Tiv',
        'tk' => 'Turkmen',
        'tkl' => 'Tokelau',
        'tl' => 'Tagalog',
        'tlh' => 'Klingon',
        'tli' => 'Tlingit',
        'tmh' => 'Tamashek',
        'tn' => 'Tswana',
        'to' => 'Tonga',
        'tog' => 'Nyasa Tonga',
        'tok' => 'Toki Pona',
        'tpi' => 'Tok Pisin',
        'tr' => 'Turki',
        'tru' => 'Turoyo',
        'trv' => 'Taroko',
        'ts' => 'Tsonga',
        'tsi' => 'Tsimshia',
        'tt' => 'Tatar',
        'ttm' => 'Tutchone Utara',
        'ttt' => 'Tat Muslim',
        'tum' => 'Tumbuka',
        'tvl' => 'Tuvalu',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahiti',
        'tyv' => 'Tuvinia',
        'tzm' => 'Tamazight Maroko Tengah',
        'udm' => 'Udmurt',
        'ug' => 'Uyghur',
        'uga' => 'Ugarit',
        'uk' => 'Ukraina',
        'umb' => 'Umbundu',
        'ur' => 'Urdu',
        'uz' => 'Uzbek',
        'vai' => 'Vai',
        've' => 'Venda',
        'vec' => 'Venesia',
        'vi' => 'Vietnam',
        'vo' => 'Volapuk',
        'vot' => 'Votia',
        'vun' => 'Vunjo',
        'wa' => 'Walloon',
        'wae' => 'Walser',
        'wal' => 'Walamo',
        'war' => 'Warai',
        'was' => 'Washo',
        'wbp' => 'Warlpiri',
        'wo' => 'Wolof',
        'wuu' => 'Wu Tionghoa',
        'xal' => 'Kalmuk',
        'xh' => 'Xhosa',
        'xog' => 'Soga',
        'yao' => 'Yao',
        'yap' => 'Yapois',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Yiddish',
        'yo' => 'Yoruba',
        'yrl' => 'Nheengatu',
        'yue' => 'Kanton',
        'za' => 'Zhuang',
        'zap' => 'Zapotek',
        'zbl' => 'Blissymbol',
        'zen' => 'Zenaga',
        'zgh' => 'Tamazight Maroko Standar',
        'zh' => 'Tionghoa',
        'zu' => 'Zulu',
        'zun' => 'Zuni',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Arab Standar Modern',
        'de_CH' => 'Jerman Tinggi (Swiss)',
        'en_GB' => 'Inggris (Britania)',
        'es_ES' => 'Spanyol (Eropa)',
        'fa_AF' => 'Persia Dari',
        'pt_PT' => 'Portugis (Eropa)',
        'ro_MD' => 'Moldavia',
        'sw_CD' => 'Swahili (Kongo)',
    ],
];
