<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'hora do meridiano de Greenwich (Abidjan)',
        'Africa/Accra' => 'hora do meridiano de Greenwich (Acra)',
        'Africa/Addis_Ababa' => 'hora de África Oriental (Adís Abeba)',
        'Africa/Algiers' => 'hora de Europa Central (Alxer)',
        'Africa/Asmera' => 'hora de África Oriental (Asmara)',
        'Africa/Bamako' => 'hora do meridiano de Greenwich (Bamaco)',
        'Africa/Bangui' => 'hora de África Occidental (Bangui)',
        'Africa/Banjul' => 'hora do meridiano de Greenwich (Banjul)',
        'Africa/Bissau' => 'hora do meridiano de Greenwich (Bissau)',
        'Africa/Blantyre' => 'hora de África Central (Blantyre)',
        'Africa/Brazzaville' => 'hora de África Occidental (Brazzaville)',
        'Africa/Bujumbura' => 'hora de África Central (Bujumbura)',
        'Africa/Cairo' => 'hora de Europa Oriental (O Cairo)',
        'Africa/Casablanca' => 'hora de Europa Occidental (Casablanca)',
        'Africa/Ceuta' => 'hora de Europa Central (Ceuta)',
        'Africa/Conakry' => 'hora do meridiano de Greenwich (Conakry)',
        'Africa/Dakar' => 'hora do meridiano de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'hora de África Oriental (Dar es Salaam)',
        'Africa/Djibouti' => 'hora de África Oriental (Djibuti)',
        'Africa/Douala' => 'hora de África Occidental (Douala)',
        'Africa/El_Aaiun' => 'hora de Europa Occidental (O Aiún)',
        'Africa/Freetown' => 'hora do meridiano de Greenwich (Freetown)',
        'Africa/Gaborone' => 'hora de África Central (Gaborone)',
        'Africa/Harare' => 'hora de África Central (Harare)',
        'Africa/Johannesburg' => 'hora de África Meridional (Xohanesburgo)',
        'Africa/Juba' => 'hora de África Central (Juba)',
        'Africa/Kampala' => 'hora de África Oriental (Kampala)',
        'Africa/Khartoum' => 'hora de África Central (Khartún)',
        'Africa/Kigali' => 'hora de África Central (Kigali)',
        'Africa/Kinshasa' => 'hora de África Occidental (Kinshasa)',
        'Africa/Lagos' => 'hora de África Occidental (Lagos)',
        'Africa/Libreville' => 'hora de África Occidental (Libreville)',
        'Africa/Lome' => 'hora do meridiano de Greenwich (Lomé)',
        'Africa/Luanda' => 'hora de África Occidental (Luanda)',
        'Africa/Lubumbashi' => 'hora de África Central (Lubumbashi)',
        'Africa/Lusaka' => 'hora de África Central (Lusaca)',
        'Africa/Malabo' => 'hora de África Occidental (Malabo)',
        'Africa/Maputo' => 'hora de África Central (Maputo)',
        'Africa/Maseru' => 'hora de África Meridional (Maseru)',
        'Africa/Mbabane' => 'hora de África Meridional (Mbabane)',
        'Africa/Mogadishu' => 'hora de África Oriental (Mogadixo)',
        'Africa/Monrovia' => 'hora do meridiano de Greenwich (Monrovia)',
        'Africa/Nairobi' => 'hora de África Oriental (Nairobi)',
        'Africa/Ndjamena' => 'hora de África Occidental (N’Djamena)',
        'Africa/Niamey' => 'hora de África Occidental (Niamey)',
        'Africa/Nouakchott' => 'hora do meridiano de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'hora do meridiano de Greenwich (Uagadugu)',
        'Africa/Porto-Novo' => 'hora de África Occidental (Porto-Novo)',
        'Africa/Sao_Tome' => 'hora do meridiano de Greenwich (San Tomé)',
        'Africa/Tripoli' => 'hora de Europa Oriental (Trípoli)',
        'Africa/Tunis' => 'hora de Europa Central (Tunes)',
        'Africa/Windhoek' => 'hora de África Central (Windhoek)',
        'America/Adak' => 'hora de Hawai-illas Aleutianas (Adak)',
        'America/Anchorage' => 'hora de Alasca (Anchorage)',
        'America/Anguilla' => 'hora do Atlántico (Anguila)',
        'America/Antigua' => 'hora do Atlántico (Antigua)',
        'America/Araguaina' => 'hora de Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'hora da Arxentina (A Rioxa)',
        'America/Argentina/Rio_Gallegos' => 'hora da Arxentina (Río Gallegos)',
        'America/Argentina/Salta' => 'hora da Arxentina (Salta)',
        'America/Argentina/San_Juan' => 'hora da Arxentina (San Juan)',
        'America/Argentina/San_Luis' => 'hora da Arxentina (San Luis)',
        'America/Argentina/Tucuman' => 'hora da Arxentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'hora da Arxentina (Ushuaia)',
        'America/Aruba' => 'hora do Atlántico (Aruba)',
        'America/Asuncion' => 'hora do Paraguai (Asunción)',
        'America/Bahia' => 'hora de Brasilia (Baía)',
        'America/Bahia_Banderas' => 'hora central, Norteamérica (Bahía de Banderas)',
        'America/Barbados' => 'hora do Atlántico (Barbados)',
        'America/Belem' => 'hora de Brasilia (Belém)',
        'America/Belize' => 'hora central, Norteamérica (Belize)',
        'America/Blanc-Sablon' => 'hora do Atlántico (Blanc-Sablon)',
        'America/Boa_Vista' => 'hora do Amazonas (Boa Vista)',
        'America/Bogota' => 'hora de Colombia (Bogotá)',
        'America/Boise' => 'hora da montaña, América do Norte (Boise)',
        'America/Buenos_Aires' => 'hora da Arxentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'hora da montaña, América do Norte (Cambridge Bay)',
        'America/Campo_Grande' => 'hora do Amazonas (Campo Grande)',
        'America/Cancun' => 'hora do leste, América do Norte (Cancún)',
        'America/Caracas' => 'hora de Venezuela (Caracas)',
        'America/Catamarca' => 'hora da Arxentina (Catamarca)',
        'America/Cayenne' => 'hora da Güiana Francesa (Caiena)',
        'America/Cayman' => 'hora do leste, América do Norte (Illas Caimán)',
        'America/Chicago' => 'hora central, Norteamérica (Chicago)',
        'America/Chihuahua' => 'hora do Pacífico mexicano (Chihuahua)',
        'America/Coral_Harbour' => 'hora do leste, América do Norte (Atikokan)',
        'America/Cordoba' => 'hora da Arxentina (Córdoba)',
        'America/Costa_Rica' => 'hora central, Norteamérica (Costa Rica)',
        'America/Creston' => 'hora da montaña, América do Norte (Creston)',
        'America/Cuiaba' => 'hora do Amazonas (Cuiabá)',
        'America/Curacao' => 'hora do Atlántico (Curaçao)',
        'America/Danmarkshavn' => 'hora do meridiano de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'hora de Yukon (Dawson)',
        'America/Dawson_Creek' => 'hora da montaña, América do Norte (Dawson Creek)',
        'America/Denver' => 'hora da montaña, América do Norte (Denver)',
        'America/Detroit' => 'hora do leste, América do Norte (Detroit)',
        'America/Dominica' => 'hora do Atlántico (Dominica)',
        'America/Edmonton' => 'hora da montaña, América do Norte (Edmonton)',
        'America/Eirunepe' => 'hora de: O Brasil (Eirunepé)',
        'America/El_Salvador' => 'hora central, Norteamérica (O Salvador)',
        'America/Fort_Nelson' => 'hora da montaña, América do Norte (Fort Nelson)',
        'America/Fortaleza' => 'hora de Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'hora do Atlántico (Glace Bay)',
        'America/Godthab' => 'hora de Groenlandia Occidental (Nuuk)',
        'America/Goose_Bay' => 'hora do Atlántico (Goose Bay)',
        'America/Grand_Turk' => 'hora do leste, América do Norte (Grand Turk)',
        'America/Grenada' => 'hora do Atlántico (Granada)',
        'America/Guadeloupe' => 'hora do Atlántico (Guadalupe)',
        'America/Guatemala' => 'hora central, Norteamérica (Guatemala)',
        'America/Guayaquil' => 'hora de Ecuador (Guayaquil)',
        'America/Guyana' => 'hora da Güiana',
        'America/Halifax' => 'hora do Atlántico (Halifax)',
        'America/Havana' => 'hora de Cuba (A Habana)',
        'America/Hermosillo' => 'hora do Pacífico mexicano (Hermosillo)',
        'America/Indiana/Knox' => 'hora central, Norteamérica (Knox, Indiana)',
        'America/Indiana/Marengo' => 'hora do leste, América do Norte (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'hora do leste, América do Norte (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'hora central, Norteamérica (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'hora do leste, América do Norte (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'hora do leste, América do Norte (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'hora do leste, América do Norte (Winamac, Indiana)',
        'America/Indianapolis' => 'hora do leste, América do Norte (Indianápolis)',
        'America/Inuvik' => 'hora da montaña, América do Norte (Inuvik)',
        'America/Iqaluit' => 'hora do leste, América do Norte (Iqaluit)',
        'America/Jamaica' => 'hora do leste, América do Norte (Xamaica)',
        'America/Jujuy' => 'hora da Arxentina (Jujuy)',
        'America/Juneau' => 'hora de Alasca (Juneau)',
        'America/Kentucky/Monticello' => 'hora do leste, América do Norte (Monticello, Kentucky)',
        'America/Kralendijk' => 'hora do Atlántico (Kralendijk)',
        'America/La_Paz' => 'hora de Bolivia (A Paz)',
        'America/Lima' => 'hora do Perú (Lima)',
        'America/Los_Angeles' => 'hora do Pacífico, América do Norte (Os Ánxeles)',
        'America/Louisville' => 'hora do leste, América do Norte (Louisville)',
        'America/Lower_Princes' => 'hora do Atlántico (Lower Prince’s Quarter)',
        'America/Maceio' => 'hora de Brasilia (Maceió)',
        'America/Managua' => 'hora central, Norteamérica (Managua)',
        'America/Manaus' => 'hora do Amazonas (Manaus)',
        'America/Marigot' => 'hora do Atlántico (Marigot)',
        'America/Martinique' => 'hora do Atlántico (Martinica)',
        'America/Matamoros' => 'hora central, Norteamérica (Matamoros)',
        'America/Mazatlan' => 'hora do Pacífico mexicano (Mazatlán)',
        'America/Mendoza' => 'hora da Arxentina (Mendoza)',
        'America/Menominee' => 'hora central, Norteamérica (Menominee)',
        'America/Merida' => 'hora central, Norteamérica (Mérida)',
        'America/Metlakatla' => 'hora de Alasca (Metlakatla)',
        'America/Mexico_City' => 'hora central, Norteamérica (Cidade de México)',
        'America/Miquelon' => 'hora de Saint Pierre et Miquelon',
        'America/Moncton' => 'hora do Atlántico (Moncton)',
        'America/Monterrey' => 'hora central, Norteamérica (Monterrey)',
        'America/Montevideo' => 'hora do Uruguai (Montevideo)',
        'America/Montreal' => 'hora de: O Canadá (Montreal)',
        'America/Montserrat' => 'hora do Atlántico (Montserrat)',
        'America/Nassau' => 'hora do leste, América do Norte (Nassau)',
        'America/New_York' => 'hora do leste, América do Norte (Nova York)',
        'America/Nipigon' => 'hora do leste, América do Norte (Nipigon)',
        'America/Nome' => 'hora de Alasca (Nome)',
        'America/Noronha' => 'hora de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'hora central, Norteamérica (Beulah, Dacota do Norte)',
        'America/North_Dakota/Center' => 'hora central, Norteamérica (Center, Dacota do Norte)',
        'America/North_Dakota/New_Salem' => 'hora central, Norteamérica (New Salem, Dacota do Norte)',
        'America/Ojinaga' => 'hora da montaña, América do Norte (Ojinaga)',
        'America/Panama' => 'hora do leste, América do Norte (Panamá)',
        'America/Pangnirtung' => 'hora do leste, América do Norte (Pangnirtung)',
        'America/Paramaribo' => 'hora de Suriname (Paramaribo)',
        'America/Phoenix' => 'hora da montaña, América do Norte (Phoenix)',
        'America/Port-au-Prince' => 'hora do leste, América do Norte (Porto Príncipe)',
        'America/Port_of_Spain' => 'hora do Atlántico (Porto España)',
        'America/Porto_Velho' => 'hora do Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'hora do Atlántico (Porto Rico)',
        'America/Punta_Arenas' => 'hora de Chile (Punta Arenas)',
        'America/Rainy_River' => 'hora central, Norteamérica (Rainy River)',
        'America/Rankin_Inlet' => 'hora central, Norteamérica (Rankin Inlet)',
        'America/Recife' => 'hora de Brasilia (Recife)',
        'America/Regina' => 'hora central, Norteamérica (Regina)',
        'America/Resolute' => 'hora central, Norteamérica (Resolute)',
        'America/Rio_Branco' => 'hora de: O Brasil (Río Branco)',
        'America/Santa_Isabel' => 'hora do noroeste de México (Santa Isabel)',
        'America/Santarem' => 'hora de Brasilia (Santarém)',
        'America/Santiago' => 'hora de Chile (Santiago)',
        'America/Santo_Domingo' => 'hora do Atlántico (Santo Domingo)',
        'America/Sao_Paulo' => 'hora de Brasilia (São Paulo)',
        'America/Scoresbysund' => 'hora de Groenlandia Oriental (Ittoqqortoormiit)',
        'America/Sitka' => 'hora de Alasca (Sitka)',
        'America/St_Barthelemy' => 'hora do Atlántico (Saint Barthélemy)',
        'America/St_Johns' => 'hora de Terra Nova (Saint John’s)',
        'America/St_Kitts' => 'hora do Atlántico (Saint Kitts)',
        'America/St_Lucia' => 'hora do Atlántico (Santa Lucía)',
        'America/St_Thomas' => 'hora do Atlántico (Saint Thomas)',
        'America/St_Vincent' => 'hora do Atlántico (San Vicente)',
        'America/Swift_Current' => 'hora central, Norteamérica (Swift Current)',
        'America/Tegucigalpa' => 'hora central, Norteamérica (Tegucigalpa)',
        'America/Thule' => 'hora do Atlántico (Thule)',
        'America/Thunder_Bay' => 'hora do leste, América do Norte (Thunder Bay)',
        'America/Tijuana' => 'hora do Pacífico, América do Norte (Tijuana)',
        'America/Toronto' => 'hora do leste, América do Norte (Toronto)',
        'America/Tortola' => 'hora do Atlántico (Tórtola)',
        'America/Vancouver' => 'hora do Pacífico, América do Norte (Vancouver)',
        'America/Whitehorse' => 'hora de Yukon (Whitehorse)',
        'America/Winnipeg' => 'hora central, Norteamérica (Winnipeg)',
        'America/Yakutat' => 'hora de Alasca (Yakutat)',
        'America/Yellowknife' => 'hora da montaña, América do Norte (Yellowknife)',
        'Antarctica/Casey' => 'hora de: A Antártida (Casey)',
        'Antarctica/Davis' => 'hora de Davis',
        'Antarctica/DumontDUrville' => 'hora de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'hora de Australia Oriental (Macquarie)',
        'Antarctica/Mawson' => 'hora de Mawson',
        'Antarctica/McMurdo' => 'hora de Nova Zelandia (McMurdo)',
        'Antarctica/Palmer' => 'hora de Chile (Palmer)',
        'Antarctica/Rothera' => 'hora de Rothera',
        'Antarctica/Syowa' => 'hora de Syowa (Showa)',
        'Antarctica/Troll' => 'hora do meridiano de Greenwich (Troll)',
        'Antarctica/Vostok' => 'hora de Vostok',
        'Arctic/Longyearbyen' => 'hora de Europa Central (Longyearbyen)',
        'Asia/Aden' => 'hora árabe (Adén)',
        'Asia/Almaty' => 'hora de Kazakistán Oriental (Almati)',
        'Asia/Amman' => 'hora de Europa Oriental (Amán)',
        'Asia/Anadyr' => 'Horario de Anadir (Anadyr)',
        'Asia/Aqtau' => 'hora de Kazakistán Occidental (Aktau)',
        'Asia/Aqtobe' => 'hora de Kazakistán Occidental (Aktobe)',
        'Asia/Ashgabat' => 'hora de Turkmenistán (Achkhabad)',
        'Asia/Atyrau' => 'hora de Kazakistán Occidental (Atyrau)',
        'Asia/Baghdad' => 'hora árabe (Bagdad)',
        'Asia/Bahrain' => 'hora árabe (Bahrain)',
        'Asia/Baku' => 'hora de Acerbaixán (Bacú)',
        'Asia/Bangkok' => 'hora de Indochina (Bangkok)',
        'Asia/Barnaul' => 'hora de: Rusia (Barnaul)',
        'Asia/Beirut' => 'hora de Europa Oriental (Beirut)',
        'Asia/Bishkek' => 'hora de Kirguizistán (Bishkek)',
        'Asia/Brunei' => 'hora de Brunei Darussalam',
        'Asia/Calcutta' => 'hora da India (Calcuta)',
        'Asia/Chita' => 'hora de Iakutsk (Chitá)',
        'Asia/Choibalsan' => 'hora de Ulaanbaatar (Choibalsan)',
        'Asia/Colombo' => 'hora da India (Colombo)',
        'Asia/Damascus' => 'hora de Europa Oriental (Damasco)',
        'Asia/Dhaka' => 'hora de Bangladesh (Dhaka)',
        'Asia/Dili' => 'hora de Timor Leste (Dili)',
        'Asia/Dubai' => 'hora do Golfo (Dubai)',
        'Asia/Dushanbe' => 'hora de Taxiquistán (Dushanbe)',
        'Asia/Famagusta' => 'hora de Europa Oriental (Famagusta)',
        'Asia/Gaza' => 'hora de Europa Oriental (Gaza)',
        'Asia/Hebron' => 'hora de Europa Oriental (Hebrón)',
        'Asia/Hong_Kong' => 'hora de Hong Kong',
        'Asia/Hovd' => 'hora de Hovd',
        'Asia/Irkutsk' => 'hora de Irkutsk',
        'Asia/Jakarta' => 'hora de Indonesia Occidental (Iacarta)',
        'Asia/Jayapura' => 'hora de Indonesia Oriental (Jayapura)',
        'Asia/Jerusalem' => 'hora de Israel (Xerusalén)',
        'Asia/Kabul' => 'hora de Afganistán (Cabul)',
        'Asia/Kamchatka' => 'Horario de Petropávlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'hora de Paquistán (Karachi)',
        'Asia/Katmandu' => 'hora de Nepal (Katmandú)',
        'Asia/Khandyga' => 'hora de Iakutsk (Chandyga)',
        'Asia/Krasnoyarsk' => 'hora de Krasnoiarsk (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'hora de Malaisia (Kuala Lumpur)',
        'Asia/Kuching' => 'hora de Malaisia (Kuching)',
        'Asia/Kuwait' => 'hora árabe (Kuwait)',
        'Asia/Macau' => 'hora da China (Macau)',
        'Asia/Magadan' => 'hora de Magadan',
        'Asia/Makassar' => 'hora de Indonesia Central (Makassar)',
        'Asia/Manila' => 'hora de Filipinas (Manila)',
        'Asia/Muscat' => 'hora do Golfo (Mascate)',
        'Asia/Nicosia' => 'hora de Europa Oriental (Nicosia)',
        'Asia/Novokuznetsk' => 'hora de Krasnoiarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'hora de Novosibirsk',
        'Asia/Omsk' => 'hora de Omsk',
        'Asia/Oral' => 'hora de Kazakistán Occidental (Oral)',
        'Asia/Phnom_Penh' => 'hora de Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'hora de Indonesia Occidental (Pontianak)',
        'Asia/Pyongyang' => 'hora de Corea (Pyongyang)',
        'Asia/Qatar' => 'hora árabe (Qatar)',
        'Asia/Qostanay' => 'hora de Kazakistán Oriental (Qostanai)',
        'Asia/Qyzylorda' => 'hora de Kazakistán Occidental (Kyzylorda)',
        'Asia/Rangoon' => 'hora de Myanmar (Yangon)',
        'Asia/Riyadh' => 'hora árabe (Riad)',
        'Asia/Saigon' => 'hora de Indochina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'hora de Sakhalín',
        'Asia/Samarkand' => 'hora de Uzbekistán (Samarcanda)',
        'Asia/Seoul' => 'hora de Corea (Seúl)',
        'Asia/Shanghai' => 'hora da China (Shanghai)',
        'Asia/Singapore' => 'hora de Singapur',
        'Asia/Srednekolymsk' => 'hora de Magadan (Srednekolimsk)',
        'Asia/Taipei' => 'hora de Taipei',
        'Asia/Tashkent' => 'hora de Uzbekistán (Tashkent)',
        'Asia/Tbilisi' => 'hora de Xeorxia (Tbilisi)',
        'Asia/Tehran' => 'hora de Irán (Teherán)',
        'Asia/Thimphu' => 'hora de Bután (Thimphu)',
        'Asia/Tokyo' => 'hora do Xapón (Tokyo)',
        'Asia/Tomsk' => 'hora de: Rusia (Tomsk)',
        'Asia/Ulaanbaatar' => 'hora de Ulaanbaatar',
        'Asia/Urumqi' => 'hora de: A China (Ürümqi)',
        'Asia/Ust-Nera' => 'hora de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'hora de Indochina (Vientiane)',
        'Asia/Vladivostok' => 'hora de Vladivostok',
        'Asia/Yakutsk' => 'hora de Iakutsk',
        'Asia/Yekaterinburg' => 'hora de Ekaterimburgo (Ekaterinburgo)',
        'Asia/Yerevan' => 'hora de Armenia (Iereván)',
        'Atlantic/Azores' => 'hora dos Azores',
        'Atlantic/Bermuda' => 'hora do Atlántico (Illas Bermudas)',
        'Atlantic/Canary' => 'hora de Europa Occidental (Illas Canarias)',
        'Atlantic/Cape_Verde' => 'hora de Cabo Verde',
        'Atlantic/Faeroe' => 'hora de Europa Occidental (Feroe)',
        'Atlantic/Madeira' => 'hora de Europa Occidental (Madeira)',
        'Atlantic/Reykjavik' => 'hora do meridiano de Greenwich (Reiquiavik)',
        'Atlantic/South_Georgia' => 'hora de Xeorxia do Sur',
        'Atlantic/St_Helena' => 'hora do meridiano de Greenwich (Santa Helena)',
        'Atlantic/Stanley' => 'hora das Illas Malvinas (Stanley)',
        'Australia/Adelaide' => 'hora de Australia Central (Adelaida)',
        'Australia/Brisbane' => 'hora de Australia Oriental (Brisbane)',
        'Australia/Broken_Hill' => 'hora de Australia Central (Broken Hill)',
        'Australia/Currie' => 'hora de Australia Oriental (Currie)',
        'Australia/Darwin' => 'hora de Australia Central (Darwin)',
        'Australia/Eucla' => 'hora de Australia Occidental Central (Eucla)',
        'Australia/Hobart' => 'hora de Australia Oriental (Hobart)',
        'Australia/Lindeman' => 'hora de Australia Oriental (Lindeman)',
        'Australia/Lord_Howe' => 'hora de Lord Howe',
        'Australia/Melbourne' => 'hora de Australia Oriental (Melbourne)',
        'Australia/Perth' => 'hora de Australia Occidental (Perth)',
        'Australia/Sydney' => 'hora de Australia Oriental (Sidney)',
        'CST6CDT' => 'hora central, Norteamérica',
        'EST5EDT' => 'hora do leste, América do Norte',
        'Etc/GMT' => 'hora do meridiano de Greenwich',
        'Etc/UTC' => 'hora universal coordinada',
        'Europe/Amsterdam' => 'hora de Europa Central (Ámsterdam)',
        'Europe/Andorra' => 'hora de Europa Central (Andorra)',
        'Europe/Astrakhan' => 'hora de Moscova (Astrakán)',
        'Europe/Athens' => 'hora de Europa Oriental (Atenas)',
        'Europe/Belgrade' => 'hora de Europa Central (Belgrado)',
        'Europe/Berlin' => 'hora de Europa Central (Berlín)',
        'Europe/Bratislava' => 'hora de Europa Central (Bratislava)',
        'Europe/Brussels' => 'hora de Europa Central (Bruxelas)',
        'Europe/Bucharest' => 'hora de Europa Oriental (Bucarest)',
        'Europe/Budapest' => 'hora de Europa Central (Budapest)',
        'Europe/Busingen' => 'hora de Europa Central (Busingen)',
        'Europe/Chisinau' => 'hora de Europa Oriental (Chisinau)',
        'Europe/Copenhagen' => 'hora de Europa Central (Copenhague)',
        'Europe/Dublin' => 'hora do meridiano de Greenwich (Dublín)',
        'Europe/Gibraltar' => 'hora de Europa Central (Xibraltar)',
        'Europe/Guernsey' => 'hora do meridiano de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'hora de Europa Oriental (Helsinqui)',
        'Europe/Isle_of_Man' => 'hora do meridiano de Greenwich (Illa de Man)',
        'Europe/Istanbul' => 'hora de: Turquía (Istanbul)',
        'Europe/Jersey' => 'hora do meridiano de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'hora de Europa Oriental (Kaliningrado)',
        'Europe/Kiev' => 'hora de Europa Oriental (Kiev)',
        'Europe/Kirov' => 'hora de: Rusia (Kirov)',
        'Europe/Lisbon' => 'hora de Europa Occidental (Lisboa)',
        'Europe/Ljubljana' => 'hora de Europa Central (Liubliana)',
        'Europe/London' => 'hora do meridiano de Greenwich (Londres)',
        'Europe/Luxembourg' => 'hora de Europa Central (Luxemburgo)',
        'Europe/Madrid' => 'hora de Europa Central (Madrid)',
        'Europe/Malta' => 'hora de Europa Central (Malta)',
        'Europe/Mariehamn' => 'hora de Europa Oriental (Mariehamn)',
        'Europe/Minsk' => 'hora de Moscova (Minsk)',
        'Europe/Monaco' => 'hora de Europa Central (Mónaco)',
        'Europe/Moscow' => 'hora de Moscova',
        'Europe/Oslo' => 'hora de Europa Central (Oslo)',
        'Europe/Paris' => 'hora de Europa Central (París)',
        'Europe/Podgorica' => 'hora de Europa Central (Podgorica)',
        'Europe/Prague' => 'hora de Europa Central (Praga)',
        'Europe/Riga' => 'hora de Europa Oriental (Riga)',
        'Europe/Rome' => 'hora de Europa Central (Roma)',
        'Europe/Samara' => 'Horario de Samara',
        'Europe/San_Marino' => 'hora de Europa Central (San Marino)',
        'Europe/Sarajevo' => 'hora de Europa Central (Saraievo)',
        'Europe/Saratov' => 'hora de Moscova (Saratov)',
        'Europe/Simferopol' => 'hora de Moscova (Simferópol)',
        'Europe/Skopje' => 'hora de Europa Central (Skopje)',
        'Europe/Sofia' => 'hora de Europa Oriental (Sofía)',
        'Europe/Stockholm' => 'hora de Europa Central (Estocolmo)',
        'Europe/Tallinn' => 'hora de Europa Oriental (Tallinn)',
        'Europe/Tirane' => 'hora de Europa Central (Tirana)',
        'Europe/Ulyanovsk' => 'hora de Moscova (Ulianovsk)',
        'Europe/Uzhgorod' => 'hora de Europa Oriental (Uzghorod)',
        'Europe/Vaduz' => 'hora de Europa Central (Vaduz)',
        'Europe/Vatican' => 'hora de Europa Central (Vaticano)',
        'Europe/Vienna' => 'hora de Europa Central (Viena)',
        'Europe/Vilnius' => 'hora de Europa Oriental (Vilnius)',
        'Europe/Volgograd' => 'hora de Volgogrado',
        'Europe/Warsaw' => 'hora de Europa Central (Varsovia)',
        'Europe/Zagreb' => 'hora de Europa Central (Zagreb)',
        'Europe/Zaporozhye' => 'hora de Europa Oriental (Zaporizhia)',
        'Europe/Zurich' => 'hora de Europa Central (Zürich)',
        'Indian/Antananarivo' => 'hora de África Oriental (Antananarivo)',
        'Indian/Chagos' => 'hora do Océano Índico (Chagos)',
        'Indian/Christmas' => 'hora da Illa Christmas',
        'Indian/Cocos' => 'hora das Illas Cocos',
        'Indian/Comoro' => 'hora de África Oriental (Comores)',
        'Indian/Kerguelen' => 'hora das Terras Austrais e Antárticas Francesas (Kerguelen)',
        'Indian/Mahe' => 'hora das Seychelles (Mahé)',
        'Indian/Maldives' => 'hora das Maldivas',
        'Indian/Mauritius' => 'hora de Mauricio',
        'Indian/Mayotte' => 'hora de África Oriental (Mayotte)',
        'Indian/Reunion' => 'hora de Reunión',
        'MST7MDT' => 'hora da montaña, América do Norte',
        'PST8PDT' => 'hora do Pacífico, América do Norte',
        'Pacific/Apia' => 'hora de Apia',
        'Pacific/Auckland' => 'hora de Nova Zelandia (Auckland)',
        'Pacific/Bougainville' => 'hora de Papúa-Nova Guinea (Bougainville)',
        'Pacific/Chatham' => 'hora de Chatham',
        'Pacific/Easter' => 'hora da Illa de Pascua',
        'Pacific/Efate' => 'hora de Vanuatu (Efate)',
        'Pacific/Enderbury' => 'hora das Illas Fénix (Enderbury)',
        'Pacific/Fakaofo' => 'hora de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'hora de Fixi',
        'Pacific/Funafuti' => 'hora de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'hora das Galápagos (Illas Galápagos)',
        'Pacific/Gambier' => 'hora de Gambier',
        'Pacific/Guadalcanal' => 'hora das Illas Salomón (Guadalcanal)',
        'Pacific/Guam' => 'hora estándar chamorro (Guam)',
        'Pacific/Honolulu' => 'hora de Hawai-illas Aleutianas (Honolulú)',
        'Pacific/Johnston' => 'hora de Hawai-illas Aleutianas (Johnston)',
        'Pacific/Kiritimati' => 'hora das Illas da Liña (Kiritimati)',
        'Pacific/Kosrae' => 'hora de Kosrae',
        'Pacific/Kwajalein' => 'hora das Illas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'hora das Illas Marshall (Majuro)',
        'Pacific/Marquesas' => 'hora das Marquesas',
        'Pacific/Midway' => 'hora de Samoa (Midway)',
        'Pacific/Nauru' => 'hora de Nauru',
        'Pacific/Niue' => 'hora de Niue',
        'Pacific/Norfolk' => 'hora da Illa Norfolk',
        'Pacific/Noumea' => 'hora de Nova Caledonia (Noumea)',
        'Pacific/Pago_Pago' => 'hora de Samoa (Pago Pago)',
        'Pacific/Palau' => 'hora de Palau',
        'Pacific/Pitcairn' => 'hora de Pitcairn',
        'Pacific/Ponape' => 'hora de Pohnpei',
        'Pacific/Port_Moresby' => 'hora de Papúa-Nova Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'hora das Illas Cook (Rarotonga)',
        'Pacific/Saipan' => 'hora estándar chamorro (Saipan)',
        'Pacific/Tahiti' => 'hora de Tahití',
        'Pacific/Tarawa' => 'hora das Illas Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'hora de Tonga (Tongatapu)',
        'Pacific/Truk' => 'hora de Chuuk',
        'Pacific/Wake' => 'hora da Illa Wake',
        'Pacific/Wallis' => 'hora de Wallis e Futuna',
    ],
    'Meta' => [
    ],
];
