<?php

return [
    'Names' => [
        'aa' => '아파르어',
        'ab' => '압카즈어',
        'ace' => '아체어',
        'ach' => '아콜리어',
        'ada' => '아당메어',
        'ady' => '아디게어',
        'ae' => '아베스타어',
        'aeb' => '튀니지 아랍어',
        'af' => '아프리칸스어',
        'afh' => '아프리힐리어',
        'agq' => '아그햄어',
        'ain' => '아이누어',
        'ak' => '아칸어',
        'akk' => '아카드어',
        'ale' => '알류트어',
        'alt' => '남부 알타이어',
        'am' => '암하라어',
        'an' => '아라곤어',
        'ang' => '고대 영어',
        'ann' => '오볼로어',
        'anp' => '앙가어',
        'ar' => '아랍어',
        'arc' => '아람어',
        'arn' => '마푸둥군어',
        'arp' => '아라파호어',
        'arq' => '알제리 아랍어',
        'ars' => '아랍어(나즈디)',
        'arw' => '아라와크어',
        'ary' => '모로코 아랍어',
        'arz' => '이집트 아랍어',
        'as' => '아삼어',
        'asa' => '아수어',
        'ast' => '아스투리아어',
        'atj' => '아티카메쿠어',
        'av' => '아바릭어',
        'awa' => '아와히어',
        'ay' => '아이마라어',
        'az' => '아제르바이잔어',
        'ba' => '바슈키르어',
        'bal' => '발루치어',
        'ban' => '발리어',
        'bas' => '바사어',
        'bax' => '바문어',
        'bbj' => '고말라어',
        'be' => '벨라루스어',
        'bej' => '베자어',
        'bem' => '벰바어',
        'bez' => '베나어',
        'bfd' => '바푸트어',
        'bg' => '불가리아어',
        'bgn' => '서부 발로치어',
        'bho' => '호즈푸리어',
        'bi' => '비슬라마어',
        'bik' => '비콜어',
        'bin' => '비니어',
        'bkm' => '콤어',
        'bla' => '식시카어',
        'bm' => '밤바라어',
        'bn' => '벵골어',
        'bo' => '티베트어',
        'br' => '브르타뉴어',
        'bra' => '브라지어',
        'brh' => '브라후이어',
        'brx' => '보도어',
        'bs' => '보스니아어',
        'bss' => '아쿠즈어',
        'bua' => '부리아타',
        'bug' => '부기어',
        'bum' => '불루어',
        'byn' => '브린어',
        'byv' => '메둠바어',
        'ca' => '카탈로니아어',
        'cad' => '카도어',
        'car' => '카리브어',
        'cay' => '카유가어',
        'cch' => '앗삼어',
        'ccp' => '차크마어',
        'ce' => '체첸어',
        'ceb' => '세부아노어',
        'cgg' => '치가어',
        'ch' => '차모로어',
        'chb' => '치브차어',
        'chg' => '차가타이어',
        'chk' => '추크어',
        'chm' => '마리어',
        'chn' => '치누크 자곤',
        'cho' => '촉토어',
        'chp' => '치페우얀',
        'chr' => '체로키어',
        'chy' => '샤이엔어',
        'ckb' => '소라니 쿠르드어',
        'clc' => '칠코틴어',
        'co' => '코르시카어',
        'cop' => '콥트어',
        'cr' => '크리어',
        'crg' => '미치프어',
        'crh' => '크리민 터키어; 크리민 타타르어',
        'crj' => '남동부 크리어',
        'crk' => '평원 크리어',
        'crl' => '북동부 크리어',
        'crm' => '무스크리어',
        'crr' => '캐롤라이나 알곤킨어',
        'crs' => '세이셸 크리올 프랑스어',
        'cs' => '체코어',
        'csb' => '카슈비아어',
        'csw' => '습지 크리어',
        'cu' => '교회 슬라브어',
        'cv' => '추바시어',
        'cy' => '웨일스어',
        'da' => '덴마크어',
        'dak' => '다코타어',
        'dar' => '다르그와어',
        'dav' => '타이타어',
        'de' => '독일어',
        'del' => '델라웨어어',
        'den' => '슬라브어',
        'dgr' => '도그리브어',
        'din' => '딩카어',
        'dje' => '자르마어',
        'doi' => '도그리어',
        'dsb' => '저지 소르비아어',
        'dua' => '두알라어',
        'dum' => '중세 네덜란드어',
        'dv' => '디베히어',
        'dyo' => '졸라 포니어',
        'dyu' => '드율라어',
        'dz' => '종카어',
        'dzg' => '다장가어',
        'ebu' => '엠부어',
        'ee' => '에웨어',
        'efi' => '이픽어',
        'egy' => '고대 이집트어',
        'eka' => '이카죽어',
        'el' => '그리스어',
        'elx' => '엘람어',
        'en' => '영어',
        'enm' => '중세 영어',
        'eo' => '에스페란토어',
        'es' => '스페인어',
        'et' => '에스토니아어',
        'eu' => '바스크어',
        'ewo' => '이원도어',
        'fa' => '페르시아어',
        'fan' => '팡그어',
        'fat' => '판티어',
        'ff' => '풀라어',
        'fi' => '핀란드어',
        'fil' => '필리핀어',
        'fj' => '피지어',
        'fo' => '페로어',
        'fon' => '폰어',
        'fr' => '프랑스어',
        'frc' => '케이준 프랑스어',
        'frm' => '중세 프랑스어',
        'fro' => '고대 프랑스어',
        'frr' => '북부 프리지아어',
        'frs' => '동부 프리슬란드어',
        'fur' => '프리울리어',
        'fy' => '서부 프리지아어',
        'ga' => '아일랜드어',
        'gaa' => '가어',
        'gag' => '가가우스어',
        'gan' => '간어',
        'gay' => '가요어',
        'gba' => '그바야어',
        'gbz' => '조로아스터 다리어',
        'gd' => '스코틀랜드 게일어',
        'gez' => '게이즈어',
        'gil' => '키리바시어',
        'gl' => '갈리시아어',
        'glk' => '길라키어',
        'gmh' => '중세 고지 독일어',
        'gn' => '과라니어',
        'goh' => '고대 고지 독일어',
        'gom' => '고아 콘칸어',
        'gon' => '곤디어',
        'gor' => '고론탈로어',
        'got' => '고트어',
        'grb' => '게르보어',
        'grc' => '고대 그리스어',
        'gsw' => '독일어(스위스)',
        'gu' => '구자라트어',
        'guz' => '구시어',
        'gv' => '맹크스어',
        'gwi' => '그위친어',
        'ha' => '하우사어',
        'hai' => '하이다어',
        'hak' => '하카어',
        'haw' => '하와이어',
        'hax' => '남부 하이다어',
        'he' => '히브리어',
        'hi' => '힌디어',
        'hif' => '피지 힌디어',
        'hil' => '헤리가뇬어',
        'hit' => '하타이트어',
        'hmn' => '히몸어',
        'ho' => '히리 모투어',
        'hr' => '크로아티아어',
        'hsb' => '고지 소르비아어',
        'hsn' => '샹어',
        'ht' => '아이티어',
        'hu' => '헝가리어',
        'hup' => '후파어',
        'hur' => '할코멜렘어',
        'hy' => '아르메니아어',
        'hz' => '헤레로어',
        'ia' => '인터링구아',
        'iba' => '이반어',
        'ibb' => '이비비오어',
        'id' => '인도네시아어',
        'ie' => '인테르링구에',
        'ig' => '이그보어',
        'ii' => '쓰촨 이어',
        'ik' => '이누피아크어',
        'ikt' => '캐나다 서부 이누크티투트어',
        'ilo' => '이로코어',
        'inh' => '인귀시어',
        'io' => '이도어',
        'is' => '아이슬란드어',
        'it' => '이탈리아어',
        'iu' => '이눅티투트어',
        'ja' => '일본어',
        'jbo' => '로반어',
        'jgo' => '응곰바어',
        'jmc' => '마차메어',
        'jpr' => '유대-페르시아어',
        'jrb' => '유대-아라비아어',
        'jv' => '자바어',
        'ka' => '조지아어',
        'kaa' => '카라칼파크어',
        'kab' => '커바일어',
        'kac' => '카친어',
        'kaj' => '까꼬토끄어',
        'kam' => '캄바어',
        'kaw' => '카위어',
        'kbd' => '카바르디어',
        'kbl' => '카넴부어',
        'kcg' => '티얍어',
        'kde' => '마콘데어',
        'kea' => '크리올어',
        'kfo' => '코로어',
        'kg' => '콩고어',
        'kgp' => '카잉강어',
        'kha' => '카시어',
        'kho' => '호탄어',
        'khq' => '코이라 친니어',
        'khw' => '코와르어',
        'ki' => '키쿠유어',
        'kj' => '쿠안야마어',
        'kk' => '카자흐어',
        'kkj' => '카코어',
        'kl' => '그린란드어',
        'kln' => '칼렌진어',
        'km' => '크메르어',
        'kmb' => '킴분두어',
        'kn' => '칸나다어',
        'ko' => '한국어',
        'koi' => '코미페르먀크어',
        'kok' => '코카니어',
        'kos' => '코스라이엔어',
        'kpe' => '크펠레어',
        'kr' => '칸누리어',
        'krc' => '카라챠이-발카르어',
        'krl' => '카렐리야어',
        'kru' => '쿠르크어',
        'ks' => '카슈미르어',
        'ksb' => '샴발라어',
        'ksf' => '바피아어',
        'ksh' => '콜로그니안어',
        'ku' => '쿠르드어',
        'kum' => '쿠믹어',
        'kut' => '쿠테네어',
        'kv' => '코미어',
        'kw' => '콘월어',
        'kwk' => '곽왈라어',
        'ky' => '키르기스어',
        'la' => '라틴어',
        'lad' => '라디노어',
        'lag' => '랑기어',
        'lah' => '라한다어',
        'lam' => '람바어',
        'lb' => '룩셈부르크어',
        'lez' => '레즈기안어',
        'lfn' => '링구아 프랑카 노바',
        'lg' => '간다어',
        'li' => '림버거어',
        'lil' => '릴루엣어',
        'lkt' => '라코타어',
        'ln' => '링갈라어',
        'lo' => '라오어',
        'lol' => '몽고어',
        'lou' => '루이지애나 크리올어',
        'loz' => '로지어',
        'lrc' => '북부 루리어',
        'lsm' => '사미아어',
        'lt' => '리투아니아어',
        'lu' => '루바-카탄가어',
        'lua' => '루바-룰루아어',
        'lui' => '루이세노어',
        'lun' => '룬다어',
        'luo' => '루오어',
        'lus' => '루샤이어',
        'luy' => '루야어',
        'lv' => '라트비아어',
        'mad' => '마두라어',
        'maf' => '마파어',
        'mag' => '마가히어',
        'mai' => '마이틸리어',
        'mak' => '마카사어',
        'man' => '만딩고어',
        'mas' => '마사이어',
        'mde' => '마바어',
        'mdf' => '모크샤어',
        'mdr' => '만다르어',
        'men' => '멘데어',
        'mer' => '메루어',
        'mfe' => '모리스얀어',
        'mg' => '말라가시어',
        'mga' => '중세 아일랜드어',
        'mgh' => '마크후와-메토어',
        'mgo' => '메타어',
        'mh' => '마셜어',
        'mi' => '마오리어',
        'mic' => '미크맥어',
        'min' => '미낭카바우어',
        'mk' => '마케도니아어',
        'ml' => '말라얄람어',
        'mn' => '몽골어',
        'mnc' => '만주어',
        'mni' => '마니푸리어',
        'moe' => '이누아문',
        'moh' => '모호크어',
        'mos' => '모시어',
        'mr' => '마라티어',
        'mrj' => '서부 마리어',
        'ms' => '말레이어',
        'mt' => '몰타어',
        'mua' => '문당어',
        'mus' => '크리크어',
        'mwl' => '미란데어',
        'mwr' => '마르와리어',
        'my' => '버마어',
        'mye' => '미예네어',
        'myv' => '엘즈야어',
        'mzn' => '마잔데라니어',
        'na' => '나우루어',
        'nan' => '민난어',
        'nap' => '나폴리어',
        'naq' => '나마어',
        'nb' => '노르웨이어(보크말)',
        'nd' => '북부 은데벨레어',
        'nds' => '저지 독일어',
        'ne' => '네팔어',
        'new' => '네와르어',
        'ng' => '느동가어',
        'nia' => '니아스어',
        'niu' => '니웨언어',
        'nl' => '네덜란드어',
        'nmg' => '크와시오어',
        'nn' => '노르웨이어(니노르스크)',
        'nnh' => '느기엠본어',
        'no' => '노르웨이어',
        'nog' => '노가이어',
        'non' => '고대 노르웨이어',
        'nqo' => '응코어',
        'nr' => '남부 은데벨레어',
        'nso' => '북부 소토어',
        'nus' => '누에르어',
        'nv' => '나바호어',
        'nwc' => '고전 네와르어',
        'ny' => '냔자어',
        'nym' => '니암웨지어',
        'nyn' => '니안콜어',
        'nyo' => '뉴로어',
        'nzi' => '느지마어',
        'oc' => '오크어',
        'oj' => '오지브와어',
        'ojb' => '북서부 오지브와어',
        'ojc' => '중앙 오지브와어',
        'ojs' => '오지 크리어',
        'ojw' => '서부 오지브와어',
        'oka' => '오카나간어',
        'om' => '오로모어',
        'or' => '오리야어',
        'os' => '오세트어',
        'osa' => '오세이지어',
        'ota' => '오스만 터키어',
        'pa' => '펀잡어',
        'pag' => '판가시난어',
        'pal' => '팔레비어',
        'pam' => '팜팡가어',
        'pap' => '파피아먼토어',
        'pau' => '팔라우어',
        'pcm' => '나이지리아 피진어',
        'peo' => '고대 페르시아어',
        'phn' => '페니키아어',
        'pi' => '팔리어',
        'pis' => '피진어',
        'pl' => '폴란드어',
        'pnt' => '폰틱어',
        'pon' => '폼페이어',
        'pqm' => '말리시트 파사마쿼디어',
        'prg' => '프러시아어',
        'pro' => '고대 프로방스어',
        'ps' => '파슈토어',
        'pt' => '포르투갈어',
        'qu' => '케추아어',
        'quc' => '키체어',
        'raj' => '라자스탄어',
        'rap' => '라파뉴이',
        'rar' => '라로통가어',
        'rhg' => '로힝야어',
        'rm' => '로만시어',
        'rn' => '룬디어',
        'ro' => '루마니아어',
        'rof' => '롬보어',
        'rom' => '집시어',
        'ru' => '러시아어',
        'rue' => '루신어',
        'rup' => '아로마니아어',
        'rw' => '르완다어',
        'rwk' => '르와어',
        'sa' => '산스크리트어',
        'sad' => '산다웨어',
        'sah' => '야쿠트어',
        'sam' => '사마리아 아랍어',
        'saq' => '삼부루어',
        'sas' => '사사크어',
        'sat' => '산탈리어',
        'sba' => '느감바이어',
        'sbp' => '상구어',
        'sc' => '사르디니아어',
        'scn' => '시칠리아어',
        'sco' => '스코틀랜드어',
        'sd' => '신디어',
        'sdh' => '남부 쿠르드어',
        'se' => '북부 사미어',
        'see' => '세네카어',
        'seh' => '세나어',
        'sel' => '셀쿠프어',
        'ses' => '코이야보로 세니어',
        'sg' => '산고어',
        'sga' => '고대 아일랜드어',
        'sh' => '세르비아-크로아티아어',
        'shi' => '타셸히트어',
        'shn' => '샨어',
        'shu' => '차디언 아라비아어',
        'si' => '싱할라어',
        'sid' => '시다모어',
        'sk' => '슬로바키아어',
        'sl' => '슬로베니아어',
        'slh' => '남부 루슈트시드어',
        'sm' => '사모아어',
        'sma' => '남부 사미어',
        'smj' => '룰레 사미어',
        'smn' => '이나리 사미어',
        'sms' => '스콜트 사미어',
        'sn' => '쇼나어',
        'snk' => '소닌케어',
        'so' => '소말리아어',
        'sog' => '소그디엔어',
        'sq' => '알바니아어',
        'sr' => '세르비아어',
        'srn' => '스라난 통가어',
        'srr' => '세레르어',
        'ss' => '시스와티어',
        'ssy' => '사호어',
        'st' => '남부 소토어',
        'str' => '해안 살리시어',
        'su' => '순다어',
        'suk' => '수쿠마어',
        'sus' => '수수어',
        'sux' => '수메르어',
        'sv' => '스웨덴어',
        'sw' => '스와힐리어',
        'swb' => '코모로어',
        'syc' => '고전 시리아어',
        'syr' => '시리아어',
        'ta' => '타밀어',
        'tce' => '남부 투톤어',
        'te' => '텔루구어',
        'tem' => '팀니어',
        'teo' => '테조어',
        'ter' => '테레노어',
        'tet' => '테툼어',
        'tg' => '타지크어',
        'tgx' => '타기시어',
        'th' => '태국어',
        'tht' => '탈탄어',
        'ti' => '티그리냐어',
        'tig' => '티그레어',
        'tiv' => '티브어',
        'tk' => '투르크멘어',
        'tkl' => '토켈라우제도어',
        'tkr' => '차후르어',
        'tl' => '타갈로그어',
        'tlh' => '클링온어',
        'tli' => '틀링깃족어',
        'tly' => '탈리쉬어',
        'tmh' => '타마섹어',
        'tn' => '츠와나어',
        'to' => '통가어',
        'tog' => '니아사 통가어',
        'tok' => '도기 보나',
        'tpi' => '토크 피신어',
        'tr' => '터키어',
        'trv' => '타로코어',
        'ts' => '총가어',
        'tsi' => '트심시안어',
        'tt' => '타타르어',
        'ttm' => '북부 투톤어',
        'tum' => '툼부카어',
        'tvl' => '투발루어',
        'tw' => '트위어',
        'twq' => '타사와크어',
        'ty' => '타히티어',
        'tyv' => '투비니안어',
        'tzm' => '중앙 모로코 타마지트어',
        'udm' => '우드말트어',
        'ug' => '위구르어',
        'uga' => '유가리틱어',
        'uk' => '우크라이나어',
        'umb' => '움분두어',
        'ur' => '우르두어',
        'uz' => '우즈베크어',
        'vai' => '바이어',
        've' => '벤다어',
        'vi' => '베트남어',
        'vo' => '볼라퓌크어',
        'vot' => '보틱어',
        'vun' => '분조어',
        'wa' => '왈론어',
        'wae' => '월저어',
        'wal' => '월라이타어',
        'war' => '와라이어',
        'was' => '와쇼어',
        'wbp' => '왈피리어',
        'wo' => '월로프어',
        'wuu' => '우어',
        'xal' => '칼미크어',
        'xh' => '코사어',
        'xog' => '소가어',
        'yao' => '야오족어',
        'yap' => '얍페세어',
        'yav' => '양본어',
        'ybb' => '옘바어',
        'yi' => '이디시어',
        'yo' => '요루바어',
        'yrl' => '넨가투어',
        'yue' => '광둥어',
        'za' => '주앙어',
        'zap' => '사포테크어',
        'zbl' => '블리스 심볼',
        'zen' => '제나가어',
        'zgh' => '표준 모로코 타마지트어',
        'zh' => '중국어',
        'zu' => '줄루어',
        'zun' => '주니어',
        'zza' => '자자어',
    ],
    'LocalizedNames' => [
        'ar_001' => '현대 표준 아랍어',
        'de_CH' => '고지 독일어(스위스)',
        'es_ES' => '스페인어(유럽)',
        'fa_AF' => '다리어',
        'nds_NL' => '저지 색슨어',
        'nl_BE' => '플라망어',
        'pt_PT' => '포르투갈어(유럽)',
        'ro_MD' => '몰도바어',
        'sw_CD' => '콩고 스와힐리어',
    ],
];
