<?php

return [
    'Names' => [
        'BY' => 'Бјелорусија',
        'CG' => 'Конго',
        'CZ' => 'Чешка Република',
        'DE' => 'Њемачка',
        'KN' => 'Свети Китс и Невис',
        'PM' => 'Свети Пјер и Микелон',
        'RE' => 'Реунион',
        'UM' => 'Мања удаљена острва САД',
        'VC' => 'Свети Винсент и Гренадини',
        'VG' => 'Британска Дјевичанска Острва',
        'VI' => 'Америчка Дјевичанска Острва',
    ],
];
