<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dola laseArab',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kwanza yase Angola',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dola yase Australia',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinari yase Bhahareni',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Fulenki yase Bhurundi',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Phula yase Botswana',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dola yase Khanada',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Fulenki yase Khongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Fulenki yase Swisi',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan Renminbi yase China',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Escudo Caboverdiano',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Fulenki yase Jibhuthi',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinali yase Aljeriya',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Phawundi laseGibhide',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa yase Eritrea',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Dola laseEthiopia',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Yuro',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Phawundi yase Ngilandi',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Sedi yase Ghana',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi yase Gambia',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Fulenki yase Gine',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupi yase Indiya',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni yase Japhani',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shilingi yase Kenya',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Fulenki yase Khomoro',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dola yase Libheriya',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lothi yase Lesotho',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinari yase Libya',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirham yase Morokho',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Fulenki yase Malagasi',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugwiya yase Moritaniya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugwiya yase Moritaniya',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupi yase Morishasi',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kwacha yase Malawi',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metikali yase Mozambiki',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dola yase Namibiya',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nayira yase Nijeriya',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Fulenki yase Ruwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyal yase Saudi',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupi yase Seyisheli',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Dinari yase Sudani',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Phawundi yase Sudani',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Phawundindi laseSt Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leyoni',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shilingi yase Somaliya',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra yase Sao Tome lo Principe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra yase Sao Tome lo Principe',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinari yase Tunisiya',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shilingi yase Tanzaniya',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilingi yase Uganda',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dola yase Amelika',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Fulenki CFA BEAC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Fulenki CFA BCEAO',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randi yase Afrika ye Zanzi',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kwacha yase Zambiya (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kwacha yase Zambiya',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dola yase Zimbabwe',
        ],
    ],
];
