<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibie)',
        'af_ZA' => 'afrikaans (Afrique du Sud)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amharique',
        'am_ET' => 'amharique (Éthiopie)',
        'ar' => 'arabe',
        'ar_001' => 'arabe (Monde)',
        'ar_AE' => 'arabe (Émirats arabes unis)',
        'ar_BH' => 'arabe (Bahreïn)',
        'ar_DJ' => 'arabe (Djibouti)',
        'ar_DZ' => 'arabe (Algérie)',
        'ar_EG' => 'arabe (Égypte)',
        'ar_EH' => 'arabe (Sahara occidental)',
        'ar_ER' => 'arabe (Érythrée)',
        'ar_IL' => 'arabe (Israël)',
        'ar_IQ' => 'arabe (Irak)',
        'ar_JO' => 'arabe (Jordanie)',
        'ar_KM' => 'arabe (Comores)',
        'ar_KW' => 'arabe (Koweït)',
        'ar_LB' => 'arabe (Liban)',
        'ar_LY' => 'arabe (Libye)',
        'ar_MA' => 'arabe (Maroc)',
        'ar_MR' => 'arabe (Mauritanie)',
        'ar_OM' => 'arabe (Oman)',
        'ar_PS' => 'arabe (Territoires palestiniens)',
        'ar_QA' => 'arabe (Qatar)',
        'ar_SA' => 'arabe (Arabie saoudite)',
        'ar_SD' => 'arabe (Soudan)',
        'ar_SO' => 'arabe (Somalie)',
        'ar_SS' => 'arabe (Soudan du Sud)',
        'ar_SY' => 'arabe (Syrie)',
        'ar_TD' => 'arabe (Tchad)',
        'ar_TN' => 'arabe (Tunisie)',
        'ar_YE' => 'arabe (Yémen)',
        'as' => 'assamais',
        'as_IN' => 'assamais (Inde)',
        'az' => 'azerbaïdjanais',
        'az_AZ' => 'azerbaïdjanais (Azerbaïdjan)',
        'az_Cyrl' => 'azerbaïdjanais (cyrillique)',
        'az_Cyrl_AZ' => 'azerbaïdjanais (cyrillique, Azerbaïdjan)',
        'az_Latn' => 'azerbaïdjanais (latin)',
        'az_Latn_AZ' => 'azerbaïdjanais (latin, Azerbaïdjan)',
        'be' => 'biélorusse',
        'be_BY' => 'biélorusse (Biélorussie)',
        'bg' => 'bulgare',
        'bg_BG' => 'bulgare (Bulgarie)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengali',
        'bn_BD' => 'bengali (Bangladesh)',
        'bn_IN' => 'bengali (Inde)',
        'bo' => 'tibétain',
        'bo_CN' => 'tibétain (Chine)',
        'bo_IN' => 'tibétain (Inde)',
        'br' => 'breton',
        'br_FR' => 'breton (France)',
        'bs' => 'bosniaque',
        'bs_BA' => 'bosniaque (Bosnie-Herzégovine)',
        'bs_Cyrl' => 'bosniaque (cyrillique)',
        'bs_Cyrl_BA' => 'bosniaque (cyrillique, Bosnie-Herzégovine)',
        'bs_Latn' => 'bosniaque (latin)',
        'bs_Latn_BA' => 'bosniaque (latin, Bosnie-Herzégovine)',
        'ca' => 'catalan',
        'ca_AD' => 'catalan (Andorre)',
        'ca_ES' => 'catalan (Espagne)',
        'ca_FR' => 'catalan (France)',
        'ca_IT' => 'catalan (Italie)',
        'ce' => 'tchétchène',
        'ce_RU' => 'tchétchène (Russie)',
        'cs' => 'tchèque',
        'cs_CZ' => 'tchèque (Tchéquie)',
        'cv' => 'tchouvache',
        'cv_RU' => 'tchouvache (Russie)',
        'cy' => 'gallois',
        'cy_GB' => 'gallois (Royaume-Uni)',
        'da' => 'danois',
        'da_DK' => 'danois (Danemark)',
        'da_GL' => 'danois (Groenland)',
        'de' => 'allemand',
        'de_AT' => 'allemand (Autriche)',
        'de_BE' => 'allemand (Belgique)',
        'de_CH' => 'allemand (Suisse)',
        'de_DE' => 'allemand (Allemagne)',
        'de_IT' => 'allemand (Italie)',
        'de_LI' => 'allemand (Liechtenstein)',
        'de_LU' => 'allemand (Luxembourg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhoutan)',
        'ee' => 'éwé',
        'ee_GH' => 'éwé (Ghana)',
        'ee_TG' => 'éwé (Togo)',
        'el' => 'grec',
        'el_CY' => 'grec (Chypre)',
        'el_GR' => 'grec (Grèce)',
        'en' => 'anglais',
        'en_001' => 'anglais (Monde)',
        'en_150' => 'anglais (Europe)',
        'en_AE' => 'anglais (Émirats arabes unis)',
        'en_AG' => 'anglais (Antigua-et-Barbuda)',
        'en_AI' => 'anglais (Anguilla)',
        'en_AS' => 'anglais (Samoa américaines)',
        'en_AT' => 'anglais (Autriche)',
        'en_AU' => 'anglais (Australie)',
        'en_BB' => 'anglais (Barbade)',
        'en_BE' => 'anglais (Belgique)',
        'en_BI' => 'anglais (Burundi)',
        'en_BM' => 'anglais (Bermudes)',
        'en_BS' => 'anglais (Bahamas)',
        'en_BW' => 'anglais (Botswana)',
        'en_BZ' => 'anglais (Belize)',
        'en_CA' => 'anglais (Canada)',
        'en_CC' => 'anglais (Îles Cocos)',
        'en_CH' => 'anglais (Suisse)',
        'en_CK' => 'anglais (Îles Cook)',
        'en_CM' => 'anglais (Cameroun)',
        'en_CX' => 'anglais (Île Christmas)',
        'en_CY' => 'anglais (Chypre)',
        'en_DE' => 'anglais (Allemagne)',
        'en_DK' => 'anglais (Danemark)',
        'en_DM' => 'anglais (Dominique)',
        'en_ER' => 'anglais (Érythrée)',
        'en_FI' => 'anglais (Finlande)',
        'en_FJ' => 'anglais (Fidji)',
        'en_FK' => 'anglais (Îles Malouines)',
        'en_FM' => 'anglais (Micronésie)',
        'en_GB' => 'anglais (Royaume-Uni)',
        'en_GD' => 'anglais (Grenade)',
        'en_GG' => 'anglais (Guernesey)',
        'en_GH' => 'anglais (Ghana)',
        'en_GI' => 'anglais (Gibraltar)',
        'en_GM' => 'anglais (Gambie)',
        'en_GU' => 'anglais (Guam)',
        'en_GY' => 'anglais (Guyana)',
        'en_HK' => 'anglais (R.A.S. chinoise de Hong Kong)',
        'en_IE' => 'anglais (Irlande)',
        'en_IL' => 'anglais (Israël)',
        'en_IM' => 'anglais (Île de Man)',
        'en_IN' => 'anglais (Inde)',
        'en_IO' => 'anglais (Territoire britannique de l’océan Indien)',
        'en_JE' => 'anglais (Jersey)',
        'en_JM' => 'anglais (Jamaïque)',
        'en_KE' => 'anglais (Kenya)',
        'en_KI' => 'anglais (Kiribati)',
        'en_KN' => 'anglais (Saint-Christophe-et-Niévès)',
        'en_KY' => 'anglais (Îles Caïmans)',
        'en_LC' => 'anglais (Sainte-Lucie)',
        'en_LR' => 'anglais (Liberia)',
        'en_LS' => 'anglais (Lesotho)',
        'en_MG' => 'anglais (Madagascar)',
        'en_MH' => 'anglais (Îles Marshall)',
        'en_MO' => 'anglais (R.A.S. chinoise de Macao)',
        'en_MP' => 'anglais (Îles Mariannes du Nord)',
        'en_MS' => 'anglais (Montserrat)',
        'en_MT' => 'anglais (Malte)',
        'en_MU' => 'anglais (Maurice)',
        'en_MV' => 'anglais (Maldives)',
        'en_MW' => 'anglais (Malawi)',
        'en_MY' => 'anglais (Malaisie)',
        'en_NA' => 'anglais (Namibie)',
        'en_NF' => 'anglais (Île Norfolk)',
        'en_NG' => 'anglais (Nigeria)',
        'en_NL' => 'anglais (Pays-Bas)',
        'en_NR' => 'anglais (Nauru)',
        'en_NU' => 'anglais (Niue)',
        'en_NZ' => 'anglais (Nouvelle-Zélande)',
        'en_PG' => 'anglais (Papouasie-Nouvelle-Guinée)',
        'en_PH' => 'anglais (Philippines)',
        'en_PK' => 'anglais (Pakistan)',
        'en_PN' => 'anglais (Îles Pitcairn)',
        'en_PR' => 'anglais (Porto Rico)',
        'en_PW' => 'anglais (Palaos)',
        'en_RW' => 'anglais (Rwanda)',
        'en_SB' => 'anglais (Îles Salomon)',
        'en_SC' => 'anglais (Seychelles)',
        'en_SD' => 'anglais (Soudan)',
        'en_SE' => 'anglais (Suède)',
        'en_SG' => 'anglais (Singapour)',
        'en_SH' => 'anglais (Sainte-Hélène)',
        'en_SI' => 'anglais (Slovénie)',
        'en_SL' => 'anglais (Sierra Leone)',
        'en_SS' => 'anglais (Soudan du Sud)',
        'en_SX' => 'anglais (Saint-Martin [partie néerlandaise])',
        'en_SZ' => 'anglais (Eswatini)',
        'en_TC' => 'anglais (Îles Turques-et-Caïques)',
        'en_TK' => 'anglais (Tokelau)',
        'en_TO' => 'anglais (Tonga)',
        'en_TT' => 'anglais (Trinité-et-Tobago)',
        'en_TV' => 'anglais (Tuvalu)',
        'en_TZ' => 'anglais (Tanzanie)',
        'en_UG' => 'anglais (Ouganda)',
        'en_UM' => 'anglais (Îles mineures éloignées des États-Unis)',
        'en_US' => 'anglais (États-Unis)',
        'en_VC' => 'anglais (Saint-Vincent-et-les Grenadines)',
        'en_VG' => 'anglais (Îles Vierges britanniques)',
        'en_VI' => 'anglais (Îles Vierges des États-Unis)',
        'en_VU' => 'anglais (Vanuatu)',
        'en_WS' => 'anglais (Samoa)',
        'en_ZA' => 'anglais (Afrique du Sud)',
        'en_ZM' => 'anglais (Zambie)',
        'en_ZW' => 'anglais (Zimbabwe)',
        'eo' => 'espéranto',
        'eo_001' => 'espéranto (Monde)',
        'es' => 'espagnol',
        'es_419' => 'espagnol (Amérique latine)',
        'es_AR' => 'espagnol (Argentine)',
        'es_BO' => 'espagnol (Bolivie)',
        'es_BR' => 'espagnol (Brésil)',
        'es_BZ' => 'espagnol (Belize)',
        'es_CL' => 'espagnol (Chili)',
        'es_CO' => 'espagnol (Colombie)',
        'es_CR' => 'espagnol (Costa Rica)',
        'es_CU' => 'espagnol (Cuba)',
        'es_DO' => 'espagnol (République dominicaine)',
        'es_EC' => 'espagnol (Équateur)',
        'es_ES' => 'espagnol (Espagne)',
        'es_GQ' => 'espagnol (Guinée équatoriale)',
        'es_GT' => 'espagnol (Guatemala)',
        'es_HN' => 'espagnol (Honduras)',
        'es_MX' => 'espagnol (Mexique)',
        'es_NI' => 'espagnol (Nicaragua)',
        'es_PA' => 'espagnol (Panama)',
        'es_PE' => 'espagnol (Pérou)',
        'es_PH' => 'espagnol (Philippines)',
        'es_PR' => 'espagnol (Porto Rico)',
        'es_PY' => 'espagnol (Paraguay)',
        'es_SV' => 'espagnol (Salvador)',
        'es_US' => 'espagnol (États-Unis)',
        'es_UY' => 'espagnol (Uruguay)',
        'es_VE' => 'espagnol (Venezuela)',
        'et' => 'estonien',
        'et_EE' => 'estonien (Estonie)',
        'eu' => 'basque',
        'eu_ES' => 'basque (Espagne)',
        'fa' => 'persan',
        'fa_AF' => 'persan (Afghanistan)',
        'fa_IR' => 'persan (Iran)',
        'ff' => 'peul',
        'ff_Adlm' => 'peul (adlam)',
        'ff_Adlm_BF' => 'peul (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'peul (adlam, Cameroun)',
        'ff_Adlm_GH' => 'peul (adlam, Ghana)',
        'ff_Adlm_GM' => 'peul (adlam, Gambie)',
        'ff_Adlm_GN' => 'peul (adlam, Guinée)',
        'ff_Adlm_GW' => 'peul (adlam, Guinée-Bissau)',
        'ff_Adlm_LR' => 'peul (adlam, Liberia)',
        'ff_Adlm_MR' => 'peul (adlam, Mauritanie)',
        'ff_Adlm_NE' => 'peul (adlam, Niger)',
        'ff_Adlm_NG' => 'peul (adlam, Nigeria)',
        'ff_Adlm_SL' => 'peul (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'peul (adlam, Sénégal)',
        'ff_CM' => 'peul (Cameroun)',
        'ff_GN' => 'peul (Guinée)',
        'ff_Latn' => 'peul (latin)',
        'ff_Latn_BF' => 'peul (latin, Burkina Faso)',
        'ff_Latn_CM' => 'peul (latin, Cameroun)',
        'ff_Latn_GH' => 'peul (latin, Ghana)',
        'ff_Latn_GM' => 'peul (latin, Gambie)',
        'ff_Latn_GN' => 'peul (latin, Guinée)',
        'ff_Latn_GW' => 'peul (latin, Guinée-Bissau)',
        'ff_Latn_LR' => 'peul (latin, Liberia)',
        'ff_Latn_MR' => 'peul (latin, Mauritanie)',
        'ff_Latn_NE' => 'peul (latin, Niger)',
        'ff_Latn_NG' => 'peul (latin, Nigeria)',
        'ff_Latn_SL' => 'peul (latin, Sierra Leone)',
        'ff_Latn_SN' => 'peul (latin, Sénégal)',
        'ff_MR' => 'peul (Mauritanie)',
        'ff_SN' => 'peul (Sénégal)',
        'fi' => 'finnois',
        'fi_FI' => 'finnois (Finlande)',
        'fo' => 'féroïen',
        'fo_DK' => 'féroïen (Danemark)',
        'fo_FO' => 'féroïen (Îles Féroé)',
        'fr' => 'français',
        'fr_BE' => 'français (Belgique)',
        'fr_BF' => 'français (Burkina Faso)',
        'fr_BI' => 'français (Burundi)',
        'fr_BJ' => 'français (Bénin)',
        'fr_BL' => 'français (Saint-Barthélemy)',
        'fr_CA' => 'français (Canada)',
        'fr_CD' => 'français (Congo-Kinshasa)',
        'fr_CF' => 'français (République centrafricaine)',
        'fr_CG' => 'français (Congo-Brazzaville)',
        'fr_CH' => 'français (Suisse)',
        'fr_CI' => 'français (Côte d’Ivoire)',
        'fr_CM' => 'français (Cameroun)',
        'fr_DJ' => 'français (Djibouti)',
        'fr_DZ' => 'français (Algérie)',
        'fr_FR' => 'français (France)',
        'fr_GA' => 'français (Gabon)',
        'fr_GF' => 'français (Guyane française)',
        'fr_GN' => 'français (Guinée)',
        'fr_GP' => 'français (Guadeloupe)',
        'fr_GQ' => 'français (Guinée équatoriale)',
        'fr_HT' => 'français (Haïti)',
        'fr_KM' => 'français (Comores)',
        'fr_LU' => 'français (Luxembourg)',
        'fr_MA' => 'français (Maroc)',
        'fr_MC' => 'français (Monaco)',
        'fr_MF' => 'français (Saint-Martin)',
        'fr_MG' => 'français (Madagascar)',
        'fr_ML' => 'français (Mali)',
        'fr_MQ' => 'français (Martinique)',
        'fr_MR' => 'français (Mauritanie)',
        'fr_MU' => 'français (Maurice)',
        'fr_NC' => 'français (Nouvelle-Calédonie)',
        'fr_NE' => 'français (Niger)',
        'fr_PF' => 'français (Polynésie française)',
        'fr_PM' => 'français (Saint-Pierre-et-Miquelon)',
        'fr_RE' => 'français (La Réunion)',
        'fr_RW' => 'français (Rwanda)',
        'fr_SC' => 'français (Seychelles)',
        'fr_SN' => 'français (Sénégal)',
        'fr_SY' => 'français (Syrie)',
        'fr_TD' => 'français (Tchad)',
        'fr_TG' => 'français (Togo)',
        'fr_TN' => 'français (Tunisie)',
        'fr_VU' => 'français (Vanuatu)',
        'fr_WF' => 'français (Wallis-et-Futuna)',
        'fr_YT' => 'français (Mayotte)',
        'fy' => 'frison occidental',
        'fy_NL' => 'frison occidental (Pays-Bas)',
        'ga' => 'irlandais',
        'ga_GB' => 'irlandais (Royaume-Uni)',
        'ga_IE' => 'irlandais (Irlande)',
        'gd' => 'gaélique écossais',
        'gd_GB' => 'gaélique écossais (Royaume-Uni)',
        'gl' => 'galicien',
        'gl_ES' => 'galicien (Espagne)',
        'gu' => 'goudjarati',
        'gu_IN' => 'goudjarati (Inde)',
        'gv' => 'mannois',
        'gv_IM' => 'mannois (Île de Man)',
        'ha' => 'haoussa',
        'ha_GH' => 'haoussa (Ghana)',
        'ha_NE' => 'haoussa (Niger)',
        'ha_NG' => 'haoussa (Nigeria)',
        'he' => 'hébreu',
        'he_IL' => 'hébreu (Israël)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Inde)',
        'hi_Latn' => 'hindi (latin)',
        'hi_Latn_IN' => 'hindi (latin, Inde)',
        'hr' => 'croate',
        'hr_BA' => 'croate (Bosnie-Herzégovine)',
        'hr_HR' => 'croate (Croatie)',
        'hu' => 'hongrois',
        'hu_HU' => 'hongrois (Hongrie)',
        'hy' => 'arménien',
        'hy_AM' => 'arménien (Arménie)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Monde)',
        'id' => 'indonésien',
        'id_ID' => 'indonésien (Indonésie)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'yi du Sichuan',
        'ii_CN' => 'yi du Sichuan (Chine)',
        'is' => 'islandais',
        'is_IS' => 'islandais (Islande)',
        'it' => 'italien',
        'it_CH' => 'italien (Suisse)',
        'it_IT' => 'italien (Italie)',
        'it_SM' => 'italien (Saint-Marin)',
        'it_VA' => 'italien (État de la Cité du Vatican)',
        'ja' => 'japonais',
        'ja_JP' => 'japonais (Japon)',
        'jv' => 'javanais',
        'jv_ID' => 'javanais (Indonésie)',
        'ka' => 'géorgien',
        'ka_GE' => 'géorgien (Géorgie)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kazakh',
        'kk_KZ' => 'kazakh (Kazakhstan)',
        'kl' => 'groenlandais',
        'kl_GL' => 'groenlandais (Groenland)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Cambodge)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Inde)',
        'ko' => 'coréen',
        'ko_KP' => 'coréen (Corée du Nord)',
        'ko_KR' => 'coréen (Corée du Sud)',
        'ks' => 'cachemiri',
        'ks_Arab' => 'cachemiri (arabe)',
        'ks_Arab_IN' => 'cachemiri (arabe, Inde)',
        'ks_Deva' => 'cachemiri (dévanagari)',
        'ks_Deva_IN' => 'cachemiri (dévanagari, Inde)',
        'ks_IN' => 'cachemiri (Inde)',
        'ku' => 'kurde',
        'ku_TR' => 'kurde (Turquie)',
        'kw' => 'cornique',
        'kw_GB' => 'cornique (Royaume-Uni)',
        'ky' => 'kirghize',
        'ky_KG' => 'kirghize (Kirghizstan)',
        'lb' => 'luxembourgeois',
        'lb_LU' => 'luxembourgeois (Luxembourg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Ouganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo-Kinshasa)',
        'ln_CF' => 'lingala (République centrafricaine)',
        'ln_CG' => 'lingala (Congo-Brazzaville)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laos)',
        'lt' => 'lituanien',
        'lt_LT' => 'lituanien (Lituanie)',
        'lu' => 'luba-katanga [kiluba]',
        'lu_CD' => 'luba-katanga [kiluba] (Congo-Kinshasa)',
        'lv' => 'letton',
        'lv_LV' => 'letton (Lettonie)',
        'mg' => 'malgache',
        'mg_MG' => 'malgache (Madagascar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nouvelle-Zélande)',
        'mk' => 'macédonien',
        'mk_MK' => 'macédonien (Macédoine du Nord)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (Inde)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongolie)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (Inde)',
        'ms' => 'malais',
        'ms_BN' => 'malais (Brunei)',
        'ms_ID' => 'malais (Indonésie)',
        'ms_MY' => 'malais (Malaisie)',
        'ms_SG' => 'malais (Singapour)',
        'mt' => 'maltais',
        'mt_MT' => 'maltais (Malte)',
        'my' => 'birman',
        'my_MM' => 'birman (Myanmar [Birmanie])',
        'nb' => 'norvégien bokmål',
        'nb_NO' => 'norvégien bokmål (Norvège)',
        'nb_SJ' => 'norvégien bokmål (Svalbard et Jan Mayen)',
        'nd' => 'ndébélé du Nord',
        'nd_ZW' => 'ndébélé du Nord (Zimbabwe)',
        'ne' => 'népalais',
        'ne_IN' => 'népalais (Inde)',
        'ne_NP' => 'népalais (Népal)',
        'nl' => 'néerlandais',
        'nl_AW' => 'néerlandais (Aruba)',
        'nl_BE' => 'néerlandais (Belgique)',
        'nl_BQ' => 'néerlandais (Pays-Bas caribéens)',
        'nl_CW' => 'néerlandais (Curaçao)',
        'nl_NL' => 'néerlandais (Pays-Bas)',
        'nl_SR' => 'néerlandais (Suriname)',
        'nl_SX' => 'néerlandais (Saint-Martin [partie néerlandaise])',
        'nn' => 'norvégien nynorsk',
        'nn_NO' => 'norvégien nynorsk (Norvège)',
        'no' => 'norvégien',
        'no_NO' => 'norvégien (Norvège)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Éthiopie)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'odia',
        'or_IN' => 'odia (Inde)',
        'os' => 'ossète',
        'os_GE' => 'ossète (Géorgie)',
        'os_RU' => 'ossète (Russie)',
        'pa' => 'pendjabi',
        'pa_Arab' => 'pendjabi (arabe)',
        'pa_Arab_PK' => 'pendjabi (arabe, Pakistan)',
        'pa_Guru' => 'pendjabi (gourmoukhî)',
        'pa_Guru_IN' => 'pendjabi (gourmoukhî, Inde)',
        'pa_IN' => 'pendjabi (Inde)',
        'pa_PK' => 'pendjabi (Pakistan)',
        'pl' => 'polonais',
        'pl_PL' => 'polonais (Pologne)',
        'ps' => 'pachto',
        'ps_AF' => 'pachto (Afghanistan)',
        'ps_PK' => 'pachto (Pakistan)',
        'pt' => 'portugais',
        'pt_AO' => 'portugais (Angola)',
        'pt_BR' => 'portugais (Brésil)',
        'pt_CH' => 'portugais (Suisse)',
        'pt_CV' => 'portugais (Cap-Vert)',
        'pt_GQ' => 'portugais (Guinée équatoriale)',
        'pt_GW' => 'portugais (Guinée-Bissau)',
        'pt_LU' => 'portugais (Luxembourg)',
        'pt_MO' => 'portugais (R.A.S. chinoise de Macao)',
        'pt_MZ' => 'portugais (Mozambique)',
        'pt_PT' => 'portugais (Portugal)',
        'pt_ST' => 'portugais (Sao Tomé-et-Principe)',
        'pt_TL' => 'portugais (Timor oriental)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivie)',
        'qu_EC' => 'quechua (Équateur)',
        'qu_PE' => 'quechua (Pérou)',
        'rm' => 'romanche',
        'rm_CH' => 'romanche (Suisse)',
        'rn' => 'roundi',
        'rn_BI' => 'roundi (Burundi)',
        'ro' => 'roumain',
        'ro_MD' => 'roumain (Moldavie)',
        'ro_RO' => 'roumain (Roumanie)',
        'ru' => 'russe',
        'ru_BY' => 'russe (Biélorussie)',
        'ru_KG' => 'russe (Kirghizstan)',
        'ru_KZ' => 'russe (Kazakhstan)',
        'ru_MD' => 'russe (Moldavie)',
        'ru_RU' => 'russe (Russie)',
        'ru_UA' => 'russe (Ukraine)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Rwanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (Inde)',
        'sc' => 'sarde',
        'sc_IT' => 'sarde (Italie)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabe)',
        'sd_Arab_PK' => 'sindhi (arabe, Pakistan)',
        'sd_Deva' => 'sindhi (dévanagari)',
        'sd_Deva_IN' => 'sindhi (dévanagari, Inde)',
        'sd_IN' => 'sindhi (Inde)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'same du Nord',
        'se_FI' => 'same du Nord (Finlande)',
        'se_NO' => 'same du Nord (Norvège)',
        'se_SE' => 'same du Nord (Suède)',
        'sg' => 'sango',
        'sg_CF' => 'sango (République centrafricaine)',
        'sh' => 'serbo-croate',
        'sh_BA' => 'serbo-croate (Bosnie-Herzégovine)',
        'si' => 'cingalais',
        'si_LK' => 'cingalais (Sri Lanka)',
        'sk' => 'slovaque',
        'sk_SK' => 'slovaque (Slovaquie)',
        'sl' => 'slovène',
        'sl_SI' => 'slovène (Slovénie)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somali',
        'so_DJ' => 'somali (Djibouti)',
        'so_ET' => 'somali (Éthiopie)',
        'so_KE' => 'somali (Kenya)',
        'so_SO' => 'somali (Somalie)',
        'sq' => 'albanais',
        'sq_AL' => 'albanais (Albanie)',
        'sq_MK' => 'albanais (Macédoine du Nord)',
        'sr' => 'serbe',
        'sr_BA' => 'serbe (Bosnie-Herzégovine)',
        'sr_Cyrl' => 'serbe (cyrillique)',
        'sr_Cyrl_BA' => 'serbe (cyrillique, Bosnie-Herzégovine)',
        'sr_Cyrl_ME' => 'serbe (cyrillique, Monténégro)',
        'sr_Cyrl_RS' => 'serbe (cyrillique, Serbie)',
        'sr_Latn' => 'serbe (latin)',
        'sr_Latn_BA' => 'serbe (latin, Bosnie-Herzégovine)',
        'sr_Latn_ME' => 'serbe (latin, Monténégro)',
        'sr_Latn_RS' => 'serbe (latin, Serbie)',
        'sr_ME' => 'serbe (Monténégro)',
        'sr_RS' => 'serbe (Serbie)',
        'su' => 'soundanais',
        'su_ID' => 'soundanais (Indonésie)',
        'su_Latn' => 'soundanais (latin)',
        'su_Latn_ID' => 'soundanais (latin, Indonésie)',
        'sv' => 'suédois',
        'sv_AX' => 'suédois (Îles Åland)',
        'sv_FI' => 'suédois (Finlande)',
        'sv_SE' => 'suédois (Suède)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Congo-Kinshasa)',
        'sw_KE' => 'swahili (Kenya)',
        'sw_TZ' => 'swahili (Tanzanie)',
        'sw_UG' => 'swahili (Ouganda)',
        'ta' => 'tamoul',
        'ta_IN' => 'tamoul (Inde)',
        'ta_LK' => 'tamoul (Sri Lanka)',
        'ta_MY' => 'tamoul (Malaisie)',
        'ta_SG' => 'tamoul (Singapour)',
        'te' => 'télougou',
        'te_IN' => 'télougou (Inde)',
        'tg' => 'tadjik',
        'tg_TJ' => 'tadjik (Tadjikistan)',
        'th' => 'thaï',
        'th_TH' => 'thaï (Thaïlande)',
        'ti' => 'tigrigna',
        'ti_ER' => 'tigrigna (Érythrée)',
        'ti_ET' => 'tigrigna (Éthiopie)',
        'tk' => 'turkmène',
        'tk_TM' => 'turkmène (Turkménistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Philippines)',
        'to' => 'tongien',
        'to_TO' => 'tongien (Tonga)',
        'tr' => 'turc',
        'tr_CY' => 'turc (Chypre)',
        'tr_TR' => 'turc (Turquie)',
        'tt' => 'tatar',
        'tt_RU' => 'tatar (Russie)',
        'ug' => 'ouïghour',
        'ug_CN' => 'ouïghour (Chine)',
        'uk' => 'ukrainien',
        'uk_UA' => 'ukrainien (Ukraine)',
        'ur' => 'ourdou',
        'ur_IN' => 'ourdou (Inde)',
        'ur_PK' => 'ourdou (Pakistan)',
        'uz' => 'ouzbek',
        'uz_AF' => 'ouzbek (Afghanistan)',
        'uz_Arab' => 'ouzbek (arabe)',
        'uz_Arab_AF' => 'ouzbek (arabe, Afghanistan)',
        'uz_Cyrl' => 'ouzbek (cyrillique)',
        'uz_Cyrl_UZ' => 'ouzbek (cyrillique, Ouzbékistan)',
        'uz_Latn' => 'ouzbek (latin)',
        'uz_Latn_UZ' => 'ouzbek (latin, Ouzbékistan)',
        'uz_UZ' => 'ouzbek (Ouzbékistan)',
        'vi' => 'vietnamien',
        'vi_VN' => 'vietnamien (Viêt Nam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Sénégal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Afrique du Sud)',
        'yi' => 'yiddish',
        'yi_001' => 'yiddish (Monde)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Bénin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'zh' => 'chinois',
        'zh_CN' => 'chinois (Chine)',
        'zh_HK' => 'chinois (R.A.S. chinoise de Hong Kong)',
        'zh_Hans' => 'chinois (simplifié)',
        'zh_Hans_CN' => 'chinois (simplifié, Chine)',
        'zh_Hans_HK' => 'chinois (simplifié, R.A.S. chinoise de Hong Kong)',
        'zh_Hans_MO' => 'chinois (simplifié, R.A.S. chinoise de Macao)',
        'zh_Hans_SG' => 'chinois (simplifié, Singapour)',
        'zh_Hant' => 'chinois (traditionnel)',
        'zh_Hant_HK' => 'chinois (traditionnel, R.A.S. chinoise de Hong Kong)',
        'zh_Hant_MO' => 'chinois (traditionnel, R.A.S. chinoise de Macao)',
        'zh_Hant_TW' => 'chinois (traditionnel, Taïwan)',
        'zh_MO' => 'chinois (R.A.S. chinoise de Macao)',
        'zh_SG' => 'chinois (Singapour)',
        'zh_TW' => 'chinois (Taïwan)',
        'zu' => 'zoulou',
        'zu_ZA' => 'zoulou (Afrique du Sud)',
    ],
];
