<?php

return [
    'Names' => [
        'ab' => 'абхазаг',
        'ady' => 'адыгейаг',
        'ae' => 'авестӕ',
        'af' => 'африкаанс',
        'ang' => 'рагон англисаг',
        'ar' => 'араббаг',
        'av' => 'авайраг',
        'az' => 'тӕтӕйраг',
        'ba' => 'башкираг',
        'bg' => 'болгайраг',
        'bs' => 'босниаг',
        'bua' => 'бурятаг',
        'ca' => 'каталайнаг',
        'ce' => 'цӕцӕйнаг',
        'cop' => 'коптаг',
        'cs' => 'чехаг',
        'cv' => 'чувашаг',
        'da' => 'даниаг',
        'de' => 'немыцаг',
        'egy' => 'рагон египтаг',
        'el' => 'бердзейнаг',
        'en' => 'англисаг',
        'eo' => 'есперанто',
        'es' => 'испайнаг',
        'et' => 'естойнаг',
        'eu' => 'баскаг',
        'fa' => 'персайнаг',
        'fi' => 'финнаг',
        'fil' => 'филиппинаг',
        'fj' => 'фиджи',
        'fo' => 'фарераг',
        'fr' => 'францаг',
        'fro' => 'рагон францаг',
        'ga' => 'ирландиаг',
        'grc' => 'рагон бердзейнаг',
        'he' => 'уираг',
        'hr' => 'хорватаг',
        'hu' => 'венгериаг',
        'hy' => 'сомихаг',
        'inh' => 'мӕхъӕлон',
        'it' => 'италиаг',
        'ja' => 'япойнаг',
        'ka' => 'гуырдзиаг',
        'kbd' => 'кӕсгон',
        'krc' => 'бӕлхъӕрон',
        'ku' => 'курдаг',
        'kum' => 'хъуымыхъхъаг',
        'la' => 'латинаг',
        'lez' => 'лекъаг',
        'mk' => 'мӕчъидон',
        'os' => 'ирон',
        'pt' => 'португалиаг',
        'rom' => 'цигайнаг',
        'ru' => 'уырыссаг',
        'zh' => 'китайаг',
    ],
    'LocalizedNames' => [
        'de_AT' => 'австралиаг немыцаг',
        'de_CH' => 'швйецариаг немыцаг',
        'en_AU' => 'австралиаг англисаг',
        'en_CA' => 'канадӕйаг англисаг',
        'en_GB' => 'бритайнаг англисаг',
        'en_US' => 'америкаг англисаг',
        'es_419' => 'латинаг америкаг англисаг',
        'es_ES' => 'европӕйаг англисаг',
        'fr_CA' => 'канадӕйаг францаг',
        'fr_CH' => 'швейцариаг францаг',
        'pt_BR' => 'бразилиаг португалиаг',
        'pt_PT' => 'европӕйаг полтугалиаг',
        'zh_Hans' => 'ӕнцонгонд китайаг',
        'zh_Hant' => 'традицион китайаг',
    ],
];
