<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Dirhami i Emirateve të Bashkuara Arabe',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afgani afgan',
        ],
        'ALL' => [
            0 => 'Lekë',
            1 => 'Leku shqiptar',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dramia armene',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Gilderi antilian holandez',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Kuanza e Angolës',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Pesoja argjentinase',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dollari australian',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Florini aruban',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manata azerbajxhanase',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Marka e Bosnjë-Hercegovinës [e shkëmbyeshme]',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dollari barbadian',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka e Bangladeshit',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Leva bullgare',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dinari i Bahreinit',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Franga burundiane',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dollari i Bermudeve',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dollari i Bruneit',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviani i Bolivisë',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Reali brazilian',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dollari i Bahamasit',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrumi butanez',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula botsuane',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rubla bjelloruse',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Rubla bjelloruse (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dollari i Ishujve Belize',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dollari kanadez',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Franga kongole',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Franga zvicerane',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Pesoja kiliane',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Juani kinez (për treg të jashtëm)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Juani kinez',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Pesoja kolumbiane',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Koloni kostarikan',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Pesoja kubaneze e shkëmbyeshme',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Pesoja kubaneze',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Eskudoja e Kepit të Gjelbër',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna e Çekisë',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Franga xhibutiane',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Korona daneze',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Pesoja dominikane',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinari algjerian',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Sterlina egjiptiane',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakfa e Eritresë',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Bira etiopiane',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euroja',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dollari i Fixhit',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Stërlina e Ishujve Falkland',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Sterlina britanike',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Laria gjeorgjiane',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Sejda ganeze',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Sterlina e Gjibraltarit',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi gambian',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Franga guinease',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Kuecali i Guatemalës',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dollari guajanez',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dollari i Hong-Kongut',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lempira hondurase',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna kroate',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gurdi haitian',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Forinta hungareze',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupia indoneziane',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Shekeli izrealit',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupia indiane',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dinari irakian',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Riali iranian',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Korona islandeze',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dollari xhamajkan',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinari jordanez',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Jeni japonez',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Shilinga keniane',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Soma kirgize',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Riali kamboxhian',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Franga komore',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Uoni koreano-verior',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Uoni koreano-jugor',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dinari kuvajtian',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dollari i Ishujve Kajman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenga kazake',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kipa e Laosit',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Sterlina libaneze',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rupia e Sri-Lankës',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dollari liberian',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lota lesotiane',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Lita lituaneze',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Lata letoneze',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dinari libian',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dirhami maroken',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Leuja moldave',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Arieri malagez',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Denari maqedonas',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kiata e Mianmarit',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Tugrika mongole',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataka e Makaos',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ugija mauritane (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ugija mauritane',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupia mauritiane',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiu i Maldivit',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kuaça malaviane',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Pesoja meksikane',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringiti malajzian',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Metikali i Mozambikut',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dollari i Namibisë',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira nigeriane',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Kordoba nikaraguane',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Korona norvegjeze',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupia nepaleze',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dollari i Zelandës së Re',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Riali i Omanit',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Balboa panameze',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Sola peruane',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kina e Guinesë së Re-Papua',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Pesoja filipinase',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupia pakistaneze',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Zllota polake',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Guarani paraguaian',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Riali i Katarit',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Leuja rumune',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinari serb',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Rubla ruse',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Franga ruandeze',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riali saudit',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dollari i Ishujve Solomonë',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rupia e Ishujve Sishelë',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sterlina sudaneze',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Korona suedeze',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dollari i Singaporit',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Sterlina e Ishullit të Shën-Helenës',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leoni i Sierra-Leones',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Shilinga somaleze',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dollari surinamez',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Sterlina sudanezo-jugore',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobra e Sao-Tomes dhe Prinsipes (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dobra e Sao-Tomes dhe Prinsipes',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Sterlina siriane',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni i Suazilandës',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Bata tajlandeze',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somona taxhike',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manata turkmene',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dinari tunizian',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Panga tongane',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lira turke',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dollari i Trinidadit dhe Tobagos',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dollari tajvanez',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Shilinga e Tanzanisë',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Rivnia ukrainase',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Shilinga ugandeze',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Dollari amerikan',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Pesoja uruguaiane',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Soma uzbeke',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Bolivari venezuelian (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bolivari venezuelas',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Donga vietnameze',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vatuja e Vanuatusë',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tala samoane',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Franga kamerunase',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dollari i Karaibeve Lindore',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Franga e Bregut të Fildishtë',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Franga franceze e Polinezisë',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Riali i Jemenit',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Randi afrikano-jugor',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kuaça e Zambikut',
        ],
    ],
];
