<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorrese peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Verenigde Arabyske Emiraten-dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghaanske afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanese lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armeense dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Nederlânsk-Antilliaanske gûne',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolese kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolese kwanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolese nieuwe kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolese kwanza reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentynske austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Argentynske peso ley (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Argentynske peso (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentynske peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentynske peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Eastenrykse schilling',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Australyske dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Arubaanske gulden',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbeidzjaanske manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbeidzjaanske manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosnyske dinar',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnyske convertibele mark',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Nije Bosnyske dinar (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadaanske dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bengalese taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belgyske frank (convertibel)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgyske frank',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belgyske frank (finansjeel)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgaarse harde lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Bulgaarse socialistyske lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgaarse lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Bulgaarse lev (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreinse dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundese frank',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda-dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Bruneise dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviaanske boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Boliviaanske boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Boliviaanske peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Boliviaanske mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Braziliaanske cruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Braziliaanske cruzado',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Braziliaanske cruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Braziliaanske real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Braziliaanske cruzado novo',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Braziliaanske cruzeiro',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Braziliaanske cruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamaanske dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhutaanske ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Birmese kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswaanske pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Wit-Russyske nieuwe roebel (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Wit-Russyske roebel',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Wit-Russyske roebel (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belizaanske dollar',
        ],
        'CAD' => [
            0 => 'C$',
            1 => 'Canadese dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Congolese frank',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Zwitserse frank',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR franc',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Sileenske escudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Sileenske unidades de fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Sileenske peso',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Sineeske yuan renminbi',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Kolombiaanske peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Unidad de Valor Real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Costaricaanske colón',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Alde Servyske dinar',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Tsjechoslowaakse harde koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Kubaanske convertibele peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Kubaanske peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kaapverdyske escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Cyprysk pûn',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Tsjechyske kroon',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'East-Dútske ostmark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Dútske mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djiboutiaanske frank',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Deenske kroon',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominikaanske peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algerynske dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ecuadoraanske sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Ecuadoraanske unidad de valor constante (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estlânske kroon',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptysk pûn',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrese nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Spaanske peseta (account A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Spaanske peseta (convertibele account)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Spaanske peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ethiopyske birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Finse markka',
        ],
        'FJD' => [
            0 => 'FJ$',
            1 => 'Fiji-dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falklâneilânske pûn',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franske franc',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Brits pûn',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Georgyske kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgyske lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ghanese cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanese cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltarees pûn',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambiaanske dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinese franc',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guinese syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Equatoriaal-Guinese ekwele guineana',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Grykse drachme',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemalteekse quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugees-Guinese escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guinee-Bissause peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyaanske dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hongkongske dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Hondurese lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Kroatyske dinar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatyske kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haïtiaanske gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Hongaarse forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesyske roepia',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Ierske pûn',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Israëlysk pûn',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Israëlyske nieuwe shekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indiase roepie',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Iraakse dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iraanske rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Yslânske kroon',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italiaanske lire',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaikaanske dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordaanske dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Japanse yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Keniaanske shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgizyske som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Kambodjaanske riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Komorese frank',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Noard-Koreaanske won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Sûd-Koreaanske hwan (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Alde Sûd-Koreaanske won (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Sûd-Koreaanske won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Koeweitse dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Caymaneilânske dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazachstaanske tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laotiaanske kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libaneeske pûn',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lankaanske roepie',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberiaanske dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesothaanske loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litouwse litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litouwse talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Lúksemboargske convertibele franc',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Lúksemboargske frank',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Lúksemboargske finansjele franc',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Letse lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Letse roebel',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libyske dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokkaanske dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokkaanske franc',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Monegaskyske frank',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Moldavyske cupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldavyske leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagassyske ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Malagassyske franc',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Macedonyske denar',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Macedonyske denar (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malinese franc',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmarese kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongoalske tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macause pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritaanske ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritaanske ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltese lire',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltees pûn',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritiaanske roepie',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldivyske rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawyske kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Meksikaanske peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Meksikaanske sulveren peso (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Meksikaanske unidad de inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Maleisyske ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambikaanske escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Alde Mozambikaanske metical',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambikaanske metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibyske dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeriaanske naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nicaraguaanske córdoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nicaraguaanske córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Nederlânske gûne',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Noarske kroon',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalese roepie',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Nij-Seelânske dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omaanske rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamese balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peruaanske inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruaanske sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peruaanske sol (1863–1985)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papuaanske kina',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'Filipynske peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistaanske roepie',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Poalske zloty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Poalske zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugeeske escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguayaanske guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Katarese rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rhodesyske dollar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Alde Roemeenske leu',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Roemeenske leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Servyske dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russyske roebel',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Russyske roebel (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Rwandese frank',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saoedi-Arabyske riyal',
        ],
        'SBD' => [
            0 => 'SI$',
            1 => 'Salomon-dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seychelse roepie',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Soedaneeske dinar',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Soedaneeske pûn',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Soedaneeske pûn (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Sweedske kroon',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singaporese dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Sint-Heleenske pûn',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Sloveenske tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slowaakse koruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierraleoonse leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalyske shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinaamske dollar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinaamske gulden',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Sûd-Soedaneeske pûn',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Santomese dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Santomese dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovjet-roebel',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Salvadoraanske colón',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Syrysk pûn',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazyske lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Thaise baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadzjikistaanske roebel',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadzjikistaanske somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmeense manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmeense manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunesyske dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongaanske paʻanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timorese escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turkse lire',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkse lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad en Tobago-dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Nije Taiwanese dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniaanske shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Oekraïense hryvnia',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Oekraïense karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Oegandese shilling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Oegandese shilling',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Amerikaanske dollar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Amerikaanske dollar (folgjende dei)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Amerikaanske dollar (zelfde dei)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Uruguayaanske peso en geïndexeerde eenheden',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruguayaanske peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguayaanske peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Oezbekistaanske sum',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Fenezolaanske bolivar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Fenezolaanske bolivar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Fenezolaanske bolivar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Fietnameeske dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Alde Fietnameeske dong (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatuaanske vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoaanske tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA-frank',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'East-Karibyske dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'European Currency Unit',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franse gouden franc',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Franse UIC-franc',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'CFA-franc BCEAO',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'CFP-franc',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET-fondsen',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemenityske dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemenityske rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Joegoslavyske harde dinar',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Joegoslavyske noviy-dinar',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Joegoslavyske convertibele dinar',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Joegoslavyske herfoarme dinar (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Sûd-Afrikaanske rand (finansjeel)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Sûd-Afrikaanske rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Sambiaanske kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Sambiaanske kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Saïreeske nije Saïre',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Saïreeske Saïre',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Simbabwaanske dollar',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Simbabwaanske dollar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Simbabwaanske dollar (2008)',
        ],
    ],
];
