<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Abidjan (Greenwicha áigi)',
        'Africa/Accra' => 'Accra (Greenwicha áigi)',
        'Africa/Addis_Ababa' => 'Addis Ababa (Nuorta-Afrihká áigi)',
        'Africa/Algiers' => 'Algiers (Gaska-Eurohpá áigi)',
        'Africa/Asmera' => 'Asmara (Nuorta-Afrihká áigi)',
        'Africa/Bamako' => 'Bamako (Greenwicha áigi)',
        'Africa/Bangui' => 'Bangui (Oarje-Afrihká áigi)',
        'Africa/Banjul' => 'Banjul (Greenwicha áigi)',
        'Africa/Bissau' => 'Bissau (Greenwicha áigi)',
        'Africa/Blantyre' => 'Blantyre (Gaska-Afrihká áigi)',
        'Africa/Brazzaville' => 'Brazzaville (Oarje-Afrihká áigi)',
        'Africa/Bujumbura' => 'Bujumbura (Gaska-Afrihká áigi)',
        'Africa/Cairo' => 'Kairo (Nuorta-Eurohpa áigi)',
        'Africa/Casablanca' => 'Casablanca (Oarje-Eurohpá áigi)',
        'Africa/Ceuta' => 'Ceuta (Gaska-Eurohpá áigi)',
        'Africa/Conakry' => 'Conakry (Greenwicha áigi)',
        'Africa/Dakar' => 'Dakar (Greenwicha áigi)',
        'Africa/Dar_es_Salaam' => 'Dar es Salaam (Nuorta-Afrihká áigi)',
        'Africa/Djibouti' => 'Djibouti (Nuorta-Afrihká áigi)',
        'Africa/Douala' => 'Douala (Oarje-Afrihká áigi)',
        'Africa/El_Aaiun' => 'El Aaiun (Oarje-Eurohpá áigi)',
        'Africa/Freetown' => 'Freetown (Greenwicha áigi)',
        'Africa/Gaborone' => 'Gaborone (Gaska-Afrihká áigi)',
        'Africa/Harare' => 'Harare (Gaska-Afrihká áigi)',
        'Africa/Johannesburg' => 'Johannesburg (Lulli-Afrihká dálveáigi)',
        'Africa/Juba' => 'Juba (Gaska-Afrihká áigi)',
        'Africa/Kampala' => 'Kampala (Nuorta-Afrihká áigi)',
        'Africa/Khartoum' => 'Khartoum (Gaska-Afrihká áigi)',
        'Africa/Kigali' => 'Kigali (Gaska-Afrihká áigi)',
        'Africa/Kinshasa' => 'Kinshasa (Oarje-Afrihká áigi)',
        'Africa/Lagos' => 'Lagos (Oarje-Afrihká áigi)',
        'Africa/Libreville' => 'Libreville (Oarje-Afrihká áigi)',
        'Africa/Lome' => 'Lome (Greenwicha áigi)',
        'Africa/Luanda' => 'Luanda (Oarje-Afrihká áigi)',
        'Africa/Lubumbashi' => 'Lubumbashi (Gaska-Afrihká áigi)',
        'Africa/Lusaka' => 'Lusaka (Gaska-Afrihká áigi)',
        'Africa/Malabo' => 'Malabo (Oarje-Afrihká áigi)',
        'Africa/Maputo' => 'Maputo (Gaska-Afrihká áigi)',
        'Africa/Maseru' => 'Maseru (Lulli-Afrihká dálveáigi)',
        'Africa/Mbabane' => 'Mbabane (Lulli-Afrihká dálveáigi)',
        'Africa/Mogadishu' => 'Mogadishu (Nuorta-Afrihká áigi)',
        'Africa/Monrovia' => 'Monrovia (Greenwicha áigi)',
        'Africa/Nairobi' => 'Nairobi (Nuorta-Afrihká áigi)',
        'Africa/Ndjamena' => 'Ndjamena (Oarje-Afrihká áigi)',
        'Africa/Niamey' => 'Niamey (Oarje-Afrihká áigi)',
        'Africa/Nouakchott' => 'Nouakchott (Greenwicha áigi)',
        'Africa/Ouagadougou' => 'Ouagadougou (Greenwicha áigi)',
        'Africa/Porto-Novo' => 'Porto-Novo (Oarje-Afrihká áigi)',
        'Africa/Sao_Tome' => 'Sao Tome (Greenwicha áigi)',
        'Africa/Tripoli' => 'Tripoli (Nuorta-Eurohpa áigi)',
        'Africa/Tunis' => 'Tunis (Gaska-Eurohpá áigi)',
        'Africa/Windhoek' => 'Windhoek (Gaska-Afrihká áigi)',
        'America/Adak' => 'Adak (Hawaii-aleuhtalaš áigi)',
        'America/Anchorage' => 'Anchorage (Alaska áigi)',
        'America/Anguilla' => 'Anguilla (atlántalaš áigi)',
        'America/Antigua' => 'Antigua (atlántalaš áigi)',
        'America/Araguaina' => 'Araguaina (Brasilia áigi)',
        'America/Aruba' => 'Aruba (atlántalaš áigi)',
        'America/Asuncion' => 'Asuncion (Paraguaya áigi)',
        'America/Bahia' => 'Bahia (Brasilia áigi)',
        'America/Bahia_Banderas' => 'Bahia Banderas (dábálašáigi)',
        'America/Barbados' => 'Barbados (atlántalaš áigi)',
        'America/Belem' => 'Belem (Brasilia áigi)',
        'America/Belize' => 'Belize (dábálašáigi)',
        'America/Blanc-Sablon' => 'Blanc-Sablon (atlántalaš áigi)',
        'America/Boa_Vista' => 'Boa Vista (Amazona áigi)',
        'America/Bogota' => 'Bogota (Colombia áigi)',
        'America/Boise' => 'Boise (duottaráigi)',
        'America/Cambridge_Bay' => 'Cambridge Bay (duottaráigi)',
        'America/Campo_Grande' => 'Campo Grande (Amazona áigi)',
        'America/Cancun' => 'Cancun (áigi nuortan)',
        'America/Cayenne' => 'Cayenne (Frankriikka Guyana áigi)',
        'America/Cayman' => 'Cayman (áigi nuortan)',
        'America/Chicago' => 'Chicago (dábálašáigi)',
        'America/Chihuahua' => 'Chihuahua (Meksiko Jáskesábi áigi)',
        'America/Coral_Harbour' => 'Atikokan (áigi nuortan)',
        'America/Costa_Rica' => 'Costa Rica (dábálašáigi)',
        'America/Creston' => 'Creston (duottaráigi)',
        'America/Cuiaba' => 'Cuiaba (Amazona áigi)',
        'America/Curacao' => 'Curaçao (atlántalaš áigi)',
        'America/Danmarkshavn' => 'Dánmárkkuhámman (Greenwicha áigi)',
        'America/Dawson_Creek' => 'Dawson Creek (duottaráigi)',
        'America/Denver' => 'Denver (duottaráigi)',
        'America/Detroit' => 'Detroit (áigi nuortan)',
        'America/Dominica' => 'Dominica (atlántalaš áigi)',
        'America/Edmonton' => 'Edmonton (duottaráigi)',
        'America/El_Salvador' => 'El Salvador (dábálašáigi)',
        'America/Fort_Nelson' => 'Fort Nelson (duottaráigi)',
        'America/Fortaleza' => 'Fortaleza (Brasilia áigi)',
        'America/Glace_Bay' => 'Glace Bay (atlántalaš áigi)',
        'America/Godthab' => 'Nuuk (Oarje-Ruonáeatnama áigi)',
        'America/Goose_Bay' => 'Goose Bay (atlántalaš áigi)',
        'America/Grand_Turk' => 'Grand Turk (áigi nuortan)',
        'America/Grenada' => 'Grenada (atlántalaš áigi)',
        'America/Guadeloupe' => 'Guadeloupe (atlántalaš áigi)',
        'America/Guatemala' => 'Guatemala (dábálašáigi)',
        'America/Guayaquil' => 'Guayaquil (Ecuadora áigi)',
        'America/Guyana' => 'Guyana áigi',
        'America/Halifax' => 'Halifax (atlántalaš áigi)',
        'America/Havana' => 'Havana (Cuba áigi)',
        'America/Hermosillo' => 'Hermosillo (Meksiko Jáskesábi áigi)',
        'America/Indiana/Knox' => 'Knox, Indiana (dábálašáigi)',
        'America/Indiana/Marengo' => 'Marengo, Indiana (áigi nuortan)',
        'America/Indiana/Petersburg' => 'Petersburg, Indiana (áigi nuortan)',
        'America/Indiana/Tell_City' => 'Tell City, Indiana (dábálašáigi)',
        'America/Indiana/Vevay' => 'Vevay, Indiana (áigi nuortan)',
        'America/Indiana/Vincennes' => 'Vincennes, Indiana (áigi nuortan)',
        'America/Indiana/Winamac' => 'Winamac, Indiana (áigi nuortan)',
        'America/Indianapolis' => 'Indianapolis (áigi nuortan)',
        'America/Inuvik' => 'Inuvik (duottaráigi)',
        'America/Iqaluit' => 'Iqaluit (áigi nuortan)',
        'America/Jamaica' => 'Jamaica (áigi nuortan)',
        'America/Juneau' => 'Juneau (Alaska áigi)',
        'America/Kentucky/Monticello' => 'Monticello, Kentucky (áigi nuortan)',
        'America/Kralendijk' => 'Kralendijk (atlántalaš áigi)',
        'America/Los_Angeles' => 'Los Angeles (Jaskesábi áigi)',
        'America/Louisville' => 'Louisville (áigi nuortan)',
        'America/Lower_Princes' => 'Lower Prince’s Quarter (atlántalaš áigi)',
        'America/Maceio' => 'Maceio (Brasilia áigi)',
        'America/Managua' => 'Managua (dábálašáigi)',
        'America/Manaus' => 'Manaus (Amazona áigi)',
        'America/Marigot' => 'Marigot (atlántalaš áigi)',
        'America/Martinique' => 'Martinique (atlántalaš áigi)',
        'America/Matamoros' => 'Matamoros (dábálašáigi)',
        'America/Mazatlan' => 'Mazatlan (Meksiko Jáskesábi áigi)',
        'America/Menominee' => 'Menominee (dábálašáigi)',
        'America/Merida' => 'Mérida (dábálašáigi)',
        'America/Metlakatla' => 'Metlakatla (Alaska áigi)',
        'America/Mexico_City' => 'Mexico City (dábálašáigi)',
        'America/Miquelon' => 'Miquelon (St. Pierre & Miquelo áigi)',
        'America/Moncton' => 'Moncton (atlántalaš áigi)',
        'America/Monterrey' => 'Monterrey (dábálašáigi)',
        'America/Montevideo' => 'Montevideo (Uruguaya áigi)',
        'America/Montserrat' => 'Montserrat (atlántalaš áigi)',
        'America/Nassau' => 'Nassau (áigi nuortan)',
        'America/New_York' => 'New York (áigi nuortan)',
        'America/Nipigon' => 'Nipigon (áigi nuortan)',
        'America/Nome' => 'Nome (Alaska áigi)',
        'America/Noronha' => 'Fernando de Noronha áigi',
        'America/North_Dakota/Beulah' => 'Beulah, Davvi-Dakota (dábálašáigi)',
        'America/North_Dakota/Center' => 'Guovddáš, Davvi-Dakota (dábálašáigi)',
        'America/North_Dakota/New_Salem' => 'New Salem, Davvi-Dakota (dábálašáigi)',
        'America/Ojinaga' => 'Ojinaga (duottaráigi)',
        'America/Panama' => 'Panama (áigi nuortan)',
        'America/Pangnirtung' => 'Pangnirtung (áigi nuortan)',
        'America/Paramaribo' => 'Paramaribo (Suriname áigi)',
        'America/Phoenix' => 'Phoenix (duottaráigi)',
        'America/Port-au-Prince' => 'Port-au-Prince (áigi nuortan)',
        'America/Port_of_Spain' => 'Port of Spain (atlántalaš áigi)',
        'America/Porto_Velho' => 'Porto Velho (Amazona áigi)',
        'America/Puerto_Rico' => 'Puerto Rico (atlántalaš áigi)',
        'America/Punta_Arenas' => 'Punta Arenas (Chile áigi)',
        'America/Rainy_River' => 'Rainy River (dábálašáigi)',
        'America/Rankin_Inlet' => 'Rankin Inlet (dábálašáigi)',
        'America/Recife' => 'Recife (Brasilia áigi)',
        'America/Regina' => 'Regina (dábálašáigi)',
        'America/Resolute' => 'Resolute (dábálašáigi)',
        'America/Santa_Isabel' => 'Santa Isabel (Oarjedavvi-Meksiko áigi)',
        'America/Santarem' => 'Santarem (Brasilia áigi)',
        'America/Santiago' => 'Santiago (Chile áigi)',
        'America/Santo_Domingo' => 'Santo Domingo (atlántalaš áigi)',
        'America/Sao_Paulo' => 'São Paulo (Brasilia áigi)',
        'America/Scoresbysund' => 'Ittoqqortoormiit (Nuorta-Ruonáeatnama áigi)',
        'America/Sitka' => 'Sitka (Alaska áigi)',
        'America/St_Barthelemy' => 'Saint Barthélemy (atlántalaš áigi)',
        'America/St_Johns' => 'St. John’s (Newfoundlanda áigi)',
        'America/St_Kitts' => 'St. Kitts (atlántalaš áigi)',
        'America/St_Lucia' => 'St. Lucia (atlántalaš áigi)',
        'America/St_Thomas' => 'St. Thomas (atlántalaš áigi)',
        'America/St_Vincent' => 'St. Vincent (atlántalaš áigi)',
        'America/Swift_Current' => 'Swift Current (dábálašáigi)',
        'America/Tegucigalpa' => 'Tegucigalpa (dábálašáigi)',
        'America/Thule' => 'Thule (atlántalaš áigi)',
        'America/Thunder_Bay' => 'Thunder Bay (áigi nuortan)',
        'America/Tijuana' => 'Tijuana (Jaskesábi áigi)',
        'America/Toronto' => 'Toronto (áigi nuortan)',
        'America/Tortola' => 'Tortola (atlántalaš áigi)',
        'America/Vancouver' => 'Vancouver (Jaskesábi áigi)',
        'America/Winnipeg' => 'Winnipeg (dábálašáigi)',
        'America/Yakutat' => 'Yakutat (Alaska áigi)',
        'America/Yellowknife' => 'Yellowknife (duottaráigi)',
        'Antarctica/Davis' => 'Davisa áigi',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville áigi',
        'Antarctica/Macquarie' => 'Macquarie (Nuorta-Austrália áigi)',
        'Antarctica/Mawson' => 'Mawsona áigi',
        'Antarctica/McMurdo' => 'McMurdo (Ođđa-Selánda áigi)',
        'Antarctica/Palmer' => 'Palmer (Chile áigi)',
        'Antarctica/Rothera' => 'Rothera áigi',
        'Antarctica/Syowa' => 'Syowa áigi',
        'Antarctica/Troll' => 'Troll (Greenwicha áigi)',
        'Antarctica/Vostok' => 'Vostoka áigi',
        'Arctic/Longyearbyen' => 'Longyearbyen (Gaska-Eurohpá áigi)',
        'Asia/Aden' => 'Aden (Arábia áigi)',
        'Asia/Almaty' => 'Almaty (Nuorta-Kasakstana áigi)',
        'Asia/Amman' => 'Amman (Nuorta-Eurohpa áigi)',
        'Asia/Aqtau' => 'Aqtau (Oarje-Kasakstana áigi)',
        'Asia/Aqtobe' => 'Aqtobe (Oarje-Kasakstana áigi)',
        'Asia/Ashgabat' => 'Ashgabat (Turkmenistana áigi)',
        'Asia/Atyrau' => 'Atyrau (Oarje-Kasakstana áigi)',
        'Asia/Baghdad' => 'Baghdad (Arábia áigi)',
        'Asia/Bahrain' => 'Bahrain (Arábia áigi)',
        'Asia/Baku' => 'Baku (Aserbaižana áigi)',
        'Asia/Bangkok' => 'Bangkok (Indokiinná áigi)',
        'Asia/Beirut' => 'Beirut (Nuorta-Eurohpa áigi)',
        'Asia/Bishkek' => 'Bishkek (Kirgisia áigi)',
        'Asia/Brunei' => 'Brunei Darussalama áigi',
        'Asia/Calcutta' => 'Kolkata (India dálveáigi)',
        'Asia/Chita' => 'Chita (Jakucka áigi)',
        'Asia/Choibalsan' => 'Choibalsan (Ulan-Batora áigi)',
        'Asia/Colombo' => 'Colombo (India dálveáigi)',
        'Asia/Damascus' => 'Damaskos (Nuorta-Eurohpa áigi)',
        'Asia/Dhaka' => 'Dhaka (Bangladesha áigi)',
        'Asia/Dili' => 'Dili (Nuorta-Timora áigi)',
        'Asia/Dubai' => 'Dubai (Golfa dálveáigi)',
        'Asia/Dushanbe' => 'Dushanbe (Tažikistana áigi)',
        'Asia/Famagusta' => 'Famagusta (Nuorta-Eurohpa áigi)',
        'Asia/Gaza' => 'Gaza (Nuorta-Eurohpa áigi)',
        'Asia/Hebron' => 'Hebron (Nuorta-Eurohpa áigi)',
        'Asia/Hong_Kong' => 'Hong Konga áigi',
        'Asia/Hovd' => 'Hovda áigi',
        'Asia/Irkutsk' => 'Irkucka áigi',
        'Asia/Jakarta' => 'Jakarta (Oarje-Indonesia áigi)',
        'Asia/Jayapura' => 'Jayapura (Nuorta-Indonesia áigi)',
        'Asia/Jerusalem' => 'Jerusalem (Israela áigi)',
        'Asia/Kabul' => 'Kabul (Afganisthana áigi)',
        'Asia/Kamchatka' => 'Kamčatka (Ruošša áigi)',
        'Asia/Karachi' => 'Karachi (Pakistana áigi)',
        'Asia/Katmandu' => 'Kathmandu (Nepala áigi)',
        'Asia/Khandyga' => 'Khandyga (Jakucka áigi)',
        'Asia/Krasnoyarsk' => 'Krasnojarska áigi',
        'Asia/Kuwait' => 'Kuwait (Arábia áigi)',
        'Asia/Macau' => 'Macao (Kiinná áigi)',
        'Asia/Magadan' => 'Magadana áigi',
        'Asia/Makassar' => 'Makassar (Gaska-Indonesia áigi)',
        'Asia/Manila' => 'Manila (Filippiinnaid áigi)',
        'Asia/Muscat' => 'Muscat (Golfa dálveáigi)',
        'Asia/Nicosia' => 'Nicosia (Nuorta-Eurohpa áigi)',
        'Asia/Novokuznetsk' => 'Novokusneck (Krasnojarska áigi)',
        'Asia/Novosibirsk' => 'Novosibirska áigi',
        'Asia/Omsk' => 'Omska áigi',
        'Asia/Oral' => 'Oral (Oarje-Kasakstana áigi)',
        'Asia/Phnom_Penh' => 'Phnom Penh (Indokiinná áigi)',
        'Asia/Pontianak' => 'Pontianak (Oarje-Indonesia áigi)',
        'Asia/Pyongyang' => 'Pyongyang (Korea áigi)',
        'Asia/Qatar' => 'Qatar (Arábia áigi)',
        'Asia/Qostanay' => 'Qostanay (Nuorta-Kasakstana áigi)',
        'Asia/Qyzylorda' => 'Qyzylorda (Oarje-Kasakstana áigi)',
        'Asia/Rangoon' => 'Rangoon (Myanmara áigi)',
        'Asia/Riyadh' => 'Riyadh (Arábia áigi)',
        'Asia/Saigon' => 'Ho Chi Minh (Indokiinná áigi)',
        'Asia/Sakhalin' => 'Sahalina áigi',
        'Asia/Samarkand' => 'Samarkand (Usbekistana áigi)',
        'Asia/Seoul' => 'Seoul (Korea áigi)',
        'Asia/Singapore' => 'Singapore dálveáigi',
        'Asia/Srednekolymsk' => 'Srednekolymsk (Magadana áigi)',
        'Asia/Taipei' => 'Taipeia áigi',
        'Asia/Tashkent' => 'Tashkent (Usbekistana áigi)',
        'Asia/Tehran' => 'Teheran (Irana áigi)',
        'Asia/Thimphu' => 'Thimphu (Bhutana áigi)',
        'Asia/Ulaanbaatar' => 'Ulan-Batora áigi',
        'Asia/Ust-Nera' => 'Ust-Nera (Vladivostoka áigi)',
        'Asia/Vientiane' => 'Vientiane (Indokiinná áigi)',
        'Asia/Vladivostok' => 'Vladivostoka áigi',
        'Asia/Yakutsk' => 'Jakucka áigi',
        'Asia/Yekaterinburg' => 'Jekaterinburga áigi',
        'Asia/Yerevan' => 'Jerevan (Armenia áigi)',
        'Atlantic/Azores' => 'Azorat (Azoraid áigi)',
        'Atlantic/Bermuda' => 'Bermuda (atlántalaš áigi)',
        'Atlantic/Canary' => 'Kanária (Oarje-Eurohpá áigi)',
        'Atlantic/Cape_Verde' => 'Kap Verde áigi',
        'Atlantic/Faeroe' => 'Faroe (Oarje-Eurohpá áigi)',
        'Atlantic/Madeira' => 'Madeira (Oarje-Eurohpá áigi)',
        'Atlantic/Reykjavik' => 'Reykjavik (Greenwicha áigi)',
        'Atlantic/South_Georgia' => 'Lulli-Georgia áigi',
        'Atlantic/St_Helena' => 'St. Helena (Greenwicha áigi)',
        'Atlantic/Stanley' => 'Stanley (Falklandsulluid áigi)',
        'Australia/Adelaide' => 'Adelaide (Gaska-Austrália áigi)',
        'Australia/Brisbane' => 'Brisbane (Nuorta-Austrália áigi)',
        'Australia/Broken_Hill' => 'Broken Hill (Gaska-Austrália áigi)',
        'Australia/Currie' => 'Currie (Nuorta-Austrália áigi)',
        'Australia/Darwin' => 'Darwin (Gaska-Austrália áigi)',
        'Australia/Eucla' => 'Eucla (Gaska-Austrália oarjjabeali áigi)',
        'Australia/Hobart' => 'Hobart (Nuorta-Austrália áigi)',
        'Australia/Lindeman' => 'Lindeman (Nuorta-Austrália áigi)',
        'Australia/Lord_Howe' => 'Lord Howe áigi',
        'Australia/Melbourne' => 'Melbourne (Nuorta-Austrália áigi)',
        'Australia/Perth' => 'Perth (Oarje-Austrália áigi)',
        'Australia/Sydney' => 'Sydney (Nuorta-Austrália áigi)',
        'CST6CDT' => 'dábálašáigi',
        'EST5EDT' => 'áigi nuortan',
        'Etc/GMT' => 'Greenwicha áigi',
        'Etc/UTC' => 'koordinerejuvvon oktasaš áigi',
        'Europe/Amsterdam' => 'Amsterdam (Gaska-Eurohpá áigi)',
        'Europe/Andorra' => 'Andorra (Gaska-Eurohpá áigi)',
        'Europe/Astrakhan' => 'Astrakhan (Moskva áigi)',
        'Europe/Athens' => 'Athena (Nuorta-Eurohpa áigi)',
        'Europe/Belgrade' => 'Belgrad (Gaska-Eurohpá áigi)',
        'Europe/Berlin' => 'Berlin (Gaska-Eurohpá áigi)',
        'Europe/Bratislava' => 'Bratislava (Gaska-Eurohpá áigi)',
        'Europe/Brussels' => 'Brüssel (Gaska-Eurohpá áigi)',
        'Europe/Bucharest' => 'Bukarest (Nuorta-Eurohpa áigi)',
        'Europe/Budapest' => 'Budapest (Gaska-Eurohpá áigi)',
        'Europe/Busingen' => 'Busingen (Gaska-Eurohpá áigi)',
        'Europe/Chisinau' => 'Chisinau (Nuorta-Eurohpa áigi)',
        'Europe/Copenhagen' => 'København (Gaska-Eurohpá áigi)',
        'Europe/Dublin' => 'Dublin (Greenwicha áigi)',
        'Europe/Gibraltar' => 'Gibraltar (Gaska-Eurohpá áigi)',
        'Europe/Guernsey' => 'Guernsey (Greenwicha áigi)',
        'Europe/Helsinki' => 'Helsset (Nuorta-Eurohpa áigi)',
        'Europe/Isle_of_Man' => 'Mansuolu (Greenwicha áigi)',
        'Europe/Jersey' => 'Jersey (Greenwicha áigi)',
        'Europe/Kaliningrad' => 'Kaliningrad (Nuorta-Eurohpa áigi)',
        'Europe/Kiev' => 'Kyiv (Nuorta-Eurohpa áigi)',
        'Europe/Lisbon' => 'Lisboa (Oarje-Eurohpá áigi)',
        'Europe/Ljubljana' => 'Ljubljana (Gaska-Eurohpá áigi)',
        'Europe/London' => 'London (Greenwicha áigi)',
        'Europe/Luxembourg' => 'Luxenburg (Gaska-Eurohpá áigi)',
        'Europe/Madrid' => 'Madrid (Gaska-Eurohpá áigi)',
        'Europe/Malta' => 'Malta (Gaska-Eurohpá áigi)',
        'Europe/Mariehamn' => 'Mariehamn (Nuorta-Eurohpa áigi)',
        'Europe/Minsk' => 'Minsk (Moskva áigi)',
        'Europe/Monaco' => 'Monaco (Gaska-Eurohpá áigi)',
        'Europe/Moscow' => 'Moskva áigi',
        'Europe/Oslo' => 'Oslo (Gaska-Eurohpá áigi)',
        'Europe/Paris' => 'Paris (Gaska-Eurohpá áigi)',
        'Europe/Podgorica' => 'Podgorica (Gaska-Eurohpá áigi)',
        'Europe/Prague' => 'Praha (Gaska-Eurohpá áigi)',
        'Europe/Riga' => 'Riga (Nuorta-Eurohpa áigi)',
        'Europe/Rome' => 'Roma (Gaska-Eurohpá áigi)',
        'Europe/San_Marino' => 'San Marino (Gaska-Eurohpá áigi)',
        'Europe/Sarajevo' => 'Sarajevo (Gaska-Eurohpá áigi)',
        'Europe/Saratov' => 'Saratov (Moskva áigi)',
        'Europe/Simferopol' => 'Simferopol (Moskva áigi)',
        'Europe/Skopje' => 'Skopje (Gaska-Eurohpá áigi)',
        'Europe/Sofia' => 'Sofia (Nuorta-Eurohpa áigi)',
        'Europe/Stockholm' => 'Stockholm (Gaska-Eurohpá áigi)',
        'Europe/Tallinn' => 'Tallinn (Nuorta-Eurohpa áigi)',
        'Europe/Tirane' => 'Tirana (Gaska-Eurohpá áigi)',
        'Europe/Ulyanovsk' => 'Uljanovsk (Moskva áigi)',
        'Europe/Uzhgorod' => 'Uzhgorod (Nuorta-Eurohpa áigi)',
        'Europe/Vaduz' => 'Vaduz (Gaska-Eurohpá áigi)',
        'Europe/Vatican' => 'Vatican (Gaska-Eurohpá áigi)',
        'Europe/Vienna' => 'Wien (Gaska-Eurohpá áigi)',
        'Europe/Vilnius' => 'Vilnius (Nuorta-Eurohpa áigi)',
        'Europe/Volgograd' => 'Volgograda áigi',
        'Europe/Warsaw' => 'Warsawa (Gaska-Eurohpá áigi)',
        'Europe/Zagreb' => 'Zagreb (Gaska-Eurohpá áigi)',
        'Europe/Zaporozhye' => 'Zaporozhye (Nuorta-Eurohpa áigi)',
        'Europe/Zurich' => 'Zürich (Gaska-Eurohpá áigi)',
        'Indian/Antananarivo' => 'Antananarivo (Nuorta-Afrihká áigi)',
        'Indian/Chagos' => 'Chagos (Indiaábi áigi)',
        'Indian/Christmas' => 'Juovlasuolu (Juovlasullo áigi)',
        'Indian/Cocos' => 'Kokossulloid áigi',
        'Indian/Comoro' => 'Comoro (Nuorta-Afrihká áigi)',
        'Indian/Kerguelen' => 'Kerguelen (Frankriikka lulli & antárktisa áigi)',
        'Indian/Mahe' => 'Mahe (Seychellaid áigi)',
        'Indian/Maldives' => 'Malediivvat (Malediivvaid áigi)',
        'Indian/Mauritius' => 'Mauritiusa áigi',
        'Indian/Mayotte' => 'Mayotte (Nuorta-Afrihká áigi)',
        'Indian/Reunion' => 'Reuniona áigi',
        'MST7MDT' => 'duottaráigi',
        'PST8PDT' => 'Jaskesábi áigi',
        'Pacific/Apia' => 'Apia áigi',
        'Pacific/Bougainville' => 'Bougainville (Papua Ođđa-Guinea áigi)',
        'Pacific/Chatham' => 'Chathama áigi',
        'Pacific/Easter' => 'Easter (Beassášsullo áigi)',
        'Pacific/Enderbury' => 'Enderbury (Phoenixsulloid áigi)',
        'Pacific/Fakaofo' => 'Fakaofo (Tokelaua áigi)',
        'Pacific/Fiji' => 'Fiji áigi',
        'Pacific/Galapagos' => 'Galapagosa áigi',
        'Pacific/Gambier' => 'Gambiera áigi',
        'Pacific/Guadalcanal' => 'Guadalcanal (Salomonsulloid áigi)',
        'Pacific/Guam' => 'Guam (Čamorro dálveáigi)',
        'Pacific/Honolulu' => 'Honolulu (Hawaii-aleuhtalaš áigi)',
        'Pacific/Johnston' => 'Johnston (Hawaii-aleuhtalaš áigi)',
        'Pacific/Kiritimati' => 'Kiritimati (Linesulloid áigi)',
        'Pacific/Kosrae' => 'Kosraea áigi',
        'Pacific/Kwajalein' => 'Kwajalein (Marshallsulloid áigi)',
        'Pacific/Majuro' => 'Majuro (Marshallsulloid áigi)',
        'Pacific/Marquesas' => 'Marquesasat (Marquesasiid áigi)',
        'Pacific/Midway' => 'Midway (Samoa áigi)',
        'Pacific/Nauru' => 'Nauru áigi',
        'Pacific/Niue' => 'Niuea áigi',
        'Pacific/Norfolk' => 'Norfolksullo áigi',
        'Pacific/Pago_Pago' => 'Pago Pago (Samoa áigi)',
        'Pacific/Palau' => 'Palaua áigi',
        'Pacific/Pitcairn' => 'Pitcairnsulloid áigi',
        'Pacific/Ponape' => 'Pohnpei (Ponape áigi)',
        'Pacific/Port_Moresby' => 'Port Moresby (Papua Ođđa-Guinea áigi)',
        'Pacific/Rarotonga' => 'Rarotonga (Cooksulloid áigi)',
        'Pacific/Saipan' => 'Saipan (Čamorro dálveáigi)',
        'Pacific/Tahiti' => 'Tahiti áigi',
        'Pacific/Tarawa' => 'Tarawa (Gilbertsulloid áigi)',
        'Pacific/Truk' => 'Chuuka áigi',
        'Pacific/Wake' => 'Wakesullo áigi',
        'Pacific/Wallis' => 'Wallis- ja Futuna áigi',
    ],
    'Meta' => [
        'GmtFormat' => '%s GMT',
        'HourFormatNeg' => '-%02d:%02d',
    ],
];
