<?php

return [
    'Names' => [
        'ak' => 'akankan',
        'am' => 'amarikikan',
        'ar' => 'larabukan',
        'be' => 'biyelorisikan',
        'bg' => 'buligarikan',
        'bm' => 'bamanakan',
        'bn' => 'bɛngalikan',
        'cs' => 'cɛkikan',
        'de' => 'alimaɲikan',
        'el' => 'gɛrɛsikan',
        'en' => 'angilɛkan',
        'es' => 'esipaɲolkan',
        'fa' => 'perisanikan',
        'fr' => 'tubabukan',
        'ha' => 'awusakan',
        'hi' => 'inidikan',
        'hu' => 'oŋirikan',
        'id' => 'Ɛndonezikan',
        'ig' => 'igibokan',
        'it' => 'italikan',
        'ja' => 'zapɔnekan',
        'jv' => 'javanekan',
        'km' => 'kambojikan',
        'ko' => 'korekan',
        'ms' => 'malɛzikan',
        'my' => 'birimanikan',
        'ne' => 'nepalekan',
        'nl' => 'olandekan',
        'pa' => 'pɛnijabikan',
        'pl' => 'polonekan',
        'pt' => 'pɔritigalikan',
        'ro' => 'rumanikan',
        'ru' => 'irisikan',
        'rw' => 'ruwandakan',
        'so' => 'somalikan',
        'sv' => 'suwɛdikan',
        'ta' => 'tamulikan',
        'th' => 'tayikan',
        'tr' => 'turikikan',
        'uk' => 'ukɛrɛnikan',
        'ur' => 'urudukan',
        'vi' => 'wiyɛtinamukan',
        'yo' => 'yorubakan',
        'zh' => 'siniwakan',
        'zu' => 'zulukan',
    ],
    'LocalizedNames' => [
    ],
];
