<?php

return [
    'Names' => [
        'CG' => 'Kongo',
        'CV' => 'Kabo Verde',
        'CZ' => 'Češka Republika',
        'HK' => 'SAR Hongkong',
        'KN' => 'Sveti Kits i Nevis',
        'MO' => 'SAR Makao',
        'PM' => 'Sveti Pjer i Mikelon',
        'RE' => 'Reunion',
        'UM' => 'Manja udaljena ostrva SAD',
        'VC' => 'Sveti Vinsent i Grenadini',
    ],
];
