<?php

declare(strict_types=1);

namespace SimpleSAML\Error;

/**
 * Exception indicating wrong password given by user.
 *
 * @package SimpleSAMLphp_base
 *
 */

class InvalidCredential extends User
{
}
