<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Diramu ya Falme za Kiarabu',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghani ya Afghanistani',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Gilda ya Antili ya Uholanzi',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Manati ya Azabajani',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Maki ya Bosnia na Hezegovina Inayoweza Kubadilishwa',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dola ya Babadosi',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Taka ya Bangladeshi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dola ya Bamuda',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Reale ya Brazili',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dola ya Bahama',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ngultrumi ya Bhutani',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Ruble ya Belarusi',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dola ya Kanada',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yuan ya China (huru)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Yuan ya China',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Eskudo ya Kepuvede',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna ya Cheki',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Kroni ya Denmaki',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dinari ya Aljeria',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lari ya Jiojia',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Sidi ya Ghana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Pauni ya Jibrata',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kuna ya Kroeshia',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Godi ya Haiti',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Forinti ya Hungaria',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rupia ya Indonesia',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Riali ya Irani',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dinari ya Yordani',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni ya Japani',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Rieli ya Kambodia',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tenge ya Kazakistani',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Pauni ya Lebanoni',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Diramu ya Moroko',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Dinari ya Masedonia',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kiati ya Myama',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pataka ya Macau',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rufiyaa ya Maldivi',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ringgiti ya Malesia',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Naira ya Naijeria',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Kroni ya Norwe',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rupia ya Nepali',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Riali ya Omani',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rupia ya Pakistani',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Zloti ya Polandi',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Riali ya Katari',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dinari ya Serbia',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riyali ya Saudia',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dola ya Visiwa vya Solomoni',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Pauni ya Sudani',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dola ya Singapoo',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Leoni ya Siera Leoni',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Pauni ya Sudani Kusini',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Bahti ya Tailandi',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Somoni ya Tajikistani',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Manati ya Turkmenistani',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dola ya Trinidadi na Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dola ya Taiwani',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Hryvnia ya Ukraini',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dola ya Marekani',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Som ya Uzbekistani',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Boliva ya Venezuela',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dong ya Vietnamu',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Faranga ya CFA ya Afrika ya Kati',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faranga ya CFA ya Afrika Magharibi',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Riali ya Yemeni',
        ],
    ],
];
