<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abkhazo',
        'ace' => 'achinés',
        'ach' => 'acholí',
        'ada' => 'adangme',
        'ady' => 'adigueo',
        'af' => 'afrikaans',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'ale' => 'aleutiano',
        'alt' => 'altai meridional',
        'am' => 'amhárico',
        'an' => 'aragonés',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'árabe',
        'arc' => 'arameo',
        'arn' => 'mapuche',
        'arp' => 'arapaho',
        'ars' => 'árabe najdi',
        'as' => 'assamés',
        'asa' => 'asu',
        'ast' => 'asturiano',
        'atj' => 'atikamekw',
        'av' => 'avar',
        'awa' => 'awadhi',
        'ay' => 'aimará',
        'az' => 'acerbaixano',
        'ba' => 'baxkir',
        'ban' => 'balinés',
        'bas' => 'basaa',
        'be' => 'belaruso',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'búlgaro',
        'bgn' => 'baluchi occidental',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bin' => 'bini',
        'bla' => 'siksiká',
        'bm' => 'bambara',
        'bn' => 'bengalí',
        'bo' => 'tibetano',
        'br' => 'bretón',
        'brx' => 'bodo',
        'bs' => 'bosníaco',
        'bug' => 'buginés',
        'byn' => 'blin',
        'ca' => 'catalán',
        'cay' => 'cayuga',
        'ccp' => 'chakma',
        'ce' => 'checheno',
        'ceb' => 'cebuano',
        'cgg' => 'kiga',
        'ch' => 'chamorro',
        'chk' => 'chuuk',
        'chm' => 'mari',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'kurdo central',
        'clc' => 'chilcotin',
        'co' => 'corso',
        'crg' => 'michif',
        'crj' => 'cree do sueste',
        'crk' => 'cree das chairas',
        'crl' => 'cree do nordeste',
        'crm' => 'cree de Moose',
        'crr' => 'algonquino de Carolina',
        'crs' => 'seselwa (crioulo das Seychelles)',
        'cs' => 'checo',
        'csw' => 'cree dos pantanos',
        'cu' => 'eslavo eclesiástico',
        'cv' => 'chuvaxo',
        'cy' => 'galés',
        'da' => 'dinamarqués',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'alemán',
        'dgr' => 'dogrib',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'baixo sorbio',
        'dua' => 'duala',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egy' => 'exipcio antigo',
        'eka' => 'ekajuk',
        'el' => 'grego',
        'en' => 'inglés',
        'eo' => 'esperanto',
        'es' => 'español',
        'et' => 'estoniano',
        'eu' => 'éuscaro',
        'ewo' => 'ewondo',
        'fa' => 'persa',
        'ff' => 'fula',
        'fi' => 'finés',
        'fil' => 'filipino',
        'fj' => 'fixiano',
        'fo' => 'feroés',
        'fon' => 'fon',
        'fr' => 'francés',
        'frc' => 'francés cajun',
        'frr' => 'frisón setentrional',
        'fur' => 'friulano',
        'fy' => 'frisón occidental',
        'ga' => 'irlandés',
        'gaa' => 'ga',
        'gag' => 'gagauz',
        'gd' => 'gaélico escocés',
        'gez' => 'ge’ez',
        'gil' => 'kiribatiano',
        'gl' => 'galego',
        'gn' => 'guaraní',
        'gor' => 'gorontalo',
        'grc' => 'grego antigo',
        'gsw' => 'alemán suízo',
        'gu' => 'guxarati',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwichʼin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'haw' => 'hawaiano',
        'hax' => 'haida do sur',
        'he' => 'hebreo',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hmn' => 'hmong',
        'hr' => 'croata',
        'hsb' => 'alto sorbio',
        'ht' => 'crioulo haitiano',
        'hu' => 'húngaro',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armenio',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesio',
        'ig' => 'igbo',
        'ii' => 'yi sichuanés',
        'ikt' => 'inuktitut canadense occidental',
        'ilo' => 'ilocano',
        'inh' => 'inguxo',
        'io' => 'ido',
        'is' => 'islandés',
        'it' => 'italiano',
        'iu' => 'inuktitut',
        'ja' => 'xaponés',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'xavanés',
        'ka' => 'xeorxiano',
        'kab' => 'cabila',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kbd' => 'cabardiano',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'caboverdiano',
        'kfo' => 'koro',
        'kg' => 'kongo',
        'kgp' => 'caingangue',
        'kha' => 'khasi',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kazako',
        'kkj' => 'kako',
        'kl' => 'groenlandés',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannará',
        'ko' => 'coreano',
        'koi' => 'komi permio',
        'kok' => 'konkani',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'carachaio-bálcara',
        'krl' => 'carelio',
        'kru' => 'kurukh',
        'ks' => 'caxemirés',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'kurdo',
        'kum' => 'kumyk',
        'kv' => 'komi',
        'kw' => 'córnico',
        'kwk' => 'kwakiutl',
        'ky' => 'kirguiz',
        'la' => 'latín',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lb' => 'luxemburgués',
        'lez' => 'lezguio',
        'lg' => 'ganda',
        'li' => 'limburgués',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'laosiano',
        'lou' => 'crioulo de Luisiana',
        'loz' => 'lozi',
        'lrc' => 'luri setentrional',
        'lsm' => 'saamia',
        'lt' => 'lituano',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'letón',
        'mad' => 'madurés',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'crioulo mauriciano',
        'mg' => 'malgaxe',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshalés',
        'mi' => 'maorí',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'macedonio',
        'ml' => 'malabar',
        'mn' => 'mongol',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malaio',
        'mt' => 'maltés',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandés',
        'my' => 'birmano',
        'myv' => 'erzya',
        'mzn' => 'mazandaraní',
        'na' => 'nauruano',
        'nap' => 'napolitano',
        'naq' => 'nama',
        'nb' => 'noruegués bokmål',
        'nd' => 'ndebele setentrional',
        'nds' => 'baixo alemán',
        'ne' => 'nepalí',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niueano',
        'nl' => 'neerlandés',
        'nmg' => 'kwasio',
        'nn' => 'noruegués nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'noruegués',
        'nog' => 'nogai',
        'nqo' => 'n’ko',
        'nr' => 'ndebele meridional',
        'nso' => 'sesotho do norte',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'ny' => 'chewa',
        'nyn' => 'nyankole',
        'oc' => 'occitano',
        'ojb' => 'ojibwa do noroeste',
        'ojc' => 'ojibwa',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwa do oeste',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'odiá',
        'os' => 'ossetio',
        'pa' => 'panxabí',
        'pag' => 'pangasinan',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauano',
        'pcm' => 'pidgin nixeriano',
        'pis' => 'pijin',
        'pl' => 'polaco',
        'pqm' => 'malecite-passamaquoddy',
        'prg' => 'prusiano',
        'ps' => 'paxto',
        'pt' => 'portugués',
        'qu' => 'quechua',
        'quc' => 'quiché',
        'rap' => 'rapanui',
        'rar' => 'rarotongano',
        'rhg' => 'rohingya',
        'rm' => 'romanche',
        'rn' => 'rundi',
        'ro' => 'romanés',
        'rof' => 'rombo',
        'ru' => 'ruso',
        'rup' => 'aromanés',
        'rw' => 'kiñaruanda',
        'rwk' => 'rwa',
        'sa' => 'sánscrito',
        'sad' => 'sandawe',
        'sah' => 'iacuto',
        'saq' => 'samburu',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardo',
        'scn' => 'siciliano',
        'sco' => 'escocés',
        'sd' => 'sindhi',
        'sdh' => 'kurdo meridional',
        'se' => 'saami setentrional',
        'seh' => 'sena',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sh' => 'serbocroata',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'si' => 'cingalés',
        'sk' => 'eslovaco',
        'sl' => 'esloveno',
        'slh' => 'lushootseed do sur',
        'sm' => 'samoano',
        'sma' => 'saami meridional',
        'smj' => 'saami de Lule',
        'smn' => 'saami de Inari',
        'sms' => 'saami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somalí',
        'sq' => 'albanés',
        'sr' => 'serbio',
        'srn' => 'sranan tongo',
        'ss' => 'suazi',
        'ssy' => 'saho',
        'st' => 'sesotho',
        'str' => 'salish dos estreitos',
        'su' => 'sundanés',
        'suk' => 'sukuma',
        'sv' => 'sueco',
        'sw' => 'suahili',
        'swb' => 'comoriano',
        'syr' => 'siríaco',
        'ta' => 'támil',
        'tce' => 'tutchone do sur',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'tet' => 'tetun',
        'tg' => 'taxico',
        'tgx' => 'tagish',
        'th' => 'tailandés',
        'tht' => 'tahltan',
        'ti' => 'tigriña',
        'tig' => 'tigré',
        'tk' => 'turkmeno',
        'tl' => 'tagalo',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tn' => 'tswana',
        'to' => 'tongano',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turco',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tt' => 'tártaro',
        'ttm' => 'tutchone do norte',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalés',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitiano',
        'tyv' => 'tuvaniano',
        'tzm' => 'tamazight de Marrocos central',
        'udm' => 'udmurto',
        'ug' => 'uigur',
        'uk' => 'ucraíno',
        'umb' => 'umbundu',
        'ur' => 'urdú',
        'uz' => 'uzbeko',
        'vai' => 'vai',
        've' => 'venda',
        'vi' => 'vietnamita',
        'vo' => 'volapuk',
        'vun' => 'vunjo',
        'wa' => 'valón',
        'wae' => 'walser',
        'wal' => 'wolaytta',
        'war' => 'waray-waray',
        'wbp' => 'walrpiri',
        'wo' => 'wólof',
        'wuu' => 'chinés wu',
        'xal' => 'calmuco',
        'xh' => 'xhosa',
        'xog' => 'soga',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'yiddish',
        'yo' => 'ioruba',
        'yrl' => 'nheengatu',
        'yue' => 'cantonés',
        'zgh' => 'tamazight marroquí estándar',
        'zh' => 'chinés',
        'zu' => 'zulú',
        'zun' => 'zuni',
        'zza' => 'zazaki',
    ],
    'LocalizedNames' => [
        'ar_001' => 'árabe estándar moderno',
        'de_AT' => 'alemán austríaco',
        'de_CH' => 'alto alemán suízo',
        'en_AU' => 'inglés australiano',
        'en_CA' => 'inglés canadense',
        'en_GB' => 'inglés británico',
        'en_US' => 'inglés estadounidense',
        'es_419' => 'español de América',
        'es_ES' => 'español de España',
        'es_MX' => 'español de México',
        'fa_AF' => 'dari',
        'fr_CA' => 'francés canadense',
        'fr_CH' => 'francés suízo',
        'hi_Latn' => 'hindi (alfabeto latino)',
        'nds_NL' => 'baixo saxón',
        'nl_BE' => 'flamengo',
        'pt_BR' => 'portugués do Brasil',
        'pt_PT' => 'portugués de Portugal',
        'ro_MD' => 'moldavo',
        'sw_CD' => 'suahili congolés',
        'zh_Hans' => 'chinés simplificado',
        'zh_Hant' => 'chinés tradicional',
    ],
];
