<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'andorska pezeta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'UAE dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'afganistanski afgani (1927.–2002.)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afganistanski afgani',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'stari albanski lek',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albanski lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'armenski dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'nizozemskoantilski gulden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angolska kvanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'angolska kvanza (1977.–1990.)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'angolska nova kvanza (1990.–2000.)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'angolska kvanza (1995.–1999.)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'argentinski austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'argentinski pezo lej (1970.–1983.)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'argentinski pezo (1881.–1970.)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'argentinski pezo (1983.–1985.)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentinski pezo',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'austrijski šiling',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'australski dolar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arupski florin',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'azerbajdžanski manat (1993.–2006.)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'azerbajdžanski manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'bosansko-hercegovački dinar',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'konvertibilna marka',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'bosansko-hercegovački novi dinar',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadoski dolar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladeška taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'belgijski franak (konvertibilan)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'belgijski franak',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'belgijski franak (financijski)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'bugarski čvrsti lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'bugarski socijalistički lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'bugarski lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'stari bugarski lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahreinski dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'burundski franak',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'bermudski dolar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'brunejski dolar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'bolivijski bolivijano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'stari bolivijski bolivijano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'bolivijski pezo',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'bolivijski mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'brazilski novi cruzeiro (1967.–1986.)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'brazilski cruzado',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'brazilski cruzeiro (1990.–1993.)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'brazilski real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'brazilski novi cruzado',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'brazilski cruzeiro',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'BRZ',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'bahamski dolar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'butanski ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'burmanski kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'bocvanska pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'bjeloruska nova rublja (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'bjeloruski rubalj',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'bjeloruska rublja (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'belizeanski dolar',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'kanadski dolar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'kongoanski franak',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'švicarski franak',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR franak',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'čileanski eskudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'čileanski unidades de fomentos',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'čileanski pezo',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'kineski juan (offshore)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'kineski narodni dolar',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'kineski yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'kolumbijski pezo',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'unidad de valor real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'kostarikanski kolon',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'stari srpski dinar',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'čehoslovačka kruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'kubanski konvertibilni pezo',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'kubanski pezo',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'zelenortski eskudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'ciparska funta',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'češka kruna',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'istočnonjemačka marka',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'njemačka marka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'džibutski franak',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'danska kruna',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dominikanski pezo',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'alžirski dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'ekvatorska sukra',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'ekvatorski unidad de valor constante (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'estonska kruna',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egipatska funta',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'eritrejska nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'španjolska pezeta (A račun)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'španjolska pezeta (konvertibilni račun)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'španjolska pezeta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'etiopski bir',
        ],
        'EUR' => [
            0 => '€',
            1 => 'euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'finska marka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fidžijski dolar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'falklandska funta',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'francuski franak',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'britanska funta',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'gruzijski kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'gruzijski lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ganski cedi (1979.–2007.)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ganski cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'gibraltarska funta',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambijski dalas',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'gvinejski franak',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'gvinejski syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekvatorski gvinejski ekwele',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'grčka drahma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'gvatemalski kvecal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'portugalski gvinejski eskudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'gvinejskobisauski pezo',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'gvajanski dolar',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'hongkonški dolar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'honduraška lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'hrvatski dinar',
        ],
        'HRK' => [
            0 => 'kn',
            1 => 'hrvatska kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haićanski gourd',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'mađarska forinta',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indonezijska rupija',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'irska funta',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'izraelska funta',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'stari izraelski šekel',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'novi izraelski šekel',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'indijska rupija',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'irački dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iranski rijal',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'stara islandska kruna',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'islandska kruna',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'talijanska lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamajčanski dolar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jordanski dinar',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'japanski jen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenijski šiling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgiski som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'kambodžanski rijal',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'komorski franak',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'sjevernokorejski won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'južnokorejski hvan',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'stari južnokorejski von',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'južnokorejski won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuvajtski dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'kajmanski dolar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kazahstanski tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laoski kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'libanonska funta',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'šrilankanska rupija',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'liberijski dolar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesotski loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litavski litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'litavski talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'luksemburški konvertibilni franak',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'luksemburški franak',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'luksemburški financijski franak',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'letonski lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'letonska rublja',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'libijski dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'marokanski dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'marokanski franak',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'MCF',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'moldavski kupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldavski lej',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'malgaški arijari',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'madagaskarski franak',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'makedonski denar',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'stari makedonski denar',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'malijski franak',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'mjanmarski kjat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongolski tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'makaoška pataka',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'mauritanijska ouguja (1973. – 2017.)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mauritanijska ouguja',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'malteška lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'malteška funta',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'mauricijska rupija',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'maldivijska rupija',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldivijska rufija',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'malavijska kvača',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'meksički pezo',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'meksički srebrni pezo (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'meksički unidad de inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malezijski ringit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'mozambijski eskudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'stari mozambijski metikal',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'mozambički metikal',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'namibijski dolar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nigerijska naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'nikaragvanska kordoba',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'nikaragvanska zlatna kordoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'nizozemski gulden',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'norveška kruna',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepalska rupija',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'novozelandski dolar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'omanski rijal',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'panamska balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'peruanski inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'peruanski sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'peruanski sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina Papue Nove Gvineje',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'filipinski pezo',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistanska rupija',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'poljska zlota',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'poljska zlota (1950.–1995.)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'portugalski eskudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paragvajski gvarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'katarski rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'rodezijski dolar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'starorumunjski lek',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'rumunjski lej',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'srpski dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'ruski rubalj',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'ruska rublja (1991.–1998.)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'ruandski franak',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'saudijski rijal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'solmonskootočni dolar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'sejšelska rupija',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'sudanski dinar',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sudanska funta',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'stara sudanska funta',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'švedska kruna',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singapurski dolar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'svetohelenska funta',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'slovenski tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'slovačka kruna',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'sijeraleonski leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'somalijski šiling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'surinamski dolar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'surinamski gulden',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'južnosudanska funta',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'dobra Svetog Tome i Principa (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'dobra Svetog Tome i Principa',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'sovjetska rublja',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'salvadorski kolon',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'sirijska funta',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'svazi lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'tajlandski baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'tajikistanska rublja',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tadžikistanski somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'turkmenistanski manat (1993.–2009.)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'turkmenistanski manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tuniski dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'tongaška pa’anga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'timorski eskudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'turska lira (1922.–2005.)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'turska lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'trininadtobaški dolar',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'novotajvanski dolar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'tanzanijski šiling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ukrajinska hrivnja',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ukrajinski karbovanet',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'ugandski šiling (1966.–1987.)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ugandski šiling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'američki dolar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'američki dolar (sljedeći dan)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'američki dolar (isti dan)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'urugvajski pezo en unidades indexadas',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'urugvajski pezo (1975.–1993.)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'urugvajski pezo',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'uzbekistanski som',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'venezuelanski bolivar (1871.–2008.)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venezuelanski bolivar (2008. – 2018.)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venezuelanski bolivar',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'vijetnamski dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'vijetnamski dong (1978.–1985.)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuatski vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'samoanska tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA franak BEAC',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'istočnokaripski dolar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'europska monetarna jedinica (ECU)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'francuski zlatni franak',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'francuski UIC-franak',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'CFA franak BCEAO',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'CFP franak',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET fondovi',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'jemenski dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'jemenski rijal',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'jugoslavenski čvrsti dinar',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'jugoslavenski novi dinar',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'jugoslavenski konvertibilni dinar',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'jugoslavenski reformirani dinar',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'južnoafrički rand (financijski)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'južnoafrički rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'zambijska kvača (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'zambijska kvača',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zairski novi zair',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zairski zair',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'zimbabveanski dolar (1980.–2008.)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'zimbabveanski dolar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'zimbabveanski dolar (2008)',
        ],
    ],
];
