<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'GMT (ኣቢጃን)',
        'Africa/Accra' => 'GMT (ኣክራ)',
        'Africa/Addis_Ababa' => 'ግዜ ምብራቕ ኣፍሪቃ (ኣዲስ ኣበባ)',
        'Africa/Algiers' => 'ግዜ ማእከላይ ኤውሮጳ (ኣልጀርስ)',
        'Africa/Asmera' => 'ግዜ ምብራቕ ኣፍሪቃ (ኣስመራ)',
        'Africa/Bamako' => 'GMT (ባማኮ)',
        'Africa/Bangui' => 'ግዜ ምዕራብ ኣፍሪቃ (ባንጊ)',
        'Africa/Banjul' => 'GMT (ባንጁል)',
        'Africa/Bissau' => 'GMT (ቢሳው)',
        'Africa/Blantyre' => 'ግዜ ማእከላይ ኣፍሪቃ (ብላንታየር)',
        'Africa/Brazzaville' => 'ግዜ ምዕራብ ኣፍሪቃ (ብራዛቪል)',
        'Africa/Bujumbura' => 'ግዜ ማእከላይ ኣፍሪቃ (ቡጁምቡራ)',
        'Africa/Cairo' => 'ግዜ ምብራቕ ኤውሮጳ (ካይሮ)',
        'Africa/Casablanca' => 'ግዜ ሞሮኮ (ካዛብላንካ)',
        'Africa/Ceuta' => 'ግዜ ማእከላይ ኤውሮጳ (ሴውታ)',
        'Africa/Conakry' => 'GMT (ኮናክሪ)',
        'Africa/Dakar' => 'GMT (ዳካር)',
        'Africa/Dar_es_Salaam' => 'ግዜ ምብራቕ ኣፍሪቃ (ዳር ኤስ ሳላም)',
        'Africa/Djibouti' => 'ግዜ ምብራቕ ኣፍሪቃ (ጅቡቲ)',
        'Africa/Douala' => 'ግዜ ምዕራብ ኣፍሪቃ (ዱዋላ)',
        'Africa/El_Aaiun' => 'ግዜ ምዕራባዊ ሰሃራ (ኤል ኣዩን)',
        'Africa/Freetown' => 'GMT (ፍሪታውን)',
        'Africa/Gaborone' => 'ግዜ ማእከላይ ኣፍሪቃ (ጋቦሮን)',
        'Africa/Harare' => 'ግዜ ማእከላይ ኣፍሪቃ (ሃራረ)',
        'Africa/Johannesburg' => 'ግዜ ደቡብ ኣፍሪቃ (ጆሃንስበርግ)',
        'Africa/Juba' => 'ግዜ ማእከላይ ኣፍሪቃ (ጁባ)',
        'Africa/Kampala' => 'ግዜ ምብራቕ ኣፍሪቃ (ካምፓላ)',
        'Africa/Khartoum' => 'ግዜ ማእከላይ ኣፍሪቃ (ካርቱም)',
        'Africa/Kigali' => 'ግዜ ማእከላይ ኣፍሪቃ (ኪጋሊ)',
        'Africa/Kinshasa' => 'ግዜ ምዕራብ ኣፍሪቃ (ኪንሻሳ)',
        'Africa/Lagos' => 'ግዜ ምዕራብ ኣፍሪቃ (ሌጎስ)',
        'Africa/Libreville' => 'ግዜ ምዕራብ ኣፍሪቃ (ሊብረቪል)',
        'Africa/Lome' => 'GMT (ሎመ)',
        'Africa/Luanda' => 'ግዜ ምዕራብ ኣፍሪቃ (ሉዋንዳ)',
        'Africa/Lubumbashi' => 'ግዜ ማእከላይ ኣፍሪቃ (ሉቡምባሺ)',
        'Africa/Lusaka' => 'ግዜ ማእከላይ ኣፍሪቃ (ሉሳካ)',
        'Africa/Malabo' => 'ግዜ ምዕራብ ኣፍሪቃ (ማላቦ)',
        'Africa/Maputo' => 'ግዜ ማእከላይ ኣፍሪቃ (ማፑቶ)',
        'Africa/Maseru' => 'ግዜ ደቡብ ኣፍሪቃ (ማሰሩ)',
        'Africa/Mbabane' => 'ግዜ ደቡብ ኣፍሪቃ (ምባባነ)',
        'Africa/Mogadishu' => 'ግዜ ምብራቕ ኣፍሪቃ (ሞቓድሾ)',
        'Africa/Monrovia' => 'GMT (ሞንሮቭያ)',
        'Africa/Nairobi' => 'ግዜ ምብራቕ ኣፍሪቃ (ናይሮቢ)',
        'Africa/Ndjamena' => 'ግዜ ምዕራብ ኣፍሪቃ (ንጃመና)',
        'Africa/Niamey' => 'ግዜ ምዕራብ ኣፍሪቃ (ንያመይ)',
        'Africa/Nouakchott' => 'GMT (ንዋክሾት)',
        'Africa/Ouagadougou' => 'GMT (ዋጋዱጉ)',
        'Africa/Porto-Novo' => 'ግዜ ምዕራብ ኣፍሪቃ (ፖርቶ ኖቮ)',
        'Africa/Sao_Tome' => 'GMT (ሳኦ ቶመ)',
        'Africa/Tripoli' => 'ግዜ ምብራቕ ኤውሮጳ (ትሪፖሊ)',
        'Africa/Tunis' => 'ግዜ ማእከላይ ኤውሮጳ (ቱኒስ)',
        'Africa/Windhoek' => 'ግዜ ማእከላይ ኣፍሪቃ (ዊንድሆክ)',
        'America/Adak' => 'ግዜ ኣመሪካ (ኣዳክ)',
        'America/Anchorage' => 'ግዜ ኣላስካ (ኣንኮረጅ)',
        'America/Anguilla' => 'ግዜ ኣንጒላ (ኣንጒላ)',
        'America/Antigua' => 'ግዜ ኣንቲጓን ባርቡዳን (ኣንቲጓ)',
        'America/Araguaina' => 'ግዜ ብራዚልያ (ኣራጓይና)',
        'America/Argentina/La_Rioja' => 'ግዜ ኣርጀንቲና (ላ ርዮሃ)',
        'America/Argentina/Rio_Gallegos' => 'ግዜ ኣርጀንቲና (ርዮ ጋየጎስ)',
        'America/Argentina/Salta' => 'ግዜ ኣርጀንቲና (ሳልታ)',
        'America/Argentina/San_Juan' => 'ግዜ ኣርጀንቲና (ሳን ህዋን)',
        'America/Argentina/San_Luis' => 'ግዜ ኣርጀንቲና (ሳን ልዊስ)',
        'America/Argentina/Tucuman' => 'ግዜ ኣርጀንቲና (ቱኩማን)',
        'America/Argentina/Ushuaia' => 'ግዜ ኣርጀንቲና (ኡሽዋያ)',
        'America/Aruba' => 'ግዜ ኣሩባ (ኣሩባ)',
        'America/Asuncion' => 'ግዜ ፓራጓይ (ኣሱንስዮን)',
        'America/Bahia' => 'ግዜ ብራዚልያ (ባህያ)',
        'America/Bahia_Banderas' => 'ግዜ ሜክሲኮ (ባእያ ደ ባንደራስ)',
        'America/Barbados' => 'ግዜ ባርባዶስ (ባርባዶስ)',
        'America/Belem' => 'ግዜ ብራዚልያ (በለም)',
        'America/Belize' => 'ግዜ በሊዝ (በሊዝ)',
        'America/Blanc-Sablon' => 'ግዜ ካናዳ (ብላንክ-ሳብሎን)',
        'America/Boa_Vista' => 'ግዜ ኣማዞን (ቦዋ ቪስታ)',
        'America/Bogota' => 'ግዜ ኮሎምብያ (ቦጎታ)',
        'America/Boise' => 'ግዜ ኣመሪካ (ቦይዚ)',
        'America/Buenos_Aires' => 'ግዜ ኣርጀንቲና (ብወኖስ ኣይረስ)',
        'America/Cambridge_Bay' => 'ግዜ ካናዳ (ካምብሪጅ በይ)',
        'America/Campo_Grande' => 'ግዜ ኣማዞን (ካምፖ ግራንደ)',
        'America/Cancun' => 'ግዜ ሜክሲኮ (ካንኩን)',
        'America/Caracas' => 'ግዜ ቬኔዝዌላ (ካራካስ)',
        'America/Catamarca' => 'ግዜ ኣርጀንቲና (ካታማርካ)',
        'America/Cayenne' => 'ግዜ ፈረንሳዊት ጊያና (ካየን)',
        'America/Cayman' => 'ግዜ ደሴታት ካይማን (ካይማን)',
        'America/Chicago' => 'ግዜ ኣመሪካ (ቺካጎ)',
        'America/Chihuahua' => 'ግዜ ሜክሲኮ (ቺዋዋ)',
        'America/Coral_Harbour' => 'ግዜ ካናዳ (ኣቲኮካን)',
        'America/Cordoba' => 'ግዜ ኣርጀንቲና (ኮርዶባ)',
        'America/Costa_Rica' => 'ግዜ ኮስታ ሪካ (ኮስታ ሪካ)',
        'America/Creston' => 'ግዜ ካናዳ (ክረስተን)',
        'America/Cuiaba' => 'ግዜ ኣማዞን (ኩያባ)',
        'America/Curacao' => 'ግዜ ኩራሳው (ኩራሳው)',
        'America/Danmarkshavn' => 'GMT (ዳንማርክሻቭን)',
        'America/Dawson' => 'ግዜ ካናዳ (ዳውሰን)',
        'America/Dawson_Creek' => 'ግዜ ካናዳ (ዳውሰን ክሪክ)',
        'America/Denver' => 'ግዜ ኣመሪካ (ደንቨር)',
        'America/Detroit' => 'ግዜ ኣመሪካ (ዲትሮይት)',
        'America/Dominica' => 'ግዜ ዶሚኒካ (ዶሚኒካ)',
        'America/Edmonton' => 'ግዜ ካናዳ (ኤድመንተን)',
        'America/Eirunepe' => 'ግዜ ኣክሪ (ኤይሩኔፒ)',
        'America/El_Salvador' => 'ግዜ ኤል ሳልቫዶር (ኤል ሳልቫዶር)',
        'America/Fort_Nelson' => 'ግዜ ካናዳ (ፎርት ነልሰን)',
        'America/Fortaleza' => 'ግዜ ብራዚልያ (ፎርታለዛ)',
        'America/Glace_Bay' => 'ግዜ ካናዳ (ግሌስ በይ)',
        'America/Godthab' => 'ግዜ ግሪንላንድ (ኑክ)',
        'America/Goose_Bay' => 'ግዜ ካናዳ (ጉዝ በይ)',
        'America/Grand_Turk' => 'ግዜ ደሴታት ቱርካትን ካይኮስን (ግራንድ ቱርክ)',
        'America/Grenada' => 'ግዜ ግረናዳ (ግረናዳ)',
        'America/Guadeloupe' => 'ግዜ ጓደሉፕ (ጓደሉፕ)',
        'America/Guatemala' => 'ግዜ ጓቲማላ (ጓቲማላ)',
        'America/Guayaquil' => 'ግዜ ኤኳዶር (ጓያኪል)',
        'America/Guyana' => 'ግዜ ጉያና',
        'America/Halifax' => 'ግዜ ካናዳ (ሃሊፋክስ)',
        'America/Havana' => 'ግዜ ኩባ (ሃቫና)',
        'America/Hermosillo' => 'ግዜ ሜክሲኮ (ኤርሞስዮ)',
        'America/Indiana/Knox' => 'ግዜ ኣመሪካ (ኖክስ፣ ኢንድያና)',
        'America/Indiana/Marengo' => 'ግዜ ኣመሪካ (ማረንጎ፣ ኢንድያና)',
        'America/Indiana/Petersburg' => 'ግዜ ኣመሪካ (ፒተርስበርግ፣ ኢንድያና)',
        'America/Indiana/Tell_City' => 'ግዜ ኣመሪካ (ተል ሲቲ፣ ኢንድያና)',
        'America/Indiana/Vevay' => 'ግዜ ኣመሪካ (ቪቪ፣ ኢንድያና)',
        'America/Indiana/Vincennes' => 'ግዜ ኣመሪካ (ቪንሰንስ፣ ኢንድያና)',
        'America/Indiana/Winamac' => 'ግዜ ኣመሪካ (ዊናማክ፣ ኢንድያና)',
        'America/Indianapolis' => 'ግዜ ኣመሪካ (ኢንድያናፖሊስ)',
        'America/Inuvik' => 'ግዜ ካናዳ (ኢኑቪክ)',
        'America/Iqaluit' => 'ግዜ ካናዳ (ኢቃልዊት)',
        'America/Jamaica' => 'ግዜ ጃማይካ (ጃማይካ)',
        'America/Jujuy' => 'ግዜ ኣርጀንቲና (ሁሁይ)',
        'America/Juneau' => 'ግዜ ኣላስካ (ጁነው)',
        'America/Kentucky/Monticello' => 'ግዜ ኣመሪካ (ሞንቲቸሎ፣ ከንታኪ)',
        'America/Kralendijk' => 'ግዜ ካሪብያን ኔዘርላንድ (ክራለንዳይክ)',
        'America/La_Paz' => 'ግዜ ቦሊቭያ (ላ ፓዝ)',
        'America/Lima' => 'ግዜ ፔሩ (ሊማ)',
        'America/Los_Angeles' => 'ግዜ ኣመሪካ (ሎስ ኣንጀለስ)',
        'America/Louisville' => 'ግዜ ኣመሪካ (ልዊቪል)',
        'America/Lower_Princes' => 'ግዜ ሲንት ማርተን (ለወር ፕሪንሰስ ኳርተር)',
        'America/Maceio' => 'ግዜ ብራዚልያ (ማሰዮ)',
        'America/Managua' => 'ግዜ ኒካራጓ (ማናጓ)',
        'America/Manaus' => 'ግዜ ኣማዞን (ማናውስ)',
        'America/Marigot' => 'ግዜ ቅዱስ ማርቲን (ማሪጎት)',
        'America/Martinique' => 'ግዜ ማርቲኒክ (ማርቲኒክ)',
        'America/Matamoros' => 'ግዜ ሜክሲኮ (ማታሞሮስ)',
        'America/Mazatlan' => 'ግዜ ሜክሲኮ (ማዛትላን)',
        'America/Mendoza' => 'ግዜ ኣርጀንቲና (መንዶዛ)',
        'America/Menominee' => 'ግዜ ኣመሪካ (ሜኖሚኒ)',
        'America/Merida' => 'ግዜ ሜክሲኮ (መሪዳ)',
        'America/Metlakatla' => 'ግዜ ኣላስካ (መትላካትላ)',
        'America/Mexico_City' => 'ግዜ ሜክሲኮ (ከተማ ሜክሲኮ)',
        'America/Miquelon' => 'ግዜ ቅዱስ ፕየርን ሚከሎንን (ሚከሎን)',
        'America/Moncton' => 'ግዜ ካናዳ (ሞንክተን)',
        'America/Monterrey' => 'ግዜ ሜክሲኮ (ሞንተረይ)',
        'America/Montevideo' => 'ግዜ ኡራጓይ (ሞንተቪደዮ)',
        'America/Montreal' => 'ግዜ ካናዳ (Montreal)',
        'America/Montserrat' => 'ግዜ ሞንትሰራት (ሞንትሰራት)',
        'America/Nassau' => 'ግዜ ባሃማስ (ናሳው)',
        'America/New_York' => 'ግዜ ኣመሪካ (ኒው ዮርክ)',
        'America/Nipigon' => 'ግዜ ካናዳ (ኒፒጎን)',
        'America/Nome' => 'ግዜ ኣላስካ (ነውም)',
        'America/Noronha' => 'ግዜ ፈርናንዶ ደ ኖሮንያ',
        'America/North_Dakota/Beulah' => 'ግዜ ኣመሪካ (ብዩላ፣ ሰሜን ዳኮታ)',
        'America/North_Dakota/Center' => 'ግዜ ኣመሪካ (ሰንተር፣ ሰሜን ዳኮታ)',
        'America/North_Dakota/New_Salem' => 'ግዜ ኣመሪካ (ኒው ሳለም፣ ሰሜን ዳኮታ)',
        'America/Ojinaga' => 'ግዜ ሜክሲኮ (ኦጂናጋ)',
        'America/Panama' => 'ግዜ ፓናማ (ፓናማ)',
        'America/Pangnirtung' => 'ግዜ ካናዳ (ፓንግኒርተንግ)',
        'America/Paramaribo' => 'ግዜ ሱሪናም (ፓራማሪቦ)',
        'America/Phoenix' => 'ግዜ ኣመሪካ (ፊኒክስ)',
        'America/Port-au-Prince' => 'ግዜ ሃይቲ (ፖርት-ኦ-ፕሪንስ)',
        'America/Port_of_Spain' => 'ግዜ ትሪኒዳድን ቶባጎን (ፖርት ኦፍ ስፔን)',
        'America/Porto_Velho' => 'ግዜ ኣማዞን (ፖርቶ ቨልዮ)',
        'America/Puerto_Rico' => 'ግዜ ፖርቶ ሪኮ (ፖርቶ ሪኮ)',
        'America/Punta_Arenas' => 'ግዜ ቺሌ (ፑንታ ኣረናስ)',
        'America/Rainy_River' => 'ግዜ ካናዳ (ረይኒ ሪቨር)',
        'America/Rankin_Inlet' => 'ግዜ ካናዳ (ራንኪን ኢንለት)',
        'America/Recife' => 'ግዜ ብራዚልያ (ረሲፈ)',
        'America/Regina' => 'ግዜ ካናዳ (ረጂና)',
        'America/Resolute' => 'ግዜ ካናዳ (ረዞሉት)',
        'America/Rio_Branco' => 'ግዜ ኣክሪ (ርዮ ብራንኮ)',
        'America/Santa_Isabel' => 'ግዜ ሜክሲኮ (Santa Isabel)',
        'America/Santarem' => 'ግዜ ብራዚልያ (ሳንታረም)',
        'America/Santiago' => 'ግዜ ቺሌ (ሳንትያጎ)',
        'America/Santo_Domingo' => 'ግዜ ዶሚኒካዊት ሪፓብሊክ (ሳንቶ ዶሚንጎ)',
        'America/Sao_Paulo' => 'ግዜ ብራዚልያ (ሳኦ ፓውሎ)',
        'America/Scoresbysund' => 'ግዜ ግሪንላንድ (ኢቶቆርቶሚት)',
        'America/Sitka' => 'ግዜ ኣላስካ (ሲትካ)',
        'America/St_Barthelemy' => 'ግዜ ቅዱስ ባርተለሚ (ቅዱስ ባርተለሚ)',
        'America/St_Johns' => 'ግዜ ካናዳ (ቅዱስ ዮሃንስ)',
        'America/St_Kitts' => 'ግዜ ቅዱስ ኪትስን ኔቪስን (ቅዱስ ኪትስ)',
        'America/St_Lucia' => 'ግዜ ቅድስቲ ሉስያ (ቅድስቲ ሉስያ)',
        'America/St_Thomas' => 'ግዜ ደሴታት ደናግል ኣመሪካ (ሰይንት ቶማስ)',
        'America/St_Vincent' => 'ግዜ ቅዱስ ቪንሰንትን ግረነዲነዝን (ቅዱስ ቪንሰንት)',
        'America/Swift_Current' => 'ግዜ ካናዳ (ስዊፍት ካረንት)',
        'America/Tegucigalpa' => 'ግዜ ሆንዱራስ (ተጉሲጋልፓ)',
        'America/Thule' => 'ግዜ ግሪንላንድ (ዙል)',
        'America/Thunder_Bay' => 'ግዜ ካናዳ (ዛንደር በይ)',
        'America/Tijuana' => 'ግዜ ሜክሲኮ (ቲጅዋና)',
        'America/Toronto' => 'ግዜ ካናዳ (ቶሮንቶ)',
        'America/Tortola' => 'ግዜ ደሴታት ደናግል ብሪጣንያ (ቶርቶላ)',
        'America/Vancouver' => 'ግዜ ካናዳ (ቫንኩቨር)',
        'America/Whitehorse' => 'ግዜ ካናዳ (ዋይትሆዝ)',
        'America/Winnipeg' => 'ግዜ ካናዳ (ዊኒፐግ)',
        'America/Yakutat' => 'ግዜ ኣላስካ (ያኩታት)',
        'America/Yellowknife' => 'ግዜ ካናዳ (የለውናይፍ)',
        'Antarctica/Casey' => 'ግዜ ኣንታርክቲካ (ከይዚ)',
        'Antarctica/Davis' => 'ግዜ ኣንታርክቲካ (ደቪስ)',
        'Antarctica/DumontDUrville' => 'ግዜ ኣንታርክቲካ (ዱሞንት ዲኡርቪል)',
        'Antarctica/Macquarie' => 'ግዜ ኣውስትራልያ (ማኳሪ)',
        'Antarctica/Mawson' => 'ግዜ ኣንታርክቲካ (ማውሰን)',
        'Antarctica/McMurdo' => 'ግዜ ኣንታርክቲካ (ማክሙርዶ)',
        'Antarctica/Palmer' => 'ግዜ ቺሌ (ፓልመር)',
        'Antarctica/Rothera' => 'ግዜ ኣንታርክቲካ (ሮዘራ)',
        'Antarctica/Syowa' => 'ግዜ ኣንታርክቲካ (ስዮዋ)',
        'Antarctica/Troll' => 'GMT (ትሮል)',
        'Antarctica/Vostok' => 'ግዜ ኣንታርክቲካ (ቮስቶክ)',
        'Arctic/Longyearbyen' => 'ግዜ ማእከላይ ኤውሮጳ (ሎንግየርባየን)',
        'Asia/Aden' => 'ግዜ የመን (ዓደን)',
        'Asia/Almaty' => 'ግዜ ካዛኪስታን (ኣልማቲ)',
        'Asia/Amman' => 'ግዜ ምብራቕ ኤውሮጳ (ዓማን)',
        'Asia/Anadyr' => 'ግዜ ሩስያ (ኣናዲር)',
        'Asia/Aqtau' => 'ግዜ ካዛኪስታን (ኣክታው)',
        'Asia/Aqtobe' => 'ግዜ ካዛኪስታን (ኣክቶበ)',
        'Asia/Ashgabat' => 'ግዜ ቱርክመኒስታን (ኣሽጋባት)',
        'Asia/Atyrau' => 'ግዜ ካዛኪስታን (ኣቲራው)',
        'Asia/Baghdad' => 'ግዜ ዒራቕ (ባቕዳድ)',
        'Asia/Bahrain' => 'ግዜ ባሕሬን (ባሕሬን)',
        'Asia/Baku' => 'ግዜ ኣዘርባጃን (ባኩ)',
        'Asia/Bangkok' => 'ግዜ ታይላንድ (ባንግኮክ)',
        'Asia/Barnaul' => 'ግዜ ሩስያ (ባርናውል)',
        'Asia/Beirut' => 'ግዜ ምብራቕ ኤውሮጳ (በይሩት)',
        'Asia/Bishkek' => 'ግዜ ኪርጊዝስታን (ቢሽኬክ)',
        'Asia/Brunei' => 'ግዜ ብሩነይ (ብሩነይ)',
        'Asia/Calcutta' => 'ግዜ ህንዲ (ኮልካታ)',
        'Asia/Chita' => 'ግዜ ሩስያ (ቺታ)',
        'Asia/Choibalsan' => 'ግዜ ሞንጎልያ (ቾይባልሳን)',
        'Asia/Colombo' => 'ግዜ ስሪ ላንካ (ኮሎምቦ)',
        'Asia/Damascus' => 'ግዜ ምብራቕ ኤውሮጳ (ደማስቆ)',
        'Asia/Dhaka' => 'ግዜ ባንግላደሽ (ዳካ)',
        'Asia/Dili' => 'ግዜ ቲሞር-ለስተ (ዲሊ)',
        'Asia/Dubai' => 'ግዜ ሕቡራት ኢማራት ዓረብ (ዱባይ)',
        'Asia/Dushanbe' => 'ግዜ ታጂኪስታን (ዱሻንበ)',
        'Asia/Famagusta' => 'ግዜ ምብራቕ ኤውሮጳ (ፋማጉስታ)',
        'Asia/Gaza' => 'ግዜ ምብራቕ ኤውሮጳ (ቓዛ)',
        'Asia/Hebron' => 'ግዜ ምብራቕ ኤውሮጳ (ኬብሮን)',
        'Asia/Hong_Kong' => 'ግዜ ፍሉይ ምምሕዳራዊ ዞባ ሆንግ ኮንግ (ቻይና) (ሆንግ ኮንግ)',
        'Asia/Hovd' => 'ግዜ ሞንጎልያ (ሆቭድ)',
        'Asia/Irkutsk' => 'ግዜ ሩስያ (ኢርኩትስክ)',
        'Asia/Jakarta' => 'ግዜ ምዕራባዊ ኢንዶነዥያ (ጃካርታ)',
        'Asia/Jayapura' => 'ግዜ ምብራቓዊ ኢንዶነዥያ (ጃያፑራ)',
        'Asia/Jerusalem' => 'ግዜ እስራኤል (የሩሳሌም)',
        'Asia/Kabul' => 'ግዜ ኣፍጋኒስታን (ካቡል)',
        'Asia/Kamchatka' => 'ግዜ ሩስያ (ካምቻትካ)',
        'Asia/Karachi' => 'ግዜ ፓኪስታን (ካራቺ)',
        'Asia/Katmandu' => 'ግዜ ኔፓል (ካትማንዱ)',
        'Asia/Khandyga' => 'ግዜ ሩስያ (ካንዲጋ)',
        'Asia/Krasnoyarsk' => 'ግዜ ሩስያ (ክራስኖያርስክ)',
        'Asia/Kuala_Lumpur' => 'ግዜ ማለዥያ (ኳላ ሉምፑር)',
        'Asia/Kuching' => 'ግዜ ማለዥያ (ኩቺንግ)',
        'Asia/Kuwait' => 'ግዜ ኩዌት (ኩዌት)',
        'Asia/Macau' => 'ግዜ ፍሉይ ምምሕዳራዊ ዞባ ማካው (ቻይና) (ማካው)',
        'Asia/Magadan' => 'ግዜ ሩስያ (ማጋዳን)',
        'Asia/Makassar' => 'ግዜ ማእከላይ ኢንዶነዥያ (ማካሳር)',
        'Asia/Manila' => 'ግዜ ፊሊፒንስ (ማኒላ)',
        'Asia/Muscat' => 'ግዜ ዖማን (ሙስካት)',
        'Asia/Nicosia' => 'ግዜ ምብራቕ ኤውሮጳ (ኒኮስያ)',
        'Asia/Novokuznetsk' => 'ግዜ ሩስያ (ኖቮኩዝነትስክ)',
        'Asia/Novosibirsk' => 'ግዜ ሩስያ (ኖቮሲቢርስክ)',
        'Asia/Omsk' => 'ግዜ ሩስያ (ኦምስክ)',
        'Asia/Oral' => 'ግዜ ካዛኪስታን (ኦራል)',
        'Asia/Phnom_Penh' => 'ግዜ ካምቦድያ (ፕኖም ፐን)',
        'Asia/Pontianak' => 'ግዜ ምዕራባዊ ኢንዶነዥያ (ፖንትያናክ)',
        'Asia/Pyongyang' => 'ግዜ ሰሜን ኮርያ (ፕዮንግያንግ)',
        'Asia/Qatar' => 'ግዜ ቐጠር (ቐጠር)',
        'Asia/Qostanay' => 'ግዜ ካዛኪስታን (ኮስታናይ)',
        'Asia/Qyzylorda' => 'ግዜ ካዛኪስታን (ኪዚሎርዳ)',
        'Asia/Rangoon' => 'ግዜ ሚያንማር (በርማ) (ያንጎን)',
        'Asia/Riyadh' => 'ግዜ ስዑዲ ዓረብ (ርያድ)',
        'Asia/Saigon' => 'ግዜ ቬትናም (ከተማ ሆ ቺ ሚን)',
        'Asia/Sakhalin' => 'ግዜ ሩስያ (ሳካሊን)',
        'Asia/Samarkand' => 'ግዜ ኡዝበኪስታን (ሳማርካንድ)',
        'Asia/Seoul' => 'ግዜ ደቡብ ኮርያ (ሶውል)',
        'Asia/Shanghai' => 'ግዜ ቻይና (ሻንግሃይ)',
        'Asia/Singapore' => 'ግዜ ሲንጋፖር',
        'Asia/Srednekolymsk' => 'ግዜ ሩስያ (ስሬድነኮሊምስክ)',
        'Asia/Taipei' => 'ግዜ ታይዋን (ታይፐይ)',
        'Asia/Tashkent' => 'ግዜ ኡዝበኪስታን (ታሽከንት)',
        'Asia/Tbilisi' => 'ግዜ ጆርጅያ (ትቢሊሲ)',
        'Asia/Tehran' => 'ግዜ ኢራን (ተህራን)',
        'Asia/Thimphu' => 'ግዜ ቡታን (ቲምፉ)',
        'Asia/Tokyo' => 'ግዜ ጃፓን (ቶክዮ)',
        'Asia/Tomsk' => 'ግዜ ሩስያ (ቶምስክ)',
        'Asia/Ulaanbaatar' => 'ግዜ ሞንጎልያ (ኡላን ባቶር)',
        'Asia/Urumqi' => 'ግዜ ቻይና (ኡሩምኪ)',
        'Asia/Ust-Nera' => 'ግዜ ሩስያ (ኡስት-ኔራ)',
        'Asia/Vientiane' => 'ግዜ ላኦስ (ቭየንትያን)',
        'Asia/Vladivostok' => 'ግዜ ሩስያ (ቭላዲቮስቶክ)',
        'Asia/Yakutsk' => 'ግዜ ሩስያ (ያኩትስክ)',
        'Asia/Yekaterinburg' => 'ግዜ ሩስያ (የካተሪንበርግ)',
        'Asia/Yerevan' => 'ግዜ ኣርሜንያ (የረቫን)',
        'Atlantic/Azores' => 'ግዜ ኣዞረስ',
        'Atlantic/Bermuda' => 'ግዜ በርሙዳ (በርሙዳ)',
        'Atlantic/Canary' => 'ግዜ ስጳኛ (ካናሪ)',
        'Atlantic/Cape_Verde' => 'ግዜ ኬፕ ቨርደ',
        'Atlantic/Faeroe' => 'ግዜ ደሴታት ፋሮ (ደሴታት ፋሮ)',
        'Atlantic/Madeira' => 'ግዜ ፖርቱጋል (ማደይራ)',
        'Atlantic/Reykjavik' => 'GMT (ረይክያቪክ)',
        'Atlantic/South_Georgia' => 'ግዜ ደቡብ ጆርጅያ',
        'Atlantic/St_Helena' => 'GMT (ቅድስቲ ሄለና)',
        'Atlantic/Stanley' => 'ግዜ ደሴታት ፎክላንድ (ስታንሊ)',
        'Australia/Adelaide' => 'ግዜ ኣውስትራልያ (ኣደለይድ)',
        'Australia/Brisbane' => 'ግዜ ኣውስትራልያ (ብሪዝቤን)',
        'Australia/Broken_Hill' => 'ግዜ ኣውስትራልያ (ብሮክን ሂል)',
        'Australia/Currie' => 'ግዜ ኣውስትራልያ (ኩሪ)',
        'Australia/Darwin' => 'ግዜ ኣውስትራልያ (ዳርዊን)',
        'Australia/Eucla' => 'ግዜ ኣውስትራልያ (ዩክላ)',
        'Australia/Hobart' => 'ግዜ ኣውስትራልያ (ሆባርት)',
        'Australia/Lindeman' => 'ግዜ ኣውስትራልያ (ሊንድማን)',
        'Australia/Lord_Howe' => 'ግዜ ኣውስትራልያ (ሎርድ ሃው)',
        'Australia/Melbourne' => 'ግዜ ኣውስትራልያ (መልበርን)',
        'Australia/Perth' => 'ግዜ ኣውስትራልያ (ፐርዝ)',
        'Australia/Sydney' => 'ግዜ ኣውስትራልያ (ሲድኒ)',
        'Etc/GMT' => 'GMT',
        'Etc/UTC' => 'ዝተሳነየ ኣድማሳዊ ግዜ',
        'Europe/Amsterdam' => 'ግዜ ማእከላይ ኤውሮጳ (ኣምስተርዳም)',
        'Europe/Andorra' => 'ግዜ ማእከላይ ኤውሮጳ (ኣንዶራ)',
        'Europe/Astrakhan' => 'ግዜ ሩስያ (ኣስትራካን)',
        'Europe/Athens' => 'ግዜ ምብራቕ ኤውሮጳ (ኣቴንስ)',
        'Europe/Belgrade' => 'ግዜ ማእከላይ ኤውሮጳ (በልግሬድ)',
        'Europe/Berlin' => 'ግዜ ማእከላይ ኤውሮጳ (በርሊን)',
        'Europe/Bratislava' => 'ግዜ ማእከላይ ኤውሮጳ (ብራቲስላቫ)',
        'Europe/Brussels' => 'ግዜ ማእከላይ ኤውሮጳ (ብራስልስ)',
        'Europe/Bucharest' => 'ግዜ ምብራቕ ኤውሮጳ (ቡካረስት)',
        'Europe/Budapest' => 'ግዜ ማእከላይ ኤውሮጳ (ቡዳፐስት)',
        'Europe/Busingen' => 'ግዜ ማእከላይ ኤውሮጳ (ቡሲንገን)',
        'Europe/Chisinau' => 'ግዜ ምብራቕ ኤውሮጳ (ኪሺናው)',
        'Europe/Copenhagen' => 'ግዜ ማእከላይ ኤውሮጳ (ኮፐንሃገን)',
        'Europe/Dublin' => 'GMT (ደብሊን)',
        'Europe/Gibraltar' => 'ግዜ ማእከላይ ኤውሮጳ (ጂብራልታር)',
        'Europe/Guernsey' => 'GMT (ገርንዚ)',
        'Europe/Helsinki' => 'ግዜ ምብራቕ ኤውሮጳ (ሄልሲንኪ)',
        'Europe/Isle_of_Man' => 'GMT (ኣይል ኦፍ ማን)',
        'Europe/Istanbul' => 'ግዜ ቱርኪ (ኢስታንቡል)',
        'Europe/Jersey' => 'GMT (ጀርዚ)',
        'Europe/Kaliningrad' => 'ግዜ ምብራቕ ኤውሮጳ (ካሊኒንግራድ)',
        'Europe/Kiev' => 'ግዜ ምብራቕ ኤውሮጳ (ክየቭ)',
        'Europe/Kirov' => 'ግዜ ሩስያ (ኪሮቭ)',
        'Europe/Lisbon' => 'ግዜ ፖርቱጋል (ሊዝበን)',
        'Europe/Ljubljana' => 'ግዜ ማእከላይ ኤውሮጳ (ልዩብልያና)',
        'Europe/London' => 'GMT (ሎንደን)',
        'Europe/Luxembourg' => 'ግዜ ማእከላይ ኤውሮጳ (ሉክሰምበርግ)',
        'Europe/Madrid' => 'ግዜ ማእከላይ ኤውሮጳ (ማድሪድ)',
        'Europe/Malta' => 'ግዜ ማእከላይ ኤውሮጳ (ማልታ)',
        'Europe/Mariehamn' => 'ግዜ ምብራቕ ኤውሮጳ (ማሪሃምን)',
        'Europe/Minsk' => 'ግዜ ቤላሩስ (ሚንስክ)',
        'Europe/Monaco' => 'ግዜ ማእከላይ ኤውሮጳ (ሞናኮ)',
        'Europe/Moscow' => 'ግዜ ሩስያ (ሞስኮ)',
        'Europe/Oslo' => 'ግዜ ማእከላይ ኤውሮጳ (ኦስሎ)',
        'Europe/Paris' => 'ግዜ ማእከላይ ኤውሮጳ (ፓሪስ)',
        'Europe/Podgorica' => 'ግዜ ማእከላይ ኤውሮጳ (ፖድጎሪጻ)',
        'Europe/Prague' => 'ግዜ ማእከላይ ኤውሮጳ (ፕራግ)',
        'Europe/Riga' => 'ግዜ ምብራቕ ኤውሮጳ (ሪጋ)',
        'Europe/Rome' => 'ግዜ ማእከላይ ኤውሮጳ (ሮማ)',
        'Europe/Samara' => 'ግዜ ሩስያ (ሳማራ)',
        'Europe/San_Marino' => 'ግዜ ማእከላይ ኤውሮጳ (ሳን ማሪኖ)',
        'Europe/Sarajevo' => 'ግዜ ማእከላይ ኤውሮጳ (ሳራየቮ)',
        'Europe/Saratov' => 'ግዜ ሩስያ (ሳራቶቭ)',
        'Europe/Simferopol' => 'ግዜ ዩክሬን (ሲምፈሮፖል)',
        'Europe/Skopje' => 'ግዜ ማእከላይ ኤውሮጳ (ስኮፕየ)',
        'Europe/Sofia' => 'ግዜ ምብራቕ ኤውሮጳ (ሶፍያ)',
        'Europe/Stockholm' => 'ግዜ ማእከላይ ኤውሮጳ (ስቶክሆልም)',
        'Europe/Tallinn' => 'ግዜ ምብራቕ ኤውሮጳ (ታሊን)',
        'Europe/Tirane' => 'ግዜ ማእከላይ ኤውሮጳ (ቲራና)',
        'Europe/Ulyanovsk' => 'ግዜ ሩስያ (ኡልያኖቭስክ)',
        'Europe/Uzhgorod' => 'ግዜ ምብራቕ ኤውሮጳ (ኡዝጎሮድ)',
        'Europe/Vaduz' => 'ግዜ ማእከላይ ኤውሮጳ (ቫዱዝ)',
        'Europe/Vatican' => 'ግዜ ማእከላይ ኤውሮጳ (ቫቲካን)',
        'Europe/Vienna' => 'ግዜ ማእከላይ ኤውሮጳ (ቭየና)',
        'Europe/Vilnius' => 'ግዜ ምብራቕ ኤውሮጳ (ቪልንየስ)',
        'Europe/Volgograd' => 'ግዜ ሩስያ (ቮልጎግራድ)',
        'Europe/Warsaw' => 'ግዜ ማእከላይ ኤውሮጳ (ዋርሳው)',
        'Europe/Zagreb' => 'ግዜ ማእከላይ ኤውሮጳ (ዛግረብ)',
        'Europe/Zaporozhye' => 'ግዜ ምብራቕ ኤውሮጳ (ዛፖሪዥያ)',
        'Europe/Zurich' => 'ግዜ ማእከላይ ኤውሮጳ (ዙሪክ)',
        'Indian/Antananarivo' => 'ግዜ ምብራቕ ኣፍሪቃ (ኣንታናናሪቮ)',
        'Indian/Chagos' => 'ግዜ ህንዳዊ ውቅያኖስ (ቻጎስ)',
        'Indian/Christmas' => 'ግዜ ደሴት ክሪስማስ (ክሪስማስ)',
        'Indian/Cocos' => 'ግዜ ደሴታት ኮኮስ (ኮኮስ)',
        'Indian/Comoro' => 'ግዜ ምብራቕ ኣፍሪቃ (ኮሞሮ)',
        'Indian/Kerguelen' => 'ግዜ ፈረንሳዊ ደቡባዊ ግዝኣታትን ኣንታርቲክን (ከርጉለን)',
        'Indian/Mahe' => 'ግዜ ሲሸልስ (ማሄ)',
        'Indian/Maldives' => 'ግዜ ማልዲቭስ (ማልዲቭስ)',
        'Indian/Mauritius' => 'ግዜ ማውሪሸስ',
        'Indian/Mayotte' => 'ግዜ ምብራቕ ኣፍሪቃ (ማዮት)',
        'Indian/Reunion' => 'ግዜ ርዩንየን',
        'Pacific/Apia' => 'ግዜ ሳሞኣ (ኣፕያ)',
        'Pacific/Auckland' => 'ግዜ ኒው ዚላንድ (ኦክላንድ)',
        'Pacific/Bougainville' => 'ግዜ ፓፕዋ ኒው ጊኒ (ቡገንቪል)',
        'Pacific/Chatham' => 'ግዜ ኒው ዚላንድ (ቻታም)',
        'Pacific/Easter' => 'ግዜ ደሴት ፋሲካ',
        'Pacific/Efate' => 'ግዜ ቫንዋቱ (ኤፋቴ)',
        'Pacific/Enderbury' => 'ግዜ ኪሪባቲ (ኤንደርበሪ)',
        'Pacific/Fakaofo' => 'ግዜ ቶከላው (ፋካኦፎ)',
        'Pacific/Fiji' => 'ግዜ ፊጂ (ፊጂ)',
        'Pacific/Funafuti' => 'ግዜ ቱቫሉ (ፉናፉቲ)',
        'Pacific/Galapagos' => 'ግዜ ጋላፓጎስ',
        'Pacific/Gambier' => 'ግዜ ፈረንሳዊት ፖሊነዥያ (ጋምብየር)',
        'Pacific/Guadalcanal' => 'ግዜ ደሴታት ሰሎሞን (ጓዳልካናል)',
        'Pacific/Guam' => 'ግዜ ጓም (ጓም)',
        'Pacific/Honolulu' => 'ግዜ ኣመሪካ (ሆኖሉሉ)',
        'Pacific/Johnston' => 'ግዜ ካብ ኣመሪካ ርሒቐን ንኣሽቱ ደሴታት (ጆንስተን)',
        'Pacific/Kiritimati' => 'ግዜ ኪሪባቲ (ኪሪቲማቲ)',
        'Pacific/Kosrae' => 'ግዜ ማይክሮነዥያ (ኮስሬ)',
        'Pacific/Kwajalein' => 'ግዜ ደሴታት ማርሻል (ክዋጃሊን)',
        'Pacific/Majuro' => 'ግዜ ደሴታት ማርሻል (ማጁሮ)',
        'Pacific/Marquesas' => 'ግዜ ፈረንሳዊት ፖሊነዥያ (ማርኬሳስ)',
        'Pacific/Midway' => 'ግዜ ካብ ኣመሪካ ርሒቐን ንኣሽቱ ደሴታት (ሚድወይ)',
        'Pacific/Nauru' => 'ግዜ ናውሩ (ናውሩ)',
        'Pacific/Niue' => 'ግዜ ኒዩ (ኒዩ)',
        'Pacific/Norfolk' => 'ግዜ ደሴት ኖርፎልክ (ኖርፎልክ)',
        'Pacific/Noumea' => 'ግዜ ኒው ካለዶንያ (ኑመያ)',
        'Pacific/Pago_Pago' => 'ግዜ ኣመሪካዊት ሳሞኣ (ፓጎ ፓጎ)',
        'Pacific/Palau' => 'ግዜ ፓላው (ፓላው)',
        'Pacific/Pitcairn' => 'ግዜ ደሴታት ፒትካርን (ፒትከርን)',
        'Pacific/Ponape' => 'ግዜ ማይክሮነዥያ (ፖንፐይ)',
        'Pacific/Port_Moresby' => 'ግዜ ፓፕዋ ኒው ጊኒ (ፖርት ሞርስቢ)',
        'Pacific/Rarotonga' => 'ግዜ ደሴታት ኩክ (ራሮቶንጋ)',
        'Pacific/Saipan' => 'ግዜ ሰሜናዊ ደሴታት ማርያና (ሳይፓን)',
        'Pacific/Tahiti' => 'ግዜ ፈረንሳዊት ፖሊነዥያ (ታሂቲ)',
        'Pacific/Tarawa' => 'ግዜ ኪሪባቲ (ታራዋ)',
        'Pacific/Tongatapu' => 'ግዜ ቶንጋ (ቶንጋታፑ)',
        'Pacific/Truk' => 'ግዜ ማይክሮነዥያ (ቹክ)',
        'Pacific/Wake' => 'ግዜ ካብ ኣመሪካ ርሒቐን ንኣሽቱ ደሴታት (ዌክ)',
        'Pacific/Wallis' => 'ግዜ ዋሊስን ፉቱናን (ዋሊስ)',
    ],
    'Meta' => [
    ],
];
