<?php

return [
    'Names' => [
        'af' => 'الأفريقانية',
        'af_NA' => 'الأفريقانية (ناميبيا)',
        'af_ZA' => 'الأفريقانية (جنوب أفريقيا)',
        'ak' => 'الأكانية',
        'ak_GH' => 'الأكانية (غانا)',
        'am' => 'الأمهرية',
        'am_ET' => 'الأمهرية (إثيوبيا)',
        'ar' => 'العربية',
        'ar_001' => 'العربية (العالم)',
        'ar_AE' => 'العربية (الإمارات العربية المتحدة)',
        'ar_BH' => 'العربية (البحرين)',
        'ar_DJ' => 'العربية (جيبوتي)',
        'ar_DZ' => 'العربية (الجزائر)',
        'ar_EG' => 'العربية (مصر)',
        'ar_EH' => 'العربية (الصحراء الغربية)',
        'ar_ER' => 'العربية (إريتريا)',
        'ar_IL' => 'العربية (إسرائيل)',
        'ar_IQ' => 'العربية (العراق)',
        'ar_JO' => 'العربية (الأردن)',
        'ar_KM' => 'العربية (جزر القمر)',
        'ar_KW' => 'العربية (الكويت)',
        'ar_LB' => 'العربية (لبنان)',
        'ar_LY' => 'العربية (ليبيا)',
        'ar_MA' => 'العربية (المغرب)',
        'ar_MR' => 'العربية (موريتانيا)',
        'ar_OM' => 'العربية (عُمان)',
        'ar_PS' => 'العربية (الأراضي الفلسطينية)',
        'ar_QA' => 'العربية (قطر)',
        'ar_SA' => 'العربية (المملكة العربية السعودية)',
        'ar_SD' => 'العربية (السودان)',
        'ar_SO' => 'العربية (الصومال)',
        'ar_SS' => 'العربية (جنوب السودان)',
        'ar_SY' => 'العربية (سوريا)',
        'ar_TD' => 'العربية (تشاد)',
        'ar_TN' => 'العربية (تونس)',
        'ar_YE' => 'العربية (اليمن)',
        'as' => 'الأسامية',
        'as_IN' => 'الأسامية (الهند)',
        'az' => 'الأذربيجانية',
        'az_AZ' => 'الأذربيجانية (أذربيجان)',
        'az_Cyrl' => 'الأذربيجانية (السيريلية)',
        'az_Cyrl_AZ' => 'الأذربيجانية (السيريلية، أذربيجان)',
        'az_Latn' => 'الأذربيجانية (اللاتينية)',
        'az_Latn_AZ' => 'الأذربيجانية (اللاتينية، أذربيجان)',
        'be' => 'البيلاروسية',
        'be_BY' => 'البيلاروسية (بيلاروس)',
        'bg' => 'البلغارية',
        'bg_BG' => 'البلغارية (بلغاريا)',
        'bm' => 'البامبارا',
        'bm_ML' => 'البامبارا (مالي)',
        'bn' => 'البنغالية',
        'bn_BD' => 'البنغالية (بنغلاديش)',
        'bn_IN' => 'البنغالية (الهند)',
        'bo' => 'التبتية',
        'bo_CN' => 'التبتية (الصين)',
        'bo_IN' => 'التبتية (الهند)',
        'br' => 'البريتونية',
        'br_FR' => 'البريتونية (فرنسا)',
        'bs' => 'البوسنية',
        'bs_BA' => 'البوسنية (البوسنة والهرسك)',
        'bs_Cyrl' => 'البوسنية (السيريلية)',
        'bs_Cyrl_BA' => 'البوسنية (السيريلية، البوسنة والهرسك)',
        'bs_Latn' => 'البوسنية (اللاتينية)',
        'bs_Latn_BA' => 'البوسنية (اللاتينية، البوسنة والهرسك)',
        'ca' => 'الكتالانية',
        'ca_AD' => 'الكتالانية (أندورا)',
        'ca_ES' => 'الكتالانية (إسبانيا)',
        'ca_FR' => 'الكتالانية (فرنسا)',
        'ca_IT' => 'الكتالانية (إيطاليا)',
        'ce' => 'الشيشانية',
        'ce_RU' => 'الشيشانية (روسيا)',
        'cs' => 'التشيكية',
        'cs_CZ' => 'التشيكية (التشيك)',
        'cv' => 'التشوفاشي',
        'cv_RU' => 'التشوفاشي (روسيا)',
        'cy' => 'الويلزية',
        'cy_GB' => 'الويلزية (المملكة المتحدة)',
        'da' => 'الدانمركية',
        'da_DK' => 'الدانمركية (الدانمرك)',
        'da_GL' => 'الدانمركية (غرينلاند)',
        'de' => 'الألمانية',
        'de_AT' => 'الألمانية (النمسا)',
        'de_BE' => 'الألمانية (بلجيكا)',
        'de_CH' => 'الألمانية (سويسرا)',
        'de_DE' => 'الألمانية (ألمانيا)',
        'de_IT' => 'الألمانية (إيطاليا)',
        'de_LI' => 'الألمانية (ليختنشتاين)',
        'de_LU' => 'الألمانية (لوكسمبورغ)',
        'dz' => 'الزونخاية',
        'dz_BT' => 'الزونخاية (بوتان)',
        'ee' => 'الإيوي',
        'ee_GH' => 'الإيوي (غانا)',
        'ee_TG' => 'الإيوي (توغو)',
        'el' => 'اليونانية',
        'el_CY' => 'اليونانية (قبرص)',
        'el_GR' => 'اليونانية (اليونان)',
        'en' => 'الإنجليزية',
        'en_001' => 'الإنجليزية (العالم)',
        'en_150' => 'الإنجليزية (أوروبا)',
        'en_AE' => 'الإنجليزية (الإمارات العربية المتحدة)',
        'en_AG' => 'الإنجليزية (أنتيغوا وبربودا)',
        'en_AI' => 'الإنجليزية (أنغويلا)',
        'en_AS' => 'الإنجليزية (ساموا الأمريكية)',
        'en_AT' => 'الإنجليزية (النمسا)',
        'en_AU' => 'الإنجليزية (أستراليا)',
        'en_BB' => 'الإنجليزية (بربادوس)',
        'en_BE' => 'الإنجليزية (بلجيكا)',
        'en_BI' => 'الإنجليزية (بوروندي)',
        'en_BM' => 'الإنجليزية (برمودا)',
        'en_BS' => 'الإنجليزية (جزر البهاما)',
        'en_BW' => 'الإنجليزية (بوتسوانا)',
        'en_BZ' => 'الإنجليزية (بليز)',
        'en_CA' => 'الإنجليزية (كندا)',
        'en_CC' => 'الإنجليزية (جزر كوكوس [كيلينغ])',
        'en_CH' => 'الإنجليزية (سويسرا)',
        'en_CK' => 'الإنجليزية (جزر كوك)',
        'en_CM' => 'الإنجليزية (الكاميرون)',
        'en_CX' => 'الإنجليزية (جزيرة كريسماس)',
        'en_CY' => 'الإنجليزية (قبرص)',
        'en_DE' => 'الإنجليزية (ألمانيا)',
        'en_DK' => 'الإنجليزية (الدانمرك)',
        'en_DM' => 'الإنجليزية (دومينيكا)',
        'en_ER' => 'الإنجليزية (إريتريا)',
        'en_FI' => 'الإنجليزية (فنلندا)',
        'en_FJ' => 'الإنجليزية (فيجي)',
        'en_FK' => 'الإنجليزية (جزر فوكلاند)',
        'en_FM' => 'الإنجليزية (ميكرونيزيا)',
        'en_GB' => 'الإنجليزية (المملكة المتحدة)',
        'en_GD' => 'الإنجليزية (غرينادا)',
        'en_GG' => 'الإنجليزية (غيرنزي)',
        'en_GH' => 'الإنجليزية (غانا)',
        'en_GI' => 'الإنجليزية (جبل طارق)',
        'en_GM' => 'الإنجليزية (غامبيا)',
        'en_GU' => 'الإنجليزية (غوام)',
        'en_GY' => 'الإنجليزية (غيانا)',
        'en_HK' => 'الإنجليزية (هونغ كونغ الصينية [منطقة إدارية خاصة])',
        'en_IE' => 'الإنجليزية (أيرلندا)',
        'en_IL' => 'الإنجليزية (إسرائيل)',
        'en_IM' => 'الإنجليزية (جزيرة مان)',
        'en_IN' => 'الإنجليزية (الهند)',
        'en_IO' => 'الإنجليزية (الإقليم البريطاني في المحيط الهندي)',
        'en_JE' => 'الإنجليزية (جيرسي)',
        'en_JM' => 'الإنجليزية (جامايكا)',
        'en_KE' => 'الإنجليزية (كينيا)',
        'en_KI' => 'الإنجليزية (كيريباتي)',
        'en_KN' => 'الإنجليزية (سانت كيتس ونيفيس)',
        'en_KY' => 'الإنجليزية (جزر كايمان)',
        'en_LC' => 'الإنجليزية (سانت لوسيا)',
        'en_LR' => 'الإنجليزية (ليبيريا)',
        'en_LS' => 'الإنجليزية (ليسوتو)',
        'en_MG' => 'الإنجليزية (مدغشقر)',
        'en_MH' => 'الإنجليزية (جزر مارشال)',
        'en_MO' => 'الإنجليزية (منطقة ماكاو الإدارية الخاصة)',
        'en_MP' => 'الإنجليزية (جزر ماريانا الشمالية)',
        'en_MS' => 'الإنجليزية (مونتسرات)',
        'en_MT' => 'الإنجليزية (مالطا)',
        'en_MU' => 'الإنجليزية (موريشيوس)',
        'en_MV' => 'الإنجليزية (جزر المالديف)',
        'en_MW' => 'الإنجليزية (ملاوي)',
        'en_MY' => 'الإنجليزية (ماليزيا)',
        'en_NA' => 'الإنجليزية (ناميبيا)',
        'en_NF' => 'الإنجليزية (جزيرة نورفولك)',
        'en_NG' => 'الإنجليزية (نيجيريا)',
        'en_NL' => 'الإنجليزية (هولندا)',
        'en_NR' => 'الإنجليزية (ناورو)',
        'en_NU' => 'الإنجليزية (نيوي)',
        'en_NZ' => 'الإنجليزية (نيوزيلندا)',
        'en_PG' => 'الإنجليزية (بابوا غينيا الجديدة)',
        'en_PH' => 'الإنجليزية (الفلبين)',
        'en_PK' => 'الإنجليزية (باكستان)',
        'en_PN' => 'الإنجليزية (جزر بيتكيرن)',
        'en_PR' => 'الإنجليزية (بورتوريكو)',
        'en_PW' => 'الإنجليزية (بالاو)',
        'en_RW' => 'الإنجليزية (رواندا)',
        'en_SB' => 'الإنجليزية (جزر سليمان)',
        'en_SC' => 'الإنجليزية (سيشل)',
        'en_SD' => 'الإنجليزية (السودان)',
        'en_SE' => 'الإنجليزية (السويد)',
        'en_SG' => 'الإنجليزية (سنغافورة)',
        'en_SH' => 'الإنجليزية (سانت هيلينا)',
        'en_SI' => 'الإنجليزية (سلوفينيا)',
        'en_SL' => 'الإنجليزية (سيراليون)',
        'en_SS' => 'الإنجليزية (جنوب السودان)',
        'en_SX' => 'الإنجليزية (سانت مارتن)',
        'en_SZ' => 'الإنجليزية (إسواتيني)',
        'en_TC' => 'الإنجليزية (جزر توركس وكايكوس)',
        'en_TK' => 'الإنجليزية (توكيلو)',
        'en_TO' => 'الإنجليزية (تونغا)',
        'en_TT' => 'الإنجليزية (ترينيداد وتوباغو)',
        'en_TV' => 'الإنجليزية (توفالو)',
        'en_TZ' => 'الإنجليزية (تنزانيا)',
        'en_UG' => 'الإنجليزية (أوغندا)',
        'en_UM' => 'الإنجليزية (جزر الولايات المتحدة النائية)',
        'en_US' => 'الإنجليزية (الولايات المتحدة)',
        'en_VC' => 'الإنجليزية (سانت فنسنت وجزر غرينادين)',
        'en_VG' => 'الإنجليزية (جزر فيرجن البريطانية)',
        'en_VI' => 'الإنجليزية (جزر فيرجن التابعة للولايات المتحدة)',
        'en_VU' => 'الإنجليزية (فانواتو)',
        'en_WS' => 'الإنجليزية (ساموا)',
        'en_ZA' => 'الإنجليزية (جنوب أفريقيا)',
        'en_ZM' => 'الإنجليزية (زامبيا)',
        'en_ZW' => 'الإنجليزية (زيمبابوي)',
        'eo' => 'الإسبرانتو',
        'eo_001' => 'الإسبرانتو (العالم)',
        'es' => 'الإسبانية',
        'es_419' => 'الإسبانية (أمريكا اللاتينية)',
        'es_AR' => 'الإسبانية (الأرجنتين)',
        'es_BO' => 'الإسبانية (بوليفيا)',
        'es_BR' => 'الإسبانية (البرازيل)',
        'es_BZ' => 'الإسبانية (بليز)',
        'es_CL' => 'الإسبانية (تشيلي)',
        'es_CO' => 'الإسبانية (كولومبيا)',
        'es_CR' => 'الإسبانية (كوستاريكا)',
        'es_CU' => 'الإسبانية (كوبا)',
        'es_DO' => 'الإسبانية (جمهورية الدومينيكان)',
        'es_EC' => 'الإسبانية (الإكوادور)',
        'es_ES' => 'الإسبانية (إسبانيا)',
        'es_GQ' => 'الإسبانية (غينيا الاستوائية)',
        'es_GT' => 'الإسبانية (غواتيمالا)',
        'es_HN' => 'الإسبانية (هندوراس)',
        'es_MX' => 'الإسبانية (المكسيك)',
        'es_NI' => 'الإسبانية (نيكاراغوا)',
        'es_PA' => 'الإسبانية (بنما)',
        'es_PE' => 'الإسبانية (بيرو)',
        'es_PH' => 'الإسبانية (الفلبين)',
        'es_PR' => 'الإسبانية (بورتوريكو)',
        'es_PY' => 'الإسبانية (باراغواي)',
        'es_SV' => 'الإسبانية (السلفادور)',
        'es_US' => 'الإسبانية (الولايات المتحدة)',
        'es_UY' => 'الإسبانية (أورغواي)',
        'es_VE' => 'الإسبانية (فنزويلا)',
        'et' => 'الإستونية',
        'et_EE' => 'الإستونية (إستونيا)',
        'eu' => 'الباسكية',
        'eu_ES' => 'الباسكية (إسبانيا)',
        'fa' => 'الفارسية',
        'fa_AF' => 'الفارسية (أفغانستان)',
        'fa_IR' => 'الفارسية (إيران)',
        'ff' => 'الفولانية',
        'ff_Adlm' => 'الفولانية (أدلم)',
        'ff_Adlm_BF' => 'الفولانية (أدلم، بوركينا فاسو)',
        'ff_Adlm_CM' => 'الفولانية (أدلم، الكاميرون)',
        'ff_Adlm_GH' => 'الفولانية (أدلم، غانا)',
        'ff_Adlm_GM' => 'الفولانية (أدلم، غامبيا)',
        'ff_Adlm_GN' => 'الفولانية (أدلم، غينيا)',
        'ff_Adlm_GW' => 'الفولانية (أدلم، غينيا بيساو)',
        'ff_Adlm_LR' => 'الفولانية (أدلم، ليبيريا)',
        'ff_Adlm_MR' => 'الفولانية (أدلم، موريتانيا)',
        'ff_Adlm_NE' => 'الفولانية (أدلم، النيجر)',
        'ff_Adlm_NG' => 'الفولانية (أدلم، نيجيريا)',
        'ff_Adlm_SL' => 'الفولانية (أدلم، سيراليون)',
        'ff_Adlm_SN' => 'الفولانية (أدلم، السنغال)',
        'ff_CM' => 'الفولانية (الكاميرون)',
        'ff_GN' => 'الفولانية (غينيا)',
        'ff_Latn' => 'الفولانية (اللاتينية)',
        'ff_Latn_BF' => 'الفولانية (اللاتينية، بوركينا فاسو)',
        'ff_Latn_CM' => 'الفولانية (اللاتينية، الكاميرون)',
        'ff_Latn_GH' => 'الفولانية (اللاتينية، غانا)',
        'ff_Latn_GM' => 'الفولانية (اللاتينية، غامبيا)',
        'ff_Latn_GN' => 'الفولانية (اللاتينية، غينيا)',
        'ff_Latn_GW' => 'الفولانية (اللاتينية، غينيا بيساو)',
        'ff_Latn_LR' => 'الفولانية (اللاتينية، ليبيريا)',
        'ff_Latn_MR' => 'الفولانية (اللاتينية، موريتانيا)',
        'ff_Latn_NE' => 'الفولانية (اللاتينية، النيجر)',
        'ff_Latn_NG' => 'الفولانية (اللاتينية، نيجيريا)',
        'ff_Latn_SL' => 'الفولانية (اللاتينية، سيراليون)',
        'ff_Latn_SN' => 'الفولانية (اللاتينية، السنغال)',
        'ff_MR' => 'الفولانية (موريتانيا)',
        'ff_SN' => 'الفولانية (السنغال)',
        'fi' => 'الفنلندية',
        'fi_FI' => 'الفنلندية (فنلندا)',
        'fo' => 'الفاروية',
        'fo_DK' => 'الفاروية (الدانمرك)',
        'fo_FO' => 'الفاروية (جزر فارو)',
        'fr' => 'الفرنسية',
        'fr_BE' => 'الفرنسية (بلجيكا)',
        'fr_BF' => 'الفرنسية (بوركينا فاسو)',
        'fr_BI' => 'الفرنسية (بوروندي)',
        'fr_BJ' => 'الفرنسية (بنين)',
        'fr_BL' => 'الفرنسية (سان بارتليمي)',
        'fr_CA' => 'الفرنسية (كندا)',
        'fr_CD' => 'الفرنسية (الكونغو - كينشاسا)',
        'fr_CF' => 'الفرنسية (جمهورية أفريقيا الوسطى)',
        'fr_CG' => 'الفرنسية (الكونغو - برازافيل)',
        'fr_CH' => 'الفرنسية (سويسرا)',
        'fr_CI' => 'الفرنسية (ساحل العاج)',
        'fr_CM' => 'الفرنسية (الكاميرون)',
        'fr_DJ' => 'الفرنسية (جيبوتي)',
        'fr_DZ' => 'الفرنسية (الجزائر)',
        'fr_FR' => 'الفرنسية (فرنسا)',
        'fr_GA' => 'الفرنسية (الغابون)',
        'fr_GF' => 'الفرنسية (غويانا الفرنسية)',
        'fr_GN' => 'الفرنسية (غينيا)',
        'fr_GP' => 'الفرنسية (غوادلوب)',
        'fr_GQ' => 'الفرنسية (غينيا الاستوائية)',
        'fr_HT' => 'الفرنسية (هايتي)',
        'fr_KM' => 'الفرنسية (جزر القمر)',
        'fr_LU' => 'الفرنسية (لوكسمبورغ)',
        'fr_MA' => 'الفرنسية (المغرب)',
        'fr_MC' => 'الفرنسية (موناكو)',
        'fr_MF' => 'الفرنسية (سان مارتن)',
        'fr_MG' => 'الفرنسية (مدغشقر)',
        'fr_ML' => 'الفرنسية (مالي)',
        'fr_MQ' => 'الفرنسية (جزر المارتينيك)',
        'fr_MR' => 'الفرنسية (موريتانيا)',
        'fr_MU' => 'الفرنسية (موريشيوس)',
        'fr_NC' => 'الفرنسية (كاليدونيا الجديدة)',
        'fr_NE' => 'الفرنسية (النيجر)',
        'fr_PF' => 'الفرنسية (بولينيزيا الفرنسية)',
        'fr_PM' => 'الفرنسية (سان بيير ومكويلون)',
        'fr_RE' => 'الفرنسية (روينيون)',
        'fr_RW' => 'الفرنسية (رواندا)',
        'fr_SC' => 'الفرنسية (سيشل)',
        'fr_SN' => 'الفرنسية (السنغال)',
        'fr_SY' => 'الفرنسية (سوريا)',
        'fr_TD' => 'الفرنسية (تشاد)',
        'fr_TG' => 'الفرنسية (توغو)',
        'fr_TN' => 'الفرنسية (تونس)',
        'fr_VU' => 'الفرنسية (فانواتو)',
        'fr_WF' => 'الفرنسية (جزر والس وفوتونا)',
        'fr_YT' => 'الفرنسية (مايوت)',
        'fy' => 'الفريزيان',
        'fy_NL' => 'الفريزيان (هولندا)',
        'ga' => 'الأيرلندية',
        'ga_GB' => 'الأيرلندية (المملكة المتحدة)',
        'ga_IE' => 'الأيرلندية (أيرلندا)',
        'gd' => 'الغيلية الأسكتلندية',
        'gd_GB' => 'الغيلية الأسكتلندية (المملكة المتحدة)',
        'gl' => 'الجاليكية',
        'gl_ES' => 'الجاليكية (إسبانيا)',
        'gu' => 'الغوجاراتية',
        'gu_IN' => 'الغوجاراتية (الهند)',
        'gv' => 'المنكية',
        'gv_IM' => 'المنكية (جزيرة مان)',
        'ha' => 'الهوسا',
        'ha_GH' => 'الهوسا (غانا)',
        'ha_NE' => 'الهوسا (النيجر)',
        'ha_NG' => 'الهوسا (نيجيريا)',
        'he' => 'العبرية',
        'he_IL' => 'العبرية (إسرائيل)',
        'hi' => 'الهندية',
        'hi_IN' => 'الهندية (الهند)',
        'hi_Latn' => 'الهندية (اللاتينية)',
        'hi_Latn_IN' => 'الهندية (اللاتينية، الهند)',
        'hr' => 'الكرواتية',
        'hr_BA' => 'الكرواتية (البوسنة والهرسك)',
        'hr_HR' => 'الكرواتية (كرواتيا)',
        'hu' => 'الهنغارية',
        'hu_HU' => 'الهنغارية (هنغاريا)',
        'hy' => 'الأرمنية',
        'hy_AM' => 'الأرمنية (أرمينيا)',
        'ia' => 'اللّغة الوسيطة',
        'ia_001' => 'اللّغة الوسيطة (العالم)',
        'id' => 'الإندونيسية',
        'id_ID' => 'الإندونيسية (إندونيسيا)',
        'ig' => 'الإيجبو',
        'ig_NG' => 'الإيجبو (نيجيريا)',
        'ii' => 'السيتشيون يي',
        'ii_CN' => 'السيتشيون يي (الصين)',
        'is' => 'الأيسلندية',
        'is_IS' => 'الأيسلندية (آيسلندا)',
        'it' => 'الإيطالية',
        'it_CH' => 'الإيطالية (سويسرا)',
        'it_IT' => 'الإيطالية (إيطاليا)',
        'it_SM' => 'الإيطالية (سان مارينو)',
        'it_VA' => 'الإيطالية (الفاتيكان)',
        'ja' => 'اليابانية',
        'ja_JP' => 'اليابانية (اليابان)',
        'jv' => 'الجاوية',
        'jv_ID' => 'الجاوية (إندونيسيا)',
        'ka' => 'الجورجية',
        'ka_GE' => 'الجورجية (جورجيا)',
        'ki' => 'الكيكيو',
        'ki_KE' => 'الكيكيو (كينيا)',
        'kk' => 'الكازاخستانية',
        'kk_KZ' => 'الكازاخستانية (كازاخستان)',
        'kl' => 'الكالاليست',
        'kl_GL' => 'الكالاليست (غرينلاند)',
        'km' => 'الخميرية',
        'km_KH' => 'الخميرية (كمبوديا)',
        'kn' => 'الكانادا',
        'kn_IN' => 'الكانادا (الهند)',
        'ko' => 'الكورية',
        'ko_KP' => 'الكورية (كوريا الشمالية)',
        'ko_KR' => 'الكورية (كوريا الجنوبية)',
        'ks' => 'الكشميرية',
        'ks_Arab' => 'الكشميرية (العربية)',
        'ks_Arab_IN' => 'الكشميرية (العربية، الهند)',
        'ks_Deva' => 'الكشميرية (الديفاناجاري)',
        'ks_Deva_IN' => 'الكشميرية (الديفاناجاري، الهند)',
        'ks_IN' => 'الكشميرية (الهند)',
        'ku' => 'الكردية',
        'ku_TR' => 'الكردية (تركيا)',
        'kw' => 'الكورنية',
        'kw_GB' => 'الكورنية (المملكة المتحدة)',
        'ky' => 'القيرغيزية',
        'ky_KG' => 'القيرغيزية (قيرغيزستان)',
        'lb' => 'اللكسمبورغية',
        'lb_LU' => 'اللكسمبورغية (لوكسمبورغ)',
        'lg' => 'الغاندا',
        'lg_UG' => 'الغاندا (أوغندا)',
        'ln' => 'اللينجالا',
        'ln_AO' => 'اللينجالا (أنغولا)',
        'ln_CD' => 'اللينجالا (الكونغو - كينشاسا)',
        'ln_CF' => 'اللينجالا (جمهورية أفريقيا الوسطى)',
        'ln_CG' => 'اللينجالا (الكونغو - برازافيل)',
        'lo' => 'اللاوية',
        'lo_LA' => 'اللاوية (لاوس)',
        'lt' => 'الليتوانية',
        'lt_LT' => 'الليتوانية (ليتوانيا)',
        'lu' => 'اللوبا كاتانغا',
        'lu_CD' => 'اللوبا كاتانغا (الكونغو - كينشاسا)',
        'lv' => 'اللاتفية',
        'lv_LV' => 'اللاتفية (لاتفيا)',
        'mg' => 'الملغاشي',
        'mg_MG' => 'الملغاشي (مدغشقر)',
        'mi' => 'الماورية',
        'mi_NZ' => 'الماورية (نيوزيلندا)',
        'mk' => 'المقدونية',
        'mk_MK' => 'المقدونية (مقدونيا الشمالية)',
        'ml' => 'المالايالامية',
        'ml_IN' => 'المالايالامية (الهند)',
        'mn' => 'المنغولية',
        'mn_MN' => 'المنغولية (منغوليا)',
        'mr' => 'الماراثية',
        'mr_IN' => 'الماراثية (الهند)',
        'ms' => 'الماليزية',
        'ms_BN' => 'الماليزية (بروناي)',
        'ms_ID' => 'الماليزية (إندونيسيا)',
        'ms_MY' => 'الماليزية (ماليزيا)',
        'ms_SG' => 'الماليزية (سنغافورة)',
        'mt' => 'المالطية',
        'mt_MT' => 'المالطية (مالطا)',
        'my' => 'البورمية',
        'my_MM' => 'البورمية (ميانمار [بورما])',
        'nb' => 'النرويجية بوكمال',
        'nb_NO' => 'النرويجية بوكمال (النرويج)',
        'nb_SJ' => 'النرويجية بوكمال (سفالبارد وجان ماين)',
        'nd' => 'النديبيل الشمالية',
        'nd_ZW' => 'النديبيل الشمالية (زيمبابوي)',
        'ne' => 'النيبالية',
        'ne_IN' => 'النيبالية (الهند)',
        'ne_NP' => 'النيبالية (نيبال)',
        'nl' => 'الهولندية',
        'nl_AW' => 'الهولندية (أروبا)',
        'nl_BE' => 'الهولندية (بلجيكا)',
        'nl_BQ' => 'الهولندية (هولندا الكاريبية)',
        'nl_CW' => 'الهولندية (كوراساو)',
        'nl_NL' => 'الهولندية (هولندا)',
        'nl_SR' => 'الهولندية (سورينام)',
        'nl_SX' => 'الهولندية (سانت مارتن)',
        'nn' => 'النرويجية نينورسك',
        'nn_NO' => 'النرويجية نينورسك (النرويج)',
        'no' => 'النرويجية',
        'no_NO' => 'النرويجية (النرويج)',
        'om' => 'الأورومية',
        'om_ET' => 'الأورومية (إثيوبيا)',
        'om_KE' => 'الأورومية (كينيا)',
        'or' => 'الأورية',
        'or_IN' => 'الأورية (الهند)',
        'os' => 'الأوسيتيك',
        'os_GE' => 'الأوسيتيك (جورجيا)',
        'os_RU' => 'الأوسيتيك (روسيا)',
        'pa' => 'البنجابية',
        'pa_Arab' => 'البنجابية (العربية)',
        'pa_Arab_PK' => 'البنجابية (العربية، باكستان)',
        'pa_Guru' => 'البنجابية (الجرمخي)',
        'pa_Guru_IN' => 'البنجابية (الجرمخي، الهند)',
        'pa_IN' => 'البنجابية (الهند)',
        'pa_PK' => 'البنجابية (باكستان)',
        'pl' => 'البولندية',
        'pl_PL' => 'البولندية (بولندا)',
        'ps' => 'البشتو',
        'ps_AF' => 'البشتو (أفغانستان)',
        'ps_PK' => 'البشتو (باكستان)',
        'pt' => 'البرتغالية',
        'pt_AO' => 'البرتغالية (أنغولا)',
        'pt_BR' => 'البرتغالية (البرازيل)',
        'pt_CH' => 'البرتغالية (سويسرا)',
        'pt_CV' => 'البرتغالية (الرأس الأخضر)',
        'pt_GQ' => 'البرتغالية (غينيا الاستوائية)',
        'pt_GW' => 'البرتغالية (غينيا بيساو)',
        'pt_LU' => 'البرتغالية (لوكسمبورغ)',
        'pt_MO' => 'البرتغالية (منطقة ماكاو الإدارية الخاصة)',
        'pt_MZ' => 'البرتغالية (موزمبيق)',
        'pt_PT' => 'البرتغالية (البرتغال)',
        'pt_ST' => 'البرتغالية (ساو تومي وبرينسيبي)',
        'pt_TL' => 'البرتغالية (تيمور - ليشتي)',
        'qu' => 'الكويتشوا',
        'qu_BO' => 'الكويتشوا (بوليفيا)',
        'qu_EC' => 'الكويتشوا (الإكوادور)',
        'qu_PE' => 'الكويتشوا (بيرو)',
        'rm' => 'الرومانشية',
        'rm_CH' => 'الرومانشية (سويسرا)',
        'rn' => 'الرندي',
        'rn_BI' => 'الرندي (بوروندي)',
        'ro' => 'الرومانية',
        'ro_MD' => 'الرومانية (مولدوفا)',
        'ro_RO' => 'الرومانية (رومانيا)',
        'ru' => 'الروسية',
        'ru_BY' => 'الروسية (بيلاروس)',
        'ru_KG' => 'الروسية (قيرغيزستان)',
        'ru_KZ' => 'الروسية (كازاخستان)',
        'ru_MD' => 'الروسية (مولدوفا)',
        'ru_RU' => 'الروسية (روسيا)',
        'ru_UA' => 'الروسية (أوكرانيا)',
        'rw' => 'الكينيارواندا',
        'rw_RW' => 'الكينيارواندا (رواندا)',
        'sa' => 'السنسكريتية',
        'sa_IN' => 'السنسكريتية (الهند)',
        'sc' => 'السردينية',
        'sc_IT' => 'السردينية (إيطاليا)',
        'sd' => 'السندية',
        'sd_Arab' => 'السندية (العربية)',
        'sd_Arab_PK' => 'السندية (العربية، باكستان)',
        'sd_Deva' => 'السندية (الديفاناجاري)',
        'sd_Deva_IN' => 'السندية (الديفاناجاري، الهند)',
        'sd_IN' => 'السندية (الهند)',
        'sd_PK' => 'السندية (باكستان)',
        'se' => 'سامي الشمالية',
        'se_FI' => 'سامي الشمالية (فنلندا)',
        'se_NO' => 'سامي الشمالية (النرويج)',
        'se_SE' => 'سامي الشمالية (السويد)',
        'sg' => 'السانجو',
        'sg_CF' => 'السانجو (جمهورية أفريقيا الوسطى)',
        'sh' => 'صربية-كرواتية',
        'sh_BA' => 'صربية-كرواتية (البوسنة والهرسك)',
        'si' => 'السنهالية',
        'si_LK' => 'السنهالية (سريلانكا)',
        'sk' => 'السلوفاكية',
        'sk_SK' => 'السلوفاكية (سلوفاكيا)',
        'sl' => 'السلوفانية',
        'sl_SI' => 'السلوفانية (سلوفينيا)',
        'sn' => 'الشونا',
        'sn_ZW' => 'الشونا (زيمبابوي)',
        'so' => 'الصومالية',
        'so_DJ' => 'الصومالية (جيبوتي)',
        'so_ET' => 'الصومالية (إثيوبيا)',
        'so_KE' => 'الصومالية (كينيا)',
        'so_SO' => 'الصومالية (الصومال)',
        'sq' => 'الألبانية',
        'sq_AL' => 'الألبانية (ألبانيا)',
        'sq_MK' => 'الألبانية (مقدونيا الشمالية)',
        'sr' => 'الصربية',
        'sr_BA' => 'الصربية (البوسنة والهرسك)',
        'sr_Cyrl' => 'الصربية (السيريلية)',
        'sr_Cyrl_BA' => 'الصربية (السيريلية، البوسنة والهرسك)',
        'sr_Cyrl_ME' => 'الصربية (السيريلية، الجبل الأسود)',
        'sr_Cyrl_RS' => 'الصربية (السيريلية، صربيا)',
        'sr_Latn' => 'الصربية (اللاتينية)',
        'sr_Latn_BA' => 'الصربية (اللاتينية، البوسنة والهرسك)',
        'sr_Latn_ME' => 'الصربية (اللاتينية، الجبل الأسود)',
        'sr_Latn_RS' => 'الصربية (اللاتينية، صربيا)',
        'sr_ME' => 'الصربية (الجبل الأسود)',
        'sr_RS' => 'الصربية (صربيا)',
        'su' => 'السوندانية',
        'su_ID' => 'السوندانية (إندونيسيا)',
        'su_Latn' => 'السوندانية (اللاتينية)',
        'su_Latn_ID' => 'السوندانية (اللاتينية، إندونيسيا)',
        'sv' => 'السويدية',
        'sv_AX' => 'السويدية (جزر آلاند)',
        'sv_FI' => 'السويدية (فنلندا)',
        'sv_SE' => 'السويدية (السويد)',
        'sw' => 'السواحلية',
        'sw_CD' => 'السواحلية (الكونغو - كينشاسا)',
        'sw_KE' => 'السواحلية (كينيا)',
        'sw_TZ' => 'السواحلية (تنزانيا)',
        'sw_UG' => 'السواحلية (أوغندا)',
        'ta' => 'التاميلية',
        'ta_IN' => 'التاميلية (الهند)',
        'ta_LK' => 'التاميلية (سريلانكا)',
        'ta_MY' => 'التاميلية (ماليزيا)',
        'ta_SG' => 'التاميلية (سنغافورة)',
        'te' => 'التيلوغوية',
        'te_IN' => 'التيلوغوية (الهند)',
        'tg' => 'الطاجيكية',
        'tg_TJ' => 'الطاجيكية (طاجيكستان)',
        'th' => 'التايلاندية',
        'th_TH' => 'التايلاندية (تايلاند)',
        'ti' => 'التغرينية',
        'ti_ER' => 'التغرينية (إريتريا)',
        'ti_ET' => 'التغرينية (إثيوبيا)',
        'tk' => 'التركمانية',
        'tk_TM' => 'التركمانية (تركمانستان)',
        'tl' => 'التاغالوغية',
        'tl_PH' => 'التاغالوغية (الفلبين)',
        'to' => 'التونغية',
        'to_TO' => 'التونغية (تونغا)',
        'tr' => 'التركية',
        'tr_CY' => 'التركية (قبرص)',
        'tr_TR' => 'التركية (تركيا)',
        'tt' => 'التترية',
        'tt_RU' => 'التترية (روسيا)',
        'ug' => 'الأويغورية',
        'ug_CN' => 'الأويغورية (الصين)',
        'uk' => 'الأوكرانية',
        'uk_UA' => 'الأوكرانية (أوكرانيا)',
        'ur' => 'الأوردية',
        'ur_IN' => 'الأوردية (الهند)',
        'ur_PK' => 'الأوردية (باكستان)',
        'uz' => 'الأوزبكية',
        'uz_AF' => 'الأوزبكية (أفغانستان)',
        'uz_Arab' => 'الأوزبكية (العربية)',
        'uz_Arab_AF' => 'الأوزبكية (العربية، أفغانستان)',
        'uz_Cyrl' => 'الأوزبكية (السيريلية)',
        'uz_Cyrl_UZ' => 'الأوزبكية (السيريلية، أوزبكستان)',
        'uz_Latn' => 'الأوزبكية (اللاتينية)',
        'uz_Latn_UZ' => 'الأوزبكية (اللاتينية، أوزبكستان)',
        'uz_UZ' => 'الأوزبكية (أوزبكستان)',
        'vi' => 'الفيتنامية',
        'vi_VN' => 'الفيتنامية (فيتنام)',
        'wo' => 'الولوفية',
        'wo_SN' => 'الولوفية (السنغال)',
        'xh' => 'الخوسا',
        'xh_ZA' => 'الخوسا (جنوب أفريقيا)',
        'yi' => 'اليديشية',
        'yi_001' => 'اليديشية (العالم)',
        'yo' => 'اليوروبا',
        'yo_BJ' => 'اليوروبا (بنين)',
        'yo_NG' => 'اليوروبا (نيجيريا)',
        'zh' => 'الصينية',
        'zh_CN' => 'الصينية (الصين)',
        'zh_HK' => 'الصينية (هونغ كونغ الصينية [منطقة إدارية خاصة])',
        'zh_Hans' => 'الصينية (المبسطة)',
        'zh_Hans_CN' => 'الصينية (المبسطة، الصين)',
        'zh_Hans_HK' => 'الصينية (المبسطة، هونغ كونغ الصينية [منطقة إدارية خاصة])',
        'zh_Hans_MO' => 'الصينية (المبسطة، منطقة ماكاو الإدارية الخاصة)',
        'zh_Hans_SG' => 'الصينية (المبسطة، سنغافورة)',
        'zh_Hant' => 'الصينية (التقليدية)',
        'zh_Hant_HK' => 'الصينية (التقليدية، هونغ كونغ الصينية [منطقة إدارية خاصة])',
        'zh_Hant_MO' => 'الصينية (التقليدية، منطقة ماكاو الإدارية الخاصة)',
        'zh_Hant_TW' => 'الصينية (التقليدية، تايوان)',
        'zh_MO' => 'الصينية (منطقة ماكاو الإدارية الخاصة)',
        'zh_SG' => 'الصينية (سنغافورة)',
        'zh_TW' => 'الصينية (تايوان)',
        'zu' => 'الزولو',
        'zu_ZA' => 'الزولو (جنوب أفريقيا)',
    ],
];
