<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'андоррська песета',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'дирхам ОАЕ',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'афгані (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'афганський афгані',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'албанський лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'вірменський драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'нідерландський антильський гульден',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'ангольська кванза',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'ангольська кванза (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'ангольська нова кванза (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'ангольська кванза реаджастадо (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'аргентинський австрал',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'аргентинський песо (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'аргентинський песо',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'австрійський шилінг',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'австралійський долар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'арубський флорин',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'азербайджанський манат (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'азербайджанський манат',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'динар (Боснія і Герцеговина)',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'конвертована марка Боснії і Герцеговини',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'барбадоський долар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'бангладеська така',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'бельгійський франк (конвертований)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'бельгійський франк',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'бельгійський франк (фінансовий)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'болгарський твердий лев',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'болгарський лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'бахрейнський динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'бурундійський франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'бермудський долар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'брунейський долар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'болівійський болівіано',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'болівійське песо',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'болівійський мвдол',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'бразильське нове крузейро (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'бразильське крузадо',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'бразильське крузейро (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'бразильський реал',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'бразильське нове крузадо',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'бразильське крузейро',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'багамський долар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'бутанський нгултрум',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'бірманський кіат',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'ботсванська пула',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'білоруський новий рубль (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'білоруський рубль',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'білоруський рубль (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'белізький долар',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'канадський долар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'конголезький франк',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'євро WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'швейцарський франк',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'франк WIR',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'чилійський юнідадес де фоменто',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'чилійський песо',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'китайський офшорний юань',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'китайський юань',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'колумбійський песо',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'одиниця реальної вартості',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'костариканський колон',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'старий сербський динар',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'чехословацька тверда крона',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'кубинський конвертований песо',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'кубинський песо',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'ескудо Кабо-Верде',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'кіпрський фунт',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'чеська крона',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'марка НДР',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'німецька марка',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'джибутійський франк',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'данська крона',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'домініканський песо',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'алжирський динар',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'еквадорський сукре',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'еквадорський юнідад де валор константе',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'естонська крона',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'єгипетський фунт',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'еритрейська накфа',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'іспанська песета ("А" рахунок)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'іспанська песета (конвертовані рахунки)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'іспанська песета',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'ефіопський бир',
        ],
        'EUR' => [
            0 => 'EUR',
            1 => 'євро',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'фінляндська марка',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'фіджійський долар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'фунт Фолклендських островів',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'французький франк',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'англійський фунт',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'грузинський купон',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'грузинський ларі',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ганський седі (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ганський седі',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'гібралтарський фунт',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'гамбійський даласі',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'гвінейський франк',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'гвінейське сілі',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'еквеле (Екваторіальна Ґвінея)',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'грецька драхма',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'гватемальський кетсаль',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'ескудо португальської гвінеї',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'песо Гвінеї-Бісау',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'гаянський долар',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'гонконгський долар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'гондураська лемпіра',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'хорватський динар',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'хорватська куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'гаїтянський гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'угорський форинт',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'індонезійська рупія',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'ірландський фунт',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'ізраїльський фунт',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'ізраїльський новий шекель',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'індійська рупія',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'іракський динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'іранський ріал',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'ісландська крона',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'італійська ліра',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'ямайський долар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'йорданський динар',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'японська єна',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'кенійський шилінг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'киргизький сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'камбоджійський рієль',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'коморський франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'північнокорейський вон',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'південнокорейський вон',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'кувейтський динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'долар Кайманових островів',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'казахстанський тенге',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'лаоський кіп',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'ліванський фунт',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'шрі-ланкійська рупія',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'ліберійський долар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'лесотський лоті',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'литовський літ',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'литовський талон',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'люксембурґський франк (конвертований)',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'люксембурзький франк',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'люксембурґський франк (фінансовий)',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'латвійський лат',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'латвійський рубль',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'лівійський динар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'марокканський дирхам',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'марокканський франк',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'молдовський лей',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'малагасійський аріарі',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'мадагаскарський франк',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'македонський денар',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'малійський франк',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'кʼят Мʼянми',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'монгольський тугрик',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'патака Макао',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'мавританська угія (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'мавританська угія',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'мальтійська ліра',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'мальтійський фунт',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'маврикійська рупія',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'мальдівська руфія',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'малавійська квача',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'мексиканський песо',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'мексиканське срібне песо (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'мексиканський юнідад де інверсіон',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'малайзійський рингіт',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'мозамбіцький ескудо',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'старий мозамбіцький метикал',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'мозамбіцький метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'намібійський долар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'нігерійська найра',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'нікарагуанська кордоба (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'нікарагуанська кордоба',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'нідерландський гульден',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'норвезька крона',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'непальська рупія',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'новозеландський долар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'оманський ріал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'панамське бальбоа',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'перуанський інті',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'перуанський новий сол',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'перуанський сол (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'кіна Папуа-Нової Ґвінеї',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'філіппінський песо',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'пакистанська рупія',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'польський злотий',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'польський злотий (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'португальський ескудо',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'парагвайський гуарані',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'катарський ріал',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'родезійський долар',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'старий румунський лей',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'румунський лей',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'сербський динар',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'російський рубль',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'російський рубль (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'руандійський франк',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'саудівський ріал',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'долар Соломонових Островів',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'сейшельська рупія',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'суданський динар',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'суданський фунт',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'старий суданський фунт',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'шведська крона',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'сінгапурський долар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'фунт острова Святої Єлени',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'словенський толар',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'словацька крона',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'леоне Сьєрра-Леоне',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'сомалійський шилінг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'суринамський долар',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'суринамський гульден',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'південносуданський фунт',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'добра Сан-Томе і Прінсіпі (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'добра Сан-Томе і Прінсіпі',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'радянський рубль',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'сальвадорський колон',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'сирійський фунт',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'свазілендський лілангені',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'таїландський бат',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'таджицький рубль',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'таджицький сомоні',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'туркменський манат (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'туркменський манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'туніський динар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'тонганська паанга',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'тіморський ескудо',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'турецька ліра (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'турецька ліра',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'долар Тринідаду і Тобаго',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'новий тайванський долар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'танзанійський шилінг',
        ],
        'UAH' => [
            0 => '₴',
            1 => 'українська гривня',
        ],
        'UAK' => [
            0 => 'крб.',
            1 => 'український карбованець',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'угандійський шилінг (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'угандійський шилінг',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'долар США',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'долар США (наступного дня)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'долар США (цього дня)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'уругвайський песо в індексованих одиницях',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'уругвайське песо (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'уругвайський песо',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'узбецький сум',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'венесуельський болівар (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'венесуельський болівар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'венесуельський болівар',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'вʼєтнамський донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'вануатський вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'самоанська тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'центральноафриканський франк',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'східнокарибський долар',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'європейська валютна одиниця',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'французький золотий франк',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'французький франк UIC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'західноафриканський франк',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'французький тихоокеанський франк',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'фонди RINET',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'єменський динар',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'єменський ріал',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'югославський твердий динар',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'югославський новий динар',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'югославський конвертований динар',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'південноафриканський фінансовий ранд',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'південноафриканський ранд',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'замбійська квача (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'замбійська квача',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'заїрський новий заїр',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'заїрський заїр',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'зімбабвійський долар',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'зімбабвійський долар (2009)',
        ],
    ],
];
