<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'GMT (Abidjan)',
        'Africa/Accra' => 'GMT (Accra)',
        'Africa/Addis_Ababa' => 'Østafrikansk tid (Addis Abeba)',
        'Africa/Algiers' => 'Centraleuropæisk tid (Algier)',
        'Africa/Asmera' => 'Østafrikansk tid (Asmara)',
        'Africa/Bamako' => 'GMT (Bamako)',
        'Africa/Bangui' => 'Vestafrikansk tid (Bangui)',
        'Africa/Banjul' => 'GMT (Banjul)',
        'Africa/Bissau' => 'GMT (Bissau)',
        'Africa/Blantyre' => 'Centralafrikansk tid (Blantyre)',
        'Africa/Brazzaville' => 'Vestafrikansk tid (Brazzaville)',
        'Africa/Bujumbura' => 'Centralafrikansk tid (Bujumbura)',
        'Africa/Cairo' => 'Østeuropæisk tid (Cairo)',
        'Africa/Casablanca' => 'Vesteuropæisk tid (Casablanca)',
        'Africa/Ceuta' => 'Centraleuropæisk tid (Ceuta)',
        'Africa/Conakry' => 'GMT (Conakry)',
        'Africa/Dakar' => 'GMT (Dakar)',
        'Africa/Dar_es_Salaam' => 'Østafrikansk tid (Dar es Salaam)',
        'Africa/Djibouti' => 'Østafrikansk tid (Djibouti)',
        'Africa/Douala' => 'Vestafrikansk tid (Douala)',
        'Africa/El_Aaiun' => 'Vesteuropæisk tid (El Aaiun)',
        'Africa/Freetown' => 'GMT (Freetown)',
        'Africa/Gaborone' => 'Centralafrikansk tid (Gaborone)',
        'Africa/Harare' => 'Centralafrikansk tid (Harare)',
        'Africa/Johannesburg' => 'Sydafrikansk tid (Johannesburg)',
        'Africa/Juba' => 'Centralafrikansk tid (Juba)',
        'Africa/Kampala' => 'Østafrikansk tid (Kampala)',
        'Africa/Khartoum' => 'Centralafrikansk tid (Khartoum)',
        'Africa/Kigali' => 'Centralafrikansk tid (Kigali)',
        'Africa/Kinshasa' => 'Vestafrikansk tid (Kinshasa)',
        'Africa/Lagos' => 'Vestafrikansk tid (Lagos)',
        'Africa/Libreville' => 'Vestafrikansk tid (Libreville)',
        'Africa/Lome' => 'GMT (Lome)',
        'Africa/Luanda' => 'Vestafrikansk tid (Luanda)',
        'Africa/Lubumbashi' => 'Centralafrikansk tid (Lubumbashi)',
        'Africa/Lusaka' => 'Centralafrikansk tid (Lusaka)',
        'Africa/Malabo' => 'Vestafrikansk tid (Malabo)',
        'Africa/Maputo' => 'Centralafrikansk tid (Maputo)',
        'Africa/Maseru' => 'Sydafrikansk tid (Maseru)',
        'Africa/Mbabane' => 'Sydafrikansk tid (Mbabane)',
        'Africa/Mogadishu' => 'Østafrikansk tid (Mogadishu)',
        'Africa/Monrovia' => 'GMT (Monrovia)',
        'Africa/Nairobi' => 'Østafrikansk tid (Nairobi)',
        'Africa/Ndjamena' => 'Vestafrikansk tid (Ndjamena)',
        'Africa/Niamey' => 'Vestafrikansk tid (Niamey)',
        'Africa/Nouakchott' => 'GMT (Nouakchott)',
        'Africa/Ouagadougou' => 'GMT (Ouagadougou)',
        'Africa/Porto-Novo' => 'Vestafrikansk tid (Porto-Novo)',
        'Africa/Sao_Tome' => 'GMT (São Tomé)',
        'Africa/Tripoli' => 'Østeuropæisk tid (Tripoli)',
        'Africa/Tunis' => 'Centraleuropæisk tid (Tunis)',
        'Africa/Windhoek' => 'Centralafrikansk tid (Windhoek)',
        'America/Adak' => 'Hawaii-Aleutian-tid (Adak)',
        'America/Anchorage' => 'Alaska-tid (Anchorage)',
        'America/Anguilla' => 'Atlantic-tid (Anguilla)',
        'America/Antigua' => 'Atlantic-tid (Antigua)',
        'America/Araguaina' => 'Brasiliansk tid (Araguaina)',
        'America/Argentina/La_Rioja' => 'Argentisk tid (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentisk tid (Rio Gallegos)',
        'America/Argentina/Salta' => 'Argentisk tid (Salta)',
        'America/Argentina/San_Juan' => 'Argentisk tid (San Juan)',
        'America/Argentina/San_Luis' => 'Argentisk tid (San Luis)',
        'America/Argentina/Tucuman' => 'Argentisk tid (Tucuman)',
        'America/Argentina/Ushuaia' => 'Argentisk tid (Ushuaia)',
        'America/Aruba' => 'Atlantic-tid (Aruba)',
        'America/Asuncion' => 'Paraguayansk tid (Asunción)',
        'America/Bahia' => 'Brasiliansk tid (Bahia)',
        'America/Bahia_Banderas' => 'Central-tid (Bahia Banderas)',
        'America/Barbados' => 'Atlantic-tid (Barbados)',
        'America/Belem' => 'Brasiliansk tid (Belem)',
        'America/Belize' => 'Central-tid (Belize)',
        'America/Blanc-Sablon' => 'Atlantic-tid (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazonas-tid (Boa Vista)',
        'America/Bogota' => 'Colombiansk tid (Bogota)',
        'America/Boise' => 'Mountain-tid (Boise)',
        'America/Buenos_Aires' => 'Argentisk tid (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mountain-tid (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazonas-tid (Campo Grande)',
        'America/Cancun' => 'Eastern-tid (Cancun)',
        'America/Caracas' => 'Venezuelansk tid (Caracas)',
        'America/Catamarca' => 'Argentisk tid (Catamarca)',
        'America/Cayenne' => 'Fransk Guyana-tid (Cayenne)',
        'America/Cayman' => 'Eastern-tid (Caymanøerne)',
        'America/Chicago' => 'Central-tid (Chicago)',
        'America/Chihuahua' => 'Mexicansk Pacific-tid (Chihuahua)',
        'America/Coral_Harbour' => 'Eastern-tid (Atikokan)',
        'America/Cordoba' => 'Argentisk tid (Cordoba)',
        'America/Costa_Rica' => 'Central-tid (Costa Rica)',
        'America/Creston' => 'Mountain-tid (Creston)',
        'America/Cuiaba' => 'Amazonas-tid (Cuiaba)',
        'America/Curacao' => 'Atlantic-tid (Curaçao)',
        'America/Danmarkshavn' => 'GMT (Danmarkshavn)',
        'America/Dawson' => 'Yukon-tid (Dawson)',
        'America/Dawson_Creek' => 'Mountain-tid (Dawson Creek)',
        'America/Denver' => 'Mountain-tid (Denver)',
        'America/Detroit' => 'Eastern-tid (Detroit)',
        'America/Dominica' => 'Atlantic-tid (Dominica)',
        'America/Edmonton' => 'Mountain-tid (Edmonton)',
        'America/Eirunepe' => 'Acre-tid (Eirunepe)',
        'America/El_Salvador' => 'Central-tid (El Salvador)',
        'America/Fort_Nelson' => 'Mountain-tid (Fort Nelson)',
        'America/Fortaleza' => 'Brasiliansk tid (Fortaleza)',
        'America/Glace_Bay' => 'Atlantic-tid (Glace Bay)',
        'America/Godthab' => 'Vestgrønlandsk tid (Nuuk)',
        'America/Goose_Bay' => 'Atlantic-tid (Goose Bay)',
        'America/Grand_Turk' => 'Eastern-tid (Grand Turk)',
        'America/Grenada' => 'Atlantic-tid (Grenada)',
        'America/Guadeloupe' => 'Atlantic-tid (Guadeloupe)',
        'America/Guatemala' => 'Central-tid (Guatemala)',
        'America/Guayaquil' => 'Ecuadoriansk tid (Guayaquil)',
        'America/Guyana' => 'Guyana-tid',
        'America/Halifax' => 'Atlantic-tid (Halifax)',
        'America/Havana' => 'Cubansk tid (Havana)',
        'America/Hermosillo' => 'Mexicansk Pacific-tid (Hermosillo)',
        'America/Indiana/Knox' => 'Central-tid (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Eastern-tid (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Eastern-tid (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Central-tid (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Eastern-tid (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Eastern-tid (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Eastern-tid (Winamac, Indiana)',
        'America/Indianapolis' => 'Eastern-tid (Indianapolis)',
        'America/Inuvik' => 'Mountain-tid (Inuvik)',
        'America/Iqaluit' => 'Eastern-tid (Iqaluit)',
        'America/Jamaica' => 'Eastern-tid (Jamaica)',
        'America/Jujuy' => 'Argentisk tid (Jujuy)',
        'America/Juneau' => 'Alaska-tid (Juneau)',
        'America/Kentucky/Monticello' => 'Eastern-tid (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantic-tid (Kralendijk)',
        'America/La_Paz' => 'Boliviansk tid (La Paz)',
        'America/Lima' => 'Peruviansk tid (Lima)',
        'America/Los_Angeles' => 'Pacific-tid (Los Angeles)',
        'America/Louisville' => 'Eastern-tid (Louisville)',
        'America/Lower_Princes' => 'Atlantic-tid (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasiliansk tid (Maceio)',
        'America/Managua' => 'Central-tid (Managua)',
        'America/Manaus' => 'Amazonas-tid (Manaus)',
        'America/Marigot' => 'Atlantic-tid (Marigot)',
        'America/Martinique' => 'Atlantic-tid (Martinique)',
        'America/Matamoros' => 'Central-tid (Matamoros)',
        'America/Mazatlan' => 'Mexicansk Pacific-tid (Mazatlan)',
        'America/Mendoza' => 'Argentisk tid (Mendoza)',
        'America/Menominee' => 'Central-tid (Menominee)',
        'America/Merida' => 'Central-tid (Merida)',
        'America/Metlakatla' => 'Alaska-tid (Metlakatla)',
        'America/Mexico_City' => 'Central-tid (Mexico City)',
        'America/Miquelon' => 'Saint Pierre- og Miquelon-tid',
        'America/Moncton' => 'Atlantic-tid (Moncton)',
        'America/Monterrey' => 'Central-tid (Monterrey)',
        'America/Montevideo' => 'Uruguayansk tid (Montevideo)',
        'America/Montreal' => 'Canada (Montreal)',
        'America/Montserrat' => 'Atlantic-tid (Montserrat)',
        'America/Nassau' => 'Eastern-tid (Nassau)',
        'America/New_York' => 'Eastern-tid (New York)',
        'America/Nipigon' => 'Eastern-tid (Nipigon)',
        'America/Nome' => 'Alaska-tid (Nome)',
        'America/Noronha' => 'Fernando de Noronha-tid',
        'America/North_Dakota/Beulah' => 'Central-tid (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Central-tid (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Central-tid (New Salem, North Dakota)',
        'America/Ojinaga' => 'Mountain-tid (Ojinaga)',
        'America/Panama' => 'Eastern-tid (Panama)',
        'America/Pangnirtung' => 'Eastern-tid (Pangnirtung)',
        'America/Paramaribo' => 'Surinam-tid (Paramaribo)',
        'America/Phoenix' => 'Mountain-tid (Phoenix)',
        'America/Port-au-Prince' => 'Eastern-tid (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantic-tid (Port of Spain)',
        'America/Porto_Velho' => 'Amazonas-tid (Porto Velho)',
        'America/Puerto_Rico' => 'Atlantic-tid (Puerto Rico)',
        'America/Punta_Arenas' => 'Chilensk tid (Punta Arenas)',
        'America/Rainy_River' => 'Central-tid (Rainy River)',
        'America/Rankin_Inlet' => 'Central-tid (Rankin Inlet)',
        'America/Recife' => 'Brasiliansk tid (Recife)',
        'America/Regina' => 'Central-tid (Regina)',
        'America/Resolute' => 'Central-tid (Resolute)',
        'America/Rio_Branco' => 'Acre-tid (Rio Branco)',
        'America/Santa_Isabel' => 'Nordvestmexicansk tid (Santa Isabel)',
        'America/Santarem' => 'Brasiliansk tid (Santarem)',
        'America/Santiago' => 'Chilensk tid (Santiago)',
        'America/Santo_Domingo' => 'Atlantic-tid (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasiliansk tid (São Paulo)',
        'America/Scoresbysund' => 'Østgrønlandsk tid (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska-tid (Sitka)',
        'America/St_Barthelemy' => 'Atlantic-tid (Saint-Barthélemy)',
        'America/St_Johns' => 'Newfoundlandsk tid (St. John’s)',
        'America/St_Kitts' => 'Atlantic-tid (St. Kitts)',
        'America/St_Lucia' => 'Atlantic-tid (St. Lucia)',
        'America/St_Thomas' => 'Atlantic-tid (St. Thomas)',
        'America/St_Vincent' => 'Atlantic-tid (St. Vincent)',
        'America/Swift_Current' => 'Central-tid (Swift Current)',
        'America/Tegucigalpa' => 'Central-tid (Tegucigalpa)',
        'America/Thule' => 'Atlantic-tid (Thule)',
        'America/Thunder_Bay' => 'Eastern-tid (Thunder Bay)',
        'America/Tijuana' => 'Pacific-tid (Tijuana)',
        'America/Toronto' => 'Eastern-tid (Toronto)',
        'America/Tortola' => 'Atlantic-tid (Tortola)',
        'America/Vancouver' => 'Pacific-tid (Vancouver)',
        'America/Whitehorse' => 'Yukon-tid (Whitehorse)',
        'America/Winnipeg' => 'Central-tid (Winnipeg)',
        'America/Yakutat' => 'Alaska-tid (Yakutat)',
        'America/Yellowknife' => 'Mountain-tid (Yellowknife)',
        'Antarctica/Casey' => 'Antarktis (Casey)',
        'Antarctica/Davis' => 'Davis-tid',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville-tid',
        'Antarctica/Macquarie' => 'Østaustralsk tid (Macquarie)',
        'Antarctica/Mawson' => 'Mawson-tid',
        'Antarctica/McMurdo' => 'Newzealandsk tid (McMurdo)',
        'Antarctica/Palmer' => 'Chilensk tid (Palmer)',
        'Antarctica/Rothera' => 'Rothera-tid',
        'Antarctica/Syowa' => 'Syowa-tid',
        'Antarctica/Troll' => 'GMT (Troll)',
        'Antarctica/Vostok' => 'Vostok-tid',
        'Arctic/Longyearbyen' => 'Centraleuropæisk tid (Longyearbyen)',
        'Asia/Aden' => 'Arabisk tid (Aden)',
        'Asia/Almaty' => 'Østkasakhstansk tid (Almaty)',
        'Asia/Amman' => 'Østeuropæisk tid (Amman)',
        'Asia/Anadyr' => 'Anadyr-tid',
        'Asia/Aqtau' => 'Vestkasakhstansk tid (Aktau)',
        'Asia/Aqtobe' => 'Vestkasakhstansk tid (Aktobe)',
        'Asia/Ashgabat' => 'Turkmensk tid (Asjkhabad)',
        'Asia/Atyrau' => 'Vestkasakhstansk tid (Atyrau)',
        'Asia/Baghdad' => 'Arabisk tid (Bagdad)',
        'Asia/Bahrain' => 'Arabisk tid (Bahrain)',
        'Asia/Baku' => 'Aserbajdsjansk tid (Baku)',
        'Asia/Bangkok' => 'Indokina-tid (Bangkok)',
        'Asia/Barnaul' => 'Rusland (Barnaul)',
        'Asia/Beirut' => 'Østeuropæisk tid (Beirut)',
        'Asia/Bishkek' => 'Kirgisisk tid (Bisjkek)',
        'Asia/Brunei' => 'Brunei Darussalam-tid',
        'Asia/Calcutta' => 'Indisk normaltid (Kolkata)',
        'Asia/Chita' => 'Jakutsk-tid (Chita)',
        'Asia/Choibalsan' => 'Ulan Bator-tid (Tsjojbalsan)',
        'Asia/Colombo' => 'Indisk normaltid (Colombo)',
        'Asia/Damascus' => 'Østeuropæisk tid (Damaskus)',
        'Asia/Dhaka' => 'Bangladesh-tid (Dhaka)',
        'Asia/Dili' => 'Østtimor-tid (Dili)',
        'Asia/Dubai' => 'Golflandene-normaltid (Dubai)',
        'Asia/Dushanbe' => 'Tadsjikisk tid (Dusjanbe)',
        'Asia/Famagusta' => 'Østeuropæisk tid (Famagusta)',
        'Asia/Gaza' => 'Østeuropæisk tid (Gaza)',
        'Asia/Hebron' => 'Østeuropæisk tid (Hebron)',
        'Asia/Hong_Kong' => 'Hongkong-tid',
        'Asia/Hovd' => 'Hovd-tid',
        'Asia/Irkutsk' => 'Irkutsk-tid',
        'Asia/Jakarta' => 'Vestindonesisk tid (Jakarta)',
        'Asia/Jayapura' => 'Østindonesisk tid (Jayapura)',
        'Asia/Jerusalem' => 'Israelsk tid (Jerusalem)',
        'Asia/Kabul' => 'Afghansk tid (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamchatski tid (Kamtjatka)',
        'Asia/Karachi' => 'Pakistansk tid (Karachi)',
        'Asia/Katmandu' => 'Nepalesisk tid (Katmandu)',
        'Asia/Khandyga' => 'Jakutsk-tid (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsk-tid',
        'Asia/Kuala_Lumpur' => 'Malaysia-tid (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaysia-tid (Kuching)',
        'Asia/Kuwait' => 'Arabisk tid (Kuwait)',
        'Asia/Macau' => 'Kinesisk tid (Macao)',
        'Asia/Magadan' => 'Magadan-tid',
        'Asia/Makassar' => 'Centralindonesisk tid (Makassar)',
        'Asia/Manila' => 'Filippinsk tid (Manila)',
        'Asia/Muscat' => 'Golflandene-normaltid (Muscat)',
        'Asia/Nicosia' => 'Østeuropæisk tid (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnojarsk-tid (Novokusnetsk)',
        'Asia/Novosibirsk' => 'Novosibirsk-tid',
        'Asia/Omsk' => 'Omsk-tid',
        'Asia/Oral' => 'Vestkasakhstansk tid (Oral)',
        'Asia/Phnom_Penh' => 'Indokina-tid (Phnom Penh)',
        'Asia/Pontianak' => 'Vestindonesisk tid (Pontianak)',
        'Asia/Pyongyang' => 'Koreansk tid (Pyongyang)',
        'Asia/Qatar' => 'Arabisk tid (Qatar)',
        'Asia/Qostanay' => 'Østkasakhstansk tid (Kostanay)',
        'Asia/Qyzylorda' => 'Vestkasakhstansk tid (Kyzylorda)',
        'Asia/Rangoon' => 'Myanmar-tid (Rangoon)',
        'Asia/Riyadh' => 'Arabisk tid (Riyadh)',
        'Asia/Saigon' => 'Indokina-tid (Ho Chi Minh City)',
        'Asia/Sakhalin' => 'Sakhalin-tid',
        'Asia/Samarkand' => 'Usbekisk tid (Samarkand)',
        'Asia/Seoul' => 'Koreansk tid (Seoul)',
        'Asia/Shanghai' => 'Kinesisk tid (Shanghai)',
        'Asia/Singapore' => 'Singapore-tid',
        'Asia/Srednekolymsk' => 'Magadan-tid (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei-tid',
        'Asia/Tashkent' => 'Usbekisk tid (Tasjkent)',
        'Asia/Tbilisi' => 'Georgisk tid (Tbilisi)',
        'Asia/Tehran' => 'Iransk tid (Teheran)',
        'Asia/Thimphu' => 'Bhutan-tid (Thimphu)',
        'Asia/Tokyo' => 'Japansk tid (Tokyo)',
        'Asia/Tomsk' => 'Rusland (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Bator-tid',
        'Asia/Urumqi' => 'Kina (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostok-tid (Ust-Nera)',
        'Asia/Vientiane' => 'Indokina-tid (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostok-tid',
        'Asia/Yakutsk' => 'Jakutsk-tid',
        'Asia/Yekaterinburg' => 'Jekaterinburg-tid',
        'Asia/Yerevan' => 'Armensk tid (Jerevan)',
        'Atlantic/Azores' => 'Azorerne-tid',
        'Atlantic/Bermuda' => 'Atlantic-tid (Bermuda)',
        'Atlantic/Canary' => 'Vesteuropæisk tid (De Kanariske Øer)',
        'Atlantic/Cape_Verde' => 'Kap Verde-tid',
        'Atlantic/Faeroe' => 'Vesteuropæisk tid (Færøerne)',
        'Atlantic/Madeira' => 'Vesteuropæisk tid (Madeira)',
        'Atlantic/Reykjavik' => 'GMT (Reykjavik)',
        'Atlantic/South_Georgia' => 'South Georgia-tid',
        'Atlantic/St_Helena' => 'GMT (St. Helena)',
        'Atlantic/Stanley' => 'Falklandsøerne-tid (Stanley)',
        'Australia/Adelaide' => 'Centralaustralsk tid (Adelaide)',
        'Australia/Brisbane' => 'Østaustralsk tid (Brisbane)',
        'Australia/Broken_Hill' => 'Centralaustralsk tid (Broken Hill)',
        'Australia/Currie' => 'Østaustralsk tid (Currie)',
        'Australia/Darwin' => 'Centralaustralsk tid (Darwin)',
        'Australia/Eucla' => 'Vestlig centralaustralsk tid (Eucla)',
        'Australia/Hobart' => 'Østaustralsk tid (Hobart)',
        'Australia/Lindeman' => 'Østaustralsk tid (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe-tid',
        'Australia/Melbourne' => 'Østaustralsk tid (Melbourne)',
        'Australia/Perth' => 'Vestaustralsk tid (Perth)',
        'Australia/Sydney' => 'Østaustralsk tid (Sydney)',
        'CST6CDT' => 'Central-tid',
        'EST5EDT' => 'Eastern-tid',
        'Etc/GMT' => 'GMT',
        'Etc/UTC' => 'Koordineret universaltid',
        'Europe/Amsterdam' => 'Centraleuropæisk tid (Amsterdam)',
        'Europe/Andorra' => 'Centraleuropæisk tid (Andorra)',
        'Europe/Astrakhan' => 'Moskva-tid (Astrakhan)',
        'Europe/Athens' => 'Østeuropæisk tid (Athen)',
        'Europe/Belgrade' => 'Centraleuropæisk tid (Beograd)',
        'Europe/Berlin' => 'Centraleuropæisk tid (Berlin)',
        'Europe/Bratislava' => 'Centraleuropæisk tid (Bratislava)',
        'Europe/Brussels' => 'Centraleuropæisk tid (Bruxelles)',
        'Europe/Bucharest' => 'Østeuropæisk tid (Bukarest)',
        'Europe/Budapest' => 'Centraleuropæisk tid (Budapest)',
        'Europe/Busingen' => 'Centraleuropæisk tid (Busingen)',
        'Europe/Chisinau' => 'Østeuropæisk tid (Chisinau)',
        'Europe/Copenhagen' => 'Centraleuropæisk tid (København)',
        'Europe/Dublin' => 'GMT (Dublin)',
        'Europe/Gibraltar' => 'Centraleuropæisk tid (Gibraltar)',
        'Europe/Guernsey' => 'GMT (Guernsey)',
        'Europe/Helsinki' => 'Østeuropæisk tid (Helsinki)',
        'Europe/Isle_of_Man' => 'GMT (Isle of Man)',
        'Europe/Istanbul' => 'Tyrkiet (Istanbul)',
        'Europe/Jersey' => 'GMT (Jersey)',
        'Europe/Kaliningrad' => 'Østeuropæisk tid (Kaliningrad)',
        'Europe/Kiev' => 'Østeuropæisk tid (Kiev)',
        'Europe/Kirov' => 'Rusland (Kirov)',
        'Europe/Lisbon' => 'Vesteuropæisk tid (Lissabon)',
        'Europe/Ljubljana' => 'Centraleuropæisk tid (Ljubljana)',
        'Europe/London' => 'GMT (London)',
        'Europe/Luxembourg' => 'Centraleuropæisk tid (Luxembourg)',
        'Europe/Madrid' => 'Centraleuropæisk tid (Madrid)',
        'Europe/Malta' => 'Centraleuropæisk tid (Malta)',
        'Europe/Mariehamn' => 'Østeuropæisk tid (Mariehamn)',
        'Europe/Minsk' => 'Moskva-tid (Minsk)',
        'Europe/Monaco' => 'Centraleuropæisk tid (Monaco)',
        'Europe/Moscow' => 'Moskva-tid',
        'Europe/Oslo' => 'Centraleuropæisk tid (Oslo)',
        'Europe/Paris' => 'Centraleuropæisk tid (Paris)',
        'Europe/Podgorica' => 'Centraleuropæisk tid (Podgorica)',
        'Europe/Prague' => 'Centraleuropæisk tid (Prag)',
        'Europe/Riga' => 'Østeuropæisk tid (Riga)',
        'Europe/Rome' => 'Centraleuropæisk tid (Rom)',
        'Europe/Samara' => 'Samara-tid',
        'Europe/San_Marino' => 'Centraleuropæisk tid (San Marino)',
        'Europe/Sarajevo' => 'Centraleuropæisk tid (Sarajevo)',
        'Europe/Saratov' => 'Moskva-tid (Saratov)',
        'Europe/Simferopol' => 'Moskva-tid (Simferopol)',
        'Europe/Skopje' => 'Centraleuropæisk tid (Skopje)',
        'Europe/Sofia' => 'Østeuropæisk tid (Sofia)',
        'Europe/Stockholm' => 'Centraleuropæisk tid (Stockholm)',
        'Europe/Tallinn' => 'Østeuropæisk tid (Tallinn)',
        'Europe/Tirane' => 'Centraleuropæisk tid (Tirana)',
        'Europe/Ulyanovsk' => 'Moskva-tid (Uljanovsk)',
        'Europe/Uzhgorod' => 'Østeuropæisk tid (Uzjhorod)',
        'Europe/Vaduz' => 'Centraleuropæisk tid (Vaduz)',
        'Europe/Vatican' => 'Centraleuropæisk tid (Vatikanet)',
        'Europe/Vienna' => 'Centraleuropæisk tid (Wien)',
        'Europe/Vilnius' => 'Østeuropæisk tid (Vilnius)',
        'Europe/Volgograd' => 'Volgograd-tid',
        'Europe/Warsaw' => 'Centraleuropæisk tid (Warszawa)',
        'Europe/Zagreb' => 'Centraleuropæisk tid (Zagreb)',
        'Europe/Zaporozhye' => 'Østeuropæisk tid (Zaporizjzja)',
        'Europe/Zurich' => 'Centraleuropæisk tid (Zürich)',
        'Indian/Antananarivo' => 'Østafrikansk tid (Antananarivo)',
        'Indian/Chagos' => 'Indiske Ocean-normaltid (Chagos)',
        'Indian/Christmas' => 'Juleøen-normaltid',
        'Indian/Cocos' => 'Cocosøerne-normaltid',
        'Indian/Comoro' => 'Østafrikansk tid (Comorerne)',
        'Indian/Kerguelen' => 'Franske Sydlige og Antarktiske Territorier-tid (Kerguelen)',
        'Indian/Mahe' => 'Seychellisk tid (Mahe)',
        'Indian/Maldives' => 'Maldiverne-tid',
        'Indian/Mauritius' => 'Mauritius-tid',
        'Indian/Mayotte' => 'Østafrikansk tid (Mayotte)',
        'Indian/Reunion' => 'Reunion-tid (Réunion)',
        'MST7MDT' => 'Mountain-tid',
        'PST8PDT' => 'Pacific-tid',
        'Pacific/Apia' => 'Apia-tid',
        'Pacific/Auckland' => 'Newzealandsk tid (Auckland)',
        'Pacific/Bougainville' => 'Papua Ny Guinea-tid (Bougainville)',
        'Pacific/Chatham' => 'Chatham-tid',
        'Pacific/Easter' => 'Påskeøen-tid',
        'Pacific/Efate' => 'Vanuatu-tid (Efate)',
        'Pacific/Enderbury' => 'Phoenixøen-tid (Enderbury)',
        'Pacific/Fakaofo' => 'Tokelau-tid (Fakaofo)',
        'Pacific/Fiji' => 'Fijiansk tid',
        'Pacific/Funafuti' => 'Tuvalu-tid (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos-tid',
        'Pacific/Gambier' => 'Gambier-tid',
        'Pacific/Guadalcanal' => 'Salomonøerne-tid (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro-tid (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleutian-tid (Honolulu)',
        'Pacific/Johnston' => 'Hawaii-Aleutian-tid (Johnston)',
        'Pacific/Kiritimati' => 'Linjeøerne-tid (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae-tid',
        'Pacific/Kwajalein' => 'Marshalløerne-tid (Kwajalein)',
        'Pacific/Majuro' => 'Marshalløerne-tid (Majuro)',
        'Pacific/Marquesas' => 'Marquesas-tid',
        'Pacific/Midway' => 'Samoansk tid (Midway)',
        'Pacific/Nauru' => 'Nauru-tid',
        'Pacific/Niue' => 'Niue-tid',
        'Pacific/Norfolk' => 'Norfolk Island-tid',
        'Pacific/Noumea' => 'Ny Kaledonien-tid (Noumea)',
        'Pacific/Pago_Pago' => 'Samoansk tid (Pago Pago)',
        'Pacific/Palau' => 'Palau-normaltid',
        'Pacific/Pitcairn' => 'Pitcairn-tid',
        'Pacific/Ponape' => 'Ponape-tid (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua Ny Guinea-tid (Port Moresby)',
        'Pacific/Rarotonga' => 'Cookøerne-tid (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro-tid (Saipan)',
        'Pacific/Tahiti' => 'Tahiti-tid',
        'Pacific/Tarawa' => 'Gilbertøerne-tid (Tarawa)',
        'Pacific/Tongatapu' => 'Tongansk tid (Tongatapu)',
        'Pacific/Truk' => 'Chuuk-tid',
        'Pacific/Wake' => 'Wake Island-tid',
        'Pacific/Wallis' => 'Wallis og Futuna-tid',
    ],
    'Meta' => [
        'HourFormatPos' => '+%02d.%02d',
        'HourFormatNeg' => '-%02d.%02d',
    ],
];
