<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'andorska peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'dirham Združenih arabskih emiratov',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'stari afganistanski afgani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'afgani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'albanski lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'armenski dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'nizozemsko-antilski gulden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'angolska kvanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'stara angolska kvanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'angolska nova kvanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'konvertibilna angolska kvanza (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'argentinski avstral',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'argentinski peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'argentinski peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'avstrijski šiling',
        ],
        'AUD' => [
            0 => 'AUD',
            1 => 'avstralski dolar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'arubski florin',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'stari azerbajdžanski manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'azerbajdžanski manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'bosansko-hercegovski dinar',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'bosansko-hercegovska konvertibilna marka',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'barbadoški dolar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'bangladeška taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'belgijski konvertibilni frank',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'belgijski frank',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'belgijski finančni frank',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'stari bolgarski lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'bolgarski lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'bahranski dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'burundski frank',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'bermudski dolar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'brunejski dolar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'bolivijski boliviano',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'bolivijski peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'bolivijski mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'brazilski novi kruzeiro (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'brazilski kruzado',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'stari brazilski kruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'brazilski real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'novi brazilski kruzado',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'brazilski kruzeiro',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'bahamski dolar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'butanski ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'burmanski kjat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'bocvanska pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'beloruski novi rubelj (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'beloruski rubelj',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'beloruski rubelj (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'belizejski dolar',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'kanadski dolar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'kongovski frank',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'evro WIR',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'švicarski frank',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'frank WIR',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'čilski unidades de fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'čilski peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'kitajski juan (offshore)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'kitajski juan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'kolumbijski peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'kolumbijska enota realne vrednosti',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'kostariški kolon',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'stari srbski dinar',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'češkoslovaška krona',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'kubanski konvertibilni peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'kubanski peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'zelenortski eskudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'ciprski funt',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'češka krona',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'vzhodnonemška marka',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'nemška marka',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'džibutski frank',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'danska krona',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'dominikanski peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'alžirski dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'ekvadorski sukre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'ekvadorska enota realne vrednosti (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'estonska krona',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'egiptovski funt',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'eritrejska nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'španska pezeta (račun A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'španska pezeta (račun B)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'španska pezeta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'etiopski bir',
        ],
        'EUR' => [
            0 => '€',
            1 => 'evro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'finska marka',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'fidžijski dolar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'falklandski funt',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'francoski frank',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'britanski funt',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'gruzijski bon lari',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'gruzijski lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'stari ganski cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ganski cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'gibraltarski funt',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'gambijski dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'gvinejski frank',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'gvinejski sili',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'ekwele Ekvatorialne Gvineje',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'grška drahma',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'gvatemalski kecal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'eskudo Portugalske Gvineje',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'peso Gvineje Bissau',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'gvajanski dolar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'hongkonški dolar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'honduraška lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'hrvaški dinar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'hrvaška kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'haitski gurd',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'madžarski forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'indonezijska rupija',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'irski funt',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'izraelski funt',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'izraelski šekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'indijska rupija',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'iraški dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'iranski rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'islandska krona',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'italijanska lira',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'jamajški dolar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'jordanski dinar',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'japonski jen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'kenijski šiling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'kirgiški som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'kamboški riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'komorski frank',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'severnokorejski von',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'južnokorejski von',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'kuvajtski dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'kajmanski dolar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'kazahstanski tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'laoški kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'libanonski funt',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'šrilanška rupija',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'liberijski dolar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'lesotski loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'litovski litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'litvanski litas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'luksemburški konvertibilni frank',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'luksemburški frank',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'luksemburški finančni frank',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'latvijski lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'latvijski rubelj',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'libijski dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'maroški dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'maroški frank',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'moldavijski leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'malgaški ariarij',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'malgaški frank',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'makedonski denar',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'malijski frank',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'mjanmarski kjat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'mongolski tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'makavska pataka',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'mavretanska uguija (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'mavretanska uguija',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'malteška lira',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'malteški funt',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'mavricijska rupija',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'maldivska rufija',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'malavijska kvača',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'mehiški peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'mehiški srebrni peso (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'mehiška inverzna enota (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'malezijski ringit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'mozambiški eskudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'stari mozambiški metikal',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'mozambiški metikal',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'namibijski dolar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'nigerijska naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'nikaraška kordova',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'nikaraška zlata kordova',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'nizozemski gulden',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'norveška krona',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'nepalska rupija',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'novozelandski dolar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'omanski rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'panamska balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'perujski inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'perujski sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'perujski sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'kina Papue Nove Gvineje',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'filipinski peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'pakistanska rupija',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'poljski novi zlot',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'stari poljski zlot (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'portugalski eskudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'paragvajski gvarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'katarski rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'rodezijski dolar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'stari romunski leu',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'romunski leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'srbski dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'ruski rubelj',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'ruski rubelj (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'ruandski frank',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'saudski rial',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'solomonski dolar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'sejšelska rupija',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'stari sudanski dinar',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'sudanski funt',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'stari sudanski funt',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'švedska krona',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'singapurski dolar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'funt Sv. Helene',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'slovenski tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'slovaška krona',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'sieraleonski leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'somalski šiling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'surinamski dolar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'surinamski gulden',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'južnosudanski funt',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'saotomejska dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'saotomejska dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'sovjetski rubelj',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'salvadorski kolon',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'sirijski funt',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'svazijski lilangeni',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'tajski baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'tadžikistanski rubelj',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'tadžikistanski somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'turkmenski manat',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'turkmenistanski novi manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'tunizijski dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'tongovska paanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'timorski eskudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'stara turška lira',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'nova turška lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'dolar Trinidada in Tobaga',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'novi tajvanski dolar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'tanzanijski šiling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ukrajinska grivna',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'ukrajinski karbovanci',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'stari ugandski šiling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ugandski šiling',
        ],
        'USD' => [
            0 => '$',
            1 => 'ameriški dolar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'ameriški dolar, naslednji dan',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'ameriški dolar, isti dan',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'stari urugvajski peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'urugvajski peso',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'uzbeški sum',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'venezuelski bolivar (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'venezuelski bolivar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'venezuelski bolivar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'vientnamski dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'vanuatujski vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'samoanska tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA frank BEAC',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'vzhodnokaribski dolar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'evropska denarna enota',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'zlati frank',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'frank UIC',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'zahodnoafriški frank CFA',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'CFP frank',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'jemenski dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'jemenski rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'stari jugoslovanski dinar',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'novi jugoslovanski dinar',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'jugoslovanski konvertibilni dinar',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'južnoafriški finančni rand',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'južnoafriški rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'zambijska kvača (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'zambijska kvača',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'zairski novi zaire',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'zairski zaire',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'zimbabvejski dolar',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'zimbabvejski dolar (2009)',
        ],
    ],
];
