<?php

$attributemap = [
    'sn'                         => 'urn:mace:dir:attribute-def:sn',
    'telephoneNumber'            => 'urn:mace:dir:attribute-def:telephoneNumber',
    'facsimileTelephoneNumber'   => 'urn:mace:dir:attribute-def:facsimileTelephoneNumber',
    'postalAddress'              => 'urn:mace:dir:attribute-def:postalAddress',
    'givenName'                  => 'urn:mace:dir:attribute-def:givenName',
    'homePhone'                  => 'urn:mace:dir:attribute-def:homePhone',
    'homePostalAddress'          => 'urn:mace:dir:attribute-def:homePostalAddress',
    'mail'                       => 'urn:mace:dir:attribute-def:mail',
    'mobile'                     => 'urn:mace:dir:attribute-def:mobile',
    'preferredLanguage'          => 'urn:mace:dir:attribute-def:preferredLanguage',
    'eduPersonPrincipalName'     => 'urn:mace:dir:attribute-def:eduPersonPrincipalName',
    'eduPersonAffiliation'       => 'urn:mace:dir:attribute-def:eduPersonAffiliation',
    'eduPersonScopedAffiliation' => 'urn:mace:dir:attribute-def:eduPersonScopedAffiliation',
    'eduPersonEntitlement'       => 'urn:mace:dir:attribute-def:eduPersonEntitlement',
    'eduPersonOrgDN'             => 'urn:mace:dir:attribute-def:eduPersonOrgDN',
    'eduPersonOrgUnitDN'         => 'urn:mace:dir:attribute-def:eduPersonOrgUnitDN',
];
