<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ګرينويچ معياري وخت (ابيجان)',
        'Africa/Accra' => 'ګرينويچ معياري وخت (اکرا)',
        'Africa/Addis_Ababa' => 'ختيځ افريقا وخت (اديس ابابا)',
        'Africa/Algiers' => 'مرکزي اروپايي وخت (الجييرز)',
        'Africa/Asmera' => 'ختيځ افريقا وخت (اسماره)',
        'Africa/Bamako' => 'ګرينويچ معياري وخت (بامیکو)',
        'Africa/Bangui' => 'لوېديځ افريقا وخت (بانګوي)',
        'Africa/Banjul' => 'ګرينويچ معياري وخت (بانجول)',
        'Africa/Bissau' => 'ګرينويچ معياري وخت (بساؤ)',
        'Africa/Blantyre' => 'منځنی افريقا وخت (بلنټاير)',
        'Africa/Brazzaville' => 'لوېديځ افريقا وخت (برازاويل)',
        'Africa/Bujumbura' => 'منځنی افريقا وخت (بجوګورا)',
        'Africa/Cairo' => 'ختيځ اروپايي وخت (قاهره)',
        'Africa/Casablanca' => 'لوېديځ اروپايي وخت (کاسابلانکا)',
        'Africa/Ceuta' => 'مرکزي اروپايي وخت (سيوټا)',
        'Africa/Conakry' => 'ګرينويچ معياري وخت (کونکري)',
        'Africa/Dakar' => 'ګرينويچ معياري وخت (ډاکار)',
        'Africa/Dar_es_Salaam' => 'ختيځ افريقا وخت (دار السلام)',
        'Africa/Djibouti' => 'ختيځ افريقا وخت (جبوتي)',
        'Africa/Douala' => 'لوېديځ افريقا وخت (دوالا)',
        'Africa/El_Aaiun' => 'لوېديځ اروپايي وخت (الیون)',
        'Africa/Freetown' => 'ګرينويچ معياري وخت (فریټون)',
        'Africa/Gaborone' => 'منځنی افريقا وخت (ګابرون)',
        'Africa/Harare' => 'منځنی افريقا وخت (هرارې)',
        'Africa/Johannesburg' => 'جنوبي افريقا معياري وخت (جوهانسبرګ)',
        'Africa/Juba' => 'منځنی افريقا وخت (جوبا)',
        'Africa/Kampala' => 'ختيځ افريقا وخت (کمپاله)',
        'Africa/Khartoum' => 'منځنی افريقا وخت (خرتوم)',
        'Africa/Kigali' => 'منځنی افريقا وخت (کيگالي)',
        'Africa/Kinshasa' => 'لوېديځ افريقا وخت (کينشاسا)',
        'Africa/Lagos' => 'لوېديځ افريقا وخت (لاگوس)',
        'Africa/Libreville' => 'لوېديځ افريقا وخت (لیبریل)',
        'Africa/Lome' => 'ګرينويچ معياري وخت (لووم)',
        'Africa/Luanda' => 'لوېديځ افريقا وخت (لونده)',
        'Africa/Lubumbashi' => 'منځنی افريقا وخت (لبوباشي)',
        'Africa/Lusaka' => 'منځنی افريقا وخت (لوساکا)',
        'Africa/Malabo' => 'لوېديځ افريقا وخت (مالابو)',
        'Africa/Maputo' => 'منځنی افريقا وخت (ماپوټو)',
        'Africa/Maseru' => 'جنوبي افريقا معياري وخت (مسيرو)',
        'Africa/Mbabane' => 'جنوبي افريقا معياري وخت (مبابانې)',
        'Africa/Mogadishu' => 'ختيځ افريقا وخت (موگديشو)',
        'Africa/Monrovia' => 'ګرينويچ معياري وخت (مونروفیا)',
        'Africa/Nairobi' => 'ختيځ افريقا وخت (نايروبي)',
        'Africa/Ndjamena' => 'لوېديځ افريقا وخت (نجامینا)',
        'Africa/Niamey' => 'لوېديځ افريقا وخت (نیمي)',
        'Africa/Nouakchott' => 'ګرينويچ معياري وخت (نوکوچټ)',
        'Africa/Ouagadougou' => 'ګرينويچ معياري وخت (اوګوډوګو)',
        'Africa/Porto-Novo' => 'لوېديځ افريقا وخت (پورټو - نوو)',
        'Africa/Sao_Tome' => 'ګرينويچ معياري وخت (ساو ټوم)',
        'Africa/Tripoli' => 'ختيځ اروپايي وخت (تريپولي)',
        'Africa/Tunis' => 'مرکزي اروپايي وخت (تونس)',
        'Africa/Windhoek' => 'منځنی افريقا وخت (وینهوک)',
        'America/Adak' => 'هوایی الیوتین وخت (اداک)',
        'America/Anchorage' => 'الاسکا وخت (اینکریج)',
        'America/Anguilla' => 'اتلانتیک وخت (انګیلا)',
        'America/Antigua' => 'اتلانتیک وخت (انټيګ)',
        'America/Araguaina' => 'برسلیا وخت (ارګینیا)',
        'America/Argentina/La_Rioja' => 'ارجنټاین وخت (لاريوجا)',
        'America/Argentina/Rio_Gallegos' => 'ارجنټاین وخت (ريو ګيليګوس)',
        'America/Argentina/Salta' => 'ارجنټاین وخت (سالټا)',
        'America/Argentina/San_Juan' => 'ارجنټاین وخت (سان جوان)',
        'America/Argentina/San_Luis' => 'ارجنټاین وخت (سان لویس)',
        'America/Argentina/Tucuman' => 'ارجنټاین وخت (ټيکووم)',
        'America/Argentina/Ushuaia' => 'ارجنټاین وخت (اوشوایا)',
        'America/Aruba' => 'اتلانتیک وخت (آروبا)',
        'America/Asuncion' => 'پيراګوای وخت (اسونسيون)',
        'America/Bahia' => 'برسلیا وخت (بهیا)',
        'America/Bahia_Banderas' => 'مرکزي وخت (بهیا بینډراس)',
        'America/Barbados' => 'اتلانتیک وخت (باربادوس)',
        'America/Belem' => 'برسلیا وخت (بلم)',
        'America/Belize' => 'مرکزي وخت (بلیز)',
        'America/Blanc-Sablon' => 'اتلانتیک وخت (بلانک-سابلون)',
        'America/Boa_Vista' => 'ایمیزون وخت (بوا ویسټا)',
        'America/Bogota' => 'کولمبیا وخت (بوګټا)',
        'America/Boise' => 'د غره د وخت (بوز)',
        'America/Buenos_Aires' => 'ارجنټاین وخت (بينوس اييرز)',
        'America/Cambridge_Bay' => 'د غره د وخت (کیمبرج بي)',
        'America/Campo_Grande' => 'ایمیزون وخت (کمپو ګرډی)',
        'America/Cancun' => 'ختیځ وخت (کينکن)',
        'America/Caracas' => 'وینزویلا وخت (کاراکاس)',
        'America/Catamarca' => 'ارجنټاین وخت (کټامارکا)',
        'America/Cayenne' => 'د فرانسوي ګانا وخت (کیین)',
        'America/Cayman' => 'ختیځ وخت (کیمن)',
        'America/Chicago' => 'مرکزي وخت (شیکاګو)',
        'America/Chihuahua' => 'مکسیکن پیسفک وخت (چھواھوا)',
        'America/Coral_Harbour' => 'ختیځ وخت (اتیکوکن)',
        'America/Cordoba' => 'ارجنټاین وخت (کورډوبا)',
        'America/Costa_Rica' => 'مرکزي وخت (کوستاریکا)',
        'America/Creston' => 'د غره د وخت (کرسټون)',
        'America/Cuiaba' => 'ایمیزون وخت (کویابا)',
        'America/Curacao' => 'اتلانتیک وخت (کوراکاؤ)',
        'America/Danmarkshavn' => 'ګرينويچ معياري وخت (ډنمارکشان)',
        'America/Dawson' => 'د یوکون وخت (داوسن)',
        'America/Dawson_Creek' => 'د غره د وخت (داسن کریک)',
        'America/Denver' => 'د غره د وخت (ډنور)',
        'America/Detroit' => 'ختیځ وخت (ډایټروټ)',
        'America/Dominica' => 'اتلانتیک وخت (دومینیکا)',
        'America/Edmonton' => 'د غره د وخت (ایډمونټن)',
        'America/Eirunepe' => 'د برازیل په وخت (اییرونپ)',
        'America/El_Salvador' => 'مرکزي وخت (ايل سلوادور)',
        'America/Fort_Nelson' => 'د غره د وخت (فورټ نیلسن)',
        'America/Fortaleza' => 'برسلیا وخت (فورتیلزا)',
        'America/Glace_Bay' => 'اتلانتیک وخت (ګیسس بيی)',
        'America/Godthab' => 'لویدیځ ګرینلینډ وخت (نووک)',
        'America/Goose_Bay' => 'اتلانتیک وخت (گوز بي)',
        'America/Grand_Turk' => 'ختیځ وخت (لوی ترک)',
        'America/Grenada' => 'اتلانتیک وخت (ګرنادا)',
        'America/Guadeloupe' => 'اتلانتیک وخت (ګالډیپ)',
        'America/Guatemala' => 'مرکزي وخت (ګواتمالا)',
        'America/Guayaquil' => 'د اکوادور وخت (ګوياکل)',
        'America/Guyana' => 'د ګوانانا وخت (ګیانا)',
        'America/Halifax' => 'اتلانتیک وخت (هیلفکس)',
        'America/Havana' => 'کيوبا وخت (هوانا)',
        'America/Hermosillo' => 'مکسیکن پیسفک وخت (هرموسیلو)',
        'America/Indiana/Knox' => 'مرکزي وخت (نوکس انډيانا)',
        'America/Indiana/Marengo' => 'ختیځ وخت (مورينګو انډيانا)',
        'America/Indiana/Petersburg' => 'ختیځ وخت (پيټسبرګ، انډيانا)',
        'America/Indiana/Tell_City' => 'مرکزي وخت (ټل سټي، انډيانا)',
        'America/Indiana/Vevay' => 'ختیځ وخت (ویوی، انډيانا)',
        'America/Indiana/Vincennes' => 'ختیځ وخت (وينسينس، انډيانا)',
        'America/Indiana/Winamac' => 'ختیځ وخت (وينامک انډيانا)',
        'America/Indianapolis' => 'ختیځ وخت (انډيانا پوليس)',
        'America/Inuvik' => 'د غره د وخت (انوک)',
        'America/Iqaluit' => 'ختیځ وخت (اقلیټ)',
        'America/Jamaica' => 'ختیځ وخت (جمایکه)',
        'America/Jujuy' => 'ارجنټاین وخت (جوجوي)',
        'America/Juneau' => 'الاسکا وخت (جونو)',
        'America/Kentucky/Monticello' => 'ختیځ وخت (مونټيسيلو، کونټکی)',
        'America/Kralendijk' => 'اتلانتیک وخت (کلینډیزج)',
        'America/La_Paz' => 'بولیویا وخت (لا پاز)',
        'America/Lima' => 'پیرو وخت (لیما)',
        'America/Los_Angeles' => 'پیسفک وخت (لاس اینجلس)',
        'America/Louisville' => 'ختیځ وخت (لوئس ویل)',
        'America/Lower_Princes' => 'اتلانتیک وخت (لوور پرنس کوارټر)',
        'America/Maceio' => 'برسلیا وخت (ماسيو)',
        'America/Managua' => 'مرکزي وخت (منګوا)',
        'America/Manaus' => 'ایمیزون وخت (مناوس)',
        'America/Marigot' => 'اتلانتیک وخت (ميريګاټ)',
        'America/Martinique' => 'اتلانتیک وخت (مارټینیک)',
        'America/Matamoros' => 'مرکزي وخت (ميټاموروس)',
        'America/Mazatlan' => 'مکسیکن پیسفک وخت (مزاتلان)',
        'America/Mendoza' => 'ارجنټاین وخت (مینډوزا)',
        'America/Menominee' => 'مرکزي وخت (مینومین)',
        'America/Merida' => 'مرکزي وخت (ميريډا)',
        'America/Metlakatla' => 'الاسکا وخت (میتلاکاټلا)',
        'America/Mexico_City' => 'مرکزي وخت (مکسيکو ښار)',
        'America/Miquelon' => 'سینټ پییرا و ميکلين وخت (ميکويلان)',
        'America/Moncton' => 'اتلانتیک وخت (مونکټون)',
        'America/Monterrey' => 'مرکزي وخت (منټرري)',
        'America/Montevideo' => 'یوروګوای وخت (مونټ وډیو)',
        'America/Montreal' => 'د کاناډا په وخت (Montreal)',
        'America/Montserrat' => 'اتلانتیک وخت (مانټیسیرت)',
        'America/Nassau' => 'ختیځ وخت (نیساو)',
        'America/New_York' => 'ختیځ وخت (نیویارک)',
        'America/Nipigon' => 'ختیځ وخت (نیپګون)',
        'America/Nome' => 'الاسکا وخت (نوم)',
        'America/Noronha' => 'فرنانڈو دي نورونها وخت',
        'America/North_Dakota/Beulah' => 'مرکزي وخت (بيولا، شمالي ډاکوټا)',
        'America/North_Dakota/Center' => 'مرکزي وخت (مرکز، شمالي ډاکوټا)',
        'America/North_Dakota/New_Salem' => 'مرکزي وخت (نوی سلیم، شمالي داکوتا)',
        'America/Ojinaga' => 'د غره د وخت (اوجنګا)',
        'America/Panama' => 'ختیځ وخت (پاناما)',
        'America/Pangnirtung' => 'ختیځ وخت (پينګنرچونګ)',
        'America/Paramaribo' => 'سورینام وخت (پاراماربو)',
        'America/Phoenix' => 'د غره د وخت (فینکس)',
        'America/Port-au-Prince' => 'ختیځ وخت (پورټ ایو - پرنس)',
        'America/Port_of_Spain' => 'اتلانتیک وخت (د اسپانیا بندر)',
        'America/Porto_Velho' => 'ایمیزون وخت (پورټو ویلهو)',
        'America/Puerto_Rico' => 'اتلانتیک وخت (پورتو ریکو)',
        'America/Punta_Arenas' => 'چلی وخت (پنټا آریناس)',
        'America/Rainy_River' => 'مرکزي وخت (د باران باران)',
        'America/Rankin_Inlet' => 'مرکزي وخت (رينکن انلټ)',
        'America/Recife' => 'برسلیا وخت (ریسیفي)',
        'America/Regina' => 'مرکزي وخت (ریګینا)',
        'America/Resolute' => 'مرکزي وخت (ريسالوټ)',
        'America/Rio_Branco' => 'د برازیل په وخت (ریو برانکو)',
        'America/Santa_Isabel' => 'د شمال لویدیځ مکسیکو وخت (Santa Isabel)',
        'America/Santarem' => 'برسلیا وخت (سناترم)',
        'America/Santiago' => 'چلی وخت (سنتياګو)',
        'America/Santo_Domingo' => 'اتلانتیک وخت (سنتو ډومینګو)',
        'America/Sao_Paulo' => 'برسلیا وخت (ساو پاولو)',
        'America/Scoresbysund' => 'د ختیځ ګرینلینډ وخت (اټوکوټورمیټ)',
        'America/Sitka' => 'الاسکا وخت (سیټکا)',
        'America/St_Barthelemy' => 'اتلانتیک وخت (سینټ بارټیلیم)',
        'America/St_Johns' => 'نيو فاونډلېنډ وخت (سینټ جانز)',
        'America/St_Kitts' => 'اتلانتیک وخت (سینټ کټس)',
        'America/St_Lucia' => 'اتلانتیک وخت (سینټ لوسیا)',
        'America/St_Thomas' => 'اتلانتیک وخت (سينټ تهامس)',
        'America/St_Vincent' => 'اتلانتیک وخت (سېنټ ویسنټ)',
        'America/Swift_Current' => 'مرکزي وخت (سويفټ کرنټ)',
        'America/Tegucigalpa' => 'مرکزي وخت (ټګسیګالپا)',
        'America/Thule' => 'اتلانتیک وخت (تول)',
        'America/Thunder_Bay' => 'ختیځ وخت (تنډر بی)',
        'America/Tijuana' => 'پیسفک وخت (تجوانا)',
        'America/Toronto' => 'ختیځ وخت (ټورنټو)',
        'America/Tortola' => 'اتلانتیک وخت (ټورتولا)',
        'America/Vancouver' => 'پیسفک وخت (وینکوور)',
        'America/Whitehorse' => 'د یوکون وخت (وايټ هارس)',
        'America/Winnipeg' => 'مرکزي وخت (وینپیګ)',
        'America/Yakutat' => 'الاسکا وخت (ياکوټټ)',
        'America/Yellowknife' => 'د غره د وخت (يلونايف)',
        'Antarctica/Casey' => 'د انتارکتیکا په وخت (کیسي)',
        'Antarctica/Davis' => 'ډيوس وخت',
        'Antarctica/DumontDUrville' => 'ډومونټ ډي ارول',
        'Antarctica/Macquarie' => 'ختيځ آستراليا وخت (مکواري)',
        'Antarctica/Mawson' => 'ماوسن وخت',
        'Antarctica/McMurdo' => 'نيوزي لېنډ وخت (مکمرډو)',
        'Antarctica/Palmer' => 'چلی وخت (پالمر)',
        'Antarctica/Rothera' => 'رودرا وخت',
        'Antarctica/Syowa' => 'سیوا وخت',
        'Antarctica/Troll' => 'ګرينويچ معياري وخت (ټرول)',
        'Antarctica/Vostok' => 'واستوک وخت',
        'Arctic/Longyearbyen' => 'مرکزي اروپايي وخت (لانګيربين)',
        'Asia/Aden' => 'عربي وخت (اډن)',
        'Asia/Almaty' => 'ختيځ قازقستان وخت (الماتی)',
        'Asia/Amman' => 'ختيځ اروپايي وخت (اممان)',
        'Asia/Anadyr' => 'د روسیه په وخت (اناډير)',
        'Asia/Aqtau' => 'لویدیځ قزاقستان وخت (اکټاو)',
        'Asia/Aqtobe' => 'لویدیځ قزاقستان وخت (اکتوب)',
        'Asia/Ashgabat' => 'ترکمانستان وخت (اشغ آباد)',
        'Asia/Atyrau' => 'لویدیځ قزاقستان وخت (اېټراو)',
        'Asia/Baghdad' => 'عربي وخت (بغداد)',
        'Asia/Bahrain' => 'عربي وخت (بحرین)',
        'Asia/Baku' => 'د آذربايجان وخت (باکو)',
        'Asia/Bangkok' => 'انډوچاینه وخت (بنکاک)',
        'Asia/Barnaul' => 'د روسیه په وخت (برنول)',
        'Asia/Beirut' => 'ختيځ اروپايي وخت (بیروت)',
        'Asia/Bishkek' => 'کرغیزستان وخت (بشکیک)',
        'Asia/Brunei' => 'برونايي دارالسلام وخت (برویني)',
        'Asia/Calcutta' => 'هند معیاري وخت (کولکته)',
        'Asia/Chita' => 'ياکوټسک وخت (چيتا)',
        'Asia/Choibalsan' => 'اولان باټر وخت (چويبلسان)',
        'Asia/Colombo' => 'هند معیاري وخت (کولمبو)',
        'Asia/Damascus' => 'ختيځ اروپايي وخت (دمشق)',
        'Asia/Dhaka' => 'بنگله دېش وخت (ډهاکه)',
        'Asia/Dili' => 'ختيځ تيمور وخت (دلي)',
        'Asia/Dubai' => 'خلیج معياري وخت (دوبی)',
        'Asia/Dushanbe' => 'تاجکستان وخت (دوشنبي)',
        'Asia/Famagusta' => 'ختيځ اروپايي وخت (فاماګستا)',
        'Asia/Gaza' => 'ختيځ اروپايي وخت (غزه)',
        'Asia/Hebron' => 'ختيځ اروپايي وخت (هبرون)',
        'Asia/Hong_Kong' => 'هانګ کانګ وخت',
        'Asia/Hovd' => 'هاوډ وخت',
        'Asia/Irkutsk' => 'ارکوټسک وخت',
        'Asia/Jakarta' => 'لویدیځ اندونیزیا وخت (جکارتا)',
        'Asia/Jayapura' => 'اندونیزیا وخت (جاياپورا)',
        'Asia/Jerusalem' => 'اسراییل وخت (يروشلم)',
        'Asia/Kabul' => 'افغانستان وخت (کابل)',
        'Asia/Kamchatka' => 'د روسیه په وخت (کامچاتکا)',
        'Asia/Karachi' => 'پاکستان وخت (کراچي)',
        'Asia/Katmandu' => 'نیپال وخت (کټمنډو)',
        'Asia/Khandyga' => 'ياکوټسک وخت (خنديګا)',
        'Asia/Krasnoyarsk' => 'کريسنويارسک وخت',
        'Asia/Kuala_Lumpur' => 'ملائیشیا وخت (کولالمپور)',
        'Asia/Kuching' => 'ملائیشیا وخت (کوچنګ)',
        'Asia/Kuwait' => 'عربي وخت (کوېت)',
        'Asia/Macau' => 'چين وخت (مکاو)',
        'Asia/Magadan' => 'ميګډان وخت (مګدان)',
        'Asia/Makassar' => 'مرکزي ادونيزيا وخت (مکاسار)',
        'Asia/Manila' => 'فلپاين وخت (منیلا)',
        'Asia/Muscat' => 'خلیج معياري وخت (مسقط)',
        'Asia/Nicosia' => 'ختيځ اروپايي وخت (نیکوسیا)',
        'Asia/Novokuznetsk' => 'کريسنويارسک وخت (نووکوزنیټک)',
        'Asia/Novosibirsk' => 'نووسيبرسک وخت',
        'Asia/Omsk' => 'اومسک وخت',
        'Asia/Oral' => 'لویدیځ قزاقستان وخت (اورل)',
        'Asia/Phnom_Penh' => 'انډوچاینه وخت (پنوم پن)',
        'Asia/Pontianak' => 'لویدیځ اندونیزیا وخت (پونټینیک)',
        'Asia/Pyongyang' => 'کوريايي وخت (پيانګ يانګ)',
        'Asia/Qatar' => 'عربي وخت (قطر)',
        'Asia/Qostanay' => 'ختيځ قازقستان وخت (کوستانې)',
        'Asia/Qyzylorda' => 'لویدیځ قزاقستان وخت (قيزي لورډا)',
        'Asia/Rangoon' => 'میانمار وخت (یانګون)',
        'Asia/Riyadh' => 'عربي وخت (رياض)',
        'Asia/Saigon' => 'انډوچاینه وخت (هو چي من ښار)',
        'Asia/Sakhalin' => 'سخلين وخت (سخالين)',
        'Asia/Samarkand' => 'ازبکستان وخت (سمرقند)',
        'Asia/Seoul' => 'کوريايي وخت (سیول)',
        'Asia/Shanghai' => 'چين وخت (شنگھائی)',
        'Asia/Singapore' => 'سنګاپور معیاري وخت (سینګاپور)',
        'Asia/Srednekolymsk' => 'ميګډان وخت (سريډنيکوليمسک)',
        'Asia/Taipei' => 'تايپي وخت',
        'Asia/Tashkent' => 'ازبکستان وخت (تاشقند)',
        'Asia/Tbilisi' => 'جورجیا وخت (تبلیسي)',
        'Asia/Tehran' => 'ایران وخت (تهران)',
        'Asia/Thimphu' => 'بهوټان وخت (تهيمفو)',
        'Asia/Tokyo' => 'جاپان وخت (ټوکیو)',
        'Asia/Tomsk' => 'د روسیه په وخت (توماس)',
        'Asia/Ulaanbaatar' => 'اولان باټر وخت',
        'Asia/Urumqi' => 'د چین په وخت (اورومقي)',
        'Asia/Ust-Nera' => 'ولادیوستاک وخت (اوستنيرا)',
        'Asia/Vientiane' => 'انډوچاینه وخت (وينټين)',
        'Asia/Vladivostok' => 'ولادیوستاک وخت',
        'Asia/Yakutsk' => 'ياکوټسک وخت',
        'Asia/Yekaterinburg' => 'یکاټیرینبرګ وخت (يکاټيرنبرګ)',
        'Asia/Yerevan' => 'ارمنستان وخت (يريوان)',
        'Atlantic/Azores' => 'ايزورس وخت',
        'Atlantic/Bermuda' => 'اتلانتیک وخت (برمودا)',
        'Atlantic/Canary' => 'لوېديځ اروپايي وخت (کناري)',
        'Atlantic/Cape_Verde' => 'کیپ وردډ وخت (کيپ ورډ)',
        'Atlantic/Faeroe' => 'لوېديځ اروپايي وخت (فارو)',
        'Atlantic/Madeira' => 'لوېديځ اروپايي وخت (مديرا)',
        'Atlantic/Reykjavik' => 'ګرينويچ معياري وخت (ريکجاويک)',
        'Atlantic/South_Georgia' => 'د سویل جورجیا وخت (سويلي جورجيا)',
        'Atlantic/St_Helena' => 'ګرينويچ معياري وخت (سینټ هیلینا)',
        'Atlantic/Stanley' => 'فوکلنډ ټاپو وخت (سټنلي)',
        'Australia/Adelaide' => 'مرکزي آستراليا وخت (اډیلایډ)',
        'Australia/Brisbane' => 'ختيځ آستراليا وخت (بریسبن)',
        'Australia/Broken_Hill' => 'مرکزي آستراليا وخت (بروکن هل)',
        'Australia/Currie' => 'ختيځ آستراليا وخت (کرري)',
        'Australia/Darwin' => 'مرکزي آستراليا وخت (ډارون)',
        'Australia/Eucla' => 'آسترالوي مرکزي لوېديځ وخت (ايوکلا)',
        'Australia/Hobart' => 'ختيځ آستراليا وخت (هوبارټ)',
        'Australia/Lindeman' => 'ختيځ آستراليا وخت (لینډامین)',
        'Australia/Lord_Howe' => 'لارډ هوي وخت',
        'Australia/Melbourne' => 'ختيځ آستراليا وخت (میلبورن)',
        'Australia/Perth' => 'لوېديځ آستراليا وخت (پرت)',
        'Australia/Sydney' => 'ختيځ آستراليا وخت (سډني)',
        'CST6CDT' => 'مرکزي وخت',
        'EST5EDT' => 'ختیځ وخت',
        'Etc/GMT' => 'ګرينويچ معياري وخت',
        'Etc/UTC' => 'همغږى نړیوال وخت',
        'Europe/Amsterdam' => 'مرکزي اروپايي وخت (امستردام)',
        'Europe/Andorra' => 'مرکزي اروپايي وخت (اندورا)',
        'Europe/Astrakhan' => 'ماسکو وخت (استرا خان)',
        'Europe/Athens' => 'ختيځ اروپايي وخت (ايتنز)',
        'Europe/Belgrade' => 'مرکزي اروپايي وخت (بلغاد)',
        'Europe/Berlin' => 'مرکزي اروپايي وخت (برلن)',
        'Europe/Bratislava' => 'مرکزي اروپايي وخت (براټسلاوا)',
        'Europe/Brussels' => 'مرکزي اروپايي وخت (بروسلز)',
        'Europe/Bucharest' => 'ختيځ اروپايي وخت (بخارست)',
        'Europe/Budapest' => 'مرکزي اروپايي وخت (بداپسټ)',
        'Europe/Busingen' => 'مرکزي اروپايي وخت (بوسينجن)',
        'Europe/Chisinau' => 'ختيځ اروپايي وخت (چیسینو)',
        'Europe/Copenhagen' => 'مرکزي اروپايي وخت (کوپن هيګن)',
        'Europe/Dublin' => 'ګرينويچ معياري وخت (ډبلن)',
        'Europe/Gibraltar' => 'مرکزي اروپايي وخت (جبل الطارق)',
        'Europe/Guernsey' => 'ګرينويچ معياري وخت (ګرنسي)',
        'Europe/Helsinki' => 'ختيځ اروپايي وخت (هیلسنکی)',
        'Europe/Isle_of_Man' => 'ګرينويچ معياري وخت (د آئل آف مین)',
        'Europe/Istanbul' => 'د ترکي په وخت (استنبول)',
        'Europe/Jersey' => 'ګرينويچ معياري وخت (جرسی)',
        'Europe/Kaliningrad' => 'ختيځ اروپايي وخت (کيلنينګراډ)',
        'Europe/Kiev' => 'ختيځ اروپايي وخت (کیف)',
        'Europe/Kirov' => 'د روسیه په وخت (کیروف)',
        'Europe/Lisbon' => 'لوېديځ اروپايي وخت (لیسبون)',
        'Europe/Ljubljana' => 'مرکزي اروپايي وخت (لوبجانا)',
        'Europe/London' => 'ګرينويچ معياري وخت (لندن)',
        'Europe/Luxembourg' => 'مرکزي اروپايي وخت (لوګزامبورګ)',
        'Europe/Madrid' => 'مرکزي اروپايي وخت (میډریډ)',
        'Europe/Malta' => 'مرکزي اروپايي وخت (مالټا)',
        'Europe/Mariehamn' => 'ختيځ اروپايي وخت (ميريهام)',
        'Europe/Minsk' => 'ماسکو وخت (منسک)',
        'Europe/Monaco' => 'مرکزي اروپايي وخت (موناکو)',
        'Europe/Moscow' => 'ماسکو وخت',
        'Europe/Oslo' => 'مرکزي اروپايي وخت (اوسلو)',
        'Europe/Paris' => 'مرکزي اروپايي وخت (پاریس)',
        'Europe/Podgorica' => 'مرکزي اروپايي وخت (پوډګوريکا)',
        'Europe/Prague' => 'مرکزي اروپايي وخت (پراګ)',
        'Europe/Riga' => 'ختيځ اروپايي وخت (ريګا)',
        'Europe/Rome' => 'مرکزي اروپايي وخت (روم)',
        'Europe/Samara' => 'د روسیه په وخت (سمارا)',
        'Europe/San_Marino' => 'مرکزي اروپايي وخت (سان مارینو)',
        'Europe/Sarajevo' => 'مرکزي اروپايي وخت (سيراجيوا)',
        'Europe/Saratov' => 'ماسکو وخت (سراتف)',
        'Europe/Simferopol' => 'ماسکو وخت (سیمفروپول)',
        'Europe/Skopje' => 'مرکزي اروپايي وخت (سکپوګ)',
        'Europe/Sofia' => 'ختيځ اروپايي وخت (صوفیا)',
        'Europe/Stockholm' => 'مرکزي اروپايي وخت (استولوم)',
        'Europe/Tallinn' => 'ختيځ اروپايي وخت (تالين)',
        'Europe/Tirane' => 'مرکزي اروپايي وخت (تيران)',
        'Europe/Ulyanovsk' => 'ماسکو وخت (اليانوسک)',
        'Europe/Uzhgorod' => 'ختيځ اروپايي وخت (یوژورډ)',
        'Europe/Vaduz' => 'مرکزي اروپايي وخت (واډوز)',
        'Europe/Vatican' => 'مرکزي اروپايي وخت (ویټیکان)',
        'Europe/Vienna' => 'مرکزي اروپايي وخت (ویانا)',
        'Europe/Vilnius' => 'ختيځ اروپايي وخت (ويلنيوس)',
        'Europe/Volgograd' => 'والګوګراد وخت (والګوګراډ)',
        'Europe/Warsaw' => 'مرکزي اروپايي وخت (وارسا)',
        'Europe/Zagreb' => 'مرکزي اروپايي وخت (زګرب)',
        'Europe/Zaporozhye' => 'ختيځ اروپايي وخت (زاپوروژی)',
        'Europe/Zurich' => 'مرکزي اروپايي وخت (زریچ)',
        'Indian/Antananarivo' => 'ختيځ افريقا وخت (انتانناريوو)',
        'Indian/Chagos' => 'د هند سمندر وخت (چاګوس)',
        'Indian/Christmas' => 'کريسمس ټاپو وخت',
        'Indian/Cocos' => 'کوکوز ټاپوګانو وخت',
        'Indian/Comoro' => 'ختيځ افريقا وخت (کومورو)',
        'Indian/Kerguelen' => 'د فرانسې سویل او انټارټيک وخت (کرګولين)',
        'Indian/Mahe' => 'سیچیلس وخت (ماهي)',
        'Indian/Maldives' => 'مالديپ وخت',
        'Indian/Mauritius' => 'ماريشيس وخت',
        'Indian/Mayotte' => 'ختيځ افريقا وخت (میټوت)',
        'Indian/Reunion' => 'ري يونين وخت',
        'MST7MDT' => 'د غره د وخت',
        'PST8PDT' => 'پیسفک وخت',
        'Pacific/Apia' => 'اپیا وخت',
        'Pacific/Auckland' => 'نيوزي لېنډ وخت (اکلند)',
        'Pacific/Bougainville' => 'پاپوا نیو ګنی وخت (بوګن ویل)',
        'Pacific/Chatham' => 'چاتام وخت',
        'Pacific/Easter' => 'ايستر ټاپو وخت (ایسټر)',
        'Pacific/Efate' => 'د وناتو وخت (عفات)',
        'Pacific/Enderbury' => 'د فینکس ټاپو وخت (انډربري)',
        'Pacific/Fakaofo' => 'توکیلاو وخت (فوکافو)',
        'Pacific/Fiji' => 'فجی وخت (فجي)',
        'Pacific/Funafuti' => 'تووالو وخت (فونافوتي)',
        'Pacific/Galapagos' => 'ګالپګوس وخت',
        'Pacific/Gambier' => 'ګيمبير وخت',
        'Pacific/Guadalcanal' => 'سلیمان ټاپوګانو وخت (ګواډلکينال)',
        'Pacific/Guam' => 'چمارو معياري وخت (ګوام)',
        'Pacific/Honolulu' => 'هوایی الیوتین وخت (هینولولو)',
        'Pacific/Johnston' => 'هوایی الیوتین وخت (جانسټن)',
        'Pacific/Kiritimati' => 'لاين ټاپوګانو وخت (کيريټماټي)',
        'Pacific/Kosrae' => 'کوسراي وخت',
        'Pacific/Kwajalein' => 'مارشل ټاپوګانو وخت (کواجلين)',
        'Pacific/Majuro' => 'مارشل ټاپوګانو وخت (مجورو)',
        'Pacific/Marquesas' => 'مارکسس وخت (مارکيساس)',
        'Pacific/Midway' => 'سموا وخت (ميډوی)',
        'Pacific/Nauru' => 'ناورو وخت (نایرو)',
        'Pacific/Niue' => 'نییو وخت (نیوو)',
        'Pacific/Norfolk' => 'نورفوک ټاپو وخت (نورفک)',
        'Pacific/Noumea' => 'نیو کالیډونیا وخت (نوميا)',
        'Pacific/Pago_Pago' => 'سموا وخت (پيګو پيګو)',
        'Pacific/Palau' => 'پالاو وخت (پلاو)',
        'Pacific/Pitcairn' => 'پیټ کارین وخت (پيټيکيرن)',
        'Pacific/Ponape' => 'پونيپ وخت (پونپي)',
        'Pacific/Port_Moresby' => 'پاپوا نیو ګنی وخت (پورټ مورسبی)',
        'Pacific/Rarotonga' => 'کوک ټاپوګانو وخت (راروټونګا)',
        'Pacific/Saipan' => 'چمارو معياري وخت (سيپان)',
        'Pacific/Tahiti' => 'ټهيټي وخت',
        'Pacific/Tarawa' => 'جلبرټ ټاپوګانو وخت (تاراوا)',
        'Pacific/Tongatapu' => 'ټونګا وخت (ټونګاتاپو)',
        'Pacific/Truk' => 'چوک وخت',
        'Pacific/Wake' => 'ويک تاپو وخت (ویک)',
        'Pacific/Wallis' => 'والس او فوتونا وخت',
    ],
    'Meta' => [
    ],
];
