<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'univerzalno vrijeme (Abidjan)',
        'Africa/Accra' => 'univerzalno vrijeme (Accra)',
        'Africa/Addis_Ababa' => 'istočnoafričko vrijeme (Addis Abeba)',
        'Africa/Algiers' => 'srednjoeuropsko vrijeme (Alžir)',
        'Africa/Asmera' => 'istočnoafričko vrijeme (Asmara)',
        'Africa/Bamako' => 'univerzalno vrijeme (Bamako)',
        'Africa/Bangui' => 'zapadnoafričko vrijeme (Bangui)',
        'Africa/Banjul' => 'univerzalno vrijeme (Banjul)',
        'Africa/Bissau' => 'univerzalno vrijeme (Bissau)',
        'Africa/Blantyre' => 'srednjoafričko vrijeme (Blantyre)',
        'Africa/Brazzaville' => 'zapadnoafričko vrijeme (Brazzaville)',
        'Africa/Bujumbura' => 'srednjoafričko vrijeme (Bujumbura)',
        'Africa/Cairo' => 'istočnoeuropsko vrijeme (Kairo)',
        'Africa/Casablanca' => 'zapadnoeuropsko vrijeme (Casablanca)',
        'Africa/Ceuta' => 'srednjoeuropsko vrijeme (Ceuta)',
        'Africa/Conakry' => 'univerzalno vrijeme (Conakry)',
        'Africa/Dakar' => 'univerzalno vrijeme (Dakar)',
        'Africa/Dar_es_Salaam' => 'istočnoafričko vrijeme (Dar es Salaam)',
        'Africa/Djibouti' => 'istočnoafričko vrijeme (Džibuti)',
        'Africa/Douala' => 'zapadnoafričko vrijeme (Douala)',
        'Africa/El_Aaiun' => 'zapadnoeuropsko vrijeme (El Aaiun)',
        'Africa/Freetown' => 'univerzalno vrijeme (Freetown)',
        'Africa/Gaborone' => 'srednjoafričko vrijeme (Gaborone)',
        'Africa/Harare' => 'srednjoafričko vrijeme (Harare)',
        'Africa/Johannesburg' => 'južnoafričko vrijeme (Johannesburg)',
        'Africa/Juba' => 'srednjoafričko vrijeme (Juba)',
        'Africa/Kampala' => 'istočnoafričko vrijeme (Kampala)',
        'Africa/Khartoum' => 'srednjoafričko vrijeme (Khartoum)',
        'Africa/Kigali' => 'srednjoafričko vrijeme (Kigali)',
        'Africa/Kinshasa' => 'zapadnoafričko vrijeme (Kinshasa)',
        'Africa/Lagos' => 'zapadnoafričko vrijeme (Lagos)',
        'Africa/Libreville' => 'zapadnoafričko vrijeme (Libreville)',
        'Africa/Lome' => 'univerzalno vrijeme (Lomé)',
        'Africa/Luanda' => 'zapadnoafričko vrijeme (Luanda)',
        'Africa/Lubumbashi' => 'srednjoafričko vrijeme (Lubumbashi)',
        'Africa/Lusaka' => 'srednjoafričko vrijeme (Lusaka)',
        'Africa/Malabo' => 'zapadnoafričko vrijeme (Malabo)',
        'Africa/Maputo' => 'srednjoafričko vrijeme (Maputo)',
        'Africa/Maseru' => 'južnoafričko vrijeme (Maseru)',
        'Africa/Mbabane' => 'južnoafričko vrijeme (Mbabane)',
        'Africa/Mogadishu' => 'istočnoafričko vrijeme (Mogadishu)',
        'Africa/Monrovia' => 'univerzalno vrijeme (Monrovia)',
        'Africa/Nairobi' => 'istočnoafričko vrijeme (Nairobi)',
        'Africa/Ndjamena' => 'zapadnoafričko vrijeme (Ndjamena)',
        'Africa/Niamey' => 'zapadnoafričko vrijeme (Niamey)',
        'Africa/Nouakchott' => 'univerzalno vrijeme (Nouakchott)',
        'Africa/Ouagadougou' => 'univerzalno vrijeme (Ouagadougou)',
        'Africa/Porto-Novo' => 'zapadnoafričko vrijeme (Porto-Novo)',
        'Africa/Sao_Tome' => 'univerzalno vrijeme (São Tomé)',
        'Africa/Tripoli' => 'istočnoeuropsko vrijeme (Tripoli)',
        'Africa/Tunis' => 'srednjoeuropsko vrijeme (Tunis)',
        'Africa/Windhoek' => 'srednjoafričko vrijeme (Windhoek)',
        'America/Adak' => 'havajsko-aleutsko vrijeme (Adak)',
        'America/Anchorage' => 'aljaško vrijeme (Anchorage)',
        'America/Anguilla' => 'atlantsko vrijeme (Angvila)',
        'America/Antigua' => 'atlantsko vrijeme (Antigua)',
        'America/Araguaina' => 'brazilsko vrijeme (Araguaina)',
        'America/Argentina/La_Rioja' => 'argentinsko vrijeme (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'argentinsko vrijeme (Rio Gallegos)',
        'America/Argentina/Salta' => 'argentinsko vrijeme (Salta)',
        'America/Argentina/San_Juan' => 'argentinsko vrijeme (San Juan)',
        'America/Argentina/San_Luis' => 'argentinsko vrijeme (San Luis)',
        'America/Argentina/Tucuman' => 'argentinsko vrijeme (Tucuman)',
        'America/Argentina/Ushuaia' => 'argentinsko vrijeme (Ushuaia)',
        'America/Aruba' => 'atlantsko vrijeme (Aruba)',
        'America/Asuncion' => 'paragvajsko vrijeme (Asunción)',
        'America/Bahia' => 'brazilsko vrijeme (Bahia)',
        'America/Bahia_Banderas' => 'središnje vrijeme (Bahia Banderas)',
        'America/Barbados' => 'atlantsko vrijeme (Barbados)',
        'America/Belem' => 'brazilsko vrijeme (Belem)',
        'America/Belize' => 'središnje vrijeme (Belize)',
        'America/Blanc-Sablon' => 'atlantsko vrijeme (Blanc-Sablon)',
        'America/Boa_Vista' => 'amazonsko vrijeme (Boa Vista)',
        'America/Bogota' => 'kolumbijsko vrijeme (Bogota)',
        'America/Boise' => 'planinsko vrijeme (Boise)',
        'America/Buenos_Aires' => 'argentinsko vrijeme (Buenos Aires)',
        'America/Cambridge_Bay' => 'planinsko vrijeme (Cambridge Bay)',
        'America/Campo_Grande' => 'amazonsko vrijeme (Campo Grande)',
        'America/Cancun' => 'istočno vrijeme (Cancun)',
        'America/Caracas' => 'venezuelsko vrijeme (Caracas)',
        'America/Catamarca' => 'argentinsko vrijeme (Catamarca)',
        'America/Cayenne' => 'vrijeme Francuske Gijane (Cayenne)',
        'America/Cayman' => 'istočno vrijeme (Cayman)',
        'America/Chicago' => 'središnje vrijeme (Chicago)',
        'America/Chihuahua' => 'meksičko pacifičko vrijeme (Chihuahua)',
        'America/Coral_Harbour' => 'istočno vrijeme (Atikokan)',
        'America/Cordoba' => 'argentinsko vrijeme (Cordoba)',
        'America/Costa_Rica' => 'središnje vrijeme (Kostarika)',
        'America/Creston' => 'planinsko vrijeme (Creston)',
        'America/Cuiaba' => 'amazonsko vrijeme (Cuiaba)',
        'America/Curacao' => 'atlantsko vrijeme (Curaçao)',
        'America/Danmarkshavn' => 'univerzalno vrijeme (Danmarkshavn)',
        'America/Dawson' => 'jukonško vrijeme (Dawson)',
        'America/Dawson_Creek' => 'planinsko vrijeme (Dawson Creek)',
        'America/Denver' => 'planinsko vrijeme (Denver)',
        'America/Detroit' => 'istočno vrijeme (Detroit)',
        'America/Dominica' => 'atlantsko vrijeme (Dominika)',
        'America/Edmonton' => 'planinsko vrijeme (Edmonton)',
        'America/Eirunepe' => 'Acre vrijeme (Eirunepe)',
        'America/El_Salvador' => 'središnje vrijeme (Salvador)',
        'America/Fort_Nelson' => 'planinsko vrijeme (Fort Nelson)',
        'America/Fortaleza' => 'brazilsko vrijeme (Fortaleza)',
        'America/Glace_Bay' => 'atlantsko vrijeme (Glace Bay)',
        'America/Godthab' => 'zapadnogrenlandsko vrijeme (Nuuk)',
        'America/Goose_Bay' => 'atlantsko vrijeme (Goose Bay)',
        'America/Grand_Turk' => 'istočno vrijeme (Grand Turk)',
        'America/Grenada' => 'atlantsko vrijeme (Grenada)',
        'America/Guadeloupe' => 'atlantsko vrijeme (Guadalupe)',
        'America/Guatemala' => 'središnje vrijeme (Gvatemala)',
        'America/Guayaquil' => 'ekvadorsko vrijeme (Guayaquil)',
        'America/Guyana' => 'gvajansko vrijeme (Gvajana)',
        'America/Halifax' => 'atlantsko vrijeme (Halifax)',
        'America/Havana' => 'kubansko vrijeme (Havana)',
        'America/Hermosillo' => 'meksičko pacifičko vrijeme (Hermosillo)',
        'America/Indiana/Knox' => 'središnje vrijeme (Knox, Indiana)',
        'America/Indiana/Marengo' => 'istočno vrijeme (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'istočno vrijeme (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'središnje vrijeme (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'istočno vrijeme (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'istočno vrijeme (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'istočno vrijeme (Winamac, Indiana)',
        'America/Indianapolis' => 'istočno vrijeme (Indianapolis)',
        'America/Inuvik' => 'planinsko vrijeme (Inuvik)',
        'America/Iqaluit' => 'istočno vrijeme (Iqaluit)',
        'America/Jamaica' => 'istočno vrijeme (Jamajka)',
        'America/Jujuy' => 'argentinsko vrijeme (Jujuy)',
        'America/Juneau' => 'aljaško vrijeme (Juneau)',
        'America/Kentucky/Monticello' => 'istočno vrijeme (Monticello, Kentucky)',
        'America/Kralendijk' => 'atlantsko vrijeme (Kralendijk)',
        'America/La_Paz' => 'bolivijsko vrijeme (La Paz)',
        'America/Lima' => 'peruansko vrijeme (Lima)',
        'America/Los_Angeles' => 'pacifičko vrijeme (Los Angeles)',
        'America/Louisville' => 'istočno vrijeme (Louisville)',
        'America/Lower_Princes' => 'atlantsko vrijeme (Lower Prince’s Quarter)',
        'America/Maceio' => 'brazilsko vrijeme (Maceio)',
        'America/Managua' => 'središnje vrijeme (Managua)',
        'America/Manaus' => 'amazonsko vrijeme (Manaus)',
        'America/Marigot' => 'atlantsko vrijeme (Marigot)',
        'America/Martinique' => 'atlantsko vrijeme (Martinique)',
        'America/Matamoros' => 'središnje vrijeme (Matamoros)',
        'America/Mazatlan' => 'meksičko pacifičko vrijeme (Mazatlan)',
        'America/Mendoza' => 'argentinsko vrijeme (Mendoza)',
        'America/Menominee' => 'središnje vrijeme (Menominee)',
        'America/Merida' => 'središnje vrijeme (Merida)',
        'America/Metlakatla' => 'aljaško vrijeme (Metlakatla)',
        'America/Mexico_City' => 'središnje vrijeme (Ciudad de México)',
        'America/Miquelon' => 'vrijeme za Sveti Petar i Mikelon (Miquelon)',
        'America/Moncton' => 'atlantsko vrijeme (Moncton)',
        'America/Monterrey' => 'središnje vrijeme (Monterrey)',
        'America/Montevideo' => 'urugvajsko vrijeme (Montevideo)',
        'America/Montreal' => 'Kanada (Montreal)',
        'America/Montserrat' => 'atlantsko vrijeme (Montserrat)',
        'America/Nassau' => 'istočno vrijeme (Nassau)',
        'America/New_York' => 'istočno vrijeme (New York)',
        'America/Nipigon' => 'istočno vrijeme (Nipigon)',
        'America/Nome' => 'aljaško vrijeme (Nome)',
        'America/Noronha' => 'vrijeme grada Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'središnje vrijeme (Beulah, Sjeverna Dakota)',
        'America/North_Dakota/Center' => 'središnje vrijeme (Center, Sjeverna Dakota)',
        'America/North_Dakota/New_Salem' => 'središnje vrijeme (New Salem, Sjeverna Dakota)',
        'America/Ojinaga' => 'planinsko vrijeme (Ojinaga)',
        'America/Panama' => 'istočno vrijeme (Panama)',
        'America/Pangnirtung' => 'istočno vrijeme (Pangnirtung)',
        'America/Paramaribo' => 'surinamsko vrijeme (Paramaribo)',
        'America/Phoenix' => 'planinsko vrijeme (Phoenix)',
        'America/Port-au-Prince' => 'istočno vrijeme (Port-au-Prince)',
        'America/Port_of_Spain' => 'atlantsko vrijeme (Port of Spain)',
        'America/Porto_Velho' => 'amazonsko vrijeme (Porto Velho)',
        'America/Puerto_Rico' => 'atlantsko vrijeme (Portoriko)',
        'America/Punta_Arenas' => 'čileansko vrijeme (Punta Arenas)',
        'America/Rainy_River' => 'središnje vrijeme (Rainy River)',
        'America/Rankin_Inlet' => 'središnje vrijeme (Rankin Inlet)',
        'America/Recife' => 'brazilsko vrijeme (Recife)',
        'America/Regina' => 'središnje vrijeme (Regina)',
        'America/Resolute' => 'središnje vrijeme (Resolute)',
        'America/Rio_Branco' => 'Acre vrijeme (Rio Branco)',
        'America/Santa_Isabel' => 'sjeverozapadno meksičko vrijeme (Santa Isabel)',
        'America/Santarem' => 'brazilsko vrijeme (Santarem)',
        'America/Santiago' => 'čileansko vrijeme (Santiago)',
        'America/Santo_Domingo' => 'atlantsko vrijeme (Santo Domingo)',
        'America/Sao_Paulo' => 'brazilsko vrijeme (Sao Paulo)',
        'America/Scoresbysund' => 'istočnogrenlandsko vrijeme (Ittoqqortoormiit)',
        'America/Sitka' => 'aljaško vrijeme (Sitka)',
        'America/St_Barthelemy' => 'atlantsko vrijeme (Saint Barthélemy)',
        'America/St_Johns' => 'newfoundlandsko vrijeme (St. John’s)',
        'America/St_Kitts' => 'atlantsko vrijeme (St. Kitts)',
        'America/St_Lucia' => 'atlantsko vrijeme (St. Lucia)',
        'America/St_Thomas' => 'atlantsko vrijeme (St. Thomas)',
        'America/St_Vincent' => 'atlantsko vrijeme (St. Vincent)',
        'America/Swift_Current' => 'središnje vrijeme (Swift Current)',
        'America/Tegucigalpa' => 'središnje vrijeme (Tegucigalpa)',
        'America/Thule' => 'atlantsko vrijeme (Thule)',
        'America/Thunder_Bay' => 'istočno vrijeme (Thunder Bay)',
        'America/Tijuana' => 'pacifičko vrijeme (Tijuana)',
        'America/Toronto' => 'istočno vrijeme (Toronto)',
        'America/Tortola' => 'atlantsko vrijeme (Tortola)',
        'America/Vancouver' => 'pacifičko vrijeme (Vancouver)',
        'America/Whitehorse' => 'jukonško vrijeme (Whitehorse)',
        'America/Winnipeg' => 'središnje vrijeme (Winnipeg)',
        'America/Yakutat' => 'aljaško vrijeme (Yakutat)',
        'America/Yellowknife' => 'planinsko vrijeme (Yellowknife)',
        'Antarctica/Casey' => 'vrijeme Caseyja',
        'Antarctica/Davis' => 'vrijeme Davisa',
        'Antarctica/DumontDUrville' => 'vrijeme Dumont-d’Urvillea',
        'Antarctica/Macquarie' => 'istočnoaustralsko vrijeme (Macquarie)',
        'Antarctica/Mawson' => 'mawsonsko vrijeme',
        'Antarctica/McMurdo' => 'novozelandsko vrijeme (McMurdo)',
        'Antarctica/Palmer' => 'čileansko vrijeme (Palmer)',
        'Antarctica/Rothera' => 'vrijeme Rothere (Rothera)',
        'Antarctica/Syowa' => 'vrijeme Syowe (Syowa)',
        'Antarctica/Troll' => 'univerzalno vrijeme (Troll)',
        'Antarctica/Vostok' => 'vostočko vrijeme (Vostok)',
        'Arctic/Longyearbyen' => 'srednjoeuropsko vrijeme (Longyearbyen)',
        'Asia/Aden' => 'arapsko vrijeme (Aden)',
        'Asia/Almaty' => 'istočnokazahstansko vrijeme (Alma Ata)',
        'Asia/Amman' => 'istočnoeuropsko vrijeme (Amman)',
        'Asia/Anadyr' => 'anadirsko vrijeme',
        'Asia/Aqtau' => 'zapadnokazahstansko vrijeme (Aktau)',
        'Asia/Aqtobe' => 'zapadnokazahstansko vrijeme (Aktobe)',
        'Asia/Ashgabat' => 'turkmenistansko vrijeme (Ašgabat)',
        'Asia/Atyrau' => 'zapadnokazahstansko vrijeme (Atyrau)',
        'Asia/Baghdad' => 'arapsko vrijeme (Bagdad)',
        'Asia/Bahrain' => 'arapsko vrijeme (Bahrein)',
        'Asia/Baku' => 'azerbajdžansko vrijeme (Baku)',
        'Asia/Bangkok' => 'indokinesko vrijeme (Bangkok)',
        'Asia/Barnaul' => 'Rusija (Barnaul)',
        'Asia/Beirut' => 'istočnoeuropsko vrijeme (Beirut)',
        'Asia/Bishkek' => 'kirgistansko vrijeme (Biškek)',
        'Asia/Brunei' => 'vrijeme za Brunej Darussalam',
        'Asia/Calcutta' => 'indijsko vrijeme (Kolkata)',
        'Asia/Chita' => 'jakutsko vrijeme (Čita)',
        'Asia/Choibalsan' => 'ulanbatorsko vrijeme (Choibalsan)',
        'Asia/Colombo' => 'indijsko vrijeme (Colombo)',
        'Asia/Damascus' => 'istočnoeuropsko vrijeme (Damask)',
        'Asia/Dhaka' => 'bangladeško vrijeme (Dhaka)',
        'Asia/Dili' => 'istočnotimorsko vrijeme (Dili)',
        'Asia/Dubai' => 'zaljevsko standardno vrijeme (Dubai)',
        'Asia/Dushanbe' => 'tadžikistansko vrijeme (Dušanbe)',
        'Asia/Famagusta' => 'istočnoeuropsko vrijeme (Famagusta)',
        'Asia/Gaza' => 'istočnoeuropsko vrijeme (Gaza)',
        'Asia/Hebron' => 'istočnoeuropsko vrijeme (Hebron)',
        'Asia/Hong_Kong' => 'hongkonško vrijeme (Hong Kong)',
        'Asia/Hovd' => 'hovdsko vrijeme',
        'Asia/Irkutsk' => 'irkutsko vrijeme',
        'Asia/Jakarta' => 'zapadnoindonezijsko vrijeme (Džakarta)',
        'Asia/Jayapura' => 'istočnoindonezijsko vrijeme (Jayapura)',
        'Asia/Jerusalem' => 'izraelsko vrijeme (Jeruzalem)',
        'Asia/Kabul' => 'afganistansko vrijeme (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-kamčatsko vrijeme (Kamčatka)',
        'Asia/Karachi' => 'pakistansko vrijeme (Karachi)',
        'Asia/Katmandu' => 'nepalsko vrijeme (Kathmandu)',
        'Asia/Khandyga' => 'jakutsko vrijeme (Handiga)',
        'Asia/Krasnoyarsk' => 'krasnojarsko vrijeme',
        'Asia/Kuala_Lumpur' => 'malezijsko vrijeme (Kuala Lumpur)',
        'Asia/Kuching' => 'malezijsko vrijeme (Kuching)',
        'Asia/Kuwait' => 'arapsko vrijeme (Kuvajt)',
        'Asia/Macau' => 'kinesko vrijeme (Makao)',
        'Asia/Magadan' => 'magadansko vrijeme',
        'Asia/Makassar' => 'srednjoindonezijsko vrijeme (Makassar)',
        'Asia/Manila' => 'filipinsko vrijeme (Manila)',
        'Asia/Muscat' => 'zaljevsko standardno vrijeme (Muscat)',
        'Asia/Nicosia' => 'istočnoeuropsko vrijeme (Nikozija)',
        'Asia/Novokuznetsk' => 'krasnojarsko vrijeme (Novokuznjeck)',
        'Asia/Novosibirsk' => 'novosibirsko vrijeme',
        'Asia/Omsk' => 'omsko vrijeme',
        'Asia/Oral' => 'zapadnokazahstansko vrijeme (Oral)',
        'Asia/Phnom_Penh' => 'indokinesko vrijeme (Phnom Penh)',
        'Asia/Pontianak' => 'zapadnoindonezijsko vrijeme (Pontianak)',
        'Asia/Pyongyang' => 'korejsko vrijeme (Pjongjang)',
        'Asia/Qatar' => 'arapsko vrijeme (Katar)',
        'Asia/Qostanay' => 'istočnokazahstansko vrijeme (Kostanay)',
        'Asia/Qyzylorda' => 'zapadnokazahstansko vrijeme (Kizilorda)',
        'Asia/Rangoon' => 'mjanmarsko vrijeme (Rangoon)',
        'Asia/Riyadh' => 'arapsko vrijeme (Rijad)',
        'Asia/Saigon' => 'indokinesko vrijeme (Ho Ši Min)',
        'Asia/Sakhalin' => 'sahalinsko vrijeme',
        'Asia/Samarkand' => 'uzbekistansko vrijeme (Samarkand)',
        'Asia/Seoul' => 'korejsko vrijeme (Seoul)',
        'Asia/Shanghai' => 'kinesko vrijeme (Šangaj)',
        'Asia/Singapore' => 'singapursko vrijeme',
        'Asia/Srednekolymsk' => 'magadansko vrijeme (Srednekolimsk)',
        'Asia/Taipei' => 'tajpeško vrijeme (Taipei)',
        'Asia/Tashkent' => 'uzbekistansko vrijeme (Taškent)',
        'Asia/Tbilisi' => 'gruzijsko vrijeme (Tbilisi)',
        'Asia/Tehran' => 'iransko vrijeme (Teheran)',
        'Asia/Thimphu' => 'butansko vrijeme (Thimphu)',
        'Asia/Tokyo' => 'japansko vrijeme (Tokyo)',
        'Asia/Tomsk' => 'Rusija (Tomsk)',
        'Asia/Ulaanbaatar' => 'ulanbatorsko vrijeme (Ulan Bator)',
        'Asia/Urumqi' => 'Kina (Urumqi)',
        'Asia/Ust-Nera' => 'vladivostočko vrijeme (Ust-Nera)',
        'Asia/Vientiane' => 'indokinesko vrijeme (Vientiane)',
        'Asia/Vladivostok' => 'vladivostočko vrijeme (Vladivostok)',
        'Asia/Yakutsk' => 'jakutsko vrijeme',
        'Asia/Yekaterinburg' => 'jekaterinburško vrijeme (Jekaterinburg)',
        'Asia/Yerevan' => 'armensko vrijeme (Erevan)',
        'Atlantic/Azores' => 'azorsko vrijeme (Azorski otoci)',
        'Atlantic/Bermuda' => 'atlantsko vrijeme (Bermuda)',
        'Atlantic/Canary' => 'zapadnoeuropsko vrijeme (Kanari)',
        'Atlantic/Cape_Verde' => 'vrijeme Zelenortskog otočja (Cape Verde)',
        'Atlantic/Faeroe' => 'zapadnoeuropsko vrijeme (Ferojski otoci)',
        'Atlantic/Madeira' => 'zapadnoeuropsko vrijeme (Madeira)',
        'Atlantic/Reykjavik' => 'univerzalno vrijeme (Reykjavik)',
        'Atlantic/South_Georgia' => 'vrijeme Južne Georgije (Južna Georgija)',
        'Atlantic/St_Helena' => 'univerzalno vrijeme (St. Helena)',
        'Atlantic/Stanley' => 'falklandsko vrijeme (Stanley)',
        'Australia/Adelaide' => 'srednjoaustralsko vrijeme (Adelaide)',
        'Australia/Brisbane' => 'istočnoaustralsko vrijeme (Brisbane)',
        'Australia/Broken_Hill' => 'srednjoaustralsko vrijeme (Broken Hill)',
        'Australia/Currie' => 'istočnoaustralsko vrijeme (Currie)',
        'Australia/Darwin' => 'srednjoaustralsko vrijeme (Darwin)',
        'Australia/Eucla' => 'australsko središnje zapadno vrijeme (Eucla)',
        'Australia/Hobart' => 'istočnoaustralsko vrijeme (Hobart)',
        'Australia/Lindeman' => 'istočnoaustralsko vrijeme (Lindeman)',
        'Australia/Lord_Howe' => 'vrijeme otoka Lord Howe',
        'Australia/Melbourne' => 'istočnoaustralsko vrijeme (Melbourne)',
        'Australia/Perth' => 'zapadnoaustralsko vrijeme (Perth)',
        'Australia/Sydney' => 'istočnoaustralsko vrijeme (Sydney)',
        'CST6CDT' => 'središnje vrijeme',
        'EST5EDT' => 'istočno vrijeme',
        'Etc/GMT' => 'univerzalno vrijeme',
        'Etc/UTC' => 'koordinirano svjetsko vrijeme',
        'Europe/Amsterdam' => 'srednjoeuropsko vrijeme (Amsterdam)',
        'Europe/Andorra' => 'srednjoeuropsko vrijeme (Andora)',
        'Europe/Astrakhan' => 'moskovsko vrijeme (Astrahan)',
        'Europe/Athens' => 'istočnoeuropsko vrijeme (Atena)',
        'Europe/Belgrade' => 'srednjoeuropsko vrijeme (Beograd)',
        'Europe/Berlin' => 'srednjoeuropsko vrijeme (Berlin)',
        'Europe/Bratislava' => 'srednjoeuropsko vrijeme (Bratislava)',
        'Europe/Brussels' => 'srednjoeuropsko vrijeme (Bruxelles)',
        'Europe/Bucharest' => 'istočnoeuropsko vrijeme (Bukurešt)',
        'Europe/Budapest' => 'srednjoeuropsko vrijeme (Budimpešta)',
        'Europe/Busingen' => 'srednjoeuropsko vrijeme (Busingen)',
        'Europe/Chisinau' => 'istočnoeuropsko vrijeme (Kišinjev)',
        'Europe/Copenhagen' => 'srednjoeuropsko vrijeme (Kopenhagen)',
        'Europe/Dublin' => 'univerzalno vrijeme (Dublin)',
        'Europe/Gibraltar' => 'srednjoeuropsko vrijeme (Gibraltar)',
        'Europe/Guernsey' => 'univerzalno vrijeme (Guernsey)',
        'Europe/Helsinki' => 'istočnoeuropsko vrijeme (Helsinki)',
        'Europe/Isle_of_Man' => 'univerzalno vrijeme (Otok Man)',
        'Europe/Istanbul' => 'Turska (Istanbul)',
        'Europe/Jersey' => 'univerzalno vrijeme (Jersey)',
        'Europe/Kaliningrad' => 'istočnoeuropsko vrijeme (Kalinjingrad)',
        'Europe/Kiev' => 'istočnoeuropsko vrijeme (Kijev)',
        'Europe/Kirov' => 'Rusija (Kirov)',
        'Europe/Lisbon' => 'zapadnoeuropsko vrijeme (Lisabon)',
        'Europe/Ljubljana' => 'srednjoeuropsko vrijeme (Ljubljana)',
        'Europe/London' => 'univerzalno vrijeme (London)',
        'Europe/Luxembourg' => 'srednjoeuropsko vrijeme (Luksemburg)',
        'Europe/Madrid' => 'srednjoeuropsko vrijeme (Madrid)',
        'Europe/Malta' => 'srednjoeuropsko vrijeme (Malta)',
        'Europe/Mariehamn' => 'istočnoeuropsko vrijeme (Mariehamn)',
        'Europe/Minsk' => 'moskovsko vrijeme (Minsk)',
        'Europe/Monaco' => 'srednjoeuropsko vrijeme (Monako)',
        'Europe/Moscow' => 'moskovsko vrijeme (Moskva)',
        'Europe/Oslo' => 'srednjoeuropsko vrijeme (Oslo)',
        'Europe/Paris' => 'srednjoeuropsko vrijeme (Pariz)',
        'Europe/Podgorica' => 'srednjoeuropsko vrijeme (Podgorica)',
        'Europe/Prague' => 'srednjoeuropsko vrijeme (Prag)',
        'Europe/Riga' => 'istočnoeuropsko vrijeme (Riga)',
        'Europe/Rome' => 'srednjoeuropsko vrijeme (Rim)',
        'Europe/Samara' => 'samarsko vrijeme (Samara)',
        'Europe/San_Marino' => 'srednjoeuropsko vrijeme (San Marino)',
        'Europe/Sarajevo' => 'srednjoeuropsko vrijeme (Sarajevo)',
        'Europe/Saratov' => 'moskovsko vrijeme (Saratov)',
        'Europe/Simferopol' => 'moskovsko vrijeme (Simferopolj)',
        'Europe/Skopje' => 'srednjoeuropsko vrijeme (Skoplje)',
        'Europe/Sofia' => 'istočnoeuropsko vrijeme (Sofija)',
        'Europe/Stockholm' => 'srednjoeuropsko vrijeme (Stockholm)',
        'Europe/Tallinn' => 'istočnoeuropsko vrijeme (Tallinn)',
        'Europe/Tirane' => 'srednjoeuropsko vrijeme (Tirana)',
        'Europe/Ulyanovsk' => 'moskovsko vrijeme (Uljanovsk)',
        'Europe/Uzhgorod' => 'istočnoeuropsko vrijeme (Užgorod)',
        'Europe/Vaduz' => 'srednjoeuropsko vrijeme (Vaduz)',
        'Europe/Vatican' => 'srednjoeuropsko vrijeme (Vatikan)',
        'Europe/Vienna' => 'srednjoeuropsko vrijeme (Beč)',
        'Europe/Vilnius' => 'istočnoeuropsko vrijeme (Vilnius)',
        'Europe/Volgograd' => 'volgogradsko vrijeme',
        'Europe/Warsaw' => 'srednjoeuropsko vrijeme (Varšava)',
        'Europe/Zagreb' => 'srednjoeuropsko vrijeme (Zagreb)',
        'Europe/Zaporozhye' => 'istočnoeuropsko vrijeme (Zaporožje)',
        'Europe/Zurich' => 'srednjoeuropsko vrijeme (Zürich)',
        'Indian/Antananarivo' => 'istočnoafričko vrijeme (Antananarivo)',
        'Indian/Chagos' => 'vrijeme Indijskog oceana (Chagos)',
        'Indian/Christmas' => 'vrijeme Božićnog otoka (Christmas)',
        'Indian/Cocos' => 'vrijeme Kokosovih otoka (Cocos)',
        'Indian/Comoro' => 'istočnoafričko vrijeme (Comoro)',
        'Indian/Kerguelen' => 'vrijeme Francuskih južnih i antarktičkih teritorija (Kerguelen)',
        'Indian/Mahe' => 'sejšelsko vrijeme (Mahe)',
        'Indian/Maldives' => 'maldivsko vrijeme (Maldivi)',
        'Indian/Mauritius' => 'vrijeme Mauricijusa',
        'Indian/Mayotte' => 'istočnoafričko vrijeme (Mayotte)',
        'Indian/Reunion' => 'vrijeme Reuniona (Réunion)',
        'MST7MDT' => 'planinsko vrijeme',
        'PST8PDT' => 'pacifičko vrijeme',
        'Pacific/Apia' => 'vrijeme Apije (Apia)',
        'Pacific/Auckland' => 'novozelandsko vrijeme (Auckland)',
        'Pacific/Bougainville' => 'vrijeme Papue Nove Gvineje (Bougainville)',
        'Pacific/Chatham' => 'vrijeme Chathama',
        'Pacific/Easter' => 'vrijeme Uskršnjeg otoka (Easter)',
        'Pacific/Efate' => 'vrijeme Vanuatua (Efate)',
        'Pacific/Enderbury' => 'vrijeme Otoka Phoenix (Enderbury)',
        'Pacific/Fakaofo' => 'vrijeme Tokelaua (Fakaofo)',
        'Pacific/Fiji' => 'vrijeme Fidžija',
        'Pacific/Funafuti' => 'vrijeme Tuvalua (Funafuti)',
        'Pacific/Galapagos' => 'vrijeme Galapagosa',
        'Pacific/Gambier' => 'vrijeme Gambiera',
        'Pacific/Guadalcanal' => 'vrijeme Salomonskih Otoka (Guadalcanal)',
        'Pacific/Guam' => 'standardno vrijeme Chamorra (Guam)',
        'Pacific/Honolulu' => 'havajsko-aleutsko vrijeme (Honolulu)',
        'Pacific/Johnston' => 'havajsko-aleutsko vrijeme (Johnston)',
        'Pacific/Kiritimati' => 'vrijeme Ekvatorskih otoka (Kiritimati)',
        'Pacific/Kosrae' => 'vrijeme Kosrae',
        'Pacific/Kwajalein' => 'vrijeme Maršalovih Otoka (Kwajalein)',
        'Pacific/Majuro' => 'vrijeme Maršalovih Otoka (Majuro)',
        'Pacific/Marquesas' => 'markižansko vrijeme (Markižansko otočje)',
        'Pacific/Midway' => 'samoansko vrijeme (Midway)',
        'Pacific/Nauru' => 'vrijeme Naurua',
        'Pacific/Niue' => 'vrijeme Niuea',
        'Pacific/Norfolk' => 'vrijeme Otoka Norfolk',
        'Pacific/Noumea' => 'vrijeme Nove Kaledonije (Noumea)',
        'Pacific/Pago_Pago' => 'samoansko vrijeme (Pago Pago)',
        'Pacific/Palau' => 'vrijeme Palaua',
        'Pacific/Pitcairn' => 'pitcairnsko vrijeme',
        'Pacific/Ponape' => 'ponapejsko vrijeme (Pohnpei)',
        'Pacific/Port_Moresby' => 'vrijeme Papue Nove Gvineje (Port Moresby)',
        'Pacific/Rarotonga' => 'vrijeme Cookovih otoka (Rarotonga)',
        'Pacific/Saipan' => 'standardno vrijeme Chamorra (Saipan)',
        'Pacific/Tahiti' => 'vrijeme Tahitija',
        'Pacific/Tarawa' => 'vrijeme Gilbertovih otoka (Tarawa)',
        'Pacific/Tongatapu' => 'vrijeme Tonge (Tongatapu)',
        'Pacific/Truk' => 'vrijeme Chuuka',
        'Pacific/Wake' => 'vrijeme Otoka Wake',
        'Pacific/Wallis' => 'vrijeme Otoka Wallis i Futuna',
    ],
    'Meta' => [
        'HourFormatNeg' => ' -%02d:%02d',
    ],
];
