<?php

return [
    'Names' => [
        'Arab' => 'अरबी',
        'Cyrl' => 'सिरिलिक',
        'Deva' => 'देवनागिरी',
        'Hans' => 'सादी थियल (तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे)',
        'Hant' => 'रवायती (तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे)',
        'Latn' => 'लैटिन',
        'Zxxx' => 'अणलिखियल',
    ],
];
