<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Средно време по Гринич (Абиџан)',
        'Africa/Accra' => 'Средно време по Гринич (Акра)',
        'Africa/Addis_Ababa' => 'Источноафриканско време (Адис Абеба)',
        'Africa/Algiers' => 'Средноевропско време (Алжир)',
        'Africa/Asmera' => 'Источноафриканско време (Асмара)',
        'Africa/Bamako' => 'Средно време по Гринич (Бамако)',
        'Africa/Bangui' => 'Западноафриканско време (Банги)',
        'Africa/Banjul' => 'Средно време по Гринич (Банџул)',
        'Africa/Bissau' => 'Средно време по Гринич (Бисау)',
        'Africa/Blantyre' => 'Средноафриканско време (Блантајр)',
        'Africa/Brazzaville' => 'Западноафриканско време (Бразавил)',
        'Africa/Bujumbura' => 'Средноафриканско време (Буџумбура)',
        'Africa/Cairo' => 'Источноевропско време (Каиро)',
        'Africa/Casablanca' => 'Западноевропско време (Казабланка)',
        'Africa/Ceuta' => 'Средноевропско време (Сеута)',
        'Africa/Conakry' => 'Средно време по Гринич (Конакри)',
        'Africa/Dakar' => 'Средно време по Гринич (Дакар)',
        'Africa/Dar_es_Salaam' => 'Источноафриканско време (Дар ес Салам)',
        'Africa/Djibouti' => 'Источноафриканско време (Џибути)',
        'Africa/Douala' => 'Западноафриканско време (Дуала)',
        'Africa/El_Aaiun' => 'Западноевропско време (Ел Ајун)',
        'Africa/Freetown' => 'Средно време по Гринич (Фритаун)',
        'Africa/Gaborone' => 'Средноафриканско време (Габороне)',
        'Africa/Harare' => 'Средноафриканско време (Хараре)',
        'Africa/Johannesburg' => 'Време во Јужноафриканска Република (Јоханесбург)',
        'Africa/Juba' => 'Средноафриканско време (Џуба)',
        'Africa/Kampala' => 'Источноафриканско време (Кампала)',
        'Africa/Khartoum' => 'Средноафриканско време (Картум)',
        'Africa/Kigali' => 'Средноафриканско време (Кигали)',
        'Africa/Kinshasa' => 'Западноафриканско време (Киншаса)',
        'Africa/Lagos' => 'Западноафриканско време (Лагос)',
        'Africa/Libreville' => 'Западноафриканско време (Либрвил)',
        'Africa/Lome' => 'Средно време по Гринич (Ломе)',
        'Africa/Luanda' => 'Западноафриканско време (Луанда)',
        'Africa/Lubumbashi' => 'Средноафриканско време (Лубумбаши)',
        'Africa/Lusaka' => 'Средноафриканско време (Лусака)',
        'Africa/Malabo' => 'Западноафриканско време (Малабо)',
        'Africa/Maputo' => 'Средноафриканско време (Мапуто)',
        'Africa/Maseru' => 'Време во Јужноафриканска Република (Масеру)',
        'Africa/Mbabane' => 'Време во Јужноафриканска Република (Мбабане)',
        'Africa/Mogadishu' => 'Источноафриканско време (Могадишу)',
        'Africa/Monrovia' => 'Средно време по Гринич (Монровија)',
        'Africa/Nairobi' => 'Источноафриканско време (Најроби)',
        'Africa/Ndjamena' => 'Западноафриканско време (Нџамена)',
        'Africa/Niamey' => 'Западноафриканско време (Нијамеј)',
        'Africa/Nouakchott' => 'Средно време по Гринич (Нуакшот)',
        'Africa/Ouagadougou' => 'Средно време по Гринич (Уагадугу)',
        'Africa/Porto-Novo' => 'Западноафриканско време (Порто Ново)',
        'Africa/Sao_Tome' => 'Средно време по Гринич (Саун Томе)',
        'Africa/Tripoli' => 'Источноевропско време (Триполи)',
        'Africa/Tunis' => 'Средноевропско време (Тунис)',
        'Africa/Windhoek' => 'Средноафриканско време (Виндхук)',
        'America/Adak' => 'Време во Хаваи - Алеутски острови (Адак)',
        'America/Anchorage' => 'Време во Алјаска (Енкориџ)',
        'America/Anguilla' => 'Атлантско време (Ангвила)',
        'America/Antigua' => 'Атлантско време (Антига)',
        'America/Araguaina' => 'Време во Бразилија (Арагвајана)',
        'America/Argentina/La_Rioja' => 'Време во Аргентина (Ла Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Време во Аргентина (Рио Галегос)',
        'America/Argentina/Salta' => 'Време во Аргентина (Салта)',
        'America/Argentina/San_Juan' => 'Време во Аргентина (Сан Хуан)',
        'America/Argentina/San_Luis' => 'Време во Аргентина (Сан Луис)',
        'America/Argentina/Tucuman' => 'Време во Аргентина (Тукуман)',
        'America/Argentina/Ushuaia' => 'Време во Аргентина (Ушуаја)',
        'America/Aruba' => 'Атлантско време (Аруба)',
        'America/Asuncion' => 'Време во Парагвај (Асунсион)',
        'America/Bahia' => 'Време во Бразилија (Бахиа)',
        'America/Bahia_Banderas' => 'Централно време во Северна Америка (Бахија де Бандерас)',
        'America/Barbados' => 'Атлантско време (Барбадос)',
        'America/Belem' => 'Време во Бразилија (Белем)',
        'America/Belize' => 'Централно време во Северна Америка (Белизе)',
        'America/Blanc-Sablon' => 'Атлантско време (Бланк-Сејблон)',
        'America/Boa_Vista' => 'Време во Амазон (Боа Виста)',
        'America/Bogota' => 'Време во Колумбија (Богота)',
        'America/Boise' => 'Планинско време во Северна Америка (Бојзи)',
        'America/Buenos_Aires' => 'Време во Аргентина (Буенос Аирес)',
        'America/Cambridge_Bay' => 'Планинско време во Северна Америка (Кембриџ Беј)',
        'America/Campo_Grande' => 'Време во Амазон (Кампо Гранде)',
        'America/Cancun' => 'Источно време во Северна Америка (Канкун)',
        'America/Caracas' => 'Време во Венецуела (Каракас)',
        'America/Catamarca' => 'Време во Аргентина (Катамарка)',
        'America/Cayenne' => 'Време во Француска Гвајана (Кајена)',
        'America/Cayman' => 'Источно време во Северна Америка (Кајмански Острови)',
        'America/Chicago' => 'Централно време во Северна Америка (Чикаго)',
        'America/Chihuahua' => 'Пацифичко време во Мексико (Чивава)',
        'America/Coral_Harbour' => 'Источно време во Северна Америка (Корал Харбор)',
        'America/Cordoba' => 'Време во Аргентина (Кордоба)',
        'America/Costa_Rica' => 'Централно време во Северна Америка (Костарика)',
        'America/Creston' => 'Планинско време во Северна Америка (Крестон)',
        'America/Cuiaba' => 'Време во Амазон (Кујаба)',
        'America/Curacao' => 'Атлантско време (Курасао)',
        'America/Danmarkshavn' => 'Средно време по Гринич (Данмаркшан)',
        'America/Dawson' => 'Време во Јукон (Досон)',
        'America/Dawson_Creek' => 'Планинско време во Северна Америка (Досон Крик)',
        'America/Denver' => 'Планинско време во Северна Америка (Денвер)',
        'America/Detroit' => 'Источно време во Северна Америка (Детроит)',
        'America/Dominica' => 'Атлантско време (Доминика)',
        'America/Edmonton' => 'Планинско време во Северна Америка (Едмонтон)',
        'America/Eirunepe' => 'Акре време (Еирунепе)',
        'America/El_Salvador' => 'Централно време во Северна Америка (Ел Салвадор)',
        'America/Fort_Nelson' => 'Планинско време во Северна Америка (Форт Нелсон)',
        'America/Fortaleza' => 'Време во Бразилија (Форталеза)',
        'America/Glace_Bay' => 'Атлантско време (Глејс Беј)',
        'America/Godthab' => 'Време во Западен Гренланд (Нук)',
        'America/Goose_Bay' => 'Атлантско време (Гус Беј)',
        'America/Grand_Turk' => 'Источно време во Северна Америка (Гранд Турк)',
        'America/Grenada' => 'Атлантско време (Гренада)',
        'America/Guadeloupe' => 'Атлантско време (Гвадалупе)',
        'America/Guatemala' => 'Централно време во Северна Америка (Гватемала)',
        'America/Guayaquil' => 'Време во Еквадор (Гвајакил)',
        'America/Guyana' => 'Време во Гвајана',
        'America/Halifax' => 'Атлантско време (Халифакс)',
        'America/Havana' => 'Време во Куба (Хавана)',
        'America/Hermosillo' => 'Пацифичко време во Мексико (Ермосиљо)',
        'America/Indiana/Knox' => 'Централно време во Северна Америка (Нокс, Индијана)',
        'America/Indiana/Marengo' => 'Источно време во Северна Америка (Маренго, Индијана)',
        'America/Indiana/Petersburg' => 'Источно време во Северна Америка (Питерсбург, Индијана)',
        'America/Indiana/Tell_City' => 'Централно време во Северна Америка (Тел Сити, Индијана)',
        'America/Indiana/Vevay' => 'Источно време во Северна Америка (Вивеј, Индијана)',
        'America/Indiana/Vincennes' => 'Источно време во Северна Америка (Венсен, Индијана)',
        'America/Indiana/Winamac' => 'Источно време во Северна Америка (Винамак, Индијана)',
        'America/Indianapolis' => 'Источно време во Северна Америка (Индијанаполис)',
        'America/Inuvik' => 'Планинско време во Северна Америка (Инувик)',
        'America/Iqaluit' => 'Источно време во Северна Америка (Икалуит)',
        'America/Jamaica' => 'Источно време во Северна Америка (Јамајка)',
        'America/Jujuy' => 'Време во Аргентина (Хухуј)',
        'America/Juneau' => 'Време во Алјаска (Џуно)',
        'America/Kentucky/Monticello' => 'Источно време во Северна Америка (Монтичело, Кентаки)',
        'America/Kralendijk' => 'Атлантско време (Кралендајк)',
        'America/La_Paz' => 'Време во Боливија (Ла Паз)',
        'America/Lima' => 'Време во Перу (Лима)',
        'America/Los_Angeles' => 'Пацифичко време во Северна Америка (Лос Анџелес)',
        'America/Louisville' => 'Источно време во Северна Америка (Луизвил)',
        'America/Lower_Princes' => 'Атлантско време (Долен Принс квортр)',
        'America/Maceio' => 'Време во Бразилија (Масејо)',
        'America/Managua' => 'Централно време во Северна Америка (Манагва)',
        'America/Manaus' => 'Време во Амазон (Манаус)',
        'America/Marigot' => 'Атлантско време (Мариго)',
        'America/Martinique' => 'Атлантско време (Мартиник)',
        'America/Matamoros' => 'Централно време во Северна Америка (Матаморос)',
        'America/Mazatlan' => 'Пацифичко време во Мексико (Мазатлан)',
        'America/Mendoza' => 'Време во Аргентина (Мендоза)',
        'America/Menominee' => 'Централно време во Северна Америка (Меномини)',
        'America/Merida' => 'Централно време во Северна Америка (Мерида)',
        'America/Metlakatla' => 'Време во Алјаска (Метлакатла)',
        'America/Mexico_City' => 'Централно време во Северна Америка (Мексико Сити)',
        'America/Miquelon' => 'Време во Сент Пјер и Микелан',
        'America/Moncton' => 'Атлантско време (Монктон)',
        'America/Monterrey' => 'Централно време во Северна Америка (Монтереј)',
        'America/Montevideo' => 'Време во Уругвај (Монтевидео)',
        'America/Montreal' => 'Време во Канада (Montreal)',
        'America/Montserrat' => 'Атлантско време (Монтсерат)',
        'America/Nassau' => 'Источно време во Северна Америка (Насау)',
        'America/New_York' => 'Источно време во Северна Америка (Њујорк)',
        'America/Nipigon' => 'Источно време во Северна Америка (Нипигон)',
        'America/Nome' => 'Време во Алјаска (Ном)',
        'America/Noronha' => 'Време во Фернандо де Нороња',
        'America/North_Dakota/Beulah' => 'Централно време во Северна Америка (Бјула, Северна Дакота)',
        'America/North_Dakota/Center' => 'Централно време во Северна Америка (Центар, Северна Дакота)',
        'America/North_Dakota/New_Salem' => 'Централно време во Северна Америка (Њу Салем, Северна Дакота)',
        'America/Ojinaga' => 'Планинско време во Северна Америка (Охинага)',
        'America/Panama' => 'Источно време во Северна Америка (Панама)',
        'America/Pangnirtung' => 'Источно време во Северна Америка (Пангниртунг)',
        'America/Paramaribo' => 'Време во Суринам (Парамарибо)',
        'America/Phoenix' => 'Планинско време во Северна Америка (Феникс)',
        'America/Port-au-Prince' => 'Источно време во Северна Америка (Порт о Пренс)',
        'America/Port_of_Spain' => 'Атлантско време (Порт ов Спејн)',
        'America/Porto_Velho' => 'Време во Амазон (Порто Вељо)',
        'America/Puerto_Rico' => 'Атлантско време (Порторико)',
        'America/Punta_Arenas' => 'Време во Чиле (Пунта Аренас)',
        'America/Rainy_River' => 'Централно време во Северна Америка (Рејни Ривер)',
        'America/Rankin_Inlet' => 'Централно време во Северна Америка (Ренкин Инлет)',
        'America/Recife' => 'Време во Бразилија (Ресифи)',
        'America/Regina' => 'Централно време во Северна Америка (Реџајна)',
        'America/Resolute' => 'Централно време во Северна Америка (Резолут)',
        'America/Rio_Branco' => 'Акре време (Рио Бранко)',
        'America/Santa_Isabel' => 'Време во северозападно Мексико (Света Изабела)',
        'America/Santarem' => 'Време во Бразилија (Сантарем)',
        'America/Santiago' => 'Време во Чиле (Сантијаго)',
        'America/Santo_Domingo' => 'Атлантско време (Санто Доминго)',
        'America/Sao_Paulo' => 'Време во Бразилија (Сао Паоло)',
        'America/Scoresbysund' => 'Време во Источен Гренланд (Итокортормит)',
        'America/Sitka' => 'Време во Алјаска (Ситка)',
        'America/St_Barthelemy' => 'Атлантско време (Сент Бартоломеј)',
        'America/St_Johns' => 'Време во Њуфаундленд (Сент Џонс)',
        'America/St_Kitts' => 'Атлантско време (Свети Китс)',
        'America/St_Lucia' => 'Атлантско време (Сент Лусија)',
        'America/St_Thomas' => 'Атлантско време (Сент Томас)',
        'America/St_Vincent' => 'Атлантско време (Сент Винсент)',
        'America/Swift_Current' => 'Централно време во Северна Америка (Свифт Курент)',
        'America/Tegucigalpa' => 'Централно време во Северна Америка (Тегусигалпа)',
        'America/Thule' => 'Атлантско време (Туле)',
        'America/Thunder_Bay' => 'Источно време во Северна Америка (Тандр Беј)',
        'America/Tijuana' => 'Пацифичко време во Северна Америка (Тихуана)',
        'America/Toronto' => 'Источно време во Северна Америка (Торонто)',
        'America/Tortola' => 'Атлантско време (Тортола)',
        'America/Vancouver' => 'Пацифичко време во Северна Америка (Ванкувер)',
        'America/Whitehorse' => 'Време во Јукон (Вајтхорс)',
        'America/Winnipeg' => 'Централно време во Северна Америка (Винипег)',
        'America/Yakutat' => 'Време во Алјаска (Јакутат)',
        'America/Yellowknife' => 'Планинско време во Северна Америка (Јелоунајф)',
        'Antarctica/Casey' => 'Време во Антарктик (Кејси)',
        'Antarctica/Davis' => 'Време во Дејвис',
        'Antarctica/DumontDUrville' => 'Време во Димон Дирвил',
        'Antarctica/Macquarie' => 'Време во Источна Австралија (Маквори)',
        'Antarctica/Mawson' => 'Време во Мосон',
        'Antarctica/McMurdo' => 'Време во Нов Зеланд (Макмурдо)',
        'Antarctica/Palmer' => 'Време во Чиле (Палмер)',
        'Antarctica/Rothera' => 'Време во Ротера',
        'Antarctica/Syowa' => 'Време во Сајова',
        'Antarctica/Troll' => 'Средно време по Гринич (Трол)',
        'Antarctica/Vostok' => 'Време во Восток',
        'Arctic/Longyearbyen' => 'Средноевропско време (Лонгјербијен)',
        'Asia/Aden' => 'Арапско време (Аден)',
        'Asia/Almaty' => 'Време во Источен Казахстан (Алмати)',
        'Asia/Amman' => 'Источноевропско време (Аман)',
        'Asia/Anadyr' => 'Анадирско време',
        'Asia/Aqtau' => 'Време во Западен Казахстан (Актау)',
        'Asia/Aqtobe' => 'Време во Западен Казахстан (Актобе)',
        'Asia/Ashgabat' => 'Време во Туркменистан (Ашкабад)',
        'Asia/Atyrau' => 'Време во Западен Казахстан (Атирау)',
        'Asia/Baghdad' => 'Арапско време (Багдад)',
        'Asia/Bahrain' => 'Арапско време (Бахреин)',
        'Asia/Baku' => 'Време во Азербејџан (Баку)',
        'Asia/Bangkok' => 'Време во Индокина (Бангкок)',
        'Asia/Barnaul' => 'Време во Русија (Барнаул)',
        'Asia/Beirut' => 'Источноевропско време (Бејрут)',
        'Asia/Bishkek' => 'Време во Киргистан (Бишкек)',
        'Asia/Brunei' => 'Време во Брунеј Дарусалам',
        'Asia/Calcutta' => 'Време во Индија (Калкута)',
        'Asia/Chita' => 'Време во Јакутск (Чита)',
        'Asia/Choibalsan' => 'Време во Улан Батор (Чојбалсан)',
        'Asia/Colombo' => 'Време во Индија (Коломбо)',
        'Asia/Damascus' => 'Источноевропско време (Дамаск)',
        'Asia/Dhaka' => 'Време во Бангладеш (Дака)',
        'Asia/Dili' => 'Време во Источен Тимор (Дили)',
        'Asia/Dubai' => 'Време во Персиски Залив (Дубаи)',
        'Asia/Dushanbe' => 'Време во Таџикистан (Душанбе)',
        'Asia/Famagusta' => 'Источноевропско време (Фамагуста)',
        'Asia/Gaza' => 'Источноевропско време (Газа)',
        'Asia/Hebron' => 'Источноевропско време (Хеброн)',
        'Asia/Hong_Kong' => 'Време во Хонг Конг',
        'Asia/Hovd' => 'Време во Ховд',
        'Asia/Irkutsk' => 'Време во Иркутск',
        'Asia/Jakarta' => 'Време во Западна Индонезија (Џакарта)',
        'Asia/Jayapura' => 'Време во Источна Индонезија (Џајапура)',
        'Asia/Jerusalem' => 'Време во Израел (Ерусалим)',
        'Asia/Kabul' => 'Време во Авганистан (Кабул)',
        'Asia/Kamchatka' => 'Време во Русија (Камчатка)',
        'Asia/Karachi' => 'Време во Пакистан (Карачи)',
        'Asia/Katmandu' => 'Време во Непал (Катманду)',
        'Asia/Khandyga' => 'Време во Јакутск (Хандига)',
        'Asia/Krasnoyarsk' => 'Време во Краснојарск',
        'Asia/Kuala_Lumpur' => 'Време во Малезија (Куала Лумпур)',
        'Asia/Kuching' => 'Време во Малезија (Кучинг)',
        'Asia/Kuwait' => 'Арапско време (Кувајт)',
        'Asia/Macau' => 'Време во Кина (Макао)',
        'Asia/Magadan' => 'Време во Магадан',
        'Asia/Makassar' => 'Време во Централна Индонезија (Макасар)',
        'Asia/Manila' => 'Време во Филипини (Манила)',
        'Asia/Muscat' => 'Време во Персиски Залив (Мускат)',
        'Asia/Nicosia' => 'Источноевропско време (Никозија)',
        'Asia/Novokuznetsk' => 'Време во Краснојарск (Новокузњецк)',
        'Asia/Novosibirsk' => 'Време во Новосибирск',
        'Asia/Omsk' => 'Време во Омск',
        'Asia/Oral' => 'Време во Западен Казахстан (Орал)',
        'Asia/Phnom_Penh' => 'Време во Индокина (Пном Пен)',
        'Asia/Pontianak' => 'Време во Западна Индонезија (Понтијанак)',
        'Asia/Pyongyang' => 'Време во Кореја (Пјонгјанг)',
        'Asia/Qatar' => 'Арапско време (Катар)',
        'Asia/Qostanay' => 'Време во Источен Казахстан (Костанај)',
        'Asia/Qyzylorda' => 'Време во Западен Казахстан (Кизилорда)',
        'Asia/Rangoon' => 'Време во Мјанмар (Рангун)',
        'Asia/Riyadh' => 'Арапско време (Ријад)',
        'Asia/Saigon' => 'Време во Индокина (Хо Ши Мин)',
        'Asia/Sakhalin' => 'Време во Сакалин',
        'Asia/Samarkand' => 'Време во Узбекистан (Самарканд)',
        'Asia/Seoul' => 'Време во Кореја (Сеул)',
        'Asia/Shanghai' => 'Време во Кина (Шангај)',
        'Asia/Singapore' => 'Време во Сингапур',
        'Asia/Srednekolymsk' => 'Време во Магадан (Среднеколимск)',
        'Asia/Taipei' => 'Време во Тајпеј',
        'Asia/Tashkent' => 'Време во Узбекистан (Ташкент)',
        'Asia/Tbilisi' => 'Време во Грузија (Тбилиси)',
        'Asia/Tehran' => 'Време во Иран (Техеран)',
        'Asia/Thimphu' => 'Време во Бутан (Тимпу)',
        'Asia/Tokyo' => 'Време во Јапонија (Токио)',
        'Asia/Tomsk' => 'Време во Русија (Томск)',
        'Asia/Ulaanbaatar' => 'Време во Улан Батор',
        'Asia/Urumqi' => 'Време во Кина (Урумчи)',
        'Asia/Ust-Nera' => 'Време во Владивосток (Уст-Нера)',
        'Asia/Vientiane' => 'Време во Индокина (Виентијан)',
        'Asia/Vladivostok' => 'Време во Владивосток',
        'Asia/Yakutsk' => 'Време во Јакутск',
        'Asia/Yekaterinburg' => 'Време во Екатеринбург',
        'Asia/Yerevan' => 'Време во Ерменија (Ереван)',
        'Atlantic/Azores' => 'Време во Азорски Острови',
        'Atlantic/Bermuda' => 'Атлантско време (Бермуди)',
        'Atlantic/Canary' => 'Западноевропско време (Канарски Острови)',
        'Atlantic/Cape_Verde' => 'Време во Кабо Верде',
        'Atlantic/Faeroe' => 'Западноевропско време (Фарски Острови)',
        'Atlantic/Madeira' => 'Западноевропско време (Мадеира)',
        'Atlantic/Reykjavik' => 'Средно време по Гринич (Рејкјавик)',
        'Atlantic/South_Georgia' => 'Време во Јужна Грузија (Јужна Џорџија)',
        'Atlantic/St_Helena' => 'Средно време по Гринич (Света Елена)',
        'Atlantic/Stanley' => 'Време во Фолкландски Острови (Стенли)',
        'Australia/Adelaide' => 'Време во Централна Австралија (Аделаида)',
        'Australia/Brisbane' => 'Време во Источна Австралија (Бризбејн)',
        'Australia/Broken_Hill' => 'Време во Централна Австралија (Брокен Хил)',
        'Australia/Currie' => 'Време во Источна Австралија (Курие)',
        'Australia/Darwin' => 'Време во Централна Австралија (Дарвин)',
        'Australia/Eucla' => 'Време во Централна и Западна Австралија (Јукла)',
        'Australia/Hobart' => 'Време во Источна Австралија (Хобарт)',
        'Australia/Lindeman' => 'Време во Источна Австралија (Линдеман)',
        'Australia/Lord_Howe' => 'Време во Лорд Хау',
        'Australia/Melbourne' => 'Време во Источна Австралија (Мелбурн)',
        'Australia/Perth' => 'Време во Западна Австралија (Перт)',
        'Australia/Sydney' => 'Време во Источна Австралија (Сиднеј)',
        'CST6CDT' => 'Централно време во Северна Америка',
        'EST5EDT' => 'Источно време во Северна Америка',
        'Etc/GMT' => 'Средно време по Гринич',
        'Etc/UTC' => 'Координирано универзално време',
        'Europe/Amsterdam' => 'Средноевропско време (Амстердам)',
        'Europe/Andorra' => 'Средноевропско време (Андора)',
        'Europe/Astrakhan' => 'Време во Москва (Астрахан)',
        'Europe/Athens' => 'Источноевропско време (Атина)',
        'Europe/Belgrade' => 'Средноевропско време (Белград)',
        'Europe/Berlin' => 'Средноевропско време (Берлин)',
        'Europe/Bratislava' => 'Средноевропско време (Братислава)',
        'Europe/Brussels' => 'Средноевропско време (Брисел)',
        'Europe/Bucharest' => 'Источноевропско време (Букурешт)',
        'Europe/Budapest' => 'Средноевропско време (Будимпешта)',
        'Europe/Busingen' => 'Средноевропско време (Бизинген)',
        'Europe/Chisinau' => 'Источноевропско време (Кишинау)',
        'Europe/Copenhagen' => 'Средноевропско време (Копенхаген)',
        'Europe/Dublin' => 'Средно време по Гринич (Даблин)',
        'Europe/Gibraltar' => 'Средноевропско време (Гибралтар)',
        'Europe/Guernsey' => 'Средно време по Гринич (Гернзи)',
        'Europe/Helsinki' => 'Источноевропско време (Хелсинки)',
        'Europe/Isle_of_Man' => 'Средно време по Гринич (Остров Ман)',
        'Europe/Istanbul' => 'Време во Турција (Истанбул)',
        'Europe/Jersey' => 'Средно време по Гринич (Џерзи)',
        'Europe/Kaliningrad' => 'Источноевропско време (Калининград)',
        'Europe/Kiev' => 'Источноевропско време (Киев)',
        'Europe/Kirov' => 'Време во Русија (Киров)',
        'Europe/Lisbon' => 'Западноевропско време (Лисабон)',
        'Europe/Ljubljana' => 'Средноевропско време (Љубљана)',
        'Europe/London' => 'Средно време по Гринич (Лондон)',
        'Europe/Luxembourg' => 'Средноевропско време (Луксембург)',
        'Europe/Madrid' => 'Средноевропско време (Мадрид)',
        'Europe/Malta' => 'Средноевропско време (Малта)',
        'Europe/Mariehamn' => 'Источноевропско време (Маријехамен)',
        'Europe/Minsk' => 'Време во Москва (Минск)',
        'Europe/Monaco' => 'Средноевропско време (Монако)',
        'Europe/Moscow' => 'Време во Москва',
        'Europe/Oslo' => 'Средноевропско време (Осло)',
        'Europe/Paris' => 'Средноевропско време (Париз)',
        'Europe/Podgorica' => 'Средноевропско време (Подгорица)',
        'Europe/Prague' => 'Средноевропско време (Прага)',
        'Europe/Riga' => 'Источноевропско време (Рига)',
        'Europe/Rome' => 'Средноевропско време (Рим)',
        'Europe/Samara' => 'Самара време',
        'Europe/San_Marino' => 'Средноевропско време (Сан Марино)',
        'Europe/Sarajevo' => 'Средноевропско време (Сараево)',
        'Europe/Saratov' => 'Време во Москва (Саратов)',
        'Europe/Simferopol' => 'Време во Москва (Симферопол)',
        'Europe/Skopje' => 'Средноевропско време (Скопје)',
        'Europe/Sofia' => 'Источноевропско време (Софија)',
        'Europe/Stockholm' => 'Средноевропско време (Стокхолм)',
        'Europe/Tallinn' => 'Источноевропско време (Талин)',
        'Europe/Tirane' => 'Средноевропско време (Тирана)',
        'Europe/Ulyanovsk' => 'Време во Москва (Улјановск)',
        'Europe/Uzhgorod' => 'Источноевропско време (Ужгород)',
        'Europe/Vaduz' => 'Средноевропско време (Вадуц)',
        'Europe/Vatican' => 'Средноевропско време (Ватикан)',
        'Europe/Vienna' => 'Средноевропско време (Виена)',
        'Europe/Vilnius' => 'Источноевропско време (Вилнус)',
        'Europe/Volgograd' => 'Време во Волгоград',
        'Europe/Warsaw' => 'Средноевропско време (Варшава)',
        'Europe/Zagreb' => 'Средноевропско време (Загреб)',
        'Europe/Zaporozhye' => 'Источноевропско време (Запорожје)',
        'Europe/Zurich' => 'Средноевропско време (Цирих)',
        'Indian/Antananarivo' => 'Источноафриканско време (Антананариво)',
        'Indian/Chagos' => 'Време во Индиски океан (Чагос)',
        'Indian/Christmas' => 'Време во Божиќен Остров',
        'Indian/Cocos' => 'Време во Кокосови Острови',
        'Indian/Comoro' => 'Источноафриканско време (Комори)',
        'Indian/Kerguelen' => 'Француско јужно и антарктичко време (Кергелен)',
        'Indian/Mahe' => 'Време во Сејшели (Махе)',
        'Indian/Maldives' => 'Време во Малдиви',
        'Indian/Mauritius' => 'Време во Маврициус',
        'Indian/Mayotte' => 'Источноафриканско време (Мајот)',
        'Indian/Reunion' => 'Време во Рејунион',
        'MST7MDT' => 'Планинско време во Северна Америка',
        'PST8PDT' => 'Пацифичко време во Северна Америка',
        'Pacific/Apia' => 'Време во Апија',
        'Pacific/Auckland' => 'Време во Нов Зеланд (Окленд)',
        'Pacific/Bougainville' => 'Време во Папуа Нова Гвинеја (Буганвил)',
        'Pacific/Chatham' => 'Време во Чатам',
        'Pacific/Easter' => 'Време во Велигденски Остров',
        'Pacific/Efate' => 'Време во Вануату (Ефате)',
        'Pacific/Enderbury' => 'Време во Островите Феникс (Ендербери)',
        'Pacific/Fakaofo' => 'Време во Токелау (Факаофо)',
        'Pacific/Fiji' => 'Време во Фиџи',
        'Pacific/Funafuti' => 'Време во Тувалу (Фунафути)',
        'Pacific/Galapagos' => 'Време во Галапагос',
        'Pacific/Gambier' => 'Време во Гамбе (Гамбије)',
        'Pacific/Guadalcanal' => 'Време во Соломонски Острови (Гвадалканал)',
        'Pacific/Guam' => 'Време во Чаморо (Гвам)',
        'Pacific/Honolulu' => 'Време во Хаваи - Алеутски острови (Хонолулу)',
        'Pacific/Johnston' => 'Време во Хаваи - Алеутски острови (Џонстон)',
        'Pacific/Kiritimati' => 'Време во Линиски Острови (Киритимати)',
        'Pacific/Kosrae' => 'Време во Косра (Косрае)',
        'Pacific/Kwajalein' => 'Време во Маршалски Острови (Кваџалејн)',
        'Pacific/Majuro' => 'Време во Маршалски Острови (Маџуро)',
        'Pacific/Marquesas' => 'Време во Маркесас (Маркески Острови)',
        'Pacific/Midway' => 'Време во Самоа (Мидвеј)',
        'Pacific/Nauru' => 'Време во Науру',
        'Pacific/Niue' => 'Време во Ниуе',
        'Pacific/Norfolk' => 'Време во Норфолшки Остров (Норфолк)',
        'Pacific/Noumea' => 'Време во Нова Каледонија (Нумеа)',
        'Pacific/Pago_Pago' => 'Време во Самоа (Паго Паго)',
        'Pacific/Palau' => 'Време во Палау',
        'Pacific/Pitcairn' => 'Време во Питкерн (Питкернски Острови)',
        'Pacific/Ponape' => 'Време во Понапе (Понпеј)',
        'Pacific/Port_Moresby' => 'Време во Папуа Нова Гвинеја (Порт Морсби)',
        'Pacific/Rarotonga' => 'Време во Кукови Острови (Раротонга)',
        'Pacific/Saipan' => 'Време во Чаморо (Сајпан)',
        'Pacific/Tahiti' => 'Време во Тахити',
        'Pacific/Tarawa' => 'Време во Гилбертови Острови (Тарава)',
        'Pacific/Tongatapu' => 'Време во Тонга (Тонгатапу)',
        'Pacific/Truk' => 'Време во Чуук (Чук)',
        'Pacific/Wake' => 'Време во Островот Вејк',
        'Pacific/Wallis' => 'Време во Валис и Футуна',
    ],
    'Meta' => [
    ],
];
