<?php

return [
    'Names' => [
        'be_BY' => 'biélorusse (Bélarus)',
        'en_CC' => 'anglais (îles Cocos [Keeling])',
        'en_CK' => 'anglais (îles Cook)',
        'en_CX' => 'anglais (île Christmas)',
        'en_FK' => 'anglais (îles Malouines)',
        'en_IM' => 'anglais (île de Man)',
        'en_IO' => 'anglais (territoire britannique de l’océan Indien)',
        'en_LR' => 'anglais (Libéria)',
        'en_MP' => 'anglais (Mariannes du Nord)',
        'en_NF' => 'anglais (île Norfolk)',
        'en_NG' => 'anglais (Nigéria)',
        'en_PN' => 'anglais (îles Pitcairn)',
        'en_SX' => 'anglais (Saint-Martin [Pays-Bas])',
        'en_UM' => 'anglais (îles mineures éloignées des États-Unis)',
        'en_VG' => 'anglais (îles Vierges britanniques)',
        'en_VI' => 'anglais (îles Vierges américaines)',
        'ff_Adlm_LR' => 'peul (adlam, Libéria)',
        'ff_Adlm_NG' => 'peul (adlam, Nigéria)',
        'ff_Latn_LR' => 'peul (latin, Libéria)',
        'ff_Latn_NG' => 'peul (latin, Nigéria)',
        'fo_FO' => 'féroïen (îles Féroé)',
        'fr_MF' => 'français (Saint-Martin [France])',
        'fr_RE' => 'français (la Réunion)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (Inde)',
        'gv_IM' => 'mannois (île de Man)',
        'ha_NG' => 'haoussa (Nigéria)',
        'ig_NG' => 'igbo (Nigéria)',
        'ii' => 'yi de Sichuan',
        'ii_CN' => 'yi de Sichuan (Chine)',
        'it_VA' => 'italien (Cité du Vatican)',
        'kl' => 'kalaallisut',
        'kl_GL' => 'kalaallisut (Groenland)',
        'ks' => 'kashmiri',
        'ks_Arab' => 'kashmiri (arabe)',
        'ks_Arab_IN' => 'kashmiri (arabe, Inde)',
        'ks_Deva' => 'kashmiri (devanagari)',
        'ks_Deva_IN' => 'kashmiri (devanagari, Inde)',
        'ks_IN' => 'kashmiri (Inde)',
        'ky_KG' => 'kirghize (Kirghizistan)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Congo-Kinshasa)',
        'mr' => 'marathe',
        'mr_IN' => 'marathe (Inde)',
        'my_MM' => 'birman (Myanmar)',
        'nl_SX' => 'néerlandais (Saint-Martin [Pays-Bas])',
        'pt_TL' => 'portugais (Timor-Leste)',
        'ru_BY' => 'russe (Bélarus)',
        'ru_KG' => 'russe (Kirghizistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, Inde)',
        'sv_AX' => 'suédois (îles d’Åland)',
        'vi_VN' => 'vietnamien (Vietnam)',
        'yo_NG' => 'yoruba (Nigéria)',
        'zh_Hans' => 'chinois (idéogrammes han simplifiés)',
        'zh_Hans_CN' => 'chinois (idéogrammes han simplifiés, Chine)',
        'zh_Hans_HK' => 'chinois (idéogrammes han simplifiés, R.A.S. chinoise de Hong Kong)',
        'zh_Hans_MO' => 'chinois (idéogrammes han simplifiés, R.A.S. chinoise de Macao)',
        'zh_Hans_SG' => 'chinois (idéogrammes han simplifiés, Singapour)',
        'zh_Hant' => 'chinois (idéogrammes han traditionnels)',
        'zh_Hant_HK' => 'chinois (idéogrammes han traditionnels, R.A.S. chinoise de Hong Kong)',
        'zh_Hant_MO' => 'chinois (idéogrammes han traditionnels, R.A.S. chinoise de Macao)',
        'zh_Hant_TW' => 'chinois (idéogrammes han traditionnels, Taïwan)',
    ],
];
