<?php

return [
    'Names' => [
        'Arab' => 'Арабӣ',
        'Cyrl' => 'Кириллӣ',
        'Hans' => 'Осонфаҳм',
        'Hant' => 'Анъанавӣ',
        'Latn' => 'Лотинӣ',
        'Zxxx' => 'Нонавишта',
    ],
];
