<?php

return [
    'Names' => [
        'af' => 'Afreeki',
        'af_NA' => 'Afreeki (नामीबिया)',
        'af_ZA' => 'Afreeki (दक्षिण अफ़्रीका)',
        'bn' => 'Bangla',
        'bn_BD' => 'Bangla (बांग्लादेश)',
        'bn_IN' => 'Bangla (भारत)',
        'bo' => 'Tibbati',
        'bo_CN' => 'Tibbati (चीन)',
        'bo_IN' => 'Tibbati (भारत)',
        'en_KN' => 'अंग्रेज़ी (St. Kitts & Nevis)',
        'en_LC' => 'अंग्रेज़ी (St. Lucia)',
        'en_SH' => 'अंग्रेज़ी (St. Helena)',
        'en_UM' => 'अंग्रेज़ी (U.S. Outlying Islands)',
        'en_VC' => 'अंग्रेज़ी (St. Vincent & Grenadines)',
        'en_VI' => 'अंग्रेज़ी (U.S. Virgin Islands)',
        'fa' => 'Faarsi',
        'fa_AF' => 'Faarsi (अफ़गानिस्तान)',
        'fa_IR' => 'Faarsi (ईरान)',
        'ff' => 'Fulah',
        'ff_Adlm' => 'Fulah (ऐडलम)',
        'ff_Adlm_BF' => 'Fulah (ऐडलम, बुर्किना फ़ासो)',
        'ff_Adlm_CM' => 'Fulah (ऐडलम, कैमरून)',
        'ff_Adlm_GH' => 'Fulah (ऐडलम, घाना)',
        'ff_Adlm_GM' => 'Fulah (ऐडलम, गाम्बिया)',
        'ff_Adlm_GN' => 'Fulah (ऐडलम, गिनी)',
        'ff_Adlm_GW' => 'Fulah (ऐडलम, गिनी-बिसाउ)',
        'ff_Adlm_LR' => 'Fulah (ऐडलम, लाइबेरिया)',
        'ff_Adlm_MR' => 'Fulah (ऐडलम, मॉरिटानिया)',
        'ff_Adlm_NE' => 'Fulah (ऐडलम, नाइजर)',
        'ff_Adlm_NG' => 'Fulah (ऐडलम, नाइजीरिया)',
        'ff_Adlm_SL' => 'Fulah (ऐडलम, सिएरा लियोन)',
        'ff_Adlm_SN' => 'Fulah (ऐडलम, सेनेगल)',
        'ff_CM' => 'Fulah (कैमरून)',
        'ff_GN' => 'Fulah (गिनी)',
        'ff_Latn' => 'Fulah (लैटिन)',
        'ff_Latn_BF' => 'Fulah (लैटिन, बुर्किना फ़ासो)',
        'ff_Latn_CM' => 'Fulah (लैटिन, कैमरून)',
        'ff_Latn_GH' => 'Fulah (लैटिन, घाना)',
        'ff_Latn_GM' => 'Fulah (लैटिन, गाम्बिया)',
        'ff_Latn_GN' => 'Fulah (लैटिन, गिनी)',
        'ff_Latn_GW' => 'Fulah (लैटिन, गिनी-बिसाउ)',
        'ff_Latn_LR' => 'Fulah (लैटिन, लाइबेरिया)',
        'ff_Latn_MR' => 'Fulah (लैटिन, मॉरिटानिया)',
        'ff_Latn_NE' => 'Fulah (लैटिन, नाइजर)',
        'ff_Latn_NG' => 'Fulah (लैटिन, नाइजीरिया)',
        'ff_Latn_SL' => 'Fulah (लैटिन, सिएरा लियोन)',
        'ff_Latn_SN' => 'Fulah (लैटिन, सेनेगल)',
        'ff_MR' => 'Fulah (मॉरिटानिया)',
        'ff_SN' => 'Fulah (सेनेगल)',
        'fr_BL' => 'फ़्रेंच (St. Barthelemy)',
        'fr_CI' => 'फ़्रेंच (Cote d’Ivoire)',
        'fr_MF' => 'फ़्रेंच (St. Martin)',
        'fr_PM' => 'फ़्रेंच (St. Pierre & Miquelon)',
        'fr_RE' => 'फ़्रेंच (Reunion)',
        'nb' => 'Norwegian Bokmal',
        'nb_NO' => 'Norwegian Bokmal (नॉर्वे)',
        'nb_SJ' => 'Norwegian Bokmal (स्वालबार्ड और जान मायेन)',
        'nl_CW' => 'डच (Curacao)',
        'pt_ST' => 'पुर्तगाली (Sao Tome & Principe)',
        'sv_AX' => 'स्वीडिश (Aland Islands)',
        'ug' => 'Uighur',
        'ug_CN' => 'Uighur (चीन)',
    ],
];
