<?php

return [
    'Names' => [
        'aa' => 'афарский',
        'ab' => 'абхазский',
        'ace' => 'ачехский',
        'ach' => 'ачоли',
        'ada' => 'адангме',
        'ady' => 'адыгейский',
        'ae' => 'авестийский',
        'af' => 'африкаанс',
        'afh' => 'африхили',
        'agq' => 'агем',
        'ain' => 'айнский',
        'ak' => 'акан',
        'akk' => 'аккадский',
        'ale' => 'алеутский',
        'alt' => 'южноалтайский',
        'am' => 'амхарский',
        'an' => 'арагонский',
        'ang' => 'староанглийский',
        'ann' => 'оболо',
        'anp' => 'ангика',
        'ar' => 'арабский',
        'arc' => 'арамейский',
        'arn' => 'мапуче',
        'arp' => 'арапахо',
        'ars' => 'недждийский арабский',
        'arw' => 'аравакский',
        'as' => 'ассамский',
        'asa' => 'асу',
        'ast' => 'астурийский',
        'atj' => 'атикамек',
        'av' => 'аварский',
        'awa' => 'авадхи',
        'ay' => 'аймара',
        'az' => 'азербайджанский',
        'ba' => 'башкирский',
        'bal' => 'белуджский',
        'ban' => 'балийский',
        'bas' => 'баса',
        'bax' => 'бамум',
        'bbj' => 'гомала',
        'be' => 'белорусский',
        'bej' => 'беджа',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bfd' => 'бафут',
        'bg' => 'болгарский',
        'bgn' => 'западный белуджский',
        'bho' => 'бходжпури',
        'bi' => 'бислама',
        'bik' => 'бикольский',
        'bin' => 'бини',
        'bkm' => 'ком',
        'bla' => 'сиксика',
        'bm' => 'бамбара',
        'bn' => 'бенгальский',
        'bo' => 'тибетский',
        'br' => 'бретонский',
        'bra' => 'брауи',
        'brx' => 'бодо',
        'bs' => 'боснийский',
        'bss' => 'акоосе',
        'bua' => 'бурятский',
        'bug' => 'бугийский',
        'bum' => 'булу',
        'byn' => 'билин',
        'byv' => 'медумба',
        'ca' => 'каталанский',
        'cad' => 'каддо',
        'car' => 'кариб',
        'cay' => 'кайюга',
        'cch' => 'атсам',
        'ccp' => 'чакма',
        'ce' => 'чеченский',
        'ceb' => 'себуано',
        'cgg' => 'кига',
        'ch' => 'чаморро',
        'chb' => 'чибча',
        'chg' => 'чагатайский',
        'chk' => 'чукотский',
        'chm' => 'марийский',
        'chn' => 'чинук жаргон',
        'cho' => 'чоктавский',
        'chp' => 'чипевьян',
        'chr' => 'чероки',
        'chy' => 'шайенский',
        'ckb' => 'центральнокурдский',
        'clc' => 'чилкотин',
        'co' => 'корсиканский',
        'cop' => 'коптский',
        'cr' => 'кри',
        'crg' => 'мичиф',
        'crh' => 'крымско-татарский',
        'crj' => 'юго-восточный кри',
        'crk' => 'равнинный кри',
        'crl' => 'северо-восточный кри',
        'crm' => 'мусский кри',
        'crr' => 'каролинский алгонкинский',
        'crs' => 'сейшельский креольский',
        'cs' => 'чешский',
        'csb' => 'кашубский',
        'csw' => 'болотный кри',
        'cu' => 'церковнославянский',
        'cv' => 'чувашский',
        'cy' => 'валлийский',
        'da' => 'датский',
        'dak' => 'дакота',
        'dar' => 'даргинский',
        'dav' => 'таита',
        'de' => 'немецкий',
        'del' => 'делаварский',
        'den' => 'слейви',
        'dgr' => 'догриб',
        'din' => 'динка',
        'dje' => 'джерма',
        'doi' => 'догри',
        'dsb' => 'нижнелужицкий',
        'dua' => 'дуала',
        'dum' => 'средненидерландский',
        'dv' => 'мальдивский',
        'dyo' => 'диола-фоньи',
        'dyu' => 'диула',
        'dz' => 'дзонг-кэ',
        'dzg' => 'даза',
        'ebu' => 'эмбу',
        'ee' => 'эве',
        'efi' => 'эфик',
        'egy' => 'древнеегипетский',
        'eka' => 'экаджук',
        'el' => 'греческий',
        'elx' => 'эламский',
        'en' => 'английский',
        'enm' => 'среднеанглийский',
        'eo' => 'эсперанто',
        'es' => 'испанский',
        'et' => 'эстонский',
        'eu' => 'баскский',
        'ewo' => 'эвондо',
        'fa' => 'персидский',
        'fan' => 'фанг',
        'fat' => 'фанти',
        'ff' => 'фулах',
        'fi' => 'финский',
        'fil' => 'филиппинский',
        'fj' => 'фиджи',
        'fo' => 'фарерский',
        'fon' => 'фон',
        'fr' => 'французский',
        'frc' => 'каджунский французский',
        'frm' => 'среднефранцузский',
        'fro' => 'старофранцузский',
        'frr' => 'северный фризский',
        'frs' => 'восточный фризский',
        'fur' => 'фриульский',
        'fy' => 'западнофризский',
        'ga' => 'ирландский',
        'gaa' => 'га',
        'gag' => 'гагаузский',
        'gan' => 'гань',
        'gay' => 'гайо',
        'gba' => 'гбая',
        'gd' => 'гэльский',
        'gez' => 'геэз',
        'gil' => 'гилбертский',
        'gl' => 'галисийский',
        'gmh' => 'средневерхненемецкий',
        'gn' => 'гуарани',
        'goh' => 'древневерхненемецкий',
        'gon' => 'гонди',
        'gor' => 'горонтало',
        'got' => 'готский',
        'grb' => 'гребо',
        'grc' => 'древнегреческий',
        'gsw' => 'швейцарский немецкий',
        'gu' => 'гуджарати',
        'guz' => 'гусии',
        'gv' => 'мэнский',
        'gwi' => 'гвичин',
        'ha' => 'хауса',
        'hai' => 'хайда',
        'hak' => 'хакка',
        'haw' => 'гавайский',
        'hax' => 'южный хайда',
        'he' => 'иврит',
        'hi' => 'хинди',
        'hil' => 'хилигайнон',
        'hit' => 'хеттский',
        'hmn' => 'хмонг',
        'ho' => 'хиримоту',
        'hr' => 'хорватский',
        'hsb' => 'верхнелужицкий',
        'hsn' => 'сян',
        'ht' => 'гаитянский',
        'hu' => 'венгерский',
        'hup' => 'хупа',
        'hur' => 'халкомелем',
        'hy' => 'армянский',
        'hz' => 'гереро',
        'ia' => 'интерлингва',
        'iba' => 'ибанский',
        'ibb' => 'ибибио',
        'id' => 'индонезийский',
        'ie' => 'интерлингве',
        'ig' => 'игбо',
        'ii' => 'носу',
        'ik' => 'инупиак',
        'ikt' => 'восточноканадский инуктитут',
        'ilo' => 'илоко',
        'inh' => 'ингушский',
        'io' => 'идо',
        'is' => 'исландский',
        'it' => 'итальянский',
        'iu' => 'инуктитут',
        'ja' => 'японский',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме',
        'jpr' => 'еврейско-персидский',
        'jrb' => 'еврейско-арабский',
        'jv' => 'яванский',
        'ka' => 'грузинский',
        'kaa' => 'каракалпакский',
        'kab' => 'кабильский',
        'kac' => 'качинский',
        'kaj' => 'каджи',
        'kam' => 'камба',
        'kaw' => 'кави',
        'kbd' => 'кабардинский',
        'kbl' => 'канембу',
        'kcg' => 'тьяп',
        'kde' => 'маконде',
        'kea' => 'кабувердьяну',
        'kfo' => 'коро',
        'kg' => 'конго',
        'kgp' => 'каинганг',
        'kha' => 'кхаси',
        'kho' => 'хотанский',
        'khq' => 'койра чиини',
        'ki' => 'кикуйю',
        'kj' => 'кунама',
        'kk' => 'казахский',
        'kkj' => 'како',
        'kl' => 'гренландский',
        'kln' => 'календжин',
        'km' => 'кхмерский',
        'kmb' => 'кимбунду',
        'kn' => 'каннада',
        'ko' => 'корейский',
        'koi' => 'коми-пермяцкий',
        'kok' => 'конкани',
        'kos' => 'косраенский',
        'kpe' => 'кпелле',
        'kr' => 'канури',
        'krc' => 'карачаево-балкарский',
        'krl' => 'карельский',
        'kru' => 'курух',
        'ks' => 'кашмири',
        'ksb' => 'шамбала',
        'ksf' => 'бафия',
        'ksh' => 'кёльнский',
        'ku' => 'курдский',
        'kum' => 'кумыкский',
        'kut' => 'кутенаи',
        'kv' => 'коми',
        'kw' => 'корнский',
        'kwk' => 'квакиутль',
        'ky' => 'киргизский',
        'la' => 'латинский',
        'lad' => 'ладино',
        'lag' => 'ланго',
        'lah' => 'лахнда',
        'lam' => 'ламба',
        'lb' => 'люксембургский',
        'lez' => 'лезгинский',
        'lg' => 'ганда',
        'li' => 'лимбургский',
        'lil' => 'лиллуэт',
        'lkt' => 'лакота',
        'ln' => 'лингала',
        'lo' => 'лаосский',
        'lol' => 'монго',
        'lou' => 'луизианский креольский',
        'loz' => 'лози',
        'lrc' => 'севернолурский',
        'lsm' => 'саамиа',
        'lt' => 'литовский',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lui' => 'луисеньо',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'мизо',
        'luy' => 'лухья',
        'lv' => 'латышский',
        'mad' => 'мадурский',
        'maf' => 'мафа',
        'mag' => 'магахи',
        'mai' => 'майтхили',
        'mak' => 'макассарский',
        'man' => 'мандинго',
        'mas' => 'масаи',
        'mde' => 'маба',
        'mdf' => 'мокшанский',
        'mdr' => 'мандарский',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'маврикийский креольский',
        'mg' => 'малагасийский',
        'mga' => 'среднеирландский',
        'mgh' => 'макуа-меетто',
        'mgo' => 'мета',
        'mh' => 'маршалльский',
        'mi' => 'маори',
        'mic' => 'микмак',
        'min' => 'минангкабау',
        'mk' => 'македонский',
        'ml' => 'малаялам',
        'mn' => 'монгольский',
        'mnc' => 'маньчжурский',
        'mni' => 'манипурский',
        'moe' => 'инну-аймун',
        'moh' => 'мохаук',
        'mos' => 'моси',
        'mr' => 'маратхи',
        'ms' => 'малайский',
        'mt' => 'мальтийский',
        'mua' => 'мунданг',
        'mus' => 'крик',
        'mwl' => 'мирандский',
        'mwr' => 'марвари',
        'my' => 'бирманский',
        'mye' => 'миене',
        'myv' => 'эрзянский',
        'mzn' => 'мазандеранский',
        'na' => 'науру',
        'nan' => 'миньнань',
        'nap' => 'неаполитанский',
        'naq' => 'нама',
        'nb' => 'норвежский букмол',
        'nd' => 'северный ндебеле',
        'nds' => 'нижненемецкий',
        'ne' => 'непальский',
        'new' => 'неварский',
        'ng' => 'ндонга',
        'nia' => 'ниас',
        'niu' => 'ниуэ',
        'nl' => 'нидерландский',
        'nmg' => 'квасио',
        'nn' => 'нюнорск',
        'nnh' => 'нгиембунд',
        'no' => 'норвежский',
        'nog' => 'ногайский',
        'non' => 'старонорвежский',
        'nqo' => 'нко',
        'nr' => 'южный ндебеле',
        'nso' => 'северный сото',
        'nus' => 'нуэр',
        'nv' => 'навахо',
        'nwc' => 'классический невари',
        'ny' => 'ньянджа',
        'nym' => 'ньямвези',
        'nyn' => 'ньянколе',
        'nyo' => 'ньоро',
        'nzi' => 'нзима',
        'oc' => 'окситанский',
        'oj' => 'оджибва',
        'ojb' => 'северо-западный оджибве',
        'ojc' => 'центральный оджибве',
        'ojs' => 'оджи-кри',
        'ojw' => 'западный оджибве',
        'oka' => 'оканаган',
        'om' => 'оромо',
        'or' => 'ория',
        'os' => 'осетинский',
        'osa' => 'оседжи',
        'ota' => 'старотурецкий',
        'pa' => 'панджаби',
        'pag' => 'пангасинан',
        'pal' => 'пехлевийский',
        'pam' => 'пампанга',
        'pap' => 'папьяменто',
        'pau' => 'палау',
        'pcm' => 'нигерийско-креольский',
        'peo' => 'староперсидский',
        'phn' => 'финикийский',
        'pi' => 'пали',
        'pis' => 'соломонский пиджин',
        'pl' => 'польский',
        'pon' => 'понапе',
        'pqm' => 'малесит-пассамакводди',
        'prg' => 'прусский',
        'pro' => 'старопровансальский',
        'ps' => 'пушту',
        'pt' => 'португальский',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'raj' => 'раджастхани',
        'rap' => 'рапануйский',
        'rar' => 'раротонга',
        'rhg' => 'рохинджа',
        'rm' => 'романшский',
        'rn' => 'рунди',
        'ro' => 'румынский',
        'rof' => 'ромбо',
        'rom' => 'цыганский',
        'ru' => 'русский',
        'rup' => 'арумынский',
        'rw' => 'киньяруанда',
        'rwk' => 'руанда',
        'sa' => 'санскрит',
        'sad' => 'сандаве',
        'sah' => 'саха',
        'sam' => 'самаритянский арамейский',
        'saq' => 'самбуру',
        'sas' => 'сасакский',
        'sat' => 'сантали',
        'sba' => 'нгамбайский',
        'sbp' => 'сангу',
        'sc' => 'сардинский',
        'scn' => 'сицилийский',
        'sco' => 'шотландский',
        'sd' => 'синдхи',
        'sdh' => 'южнокурдский',
        'se' => 'северносаамский',
        'see' => 'сенека',
        'seh' => 'сена',
        'sel' => 'селькупский',
        'ses' => 'койраборо сенни',
        'sg' => 'санго',
        'sga' => 'староирландский',
        'sh' => 'сербскохорватский',
        'shi' => 'ташельхит',
        'shn' => 'шанский',
        'shu' => 'чадский арабский',
        'si' => 'сингальский',
        'sid' => 'сидама',
        'sk' => 'словацкий',
        'sl' => 'словенский',
        'slh' => 'южный лушуцид',
        'sm' => 'самоанский',
        'sma' => 'южносаамский',
        'smj' => 'луле-саамский',
        'smn' => 'инари-саамский',
        'sms' => 'колтта-саамский',
        'sn' => 'шона',
        'snk' => 'сонинке',
        'so' => 'сомали',
        'sog' => 'согдийский',
        'sq' => 'албанский',
        'sr' => 'сербский',
        'srn' => 'сранан-тонго',
        'srr' => 'серер',
        'ss' => 'свази',
        'ssy' => 'сахо',
        'st' => 'южный сото',
        'str' => 'стрейтс салиш',
        'su' => 'сунданский',
        'suk' => 'сукума',
        'sus' => 'сусу',
        'sux' => 'шумерский',
        'sv' => 'шведский',
        'sw' => 'суахили',
        'swb' => 'коморский',
        'syc' => 'классический сирийский',
        'syr' => 'сирийский',
        'ta' => 'тамильский',
        'tce' => 'южный тутчоне',
        'te' => 'телугу',
        'tem' => 'темне',
        'teo' => 'тесо',
        'ter' => 'терено',
        'tet' => 'тетум',
        'tg' => 'таджикский',
        'tgx' => 'тагиш',
        'th' => 'тайский',
        'tht' => 'талтан',
        'ti' => 'тигринья',
        'tig' => 'тигре',
        'tiv' => 'тиви',
        'tk' => 'туркменский',
        'tkl' => 'токелайский',
        'tl' => 'тагалог',
        'tlh' => 'клингонский',
        'tli' => 'тлингит',
        'tmh' => 'тамашек',
        'tn' => 'тсвана',
        'to' => 'тонганский',
        'tog' => 'тонга',
        'tok' => 'токипона',
        'tpi' => 'ток-писин',
        'tr' => 'турецкий',
        'tru' => 'туройо',
        'trv' => 'седекский',
        'ts' => 'тсонга',
        'tsi' => 'цимшиан',
        'tt' => 'татарский',
        'ttm' => 'северный тутчоне',
        'tum' => 'тумбука',
        'tvl' => 'тувалу',
        'tw' => 'тви',
        'twq' => 'тасавак',
        'ty' => 'таитянский',
        'tyv' => 'тувинский',
        'tzm' => 'среднеатласский тамазигхтский',
        'udm' => 'удмуртский',
        'ug' => 'уйгурский',
        'uga' => 'угаритский',
        'uk' => 'украинский',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбекский',
        'vai' => 'ваи',
        've' => 'венда',
        'vi' => 'вьетнамский',
        'vo' => 'волапюк',
        'vot' => 'водский',
        'vun' => 'вунджо',
        'wa' => 'валлонский',
        'wae' => 'валлисский',
        'wal' => 'воламо',
        'war' => 'варай',
        'was' => 'вашо',
        'wbp' => 'вальбири',
        'wo' => 'волоф',
        'wuu' => 'у',
        'xal' => 'калмыцкий',
        'xh' => 'коса',
        'xog' => 'сога',
        'yao' => 'яо',
        'yap' => 'яп',
        'yav' => 'янгбен',
        'ybb' => 'йемба',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'yrl' => 'ньенгату',
        'yue' => 'кантонский',
        'za' => 'чжуань',
        'zap' => 'сапотекский',
        'zbl' => 'блиссимволика',
        'zen' => 'зенагский',
        'zgh' => 'тамазигхтский',
        'zh' => 'китайский',
        'zu' => 'зулу',
        'zun' => 'зуньи',
        'zza' => 'заза',
    ],
    'LocalizedNames' => [
        'ar_001' => 'арабский литературный',
        'de_AT' => 'австрийский немецкий',
        'de_CH' => 'литературный швейцарский немецкий',
        'en_AU' => 'австралийский английский',
        'en_CA' => 'канадский английский',
        'en_GB' => 'британский английский',
        'en_US' => 'американский английский',
        'es_419' => 'латиноамериканский испанский',
        'es_ES' => 'европейский испанский',
        'es_MX' => 'мексиканский испанский',
        'fa_AF' => 'дари',
        'fr_CA' => 'канадский французский',
        'fr_CH' => 'швейцарский французский',
        'nds_NL' => 'нижнесаксонский',
        'nl_BE' => 'фламандский',
        'pt_BR' => 'бразильский португальский',
        'pt_PT' => 'европейский португальский',
        'ro_MD' => 'молдавский',
        'sw_CD' => 'конголезский суахили',
        'zh_Hans' => 'китайский, упрощенное письмо',
        'zh_Hant' => 'китайский, традиционное письмо',
    ],
];
