<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'கிரீன்விச் சராசரி நேரம் (அபிட்ஜான்)',
        'Africa/Accra' => 'கிரீன்விச் சராசரி நேரம் (அக்ரா)',
        'Africa/Addis_Ababa' => 'கிழக்கு ஆப்பிரிக்க நேரம் (அடிஸ் அபாபா)',
        'Africa/Algiers' => 'மத்திய ஐரோப்பிய நேரம் (அல்ஜியர்ஸ்)',
        'Africa/Asmera' => 'கிழக்கு ஆப்பிரிக்க நேரம் (அஸ்மாரா)',
        'Africa/Bamako' => 'கிரீன்விச் சராசரி நேரம் (பமாகோ)',
        'Africa/Bangui' => 'மேற்கு ஆப்பிரிக்க நேரம் (பாங்குயீ)',
        'Africa/Banjul' => 'கிரீன்விச் சராசரி நேரம் (பஞ்சுல்)',
        'Africa/Bissau' => 'கிரீன்விச் சராசரி நேரம் (பிஸாவ்)',
        'Africa/Blantyre' => 'மத்திய ஆப்பிரிக்க நேரம் (பிளான்டையர்)',
        'Africa/Brazzaville' => 'மேற்கு ஆப்பிரிக்க நேரம் (பிராஸாவில்லி)',
        'Africa/Bujumbura' => 'மத்திய ஆப்பிரிக்க நேரம் (புஜும்புரா)',
        'Africa/Cairo' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (கெய்ரோ)',
        'Africa/Casablanca' => 'மேற்கத்திய ஐரோப்பிய நேரம் (காஸாபிளான்கா)',
        'Africa/Ceuta' => 'மத்திய ஐரோப்பிய நேரம் (சியூட்டா)',
        'Africa/Conakry' => 'கிரீன்விச் சராசரி நேரம் (கோனக்ரே)',
        'Africa/Dakar' => 'கிரீன்விச் சராசரி நேரம் (டாகர்)',
        'Africa/Dar_es_Salaam' => 'கிழக்கு ஆப்பிரிக்க நேரம் (தார் எஸ் சலாம்)',
        'Africa/Djibouti' => 'கிழக்கு ஆப்பிரிக்க நேரம் (ஜிபௌட்டி)',
        'Africa/Douala' => 'மேற்கு ஆப்பிரிக்க நேரம் (தவுலா)',
        'Africa/El_Aaiun' => 'மேற்கத்திய ஐரோப்பிய நேரம் (எல் ஆயுன்)',
        'Africa/Freetown' => 'கிரீன்விச் சராசரி நேரம் (ஃப்ரீடவுன்)',
        'Africa/Gaborone' => 'மத்திய ஆப்பிரிக்க நேரம் (கபோரோன்)',
        'Africa/Harare' => 'மத்திய ஆப்பிரிக்க நேரம் (ஹராரே)',
        'Africa/Johannesburg' => 'தென் ஆப்பிரிக்க நிலையான நேரம் (ஜோஹன்னஸ்பெர்க்)',
        'Africa/Juba' => 'மத்திய ஆப்பிரிக்க நேரம் (ஜுபா)',
        'Africa/Kampala' => 'கிழக்கு ஆப்பிரிக்க நேரம் (கம்பாலா)',
        'Africa/Khartoum' => 'மத்திய ஆப்பிரிக்க நேரம் (கார்டோம்)',
        'Africa/Kigali' => 'மத்திய ஆப்பிரிக்க நேரம் (கிகலி)',
        'Africa/Kinshasa' => 'மேற்கு ஆப்பிரிக்க நேரம் (கின்ஷசா)',
        'Africa/Lagos' => 'மேற்கு ஆப்பிரிக்க நேரம் (லாகோஸ்)',
        'Africa/Libreville' => 'மேற்கு ஆப்பிரிக்க நேரம் (லிப்ரேவில்லே)',
        'Africa/Lome' => 'கிரீன்விச் சராசரி நேரம் (லோம்)',
        'Africa/Luanda' => 'மேற்கு ஆப்பிரிக்க நேரம் (லுவான்டா)',
        'Africa/Lubumbashi' => 'மத்திய ஆப்பிரிக்க நேரம் (லுபும்பாஷி)',
        'Africa/Lusaka' => 'மத்திய ஆப்பிரிக்க நேரம் (லுசாகா)',
        'Africa/Malabo' => 'மேற்கு ஆப்பிரிக்க நேரம் (மாலபோ)',
        'Africa/Maputo' => 'மத்திய ஆப்பிரிக்க நேரம் (மபுடோ)',
        'Africa/Maseru' => 'தென் ஆப்பிரிக்க நிலையான நேரம் (மசேரு)',
        'Africa/Mbabane' => 'தென் ஆப்பிரிக்க நிலையான நேரம் (பபான்)',
        'Africa/Mogadishu' => 'கிழக்கு ஆப்பிரிக்க நேரம் (மொகாதிஷு)',
        'Africa/Monrovia' => 'கிரீன்விச் சராசரி நேரம் (மான்ரோவியா)',
        'Africa/Nairobi' => 'கிழக்கு ஆப்பிரிக்க நேரம் (நைரோபி)',
        'Africa/Ndjamena' => 'மேற்கு ஆப்பிரிக்க நேரம் (ஜமேனா)',
        'Africa/Niamey' => 'மேற்கு ஆப்பிரிக்க நேரம் (நியாமே)',
        'Africa/Nouakchott' => 'கிரீன்விச் சராசரி நேரம் (நோவாக்சோட்)',
        'Africa/Ouagadougou' => 'கிரீன்விச் சராசரி நேரம் (அவுகடவ்கு)',
        'Africa/Porto-Novo' => 'மேற்கு ஆப்பிரிக்க நேரம் (போர்ட்டோ-நோவோ)',
        'Africa/Sao_Tome' => 'கிரீன்விச் சராசரி நேரம் (சாவோ டோமே)',
        'Africa/Tripoli' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (த்ரிபோலி)',
        'Africa/Tunis' => 'மத்திய ஐரோப்பிய நேரம் (டுனிஸ்)',
        'Africa/Windhoek' => 'மத்திய ஆப்பிரிக்க நேரம் (வைண்ட்ஹோக்)',
        'America/Adak' => 'ஹவாய்-அலேஷியன் நேரம் (அடக்)',
        'America/Anchorage' => 'அலாஸ்கா நேரம் (அங்கோரேஜ்)',
        'America/Anguilla' => 'அட்லாண்டிக் நேரம் (அங்குயுலா)',
        'America/Antigua' => 'அட்லாண்டிக் நேரம் (ஆன்டிகுவா)',
        'America/Araguaina' => 'பிரேசிலியா நேரம் (அரகுவாய்னா)',
        'America/Argentina/La_Rioja' => 'அர்ஜென்டினா நேரம் (லா ரியோஜா)',
        'America/Argentina/Rio_Gallegos' => 'அர்ஜென்டினா நேரம் (ரியோ கேலெகோஸ்)',
        'America/Argentina/Salta' => 'அர்ஜென்டினா நேரம் (சால்டா)',
        'America/Argentina/San_Juan' => 'அர்ஜென்டினா நேரம் (சான் ஜுவான்)',
        'America/Argentina/San_Luis' => 'அர்ஜென்டினா நேரம் (சான் லூயிஸ்)',
        'America/Argentina/Tucuman' => 'அர்ஜென்டினா நேரம் (டுகுமன்)',
        'America/Argentina/Ushuaia' => 'அர்ஜென்டினா நேரம் (உஷுவாயா)',
        'America/Aruba' => 'அட்லாண்டிக் நேரம் (அரூபா)',
        'America/Asuncion' => 'பராகுவே நேரம் (அஸன்சியன்)',
        'America/Bahia' => 'பிரேசிலியா நேரம் (பாஹியா)',
        'America/Bahia_Banderas' => 'மத்திய நேரம் (பஹியா பந்தேராஸ்)',
        'America/Barbados' => 'அட்லாண்டிக் நேரம் (பார்படாஸ்)',
        'America/Belem' => 'பிரேசிலியா நேரம் (பெலெம்)',
        'America/Belize' => 'மத்திய நேரம் (பெலிஸ்)',
        'America/Blanc-Sablon' => 'அட்லாண்டிக் நேரம் (ப்லாங்க்-சப்லான்)',
        'America/Boa_Vista' => 'அமேசான் நேரம் (போவா விஸ்டா)',
        'America/Bogota' => 'கொலம்பியா நேரம் (போகோடா)',
        'America/Boise' => 'மவுன்டைன் நேரம் (போய்ஸ்)',
        'America/Buenos_Aires' => 'அர்ஜென்டினா நேரம் (ப்யூனோஸ் ஏர்ஸ்)',
        'America/Cambridge_Bay' => 'மவுன்டைன் நேரம் (கேம்பிரிட்ஜ் வளைகுடா)',
        'America/Campo_Grande' => 'அமேசான் நேரம் (கேம்போ கிராண்டே)',
        'America/Cancun' => 'கிழக்கத்திய நேரம் (கன்குன்)',
        'America/Caracas' => 'வெனிசுலா நேரம் (கரகாஸ்)',
        'America/Catamarca' => 'அர்ஜென்டினா நேரம் (கடமார்கா)',
        'America/Cayenne' => 'ஃபிரஞ்சு கயானா நேரம் (கெய்ன்)',
        'America/Cayman' => 'கிழக்கத்திய நேரம் (கேமன்)',
        'America/Chicago' => 'மத்திய நேரம் (சிகாகோ)',
        'America/Chihuahua' => 'மெக்ஸிகன் பசிபிக் நேரம் (சுவாவா)',
        'America/Coral_Harbour' => 'கிழக்கத்திய நேரம் (அடிகோகன்)',
        'America/Cordoba' => 'அர்ஜென்டினா நேரம் (கார்டோபா)',
        'America/Costa_Rica' => 'மத்திய நேரம் (கோஸ்டா ரிகா)',
        'America/Creston' => 'மவுன்டைன் நேரம் (க்ரெஸ்டான்)',
        'America/Cuiaba' => 'அமேசான் நேரம் (குயாபே)',
        'America/Curacao' => 'அட்லாண்டிக் நேரம் (க்யூராகோ)',
        'America/Danmarkshavn' => 'கிரீன்விச் சராசரி நேரம் (டென்மார்க்ஷாவ்ன்)',
        'America/Dawson' => 'யூகோன் நேரம் (டாவ்சன்)',
        'America/Dawson_Creek' => 'மவுன்டைன் நேரம் (டாவ்சன் கிரீக்)',
        'America/Denver' => 'மவுன்டைன் நேரம் (டென்வர்)',
        'America/Detroit' => 'கிழக்கத்திய நேரம் (டெட்ராய்ட்)',
        'America/Dominica' => 'அட்லாண்டிக் நேரம் (டொமினிகா)',
        'America/Edmonton' => 'மவுன்டைன் நேரம் (எட்மான்டான்)',
        'America/Eirunepe' => 'அக்ரே நேரம் (ஈருனெபே)',
        'America/El_Salvador' => 'மத்திய நேரம் (எல் சால்வடோர்)',
        'America/Fort_Nelson' => 'மவுன்டைன் நேரம் (ஃபோர்ட் நெல்சன்)',
        'America/Fortaleza' => 'பிரேசிலியா நேரம் (ஃபோர்டாலெசா)',
        'America/Glace_Bay' => 'அட்லாண்டிக் நேரம் (கிலேஸ் வளைகுடா)',
        'America/Godthab' => 'மேற்கு கிரீன்லாந்து நேரம் (நூக்)',
        'America/Goose_Bay' => 'அட்லாண்டிக் நேரம் (கூஸ் பே)',
        'America/Grand_Turk' => 'கிழக்கத்திய நேரம் (கிராண்ட் டர்க்)',
        'America/Grenada' => 'அட்லாண்டிக் நேரம் (கிரனடா)',
        'America/Guadeloupe' => 'அட்லாண்டிக் நேரம் (கவுடேலூப்)',
        'America/Guatemala' => 'மத்திய நேரம் (கவுதமாலா)',
        'America/Guayaquil' => 'ஈக்வடார் நேரம் (குவாயகில்)',
        'America/Guyana' => 'கயானா நேரம்',
        'America/Halifax' => 'அட்லாண்டிக் நேரம் (ஹலிஃபேக்ஸ்)',
        'America/Havana' => 'கியூபா நேரம் (ஹவானா)',
        'America/Hermosillo' => 'மெக்ஸிகன் பசிபிக் நேரம் (ஹெர்மோசிலோ)',
        'America/Indiana/Knox' => 'மத்திய நேரம் (நாக்ஸ், இண்டியானா)',
        'America/Indiana/Marengo' => 'கிழக்கத்திய நேரம் (மரென்கோ, இண்டியானா)',
        'America/Indiana/Petersburg' => 'கிழக்கத்திய நேரம் (பீட்டர்ஸ்பெர்க், இண்டியானா)',
        'America/Indiana/Tell_City' => 'மத்திய நேரம் (டெல் சிட்டி, இண்டியானா)',
        'America/Indiana/Vevay' => 'கிழக்கத்திய நேரம் (வேவே, இண்டியானா)',
        'America/Indiana/Vincennes' => 'கிழக்கத்திய நேரம் (வின்செனேஸ், இண்டியானா)',
        'America/Indiana/Winamac' => 'கிழக்கத்திய நேரம் (வினாமேக், இண்டியானா)',
        'America/Indianapolis' => 'கிழக்கத்திய நேரம் (இண்டியானாபொலிஸ்)',
        'America/Inuvik' => 'மவுன்டைன் நேரம் (இனுவிக்)',
        'America/Iqaluit' => 'கிழக்கத்திய நேரம் (இகாலூயித்)',
        'America/Jamaica' => 'கிழக்கத்திய நேரம் (ஜமைக்கா)',
        'America/Jujuy' => 'அர்ஜென்டினா நேரம் (ஜூஜுய்)',
        'America/Juneau' => 'அலாஸ்கா நேரம் (ஜுனியூ)',
        'America/Kentucky/Monticello' => 'கிழக்கத்திய நேரம் (மான்டிசெல்லோ, கென்டகி)',
        'America/Kralendijk' => 'அட்லாண்டிக் நேரம் (கிரெலன்டிஜ்)',
        'America/La_Paz' => 'பொலிவியா நேரம் (லா பாஸ்)',
        'America/Lima' => 'பெரு நேரம் (லிமா)',
        'America/Los_Angeles' => 'பசிபிக் நேரம் (லாஸ் ஏஞ்சல்ஸ்)',
        'America/Louisville' => 'கிழக்கத்திய நேரம் (லூயிஸ்வில்லே)',
        'America/Lower_Princes' => 'அட்லாண்டிக் நேரம் (லோயர் பிரின்ஸஸ் குவார்ட்டர்)',
        'America/Maceio' => 'பிரேசிலியா நேரம் (மேசியோ)',
        'America/Managua' => 'மத்திய நேரம் (மானாகுவா)',
        'America/Manaus' => 'அமேசான் நேரம் (மனாஸ்)',
        'America/Marigot' => 'அட்லாண்டிக் நேரம் (மாரிகாட்)',
        'America/Martinique' => 'அட்லாண்டிக் நேரம் (மார்ட்டினிக்)',
        'America/Matamoros' => 'மத்திய நேரம் (மடமோராஸ்)',
        'America/Mazatlan' => 'மெக்ஸிகன் பசிபிக் நேரம் (மஸட்லன்)',
        'America/Mendoza' => 'அர்ஜென்டினா நேரம் (மென்டோஸா)',
        'America/Menominee' => 'மத்திய நேரம் (மெனோமினி)',
        'America/Merida' => 'மத்திய நேரம் (மெரிடா)',
        'America/Metlakatla' => 'அலாஸ்கா நேரம் (மெட்லகட்லா)',
        'America/Mexico_City' => 'மத்திய நேரம் (மெக்ஸிகோ நகரம்)',
        'America/Miquelon' => 'செயின்ட் பியரி & மிக்குயிலான் நேரம் (மிக்யூலன்)',
        'America/Moncton' => 'அட்லாண்டிக் நேரம் (மாங்டான்)',
        'America/Monterrey' => 'மத்திய நேரம் (மான்டெர்ரே)',
        'America/Montevideo' => 'உருகுவே நேரம் (மான்டேவீடியோ)',
        'America/Montreal' => 'கனடா நேரம் (Montreal)',
        'America/Montserrat' => 'அட்லாண்டிக் நேரம் (மான்செரேட்)',
        'America/Nassau' => 'கிழக்கத்திய நேரம் (நசவ்)',
        'America/New_York' => 'கிழக்கத்திய நேரம் (நியூயார்க்)',
        'America/Nipigon' => 'கிழக்கத்திய நேரம் (நிபிகான்)',
        'America/Nome' => 'அலாஸ்கா நேரம் (நோம்)',
        'America/Noronha' => 'பெர்னாண்டோ டி நோரன்ஹா நேரம்',
        'America/North_Dakota/Beulah' => 'மத்திய நேரம் (பெவுலா, வடக்கு டகோட்டா)',
        'America/North_Dakota/Center' => 'மத்திய நேரம் (சென்டர், வடக்கு டகோடா)',
        'America/North_Dakota/New_Salem' => 'மத்திய நேரம் (நியூ சலேம், வடக்கு டகோடா)',
        'America/Ojinaga' => 'மவுன்டைன் நேரம் (ஒஜினகா)',
        'America/Panama' => 'கிழக்கத்திய நேரம் (பனாமா)',
        'America/Pangnirtung' => 'கிழக்கத்திய நேரம் (பாங்னிர்துங்)',
        'America/Paramaribo' => 'சுரினாம் நேரம் (பரமரிபோ)',
        'America/Phoenix' => 'மவுன்டைன் நேரம் (ஃபோனிக்ஸ்)',
        'America/Port-au-Prince' => 'கிழக்கத்திய நேரம் (போர்ட்-அவ்-பிரின்ஸ்)',
        'America/Port_of_Spain' => 'அட்லாண்டிக் நேரம் (போர்ட் ஆஃப் ஸ்பெயின்)',
        'America/Porto_Velho' => 'அமேசான் நேரம் (போர்ட்டோ வெல்ஹோ)',
        'America/Puerto_Rico' => 'அட்லாண்டிக் நேரம் (பியூர்டோ ரிகோ)',
        'America/Punta_Arenas' => 'சிலி நேரம் (புன்டா அரீனாஸ்)',
        'America/Rainy_River' => 'மத்திய நேரம் (ரெய்னி ரிவர்)',
        'America/Rankin_Inlet' => 'மத்திய நேரம் (ரான்கின் இன்லெட்)',
        'America/Recife' => 'பிரேசிலியா நேரம் (ரெஸிஃபி)',
        'America/Regina' => 'மத்திய நேரம் (ரெஜினா)',
        'America/Resolute' => 'மத்திய நேரம் (ரெசலூட்)',
        'America/Rio_Branco' => 'அக்ரே நேரம் (ரியோ பிரான்கோ)',
        'America/Santa_Isabel' => 'வடமேற்கு மெக்ஸிகோ நேரம் (சான்டா இசபெல்)',
        'America/Santarem' => 'பிரேசிலியா நேரம் (சான்டரெம்)',
        'America/Santiago' => 'சிலி நேரம் (சாண்டியாகோ)',
        'America/Santo_Domingo' => 'அட்லாண்டிக் நேரம் (சாண்டோ டோமிங்கோ)',
        'America/Sao_Paulo' => 'பிரேசிலியா நேரம் (சாவோ பவுலோ)',
        'America/Scoresbysund' => 'கிழக்கு கிரீன்லாந்து நேரம் (இடோகோர்டோர்மிட்)',
        'America/Sitka' => 'அலாஸ்கா நேரம் (சிட்கா)',
        'America/St_Barthelemy' => 'அட்லாண்டிக் நேரம் (செயின்ட் பார்தேலெமி)',
        'America/St_Johns' => 'நியூஃபவுண்ட்லாந்து நேரம் (செயின்ட் ஜான்ஸ்)',
        'America/St_Kitts' => 'அட்லாண்டிக் நேரம் (செயின்ட் கீட்ஸ்)',
        'America/St_Lucia' => 'அட்லாண்டிக் நேரம் (செயின்ட் லூசியா)',
        'America/St_Thomas' => 'அட்லாண்டிக் நேரம் (செயின்ட் தாமஸ்)',
        'America/St_Vincent' => 'அட்லாண்டிக் நேரம் (செயின்ட் வின்சென்ட்)',
        'America/Swift_Current' => 'மத்திய நேரம் (ஸ்விஃப்ட் கரண்ட்)',
        'America/Tegucigalpa' => 'மத்திய நேரம் (தெகுசிகல்பா)',
        'America/Thule' => 'அட்லாண்டிக் நேரம் (துலே)',
        'America/Thunder_Bay' => 'கிழக்கத்திய நேரம் (தண்டர் பே)',
        'America/Tijuana' => 'பசிபிக் நேரம் (டிஜுவானா)',
        'America/Toronto' => 'கிழக்கத்திய நேரம் (டொரொன்டோ)',
        'America/Tortola' => 'அட்லாண்டிக் நேரம் (டோர்டோலா)',
        'America/Vancouver' => 'பசிபிக் நேரம் (வான்கூவர்)',
        'America/Whitehorse' => 'யூகோன் நேரம் (வொயிட்ஹார்ஸ்)',
        'America/Winnipeg' => 'மத்திய நேரம் (வின்னிபெக்)',
        'America/Yakutat' => 'அலாஸ்கா நேரம் (யகுடட்)',
        'America/Yellowknife' => 'மவுன்டைன் நேரம் (யெல்லோநைஃப்)',
        'Antarctica/Casey' => 'அண்டார்டிகா நேரம் (கேஸி)',
        'Antarctica/Davis' => 'டேவிஸ் நேரம்',
        'Antarctica/DumontDUrville' => 'டுமோண்ட்-டி உர்வில்லே நேரம்',
        'Antarctica/Macquarie' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (மாக்கியூரி)',
        'Antarctica/Mawson' => 'மாசன் நேரம்',
        'Antarctica/McMurdo' => 'நியூசிலாந்து நேரம் (மெக்மர்டோ)',
        'Antarctica/Palmer' => 'சிலி நேரம் (பால்மர்)',
        'Antarctica/Rothera' => 'ரோதேரா நேரம்',
        'Antarctica/Syowa' => 'ஸ்யோவா நேரம்',
        'Antarctica/Troll' => 'கிரீன்விச் சராசரி நேரம் (ட்ரோல்)',
        'Antarctica/Vostok' => 'வோஸ்டோக் நேரம்',
        'Arctic/Longyearbyen' => 'மத்திய ஐரோப்பிய நேரம் (லாங்இயர்பியன்)',
        'Asia/Aden' => 'அரேபிய நேரம் (ஏடன்)',
        'Asia/Almaty' => 'கிழக்கு கஜகஸ்தான் நேரம் (அல்மாதி)',
        'Asia/Amman' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (அம்மான்)',
        'Asia/Anadyr' => 'அனடீர் நேரம்',
        'Asia/Aqtau' => 'மேற்கு கஜகஸ்தான் நேரம் (அக்தவ்)',
        'Asia/Aqtobe' => 'மேற்கு கஜகஸ்தான் நேரம் (அக்டோப்)',
        'Asia/Ashgabat' => 'துர்க்மெனிஸ்தான் நேரம் (அஷ்காபாத்)',
        'Asia/Atyrau' => 'மேற்கு கஜகஸ்தான் நேரம் (அடிரா)',
        'Asia/Baghdad' => 'அரேபிய நேரம் (பாக்தாத்)',
        'Asia/Bahrain' => 'அரேபிய நேரம் (பஹ்ரைன்)',
        'Asia/Baku' => 'அசர்பைஜான் நேரம் (பாக்கூ)',
        'Asia/Bangkok' => 'இந்தோசீன நேரம் (பாங்காக்)',
        'Asia/Barnaul' => 'ரஷ்யா நேரம் (பார்னால்)',
        'Asia/Beirut' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (பெய்ரூட்)',
        'Asia/Bishkek' => 'கிர்கிஸ்தான் நேரம் (பிஷ்கெக்)',
        'Asia/Brunei' => 'புருனே டருஸ்ஸலாம் நேரம்',
        'Asia/Calcutta' => 'இந்திய நிலையான நேரம் (கொல்கத்தா)',
        'Asia/Chita' => 'யகுட்ஸ்க் நேரம் (சிடா)',
        'Asia/Choibalsan' => 'உலன் பாடர் நேரம் (சோய்பால்சான்)',
        'Asia/Colombo' => 'இந்திய நிலையான நேரம் (கொழும்பு)',
        'Asia/Damascus' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (டமாஸ்கஸ்)',
        'Asia/Dhaka' => 'வங்கதேச நேரம் (டாக்கா)',
        'Asia/Dili' => 'கிழக்கு திமோர் நேரம் (டிலி)',
        'Asia/Dubai' => 'வளைகுடா நிலையான நேரம் (துபாய்)',
        'Asia/Dushanbe' => 'தஜிகிஸ்தான் நேரம் (துஷன்பே)',
        'Asia/Famagusta' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ஃபாமகுஸ்டா)',
        'Asia/Gaza' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (காஸா)',
        'Asia/Hebron' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ஹெப்ரான்)',
        'Asia/Hong_Kong' => 'ஹாங்காங் நேரம்',
        'Asia/Hovd' => 'ஹோவ்த் நேரம்',
        'Asia/Irkutsk' => 'இர்குட்ஸ்க் நேரம்',
        'Asia/Jakarta' => 'மேற்கத்திய இந்தோனேசிய நேரம் (ஜகார்த்தா)',
        'Asia/Jayapura' => 'கிழக்கத்திய இந்தோனேசிய நேரம் (ஜெயபூரா)',
        'Asia/Jerusalem' => 'இஸ்ரேல் நேரம் (ஜெருசலேம்)',
        'Asia/Kabul' => 'ஆஃப்கானிஸ்தான் நேரம் (காபூல்)',
        'Asia/Kamchatka' => 'பெட்ரோபவ்லோவ்ஸ்க் கம்சட்ஸ்கி நேரம் (காம்சட்கா)',
        'Asia/Karachi' => 'பாகிஸ்தான் நேரம் (கராச்சி)',
        'Asia/Katmandu' => 'நேபாள நேரம் (காத்மாண்டு)',
        'Asia/Khandyga' => 'யகுட்ஸ்க் நேரம் (கான்டிகா)',
        'Asia/Krasnoyarsk' => 'க்ரஸ்னோயார்ஸ்க் நேரம் (கிராஸ்னோயார்க்ஸ்)',
        'Asia/Kuala_Lumpur' => 'மலேஷிய நேரம் (கோலாலம்பூர்)',
        'Asia/Kuching' => 'மலேஷிய நேரம் (குசிங்)',
        'Asia/Kuwait' => 'அரேபிய நேரம் (குவைத்)',
        'Asia/Macau' => 'சீன நேரம் (மகாவு)',
        'Asia/Magadan' => 'மகதன் நேரம்',
        'Asia/Makassar' => 'மத்திய இந்தோனேசிய நேரம் (மக்கஸர்)',
        'Asia/Manila' => 'பிலிப்பைன் நேரம் (மணிலா)',
        'Asia/Muscat' => 'வளைகுடா நிலையான நேரம் (மஸ்கட்)',
        'Asia/Nicosia' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (நிகோசியா)',
        'Asia/Novokuznetsk' => 'க்ரஸ்னோயார்ஸ்க் நேரம் (நோவோகுஸ்நெட்ஸ்க்)',
        'Asia/Novosibirsk' => 'நோவோசிபிரிஸ்க் நேரம் (நோவோசீபிர்ஸ்க்)',
        'Asia/Omsk' => 'ஓம்ஸ்க் நேரம்',
        'Asia/Oral' => 'மேற்கு கஜகஸ்தான் நேரம் (ஓரல்)',
        'Asia/Phnom_Penh' => 'இந்தோசீன நேரம் (ஃப்னோம் பென்)',
        'Asia/Pontianak' => 'மேற்கத்திய இந்தோனேசிய நேரம் (போன்டியானாக்)',
        'Asia/Pyongyang' => 'கொரிய நேரம் (பியாங்யாங்)',
        'Asia/Qatar' => 'அரேபிய நேரம் (கத்தார்)',
        'Asia/Qostanay' => 'கிழக்கு கஜகஸ்தான் நேரம் (கோஸ்டானே)',
        'Asia/Qyzylorda' => 'மேற்கு கஜகஸ்தான் நேரம் (கிஸிலோர்டா)',
        'Asia/Rangoon' => 'மியான்மர் நேரம் (ரங்கூன்)',
        'Asia/Riyadh' => 'அரேபிய நேரம் (ரியாத்)',
        'Asia/Saigon' => 'இந்தோசீன நேரம் (ஹோ சி மின் சிட்டி)',
        'Asia/Sakhalin' => 'சகலின் நேரம்',
        'Asia/Samarkand' => 'உஸ்பெகிஸ்தான் நேரம் (சமார்கண்ட்)',
        'Asia/Seoul' => 'கொரிய நேரம் (சியோல்)',
        'Asia/Shanghai' => 'சீன நேரம் (ஷாங்காய்)',
        'Asia/Singapore' => 'சிங்கப்பூர் நிலையான நேரம்',
        'Asia/Srednekolymsk' => 'மகதன் நேரம் (ஸ்ரெட்நிகோலிம்ஸ்க்)',
        'Asia/Taipei' => 'தாய்பே நேரம்',
        'Asia/Tashkent' => 'உஸ்பெகிஸ்தான் நேரம் (தாஷ்கண்ட்)',
        'Asia/Tbilisi' => 'ஜார்ஜியா நேரம் (த்பிலிசி)',
        'Asia/Tehran' => 'ஈரான் நேரம் (டெஹ்ரான்)',
        'Asia/Thimphu' => 'பூடான் நேரம் (திம்பு)',
        'Asia/Tokyo' => 'ஜப்பான் நேரம் (டோக்கியோ)',
        'Asia/Tomsk' => 'ரஷ்யா நேரம் (டாம்ஸ்க்)',
        'Asia/Ulaanbaatar' => 'உலன் பாடர் நேரம் (உலான்பாட்டர்)',
        'Asia/Urumqi' => 'சீனா நேரம் (உரும்கி)',
        'Asia/Ust-Nera' => 'விளாடிவோஸ்டோக் நேரம் (உஸ்ட்-நேரா)',
        'Asia/Vientiane' => 'இந்தோசீன நேரம் (வியன்டியன்)',
        'Asia/Vladivostok' => 'விளாடிவோஸ்டோக் நேரம் (விளாடிவொஸ்தோக்)',
        'Asia/Yakutsk' => 'யகுட்ஸ்க் நேரம்',
        'Asia/Yekaterinburg' => 'யேகாடெரின்பர்க் நேரம் (யெகாடிரின்பர்க்)',
        'Asia/Yerevan' => 'ஆர்மேனிய நேரம் (ஏரேவன்)',
        'Atlantic/Azores' => 'அசோரஸ் நேரம்',
        'Atlantic/Bermuda' => 'அட்லாண்டிக் நேரம் (பெர்முடா)',
        'Atlantic/Canary' => 'மேற்கத்திய ஐரோப்பிய நேரம் (கேனரி)',
        'Atlantic/Cape_Verde' => 'கேப் வெர்டே நேரம்',
        'Atlantic/Faeroe' => 'மேற்கத்திய ஐரோப்பிய நேரம் (ஃபரோ)',
        'Atlantic/Madeira' => 'மேற்கத்திய ஐரோப்பிய நேரம் (மடிரா)',
        'Atlantic/Reykjavik' => 'கிரீன்விச் சராசரி நேரம் (ரேக்ஜாவிக்)',
        'Atlantic/South_Georgia' => 'தெற்கு ஜார்ஜியா நேரம்',
        'Atlantic/St_Helena' => 'கிரீன்விச் சராசரி நேரம் (செயின்ட் ஹெலெனா)',
        'Atlantic/Stanley' => 'ஃபாக்லாந்து தீவுகள் நேரம் (ஸ்டேன்லி)',
        'Australia/Adelaide' => 'மத்திய ஆஸ்திரேலிய நேரம் (அடிலெய்ட்)',
        'Australia/Brisbane' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (பிரிஸ்பேன்)',
        'Australia/Broken_Hill' => 'மத்திய ஆஸ்திரேலிய நேரம் (புரோக்கன் ஹில்)',
        'Australia/Currie' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (கியூரி)',
        'Australia/Darwin' => 'மத்திய ஆஸ்திரேலிய நேரம் (டார்வின்)',
        'Australia/Eucla' => 'ஆஸ்திரேலியன் மத்திய மேற்கத்திய நேரம் (யூக்லா)',
        'Australia/Hobart' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (ஹோபர்ட்)',
        'Australia/Lindeman' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (லின்டெமன்)',
        'Australia/Lord_Howe' => 'லார்ட் ஹோவ் நேரம் (லார்ட் ஹோவே)',
        'Australia/Melbourne' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (மெல்போர்ன்)',
        'Australia/Perth' => 'மேற்கத்திய ஆஸ்திரேலிய நேரம் (பெர்த்)',
        'Australia/Sydney' => 'கிழக்கத்திய ஆஸ்திரேலிய நேரம் (சிட்னி)',
        'CST6CDT' => 'மத்திய நேரம்',
        'EST5EDT' => 'கிழக்கத்திய நேரம்',
        'Etc/GMT' => 'கிரீன்விச் சராசரி நேரம்',
        'Etc/UTC' => 'ஒருங்கிணைந்த சர்வதேச நேரம்',
        'Europe/Amsterdam' => 'மத்திய ஐரோப்பிய நேரம் (ஆம்ஸ்ட்ரடாம்)',
        'Europe/Andorra' => 'மத்திய ஐரோப்பிய நேரம் (அண்டோரா)',
        'Europe/Astrakhan' => 'மாஸ்கோ நேரம் (அஸ்ட்ராகான்)',
        'Europe/Athens' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ஏதன்ஸ்)',
        'Europe/Belgrade' => 'மத்திய ஐரோப்பிய நேரம் (பெல்கிரேட்)',
        'Europe/Berlin' => 'மத்திய ஐரோப்பிய நேரம் (பெர்லின்)',
        'Europe/Bratislava' => 'மத்திய ஐரோப்பிய நேரம் (பிரடிஸ்லாவா)',
        'Europe/Brussels' => 'மத்திய ஐரோப்பிய நேரம் (புரூசல்ஸ்)',
        'Europe/Bucharest' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (புசாரெஸ்ட்)',
        'Europe/Budapest' => 'மத்திய ஐரோப்பிய நேரம் (புடாபெஸ்ட்)',
        'Europe/Busingen' => 'மத்திய ஐரோப்பிய நேரம் (பசிங்ஜென்)',
        'Europe/Chisinau' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (சிசினவ்)',
        'Europe/Copenhagen' => 'மத்திய ஐரோப்பிய நேரம் (கோபன்ஹேகன்)',
        'Europe/Dublin' => 'கிரீன்விச் சராசரி நேரம் (டப்ளின்)',
        'Europe/Gibraltar' => 'மத்திய ஐரோப்பிய நேரம் (ஜிப்ரால்டர்)',
        'Europe/Guernsey' => 'கிரீன்விச் சராசரி நேரம் (கர்னஸே)',
        'Europe/Helsinki' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ஹெல்சிங்கி)',
        'Europe/Isle_of_Man' => 'கிரீன்விச் சராசரி நேரம் (ஐல் ஆஃப் மேன்)',
        'Europe/Istanbul' => 'துருக்கி நேரம் (இஸ்தான்புல்)',
        'Europe/Jersey' => 'கிரீன்விச் சராசரி நேரம் (ஜெர்சி)',
        'Europe/Kaliningrad' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (கலினின்கிராட்)',
        'Europe/Kiev' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (கீவ்)',
        'Europe/Kirov' => 'ரஷ்யா நேரம் (கிரோவ்)',
        'Europe/Lisbon' => 'மேற்கத்திய ஐரோப்பிய நேரம் (லிஸ்பன்)',
        'Europe/Ljubljana' => 'மத்திய ஐரோப்பிய நேரம் (ஜுப்லானா)',
        'Europe/London' => 'கிரீன்விச் சராசரி நேரம் (லண்டன்)',
        'Europe/Luxembourg' => 'மத்திய ஐரோப்பிய நேரம் (லக்சம்பர்க்)',
        'Europe/Madrid' => 'மத்திய ஐரோப்பிய நேரம் (மேட்ரிட்)',
        'Europe/Malta' => 'மத்திய ஐரோப்பிய நேரம் (மால்டா)',
        'Europe/Mariehamn' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (மரிஹம்)',
        'Europe/Minsk' => 'மாஸ்கோ நேரம் (மின்ஸ்க்)',
        'Europe/Monaco' => 'மத்திய ஐரோப்பிய நேரம் (மொனாக்கோ)',
        'Europe/Moscow' => 'மாஸ்கோ நேரம்',
        'Europe/Oslo' => 'மத்திய ஐரோப்பிய நேரம் (ஓஸ்லோ)',
        'Europe/Paris' => 'மத்திய ஐரோப்பிய நேரம் (பாரீஸ்)',
        'Europe/Podgorica' => 'மத்திய ஐரோப்பிய நேரம் (போட்கோரிகா)',
        'Europe/Prague' => 'மத்திய ஐரோப்பிய நேரம் (ப்ராக்)',
        'Europe/Riga' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ரிகா)',
        'Europe/Rome' => 'மத்திய ஐரோப்பிய நேரம் (ரோம்)',
        'Europe/Samara' => 'சமரா நேரம் (சமாரா)',
        'Europe/San_Marino' => 'மத்திய ஐரோப்பிய நேரம் (சான் மரினோ)',
        'Europe/Sarajevo' => 'மத்திய ஐரோப்பிய நேரம் (சரயேவோ)',
        'Europe/Saratov' => 'மாஸ்கோ நேரம் (சரடோவ்)',
        'Europe/Simferopol' => 'மாஸ்கோ நேரம் (சிம்ஃபெரோபோல்)',
        'Europe/Skopje' => 'மத்திய ஐரோப்பிய நேரம் (ஸ்கோப்ஜே)',
        'Europe/Sofia' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (சோஃபியா)',
        'Europe/Stockholm' => 'மத்திய ஐரோப்பிய நேரம் (ஸ்டாக்ஹோம்)',
        'Europe/Tallinn' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (டலின்)',
        'Europe/Tirane' => 'மத்திய ஐரோப்பிய நேரம் (திரானே)',
        'Europe/Ulyanovsk' => 'மாஸ்கோ நேரம் (உல்யானோஸ்க்)',
        'Europe/Uzhgorod' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (உஷோரோட்)',
        'Europe/Vaduz' => 'மத்திய ஐரோப்பிய நேரம் (வதுஸ்)',
        'Europe/Vatican' => 'மத்திய ஐரோப்பிய நேரம் (வாடிகன்)',
        'Europe/Vienna' => 'மத்திய ஐரோப்பிய நேரம் (வியன்னா)',
        'Europe/Vilnius' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (வில்னியஸ்)',
        'Europe/Volgograd' => 'வோல்கோக்ராட் நேரம் (வோல்கோகிராட்)',
        'Europe/Warsaw' => 'மத்திய ஐரோப்பிய நேரம் (வார்ஸா)',
        'Europe/Zagreb' => 'மத்திய ஐரோப்பிய நேரம் (ஸக்ரெப்)',
        'Europe/Zaporozhye' => 'கிழக்கத்திய ஐரோப்பிய நேரம் (ஜபோரோஸியே)',
        'Europe/Zurich' => 'மத்திய ஐரோப்பிய நேரம் (ஜூரிச்)',
        'Indian/Antananarivo' => 'கிழக்கு ஆப்பிரிக்க நேரம் (ஆண்டனநரிவோ)',
        'Indian/Chagos' => 'இந்தியப் பெருங்கடல் நேரம் (சாகோஸ்)',
        'Indian/Christmas' => 'கிறிஸ்துமஸ் தீவு நேரம்',
        'Indian/Cocos' => 'கோகோஸ் தீவுகள் நேரம்',
        'Indian/Comoro' => 'கிழக்கு ஆப்பிரிக்க நேரம் (கொமரோ)',
        'Indian/Kerguelen' => 'பிரெஞ்சு தெற்கத்திய & அண்டார்டிக் நேரம் (கெர்யூலென்)',
        'Indian/Mahe' => 'சீசெல்ஸ் நேரம் (மாஹே)',
        'Indian/Maldives' => 'மாலத்தீவுகள் நேரம்',
        'Indian/Mauritius' => 'மொரிஷியஸ் நேரம்',
        'Indian/Mayotte' => 'கிழக்கு ஆப்பிரிக்க நேரம் (மயோட்டி)',
        'Indian/Reunion' => 'ரீயூனியன் நேரம்',
        'MST7MDT' => 'மவுன்டைன் நேரம்',
        'PST8PDT' => 'பசிபிக் நேரம்',
        'Pacific/Apia' => 'ஏபியா நேரம் (அபியா)',
        'Pacific/Auckland' => 'நியூசிலாந்து நேரம் (ஆக்லாந்து)',
        'Pacific/Bougainville' => 'பபுவா நியூ கினியா நேரம் (போகெய்ன்வில்லே)',
        'Pacific/Chatham' => 'சத்தாம் நேரம்',
        'Pacific/Easter' => 'ஈஸ்டர் தீவு நேரம்',
        'Pacific/Efate' => 'வனுவாட்டு நேரம் (ஈஃபேட்)',
        'Pacific/Enderbury' => 'ஃபோனிக்ஸ் தீவுகள் நேரம் (எண்டர்பரி)',
        'Pacific/Fakaofo' => 'டோக்கெலாவ் நேரம் (ஃபகாஃபோ)',
        'Pacific/Fiji' => 'ஃபிஜி நேரம்',
        'Pacific/Funafuti' => 'துவாலு நேரம் (ஃபுனாஃபுடி)',
        'Pacific/Galapagos' => 'கலபகோஸ் நேரம்',
        'Pacific/Gambier' => 'கேம்பியர் நேரம்',
        'Pacific/Guadalcanal' => 'சாலமன் தீவுகள் நேரம் (க்வாடால்கேனல்)',
        'Pacific/Guam' => 'சாமோரோ நிலையான நேரம் (குவாம்)',
        'Pacific/Honolulu' => 'ஹவாய்-அலேஷியன் நேரம் (ஹோனோலூலூ)',
        'Pacific/Johnston' => 'ஹவாய்-அலேஷியன் நேரம் (ஜோன்ஸ்டன்)',
        'Pacific/Kiritimati' => 'லைன் தீவுகள் நேரம் (கிரிடிமாட்டி)',
        'Pacific/Kosrae' => 'கோஸ்ரே நேரம்',
        'Pacific/Kwajalein' => 'மார்ஷல் தீவுகள் நேரம் (க்வாஜாலீயன்)',
        'Pacific/Majuro' => 'மார்ஷல் தீவுகள் நேரம் (மஜுரோ)',
        'Pacific/Marquesas' => 'மார்கியூசாஸ் நேரம்',
        'Pacific/Midway' => 'சமோவா நேரம் (மிட்வே)',
        'Pacific/Nauru' => 'நவ்ரூ நேரம்',
        'Pacific/Niue' => 'நியு நேரம்',
        'Pacific/Norfolk' => 'நார்ஃபோக் தீவு நேரம்',
        'Pacific/Noumea' => 'நியூ கலிடோனியா நேரம் (நோவுமியா)',
        'Pacific/Pago_Pago' => 'சமோவா நேரம் (பேகோ பேகோ)',
        'Pacific/Palau' => 'பாலவ் நேரம்',
        'Pacific/Pitcairn' => 'பிட்கெய்ர்ன் நேரம்',
        'Pacific/Ponape' => 'போனாபே நேரம் (ஃபோன்பெய்)',
        'Pacific/Port_Moresby' => 'பபுவா நியூ கினியா நேரம் (போர்ட் மோர்ஸ்பை)',
        'Pacific/Rarotonga' => 'குக் தீவுகள் நேரம் (ரரோடோங்கா)',
        'Pacific/Saipan' => 'சாமோரோ நிலையான நேரம் (சைபன்)',
        'Pacific/Tahiti' => 'தஹிதி நேரம்',
        'Pacific/Tarawa' => 'கில்பர்ட் தீவுகள் நேரம் (தராவா)',
        'Pacific/Tongatapu' => 'டோங்கா நேரம் (டோன்கடப்பு)',
        'Pacific/Truk' => 'சுக் நேரம்',
        'Pacific/Wake' => 'வேக் தீவு நேரம்',
        'Pacific/Wallis' => 'வாலிஸ் மற்றும் ஃப்யூடுனா நேரம்',
    ],
    'Meta' => [
    ],
];
