<?php

return [
    'Names' => [
        'af' => 'Afracáinis',
        'af_NA' => 'Afracáinis (an Namaib)',
        'af_ZA' => 'Afracáinis (an Afraic Theas)',
        'ak' => 'Acáinis',
        'ak_GH' => 'Acáinis (Gána)',
        'am' => 'Amáiris',
        'am_ET' => 'Amáiris (an Aetóip)',
        'ar' => 'Araibis',
        'ar_001' => 'Araibis (an Domhan)',
        'ar_AE' => 'Araibis (Aontas na nÉimíríochtaí Arabacha)',
        'ar_BH' => 'Araibis (Bairéin)',
        'ar_DJ' => 'Araibis (Djibouti)',
        'ar_DZ' => 'Araibis (an Ailgéir)',
        'ar_EG' => 'Araibis (an Éigipt)',
        'ar_EH' => 'Araibis (an Sahára Thiar)',
        'ar_ER' => 'Araibis (an Eiritré)',
        'ar_IL' => 'Araibis (Iosrael)',
        'ar_IQ' => 'Araibis (an Iaráic)',
        'ar_JO' => 'Araibis (an Iordáin)',
        'ar_KM' => 'Araibis (Oileáin Chomóra)',
        'ar_KW' => 'Araibis (Cuáit)',
        'ar_LB' => 'Araibis (an Liobáin)',
        'ar_LY' => 'Araibis (an Libia)',
        'ar_MA' => 'Araibis (Maracó)',
        'ar_MR' => 'Araibis (an Mháratáin)',
        'ar_OM' => 'Araibis (Óman)',
        'ar_PS' => 'Araibis (na Críocha Palaistíneacha)',
        'ar_QA' => 'Araibis (Catar)',
        'ar_SA' => 'Araibis (an Araib Shádach)',
        'ar_SD' => 'Araibis (an tSúdáin)',
        'ar_SO' => 'Araibis (an tSomáil)',
        'ar_SS' => 'Araibis (an tSúdáin Theas)',
        'ar_SY' => 'Araibis (an tSiria)',
        'ar_TD' => 'Araibis (Sead)',
        'ar_TN' => 'Araibis (an Túinéis)',
        'ar_YE' => 'Araibis (Éimin)',
        'as' => 'Asaimis',
        'as_IN' => 'Asaimis (an India)',
        'az' => 'Asarbaiseáinis',
        'az_AZ' => 'Asarbaiseáinis (an Asarbaiseáin)',
        'az_Cyrl' => 'Asarbaiseáinis (Coireallach)',
        'az_Cyrl_AZ' => 'Asarbaiseáinis (Coireallach, an Asarbaiseáin)',
        'az_Latn' => 'Asarbaiseáinis (Laidineach)',
        'az_Latn_AZ' => 'Asarbaiseáinis (Laidineach, an Asarbaiseáin)',
        'be' => 'Bealarúisis',
        'be_BY' => 'Bealarúisis (an Bhealarúis)',
        'bg' => 'Bulgáiris',
        'bg_BG' => 'Bulgáiris (an Bhulgáir)',
        'bm' => 'Bambairis',
        'bm_ML' => 'Bambairis (Mailí)',
        'bn' => 'Beangáilis',
        'bn_BD' => 'Beangáilis (an Bhanglaidéis)',
        'bn_IN' => 'Beangáilis (an India)',
        'bo' => 'Tibéidis',
        'bo_CN' => 'Tibéidis (an tSín)',
        'bo_IN' => 'Tibéidis (an India)',
        'br' => 'Briotáinis',
        'br_FR' => 'Briotáinis (an Fhrainc)',
        'bs' => 'Boisnis',
        'bs_BA' => 'Boisnis (an Bhoisnia agus an Heirseagaivéin)',
        'bs_Cyrl' => 'Boisnis (Coireallach)',
        'bs_Cyrl_BA' => 'Boisnis (Coireallach, an Bhoisnia agus an Heirseagaivéin)',
        'bs_Latn' => 'Boisnis (Laidineach)',
        'bs_Latn_BA' => 'Boisnis (Laidineach, an Bhoisnia agus an Heirseagaivéin)',
        'ca' => 'Catalóinis',
        'ca_AD' => 'Catalóinis (Andóra)',
        'ca_ES' => 'Catalóinis (an Spáinn)',
        'ca_FR' => 'Catalóinis (an Fhrainc)',
        'ca_IT' => 'Catalóinis (an Iodáil)',
        'ce' => 'Seisnis',
        'ce_RU' => 'Seisnis (an Rúis)',
        'cs' => 'Seicis',
        'cs_CZ' => 'Seicis (an tSeicia)',
        'cv' => 'Suvaisis',
        'cv_RU' => 'Suvaisis (an Rúis)',
        'cy' => 'Breatnais',
        'cy_GB' => 'Breatnais (an Ríocht Aontaithe)',
        'da' => 'Danmhairgis',
        'da_DK' => 'Danmhairgis (an Danmhairg)',
        'da_GL' => 'Danmhairgis (an Ghraonlainn)',
        'de' => 'Gearmáinis',
        'de_AT' => 'Gearmáinis (an Ostair)',
        'de_BE' => 'Gearmáinis (an Bheilg)',
        'de_CH' => 'Gearmáinis (an Eilvéis)',
        'de_DE' => 'Gearmáinis (an Ghearmáin)',
        'de_IT' => 'Gearmáinis (an Iodáil)',
        'de_LI' => 'Gearmáinis (Lichtinstéin)',
        'de_LU' => 'Gearmáinis (Lucsamburg)',
        'dz' => 'Seoinicis',
        'dz_BT' => 'Seoinicis (an Bhútáin)',
        'ee' => 'Éabhais',
        'ee_GH' => 'Éabhais (Gána)',
        'ee_TG' => 'Éabhais (Tóga)',
        'el' => 'Gréigis',
        'el_CY' => 'Gréigis (an Chipir)',
        'el_GR' => 'Gréigis (an Ghréig)',
        'en' => 'Béarla',
        'en_001' => 'Béarla (an Domhan)',
        'en_150' => 'Béarla (an Eoraip)',
        'en_AE' => 'Béarla (Aontas na nÉimíríochtaí Arabacha)',
        'en_AG' => 'Béarla (Antigua agus Barbúda)',
        'en_AI' => 'Béarla (Angaíle)',
        'en_AS' => 'Béarla (Samó Mheiriceá)',
        'en_AT' => 'Béarla (an Ostair)',
        'en_AU' => 'Béarla (an Astráil)',
        'en_BB' => 'Béarla (Barbadós)',
        'en_BE' => 'Béarla (an Bheilg)',
        'en_BI' => 'Béarla (an Bhurúin)',
        'en_BM' => 'Béarla (Beirmiúda)',
        'en_BS' => 'Béarla (na Bahámaí)',
        'en_BW' => 'Béarla (an Bhotsuáin)',
        'en_BZ' => 'Béarla (an Bheilís)',
        'en_CA' => 'Béarla (Ceanada)',
        'en_CC' => 'Béarla (Oileáin Cocos [Keeling])',
        'en_CH' => 'Béarla (an Eilvéis)',
        'en_CK' => 'Béarla (Oileáin Cook)',
        'en_CM' => 'Béarla (Camarún)',
        'en_CX' => 'Béarla (Oileán na Nollag)',
        'en_CY' => 'Béarla (an Chipir)',
        'en_DE' => 'Béarla (an Ghearmáin)',
        'en_DK' => 'Béarla (an Danmhairg)',
        'en_DM' => 'Béarla (Doiminice)',
        'en_ER' => 'Béarla (an Eiritré)',
        'en_FI' => 'Béarla (an Fhionlainn)',
        'en_FJ' => 'Béarla (Fidsí)',
        'en_FK' => 'Béarla (Oileáin Fháclainne)',
        'en_FM' => 'Béarla (an Mhicrinéis)',
        'en_GB' => 'Béarla (an Ríocht Aontaithe)',
        'en_GD' => 'Béarla (Greanáda)',
        'en_GG' => 'Béarla (Geansaí)',
        'en_GH' => 'Béarla (Gána)',
        'en_GI' => 'Béarla (Giobráltar)',
        'en_GM' => 'Béarla (an Ghaimbia)',
        'en_GU' => 'Béarla (Guam)',
        'en_GY' => 'Béarla (an Ghuáin)',
        'en_HK' => 'Béarla (Sainréigiún Riaracháin Hong Cong, Daonphoblacht na Síne)',
        'en_IE' => 'Béarla (Éire)',
        'en_IL' => 'Béarla (Iosrael)',
        'en_IM' => 'Béarla (Oileán Mhanann)',
        'en_IN' => 'Béarla (an India)',
        'en_IO' => 'Béarla (Críoch Aigéan Indiach na Breataine)',
        'en_JE' => 'Béarla (Geirsí)',
        'en_JM' => 'Béarla (Iamáice)',
        'en_KE' => 'Béarla (an Chéinia)',
        'en_KI' => 'Béarla (Ciribeas)',
        'en_KN' => 'Béarla (San Críostóir-Nimheas)',
        'en_KY' => 'Béarla (Oileáin Cayman)',
        'en_LC' => 'Béarla (Saint Lucia)',
        'en_LR' => 'Béarla (an Libéir)',
        'en_LS' => 'Béarla (Leosóta)',
        'en_MG' => 'Béarla (Madagascar)',
        'en_MH' => 'Béarla (Oileáin Marshall)',
        'en_MO' => 'Béarla (Sainréigiún Riaracháin Macao, Daonphoblacht na Síne)',
        'en_MP' => 'Béarla (na hOileáin Mháirianacha Thuaidh)',
        'en_MS' => 'Béarla (Montsarat)',
        'en_MT' => 'Béarla (Málta)',
        'en_MU' => 'Béarla (Oileán Mhuirís)',
        'en_MV' => 'Béarla (Oileáin Mhaildíve)',
        'en_MW' => 'Béarla (an Mhaláiv)',
        'en_MY' => 'Béarla (an Mhalaeisia)',
        'en_NA' => 'Béarla (an Namaib)',
        'en_NF' => 'Béarla (Oileán Norfolk)',
        'en_NG' => 'Béarla (an Nigéir)',
        'en_NL' => 'Béarla (an Ísiltír)',
        'en_NR' => 'Béarla (Nárú)',
        'en_NU' => 'Béarla (Niue)',
        'en_NZ' => 'Béarla (an Nua-Shéalainn)',
        'en_PG' => 'Béarla (Nua-Ghuine Phapua)',
        'en_PH' => 'Béarla (na hOileáin Fhilipíneacha)',
        'en_PK' => 'Béarla (an Phacastáin)',
        'en_PN' => 'Béarla (Oileáin Pitcairn)',
        'en_PR' => 'Béarla (Pórtó Ríce)',
        'en_PW' => 'Béarla (Oileáin Palau)',
        'en_RW' => 'Béarla (Ruanda)',
        'en_SB' => 'Béarla (Oileáin Sholaimh)',
        'en_SC' => 'Béarla (na Séiséil)',
        'en_SD' => 'Béarla (an tSúdáin)',
        'en_SE' => 'Béarla (an tSualainn)',
        'en_SG' => 'Béarla (Singeapór)',
        'en_SH' => 'Béarla (San Héilin)',
        'en_SI' => 'Béarla (an tSlóivéin)',
        'en_SL' => 'Béarla (Siarra Leon)',
        'en_SS' => 'Béarla (an tSúdáin Theas)',
        'en_SX' => 'Béarla (Sint Maarten)',
        'en_SZ' => 'Béarla (eSuaitíní)',
        'en_TC' => 'Béarla (Oileáin na dTurcach agus Caicos)',
        'en_TK' => 'Béarla (Tócalá)',
        'en_TO' => 'Béarla (Tonga)',
        'en_TT' => 'Béarla (Oileán na Tríonóide agus Tobága)',
        'en_TV' => 'Béarla (Túvalú)',
        'en_TZ' => 'Béarla (an Tansáin)',
        'en_UG' => 'Béarla (Uganda)',
        'en_UM' => 'Béarla (Oileáin Imeallacha S.A.M.)',
        'en_US' => 'Béarla (Stáit Aontaithe Mheiriceá)',
        'en_VC' => 'Béarla (San Uinseann agus na Greanáidíní)',
        'en_VG' => 'Béarla (Oileáin Bhriotanacha na Maighdean)',
        'en_VI' => 'Béarla (Oileáin Mheiriceánacha na Maighdean)',
        'en_VU' => 'Béarla (Vanuatú)',
        'en_WS' => 'Béarla (Samó)',
        'en_ZA' => 'Béarla (an Afraic Theas)',
        'en_ZM' => 'Béarla (an tSaimbia)',
        'en_ZW' => 'Béarla (an tSiombáib)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (an Domhan)',
        'es' => 'Spáinnis',
        'es_419' => 'Spáinnis (Meiriceá Laidineach)',
        'es_AR' => 'Spáinnis (an Airgintín)',
        'es_BO' => 'Spáinnis (an Bholaiv)',
        'es_BR' => 'Spáinnis (an Bhrasaíl)',
        'es_BZ' => 'Spáinnis (an Bheilís)',
        'es_CL' => 'Spáinnis (an tSile)',
        'es_CO' => 'Spáinnis (an Cholóim)',
        'es_CR' => 'Spáinnis (Cósta Ríce)',
        'es_CU' => 'Spáinnis (Cúba)',
        'es_DO' => 'Spáinnis (an Phoblacht Dhoiminiceach)',
        'es_EC' => 'Spáinnis (Eacuadór)',
        'es_ES' => 'Spáinnis (an Spáinn)',
        'es_GQ' => 'Spáinnis (an Ghuine Mheánchiorclach)',
        'es_GT' => 'Spáinnis (Guatamala)',
        'es_HN' => 'Spáinnis (Hondúras)',
        'es_MX' => 'Spáinnis (Meicsiceo)',
        'es_NI' => 'Spáinnis (Nicearagua)',
        'es_PA' => 'Spáinnis (Panama)',
        'es_PE' => 'Spáinnis (Peiriú)',
        'es_PH' => 'Spáinnis (na hOileáin Fhilipíneacha)',
        'es_PR' => 'Spáinnis (Pórtó Ríce)',
        'es_PY' => 'Spáinnis (Paragua)',
        'es_SV' => 'Spáinnis (an tSalvadóir)',
        'es_US' => 'Spáinnis (Stáit Aontaithe Mheiriceá)',
        'es_UY' => 'Spáinnis (Uragua)',
        'es_VE' => 'Spáinnis (Veiniséala)',
        'et' => 'Eastóinis',
        'et_EE' => 'Eastóinis (an Eastóin)',
        'eu' => 'Bascais',
        'eu_ES' => 'Bascais (an Spáinn)',
        'fa' => 'Peirsis',
        'fa_AF' => 'Peirsis (an Afganastáin)',
        'fa_IR' => 'Peirsis (an Iaráin)',
        'ff' => 'Fuláinis',
        'ff_Adlm' => 'Fuláinis (Adlam)',
        'ff_Adlm_BF' => 'Fuláinis (Adlam, Buircíne Fasó)',
        'ff_Adlm_CM' => 'Fuláinis (Adlam, Camarún)',
        'ff_Adlm_GH' => 'Fuláinis (Adlam, Gána)',
        'ff_Adlm_GM' => 'Fuláinis (Adlam, an Ghaimbia)',
        'ff_Adlm_GN' => 'Fuláinis (Adlam, an Ghuine)',
        'ff_Adlm_GW' => 'Fuláinis (Adlam, Guine Bissau)',
        'ff_Adlm_LR' => 'Fuláinis (Adlam, an Libéir)',
        'ff_Adlm_MR' => 'Fuláinis (Adlam, an Mháratáin)',
        'ff_Adlm_NE' => 'Fuláinis (Adlam, an Nígir)',
        'ff_Adlm_NG' => 'Fuláinis (Adlam, an Nigéir)',
        'ff_Adlm_SL' => 'Fuláinis (Adlam, Siarra Leon)',
        'ff_Adlm_SN' => 'Fuláinis (Adlam, an tSeineagáil)',
        'ff_CM' => 'Fuláinis (Camarún)',
        'ff_GN' => 'Fuláinis (an Ghuine)',
        'ff_Latn' => 'Fuláinis (Laidineach)',
        'ff_Latn_BF' => 'Fuláinis (Laidineach, Buircíne Fasó)',
        'ff_Latn_CM' => 'Fuláinis (Laidineach, Camarún)',
        'ff_Latn_GH' => 'Fuláinis (Laidineach, Gána)',
        'ff_Latn_GM' => 'Fuláinis (Laidineach, an Ghaimbia)',
        'ff_Latn_GN' => 'Fuláinis (Laidineach, an Ghuine)',
        'ff_Latn_GW' => 'Fuláinis (Laidineach, Guine Bissau)',
        'ff_Latn_LR' => 'Fuláinis (Laidineach, an Libéir)',
        'ff_Latn_MR' => 'Fuláinis (Laidineach, an Mháratáin)',
        'ff_Latn_NE' => 'Fuláinis (Laidineach, an Nígir)',
        'ff_Latn_NG' => 'Fuláinis (Laidineach, an Nigéir)',
        'ff_Latn_SL' => 'Fuláinis (Laidineach, Siarra Leon)',
        'ff_Latn_SN' => 'Fuláinis (Laidineach, an tSeineagáil)',
        'ff_MR' => 'Fuláinis (an Mháratáin)',
        'ff_SN' => 'Fuláinis (an tSeineagáil)',
        'fi' => 'Fionlainnis',
        'fi_FI' => 'Fionlainnis (an Fhionlainn)',
        'fo' => 'Faróis',
        'fo_DK' => 'Faróis (an Danmhairg)',
        'fo_FO' => 'Faróis (Oileáin Fharó)',
        'fr' => 'Fraincis',
        'fr_BE' => 'Fraincis (an Bheilg)',
        'fr_BF' => 'Fraincis (Buircíne Fasó)',
        'fr_BI' => 'Fraincis (an Bhurúin)',
        'fr_BJ' => 'Fraincis (Beinin)',
        'fr_BL' => 'Fraincis (Saint Barthélemy)',
        'fr_CA' => 'Fraincis (Ceanada)',
        'fr_CD' => 'Fraincis (Poblacht Dhaonlathach an Chongó)',
        'fr_CF' => 'Fraincis (Poblacht na hAfraice Láir)',
        'fr_CG' => 'Fraincis (Congó-Brazzaville)',
        'fr_CH' => 'Fraincis (an Eilvéis)',
        'fr_CI' => 'Fraincis (an Cósta Eabhair)',
        'fr_CM' => 'Fraincis (Camarún)',
        'fr_DJ' => 'Fraincis (Djibouti)',
        'fr_DZ' => 'Fraincis (an Ailgéir)',
        'fr_FR' => 'Fraincis (an Fhrainc)',
        'fr_GA' => 'Fraincis (an Ghabúin)',
        'fr_GF' => 'Fraincis (Guáin na Fraince)',
        'fr_GN' => 'Fraincis (an Ghuine)',
        'fr_GP' => 'Fraincis (Guadalúip)',
        'fr_GQ' => 'Fraincis (an Ghuine Mheánchiorclach)',
        'fr_HT' => 'Fraincis (Háítí)',
        'fr_KM' => 'Fraincis (Oileáin Chomóra)',
        'fr_LU' => 'Fraincis (Lucsamburg)',
        'fr_MA' => 'Fraincis (Maracó)',
        'fr_MC' => 'Fraincis (Monacó)',
        'fr_MF' => 'Fraincis (Saint-Martin)',
        'fr_MG' => 'Fraincis (Madagascar)',
        'fr_ML' => 'Fraincis (Mailí)',
        'fr_MQ' => 'Fraincis (Martinique)',
        'fr_MR' => 'Fraincis (an Mháratáin)',
        'fr_MU' => 'Fraincis (Oileán Mhuirís)',
        'fr_NC' => 'Fraincis (an Nua-Chaladóin)',
        'fr_NE' => 'Fraincis (an Nígir)',
        'fr_PF' => 'Fraincis (Polainéis na Fraince)',
        'fr_PM' => 'Fraincis (San Pierre agus Miquelon)',
        'fr_RE' => 'Fraincis (La Réunion)',
        'fr_RW' => 'Fraincis (Ruanda)',
        'fr_SC' => 'Fraincis (na Séiséil)',
        'fr_SN' => 'Fraincis (an tSeineagáil)',
        'fr_SY' => 'Fraincis (an tSiria)',
        'fr_TD' => 'Fraincis (Sead)',
        'fr_TG' => 'Fraincis (Tóga)',
        'fr_TN' => 'Fraincis (an Túinéis)',
        'fr_VU' => 'Fraincis (Vanuatú)',
        'fr_WF' => 'Fraincis (Vailís agus Futúna)',
        'fr_YT' => 'Fraincis (Mayotte)',
        'fy' => 'Freaslainnis Iartharach',
        'fy_NL' => 'Freaslainnis Iartharach (an Ísiltír)',
        'ga' => 'Gaeilge',
        'ga_GB' => 'Gaeilge (an Ríocht Aontaithe)',
        'ga_IE' => 'Gaeilge (Éire)',
        'gd' => 'Gaeilge na hAlban',
        'gd_GB' => 'Gaeilge na hAlban (an Ríocht Aontaithe)',
        'gl' => 'Gailísis',
        'gl_ES' => 'Gailísis (an Spáinn)',
        'gu' => 'Gúisearáitis',
        'gu_IN' => 'Gúisearáitis (an India)',
        'gv' => 'Manainnis',
        'gv_IM' => 'Manainnis (Oileán Mhanann)',
        'ha' => 'Hásais',
        'ha_GH' => 'Hásais (Gána)',
        'ha_NE' => 'Hásais (an Nígir)',
        'ha_NG' => 'Hásais (an Nigéir)',
        'he' => 'Eabhrais',
        'he_IL' => 'Eabhrais (Iosrael)',
        'hi' => 'Hiondúis',
        'hi_IN' => 'Hiondúis (an India)',
        'hi_Latn' => 'Hiondúis (Laidineach)',
        'hi_Latn_IN' => 'Hiondúis (Laidineach, an India)',
        'hr' => 'Cróitis',
        'hr_BA' => 'Cróitis (an Bhoisnia agus an Heirseagaivéin)',
        'hr_HR' => 'Cróitis (an Chróit)',
        'hu' => 'Ungáiris',
        'hu_HU' => 'Ungáiris (an Ungáir)',
        'hy' => 'Airméinis',
        'hy_AM' => 'Airméinis (an Airméin)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (an Domhan)',
        'id' => 'Indinéisis',
        'id_ID' => 'Indinéisis (an Indinéis)',
        'ig' => 'Íogbóis',
        'ig_NG' => 'Íogbóis (an Nigéir)',
        'ii' => 'Ís Shichuan',
        'ii_CN' => 'Ís Shichuan (an tSín)',
        'is' => 'Íoslainnis',
        'is_IS' => 'Íoslainnis (an Íoslainn)',
        'it' => 'Iodáilis',
        'it_CH' => 'Iodáilis (an Eilvéis)',
        'it_IT' => 'Iodáilis (an Iodáil)',
        'it_SM' => 'Iodáilis (San Mairíne)',
        'it_VA' => 'Iodáilis (Cathair na Vatacáine)',
        'ja' => 'Seapáinis',
        'ja_JP' => 'Seapáinis (an tSeapáin)',
        'jv' => 'Iáivis',
        'jv_ID' => 'Iáivis (an Indinéis)',
        'ka' => 'Seoirsis',
        'ka_GE' => 'Seoirsis (an tSeoirsia)',
        'ki' => 'Ciocúis',
        'ki_KE' => 'Ciocúis (an Chéinia)',
        'kk' => 'Casaicis',
        'kk_KZ' => 'Casaicis (an Chasacstáin)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (an Ghraonlainn)',
        'km' => 'Ciméiris',
        'km_KH' => 'Ciméiris (an Chambóid)',
        'kn' => 'Cannadais',
        'kn_IN' => 'Cannadais (an India)',
        'ko' => 'Cóiréis',
        'ko_KP' => 'Cóiréis (an Chóiré Thuaidh)',
        'ko_KR' => 'Cóiréis (an Chóiré Theas)',
        'ks' => 'Caismíris',
        'ks_Arab' => 'Caismíris (Arabach)',
        'ks_Arab_IN' => 'Caismíris (Arabach, an India)',
        'ks_Deva' => 'Caismíris (Déiveanágrach)',
        'ks_Deva_IN' => 'Caismíris (Déiveanágrach, an India)',
        'ks_IN' => 'Caismíris (an India)',
        'ku' => 'Coirdis',
        'ku_TR' => 'Coirdis (an Tuirc)',
        'kw' => 'Coirnis',
        'kw_GB' => 'Coirnis (an Ríocht Aontaithe)',
        'ky' => 'Cirgisis',
        'ky_KG' => 'Cirgisis (an Chirgeastáin)',
        'lb' => 'Lucsambuirgis',
        'lb_LU' => 'Lucsambuirgis (Lucsamburg)',
        'lg' => 'Lugandais',
        'lg_UG' => 'Lugandais (Uganda)',
        'ln' => 'Liongáilis',
        'ln_AO' => 'Liongáilis (Angóla)',
        'ln_CD' => 'Liongáilis (Poblacht Dhaonlathach an Chongó)',
        'ln_CF' => 'Liongáilis (Poblacht na hAfraice Láir)',
        'ln_CG' => 'Liongáilis (Congó-Brazzaville)',
        'lo' => 'Laoisis',
        'lo_LA' => 'Laoisis (Laos)',
        'lt' => 'Liotuáinis',
        'lt_LT' => 'Liotuáinis (an Liotuáin)',
        'lu' => 'Lúba-Cataingis',
        'lu_CD' => 'Lúba-Cataingis (Poblacht Dhaonlathach an Chongó)',
        'lv' => 'Laitvis',
        'lv_LV' => 'Laitvis (an Laitvia)',
        'mg' => 'Malagáisis',
        'mg_MG' => 'Malagáisis (Madagascar)',
        'mi' => 'Maorais',
        'mi_NZ' => 'Maorais (an Nua-Shéalainn)',
        'mk' => 'Macadóinis',
        'mk_MK' => 'Macadóinis (an Mhacadóin Thuaidh)',
        'ml' => 'Mailéalaimis',
        'ml_IN' => 'Mailéalaimis (an India)',
        'mn' => 'Mongóilis',
        'mn_MN' => 'Mongóilis (an Mhongóil)',
        'mr' => 'Maraitis',
        'mr_IN' => 'Maraitis (an India)',
        'ms' => 'Malaeis',
        'ms_BN' => 'Malaeis (Brúiné)',
        'ms_ID' => 'Malaeis (an Indinéis)',
        'ms_MY' => 'Malaeis (an Mhalaeisia)',
        'ms_SG' => 'Malaeis (Singeapór)',
        'mt' => 'Máltais',
        'mt_MT' => 'Máltais (Málta)',
        'my' => 'Burmais',
        'my_MM' => 'Burmais (Maenmar [Burma])',
        'nb' => 'Bocmál',
        'nb_NO' => 'Bocmál (an Iorua)',
        'nb_SJ' => 'Bocmál (Svalbard agus Jan Mayen)',
        'nd' => 'N-deibéilis an Tuaiscirt',
        'nd_ZW' => 'N-deibéilis an Tuaiscirt (an tSiombáib)',
        'ne' => 'Neipeailis',
        'ne_IN' => 'Neipeailis (an India)',
        'ne_NP' => 'Neipeailis (Neipeal)',
        'nl' => 'Ollainnis',
        'nl_AW' => 'Ollainnis (Arúba)',
        'nl_BE' => 'Ollainnis (an Bheilg)',
        'nl_BQ' => 'Ollainnis (an Ísiltír Chairibeach)',
        'nl_CW' => 'Ollainnis (Cúrasó)',
        'nl_NL' => 'Ollainnis (an Ísiltír)',
        'nl_SR' => 'Ollainnis (Suranam)',
        'nl_SX' => 'Ollainnis (Sint Maarten)',
        'nn' => 'Nua-Ioruais',
        'nn_NO' => 'Nua-Ioruais (an Iorua)',
        'no' => 'Ioruais',
        'no_NO' => 'Ioruais (an Iorua)',
        'om' => 'Oraimis',
        'om_ET' => 'Oraimis (an Aetóip)',
        'om_KE' => 'Oraimis (an Chéinia)',
        'or' => 'Odia',
        'or_IN' => 'Odia (an India)',
        'os' => 'Oiséitis',
        'os_GE' => 'Oiséitis (an tSeoirsia)',
        'os_RU' => 'Oiséitis (an Rúis)',
        'pa' => 'Puinseáibis',
        'pa_Arab' => 'Puinseáibis (Arabach)',
        'pa_Arab_PK' => 'Puinseáibis (Arabach, an Phacastáin)',
        'pa_Guru' => 'Puinseáibis (Gurmúcach)',
        'pa_Guru_IN' => 'Puinseáibis (Gurmúcach, an India)',
        'pa_IN' => 'Puinseáibis (an India)',
        'pa_PK' => 'Puinseáibis (an Phacastáin)',
        'pl' => 'Polainnis',
        'pl_PL' => 'Polainnis (an Pholainn)',
        'ps' => 'Paistis',
        'ps_AF' => 'Paistis (an Afganastáin)',
        'ps_PK' => 'Paistis (an Phacastáin)',
        'pt' => 'Portaingéilis',
        'pt_AO' => 'Portaingéilis (Angóla)',
        'pt_BR' => 'Portaingéilis (an Bhrasaíl)',
        'pt_CH' => 'Portaingéilis (an Eilvéis)',
        'pt_CV' => 'Portaingéilis (Rinn Verde)',
        'pt_GQ' => 'Portaingéilis (an Ghuine Mheánchiorclach)',
        'pt_GW' => 'Portaingéilis (Guine Bissau)',
        'pt_LU' => 'Portaingéilis (Lucsamburg)',
        'pt_MO' => 'Portaingéilis (Sainréigiún Riaracháin Macao, Daonphoblacht na Síne)',
        'pt_MZ' => 'Portaingéilis (Mósaimbíc)',
        'pt_PT' => 'Portaingéilis (an Phortaingéil)',
        'pt_ST' => 'Portaingéilis (São Tomé agus Príncipe)',
        'pt_TL' => 'Portaingéilis (Tíomór Thoir)',
        'qu' => 'Ceatsuais',
        'qu_BO' => 'Ceatsuais (an Bholaiv)',
        'qu_EC' => 'Ceatsuais (Eacuadór)',
        'qu_PE' => 'Ceatsuais (Peiriú)',
        'rm' => 'Rómainis',
        'rm_CH' => 'Rómainis (an Eilvéis)',
        'rn' => 'Rúindis',
        'rn_BI' => 'Rúindis (an Bhurúin)',
        'ro' => 'Rómáinis',
        'ro_MD' => 'Rómáinis (an Mholdóiv)',
        'ro_RO' => 'Rómáinis (an Rómáin)',
        'ru' => 'Rúisis',
        'ru_BY' => 'Rúisis (an Bhealarúis)',
        'ru_KG' => 'Rúisis (an Chirgeastáin)',
        'ru_KZ' => 'Rúisis (an Chasacstáin)',
        'ru_MD' => 'Rúisis (an Mholdóiv)',
        'ru_RU' => 'Rúisis (an Rúis)',
        'ru_UA' => 'Rúisis (an Úcráin)',
        'rw' => 'Ciniaruaindis',
        'rw_RW' => 'Ciniaruaindis (Ruanda)',
        'sa' => 'Sanscrait',
        'sa_IN' => 'Sanscrait (an India)',
        'sc' => 'Sairdínis',
        'sc_IT' => 'Sairdínis (an Iodáil)',
        'sd' => 'Sindis',
        'sd_Arab' => 'Sindis (Arabach)',
        'sd_Arab_PK' => 'Sindis (Arabach, an Phacastáin)',
        'sd_Deva' => 'Sindis (Déiveanágrach)',
        'sd_Deva_IN' => 'Sindis (Déiveanágrach, an India)',
        'sd_IN' => 'Sindis (an India)',
        'sd_PK' => 'Sindis (an Phacastáin)',
        'se' => 'Sáimis an Tuaiscirt',
        'se_FI' => 'Sáimis an Tuaiscirt (an Fhionlainn)',
        'se_NO' => 'Sáimis an Tuaiscirt (an Iorua)',
        'se_SE' => 'Sáimis an Tuaiscirt (an tSualainn)',
        'sg' => 'Sangóis',
        'sg_CF' => 'Sangóis (Poblacht na hAfraice Láir)',
        'sh' => 'Seirbea-Chróitis',
        'sh_BA' => 'Seirbea-Chróitis (an Bhoisnia agus an Heirseagaivéin)',
        'si' => 'Siolóinis',
        'si_LK' => 'Siolóinis (Srí Lanca)',
        'sk' => 'Slóvaicis',
        'sk_SK' => 'Slóvaicis (an tSlóvaic)',
        'sl' => 'Slóivéinis',
        'sl_SI' => 'Slóivéinis (an tSlóivéin)',
        'sn' => 'Seoinis',
        'sn_ZW' => 'Seoinis (an tSiombáib)',
        'so' => 'Somáilis',
        'so_DJ' => 'Somáilis (Djibouti)',
        'so_ET' => 'Somáilis (an Aetóip)',
        'so_KE' => 'Somáilis (an Chéinia)',
        'so_SO' => 'Somáilis (an tSomáil)',
        'sq' => 'Albáinis',
        'sq_AL' => 'Albáinis (an Albáin)',
        'sq_MK' => 'Albáinis (an Mhacadóin Thuaidh)',
        'sr' => 'Seirbis',
        'sr_BA' => 'Seirbis (an Bhoisnia agus an Heirseagaivéin)',
        'sr_Cyrl' => 'Seirbis (Coireallach)',
        'sr_Cyrl_BA' => 'Seirbis (Coireallach, an Bhoisnia agus an Heirseagaivéin)',
        'sr_Cyrl_ME' => 'Seirbis (Coireallach, Montainéagró)',
        'sr_Cyrl_RS' => 'Seirbis (Coireallach, an tSeirbia)',
        'sr_Latn' => 'Seirbis (Laidineach)',
        'sr_Latn_BA' => 'Seirbis (Laidineach, an Bhoisnia agus an Heirseagaivéin)',
        'sr_Latn_ME' => 'Seirbis (Laidineach, Montainéagró)',
        'sr_Latn_RS' => 'Seirbis (Laidineach, an tSeirbia)',
        'sr_ME' => 'Seirbis (Montainéagró)',
        'sr_RS' => 'Seirbis (an tSeirbia)',
        'su' => 'Sundais',
        'su_ID' => 'Sundais (an Indinéis)',
        'su_Latn' => 'Sundais (Laidineach)',
        'su_Latn_ID' => 'Sundais (Laidineach, an Indinéis)',
        'sv' => 'Sualainnis',
        'sv_AX' => 'Sualainnis (Oileáin Åland)',
        'sv_FI' => 'Sualainnis (an Fhionlainn)',
        'sv_SE' => 'Sualainnis (an tSualainn)',
        'sw' => 'Svahaílis',
        'sw_CD' => 'Svahaílis (Poblacht Dhaonlathach an Chongó)',
        'sw_KE' => 'Svahaílis (an Chéinia)',
        'sw_TZ' => 'Svahaílis (an Tansáin)',
        'sw_UG' => 'Svahaílis (Uganda)',
        'ta' => 'Tamailis',
        'ta_IN' => 'Tamailis (an India)',
        'ta_LK' => 'Tamailis (Srí Lanca)',
        'ta_MY' => 'Tamailis (an Mhalaeisia)',
        'ta_SG' => 'Tamailis (Singeapór)',
        'te' => 'Teileagúis',
        'te_IN' => 'Teileagúis (an India)',
        'tg' => 'Taidsícis',
        'tg_TJ' => 'Taidsícis (an Táidsíceastáin)',
        'th' => 'Téalainnis',
        'th_TH' => 'Téalainnis (an Téalainn)',
        'ti' => 'Tigrinis',
        'ti_ER' => 'Tigrinis (an Eiritré)',
        'ti_ET' => 'Tigrinis (an Aetóip)',
        'tk' => 'Tuircméinis',
        'tk_TM' => 'Tuircméinis (an Tuircméanastáin)',
        'tl' => 'Tagálaigis',
        'tl_PH' => 'Tagálaigis (na hOileáin Fhilipíneacha)',
        'to' => 'Tongais',
        'to_TO' => 'Tongais (Tonga)',
        'tr' => 'Tuircis',
        'tr_CY' => 'Tuircis (an Chipir)',
        'tr_TR' => 'Tuircis (an Tuirc)',
        'tt' => 'Tatairis',
        'tt_RU' => 'Tatairis (an Rúis)',
        'ug' => 'Uigiúiris',
        'ug_CN' => 'Uigiúiris (an tSín)',
        'uk' => 'Úcráinis',
        'uk_UA' => 'Úcráinis (an Úcráin)',
        'ur' => 'Urdúis',
        'ur_IN' => 'Urdúis (an India)',
        'ur_PK' => 'Urdúis (an Phacastáin)',
        'uz' => 'Úisbéiceastáinis',
        'uz_AF' => 'Úisbéiceastáinis (an Afganastáin)',
        'uz_Arab' => 'Úisbéiceastáinis (Arabach)',
        'uz_Arab_AF' => 'Úisbéiceastáinis (Arabach, an Afganastáin)',
        'uz_Cyrl' => 'Úisbéiceastáinis (Coireallach)',
        'uz_Cyrl_UZ' => 'Úisbéiceastáinis (Coireallach, an Úisbéiceastáin)',
        'uz_Latn' => 'Úisbéiceastáinis (Laidineach)',
        'uz_Latn_UZ' => 'Úisbéiceastáinis (Laidineach, an Úisbéiceastáin)',
        'uz_UZ' => 'Úisbéiceastáinis (an Úisbéiceastáin)',
        'vi' => 'Vítneaimis',
        'vi_VN' => 'Vítneaimis (Vítneam)',
        'wo' => 'Volaifis',
        'wo_SN' => 'Volaifis (an tSeineagáil)',
        'xh' => 'Cóisis',
        'xh_ZA' => 'Cóisis (an Afraic Theas)',
        'yi' => 'Giúdais',
        'yi_001' => 'Giúdais (an Domhan)',
        'yo' => 'Iarúibis',
        'yo_BJ' => 'Iarúibis (Beinin)',
        'yo_NG' => 'Iarúibis (an Nigéir)',
        'zh' => 'Sínis',
        'zh_CN' => 'Sínis (an tSín)',
        'zh_HK' => 'Sínis (Sainréigiún Riaracháin Hong Cong, Daonphoblacht na Síne)',
        'zh_Hans' => 'Sínis (Simplithe)',
        'zh_Hans_CN' => 'Sínis (Simplithe, an tSín)',
        'zh_Hans_HK' => 'Sínis (Simplithe, Sainréigiún Riaracháin Hong Cong, Daonphoblacht na Síne)',
        'zh_Hans_MO' => 'Sínis (Simplithe, Sainréigiún Riaracháin Macao, Daonphoblacht na Síne)',
        'zh_Hans_SG' => 'Sínis (Simplithe, Singeapór)',
        'zh_Hant' => 'Sínis (Traidisiúnta)',
        'zh_Hant_HK' => 'Sínis (Traidisiúnta, Sainréigiún Riaracháin Hong Cong, Daonphoblacht na Síne)',
        'zh_Hant_MO' => 'Sínis (Traidisiúnta, Sainréigiún Riaracháin Macao, Daonphoblacht na Síne)',
        'zh_Hant_TW' => 'Sínis (Traidisiúnta, an Téaváin)',
        'zh_MO' => 'Sínis (Sainréigiún Riaracháin Macao, Daonphoblacht na Síne)',
        'zh_SG' => 'Sínis (Singeapór)',
        'zh_TW' => 'Sínis (an Téaváin)',
        'zu' => 'Súlúis',
        'zu_ZA' => 'Súlúis (an Afraic Theas)',
    ],
];
