<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ग्रीनविच मीन टाइम (Abidjan)',
        'Africa/Accra' => 'ग्रीनविच मीन टाइम (Accra)',
        'Africa/Addis_Ababa' => 'पूर्वी अफ़्रीका समय (Addis Ababa)',
        'Africa/Algiers' => 'मध्य यूरोपीय समय (Algiers)',
        'Africa/Asmera' => 'पूर्वी अफ़्रीका समय (Asmera)',
        'Africa/Bamako' => 'ग्रीनविच मीन टाइम (Bamako)',
        'Africa/Bangui' => 'पश्चिम अफ़्रीका समय (Bangui)',
        'Africa/Banjul' => 'ग्रीनविच मीन टाइम (Banjul)',
        'Africa/Bissau' => 'ग्रीनविच मीन टाइम (Bissau)',
        'Africa/Blantyre' => 'मध्य अफ़्रीका समय (Blantyre)',
        'Africa/Brazzaville' => 'पश्चिम अफ़्रीका समय (Brazzaville)',
        'Africa/Bujumbura' => 'मध्य अफ़्रीका समय (Bujumbura)',
        'Africa/Cairo' => 'पूर्वी यूरोपीय समय (Cairo)',
        'Africa/Casablanca' => 'पश्चिमी यूरोपीय समय (Casablanca)',
        'Africa/Ceuta' => 'मध्य यूरोपीय समय (Ceuta)',
        'Africa/Conakry' => 'ग्रीनविच मीन टाइम (Conakry)',
        'Africa/Dakar' => 'ग्रीनविच मीन टाइम (Dakar)',
        'Africa/Dar_es_Salaam' => 'पूर्वी अफ़्रीका समय (Dar es Salaam)',
        'Africa/Djibouti' => 'पूर्वी अफ़्रीका समय (Djibouti)',
        'Africa/Douala' => 'पश्चिम अफ़्रीका समय (Douala)',
        'Africa/El_Aaiun' => 'पश्चिमी यूरोपीय समय (El Aaiun)',
        'Africa/Freetown' => 'ग्रीनविच मीन टाइम (Freetown)',
        'Africa/Gaborone' => 'मध्य अफ़्रीका समय (Gaborone)',
        'Africa/Harare' => 'मध्य अफ़्रीका समय (Harare)',
        'Africa/Johannesburg' => 'दक्षिण अफ़्रीका मानक समय (Johannesburg)',
        'Africa/Juba' => 'मध्य अफ़्रीका समय (Juba)',
        'Africa/Kampala' => 'पूर्वी अफ़्रीका समय (Kampala)',
        'Africa/Khartoum' => 'मध्य अफ़्रीका समय (Khartoum)',
        'Africa/Kigali' => 'मध्य अफ़्रीका समय (Kigali)',
        'Africa/Kinshasa' => 'पश्चिम अफ़्रीका समय (Kinshasa)',
        'Africa/Lagos' => 'पश्चिम अफ़्रीका समय (Lagos)',
        'Africa/Libreville' => 'पश्चिम अफ़्रीका समय (Libreville)',
        'Africa/Lome' => 'ग्रीनविच मीन टाइम (Lome)',
        'Africa/Luanda' => 'पश्चिम अफ़्रीका समय (Luanda)',
        'Africa/Lubumbashi' => 'मध्य अफ़्रीका समय (Lubumbashi)',
        'Africa/Lusaka' => 'मध्य अफ़्रीका समय (Lusaka)',
        'Africa/Malabo' => 'पश्चिम अफ़्रीका समय (Malabo)',
        'Africa/Maputo' => 'मध्य अफ़्रीका समय (Maputo)',
        'Africa/Maseru' => 'दक्षिण अफ़्रीका मानक समय (Maseru)',
        'Africa/Mbabane' => 'दक्षिण अफ़्रीका मानक समय (Mbabane)',
        'Africa/Mogadishu' => 'पूर्वी अफ़्रीका समय (Mogadishu)',
        'Africa/Monrovia' => 'ग्रीनविच मीन टाइम (Monrovia)',
        'Africa/Nairobi' => 'पूर्वी अफ़्रीका समय (Nairobi)',
        'Africa/Ndjamena' => 'पश्चिम अफ़्रीका समय (Ndjamena)',
        'Africa/Niamey' => 'पश्चिम अफ़्रीका समय (Niamey)',
        'Africa/Nouakchott' => 'ग्रीनविच मीन टाइम (Nouakchott)',
        'Africa/Ouagadougou' => 'ग्रीनविच मीन टाइम (Ouagadougou)',
        'Africa/Porto-Novo' => 'पश्चिम अफ़्रीका समय (Porto Novo)',
        'Africa/Sao_Tome' => 'ग्रीनविच मीन टाइम (Sao Tome)',
        'Africa/Tripoli' => 'पूर्वी यूरोपीय समय (Tripoli)',
        'Africa/Tunis' => 'मध्य यूरोपीय समय (Tunis)',
        'Africa/Windhoek' => 'मध्य अफ़्रीका समय (Windhoek)',
        'America/Adak' => 'हवाई–आल्यूशन समय (Adak)',
        'America/Anchorage' => 'अलास्का समय (Anchorage)',
        'America/Anguilla' => 'अटलांटिक समय (Anguilla)',
        'America/Antigua' => 'अटलांटिक समय (Antigua)',
        'America/Araguaina' => 'ब्राज़ीलिया समय (Araguaina)',
        'America/Argentina/La_Rioja' => 'अर्जेंटीना समय (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'अर्जेंटीना समय (Rio Gallegos)',
        'America/Argentina/Salta' => 'अर्जेंटीना समय (Salta)',
        'America/Argentina/San_Juan' => 'अर्जेंटीना समय (San Juan)',
        'America/Argentina/San_Luis' => 'अर्जेंटीना समय (San Luis)',
        'America/Argentina/Tucuman' => 'अर्जेंटीना समय (Tucuman)',
        'America/Argentina/Ushuaia' => 'अर्जेंटीना समय (Ushuaia)',
        'America/Aruba' => 'अटलांटिक समय (Aruba)',
        'America/Asuncion' => 'पैराग्वे समय (Asuncion)',
        'America/Bahia' => 'ब्राज़ीलिया समय (Bahia)',
        'America/Bahia_Banderas' => 'North America Central Time (Bahia Banderas)',
        'America/Barbados' => 'अटलांटिक समय (Barbados)',
        'America/Belem' => 'ब्राज़ीलिया समय (Belem)',
        'America/Belize' => 'North America Central Time (Belize)',
        'America/Blanc-Sablon' => 'अटलांटिक समय (Blanc Sablon)',
        'America/Boa_Vista' => 'अमेज़न समय (Boa Vista)',
        'America/Bogota' => 'कोलंबिया समय (Bogota)',
        'America/Boise' => 'North America Mountain Time (Boise)',
        'America/Buenos_Aires' => 'अर्जेंटीना समय (Buenos Aires)',
        'America/Cambridge_Bay' => 'North America Mountain Time (Cambridge Bay)',
        'America/Campo_Grande' => 'अमेज़न समय (Campo Grande)',
        'America/Cancun' => 'North America Eastern Time (Cancun)',
        'America/Caracas' => 'वेनेज़ुएला समय (Caracas)',
        'America/Catamarca' => 'अर्जेंटीना समय (Catamarca)',
        'America/Cayenne' => 'फ़्रेंच गुयाना समय (Cayenne)',
        'America/Cayman' => 'North America Eastern Time (Cayman)',
        'America/Chicago' => 'North America Central Time (Chicago)',
        'America/Chihuahua' => 'मेक्सिकन प्रशांत समय (Chihuahua)',
        'America/Coral_Harbour' => 'North America Eastern Time (Coral Harbour)',
        'America/Cordoba' => 'अर्जेंटीना समय (Cordoba)',
        'America/Costa_Rica' => 'North America Central Time (Costa Rica)',
        'America/Creston' => 'North America Mountain Time (Creston)',
        'America/Cuiaba' => 'अमेज़न समय (Cuiaba)',
        'America/Curacao' => 'अटलांटिक समय (Curacao)',
        'America/Danmarkshavn' => 'ग्रीनविच मीन टाइम (Danmarkshavn)',
        'America/Dawson' => 'युकॉन समय (Dawson)',
        'America/Dawson_Creek' => 'North America Mountain Time (Dawson Creek)',
        'America/Denver' => 'North America Mountain Time (Denver)',
        'America/Detroit' => 'North America Eastern Time (Detroit)',
        'America/Dominica' => 'अटलांटिक समय (Dominica)',
        'America/Edmonton' => 'North America Mountain Time (Edmonton)',
        'America/Eirunepe' => 'ब्राज़ील समय (Eirunepe)',
        'America/El_Salvador' => 'North America Central Time (El Salvador)',
        'America/Fort_Nelson' => 'North America Mountain Time (Fort Nelson)',
        'America/Fortaleza' => 'ब्राज़ीलिया समय (Fortaleza)',
        'America/Glace_Bay' => 'अटलांटिक समय (Glace Bay)',
        'America/Goose_Bay' => 'अटलांटिक समय (Goose Bay)',
        'America/Grand_Turk' => 'North America Eastern Time (Grand Turk)',
        'America/Grenada' => 'अटलांटिक समय (Grenada)',
        'America/Guadeloupe' => 'अटलांटिक समय (Guadeloupe)',
        'America/Guatemala' => 'North America Central Time (Guatemala)',
        'America/Guayaquil' => 'इक्वाडोर समय (Guayaquil)',
        'America/Guyana' => 'गुयाना समय (Guyana)',
        'America/Halifax' => 'अटलांटिक समय (Halifax)',
        'America/Havana' => 'क्यूबा समय (Havana)',
        'America/Hermosillo' => 'मेक्सिकन प्रशांत समय (Hermosillo)',
        'America/Indiana/Knox' => 'North America Central Time (Knox, Indiana)',
        'America/Indiana/Marengo' => 'North America Eastern Time (मारेंगो, इंडियाना)',
        'America/Indiana/Petersburg' => 'North America Eastern Time (पीटर्सबर्ग, इंडियाना)',
        'America/Indiana/Tell_City' => 'North America Central Time (टेल सिटी, इंडियाना)',
        'America/Indiana/Vevay' => 'North America Eastern Time (वेवे, इंडियाना)',
        'America/Indiana/Vincennes' => 'North America Eastern Time (विंसेनेस, इंडियाना)',
        'America/Indiana/Winamac' => 'North America Eastern Time (विनामेक, इंडियाना)',
        'America/Indianapolis' => 'North America Eastern Time (Indianapolis)',
        'America/Inuvik' => 'North America Mountain Time (Inuvik)',
        'America/Iqaluit' => 'North America Eastern Time (Iqaluit)',
        'America/Jamaica' => 'North America Eastern Time (Jamaica)',
        'America/Jujuy' => 'अर्जेंटीना समय (Jujuy)',
        'America/Juneau' => 'अलास्का समय (Juneau)',
        'America/Kentucky/Monticello' => 'North America Eastern Time (मोंटीसेलो, केंटकी)',
        'America/Kralendijk' => 'अटलांटिक समय (Kralendijk)',
        'America/La_Paz' => 'बोलीविया समय (La Paz)',
        'America/Lima' => 'पेरू समय (Lima)',
        'America/Los_Angeles' => 'North America Pacific Time (Los Angeles)',
        'America/Louisville' => 'North America Eastern Time (Louisville)',
        'America/Maceio' => 'ब्राज़ीलिया समय (Maceio)',
        'America/Managua' => 'North America Central Time (Managua)',
        'America/Manaus' => 'अमेज़न समय (Manaus)',
        'America/Marigot' => 'अटलांटिक समय (Marigot)',
        'America/Martinique' => 'अटलांटिक समय (Martinique)',
        'America/Matamoros' => 'North America Central Time (Matamoros)',
        'America/Mazatlan' => 'मेक्सिकन प्रशांत समय (Mazatlan)',
        'America/Mendoza' => 'अर्जेंटीना समय (Mendoza)',
        'America/Menominee' => 'North America Central Time (Menominee)',
        'America/Merida' => 'North America Central Time (Merida)',
        'America/Metlakatla' => 'अलास्का समय (Metlakatla)',
        'America/Mexico_City' => 'North America Central Time (Mexico City)',
        'America/Miquelon' => 'St. Pierre & Miquelon Time',
        'America/Moncton' => 'अटलांटिक समय (Moncton)',
        'America/Monterrey' => 'North America Central Time (Monterrey)',
        'America/Montevideo' => 'उरुग्वे समय (Montevideo)',
        'America/Montserrat' => 'अटलांटिक समय (Montserrat)',
        'America/Nassau' => 'North America Eastern Time (Nassau)',
        'America/New_York' => 'North America Eastern Time (New York)',
        'America/Nipigon' => 'North America Eastern Time (Nipigon)',
        'America/Nome' => 'अलास्का समय (Nome)',
        'America/Noronha' => 'फ़र्नांर्डो डे नोरोन्हा समय (Noronha)',
        'America/North_Dakota/Beulah' => 'North America Central Time (ब्यूला, उत्तरी डकोटा)',
        'America/North_Dakota/Center' => 'North America Central Time (मध्य, उत्तरी दाकोता)',
        'America/North_Dakota/New_Salem' => 'North America Central Time (न्यू सालेम, उत्तरी डकोटा)',
        'America/Ojinaga' => 'North America Mountain Time (Ojinaga)',
        'America/Panama' => 'North America Eastern Time (Panama)',
        'America/Pangnirtung' => 'North America Eastern Time (Pangnirtung)',
        'America/Paramaribo' => 'सूरीनाम समय (Paramaribo)',
        'America/Phoenix' => 'North America Mountain Time (Phoenix)',
        'America/Port-au-Prince' => 'North America Eastern Time (Port-au-Prince)',
        'America/Port_of_Spain' => 'अटलांटिक समय (Port of Spain)',
        'America/Porto_Velho' => 'अमेज़न समय (Porto Velho)',
        'America/Puerto_Rico' => 'अटलांटिक समय (Puerto Rico)',
        'America/Punta_Arenas' => 'चिली समय (Punta Arenas)',
        'America/Rainy_River' => 'North America Central Time (Rainy River)',
        'America/Rankin_Inlet' => 'North America Central Time (Rankin Inlet)',
        'America/Recife' => 'ब्राज़ीलिया समय (Recife)',
        'America/Regina' => 'North America Central Time (Regina)',
        'America/Resolute' => 'North America Central Time (Resolute)',
        'America/Rio_Branco' => 'ब्राज़ील समय (Rio Branco)',
        'America/Santarem' => 'ब्राज़ीलिया समय (Santarem)',
        'America/Santiago' => 'चिली समय (Santiago)',
        'America/Santo_Domingo' => 'अटलांटिक समय (Santo Domingo)',
        'America/Sao_Paulo' => 'ब्राज़ीलिया समय (Sao Paulo)',
        'America/Sitka' => 'अलास्का समय (Sitka)',
        'America/St_Barthelemy' => 'अटलांटिक समय (St Barthelemy)',
        'America/Swift_Current' => 'North America Central Time (Swift Current)',
        'America/Tegucigalpa' => 'North America Central Time (Tegucigalpa)',
        'America/Thule' => 'अटलांटिक समय (Thule)',
        'America/Thunder_Bay' => 'North America Eastern Time (Thunder Bay)',
        'America/Tijuana' => 'North America Pacific Time (Tijuana)',
        'America/Toronto' => 'North America Eastern Time (Toronto)',
        'America/Tortola' => 'अटलांटिक समय (Tortola)',
        'America/Vancouver' => 'North America Pacific Time (Vancouver)',
        'America/Whitehorse' => 'युकॉन समय (Whitehorse)',
        'America/Winnipeg' => 'North America Central Time (Winnipeg)',
        'America/Yakutat' => 'अलास्का समय (Yakutat)',
        'America/Yellowknife' => 'North America Mountain Time (Yellowknife)',
        'Antarctica/Casey' => 'अंटार्कटिका समय (Casey)',
        'Antarctica/Davis' => 'डेविस समय (Davis)',
        'Antarctica/DumontDUrville' => 'ड्यूमोंट डी अर्विले समय (DumontDUrville)',
        'Antarctica/Macquarie' => 'पूर्वी ऑस्ट्रेलिया समय (Macquarie)',
        'Antarctica/Mawson' => 'माव्सन समय (Mawson)',
        'Antarctica/McMurdo' => 'न्यूज़ीलैंड समय (McMurdo)',
        'Antarctica/Palmer' => 'चिली समय (Palmer)',
        'Antarctica/Rothera' => 'रोथेरा समय (Rothera)',
        'Antarctica/Syowa' => 'स्योवा समय (Syowa)',
        'Antarctica/Troll' => 'ग्रीनविच मीन टाइम (Troll)',
        'Antarctica/Vostok' => 'वोस्तोक समय (Vostok)',
        'Arctic/Longyearbyen' => 'मध्य यूरोपीय समय (Longyearbyen)',
        'Asia/Aden' => 'अरब समय (Aden)',
        'Asia/Almaty' => 'पूर्व कज़ाखस्तान समय (Almaty)',
        'Asia/Amman' => 'पूर्वी यूरोपीय समय (Amman)',
        'Asia/Anadyr' => 'एनाडीयर समय (Anadyr)',
        'Asia/Aqtau' => 'पश्चिम कज़ाखस्तान समय (Aqtau)',
        'Asia/Aqtobe' => 'पश्चिम कज़ाखस्तान समय (Aqtobe)',
        'Asia/Ashgabat' => 'तुर्कमेनिस्तान समय (Ashgabat)',
        'Asia/Atyrau' => 'पश्चिम कज़ाखस्तान समय (Atyrau)',
        'Asia/Baghdad' => 'अरब समय (Baghdad)',
        'Asia/Bahrain' => 'अरब समय (Bahrain)',
        'Asia/Baku' => 'अज़रबैजान समय (Baku)',
        'Asia/Bangkok' => 'इंडोचाइना समय (Bangkok)',
        'Asia/Barnaul' => 'रूस समय (Barnaul)',
        'Asia/Beirut' => 'पूर्वी यूरोपीय समय (Beirut)',
        'Asia/Bishkek' => 'किर्गिस्‍तान समय (Bishkek)',
        'Asia/Brunei' => 'ब्रूनेई दारूस्सलम समय (Brunei)',
        'Asia/Calcutta' => 'भारतीय मानक समय (Kolkata)',
        'Asia/Chita' => 'याकुत्स्क समय (Chita)',
        'Asia/Choibalsan' => 'उलान बटोर समय (Choibalsan)',
        'Asia/Colombo' => 'भारतीय मानक समय (Colombo)',
        'Asia/Damascus' => 'पूर्वी यूरोपीय समय (Damascus)',
        'Asia/Dhaka' => 'बांग्लादेश समय (Dhaka)',
        'Asia/Dili' => 'पूर्वी तिमोर समय (Dili)',
        'Asia/Dubai' => 'खाड़ी मानक समय (Dubai)',
        'Asia/Dushanbe' => 'ताजिकिस्तान समय (Dushanbe)',
        'Asia/Famagusta' => 'पूर्वी यूरोपीय समय (Famagusta)',
        'Asia/Gaza' => 'पूर्वी यूरोपीय समय (Gaza)',
        'Asia/Hebron' => 'पूर्वी यूरोपीय समय (Hebron)',
        'Asia/Hong_Kong' => 'हाँग काँग समय (Hong Kong)',
        'Asia/Hovd' => 'होव्ड समय (Hovd)',
        'Asia/Irkutsk' => 'इर्कुत्स्क समय (Irkutsk)',
        'Asia/Jakarta' => 'पश्चिमी इंडोनेशिया समय (Jakarta)',
        'Asia/Jayapura' => 'पूर्वी इंडोनेशिया समय (Jayapura)',
        'Asia/Jerusalem' => 'इज़राइल समय (Jerusalem)',
        'Asia/Kabul' => 'अफ़गानिस्तान समय (Kabul)',
        'Asia/Kamchatka' => 'पेट्रोपेवलास्क-कैमचात्सकी समय (Kamchatka)',
        'Asia/Karachi' => 'पाकिस्तान समय (Karachi)',
        'Asia/Khandyga' => 'याकुत्स्क समय (Khandyga)',
        'Asia/Krasnoyarsk' => 'क्रास्नोयार्स्क समय (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'मलेशिया समय (Kuala Lumpur)',
        'Asia/Kuching' => 'मलेशिया समय (Kuching)',
        'Asia/Kuwait' => 'अरब समय (Kuwait)',
        'Asia/Macau' => 'चीन समय (Macau)',
        'Asia/Magadan' => 'मागादान समय (Magadan)',
        'Asia/Makassar' => 'मध्य इंडोनेशिया समय (Makassar)',
        'Asia/Manila' => 'फ़िलिपीन समय (Manila)',
        'Asia/Muscat' => 'खाड़ी मानक समय (Muscat)',
        'Asia/Nicosia' => 'पूर्वी यूरोपीय समय (Nicosia)',
        'Asia/Novokuznetsk' => 'क्रास्नोयार्स्क समय (Novokuznetsk)',
        'Asia/Novosibirsk' => 'नोवोसिबिर्स्क समय (Novosibirsk)',
        'Asia/Omsk' => 'ओम्स्क समय (Omsk)',
        'Asia/Oral' => 'पश्चिम कज़ाखस्तान समय (Oral)',
        'Asia/Phnom_Penh' => 'इंडोचाइना समय (Phnom Penh)',
        'Asia/Pontianak' => 'पश्चिमी इंडोनेशिया समय (Pontianak)',
        'Asia/Pyongyang' => 'कोरियाई समय (Pyongyang)',
        'Asia/Qatar' => 'अरब समय (Qatar)',
        'Asia/Qostanay' => 'पूर्व कज़ाखस्तान समय (Qostanay)',
        'Asia/Qyzylorda' => 'पश्चिम कज़ाखस्तान समय (Qyzylorda)',
        'Asia/Riyadh' => 'अरब समय (Riyadh)',
        'Asia/Saigon' => 'इंडोचाइना समय (Saigon)',
        'Asia/Sakhalin' => 'सखालिन समय (Sakhalin)',
        'Asia/Samarkand' => 'उज़्बेकिस्तान समय (Samarkand)',
        'Asia/Seoul' => 'कोरियाई समय (Seoul)',
        'Asia/Shanghai' => 'चीन समय (Shanghai)',
        'Asia/Singapore' => 'सिंगापुर समय (Singapore)',
        'Asia/Srednekolymsk' => 'मागादान समय (Srednekolymsk)',
        'Asia/Taipei' => 'ताइपे समय (Taipei)',
        'Asia/Tashkent' => 'उज़्बेकिस्तान समय (Tashkent)',
        'Asia/Tbilisi' => 'जॉर्जिया समय (Tbilisi)',
        'Asia/Tehran' => 'ईरान समय (Tehran)',
        'Asia/Thimphu' => 'भूटान समय (Thimphu)',
        'Asia/Tokyo' => 'जापान समय (Tokyo)',
        'Asia/Tomsk' => 'रूस समय (Tomsk)',
        'Asia/Ulaanbaatar' => 'उलान बटोर समय (Ulaanbaatar)',
        'Asia/Urumqi' => 'चीन समय (Urumqi)',
        'Asia/Ust-Nera' => 'व्लादिवोस्तोक समय (Ust-Nera)',
        'Asia/Vientiane' => 'इंडोचाइना समय (Vientiane)',
        'Asia/Vladivostok' => 'व्लादिवोस्तोक समय (Vladivostok)',
        'Asia/Yakutsk' => 'याकुत्स्क समय (Yakutsk)',
        'Asia/Yekaterinburg' => 'येकातेरिनबर्ग समय (Yekaterinburg)',
        'Asia/Yerevan' => 'आर्मेनिया समय (Yerevan)',
        'Atlantic/Azores' => 'अज़ोरेस समय (Azores)',
        'Atlantic/Bermuda' => 'अटलांटिक समय (Bermuda)',
        'Atlantic/Canary' => 'पश्चिमी यूरोपीय समय (Canary)',
        'Atlantic/Cape_Verde' => 'केप वर्ड समय (Cape Verde)',
        'Atlantic/Faeroe' => 'पश्चिमी यूरोपीय समय (Faeroe)',
        'Atlantic/Madeira' => 'पश्चिमी यूरोपीय समय (Madeira)',
        'Atlantic/Reykjavik' => 'ग्रीनविच मीन टाइम (Reykjavik)',
        'Atlantic/South_Georgia' => 'दक्षिणी जॉर्जिया समय (South Georgia)',
        'Atlantic/Stanley' => 'फ़ॉकलैंड द्वीपसमूह समय (Stanley)',
        'Australia/Adelaide' => 'मध्य ऑस्ट्रेलियाई समय (Adelaide)',
        'Australia/Brisbane' => 'पूर्वी ऑस्ट्रेलिया समय (Brisbane)',
        'Australia/Broken_Hill' => 'मध्य ऑस्ट्रेलियाई समय (Broken Hill)',
        'Australia/Darwin' => 'मध्य ऑस्ट्रेलियाई समय (Darwin)',
        'Australia/Eucla' => 'ऑस्‍ट्रेलियाई केंद्रीय पश्चिमी समय (Eucla)',
        'Australia/Hobart' => 'पूर्वी ऑस्ट्रेलिया समय (Hobart)',
        'Australia/Lindeman' => 'पूर्वी ऑस्ट्रेलिया समय (Lindeman)',
        'Australia/Lord_Howe' => 'लॉर्ड होवे समय (Lord Howe)',
        'Australia/Melbourne' => 'पूर्वी ऑस्ट्रेलिया समय (Melbourne)',
        'Australia/Perth' => 'पश्चिमी ऑस्ट्रेलिया समय (Perth)',
        'Australia/Sydney' => 'पूर्वी ऑस्ट्रेलिया समय (Sydney)',
        'CST6CDT' => 'North America Central Time',
        'EST5EDT' => 'North America Eastern Time',
        'Europe/Amsterdam' => 'मध्य यूरोपीय समय (Amsterdam)',
        'Europe/Andorra' => 'मध्य यूरोपीय समय (Andorra)',
        'Europe/Astrakhan' => 'मॉस्को समय (Astrakhan)',
        'Europe/Athens' => 'पूर्वी यूरोपीय समय (Athens)',
        'Europe/Belgrade' => 'मध्य यूरोपीय समय (Belgrade)',
        'Europe/Berlin' => 'मध्य यूरोपीय समय (Berlin)',
        'Europe/Bratislava' => 'मध्य यूरोपीय समय (Bratislava)',
        'Europe/Brussels' => 'मध्य यूरोपीय समय (Brussels)',
        'Europe/Bucharest' => 'पूर्वी यूरोपीय समय (Bucharest)',
        'Europe/Budapest' => 'मध्य यूरोपीय समय (Budapest)',
        'Europe/Busingen' => 'मध्य यूरोपीय समय (Busingen)',
        'Europe/Chisinau' => 'पूर्वी यूरोपीय समय (Chisinau)',
        'Europe/Copenhagen' => 'मध्य यूरोपीय समय (Copenhagen)',
        'Europe/Dublin' => 'ग्रीनविच मीन टाइम (Dublin)',
        'Europe/Gibraltar' => 'मध्य यूरोपीय समय (Gibraltar)',
        'Europe/Guernsey' => 'ग्रीनविच मीन टाइम (Guernsey)',
        'Europe/Helsinki' => 'पूर्वी यूरोपीय समय (Helsinki)',
        'Europe/Isle_of_Man' => 'ग्रीनविच मीन टाइम (Isle of Man)',
        'Europe/Istanbul' => 'तुर्की समय (Istanbul)',
        'Europe/Jersey' => 'ग्रीनविच मीन टाइम (Jersey)',
        'Europe/Kaliningrad' => 'पूर्वी यूरोपीय समय (Kaliningrad)',
        'Europe/Kirov' => 'रूस समय (Kirov)',
        'Europe/Lisbon' => 'पश्चिमी यूरोपीय समय (Lisbon)',
        'Europe/Ljubljana' => 'मध्य यूरोपीय समय (Ljubljana)',
        'Europe/London' => 'ग्रीनविच मीन टाइम (London)',
        'Europe/Luxembourg' => 'मध्य यूरोपीय समय (Luxembourg)',
        'Europe/Madrid' => 'मध्य यूरोपीय समय (Madrid)',
        'Europe/Malta' => 'मध्य यूरोपीय समय (Malta)',
        'Europe/Mariehamn' => 'पूर्वी यूरोपीय समय (Mariehamn)',
        'Europe/Minsk' => 'मॉस्को समय (Minsk)',
        'Europe/Monaco' => 'मध्य यूरोपीय समय (Monaco)',
        'Europe/Moscow' => 'मॉस्को समय (Moscow)',
        'Europe/Oslo' => 'मध्य यूरोपीय समय (Oslo)',
        'Europe/Paris' => 'मध्य यूरोपीय समय (Paris)',
        'Europe/Podgorica' => 'मध्य यूरोपीय समय (Podgorica)',
        'Europe/Prague' => 'मध्य यूरोपीय समय (Prague)',
        'Europe/Riga' => 'पूर्वी यूरोपीय समय (Riga)',
        'Europe/Rome' => 'मध्य यूरोपीय समय (Rome)',
        'Europe/Samara' => 'समारा समय (Samara)',
        'Europe/San_Marino' => 'मध्य यूरोपीय समय (San Marino)',
        'Europe/Sarajevo' => 'मध्य यूरोपीय समय (Sarajevo)',
        'Europe/Saratov' => 'मॉस्को समय (Saratov)',
        'Europe/Simferopol' => 'मॉस्को समय (Simferopol)',
        'Europe/Skopje' => 'मध्य यूरोपीय समय (Skopje)',
        'Europe/Sofia' => 'पूर्वी यूरोपीय समय (Sofia)',
        'Europe/Stockholm' => 'मध्य यूरोपीय समय (Stockholm)',
        'Europe/Tallinn' => 'पूर्वी यूरोपीय समय (Tallinn)',
        'Europe/Tirane' => 'मध्य यूरोपीय समय (Tirane)',
        'Europe/Ulyanovsk' => 'मॉस्को समय (Ulyanovsk)',
        'Europe/Uzhgorod' => 'पूर्वी यूरोपीय समय (Uzhgorod)',
        'Europe/Vaduz' => 'मध्य यूरोपीय समय (Vaduz)',
        'Europe/Vatican' => 'मध्य यूरोपीय समय (Vatican)',
        'Europe/Vienna' => 'मध्य यूरोपीय समय (Vienna)',
        'Europe/Vilnius' => 'पूर्वी यूरोपीय समय (Vilnius)',
        'Europe/Volgograd' => 'वोल्गोग्राड समय (Volgograd)',
        'Europe/Warsaw' => 'मध्य यूरोपीय समय (Warsaw)',
        'Europe/Zagreb' => 'मध्य यूरोपीय समय (Zagreb)',
        'Europe/Zaporozhye' => 'पूर्वी यूरोपीय समय (Zaporozhye)',
        'Europe/Zurich' => 'मध्य यूरोपीय समय (Zurich)',
        'Indian/Antananarivo' => 'पूर्वी अफ़्रीका समय (Antananarivo)',
        'Indian/Chagos' => 'हिंद महासागर समय (Chagos)',
        'Indian/Christmas' => 'क्रिसमस द्वीप समय (Christmas)',
        'Indian/Cocos' => 'कोकोस द्वीपसमूह समय (Cocos)',
        'Indian/Comoro' => 'पूर्वी अफ़्रीका समय (Comoro)',
        'Indian/Kerguelen' => 'दक्षिणी फ़्रांस और अंटार्कटिक समय (Kerguelen)',
        'Indian/Mahe' => 'सेशेल्स समय (Mahe)',
        'Indian/Maldives' => 'मालदीव समय (Maldives)',
        'Indian/Mauritius' => 'मॉरीशस समय (Mauritius)',
        'Indian/Mayotte' => 'पूर्वी अफ़्रीका समय (Mayotte)',
        'Indian/Reunion' => 'Reunion Time',
        'MST7MDT' => 'North America Mountain Time',
        'PST8PDT' => 'North America Pacific Time',
        'Pacific/Apia' => 'एपिआ समय (Apia)',
        'Pacific/Auckland' => 'न्यूज़ीलैंड समय (Auckland)',
        'Pacific/Bougainville' => 'पापुआ न्यू गिनी समय (Bougainville)',
        'Pacific/Chatham' => 'चैथम समय (Chatham)',
        'Pacific/Easter' => 'ईस्टर द्वीप समय (Easter)',
        'Pacific/Efate' => 'वनुआतू समय (Efate)',
        'Pacific/Fakaofo' => 'टोकेलाऊ समय (Fakaofo)',
        'Pacific/Fiji' => 'फ़िजी समय (Fiji)',
        'Pacific/Funafuti' => 'तुवालू समय (Funafuti)',
        'Pacific/Galapagos' => 'गैलापेगोस का समय (Galapagos)',
        'Pacific/Gambier' => 'गैंबियर समय (Gambier)',
        'Pacific/Guadalcanal' => 'सोलोमन द्वीपसमूह समय (Guadalcanal)',
        'Pacific/Guam' => 'चामोरो मानक समय (Guam)',
        'Pacific/Honolulu' => 'हवाई–आल्यूशन समय (Honolulu)',
        'Pacific/Johnston' => 'हवाई–आल्यूशन समय (Johnston)',
        'Pacific/Kiritimati' => 'लाइन द्वीपसमूह समय (Kiritimati)',
        'Pacific/Kosrae' => 'कोसराए समय (Kosrae)',
        'Pacific/Kwajalein' => 'मार्शल द्वीपसमूह समय (Kwajalein)',
        'Pacific/Majuro' => 'मार्शल द्वीपसमूह समय (Majuro)',
        'Pacific/Marquesas' => 'मार्केसस समय (Marquesas)',
        'Pacific/Midway' => 'समोआ समय (Midway)',
        'Pacific/Nauru' => 'नौरू समय (Nauru)',
        'Pacific/Niue' => 'नीयू समय (Niue)',
        'Pacific/Norfolk' => 'नॉरफ़ॉक द्वीप समय (Norfolk)',
        'Pacific/Noumea' => 'न्यू कैलेडोनिया समय (Noumea)',
        'Pacific/Pago_Pago' => 'समोआ समय (Pago Pago)',
        'Pacific/Palau' => 'पलाउ समय (Palau)',
        'Pacific/Pitcairn' => 'पिटकैर्न समय (Pitcairn)',
        'Pacific/Ponape' => 'पोनापे समय (Ponape)',
        'Pacific/Port_Moresby' => 'पापुआ न्यू गिनी समय (Port Moresby)',
        'Pacific/Rarotonga' => 'कुक द्वीपसमूह समय (Rarotonga)',
        'Pacific/Saipan' => 'चामोरो मानक समय (Saipan)',
        'Pacific/Tahiti' => 'ताहिती समय (Tahiti)',
        'Pacific/Tarawa' => 'गिल्बर्ट द्वीपसमूह समय (Tarawa)',
        'Pacific/Tongatapu' => 'टोंगा समय (Tongatapu)',
        'Pacific/Truk' => 'चुक समय (Truk)',
        'Pacific/Wake' => 'वेक द्वीप समय (Wake)',
        'Pacific/Wallis' => 'वालिस और फ़्यूचूना समय (Wallis)',
    ],
    'Meta' => [
    ],
];
