<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Aghb' => 'albanishte e Kaukazit',
        'Ahom' => 'ahomisht',
        'Arab' => 'arabik',
        'Aran' => 'nastalik',
        'Armi' => 'aramaishte perandorake',
        'Armn' => 'armen',
        'Avst' => 'avestanisht',
        'Bali' => 'bali',
        'Bamu' => 'bamu',
        'Bass' => 'basavahisht',
        'Batk' => 'batak',
        'Beng' => 'bengal',
        'Bhks' => 'baiksukisht',
        'Bopo' => 'bopomof',
        'Brah' => 'brahmisht',
        'Brai' => 'brailisht',
        'Bugi' => 'buginisht',
        'Buhd' => 'buhidisht',
        'Cakm' => 'çakma',
        'Cans' => 'rrokje të unifikuara aborigjene kanadeze',
        'Cari' => 'karianisht',
        'Cham' => 'çam',
        'Cher' => 'çeroki',
        'Chrs' => 'korasmianisht',
        'Copt' => 'koptisht',
        'Cpmn' => 'minoishte e Qipros',
        'Cprt' => 'qipriotisht',
        'Cyrl' => 'cirilik',
        'Deva' => 'devanagar',
        'Diak' => 'divesakuruisht',
        'Dogr' => 'dograisht',
        'Dsrt' => 'deseretisht',
        'Dupl' => 'duplojanisht - formë e shkurtër',
        'Egyp' => 'hieroglife egjiptiane',
        'Elba' => 'shkrim i Elbasanit',
        'Elym' => 'elimaisht',
        'Ethi' => 'etiopik',
        'Geor' => 'gjeorgjian',
        'Glag' => 'glagolitikisht',
        'Gong' => 'gong',
        'Gonm' => 'masaramgondisht',
        'Goth' => 'gotik',
        'Gran' => 'grantaisht',
        'Grek' => 'grek',
        'Gujr' => 'guxharat',
        'Guru' => 'gurmuk',
        'Hanb' => 'hanbik',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoisht',
        'Hans' => 'i thjeshtuar',
        'Hant' => 'tradicional',
        'Hatr' => 'hatranisht',
        'Hebr' => 'hebraik',
        'Hira' => 'hiragan',
        'Hluw' => 'hieroglife anatoliane',
        'Hmng' => 'pahauhmonisht',
        'Hmnp' => 'niakeng puaçue hmong',
        'Hrkt' => 'alfabet rrokjesor japonez',
        'Hung' => 'hungarishte e vjetër',
        'Ital' => 'italishte e vjetër',
        'Jamo' => 'jamosisht',
        'Java' => 'java',
        'Jpan' => 'japonez',
        'Kali' => 'kajali',
        'Kana' => 'katakan',
        'Kawi' => 'kavi',
        'Khar' => 'karoshtisht',
        'Khmr' => 'kmer',
        'Khoj' => 'koxhkisht',
        'Kits' => 'shkrim i vogël kitan',
        'Knda' => 'kanad',
        'Kore' => 'korean',
        'Kthi' => 'kaitisht',
        'Lana' => 'lana',
        'Laoo' => 'laosisht',
        'Latn' => 'latin',
        'Lepc' => 'lepça',
        'Limb' => 'limbu',
        'Lina' => 'Linear A',
        'Linb' => 'Linear B',
        'Lisu' => 'fraser',
        'Lyci' => 'licianisht',
        'Lydi' => 'lidianisht',
        'Mahj' => 'mahaxhanisht',
        'Maka' => 'makasarisht',
        'Mand' => 'mande',
        'Mani' => 'manikeanisht',
        'Marc' => 'markenisht',
        'Medf' => 'medefaidrinisht',
        'Mend' => 'mendeisht',
        'Merc' => 'meroitik kursiv',
        'Mero' => 'meroitik',
        'Mlym' => 'malajalam',
        'Modi' => 'modisht',
        'Mong' => 'mongolisht',
        'Mroo' => 'mroisht',
        'Mtei' => 'mitei-majek',
        'Mult' => 'multanisht',
        'Mymr' => 'birman',
        'Nagm' => 'nag mundari',
        'Nand' => 'nandigarisht',
        'Narb' => 'arabishte veriore e vjetër',
        'Nbat' => 'nabateanisht',
        'Newa' => 'neva',
        'Nkoo' => 'nko',
        'Nshu' => 'nyshuisht',
        'Ogam' => 'ogamisht',
        'Olck' => 'ol çiki',
        'Orkh' => 'orkonisht',
        'Orya' => 'orija',
        'Osge' => 'osage',
        'Osma' => 'osmaniaisht',
        'Ougr' => 'ujgurishte e vjetër',
        'Palm' => 'palmirenisht',
        'Pauc' => 'pausinhauisht',
        'Perm' => 'permike e vjetër',
        'Phag' => 'fagspaisht',
        'Phli' => 'palavishte mbishkrimesh',
        'Phlp' => 'palavishte psalteri',
        'Phnx' => 'fenikisht',
        'Plrd' => 'polard fonetik',
        'Prti' => 'persishte mbishkrimesh',
        'Qaag' => 'zaugi',
        'Rjng' => 'rexhangisht',
        'Rohg' => 'hanifi',
        'Runr' => 'runike',
        'Samr' => 'samaritanisht',
        'Sarb' => 'arabishte jugore e vjetër',
        'Saur' => 'saurashtra',
        'Sgnw' => 'shkrim sing',
        'Shaw' => 'shavianisht',
        'Shrd' => 'sharadisht',
        'Sidd' => 'sidamisht',
        'Sind' => 'kudavadisht',
        'Sinh' => 'sinhal',
        'Sogd' => 'sogdianisht',
        'Sogo' => 'sogdianishte e vjetër',
        'Sora' => 'sorasompengisht',
        'Soyo' => 'sojomboisht',
        'Sund' => 'sundan',
        'Sylo' => 'siloti nagri',
        'Syrc' => 'siriak',
        'Tagb' => 'tagbanvaisht',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'tai lue i ri',
        'Taml' => 'tamil',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telug',
        'Tfng' => 'tifinag',
        'Tglg' => 'tagalog',
        'Thaa' => 'tanisht',
        'Thai' => 'tajlandez',
        'Tibt' => 'tibetisht',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Toto' => 'toto',
        'Ugar' => 'ugaritik',
        'Vaii' => 'vai',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'vanço',
        'Xpeo' => 'persian i vjetër',
        'Xsux' => 'kuneiform sumero-akadian',
        'Yezi' => 'jezidi',
        'Yiii' => 'ji',
        'Zanb' => 'katror zanabazar',
        'Zinh' => 'zin',
        'Zmth' => 'simbole matematikore',
        'Zsye' => 'emoji',
        'Zsym' => 'me simbole',
        'Zxxx' => 'i pashkruar',
        'Zyyy' => 'i zakonshëm',
    ],
];
