<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Aghb' => 'Albánach Cugasach',
        'Ahom' => 'Ahom',
        'Arab' => 'Arabach',
        'Aran' => 'Nastaliq',
        'Armi' => 'Aramach Impiriúil',
        'Armn' => 'Airméanach',
        'Avst' => 'Aivéisteach',
        'Bali' => 'Bailíoch',
        'Batk' => 'Batacach',
        'Beng' => 'Beangálach',
        'Bopo' => 'Bopomofo',
        'Brai' => 'Braille',
        'Bugi' => 'Buigineach',
        'Buhd' => 'Buthaideach',
        'Cakm' => 'Seácmais',
        'Cans' => 'Siollach Bundúchasach Ceanadach Aontaithe',
        'Cher' => 'Seiricíoch',
        'Copt' => 'Coptach',
        'Cprt' => 'Cipireach',
        'Cyrl' => 'Coireallach',
        'Deva' => 'Déiveanágrach',
        'Dupl' => 'Gearrscríobh Duployan',
        'Egyd' => 'Éigipteach coiteann',
        'Egyh' => 'Éigipteach cliarúil',
        'Egyp' => 'Iairiglifí Éigipteacha',
        'Ethi' => 'Aetóipic',
        'Geor' => 'Seoirseach',
        'Glag' => 'Glagalach',
        'Goth' => 'Gotach',
        'Grek' => 'Gréagach',
        'Gujr' => 'Gúisearátach',
        'Guru' => 'Gurmúcach',
        'Hanb' => 'Han agus Bopomofo',
        'Hang' => 'Hangalach',
        'Hani' => 'Han',
        'Hano' => 'Hananúis',
        'Hans' => 'Simplithe',
        'Hant' => 'Traidisiúnta',
        'Hebr' => 'Eabhrach',
        'Hira' => 'Hireagánach',
        'Hluw' => 'Iairiglifí Anatólacha',
        'Hrkt' => 'Siollabraí Seapánacha',
        'Hung' => 'Sean-Ungárach',
        'Ital' => 'Sean-Iodáilic',
        'Jamo' => 'Seamó',
        'Java' => 'Iávach',
        'Jpan' => 'Seapánach',
        'Kana' => 'Catacánach',
        'Khmr' => 'Ciméarach',
        'Knda' => 'Cannadach',
        'Kore' => 'Cóiréach',
        'Laoo' => 'Laosach',
        'Latg' => 'Cló Gaelach',
        'Latn' => 'Laidineach',
        'Limb' => 'Liombúch',
        'Lina' => 'Líneach A',
        'Linb' => 'Líneach B',
        'Lisu' => 'Fraser',
        'Lyci' => 'Liciach',
        'Lydi' => 'Lidiach',
        'Mahj' => 'Mahasánach',
        'Mani' => 'Mainicéasach',
        'Maya' => 'Iairiglifí Máigheacha',
        'Mend' => 'Meindeach',
        'Mlym' => 'Mailéalamach',
        'Mong' => 'Mongólach',
        'Mtei' => 'Meitei Mayek',
        'Mult' => 'Multani',
        'Mymr' => 'Maenmarach',
        'Narb' => 'Sean-Arabach Thuaidh',
        'Newa' => 'Newa',
        'Nkoo' => 'N-cóis',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orya' => 'Oiríseach',
        'Osge' => 'Ósáis',
        'Perm' => 'Sean-Pheirmeach',
        'Phnx' => 'Féiníceach',
        'Plrd' => 'Pollard Foghrach',
        'Prti' => 'Pairtiach Inscríbhinniúil',
        'Rohg' => 'Hanifi',
        'Runr' => 'Rúnach',
        'Samr' => 'Samárach',
        'Sarb' => 'Sean-Arabach Theas',
        'Sgnw' => 'Litritheoireacht Comharthaí',
        'Shaw' => 'Shawach',
        'Sinh' => 'Siolónach',
        'Sund' => 'Sundainéis',
        'Syrc' => 'Siriceach',
        'Tale' => 'Deiheoingis',
        'Talu' => 'Tai Lue Nua',
        'Taml' => 'Tamalach',
        'Telu' => 'Teileagúch',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagálagach',
        'Thaa' => 'Tánach',
        'Thai' => 'Téalannach',
        'Tibt' => 'Tibéadach',
        'Ugar' => 'Úgairíteach',
        'Vaii' => 'Vadhais',
        'Xpeo' => 'Sean-Pheirseach',
        'Xsux' => 'Dingchruthach Suiméar-Acádach',
        'Yiii' => 'Ís',
        'Zinh' => 'Oidhreacht',
        'Zmth' => 'Nodaireacht Mhatamaiticiúil',
        'Zsye' => 'Emoji',
        'Zsym' => 'Siombailí',
        'Zxxx' => 'Neamhscríofa',
        'Zyyy' => 'Coitianta',
    ],
];
