<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Արաբական Միացյալ Էմիրությունների դիրհամ',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'աֆղանական աֆղանի',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'ալբանական լեկ',
        ],
        'AMD' => [
            0 => '֏',
            1 => 'հայկական դրամ',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'նիդեռլանդական անտիլյան գուլդեն',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'անգոլական կվանզա',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'արգենտինական պեսո',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'ավստրալիական դոլար',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'արուբական ֆլորին',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'ադրբեջանական մանաթ',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Բոսնիա և Հերցեգովինայի փոխարկվող մարկ',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'բարբադոսյան դոլար',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Բանգլադեշի տակա',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'բուլղարական լև',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Բահրեյնի դինար',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'բուրունդիական ֆրանկ',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'բերմուդյան դոլար',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Բրունեյի դոլար',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'բոլիվիական բոլիվիանո',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'բրազիլական ռեալ',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'բահամյան դոլար',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'բութանական նգուլտրում',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'բոթսվանական պուլա',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'բելառուսական ռուբլի',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Բելառուսական ռուբլի (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Բելիզի դոլար',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'կանադական դոլար',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Կոնգոյի ֆրանկ',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'շվեյցարական ֆրանկ',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'չիլիական պեսո',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'չինական օֆշորային յուան',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'չինական յուան',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'կոլումբիական պեսո',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Կոստա Ռիկայի կոլոն',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'կուբայական փոխարկվող պեսո',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'կուբայական պեսո',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Կաբո Վերդեի էսկուդո',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'չեխական կրոն',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Ջիբութիի ֆրանկ',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'դանիական կրոն',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'դոմինիկյան պեսո',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'ալժիրական դինար',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'եգիպտական ֆունտ',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'էրիթրեական նակվա',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'եթովպիական բիր',
        ],
        'EUR' => [
            0 => '€',
            1 => 'եվրո',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'ֆիջիական դոլար',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Ֆոլքլենդյան կղզիների ֆունտ',
        ],
        'GBP' => [
            0 => '£',
            1 => 'բրիտանական ֆունտ ստերլինգ',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'վրացական լարի',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'գայանական սեդի',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Ջիբրալթարի ֆունտ',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'գամբիական դալասի',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'գվինեական ֆրանկ',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'գվատեմալական կետսալ',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'գայանական դոլար',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Հոնկոնգի դոլար',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'հոնդուրասական լեմպիրա',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'խորվաթական կունա',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'հայիթյան գուրդ',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'հունգարական ֆորինտ',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'ինդոնեզիական ռուփի',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Իսրայելի նոր շեկել',
        ],
        'INR' => [
            0 => '₹',
            1 => 'հնդկական ռուփի',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'իրաքյան դինար',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'իրանական ռիալ',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'իսլանդական կրոն',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ճամայկայի դոլար',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'հորդանանյան դինար',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'ճապոնական իեն',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'քենիական շիլինգ',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'ղրղզական սոմ',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'կամբոջական ռիել',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'կոմորյան ֆրանկ',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'հյուսիսկորեական վոն',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'հարավկորեական վոն',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Քուվեյթի դինար',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Կայմանյան կղզիների դոլար',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'ղազախական տենգե',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'լաոսական կիպ',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'լիբանանյան ֆունտ',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Շրի Լանկայի ռուփի',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'լիբերիական դոլար',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'լեսոթոյական լոտի',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Լիտվական լիտ',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Լատվիական լատ',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'լիբիական դինար',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Մարոկկոյի դիրհամ',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'մոլդովական լեյ',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Մադագասկարի արիարի',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'մակեդոնական դենար',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Մյանմայի կյատ',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'մոնղոլական տուգրիկ',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Մակաոյի պատակա',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'մավրիտանական ուգիյա (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'մավրիտանական ուգիյա',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'մավրիկյան ռուփի',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'մալդիվյան ռուֆիյա',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'մալավիական կվաչա',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'մեքսիկական պեսո',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'մալայզիական ռինգիտ',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'մոզամբիկյան մետիկալ',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'նամիբիական դոլար',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'նիգերիական նայրա',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'նիկարագուական կորդոբա',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'նորվեգական կրոն',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Նեպալի ռուփի',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'նորզելանդական դոլար',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Օմանի ռիալ',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'պանամական բալբոա',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Պերուի սոլ',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Պապուա Նոր Գվինեայի կինա',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'ֆիլիպինյան պեսո',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'պակիստանյան ռուփի',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'լեհական զլոտի',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'պարագվայական գուարանի',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Կատարի ռիալ',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'ռումինական լեյ',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'սերբական դինար',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'ռուսական ռուբլի',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'ռուանդական ֆրանկ',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Սաուդյան Արաբիայի ռիալ',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Սողոմոնյան կղզիների դոլար',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'սեյշելյան ռուփի',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'սուդանական ֆունտ',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'շվեդական կրոն',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Սինգապուրի դոլար',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Սուրբ Հեղինեի ֆունտ',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Սիեռա Լեոնեի լեոնե',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'սոմալիական շիլինգ',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'սուրինամական դոլար',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'հարավսուդանական ֆունտ',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Սան Տոմե և Փրինսիպիի դոբրա (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Սան Տոմե և Փրինսիպիի դոբրա',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'սիրիական ֆունտ',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'սվազիլենդական լիլանգենի',
        ],
        'THB' => [
            0 => '฿',
            1 => 'թայլանդական բատ',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'տաջիկական սոմոնի',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'թուրքմենական մանաթ',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'թունիսյան դինար',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Տոնգայի պաանգա',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'թուրքական լիրա',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Տրինիդադ և Տոբագոյի դոլար',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'թայվանական նոր դոլար',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'տանզանիական շիլինգ',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'ուկրաինական գրիվնա',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'ուգանդական շիլինգ',
        ],
        'USD' => [
            0 => '$',
            1 => 'ԱՄՆ դոլար',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'ուրուգվայական պեսո',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'ուզբեկական սոմ',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'վենեսուելական բոլիվար (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'վենեսուելական բոլիվար',
        ],
        'VND' => [
            0 => '₫',
            1 => 'վիետնամական դոնգ',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Վանուատուի վատու',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'սամոական տալա',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Կենտրոնական Աֆրիկայի ԿՖԱ ֆրանկ',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'արևելակարիբյան դոլար',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Արևմտյան Աֆրիկայի ԿՖԱ ֆրանկ',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'ԿՊՖ ֆրանկ',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'եմենական ռիալ',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'հարավաֆրիկյան ռանդ',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Զամբիական կվաչա (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'զամբիական կվաչա',
        ],
    ],
];
