<?php

return [
    'Names' => [
        'aa' => 'afarčina',
        'ab' => 'abcházčina',
        'ace' => 'acehčina',
        'ach' => 'ačoli',
        'ada' => 'adangme',
        'ady' => 'adygejčina',
        'ae' => 'avestčina',
        'af' => 'afrikánčina',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainčina',
        'ak' => 'akančina',
        'akk' => 'akkadčina',
        'ale' => 'aleutčina',
        'alt' => 'južná altajčina',
        'am' => 'amharčina',
        'an' => 'aragónčina',
        'ang' => 'stará angličtina',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabčina',
        'arc' => 'aramejčina',
        'arn' => 'mapudungun',
        'arp' => 'arapažština',
        'ars' => 'arabčina (nadždská)',
        'arw' => 'arawačtina',
        'as' => 'ásamčina',
        'asa' => 'asu',
        'ast' => 'astúrčina',
        'atj' => 'atikamekwčina',
        'av' => 'avarčina',
        'awa' => 'awadhi',
        'ay' => 'aymarčina',
        'az' => 'azerbajdžančina',
        'ba' => 'baškirčina',
        'bal' => 'balúčtina',
        'ban' => 'balijčina',
        'bas' => 'basa',
        'bax' => 'bamun',
        'bbj' => 'ghomala',
        'be' => 'bieloruština',
        'bej' => 'bedža',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bg' => 'bulharčina',
        'bgn' => 'západná balúčtina',
        'bho' => 'bhódžpurčina',
        'bi' => 'bislama',
        'bik' => 'bikolčina',
        'bin' => 'bini',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'bm' => 'bambarčina',
        'bn' => 'bengálčina',
        'bo' => 'tibetčina',
        'br' => 'bretónčina',
        'bra' => 'bradžčina',
        'brx' => 'bodo',
        'bs' => 'bosniačtina',
        'bss' => 'akoose',
        'bua' => 'buriatčina',
        'bug' => 'bugiština',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumba',
        'ca' => 'katalánčina',
        'cad' => 'kaddo',
        'car' => 'karibčina',
        'cay' => 'kajugčina',
        'cch' => 'atsam',
        'ccp' => 'čakma',
        'ce' => 'čečenčina',
        'ceb' => 'cebuánčina',
        'cgg' => 'kiga',
        'ch' => 'čamorčina',
        'chb' => 'čibča',
        'chg' => 'čagatajčina',
        'chk' => 'chuuk',
        'chm' => 'marijčina',
        'chn' => 'činucký žargón',
        'cho' => 'čoktčina',
        'chp' => 'čipevajčina',
        'chr' => 'čerokí',
        'chy' => 'čejenčina',
        'ckb' => 'kurdčina (sorání)',
        'clc' => 'chilcotin',
        'co' => 'korzičtina',
        'cop' => 'koptčina',
        'cr' => 'krí',
        'crg' => 'michif',
        'crh' => 'krymská tatárčina',
        'crj' => 'cree (juhovýchod)',
        'crk' => 'plains cree',
        'crl' => 'northern east cree',
        'crm' => 'moose cree',
        'crr' => 'karolínska algonkčina',
        'crs' => 'seychelská kreolčina',
        'cs' => 'čeština',
        'csb' => 'kašubčina',
        'csw' => 'swampy cree',
        'cu' => 'cirkevná slovančina',
        'cv' => 'čuvaština',
        'cy' => 'waleština',
        'da' => 'dánčina',
        'dak' => 'dakotčina',
        'dar' => 'darginčina',
        'dav' => 'taita',
        'de' => 'nemčina',
        'del' => 'delawarčina',
        'den' => 'slavé',
        'dgr' => 'dogribčina',
        'din' => 'dinkčina',
        'dje' => 'zarma',
        'doi' => 'dógrí',
        'dsb' => 'dolnolužická srbčina',
        'dua' => 'duala',
        'dum' => 'stredná holandčina',
        'dv' => 'maldivčina',
        'dyo' => 'jola-fonyi',
        'dyu' => 'ďula',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'eweština',
        'efi' => 'efik',
        'egy' => 'staroegyptčina',
        'eka' => 'ekadžuk',
        'el' => 'gréčtina',
        'elx' => 'elamčina',
        'en' => 'angličtina',
        'enm' => 'stredná angličtina',
        'eo' => 'esperanto',
        'es' => 'španielčina',
        'et' => 'estónčina',
        'eu' => 'baskičtina',
        'ewo' => 'ewondo',
        'fa' => 'perzština',
        'fan' => 'fangčina',
        'fat' => 'fanti',
        'ff' => 'fulbčina',
        'fi' => 'fínčina',
        'fil' => 'filipínčina',
        'fj' => 'fidžijčina',
        'fo' => 'faerčina',
        'fon' => 'fončina',
        'fr' => 'francúzština',
        'frc' => 'francúzština (Cajun)',
        'frm' => 'stredná francúzština',
        'fro' => 'stará francúzština',
        'frr' => 'severná frízština',
        'frs' => 'východofrízština',
        'fur' => 'friulčina',
        'fy' => 'západná frízština',
        'ga' => 'írčina',
        'gaa' => 'ga',
        'gag' => 'gagauzština',
        'gay' => 'gayo',
        'gba' => 'gbaja',
        'gd' => 'škótska gaelčina',
        'gez' => 'etiópčina',
        'gil' => 'kiribatčina',
        'gl' => 'galícijčina',
        'gmh' => 'stredná horná nemčina',
        'gn' => 'guaraníjčina',
        'goh' => 'stará horná nemčina',
        'gon' => 'góndčina',
        'gor' => 'gorontalo',
        'got' => 'gótčina',
        'grb' => 'grebo',
        'grc' => 'starogréčtina',
        'gsw' => 'nemčina (švajčiarska)',
        'gu' => 'gudžarátčina',
        'guz' => 'gusii',
        'gv' => 'mančina',
        'gwi' => 'kučinčina',
        'ha' => 'hauština',
        'hai' => 'haida',
        'haw' => 'havajčina',
        'hax' => 'haida (juh)',
        'he' => 'hebrejčina',
        'hi' => 'hindčina',
        'hil' => 'hiligajnončina',
        'hit' => 'chetitčina',
        'hmn' => 'hmongčina',
        'ho' => 'hiri motu',
        'hr' => 'chorvátčina',
        'hsb' => 'hornolužická srbčina',
        'ht' => 'haitská kreolčina',
        'hu' => 'maďarčina',
        'hup' => 'hupčina',
        'hur' => 'halkomelem',
        'hy' => 'arménčina',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'ibančina',
        'ibb' => 'ibibio',
        'id' => 'indonézština',
        'ie' => 'interlingue',
        'ig' => 'igboština',
        'ii' => 's’čchuanská iovčina',
        'ik' => 'inupik',
        'ikt' => 'inuktitut (západná Kanada)',
        'ilo' => 'ilokánčina',
        'inh' => 'inguština',
        'io' => 'ido',
        'is' => 'islandčina',
        'it' => 'taliančina',
        'iu' => 'inuktitut',
        'ja' => 'japončina',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'mašame',
        'jpr' => 'židovská perzština',
        'jrb' => 'židovská arabčina',
        'jv' => 'jávčina',
        'ka' => 'gruzínčina',
        'kaa' => 'karakalpačtina',
        'kab' => 'kabylčina',
        'kac' => 'kačjinčina',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardčina',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kapverdčina',
        'kfo' => 'koro',
        'kg' => 'kongčina',
        'kgp' => 'kaingang',
        'kha' => 'khasijčina',
        'kho' => 'chotančina',
        'khq' => 'západná songhajčina',
        'ki' => 'kikujčina',
        'kj' => 'kuaňama',
        'kk' => 'kazaština',
        'kkj' => 'kako',
        'kl' => 'grónčina',
        'kln' => 'kalendžin',
        'km' => 'khmérčina',
        'kmb' => 'kimbundu',
        'kn' => 'kannadčina',
        'ko' => 'kórejčina',
        'koi' => 'komi-permiačtina',
        'kok' => 'konkánčina',
        'kos' => 'kusaie',
        'kpe' => 'kpelle',
        'kr' => 'kanurijčina',
        'krc' => 'karačajevsko-balkarčina',
        'krl' => 'karelčina',
        'kru' => 'kuruchčina',
        'ks' => 'kašmírčina',
        'ksb' => 'šambala',
        'ksf' => 'bafia',
        'ksh' => 'kolínčina',
        'ku' => 'kurdčina',
        'kum' => 'kumyčtina',
        'kut' => 'kutenajčina',
        'kv' => 'komijčina',
        'kw' => 'kornčina',
        'kwk' => 'kwakʼwala',
        'ky' => 'kirgizština',
        'la' => 'latinčina',
        'lad' => 'židovská španielčina',
        'lag' => 'langi',
        'lah' => 'lahandčina',
        'lam' => 'lamba',
        'lb' => 'luxemburčina',
        'lez' => 'lezginčina',
        'lg' => 'gandčina',
        'li' => 'limburčina',
        'lil' => 'lillooet',
        'lkt' => 'lakotčina',
        'ln' => 'lingalčina',
        'lo' => 'laoština',
        'lol' => 'mongo',
        'lou' => 'kreolčina (Louisiana)',
        'loz' => 'lozi',
        'lrc' => 'severné luri',
        'lsm' => 'saamia',
        'lt' => 'litovčina',
        'lu' => 'lubčina (katanžská)',
        'lua' => 'lubčina (luluánska)',
        'lui' => 'luiseňo',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizorámčina',
        'luy' => 'luhja',
        'lv' => 'lotyština',
        'mad' => 'madurčina',
        'maf' => 'mafa',
        'mag' => 'magadhčina',
        'mai' => 'maithilčina',
        'mak' => 'makasarčina',
        'man' => 'mandingo',
        'mas' => 'masajčina',
        'mde' => 'maba',
        'mdf' => 'mokšiančina',
        'mdr' => 'mandarčina',
        'men' => 'mendejčina',
        'mer' => 'meru',
        'mfe' => 'maurícijská kreolčina',
        'mg' => 'malgaština',
        'mga' => 'stredná írčina',
        'mgh' => 'makua-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshallčina',
        'mi' => 'maorijčina',
        'mic' => 'mikmakčina',
        'min' => 'minangkabaučina',
        'mk' => 'macedónčina',
        'ml' => 'malajálamčina',
        'mn' => 'mongolčina',
        'mnc' => 'mandžuština',
        'mni' => 'manípurčina',
        'moe' => 'innu-aimunčina',
        'moh' => 'mohawkčina',
        'mos' => 'mossi',
        'mr' => 'maráthčina',
        'ms' => 'malajčina',
        'mt' => 'maltčina',
        'mua' => 'mundang',
        'mus' => 'kríkčina',
        'mwl' => 'mirandčina',
        'mwr' => 'marwari',
        'my' => 'barmčina',
        'mye' => 'myene',
        'myv' => 'erzjančina',
        'mzn' => 'mázandaránčina',
        'na' => 'nauruština',
        'nap' => 'neapolčina',
        'naq' => 'nama',
        'nb' => 'nórčina (bokmal)',
        'nd' => 'ndebelčina (severná)',
        'nds' => 'dolná nemčina',
        'ne' => 'nepálčina',
        'new' => 'nevárčina',
        'ng' => 'ndonga',
        'nia' => 'niasánčina',
        'niu' => 'niueština',
        'nl' => 'holandčina',
        'nmg' => 'kwasio',
        'nn' => 'nórčina (nynorsk)',
        'nnh' => 'ngiemboon',
        'no' => 'nórčina',
        'nog' => 'nogajčina',
        'non' => 'stará nórčina',
        'nqo' => 'n’ko',
        'nr' => 'ndebelčina (južná)',
        'nso' => 'sothčina (severná)',
        'nus' => 'nuer',
        'nv' => 'navaho',
        'nwc' => 'klasická nevárčina',
        'ny' => 'ňandža',
        'nym' => 'ňamwezi',
        'nyn' => 'ňankole',
        'nyo' => 'ňoro',
        'nzi' => 'nzima',
        'oc' => 'okcitánčina',
        'oj' => 'odžibva',
        'ojb' => 'northwestern ojibwa',
        'ojc' => 'centrálna odžibvejčina',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwa (západ)',
        'oka' => 'okanagan',
        'om' => 'oromčina',
        'or' => 'uríjčina',
        'os' => 'osetčina',
        'osa' => 'osedžština',
        'ota' => 'osmanská turečtina',
        'pa' => 'pandžábčina',
        'pag' => 'pangasinančina',
        'pal' => 'pahlaví',
        'pam' => 'kapampangančina',
        'pap' => 'papiamento',
        'pau' => 'palaučina',
        'pcm' => 'nigerijský pidžin',
        'peo' => 'stará perzština',
        'phn' => 'feničtina',
        'pi' => 'pálí',
        'pis' => 'pidžin',
        'pl' => 'poľština',
        'pon' => 'pohnpeiština',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'pruština',
        'pro' => 'stará okcitánčina',
        'ps' => 'paštčina',
        'pt' => 'portugalčina',
        'qu' => 'kečuánčina',
        'quc' => 'quiché',
        'raj' => 'radžastančina',
        'rap' => 'rapanujčina',
        'rar' => 'rarotongská maorijčina',
        'rhg' => 'rohingčina',
        'rm' => 'rétorománčina',
        'rn' => 'rundčina',
        'ro' => 'rumunčina',
        'rof' => 'rombo',
        'rom' => 'rómčina',
        'ru' => 'ruština',
        'rup' => 'arumunčina',
        'rw' => 'rwandčina',
        'rwk' => 'rwa',
        'sa' => 'sanskrit',
        'sad' => 'sandaweština',
        'sah' => 'jakutčina',
        'sam' => 'samaritánska aramejčina',
        'saq' => 'samburu',
        'sas' => 'sasačtina',
        'sat' => 'santalčina',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardínčina',
        'scn' => 'sicílčina',
        'sco' => 'škótčina',
        'sd' => 'sindhčina',
        'sdh' => 'južná kurdčina',
        'se' => 'saamčina (severná)',
        'see' => 'senekčina',
        'seh' => 'sena',
        'sel' => 'selkupčina',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'stará írčina',
        'sh' => 'srbochorvátčina',
        'shi' => 'tachelhit',
        'shn' => 'šančina',
        'shu' => 'čadská arabčina',
        'si' => 'sinhalčina',
        'sid' => 'sidamo',
        'sk' => 'slovenčina',
        'sl' => 'slovinčina',
        'slh' => 'lushootseed (juh)',
        'sm' => 'samojčina',
        'sma' => 'saamčina (južná)',
        'smj' => 'saamčina (lulská)',
        'smn' => 'saamčina (inarijská)',
        'sms' => 'saamčina (skoltská)',
        'sn' => 'šončina',
        'snk' => 'soninke',
        'so' => 'somálčina',
        'sog' => 'sogdijčina',
        'sq' => 'albánčina',
        'sr' => 'srbčina',
        'srn' => 'surinamčina',
        'srr' => 'sererčina',
        'ss' => 'svazijčina',
        'ssy' => 'saho',
        'st' => 'sothčina (južná)',
        'str' => 'straits salish',
        'su' => 'sundčina',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumerčina',
        'sv' => 'švédčina',
        'sw' => 'swahilčina',
        'swb' => 'komorčina',
        'syc' => 'sýrčina (klasická)',
        'syr' => 'sýrčina',
        'ta' => 'tamilčina',
        'tce' => 'tutchone (juh)',
        'te' => 'telugčina',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'terêna',
        'tet' => 'tetumčina',
        'tg' => 'tadžičtina',
        'tgx' => 'tagiš',
        'th' => 'thajčina',
        'tht' => 'tahltan',
        'ti' => 'tigriňa',
        'tig' => 'tigrejčina',
        'tiv' => 'tiv',
        'tk' => 'turkménčina',
        'tkl' => 'tokelauština',
        'tl' => 'tagalčina',
        'tlh' => 'klingónčina',
        'tli' => 'tlingitčina',
        'tmh' => 'tuaregčina',
        'tn' => 'tswančina',
        'to' => 'tongčina',
        'tog' => 'ňasa tonga',
        'tok' => 'toki pona',
        'tpi' => 'novoguinejský pidžin',
        'tr' => 'turečtina',
        'trv' => 'taroko',
        'ts' => 'tsongčina',
        'tsi' => 'cimšjančina',
        'tt' => 'tatárčina',
        'ttm' => 'northern tutchone',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalčina',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitčina',
        'tyv' => 'tuviančina',
        'tzm' => 'tamazight (stredomarocký)',
        'udm' => 'udmurtčina',
        'ug' => 'ujgurčina',
        'uga' => 'ugaritčina',
        'uk' => 'ukrajinčina',
        'umb' => 'umbundu',
        'ur' => 'urdčina',
        'uz' => 'uzbečtina',
        'vai' => 'vai',
        've' => 'vendčina',
        'vi' => 'vietnamčina',
        'vo' => 'volapük',
        'vot' => 'vodčina',
        'vun' => 'vunjo',
        'wa' => 'valónčina',
        'wae' => 'walserčina',
        'wal' => 'walamčina',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'wolofčina',
        'wuu' => 'čínština (wu)',
        'xal' => 'kalmyčtina',
        'xh' => 'xhoština',
        'xog' => 'soga',
        'yao' => 'jao',
        'yap' => 'japčina',
        'yav' => 'jangben',
        'ybb' => 'yemba',
        'yi' => 'jidiš',
        'yo' => 'jorubčina',
        'yrl' => 'nheengatu',
        'yue' => 'kantončina',
        'za' => 'čuangčina',
        'zap' => 'zapotéčtina',
        'zbl' => 'systém Bliss',
        'zen' => 'zenaga',
        'zgh' => 'tuaregčina (marocká štandardná)',
        'zh' => 'čínština',
        'zu' => 'zuluština',
        'zun' => 'zuniština',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabčina (moderná štandardná)',
        'de_AT' => 'nemčina (rakúska)',
        'de_CH' => 'nemčina (švajčiarska spisovná)',
        'en_AU' => 'angličtina (austrálska)',
        'en_CA' => 'angličtina (kanadská)',
        'en_GB' => 'angličtina (britská)',
        'en_US' => 'angličtina (americká)',
        'es_419' => 'španielčina (latinskoamerická)',
        'es_ES' => 'španielčina (európska)',
        'es_MX' => 'španielčina (mexická)',
        'fa_AF' => 'daríjčina',
        'fr_CA' => 'francúzština (kanadská)',
        'fr_CH' => 'francúzština (švajčiarska)',
        'nds_NL' => 'dolná saština',
        'nl_BE' => 'flámčina',
        'pt_BR' => 'portugalčina (brazílska)',
        'pt_PT' => 'portugalčina (európska)',
        'ro_MD' => 'moldavčina',
        'sw_CD' => 'svahilčina (konžská)',
        'zh_Hans' => 'čínština (zjednodušená)',
        'zh_Hant' => 'čínština (tradičná)',
    ],
];
