<?php

return [
    'Names' => [
        'aa' => 'افري',
        'ab' => 'ابخازي',
        'ace' => 'اچيني',
        'ada' => 'ادانگمي',
        'ady' => 'اديغي',
        'af' => 'افریکانسي',
        'agq' => 'اغیمي',
        'ain' => 'اينويي',
        'ak' => 'اکاني',
        'ale' => 'اليوتي',
        'alt' => 'سویل الټای',
        'am' => 'امهاري',
        'an' => 'اراگونېسي',
        'ann' => 'Obo',
        'anp' => 'انگيکي',
        'ar' => 'عربي',
        'arn' => 'ماپوچه',
        'arp' => 'اراپاهوي',
        'ars' => 'نجدی عربی',
        'as' => 'اسامي',
        'asa' => 'اسويي',
        'ast' => 'استورياني',
        'atj' => 'اتیکامیکو',
        'av' => 'اواري',
        'awa' => 'اوادي',
        'ay' => 'ایماري',
        'az' => 'اذربایجاني',
        'ba' => 'باشکير',
        'bal' => 'بلوڅي',
        'ban' => 'بالنی',
        'bas' => 'باسا',
        'be' => 'بېلاروسي',
        'bem' => 'بيمبا',
        'bez' => 'بينا',
        'bg' => 'بلغاري',
        'bho' => 'بهوجپوري',
        'bi' => 'بسلاما',
        'bin' => 'بینی',
        'bla' => 'سکسيکا',
        'bm' => 'بمبارا',
        'bn' => 'بنگالي',
        'bo' => 'تبتي',
        'br' => 'برېتون',
        'brx' => 'بودو',
        'bs' => 'بوسني',
        'bug' => 'بگنيايي',
        'byn' => 'بلین',
        'ca' => 'کټلاني',
        'cay' => 'Ca',
        'ccp' => 'چکما',
        'ce' => 'چيچني',
        'ceb' => 'سیبوانوي',
        'cgg' => 'چيگايي',
        'ch' => 'چمورو',
        'chk' => 'چواوکي',
        'chm' => 'ماري',
        'cho' => 'چوکټاوي',
        'chp' => 'Ch',
        'chr' => 'چېروکي',
        'chy' => 'شيني',
        'ckb' => 'منځنۍ کوردي',
        'clc' => 'چیلکوټین',
        'co' => 'کورسيکاني',
        'crg' => 'mc',
        'crj' => 'سویل ختیځ کری',
        'crk' => 'پلینز کری',
        'crl' => 'شمالي ختیځ کری',
        'crm' => 'mcr',
        'crr' => 'Car Alg',
        'crs' => 'سسيلوا ڪروئل فرانسوي',
        'cs' => 'چېکي',
        'csw' => 'سومپی کری',
        'cu' => 'د کليسا سلاوي',
        'cv' => 'چوواشي',
        'cy' => 'ويلشي',
        'da' => 'ډنمارکي',
        'dak' => 'داکوتا',
        'dar' => 'درگوا',
        'dav' => 'ټایټا',
        'de' => 'الماني',
        'dgr' => 'داگرب',
        'dje' => 'زرما',
        'doi' => 'ډوګري',
        'dsb' => 'کښته سربيايي',
        'dua' => 'دوالا',
        'dv' => 'ديویهی',
        'dyo' => 'جولا فوني',
        'dz' => 'ژونگکه',
        'dzg' => 'ډزاګا',
        'ebu' => 'ايمبو',
        'ee' => 'ايو',
        'efi' => 'افک',
        'eka' => 'اکجک',
        'el' => 'یوناني',
        'en' => 'انګليسي',
        'eo' => 'اسپرانتو',
        'es' => 'هسپانوي',
        'et' => 'حبشي',
        'eu' => 'باسکي',
        'ewo' => 'اوونڊو',
        'fa' => 'فارسي',
        'ff' => 'فولاح',
        'fi' => 'فینلنډي',
        'fil' => 'فلیپیني',
        'fj' => 'فجیان',
        'fo' => 'فاروئې',
        'fon' => 'فان',
        'fr' => 'فرانسوي',
        'frc' => 'کاجون فرانسوی',
        'frr' => 'شمالي فریسیان',
        'fur' => 'فرائیلیین',
        'fy' => 'لوېديځ فريشي',
        'ga' => 'ائيرلېنډي',
        'gaa' => 'Ga',
        'gd' => 'سکاټلېنډي ګېلک',
        'gez' => 'ګیز',
        'gil' => 'گلبرتي',
        'gl' => 'ګلېشيايي',
        'gn' => 'ګوراني',
        'gor' => 'ګورن ټالو',
        'gsw' => 'سویس جرمن',
        'gu' => 'ګجراتي',
        'guz' => 'ګوسي',
        'gv' => 'مینکس',
        'gwi' => 'ګیچین',
        'ha' => 'هوسا',
        'hai' => 'ha',
        'haw' => 'هوایی',
        'hax' => 'جنوبي هایدا',
        'he' => 'عبراني',
        'hi' => 'هندي',
        'hil' => 'ھلیګینون',
        'hmn' => 'همونګ',
        'hr' => 'کروايشيايي',
        'hsb' => 'پورته سربيايي',
        'ht' => 'هيټي کريول',
        'hu' => 'هنګري',
        'hup' => 'ھوپا',
        'hur' => 'Hal',
        'hy' => 'آرمينيايي',
        'hz' => 'هیرورو',
        'ia' => 'انټرلنګوا',
        'iba' => 'ابن',
        'ibb' => 'ابیبیو',
        'id' => 'انډونېزي',
        'ig' => 'اګبو',
        'ii' => 'سیچیان یی',
        'ikt' => 'مغربی کینیډین انوکټیټ',
        'ilo' => 'الوکو',
        'inh' => 'انگش',
        'io' => 'اڊو',
        'is' => 'ايسلنډي',
        'it' => 'ایټالوي',
        'iu' => 'انوکتیتوت',
        'ja' => 'جاپاني',
        'jbo' => 'لوجبان',
        'jgo' => 'نګومبا',
        'jmc' => 'ماچمی',
        'jv' => 'جاوايي',
        'ka' => 'جورجيائي',
        'kab' => 'کیبیل',
        'kac' => 'کاچین',
        'kaj' => 'ججو',
        'kam' => 'کامبا',
        'kbd' => 'کابیرین',
        'kcg' => 'تایپ',
        'kde' => 'ميکونډي',
        'kea' => 'کابوورډیانو',
        'kfo' => 'کورو',
        'kgp' => 'kgg',
        'kha' => 'خاسې',
        'khq' => 'کویرا چینی',
        'ki' => 'ککوؤو',
        'kj' => 'کواناما',
        'kk' => 'قازق',
        'kkj' => 'کاکو',
        'kl' => 'کلالیسٹ',
        'kln' => 'کلینجن',
        'km' => 'خمر',
        'kmb' => 'کیمبوندو',
        'kn' => 'کناډا',
        'ko' => 'کوریایی',
        'kok' => 'کونکاني',
        'kpe' => 'کیلي',
        'kr' => 'کنوری',
        'krc' => 'کراچی بالکر',
        'krl' => 'کاریلین',
        'kru' => 'کورخ',
        'ks' => 'کشمیري',
        'ksb' => 'شمبالا',
        'ksf' => 'بفیا',
        'ksh' => 'کولوګنيايي',
        'ku' => 'کردي',
        'kum' => 'کومک',
        'kv' => 'کومی',
        'kw' => 'کورنيشي',
        'kwk' => 'Vote kwk',
        'ky' => 'کرغيزي',
        'la' => 'لاتیني',
        'lad' => 'لاډینو',
        'lag' => 'لنګی',
        'lb' => 'لوګزامبورګي',
        'lez' => 'لیګغیان',
        'lg' => 'ګانده',
        'li' => 'لمبرگیانی',
        'lil' => 'lill',
        'lkt' => 'لکوټا',
        'ln' => 'لنګالا',
        'lo' => 'لاو',
        'lou' => 'Louis',
        'loz' => 'لوزی',
        'lrc' => 'شمالي لوری',
        'lsm' => 'سامیه',
        'lt' => 'ليتواني',
        'lu' => 'لوبا-کټنګا',
        'lua' => 'لبا لولوا',
        'lun' => 'لندا',
        'luo' => 'لو',
        'lus' => 'ميزو',
        'luy' => 'لویا',
        'lv' => 'لېټواني',
        'mad' => 'مدراسی',
        'mag' => 'مګهي',
        'mai' => 'مایتھلي',
        'mak' => 'مکاسار',
        'mas' => 'ماسائي',
        'mdf' => 'موکشا',
        'men' => 'مینڊي',
        'mer' => 'ميرو',
        'mfe' => 'ماریسیسن',
        'mg' => 'ملغاسي',
        'mgh' => 'مکھوامیتو',
        'mgo' => 'ميټا',
        'mh' => 'مارشلیز',
        'mi' => 'ماوري',
        'mic' => 'ممکق',
        'min' => 'مينيگاباو',
        'mk' => 'مقدوني',
        'ml' => 'مالايالم',
        'mn' => 'منګولیایی',
        'mni' => 'مانی پوری',
        'moe' => 'mo',
        'moh' => 'محاواک',
        'mos' => 'ماسي',
        'mr' => 'مراټهي',
        'ms' => 'ملایا',
        'mt' => 'مالټايي',
        'mua' => 'مندانګ',
        'mus' => 'کريکي',
        'mwl' => 'مرانديز',
        'my' => 'برمایی',
        'myv' => 'ارزيا',
        'mzn' => 'مزاندراني',
        'na' => 'نایرو',
        'nap' => 'نيپالين',
        'naq' => 'ناما',
        'nb' => 'ناروېئي (بوکمال)',
        'nd' => 'شمالي نديبل',
        'nds' => 'کښته آلماني',
        'ne' => 'نېپالي',
        'new' => 'نيواري',
        'ng' => 'ندونگا',
        'nia' => 'نياس',
        'niu' => 'نیان',
        'nl' => 'هالېنډي',
        'nmg' => 'کواسیو',
        'nn' => 'ناروېئي (نائنورسک)',
        'nnh' => 'نایجیمون',
        'no' => 'ناروېئي',
        'nog' => 'نوګی',
        'nqo' => 'نکو',
        'nr' => 'سويلي نديبيل',
        'nso' => 'شمالي سوتو',
        'nus' => 'نویر',
        'nv' => 'نواجو',
        'ny' => 'نیانجا',
        'nyn' => 'نینکول',
        'oc' => 'اوکسيټاني',
        'ojb' => 'شمال لویدیځ اوجیبوا',
        'ojc' => 'Coj',
        'ojs' => 'اوجي-کري',
        'ojw' => 'لویدیځ اوجیبوا',
        'oka' => 'اوکاګان',
        'om' => 'اورومو',
        'or' => 'اوڊيا',
        'os' => 'اوسيټک',
        'pa' => 'پنجابي',
        'pag' => 'پانګاسین',
        'pam' => 'پمپانگا',
        'pap' => 'پاپيامينتو',
        'pau' => 'پالان',
        'pcm' => 'نائجیریا پیدجن',
        'pis' => 'پیجین',
        'pl' => 'پولنډي',
        'pqm' => 'mpq',
        'prg' => 'پروشين',
        'ps' => 'پښتو',
        'pt' => 'پورتګالي',
        'qu' => 'کېچوا',
        'quc' => 'کچی',
        'rap' => 'رپانوئي',
        'rar' => 'راروټانګان',
        'rhg' => 'روهینګیا',
        'rm' => 'رومانیش',
        'rn' => 'رونډی',
        'ro' => 'رومانیایی',
        'rof' => 'رومبو',
        'ru' => 'روسي',
        'rup' => 'اروماني',
        'rw' => 'کینیارونډا',
        'rwk' => 'روا',
        'sa' => 'سنسکریټ',
        'sad' => 'سنډاوی',
        'sah' => 'سخا',
        'saq' => 'سمبورو',
        'sat' => 'سنتالي',
        'sba' => 'نګبای',
        'sbp' => 'سانګوو',
        'sc' => 'سارڊيني',
        'scn' => 'سیلیسي',
        'sco' => 'سکاټس',
        'sd' => 'سندهي',
        'se' => 'شمالي سامي',
        'seh' => 'سینا',
        'ses' => 'کوییرابورو سینی',
        'sg' => 'سانګو',
        'shi' => 'تاکلهیټ',
        'shn' => 'شان',
        'si' => 'سينهالي',
        'sk' => 'سلوواکي',
        'sl' => 'سلوواني',
        'slh' => 'سویلي لوشوټسید',
        'sm' => 'ساموآن',
        'sma' => 'سویلي سامی',
        'smj' => 'لول سامي',
        'smn' => 'اناري سميع',
        'sms' => 'سکولټ سمیع',
        'sn' => 'شونا',
        'snk' => 'سونینګ',
        'so' => 'سومالي',
        'sq' => 'الباني',
        'sr' => 'سربيائي',
        'srn' => 'سوران ټونګو',
        'ss' => 'سواتی',
        'ssy' => 'سهو',
        'st' => 'سويلي سوتو',
        'str' => 'سټریټ سیلش',
        'su' => 'سوډاني',
        'suk' => 'سکوما',
        'sv' => 'سویډنی',
        'sw' => 'سواهېلي',
        'swb' => 'کومورياني',
        'syr' => 'سوریاني',
        'ta' => 'تامل',
        'tce' => 'جنوبي توچون',
        'te' => 'تېليګو',
        'tem' => 'تیمني',
        'teo' => 'تیسو',
        'tet' => 'تتوم',
        'tg' => 'تاجکي',
        'tgx' => 'ټګش',
        'th' => 'تايلېنډي',
        'tht' => 'طهلتان',
        'ti' => 'تيګريني',
        'tig' => 'تیګر',
        'tk' => 'ترکمني',
        'tlh' => 'کلينګاني',
        'tli' => 'ټلینګیت',
        'tn' => 'سووانا',
        'to' => 'تونګان',
        'tok' => 'توکی پونا',
        'tpi' => 'توک پیسین',
        'tr' => 'ترکي',
        'trv' => 'تاروکو',
        'ts' => 'سونګا',
        'tt' => 'تاتار',
        'ttm' => 'شمالي ټچون',
        'tum' => 'تامبوکا',
        'tvl' => 'تووالو',
        'twq' => 'تساواق',
        'ty' => 'تاهیتي',
        'tyv' => 'توینیان',
        'tzm' => 'مرکزی اطلس تمازائيٹ',
        'udm' => 'ادمورت',
        'ug' => 'اويغوري',
        'uk' => 'اوکرايني',
        'umb' => 'امبوندو',
        'ur' => 'اردو',
        'uz' => 'اوزبکي',
        'vai' => 'وای',
        've' => 'ویندا',
        'vi' => 'وېتنامي',
        'vo' => 'والاپوک',
        'vun' => 'وونجو',
        'wa' => 'والون',
        'wae' => 'ولسیر',
        'wal' => 'ولایټا',
        'war' => 'وارۍ',
        'wo' => 'ولوف',
        'wuu' => 'وو چینایی',
        'xal' => 'کالمک',
        'xh' => 'خوسا',
        'xog' => 'سوګا',
        'yav' => 'ینګبین',
        'ybb' => 'یمبا',
        'yi' => 'يديش',
        'yo' => 'یوروبا',
        'yrl' => 'نینګاتو',
        'yue' => 'کانټوني',
        'zgh' => 'معياري مراکشي تمازيټ',
        'zh' => 'چیني',
        'zu' => 'زولو',
        'zun' => 'زوني',
        'zza' => 'زازا',
    ],
    'LocalizedNames' => [
        'ar_001' => 'نوې معياري عربي',
        'de_AT' => 'اتريشي آلماني',
        'de_CH' => 'سویس های جرمن',
        'en_AU' => 'آسټرالياوي انګليسي',
        'en_CA' => 'کاناډايي انګلیسي',
        'en_GB' => 'بريتانوی انګلیسي',
        'es_419' => 'لاتيني امريکايي هسپانوي',
        'es_ES' => 'اروپايي هسپانوي',
        'es_MX' => 'ميکسيکي هسپانوي',
        'fa_AF' => 'دری (افغانستان)',
        'fr_CA' => 'کاناډايي فرانسوي',
        'fr_CH' => 'سويسي فرانسوي',
        'hi_Latn' => 'هندي (لاتيني)',
        'nl_BE' => 'فلېمېشي',
        'pt_BR' => 'برازیلي پرتګالي',
        'pt_PT' => 'اروپايي پرتګالي',
        'ro_MD' => 'مولداویایی',
        'sw_CD' => 'کانګو سواهلی',
        'zh_Hant' => 'دوديزه چيني',
    ],
];
