<?php

return [
    'Names' => [
        'AG' => 'Anatikua me Pāpura',
        'AI' => 'Ākuira',
        'AO' => 'Anakora',
        'AR' => 'Āketina',
        'AT' => 'Ateria',
        'AW' => 'Arūpa',
        'AX' => 'Motu Ōrana',
        'BB' => 'Pāpetō',
        'BE' => 'Paratiamu',
        'BF' => 'Pēkina Waho',
        'BI' => 'Puruniti',
        'BJ' => 'Penīna',
        'BL' => 'Hato Pāteremi',
        'BM' => 'Pemiuta',
        'BO' => 'Poriwia',
        'BQ' => 'Karepeana Hōrana',
        'BR' => 'Parīhi',
        'BS' => 'Pahāma',
        'BV' => 'Motu Pūwei',
        'BW' => 'Poriwana',
        'BZ' => 'Perīhi',
        'CA' => 'Kānata',
        'CD' => 'Kōngo - Kingihāha',
        'CF' => 'Te Puku o Āwherika',
        'CG' => 'Kōngo - Parāwhe',
        'CH' => 'Huiterangi',
        'CI' => 'Te Tai Rei',
        'CL' => 'Hiri',
        'CM' => 'Kamarūna',
        'CN' => 'Haina',
        'CO' => 'Koromōpia',
        'CR' => 'Kota Rīka',
        'CU' => 'Kiupa',
        'CV' => 'Te Kūrae Matomato',
        'CW' => 'Kurahao',
        'DE' => 'Tiamani',
        'DJ' => 'Tipūti',
        'DK' => 'Tenemāka',
        'DM' => 'Tominika',
        'DO' => 'Te Whenua Tominika',
        'DZ' => 'Aratiria',
        'EC' => 'Ekuatoa',
        'EE' => 'Etōnia',
        'EG' => 'Īhipa',
        'EH' => 'Hahāra ki te Tonga',
        'ER' => 'Eritēria',
        'ET' => 'Etiopia',
        'FI' => 'Whinirana',
        'FK' => 'Motu Whākarangi',
        'FO' => 'Motu Wharo',
        'FR' => 'Wīwī',
        'GA' => 'Kāpona',
        'GB' => 'Te Hononga o Piritene',
        'GD' => 'Kerenāta',
        'GF' => 'Kaiana Wīwī',
        'GG' => 'Kēni',
        'GH' => 'Kāna',
        'GL' => 'Kirīrangi',
        'GM' => 'Te Kamopia',
        'GN' => 'Kini',
        'GP' => 'Kuatarū',
        'GQ' => 'Kini Ekuatoria',
        'GS' => 'Hōria ki te Tonga me Motu Hanuwiti ki te Tonga',
        'GT' => 'Kuatamāra',
        'GW' => 'Kini-Pihao',
        'GY' => 'Kaiana',
        'HN' => 'Honūra',
        'HT' => 'Haiti',
        'IE' => 'Aerana',
        'IM' => 'Motu Tangata',
        'IN' => 'Inia',
        'IO' => 'Te Rohe o te Moana Īniana Piritihi',
        'IS' => 'Tiorangi',
        'IT' => 'Itāria',
        'JE' => 'Tiehe',
        'JM' => 'Hemeika',
        'JP' => 'Hapani',
        'KE' => 'Kēnia',
        'KM' => 'Komoro',
        'KN' => 'Hato Kiti me Newhi',
        'KY' => 'Ngā Motu Keimana',
        'LC' => 'Hato Ruhia',
        'LI' => 'Rīkeneteina',
        'LR' => 'Raipiri',
        'LS' => 'Teroto',
        'LT' => 'Rituānia',
        'LU' => 'Rakimipēki',
        'LV' => 'Ratawia',
        'LY' => 'Rīpia',
        'MA' => 'Moroko',
        'MC' => 'Manako',
        'MF' => 'Hato Mātene',
        'MG' => 'Marakāhia',
        'MK' => 'Makerōnia ki te Raki',
        'ML' => 'Māri',
        'MQ' => 'Māteniki',
        'MR' => 'Mauritānia',
        'MS' => 'Monoterā',
        'MU' => 'Mōrihi',
        'MW' => 'Marāwi',
        'MX' => 'Mēhiko',
        'MZ' => 'Mohapiki',
        'NA' => 'Namīpia',
        'NE' => 'Ngāika',
        'NG' => 'Ngāitiria',
        'NI' => 'Nikarakua',
        'NL' => 'Hōrana',
        'NO' => 'Nōwei',
        'NZ' => 'Aotearoa',
        'PA' => 'Panama',
        'PE' => 'Peru',
        'PM' => 'Hato Piere & Mikarona',
        'PR' => 'Pōta Riko',
        'PY' => 'Parakai',
        'RE' => 'Rēnio',
        'RU' => 'Rūhia',
        'RW' => 'Rāwana',
        'SC' => 'Heihere',
        'SD' => 'Hūtāne',
        'SE' => 'Huītene',
        'SH' => 'Hato Harīna',
        'SJ' => 'Heopāra me Ia Maiana',
        'SL' => 'Te Araone',
        'SN' => 'Henekara',
        'SO' => 'Hūmārie',
        'SR' => 'Hurināme',
        'SS' => 'Hūtāne ki te Tonga',
        'ST' => 'Hao Tomei me Pirinipei',
        'SV' => 'Ere Hāwhatō',
        'SX' => 'Hiti Mātene',
        'SZ' => 'Ewatini',
        'TC' => 'Tāke me ngā Motu o Keiko',
        'TD' => 'Kāta',
        'TF' => 'Ngā Rohe o Wīwī ki te Tonga',
        'TG' => 'Toko',
        'TN' => 'Tūnihia',
        'TT' => 'Tinitātā me Topēko',
        'TZ' => 'Tānahia',
        'UG' => 'Ukāna',
        'US' => 'Hononga o Amerika',
        'UY' => 'Urukoi',
        'VC' => 'Hato Wetene me Keretīni',
        'VE' => 'Wenehūera',
        'VG' => 'Ngā Motu o Tātāhou Piritene',
        'VI' => 'Ngā Motu o Tātāhou Amerika',
        'YT' => 'Maio',
        'ZA' => 'Āwherika ki te Tonga',
        'ZM' => 'Tāmipia',
        'ZW' => 'Timuwawe',
    ],
];
