<?php

return [
    'Names' => [
        'ab' => 'Abkaziani',
        'ace' => 'Achinisi',
        'ada' => 'Adangme',
        'ady' => 'Adigi',
        'af' => 'Afrikaans',
        'agq' => 'Aghem',
        'ain' => 'Ainu',
        'ak' => 'Akan',
        'ale' => 'Alụt',
        'alt' => 'Sọutarn Altai',
        'am' => 'Amariikị',
        'an' => 'Aragonisị',
        'ann' => 'Obolọ',
        'anp' => 'Angika',
        'ar' => 'Arabiikị',
        'arn' => 'Mapuche',
        'arp' => 'Arapaho',
        'ars' => 'Najdi Arabikị',
        'as' => 'Asamisị',
        'asa' => 'Asụ',
        'ast' => 'Asturianị',
        'atj' => 'Atikamekwe',
        'av' => 'Avarịk',
        'awa' => 'Awadị',
        'ay' => 'Ayịmarà',
        'az' => 'Azerbajanị',
        'ba' => 'Bashki',
        'ban' => 'Balinisị',
        'bas' => 'Basaà',
        'be' => 'Belarusianụ',
        'bem' => 'Bembà',
        'bez' => 'Bena',
        'bg' => 'Bọlụgarịa',
        'bho' => 'Bojpuri',
        'bi' => 'Bislama',
        'bin' => 'Bini',
        'bla' => 'Siksikà',
        'bm' => 'Bambara',
        'bn' => 'Bengali',
        'bo' => 'Tibetan',
        'br' => 'Breton',
        'brx' => 'Bọdọ',
        'bs' => 'Bosnia',
        'bug' => 'Buginisị',
        'byn' => 'Blin',
        'ca' => 'Catalan',
        'cay' => 'Cayuga',
        'ccp' => 'Chakma',
        'ce' => 'Chechen',
        'ceb' => 'Cebụanọ',
        'cgg' => 'Chiga',
        'ch' => 'Chamoro',
        'chk' => 'Chukisị',
        'chm' => 'Mari',
        'cho' => 'Choctawu',
        'chp' => 'Chipewan',
        'chr' => 'Cheroke',
        'chy' => 'Cheyene',
        'ckb' => 'Kurdish ọsote',
        'clc' => 'Chilcotinị',
        'co' => 'Kọsịan',
        'crg' => 'Mịchif',
        'crj' => 'Sọutarn East kree',
        'crk' => 'Plains kree',
        'crl' => 'Nọrtan Eastị Kree',
        'crm' => 'Moọse kree',
        'crr' => 'Carolina Algonịkwan',
        'cs' => 'Cheekị',
        'csw' => 'Swampi kree',
        'cu' => 'Church slavic',
        'cv' => 'Chuvash',
        'cy' => 'Wesh',
        'da' => 'Danịsh',
        'dak' => 'Dakota',
        'dar' => 'Dagwa',
        'dav' => 'Taịta',
        'de' => 'Jamanị',
        'dgr' => 'Dogribụ',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Lowa Sorbịan',
        'dua' => 'Dụala',
        'dv' => 'Divehi',
        'dyo' => 'Jọla-Fọnyị',
        'dz' => 'Dọzngọka',
        'dzg' => 'Dazaga',
        'ebu' => 'Ebụm',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'eka' => 'Ekajukụ',
        'el' => 'Giriikị',
        'en' => 'Bekee',
        'eo' => 'Ndị Esperantọ',
        'es' => 'Spanishi',
        'et' => 'Ndị Estọnịa',
        'eu' => 'Baskwe',
        'ewo' => 'Ewọndọ',
        'fa' => 'Peshianụ',
        'ff' => 'Fula',
        'fi' => 'Fịnịsh',
        'fil' => 'Fịlịpịnọ',
        'fj' => 'Fijanị',
        'fo' => 'Farọse',
        'fon' => 'Fon',
        'fr' => 'Fụrenchị',
        'frc' => 'Kajun Furenchị',
        'frr' => 'Nọrtan Frisian',
        'fur' => 'Frụlịan',
        'fy' => 'Westan Frịsịan',
        'ga' => 'Ịrịsh',
        'gaa' => 'Ga',
        'gd' => 'Sụkọtịs Gelị',
        'gez' => 'Gịzị',
        'gil' => 'Gilbertisị',
        'gl' => 'Galịcịan',
        'gn' => 'Gwarani',
        'gor' => 'Gorontalo',
        'gsw' => 'German Swiss',
        'gu' => 'Gụaratị',
        'guz' => 'Gụshị',
        'gv' => 'Mansị',
        'gwi' => 'Gwichin',
        'ha' => 'Hausa',
        'hai' => 'Haida',
        'haw' => 'Hawaịlịan',
        'hax' => 'Sọutarn Haida',
        'he' => 'Hebrew',
        'hi' => 'Hindị',
        'hil' => 'Hiligayanon',
        'hmn' => 'Hmong',
        'hr' => 'Kọrọtịan',
        'hsb' => 'Ụpa Sọrbịa',
        'ht' => 'Haịtịan ndị Cerọle',
        'hu' => 'Hụngarian',
        'hup' => 'Hupa',
        'hur' => 'Halkomelem',
        'hy' => 'Armenianị',
        'hz' => 'Herero',
        'ia' => 'Intalịgụa',
        'iba' => 'Ibanị',
        'ibb' => 'Ibibio',
        'id' => 'Indonisia',
        'ig' => 'Igbo',
        'ii' => 'Sịchụayị',
        'ikt' => 'Westarn Canadian Inuktitut',
        'ilo' => 'Iloko',
        'inh' => 'Ingush',
        'io' => 'Ido',
        'is' => 'Icịlandịk',
        'it' => 'Italịanu',
        'iu' => 'Inuktitutị',
        'ja' => 'Japaniisi',
        'jbo' => 'Lojban',
        'jgo' => 'Ngọmba',
        'jmc' => 'Machame',
        'jv' => 'Java',
        'ka' => 'Geọjịan',
        'kab' => 'Kabyle',
        'kac' => 'Kachin',
        'kaj' => 'Ju',
        'kam' => 'Kamba',
        'kbd' => 'Kabadian',
        'kcg' => 'Tịyap',
        'kde' => 'Makọnde',
        'kea' => 'Kabụverdịanụ',
        'kfo' => 'Koro',
        'kgp' => 'Kainganga',
        'kha' => 'Khasi',
        'khq' => 'Kọyra Chịnị',
        'ki' => 'Kịkụyụ',
        'kj' => 'Kwanyama',
        'kk' => 'Kazak',
        'kkj' => 'Kakọ',
        'kl' => 'Kalaalịsụt',
        'kln' => 'Kalenjịn',
        'km' => 'Keme',
        'kmb' => 'Kimbundụ',
        'kn' => 'Kanhada',
        'ko' => 'Korịa',
        'kok' => 'Kọnkanị',
        'kpe' => 'Kpele',
        'kr' => 'Kanuri',
        'krc' => 'Karaché-Balka',
        'krl' => 'Karelian',
        'kru' => 'Kuruk',
        'ks' => 'Kashmịrị',
        'ksb' => 'Shabala',
        'ksf' => 'Bafịa',
        'ksh' => 'Colognịan',
        'ku' => 'Ndị Kụrdịsh',
        'kum' => 'Kumik',
        'kv' => 'Komi',
        'kw' => 'Kọnịsh',
        'kwk' => 'Kwakwala',
        'ky' => 'Kyrayz',
        'la' => 'Latịn',
        'lad' => 'Ladino',
        'lag' => 'Langị',
        'lb' => 'Lụxenbọụgịsh',
        'lez' => 'Lezgian',
        'lg' => 'Ganda',
        'li' => 'Limburgish',
        'lil' => 'Liloetị',
        'lkt' => 'Lakota',
        'ln' => 'Lịngala',
        'lo' => 'Laọ',
        'lou' => 'Louisiana Kreole',
        'loz' => 'Lozi',
        'lrc' => 'Nọrtụ Lụrị',
        'lsm' => 'Samia',
        'lt' => 'Lituanian',
        'lu' => 'Lịba-Katanga',
        'lua' => 'Luba-Lulua',
        'lun' => 'Lunda',
        'lus' => 'Mizo',
        'luy' => 'Lụyịa',
        'lv' => 'Latviani',
        'mad' => 'Madurese',
        'mag' => 'Magahi',
        'mai' => 'Maịtịlị',
        'mak' => 'Makasa',
        'mas' => 'Masaị',
        'mdf' => 'Moksha',
        'men' => 'Mende',
        'mer' => 'Merụ',
        'mfe' => 'Mọrịsye',
        'mg' => 'Malagasị',
        'mgh' => 'Makụwa Metọ',
        'mgo' => 'Meta',
        'mh' => 'Marshalese',
        'mi' => 'Maọrị',
        'mic' => 'Mịkmak',
        'min' => 'Mịnangkabau',
        'mk' => 'Masedọnịa',
        'ml' => 'Malayalam',
        'mn' => 'Mọngolịan',
        'mni' => 'Manịpụrị',
        'moe' => 'Inu-imun',
        'moh' => 'Mohọk',
        'mos' => 'Mossi',
        'mr' => 'Maratị',
        'ms' => 'Maleyi',
        'mt' => 'Matịse',
        'mua' => 'Mụdang',
        'mus' => 'Muscogee',
        'mwl' => 'Mịrandisị',
        'my' => 'Bụrmese',
        'myv' => 'Erzaya',
        'mzn' => 'Mazandaranị',
        'na' => 'Nauru',
        'nap' => 'Nịapolitan',
        'naq' => 'Nama',
        'nb' => 'Nọrweyịan Bọkmal',
        'nd' => 'Nọrtụ Ndabede',
        'nds' => 'Lowa German',
        'ne' => 'Nepali',
        'new' => 'Nịwari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niwan',
        'nl' => 'Dọchị',
        'nmg' => 'Kwasịọ',
        'nn' => 'Nọrweyịan Nynersk',
        'nnh' => 'Nglembọn',
        'no' => 'Nọrweyịan',
        'nog' => 'Nogai',
        'nqo' => 'Nkọ',
        'nr' => 'Sọut Ndebele',
        'nso' => 'Nọrtan Sotọ',
        'nus' => 'Nụer',
        'nv' => 'Navajo',
        'ny' => 'Nyanja',
        'nyn' => 'Nyakọle',
        'oc' => 'Osịtan',
        'ojb' => 'Nọrtwestan Ojibwa',
        'ojc' => 'Ojibwa ọsote',
        'ojs' => 'Oji-kree',
        'ojw' => 'Westarn Ojibwa',
        'oka' => 'Okanagan',
        'om' => 'Ọromo',
        'or' => 'Ọdịa',
        'os' => 'Osetik',
        'pa' => 'Punjabi',
        'pag' => 'Pangasinan',
        'pam' => 'Pampanga',
        'pap' => 'Papịamento',
        'pau' => 'Palawan',
        'pcm' => 'Pidgịn',
        'pis' => 'Pijịn',
        'pl' => 'Poliishi',
        'pqm' => 'Maliset-Pasamakwodị',
        'prg' => 'Prụssịan',
        'ps' => 'Pashọ',
        'pt' => 'Pọrtụgụese',
        'qu' => 'Qụechụa',
        'rap' => 'Rapunwị',
        'rar' => 'Rarotonganị',
        'rhg' => 'Rohinga',
        'rm' => 'Rọmansị',
        'rn' => 'Rụndị',
        'ro' => 'Romania',
        'rof' => 'Rọmbọ',
        'ru' => 'Rọshian',
        'rup' => 'Aromanian',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sansịkịt',
        'sad' => 'Sandawe',
        'sah' => 'Saka',
        'saq' => 'Sambụrụ',
        'sat' => 'Santalị',
        'sba' => 'Nkambé',
        'sbp' => 'Sangụ',
        'sc' => 'Sardinian',
        'scn' => 'Sisịlian',
        'sco' => 'Scots',
        'sd' => 'Sịndh',
        'se' => 'Nọrtan Samị',
        'seh' => 'Sena',
        'ses' => 'Kọyraboro Senị',
        'sg' => 'Sangọ',
        'shi' => 'Tachịkịt',
        'shn' => 'Shan',
        'si' => 'Sinhala',
        'sk' => 'Slova',
        'sl' => 'Slovịan',
        'slh' => 'Sọutarn Lushoọtseed',
        'sm' => 'Samọa',
        'smn' => 'Inarị Samị',
        'sms' => 'Skolt sami',
        'sn' => 'Shọna',
        'snk' => 'Soninké',
        'so' => 'Somali',
        'sq' => 'Albanianị',
        'sr' => 'Sebịan',
        'srn' => 'Sranan Tongo',
        'ss' => 'Swati',
        'st' => 'Sọụth Soto',
        'str' => 'Straits Salish',
        'su' => 'Sudanese',
        'suk' => 'Sukuma',
        'sv' => 'Sụwidiishi',
        'sw' => 'Swahili',
        'swb' => 'Komorịan',
        'syr' => 'Sirịak',
        'ta' => 'Tamil',
        'tce' => 'Sọutarn Tuchone',
        'te' => 'Telụgụ',
        'tem' => 'Timne',
        'teo' => 'Tesọ',
        'tet' => 'Tetum',
        'tg' => 'Tajịk',
        'tgx' => 'Tagish',
        'th' => 'Taị',
        'tht' => 'Tahitan',
        'ti' => 'Tịgrịnya',
        'tig' => 'Tịgre',
        'tk' => 'Turkịs',
        'tlh' => 'Klingon',
        'tli' => 'Tlịngịt',
        'tn' => 'Swana',
        'to' => 'Tọngan',
        'tok' => 'Tokị pọna',
        'tpi' => 'Tok pisin',
        'tr' => 'Tọkiishi',
        'trv' => 'Tarokọ',
        'ts' => 'Songa',
        'tt' => 'Tata',
        'ttm' => 'Nọrtan Tuchone',
        'tum' => 'Tumbuka',
        'tvl' => 'Tuvalu',
        'twq' => 'Tasawa',
        'ty' => 'Tahitian',
        'tyv' => 'Tuvinian',
        'tzm' => 'Central Atlas',
        'udm' => 'Udumụrt',
        'ug' => 'Ụyghụr',
        'uk' => 'Ukureenị',
        'umb' => 'Umbụndụ',
        'ur' => 'Urdụ',
        'uz' => 'Ụzbek',
        'vai' => 'Val',
        've' => 'Venda',
        'vi' => 'Vietnamisi',
        'vo' => 'Volapụ',
        'vun' => 'Vụnjọ',
        'wa' => 'Waloọn',
        'wae' => 'Wasa',
        'wal' => 'Woleịta',
        'war' => 'Waraị',
        'wo' => 'Wolọf',
        'wuu' => 'Wụ Chainisị',
        'xal' => 'Kalmik',
        'xh' => 'Xhọsa',
        'xog' => 'Sọga',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Yịdịsh',
        'yo' => 'Yoruba',
        'yrl' => 'Nheengatụ',
        'yue' => 'Katọnịse',
        'zgh' => 'Standard Moroccan Tamazait',
        'zh' => 'Chainisi',
        'zu' => 'Zulu',
        'zun' => 'Zuni',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Ụdị Arabiikị nke oge a',
        'de_AT' => 'Jaman ndị Austria',
        'de_CH' => 'Jaman Izugbe ndị Switzerland',
        'en_AU' => 'Bekee ndị Australia',
        'en_CA' => 'Bekee ndị Canada',
        'en_GB' => 'Bekee ndị United Kingdom',
        'en_US' => 'Bekee ndị America',
        'es_419' => 'Spanishi ndị Latin America',
        'es_ES' => 'Spanishi ndị Europe',
        'es_MX' => 'Spanishi ndị Mexico',
        'fr_CA' => 'Fụrench ndị Canada',
        'fr_CH' => 'Fụrench ndị Switzerland',
        'pt_BR' => 'Pọrtụgụese ndị Brazil',
        'pt_PT' => 'Asụsụ Portuguese ndị Europe',
        'zh_Hans' => 'Asụsụ Chinese dị mfe',
        'zh_Hant' => 'Asụsụ Chinese Izugbe',
    ],
];
