<?php

return [
    'Names' => [
        'af' => 'afrikanisht',
        'af_NA' => 'afrikanisht (Namibi)',
        'af_ZA' => 'afrikanisht (Afrika e Jugut)',
        'ak' => 'akanisht',
        'ak_GH' => 'akanisht (Ganë)',
        'am' => 'amarisht',
        'am_ET' => 'amarisht (Etiopi)',
        'ar' => 'arabisht',
        'ar_001' => 'arabisht (Bota)',
        'ar_AE' => 'arabisht (Emiratet e Bashkuara Arabe)',
        'ar_BH' => 'arabisht (Bahrejn)',
        'ar_DJ' => 'arabisht (Xhibuti)',
        'ar_DZ' => 'arabisht (Algjeri)',
        'ar_EG' => 'arabisht (Egjipt)',
        'ar_EH' => 'arabisht (Saharaja Perëndimore)',
        'ar_ER' => 'arabisht (Eritre)',
        'ar_IL' => 'arabisht (Izrael)',
        'ar_IQ' => 'arabisht (Irak)',
        'ar_JO' => 'arabisht (Jordani)',
        'ar_KM' => 'arabisht (Komore)',
        'ar_KW' => 'arabisht (Kuvajt)',
        'ar_LB' => 'arabisht (Liban)',
        'ar_LY' => 'arabisht (Libi)',
        'ar_MA' => 'arabisht (Marok)',
        'ar_MR' => 'arabisht (Mauritani)',
        'ar_OM' => 'arabisht (Oman)',
        'ar_PS' => 'arabisht (Territoret Palestineze)',
        'ar_QA' => 'arabisht (Katar)',
        'ar_SA' => 'arabisht (Arabi Saudite)',
        'ar_SD' => 'arabisht (Sudan)',
        'ar_SO' => 'arabisht (Somali)',
        'ar_SS' => 'arabisht (Sudani i Jugut)',
        'ar_SY' => 'arabisht (Siri)',
        'ar_TD' => 'arabisht (Çad)',
        'ar_TN' => 'arabisht (Tunizi)',
        'ar_YE' => 'arabisht (Jemen)',
        'as' => 'asamezisht',
        'as_IN' => 'asamezisht (Indi)',
        'az' => 'azerbajxhanisht',
        'az_AZ' => 'azerbajxhanisht (Azerbajxhan)',
        'az_Cyrl' => 'azerbajxhanisht (cirilik)',
        'az_Cyrl_AZ' => 'azerbajxhanisht (cirilik, Azerbajxhan)',
        'az_Latn' => 'azerbajxhanisht (latin)',
        'az_Latn_AZ' => 'azerbajxhanisht (latin, Azerbajxhan)',
        'be' => 'bjellorusisht',
        'be_BY' => 'bjellorusisht (Bjellorusi)',
        'bg' => 'bullgarisht',
        'bg_BG' => 'bullgarisht (Bullgari)',
        'bm' => 'bambarisht',
        'bm_ML' => 'bambarisht (Mali)',
        'bn' => 'bengalisht',
        'bn_BD' => 'bengalisht (Bangladesh)',
        'bn_IN' => 'bengalisht (Indi)',
        'bo' => 'tibetisht',
        'bo_CN' => 'tibetisht (Kinë)',
        'bo_IN' => 'tibetisht (Indi)',
        'br' => 'bretonisht',
        'br_FR' => 'bretonisht (Francë)',
        'bs' => 'boshnjakisht',
        'bs_BA' => 'boshnjakisht (Bosnjë-Hercegovinë)',
        'bs_Cyrl' => 'boshnjakisht (cirilik)',
        'bs_Cyrl_BA' => 'boshnjakisht (cirilik, Bosnjë-Hercegovinë)',
        'bs_Latn' => 'boshnjakisht (latin)',
        'bs_Latn_BA' => 'boshnjakisht (latin, Bosnjë-Hercegovinë)',
        'ca' => 'katalonisht',
        'ca_AD' => 'katalonisht (Andorrë)',
        'ca_ES' => 'katalonisht (Spanjë)',
        'ca_FR' => 'katalonisht (Francë)',
        'ca_IT' => 'katalonisht (Itali)',
        'ce' => 'çeçenisht',
        'ce_RU' => 'çeçenisht (Rusi)',
        'cs' => 'çekisht',
        'cs_CZ' => 'çekisht (Çeki)',
        'cv' => 'çuvashisht',
        'cv_RU' => 'çuvashisht (Rusi)',
        'cy' => 'uellsisht',
        'cy_GB' => 'uellsisht (Mbretëria e Bashkuar)',
        'da' => 'danisht',
        'da_DK' => 'danisht (Danimarkë)',
        'da_GL' => 'danisht (Grënlandë)',
        'de' => 'gjermanisht',
        'de_AT' => 'gjermanisht (Austri)',
        'de_BE' => 'gjermanisht (Belgjikë)',
        'de_CH' => 'gjermanisht (Zvicër)',
        'de_DE' => 'gjermanisht (Gjermani)',
        'de_IT' => 'gjermanisht (Itali)',
        'de_LI' => 'gjermanisht (Lihtenshtajn)',
        'de_LU' => 'gjermanisht (Luksemburg)',
        'dz' => 'xhongaisht',
        'dz_BT' => 'xhongaisht (Butan)',
        'ee' => 'eveisht',
        'ee_GH' => 'eveisht (Ganë)',
        'ee_TG' => 'eveisht (Togo)',
        'el' => 'greqisht',
        'el_CY' => 'greqisht (Qipro)',
        'el_GR' => 'greqisht (Greqi)',
        'en' => 'anglisht',
        'en_001' => 'anglisht (Bota)',
        'en_150' => 'anglisht (Evropë)',
        'en_AE' => 'anglisht (Emiratet e Bashkuara Arabe)',
        'en_AG' => 'anglisht (Antigua e Barbuda)',
        'en_AI' => 'anglisht (Anguilë)',
        'en_AS' => 'anglisht (Samoa Amerikane)',
        'en_AT' => 'anglisht (Austri)',
        'en_AU' => 'anglisht (Australi)',
        'en_BB' => 'anglisht (Barbados)',
        'en_BE' => 'anglisht (Belgjikë)',
        'en_BI' => 'anglisht (Burundi)',
        'en_BM' => 'anglisht (Bermude)',
        'en_BS' => 'anglisht (Bahama)',
        'en_BW' => 'anglisht (Botsvanë)',
        'en_BZ' => 'anglisht (Belizë)',
        'en_CA' => 'anglisht (Kanada)',
        'en_CC' => 'anglisht (Ishujt Kokos)',
        'en_CH' => 'anglisht (Zvicër)',
        'en_CK' => 'anglisht (Ishujt Kuk)',
        'en_CM' => 'anglisht (Kamerun)',
        'en_CX' => 'anglisht (Ishulli i Krishtlindjes)',
        'en_CY' => 'anglisht (Qipro)',
        'en_DE' => 'anglisht (Gjermani)',
        'en_DK' => 'anglisht (Danimarkë)',
        'en_DM' => 'anglisht (Dominikë)',
        'en_ER' => 'anglisht (Eritre)',
        'en_FI' => 'anglisht (Finlandë)',
        'en_FJ' => 'anglisht (Fixhi)',
        'en_FK' => 'anglisht (Ishujt Falkland)',
        'en_FM' => 'anglisht (Mikronezi)',
        'en_GB' => 'anglisht (Mbretëria e Bashkuar)',
        'en_GD' => 'anglisht (Granadë)',
        'en_GG' => 'anglisht (Gernsej)',
        'en_GH' => 'anglisht (Ganë)',
        'en_GI' => 'anglisht (Gjibraltar)',
        'en_GM' => 'anglisht (Gambi)',
        'en_GU' => 'anglisht (Guam)',
        'en_GY' => 'anglisht (Guajanë)',
        'en_HK' => 'anglisht (RPA i Hong-Kongut)',
        'en_IE' => 'anglisht (Irlandë)',
        'en_IL' => 'anglisht (Izrael)',
        'en_IM' => 'anglisht (Ishulli i Manit)',
        'en_IN' => 'anglisht (Indi)',
        'en_IO' => 'anglisht (Territori Britanik i Oqeanit Indian)',
        'en_JE' => 'anglisht (Xhersej)',
        'en_JM' => 'anglisht (Xhamajkë)',
        'en_KE' => 'anglisht (Kenia)',
        'en_KI' => 'anglisht (Kiribati)',
        'en_KN' => 'anglisht (Shën-Kits dhe Nevis)',
        'en_KY' => 'anglisht (Ishujt Kajman)',
        'en_LC' => 'anglisht (Shën-Luçia)',
        'en_LR' => 'anglisht (Liberi)',
        'en_LS' => 'anglisht (Lesoto)',
        'en_MG' => 'anglisht (Madagaskar)',
        'en_MH' => 'anglisht (Ishujt Marshall)',
        'en_MO' => 'anglisht (RPA i Makaos)',
        'en_MP' => 'anglisht (Ishujt e Marianës Veriore)',
        'en_MS' => 'anglisht (Montserat)',
        'en_MT' => 'anglisht (Maltë)',
        'en_MU' => 'anglisht (Mauritius)',
        'en_MV' => 'anglisht (Maldive)',
        'en_MW' => 'anglisht (Malavi)',
        'en_MY' => 'anglisht (Malajzi)',
        'en_NA' => 'anglisht (Namibi)',
        'en_NF' => 'anglisht (Ishulli Norfolk)',
        'en_NG' => 'anglisht (Nigeri)',
        'en_NL' => 'anglisht (Holandë)',
        'en_NR' => 'anglisht (Nauru)',
        'en_NU' => 'anglisht (Niue)',
        'en_NZ' => 'anglisht (Zelandë e Re)',
        'en_PG' => 'anglisht (Guineja e Re-Papua)',
        'en_PH' => 'anglisht (Filipine)',
        'en_PK' => 'anglisht (Pakistan)',
        'en_PN' => 'anglisht (Ishujt Pitkern)',
        'en_PR' => 'anglisht (Porto-Riko)',
        'en_PW' => 'anglisht (Palau)',
        'en_RW' => 'anglisht (Ruandë)',
        'en_SB' => 'anglisht (Ishujt Solomon)',
        'en_SC' => 'anglisht (Sejshelle)',
        'en_SD' => 'anglisht (Sudan)',
        'en_SE' => 'anglisht (Suedi)',
        'en_SG' => 'anglisht (Singapor)',
        'en_SH' => 'anglisht (Shën-Elenë)',
        'en_SI' => 'anglisht (Slloveni)',
        'en_SL' => 'anglisht (Sierra-Leone)',
        'en_SS' => 'anglisht (Sudani i Jugut)',
        'en_SX' => 'anglisht (Sint-Marten)',
        'en_SZ' => 'anglisht (Esvatini)',
        'en_TC' => 'anglisht (Ishujt Turks dhe Kaikos)',
        'en_TK' => 'anglisht (Tokelau)',
        'en_TO' => 'anglisht (Tonga)',
        'en_TT' => 'anglisht (Trinidad e Tobago)',
        'en_TV' => 'anglisht (Tuvalu)',
        'en_TZ' => 'anglisht (Tanzani)',
        'en_UG' => 'anglisht (Ugandë)',
        'en_UM' => 'anglisht (Ishujt Periferikë të SHBA-së)',
        'en_US' => 'anglisht (SHBA)',
        'en_VC' => 'anglisht (Shën-Vincent dhe Grenadine)',
        'en_VG' => 'anglisht (Ishujt e Virgjër Britanikë)',
        'en_VI' => 'anglisht (Ishujt e Virgjër të SHBA-së)',
        'en_VU' => 'anglisht (Vanuatu)',
        'en_WS' => 'anglisht (Samoa)',
        'en_ZA' => 'anglisht (Afrika e Jugut)',
        'en_ZM' => 'anglisht (Zambi)',
        'en_ZW' => 'anglisht (Zimbabve)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Bota)',
        'es' => 'spanjisht',
        'es_419' => 'spanjisht (Amerika Latine)',
        'es_AR' => 'spanjisht (Argjentinë)',
        'es_BO' => 'spanjisht (Bolivi)',
        'es_BR' => 'spanjisht (Brazil)',
        'es_BZ' => 'spanjisht (Belizë)',
        'es_CL' => 'spanjisht (Kili)',
        'es_CO' => 'spanjisht (Kolumbi)',
        'es_CR' => 'spanjisht (Kosta-Rikë)',
        'es_CU' => 'spanjisht (Kubë)',
        'es_DO' => 'spanjisht (Republika Dominikane)',
        'es_EC' => 'spanjisht (Ekuador)',
        'es_ES' => 'spanjisht (Spanjë)',
        'es_GQ' => 'spanjisht (Guineja Ekuatoriale)',
        'es_GT' => 'spanjisht (Guatemalë)',
        'es_HN' => 'spanjisht (Honduras)',
        'es_MX' => 'spanjisht (Meksikë)',
        'es_NI' => 'spanjisht (Nikaragua)',
        'es_PA' => 'spanjisht (Panama)',
        'es_PE' => 'spanjisht (Peru)',
        'es_PH' => 'spanjisht (Filipine)',
        'es_PR' => 'spanjisht (Porto-Riko)',
        'es_PY' => 'spanjisht (Paraguai)',
        'es_SV' => 'spanjisht (Salvador)',
        'es_US' => 'spanjisht (SHBA)',
        'es_UY' => 'spanjisht (Uruguai)',
        'es_VE' => 'spanjisht (Venezuelë)',
        'et' => 'estonisht',
        'et_EE' => 'estonisht (Estoni)',
        'eu' => 'baskisht',
        'eu_ES' => 'baskisht (Spanjë)',
        'fa' => 'persisht',
        'fa_AF' => 'persisht (Afganistan)',
        'fa_IR' => 'persisht (Iran)',
        'ff' => 'fulaisht',
        'ff_Adlm' => 'fulaisht (adlam)',
        'ff_Adlm_BF' => 'fulaisht (adlam, Burkina-Faso)',
        'ff_Adlm_CM' => 'fulaisht (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fulaisht (adlam, Ganë)',
        'ff_Adlm_GM' => 'fulaisht (adlam, Gambi)',
        'ff_Adlm_GN' => 'fulaisht (adlam, Guine)',
        'ff_Adlm_GW' => 'fulaisht (adlam, Guine-Bisau)',
        'ff_Adlm_LR' => 'fulaisht (adlam, Liberi)',
        'ff_Adlm_MR' => 'fulaisht (adlam, Mauritani)',
        'ff_Adlm_NE' => 'fulaisht (adlam, Niger)',
        'ff_Adlm_NG' => 'fulaisht (adlam, Nigeri)',
        'ff_Adlm_SL' => 'fulaisht (adlam, Sierra-Leone)',
        'ff_Adlm_SN' => 'fulaisht (adlam, Senegal)',
        'ff_CM' => 'fulaisht (Kamerun)',
        'ff_GN' => 'fulaisht (Guine)',
        'ff_Latn' => 'fulaisht (latin)',
        'ff_Latn_BF' => 'fulaisht (latin, Burkina-Faso)',
        'ff_Latn_CM' => 'fulaisht (latin, Kamerun)',
        'ff_Latn_GH' => 'fulaisht (latin, Ganë)',
        'ff_Latn_GM' => 'fulaisht (latin, Gambi)',
        'ff_Latn_GN' => 'fulaisht (latin, Guine)',
        'ff_Latn_GW' => 'fulaisht (latin, Guine-Bisau)',
        'ff_Latn_LR' => 'fulaisht (latin, Liberi)',
        'ff_Latn_MR' => 'fulaisht (latin, Mauritani)',
        'ff_Latn_NE' => 'fulaisht (latin, Niger)',
        'ff_Latn_NG' => 'fulaisht (latin, Nigeri)',
        'ff_Latn_SL' => 'fulaisht (latin, Sierra-Leone)',
        'ff_Latn_SN' => 'fulaisht (latin, Senegal)',
        'ff_MR' => 'fulaisht (Mauritani)',
        'ff_SN' => 'fulaisht (Senegal)',
        'fi' => 'finlandisht',
        'fi_FI' => 'finlandisht (Finlandë)',
        'fo' => 'faroisht',
        'fo_DK' => 'faroisht (Danimarkë)',
        'fo_FO' => 'faroisht (Ishujt Faroe)',
        'fr' => 'frëngjisht',
        'fr_BE' => 'frëngjisht (Belgjikë)',
        'fr_BF' => 'frëngjisht (Burkina-Faso)',
        'fr_BI' => 'frëngjisht (Burundi)',
        'fr_BJ' => 'frëngjisht (Benin)',
        'fr_BL' => 'frëngjisht (Sen-Bartelemi)',
        'fr_CA' => 'frëngjisht (Kanada)',
        'fr_CD' => 'frëngjisht (Kongo-Kinshasa)',
        'fr_CF' => 'frëngjisht (Republika e Afrikës Qendrore)',
        'fr_CG' => 'frëngjisht (Kongo-Brazavilë)',
        'fr_CH' => 'frëngjisht (Zvicër)',
        'fr_CI' => 'frëngjisht (Côte d’Ivoire)',
        'fr_CM' => 'frëngjisht (Kamerun)',
        'fr_DJ' => 'frëngjisht (Xhibuti)',
        'fr_DZ' => 'frëngjisht (Algjeri)',
        'fr_FR' => 'frëngjisht (Francë)',
        'fr_GA' => 'frëngjisht (Gabon)',
        'fr_GF' => 'frëngjisht (Guajana Franceze)',
        'fr_GN' => 'frëngjisht (Guine)',
        'fr_GP' => 'frëngjisht (Guadelupë)',
        'fr_GQ' => 'frëngjisht (Guineja Ekuatoriale)',
        'fr_HT' => 'frëngjisht (Haiti)',
        'fr_KM' => 'frëngjisht (Komore)',
        'fr_LU' => 'frëngjisht (Luksemburg)',
        'fr_MA' => 'frëngjisht (Marok)',
        'fr_MC' => 'frëngjisht (Monako)',
        'fr_MF' => 'frëngjisht (Sen-Marten)',
        'fr_MG' => 'frëngjisht (Madagaskar)',
        'fr_ML' => 'frëngjisht (Mali)',
        'fr_MQ' => 'frëngjisht (Martinikë)',
        'fr_MR' => 'frëngjisht (Mauritani)',
        'fr_MU' => 'frëngjisht (Mauritius)',
        'fr_NC' => 'frëngjisht (Kaledoni e Re)',
        'fr_NE' => 'frëngjisht (Niger)',
        'fr_PF' => 'frëngjisht (Polinezia Franceze)',
        'fr_PM' => 'frëngjisht (Shën-Pier dhe Mikelon)',
        'fr_RE' => 'frëngjisht (Reunion)',
        'fr_RW' => 'frëngjisht (Ruandë)',
        'fr_SC' => 'frëngjisht (Sejshelle)',
        'fr_SN' => 'frëngjisht (Senegal)',
        'fr_SY' => 'frëngjisht (Siri)',
        'fr_TD' => 'frëngjisht (Çad)',
        'fr_TG' => 'frëngjisht (Togo)',
        'fr_TN' => 'frëngjisht (Tunizi)',
        'fr_VU' => 'frëngjisht (Vanuatu)',
        'fr_WF' => 'frëngjisht (Uollis e Futuna)',
        'fr_YT' => 'frëngjisht (Majotë)',
        'fy' => 'frizianishte perëndimore',
        'fy_NL' => 'frizianishte perëndimore (Holandë)',
        'ga' => 'irlandisht',
        'ga_GB' => 'irlandisht (Mbretëria e Bashkuar)',
        'ga_IE' => 'irlandisht (Irlandë)',
        'gd' => 'galishte skoceze',
        'gd_GB' => 'galishte skoceze (Mbretëria e Bashkuar)',
        'gl' => 'galicisht',
        'gl_ES' => 'galicisht (Spanjë)',
        'gu' => 'guxharatisht',
        'gu_IN' => 'guxharatisht (Indi)',
        'gv' => 'manksisht',
        'gv_IM' => 'manksisht (Ishulli i Manit)',
        'ha' => 'hausisht',
        'ha_GH' => 'hausisht (Ganë)',
        'ha_NE' => 'hausisht (Niger)',
        'ha_NG' => 'hausisht (Nigeri)',
        'he' => 'hebraisht',
        'he_IL' => 'hebraisht (Izrael)',
        'hi' => 'indisht',
        'hi_IN' => 'indisht (Indi)',
        'hi_Latn' => 'indisht (latin)',
        'hi_Latn_IN' => 'indisht (latin, Indi)',
        'hr' => 'kroatisht',
        'hr_BA' => 'kroatisht (Bosnjë-Hercegovinë)',
        'hr_HR' => 'kroatisht (Kroaci)',
        'hu' => 'hungarisht',
        'hu_HU' => 'hungarisht (Hungari)',
        'hy' => 'armenisht',
        'hy_AM' => 'armenisht (Armeni)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Bota)',
        'id' => 'indonezisht',
        'id_ID' => 'indonezisht (Indonezi)',
        'ig' => 'igboisht',
        'ig_NG' => 'igboisht (Nigeri)',
        'ii' => 'sishuanisht',
        'ii_CN' => 'sishuanisht (Kinë)',
        'is' => 'islandisht',
        'is_IS' => 'islandisht (Islandë)',
        'it' => 'italisht',
        'it_CH' => 'italisht (Zvicër)',
        'it_IT' => 'italisht (Itali)',
        'it_SM' => 'italisht (San-Marino)',
        'it_VA' => 'italisht (Vatikan)',
        'ja' => 'japonisht',
        'ja_JP' => 'japonisht (Japoni)',
        'jv' => 'javanisht',
        'jv_ID' => 'javanisht (Indonezi)',
        'ka' => 'gjeorgjisht',
        'ka_GE' => 'gjeorgjisht (Gjeorgji)',
        'ki' => 'kikujuisht',
        'ki_KE' => 'kikujuisht (Kenia)',
        'kk' => 'kazakisht',
        'kk_KZ' => 'kazakisht (Kazakistan)',
        'kl' => 'kalalisutisht',
        'kl_GL' => 'kalalisutisht (Grënlandë)',
        'km' => 'kmerisht',
        'km_KH' => 'kmerisht (Kamboxhia)',
        'kn' => 'kanadisht',
        'kn_IN' => 'kanadisht (Indi)',
        'ko' => 'koreanisht',
        'ko_KP' => 'koreanisht (Kore e Veriut)',
        'ko_KR' => 'koreanisht (Kore e Jugut)',
        'ks' => 'kashmirisht',
        'ks_Arab' => 'kashmirisht (arabik)',
        'ks_Arab_IN' => 'kashmirisht (arabik, Indi)',
        'ks_Deva' => 'kashmirisht (devanagar)',
        'ks_Deva_IN' => 'kashmirisht (devanagar, Indi)',
        'ks_IN' => 'kashmirisht (Indi)',
        'ku' => 'kurdisht',
        'ku_TR' => 'kurdisht (Turqi)',
        'kw' => 'kornisht',
        'kw_GB' => 'kornisht (Mbretëria e Bashkuar)',
        'ky' => 'kirgizisht',
        'ky_KG' => 'kirgizisht (Kirgizi)',
        'lb' => 'luksemburgisht',
        'lb_LU' => 'luksemburgisht (Luksemburg)',
        'lg' => 'gandaisht',
        'lg_UG' => 'gandaisht (Ugandë)',
        'ln' => 'lingalisht',
        'ln_AO' => 'lingalisht (Angolë)',
        'ln_CD' => 'lingalisht (Kongo-Kinshasa)',
        'ln_CF' => 'lingalisht (Republika e Afrikës Qendrore)',
        'ln_CG' => 'lingalisht (Kongo-Brazavilë)',
        'lo' => 'laosisht',
        'lo_LA' => 'laosisht (Laos)',
        'lt' => 'lituanisht',
        'lt_LT' => 'lituanisht (Lituani)',
        'lu' => 'luba-katangaisht',
        'lu_CD' => 'luba-katangaisht (Kongo-Kinshasa)',
        'lv' => 'letonisht',
        'lv_LV' => 'letonisht (Letoni)',
        'mg' => 'madagaskarisht',
        'mg_MG' => 'madagaskarisht (Madagaskar)',
        'mi' => 'maorisht',
        'mi_NZ' => 'maorisht (Zelandë e Re)',
        'mk' => 'maqedonisht',
        'mk_MK' => 'maqedonisht (Maqedonia e Veriut)',
        'ml' => 'malajalamisht',
        'ml_IN' => 'malajalamisht (Indi)',
        'mn' => 'mongolisht',
        'mn_MN' => 'mongolisht (Mongoli)',
        'mr' => 'maratisht',
        'mr_IN' => 'maratisht (Indi)',
        'ms' => 'malajisht',
        'ms_BN' => 'malajisht (Brunei)',
        'ms_ID' => 'malajisht (Indonezi)',
        'ms_MY' => 'malajisht (Malajzi)',
        'ms_SG' => 'malajisht (Singapor)',
        'mt' => 'maltisht',
        'mt_MT' => 'maltisht (Maltë)',
        'my' => 'birmanisht',
        'my_MM' => 'birmanisht (Mianmar [Burmë])',
        'nb' => 'norvegjishte letrare',
        'nb_NO' => 'norvegjishte letrare (Norvegji)',
        'nb_SJ' => 'norvegjishte letrare (Svalbard e Jan-Majen)',
        'nd' => 'ndebelishte veriore',
        'nd_ZW' => 'ndebelishte veriore (Zimbabve)',
        'ne' => 'nepalisht',
        'ne_IN' => 'nepalisht (Indi)',
        'ne_NP' => 'nepalisht (Nepal)',
        'nl' => 'holandisht',
        'nl_AW' => 'holandisht (Arubë)',
        'nl_BE' => 'holandisht (Belgjikë)',
        'nl_BQ' => 'holandisht (Karaibet holandeze)',
        'nl_CW' => 'holandisht (Kurasao)',
        'nl_NL' => 'holandisht (Holandë)',
        'nl_SR' => 'holandisht (Surinami)',
        'nl_SX' => 'holandisht (Sint-Marten)',
        'nn' => 'norvegjishte nynorsk',
        'nn_NO' => 'norvegjishte nynorsk (Norvegji)',
        'no' => 'norvegjisht',
        'no_NO' => 'norvegjisht (Norvegji)',
        'om' => 'oromoisht',
        'om_ET' => 'oromoisht (Etiopi)',
        'om_KE' => 'oromoisht (Kenia)',
        'or' => 'odisht',
        'or_IN' => 'odisht (Indi)',
        'os' => 'osetisht',
        'os_GE' => 'osetisht (Gjeorgji)',
        'os_RU' => 'osetisht (Rusi)',
        'pa' => 'punxhabisht',
        'pa_Arab' => 'punxhabisht (arabik)',
        'pa_Arab_PK' => 'punxhabisht (arabik, Pakistan)',
        'pa_Guru' => 'punxhabisht (gurmuk)',
        'pa_Guru_IN' => 'punxhabisht (gurmuk, Indi)',
        'pa_IN' => 'punxhabisht (Indi)',
        'pa_PK' => 'punxhabisht (Pakistan)',
        'pl' => 'polonisht',
        'pl_PL' => 'polonisht (Poloni)',
        'ps' => 'pashtoisht',
        'ps_AF' => 'pashtoisht (Afganistan)',
        'ps_PK' => 'pashtoisht (Pakistan)',
        'pt' => 'portugalisht',
        'pt_AO' => 'portugalisht (Angolë)',
        'pt_BR' => 'portugalisht (Brazil)',
        'pt_CH' => 'portugalisht (Zvicër)',
        'pt_CV' => 'portugalisht (Kepi i Gjelbër)',
        'pt_GQ' => 'portugalisht (Guineja Ekuatoriale)',
        'pt_GW' => 'portugalisht (Guine-Bisau)',
        'pt_LU' => 'portugalisht (Luksemburg)',
        'pt_MO' => 'portugalisht (RPA i Makaos)',
        'pt_MZ' => 'portugalisht (Mozambik)',
        'pt_PT' => 'portugalisht (Portugali)',
        'pt_ST' => 'portugalisht (Sao-Tome e Principe)',
        'pt_TL' => 'portugalisht (Timor-Leste)',
        'qu' => 'keçuaisht',
        'qu_BO' => 'keçuaisht (Bolivi)',
        'qu_EC' => 'keçuaisht (Ekuador)',
        'qu_PE' => 'keçuaisht (Peru)',
        'rm' => 'retoromanisht',
        'rm_CH' => 'retoromanisht (Zvicër)',
        'rn' => 'rundisht',
        'rn_BI' => 'rundisht (Burundi)',
        'ro' => 'rumanisht',
        'ro_MD' => 'rumanisht (Moldavi)',
        'ro_RO' => 'rumanisht (Rumani)',
        'ru' => 'rusisht',
        'ru_BY' => 'rusisht (Bjellorusi)',
        'ru_KG' => 'rusisht (Kirgizi)',
        'ru_KZ' => 'rusisht (Kazakistan)',
        'ru_MD' => 'rusisht (Moldavi)',
        'ru_RU' => 'rusisht (Rusi)',
        'ru_UA' => 'rusisht (Ukrainë)',
        'rw' => 'kiniaruandisht',
        'rw_RW' => 'kiniaruandisht (Ruandë)',
        'sa' => 'sanskritisht',
        'sa_IN' => 'sanskritisht (Indi)',
        'sc' => 'sardenjisht',
        'sc_IT' => 'sardenjisht (Itali)',
        'sd' => 'sindisht',
        'sd_Arab' => 'sindisht (arabik)',
        'sd_Arab_PK' => 'sindisht (arabik, Pakistan)',
        'sd_Deva' => 'sindisht (devanagar)',
        'sd_Deva_IN' => 'sindisht (devanagar, Indi)',
        'sd_IN' => 'sindisht (Indi)',
        'sd_PK' => 'sindisht (Pakistan)',
        'se' => 'samishte veriore',
        'se_FI' => 'samishte veriore (Finlandë)',
        'se_NO' => 'samishte veriore (Norvegji)',
        'se_SE' => 'samishte veriore (Suedi)',
        'sg' => 'sangoisht',
        'sg_CF' => 'sangoisht (Republika e Afrikës Qendrore)',
        'sh' => 'serbo-kroatisht',
        'sh_BA' => 'serbo-kroatisht (Bosnjë-Hercegovinë)',
        'si' => 'sinhalisht',
        'si_LK' => 'sinhalisht (Sri-Lankë)',
        'sk' => 'sllovakisht',
        'sk_SK' => 'sllovakisht (Sllovaki)',
        'sl' => 'sllovenisht',
        'sl_SI' => 'sllovenisht (Slloveni)',
        'sn' => 'shonisht',
        'sn_ZW' => 'shonisht (Zimbabve)',
        'so' => 'somalisht',
        'so_DJ' => 'somalisht (Xhibuti)',
        'so_ET' => 'somalisht (Etiopi)',
        'so_KE' => 'somalisht (Kenia)',
        'so_SO' => 'somalisht (Somali)',
        'sq' => 'shqip',
        'sq_AL' => 'shqip (Shqipëri)',
        'sq_MK' => 'shqip (Maqedonia e Veriut)',
        'sr' => 'serbisht',
        'sr_BA' => 'serbisht (Bosnjë-Hercegovinë)',
        'sr_Cyrl' => 'serbisht (cirilik)',
        'sr_Cyrl_BA' => 'serbisht (cirilik, Bosnjë-Hercegovinë)',
        'sr_Cyrl_ME' => 'serbisht (cirilik, Mal i Zi)',
        'sr_Cyrl_RS' => 'serbisht (cirilik, Serbi)',
        'sr_Latn' => 'serbisht (latin)',
        'sr_Latn_BA' => 'serbisht (latin, Bosnjë-Hercegovinë)',
        'sr_Latn_ME' => 'serbisht (latin, Mal i Zi)',
        'sr_Latn_RS' => 'serbisht (latin, Serbi)',
        'sr_ME' => 'serbisht (Mal i Zi)',
        'sr_RS' => 'serbisht (Serbi)',
        'su' => 'sundanisht',
        'su_ID' => 'sundanisht (Indonezi)',
        'su_Latn' => 'sundanisht (latin)',
        'su_Latn_ID' => 'sundanisht (latin, Indonezi)',
        'sv' => 'suedisht',
        'sv_AX' => 'suedisht (Ishujt Alandë)',
        'sv_FI' => 'suedisht (Finlandë)',
        'sv_SE' => 'suedisht (Suedi)',
        'sw' => 'suahilisht',
        'sw_CD' => 'suahilisht (Kongo-Kinshasa)',
        'sw_KE' => 'suahilisht (Kenia)',
        'sw_TZ' => 'suahilisht (Tanzani)',
        'sw_UG' => 'suahilisht (Ugandë)',
        'ta' => 'tamilisht',
        'ta_IN' => 'tamilisht (Indi)',
        'ta_LK' => 'tamilisht (Sri-Lankë)',
        'ta_MY' => 'tamilisht (Malajzi)',
        'ta_SG' => 'tamilisht (Singapor)',
        'te' => 'teluguisht',
        'te_IN' => 'teluguisht (Indi)',
        'tg' => 'taxhikisht',
        'tg_TJ' => 'taxhikisht (Taxhikistan)',
        'th' => 'tajlandisht',
        'th_TH' => 'tajlandisht (Tajlandë)',
        'ti' => 'tigrinjaisht',
        'ti_ER' => 'tigrinjaisht (Eritre)',
        'ti_ET' => 'tigrinjaisht (Etiopi)',
        'tk' => 'turkmenisht',
        'tk_TM' => 'turkmenisht (Turkmenistan)',
        'to' => 'tonganisht',
        'to_TO' => 'tonganisht (Tonga)',
        'tr' => 'turqisht',
        'tr_CY' => 'turqisht (Qipro)',
        'tr_TR' => 'turqisht (Turqi)',
        'tt' => 'tatarisht',
        'tt_RU' => 'tatarisht (Rusi)',
        'ug' => 'ujgurisht',
        'ug_CN' => 'ujgurisht (Kinë)',
        'uk' => 'ukrainisht',
        'uk_UA' => 'ukrainisht (Ukrainë)',
        'ur' => 'urduisht',
        'ur_IN' => 'urduisht (Indi)',
        'ur_PK' => 'urduisht (Pakistan)',
        'uz' => 'uzbekisht',
        'uz_AF' => 'uzbekisht (Afganistan)',
        'uz_Arab' => 'uzbekisht (arabik)',
        'uz_Arab_AF' => 'uzbekisht (arabik, Afganistan)',
        'uz_Cyrl' => 'uzbekisht (cirilik)',
        'uz_Cyrl_UZ' => 'uzbekisht (cirilik, Uzbekistan)',
        'uz_Latn' => 'uzbekisht (latin)',
        'uz_Latn_UZ' => 'uzbekisht (latin, Uzbekistan)',
        'uz_UZ' => 'uzbekisht (Uzbekistan)',
        'vi' => 'vietnamisht',
        'vi_VN' => 'vietnamisht (Vietnam)',
        'wo' => 'uolofisht',
        'wo_SN' => 'uolofisht (Senegal)',
        'xh' => 'xhosaisht',
        'xh_ZA' => 'xhosaisht (Afrika e Jugut)',
        'yi' => 'jidisht',
        'yi_001' => 'jidisht (Bota)',
        'yo' => 'jorubaisht',
        'yo_BJ' => 'jorubaisht (Benin)',
        'yo_NG' => 'jorubaisht (Nigeri)',
        'zh' => 'kinezisht',
        'zh_CN' => 'kinezisht (Kinë)',
        'zh_HK' => 'kinezisht (RPA i Hong-Kongut)',
        'zh_Hans' => 'kinezisht (i thjeshtuar)',
        'zh_Hans_CN' => 'kinezisht (i thjeshtuar, Kinë)',
        'zh_Hans_HK' => 'kinezisht (i thjeshtuar, RPA i Hong-Kongut)',
        'zh_Hans_MO' => 'kinezisht (i thjeshtuar, RPA i Makaos)',
        'zh_Hans_SG' => 'kinezisht (i thjeshtuar, Singapor)',
        'zh_Hant' => 'kinezisht (tradicional)',
        'zh_Hant_HK' => 'kinezisht (tradicional, RPA i Hong-Kongut)',
        'zh_Hant_MO' => 'kinezisht (tradicional, RPA i Makaos)',
        'zh_Hant_TW' => 'kinezisht (tradicional, Tajvan)',
        'zh_MO' => 'kinezisht (RPA i Makaos)',
        'zh_SG' => 'kinezisht (Singapor)',
        'zh_TW' => 'kinezisht (Tajvan)',
        'zu' => 'zuluisht',
        'zu_ZA' => 'zuluisht (Afrika e Jugut)',
    ],
];
