<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abxaz',
        'ace' => 'akin',
        'ach' => 'akoli',
        'ada' => 'adanqme',
        'ady' => 'adıgey',
        'ae' => 'avestan',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aqhem',
        'ain' => 'aynu',
        'ak' => 'akan',
        'akk' => 'akkad',
        'ale' => 'aleut',
        'alt' => 'cənubi altay',
        'am' => 'amhar',
        'an' => 'araqon',
        'ang' => 'qədim ingilis',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'ərəb',
        'arc' => 'aramik',
        'arn' => 'mapuçe',
        'arp' => 'arapaho',
        'ars' => 'Nəcd ərəbcəsi',
        'arw' => 'aravak',
        'as' => 'assam',
        'asa' => 'asu',
        'ast' => 'asturiya',
        'atj' => 'Atikamek',
        'av' => 'avar',
        'awa' => 'avadhi',
        'ay' => 'aymara',
        'az' => 'azərbaycan',
        'ba' => 'başqırd',
        'bal' => 'baluc',
        'ban' => 'bali',
        'bas' => 'basa',
        'be' => 'belarus',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bolqar',
        'bgn' => 'qərbi bəluc',
        'bho' => 'bxoçpuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bla' => 'siksikə',
        'bm' => 'bambara',
        'bn' => 'benqal',
        'bo' => 'tibet',
        'br' => 'breton',
        'bra' => 'braj',
        'brx' => 'bodo',
        'bs' => 'bosniya',
        'bua' => 'buryat',
        'bug' => 'bugin',
        'byn' => 'blin',
        'ca' => 'katalan',
        'cad' => 'keddo',
        'car' => 'karib',
        'cay' => 'Kayuqa',
        'cch' => 'atsam',
        'ccp' => 'Çakma',
        'ce' => 'çeçen',
        'ceb' => 'sebuan',
        'cgg' => 'çiqa',
        'ch' => 'çamoro',
        'chb' => 'çibça',
        'chg' => 'çağatay',
        'chk' => 'çukiz',
        'chm' => 'mari',
        'chn' => 'çinuk ləhçəsi',
        'cho' => 'çoktau',
        'chp' => 'çipevyan',
        'chr' => 'çeroki',
        'chy' => 'çeyen',
        'ckb' => 'Mərkəzi kürdcə',
        'clc' => 'Çilotin',
        'co' => 'korsika',
        'cop' => 'kopt',
        'cr' => 'kri',
        'crg' => 'miçif',
        'crh' => 'krım türkcəsi',
        'crj' => 'cənub-şərqi kri',
        'crk' => 'ova kricəsi',
        'crl' => 'şimal-şəqri kri',
        'crm' => 'muz kri',
        'crr' => 'Karolina alonkincəsi',
        'crs' => 'Seyşel kreol fransızcası',
        'cs' => 'çex',
        'csb' => 'kaşubyan',
        'csw' => 'bataqlıq kricəsi',
        'cu' => 'slavyan',
        'cv' => 'çuvaş',
        'cy' => 'uels',
        'da' => 'danimarka',
        'dak' => 'dakota',
        'dar' => 'darqva',
        'dav' => 'taita',
        'de' => 'alman',
        'del' => 'delaver',
        'den' => 'slavey',
        'dgr' => 'doqrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'doqri',
        'dsb' => 'aşağı sorb',
        'dua' => 'duala',
        'dum' => 'orta holland',
        'dv' => 'maldiv',
        'dyo' => 'diola',
        'dyu' => 'dyula',
        'dz' => 'dzonqxa',
        'dzg' => 'dazaqa',
        'ebu' => 'embu',
        'ee' => 'eve',
        'efi' => 'efik',
        'egy' => 'qədim misir',
        'eka' => 'ekacuk',
        'el' => 'yunan',
        'elx' => 'elamit',
        'en' => 'ingilis',
        'enm' => 'orta ingilis',
        'eo' => 'esperanto',
        'es' => 'ispan',
        'et' => 'eston',
        'eu' => 'bask',
        'ewo' => 'evondo',
        'fa' => 'fars',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fula',
        'fi' => 'fin',
        'fil' => 'filippin',
        'fj' => 'fici',
        'fo' => 'farer',
        'fon' => 'fon',
        'fr' => 'fransız',
        'frc' => 'Kacun fransızcası',
        'frm' => 'orta fransız',
        'fro' => 'qədim fransız',
        'frr' => 'şimali fris',
        'fur' => 'friul',
        'fy' => 'qərbi friz',
        'ga' => 'irland',
        'gaa' => 'qa',
        'gag' => 'qaqauz',
        'gan' => 'qan',
        'gay' => 'qayo',
        'gba' => 'qabaya',
        'gd' => 'Şotlandiya keltcəsi',
        'gez' => 'qez',
        'gil' => 'qilbert',
        'gl' => 'qalisiya',
        'gmh' => 'orta yüksək alman',
        'gn' => 'quarani',
        'goh' => 'qədim alman',
        'gon' => 'qondi',
        'gor' => 'qorontalo',
        'got' => 'qotika',
        'grb' => 'qrebo',
        'grc' => 'qədim yunan',
        'gsw' => 'İsveçrə almancası',
        'gu' => 'qucarat',
        'guz' => 'qusi',
        'gv' => 'manks',
        'gwi' => 'qviçin',
        'ha' => 'hausa',
        'hai' => 'hayda',
        'hak' => 'hakka',
        'haw' => 'havay',
        'hax' => 'cənubi haida',
        'he' => 'ivrit',
        'hi' => 'hind',
        'hil' => 'hiliqaynon',
        'hit' => 'hittit',
        'hmn' => 'monq',
        'ho' => 'hiri motu',
        'hr' => 'xorvat',
        'hsb' => 'yuxarı sorb',
        'hsn' => 'syan',
        'ht' => 'haiti kreol',
        'hu' => 'macar',
        'hup' => 'hupa',
        'hur' => 'Halkomelem',
        'hy' => 'erməni',
        'hz' => 'herero',
        'ia' => 'interlinqua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indoneziya',
        'ie' => 'interlinqve',
        'ig' => 'iqbo',
        'ii' => 'siçuan yi',
        'ik' => 'inupiaq',
        'ikt' => 'qərbi Kanada inuktitutu',
        'ilo' => 'iloko',
        'inh' => 'inquş',
        'io' => 'ido',
        'is' => 'island',
        'it' => 'italyan',
        'iu' => 'inuktitut',
        'ja' => 'yapon',
        'jbo' => 'loğban',
        'jgo' => 'nqomba',
        'jmc' => 'maçam',
        'jpr' => 'ivrit-fars',
        'jrb' => 'ivrit-ərəb',
        'jv' => 'yava',
        'ka' => 'gürcü',
        'kaa' => 'qaraqalpaq',
        'kab' => 'kabile',
        'kac' => 'kaçin',
        'kaj' => 'ju',
        'kam' => 'kamba',
        'kaw' => 'kavi',
        'kbd' => 'kabarda-çərkəz',
        'kcg' => 'tiyap',
        'kde' => 'makond',
        'kea' => 'kabuverdian',
        'kfo' => 'koro',
        'kg' => 'konqo',
        'kgp' => 'kaiqanq',
        'kha' => 'xazi',
        'kho' => 'xotan',
        'khq' => 'koyra çiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'qazax',
        'kkj' => 'kako',
        'kl' => 'kalaallisut',
        'kln' => 'kalencin',
        'km' => 'kxmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreya',
        'koi' => 'komi-permyak',
        'kok' => 'konkani',
        'kos' => 'kosreyan',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'qaraçay-balkar',
        'krl' => 'karel',
        'kru' => 'kurux',
        'ks' => 'kəşmir',
        'ksb' => 'şambala',
        'ksf' => 'bafia',
        'ksh' => 'köln',
        'ku' => 'kürd',
        'kum' => 'kumık',
        'kut' => 'kutenay',
        'kv' => 'komi',
        'kw' => 'korn',
        'kwk' => 'Kvakvala',
        'ky' => 'qırğız',
        'la' => 'latın',
        'lad' => 'sefard',
        'lag' => 'langi',
        'lah' => 'qərbi pəncab',
        'lam' => 'lamba',
        'lb' => 'lüksemburq',
        'lez' => 'ləzgi',
        'lg' => 'qanda',
        'li' => 'limburq',
        'lil' => 'Liluet',
        'lkt' => 'lakota',
        'ln' => 'linqala',
        'lo' => 'laos',
        'lol' => 'monqo',
        'lou' => 'Luiziana kreolu',
        'loz' => 'lozi',
        'lrc' => 'şimali luri',
        'lsm' => 'saamia',
        'lt' => 'litva',
        'lu' => 'luba-katanqa',
        'lua' => 'luba-lulua',
        'lui' => 'luyseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'mizo',
        'luy' => 'luyia',
        'lv' => 'latış',
        'mad' => 'maduriz',
        'mag' => 'maqahi',
        'mai' => 'maitili',
        'mak' => 'makasar',
        'man' => 'məndinqo',
        'mas' => 'masay',
        'mdf' => 'mokşa',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisien',
        'mg' => 'malaqas',
        'mga' => 'orta irland',
        'mgh' => 'maxuva-meetto',
        'mgo' => 'meta’',
        'mh' => 'marşal',
        'mi' => 'māori',
        'mic' => 'mikmak',
        'min' => 'minanqkaban',
        'mk' => 'makedon',
        'ml' => 'malayalam',
        'mn' => 'monqol',
        'mnc' => 'mançu',
        'mni' => 'manipüri',
        'moe' => 'İnnu-aimun',
        'moh' => 'mohavk',
        'mos' => 'mosi',
        'mr' => 'marathi',
        'ms' => 'malay',
        'mt' => 'malta',
        'mua' => 'mundanq',
        'mus' => 'krik',
        'mwl' => 'mirand',
        'mwr' => 'maruari',
        'my' => 'birman',
        'myv' => 'erzya',
        'mzn' => 'mazandaran',
        'na' => 'nauru',
        'nan' => 'Min Nan',
        'nap' => 'neapolitan',
        'naq' => 'nama',
        'nb' => 'bokmal norveç',
        'nd' => 'şimali ndebele',
        'nds' => 'aşağı alman',
        'ne' => 'nepal',
        'new' => 'nevari',
        'ng' => 'ndonqa',
        'nia' => 'nias',
        'niu' => 'niyuan',
        'nl' => 'holland',
        'nmg' => 'kvasio',
        'nn' => 'nünorsk norveç',
        'nnh' => 'ngiemboon',
        'no' => 'norveç',
        'nog' => 'noqay',
        'non' => 'qədim nors',
        'nqo' => 'nko',
        'nr' => 'cənubi ndebele',
        'nso' => 'şimal soto',
        'nus' => 'nuer',
        'nv' => 'navayo',
        'ny' => 'nyanca',
        'nym' => 'nyamvezi',
        'nyn' => 'nyankol',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'oksitan',
        'oj' => 'ocibva',
        'ojb' => 'şimal-qərbi ocibva',
        'ojc' => 'Mərkəzi ocibva',
        'ojs' => 'ocikri',
        'ojw' => 'qərbi ocibva',
        'oka' => 'okanaqan',
        'om' => 'oromo',
        'or' => 'odiya',
        'os' => 'osetin',
        'osa' => 'osage',
        'ota' => 'osman',
        'pa' => 'pəncab',
        'pag' => 'panqasinan',
        'pal' => 'pəhləvi',
        'pam' => 'pampanqa',
        'pap' => 'papyamento',
        'pau' => 'palayan',
        'pcm' => 'niger kreol',
        'peo' => 'qədim fars',
        'phn' => 'foyenik',
        'pi' => 'pali',
        'pis' => 'picin',
        'pl' => 'polyak',
        'pon' => 'ponpey',
        'pqm' => 'malesit-passamakvodi',
        'prg' => 'pruss',
        'pro' => 'qədim provansal',
        'ps' => 'puştu',
        'pt' => 'portuqal',
        'qu' => 'keçua',
        'quc' => 'kiçe',
        'raj' => 'racastani',
        'rap' => 'rapanui',
        'rar' => 'rarotonqan',
        'rhg' => 'Rohinca',
        'rm' => 'romanş',
        'rn' => 'rundi',
        'ro' => 'rumın',
        'rof' => 'rombo',
        'rom' => 'roman',
        'ru' => 'rus',
        'rup' => 'aroman',
        'rw' => 'kinyarvanda',
        'rwk' => 'rua',
        'sa' => 'sanskrit',
        'sad' => 'sandave',
        'sah' => 'saxa',
        'sam' => 'samaritan',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santal',
        'sba' => 'nqambay',
        'sbp' => 'sanqu',
        'sc' => 'sardin',
        'scn' => 'siciliya',
        'sco' => 'skots',
        'sd' => 'sindhi',
        'sdh' => 'cənubi kürd',
        'se' => 'şimali sami',
        'seh' => 'sena',
        'sel' => 'selkup',
        'ses' => 'koyraboro senni',
        'sg' => 'sanqo',
        'sga' => 'qədim irland',
        'sh' => 'serb-xorvat',
        'shi' => 'taçelit',
        'shn' => 'şan',
        'si' => 'sinhala',
        'sid' => 'sidamo',
        'sk' => 'slovak',
        'sl' => 'sloven',
        'slh' => 'cənubi luşusid',
        'sm' => 'samoa',
        'sma' => 'cənubi sami',
        'smj' => 'lule sami',
        'smn' => 'inari sami',
        'sms' => 'skolt sami',
        'sn' => 'şona',
        'snk' => 'soninke',
        'so' => 'somali',
        'sog' => 'soqdiyen',
        'sq' => 'alban',
        'sr' => 'serb',
        'srn' => 'sranan tonqo',
        'srr' => 'serer',
        'ss' => 'svati',
        'ssy' => 'saho',
        'st' => 'sesoto',
        'str' => 'streyts saliş',
        'su' => 'sundan',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumeryan',
        'sv' => 'isveç',
        'sw' => 'suahili',
        'swb' => 'komor',
        'syr' => 'suriya',
        'ta' => 'tamil',
        'tce' => 'cənubi tuçon',
        'te' => 'teluqu',
        'tem' => 'timne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tacik',
        'tgx' => 'taq',
        'th' => 'tay',
        'tht' => 'taltan',
        'ti' => 'tiqrin',
        'tig' => 'tiqre',
        'tiv' => 'tiv',
        'tk' => 'türkmən',
        'tkl' => 'tokelay',
        'tl' => 'taqaloq',
        'tlh' => 'klinqon',
        'tli' => 'tlinqit',
        'tmh' => 'tamaşek',
        'tn' => 'svana',
        'to' => 'tonqa',
        'tog' => 'nyasa tonqa',
        'tok' => 'tokipona',
        'tpi' => 'tok pisin',
        'tr' => 'türk',
        'trv' => 'taroko',
        'ts' => 'sonqa',
        'tsi' => 'simşyan',
        'tt' => 'tatar',
        'ttm' => 'şimali tuçon',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'tvi',
        'twq' => 'tasavaq',
        'ty' => 'taxiti',
        'tyv' => 'tuvinyan',
        'tzm' => 'Mərkəzi Atlas tamazicəsi',
        'udm' => 'udmurt',
        'ug' => 'uyğur',
        'uga' => 'uqarit',
        'uk' => 'ukrayna',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'özbək',
        'vai' => 'vai',
        've' => 'venda',
        'vi' => 'vyetnam',
        'vo' => 'volapük',
        'vot' => 'votik',
        'vun' => 'vunyo',
        'wa' => 'valun',
        'wae' => 'valles',
        'wal' => 'valamo',
        'war' => 'varay',
        'was' => 'vaşo',
        'wbp' => 'valpiri',
        'wo' => 'volof',
        'wuu' => 'vu',
        'xal' => 'kalmık',
        'xh' => 'xosa',
        'xog' => 'soqa',
        'yao' => 'yao',
        'yap' => 'yapiz',
        'yav' => 'yanqben',
        'ybb' => 'yemba',
        'yi' => 'idiş',
        'yo' => 'yoruba',
        'yrl' => 'nyenqatu',
        'yue' => 'kanton',
        'za' => 'çjuan',
        'zap' => 'zapotek',
        'zbl' => 'blisimbols',
        'zen' => 'zenaqa',
        'zgh' => 'tamazi',
        'zh' => 'çin',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'müasir standart ərəb',
        'az_Arab' => 'cənubi azərbaycan',
        'de_AT' => 'Avstriya almancası',
        'de_CH' => 'İsveçrə yüksək almancası',
        'en_AU' => 'Avstraliya ingiliscəsi',
        'en_CA' => 'Kanada ingiliscəsi',
        'en_GB' => 'Britaniya ingiliscəsi',
        'en_US' => 'Amerika ingiliscəsi',
        'es_419' => 'Latın Amerikası ispancası',
        'es_ES' => 'Kastiliya ispancası',
        'es_MX' => 'Meksika ispancası',
        'fa_AF' => 'dari',
        'fr_CA' => 'Kanada fransızcası',
        'fr_CH' => 'İsveçrə fransızcası',
        'hi_Latn' => 'Hindi (latın)',
        'nds_NL' => 'aşağı sakson',
        'nl_BE' => 'flamand',
        'pt_BR' => 'Braziliya portuqalcası',
        'pt_PT' => 'Portuqaliya portuqalcası',
        'ro_MD' => 'moldav',
        'sw_CD' => 'Konqo suahilicəsi',
        'zh_Hans' => 'sadələşmiş çin',
        'zh_Hant' => 'ənənəvi çin',
    ],
];
