<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Etelä-Afrikka)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amhara',
        'am_ET' => 'amhara (Etiopia)',
        'ar' => 'arabia',
        'ar_001' => 'arabia (maailma)',
        'ar_AE' => 'arabia (Arabiemiirikunnat)',
        'ar_BH' => 'arabia (Bahrain)',
        'ar_DJ' => 'arabia (Djibouti)',
        'ar_DZ' => 'arabia (Algeria)',
        'ar_EG' => 'arabia (Egypti)',
        'ar_EH' => 'arabia (Länsi-Sahara)',
        'ar_ER' => 'arabia (Eritrea)',
        'ar_IL' => 'arabia (Israel)',
        'ar_IQ' => 'arabia (Irak)',
        'ar_JO' => 'arabia (Jordania)',
        'ar_KM' => 'arabia (Komorit)',
        'ar_KW' => 'arabia (Kuwait)',
        'ar_LB' => 'arabia (Libanon)',
        'ar_LY' => 'arabia (Libya)',
        'ar_MA' => 'arabia (Marokko)',
        'ar_MR' => 'arabia (Mauritania)',
        'ar_OM' => 'arabia (Oman)',
        'ar_PS' => 'arabia (Palestiinalaisalue)',
        'ar_QA' => 'arabia (Qatar)',
        'ar_SA' => 'arabia (Saudi-Arabia)',
        'ar_SD' => 'arabia (Sudan)',
        'ar_SO' => 'arabia (Somalia)',
        'ar_SS' => 'arabia (Etelä-Sudan)',
        'ar_SY' => 'arabia (Syyria)',
        'ar_TD' => 'arabia (Tšad)',
        'ar_TN' => 'arabia (Tunisia)',
        'ar_YE' => 'arabia (Jemen)',
        'as' => 'assami',
        'as_IN' => 'assami (Intia)',
        'az' => 'azeri',
        'az_AZ' => 'azeri (Azerbaidžan)',
        'az_Cyrl' => 'azeri (kyrillinen)',
        'az_Cyrl_AZ' => 'azeri (kyrillinen, Azerbaidžan)',
        'az_Latn' => 'azeri (latinalainen)',
        'az_Latn_AZ' => 'azeri (latinalainen, Azerbaidžan)',
        'be' => 'valkovenäjä',
        'be_BY' => 'valkovenäjä (Valko-Venäjä)',
        'bg' => 'bulgaria',
        'bg_BG' => 'bulgaria (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengali',
        'bn_BD' => 'bengali (Bangladesh)',
        'bn_IN' => 'bengali (Intia)',
        'bo' => 'tiibet',
        'bo_CN' => 'tiibet (Kiina)',
        'bo_IN' => 'tiibet (Intia)',
        'br' => 'bretoni',
        'br_FR' => 'bretoni (Ranska)',
        'bs' => 'bosnia',
        'bs_BA' => 'bosnia (Bosnia ja Hertsegovina)',
        'bs_Cyrl' => 'bosnia (kyrillinen)',
        'bs_Cyrl_BA' => 'bosnia (kyrillinen, Bosnia ja Hertsegovina)',
        'bs_Latn' => 'bosnia (latinalainen)',
        'bs_Latn_BA' => 'bosnia (latinalainen, Bosnia ja Hertsegovina)',
        'ca' => 'katalaani',
        'ca_AD' => 'katalaani (Andorra)',
        'ca_ES' => 'katalaani (Espanja)',
        'ca_FR' => 'katalaani (Ranska)',
        'ca_IT' => 'katalaani (Italia)',
        'ce' => 'tšetšeeni',
        'ce_RU' => 'tšetšeeni (Venäjä)',
        'cs' => 'tšekki',
        'cs_CZ' => 'tšekki (Tšekki)',
        'cv' => 'tšuvassi',
        'cv_RU' => 'tšuvassi (Venäjä)',
        'cy' => 'kymri',
        'cy_GB' => 'kymri (Iso-Britannia)',
        'da' => 'tanska',
        'da_DK' => 'tanska (Tanska)',
        'da_GL' => 'tanska (Grönlanti)',
        'de' => 'saksa',
        'de_AT' => 'saksa (Itävalta)',
        'de_BE' => 'saksa (Belgia)',
        'de_CH' => 'saksa (Sveitsi)',
        'de_DE' => 'saksa (Saksa)',
        'de_IT' => 'saksa (Italia)',
        'de_LI' => 'saksa (Liechtenstein)',
        'de_LU' => 'saksa (Luxemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'kreikka',
        'el_CY' => 'kreikka (Kypros)',
        'el_GR' => 'kreikka (Kreikka)',
        'en' => 'englanti',
        'en_001' => 'englanti (maailma)',
        'en_150' => 'englanti (Eurooppa)',
        'en_AE' => 'englanti (Arabiemiirikunnat)',
        'en_AG' => 'englanti (Antigua ja Barbuda)',
        'en_AI' => 'englanti (Anguilla)',
        'en_AS' => 'englanti (Amerikan Samoa)',
        'en_AT' => 'englanti (Itävalta)',
        'en_AU' => 'englanti (Australia)',
        'en_BB' => 'englanti (Barbados)',
        'en_BE' => 'englanti (Belgia)',
        'en_BI' => 'englanti (Burundi)',
        'en_BM' => 'englanti (Bermuda)',
        'en_BS' => 'englanti (Bahama)',
        'en_BW' => 'englanti (Botswana)',
        'en_BZ' => 'englanti (Belize)',
        'en_CA' => 'englanti (Kanada)',
        'en_CC' => 'englanti (Kookossaaret [Keelingsaaret])',
        'en_CH' => 'englanti (Sveitsi)',
        'en_CK' => 'englanti (Cookinsaaret)',
        'en_CM' => 'englanti (Kamerun)',
        'en_CX' => 'englanti (Joulusaari)',
        'en_CY' => 'englanti (Kypros)',
        'en_DE' => 'englanti (Saksa)',
        'en_DK' => 'englanti (Tanska)',
        'en_DM' => 'englanti (Dominica)',
        'en_ER' => 'englanti (Eritrea)',
        'en_FI' => 'englanti (Suomi)',
        'en_FJ' => 'englanti (Fidži)',
        'en_FK' => 'englanti (Falklandinsaaret)',
        'en_FM' => 'englanti (Mikronesia)',
        'en_GB' => 'englanti (Iso-Britannia)',
        'en_GD' => 'englanti (Grenada)',
        'en_GG' => 'englanti (Guernsey)',
        'en_GH' => 'englanti (Ghana)',
        'en_GI' => 'englanti (Gibraltar)',
        'en_GM' => 'englanti (Gambia)',
        'en_GU' => 'englanti (Guam)',
        'en_GY' => 'englanti (Guyana)',
        'en_HK' => 'englanti (Hongkong – Kiinan erityishallintoalue)',
        'en_IE' => 'englanti (Irlanti)',
        'en_IL' => 'englanti (Israel)',
        'en_IM' => 'englanti (Mansaari)',
        'en_IN' => 'englanti (Intia)',
        'en_IO' => 'englanti (Brittiläinen Intian valtameren alue)',
        'en_JE' => 'englanti (Jersey)',
        'en_JM' => 'englanti (Jamaika)',
        'en_KE' => 'englanti (Kenia)',
        'en_KI' => 'englanti (Kiribati)',
        'en_KN' => 'englanti (Saint Kitts ja Nevis)',
        'en_KY' => 'englanti (Caymansaaret)',
        'en_LC' => 'englanti (Saint Lucia)',
        'en_LR' => 'englanti (Liberia)',
        'en_LS' => 'englanti (Lesotho)',
        'en_MG' => 'englanti (Madagaskar)',
        'en_MH' => 'englanti (Marshallinsaaret)',
        'en_MO' => 'englanti (Macao – Kiinan erityishallintoalue)',
        'en_MP' => 'englanti (Pohjois-Mariaanit)',
        'en_MS' => 'englanti (Montserrat)',
        'en_MT' => 'englanti (Malta)',
        'en_MU' => 'englanti (Mauritius)',
        'en_MV' => 'englanti (Malediivit)',
        'en_MW' => 'englanti (Malawi)',
        'en_MY' => 'englanti (Malesia)',
        'en_NA' => 'englanti (Namibia)',
        'en_NF' => 'englanti (Norfolkinsaari)',
        'en_NG' => 'englanti (Nigeria)',
        'en_NL' => 'englanti (Alankomaat)',
        'en_NR' => 'englanti (Nauru)',
        'en_NU' => 'englanti (Niue)',
        'en_NZ' => 'englanti (Uusi-Seelanti)',
        'en_PG' => 'englanti (Papua-Uusi-Guinea)',
        'en_PH' => 'englanti (Filippiinit)',
        'en_PK' => 'englanti (Pakistan)',
        'en_PN' => 'englanti (Pitcairn)',
        'en_PR' => 'englanti (Puerto Rico)',
        'en_PW' => 'englanti (Palau)',
        'en_RW' => 'englanti (Ruanda)',
        'en_SB' => 'englanti (Salomonsaaret)',
        'en_SC' => 'englanti (Seychellit)',
        'en_SD' => 'englanti (Sudan)',
        'en_SE' => 'englanti (Ruotsi)',
        'en_SG' => 'englanti (Singapore)',
        'en_SH' => 'englanti (Saint Helena)',
        'en_SI' => 'englanti (Slovenia)',
        'en_SL' => 'englanti (Sierra Leone)',
        'en_SS' => 'englanti (Etelä-Sudan)',
        'en_SX' => 'englanti (Sint Maarten)',
        'en_SZ' => 'englanti (Eswatini)',
        'en_TC' => 'englanti (Turks- ja Caicossaaret)',
        'en_TK' => 'englanti (Tokelau)',
        'en_TO' => 'englanti (Tonga)',
        'en_TT' => 'englanti (Trinidad ja Tobago)',
        'en_TV' => 'englanti (Tuvalu)',
        'en_TZ' => 'englanti (Tansania)',
        'en_UG' => 'englanti (Uganda)',
        'en_UM' => 'englanti (Yhdysvaltain erillissaaret)',
        'en_US' => 'englanti (Yhdysvallat)',
        'en_VC' => 'englanti (Saint Vincent ja Grenadiinit)',
        'en_VG' => 'englanti (Brittiläiset Neitsytsaaret)',
        'en_VI' => 'englanti (Yhdysvaltain Neitsytsaaret)',
        'en_VU' => 'englanti (Vanuatu)',
        'en_WS' => 'englanti (Samoa)',
        'en_ZA' => 'englanti (Etelä-Afrikka)',
        'en_ZM' => 'englanti (Sambia)',
        'en_ZW' => 'englanti (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (maailma)',
        'es' => 'espanja',
        'es_419' => 'espanja (Latinalainen Amerikka)',
        'es_AR' => 'espanja (Argentiina)',
        'es_BO' => 'espanja (Bolivia)',
        'es_BR' => 'espanja (Brasilia)',
        'es_BZ' => 'espanja (Belize)',
        'es_CL' => 'espanja (Chile)',
        'es_CO' => 'espanja (Kolumbia)',
        'es_CR' => 'espanja (Costa Rica)',
        'es_CU' => 'espanja (Kuuba)',
        'es_DO' => 'espanja (Dominikaaninen tasavalta)',
        'es_EC' => 'espanja (Ecuador)',
        'es_ES' => 'espanja (Espanja)',
        'es_GQ' => 'espanja (Päiväntasaajan Guinea)',
        'es_GT' => 'espanja (Guatemala)',
        'es_HN' => 'espanja (Honduras)',
        'es_MX' => 'espanja (Meksiko)',
        'es_NI' => 'espanja (Nicaragua)',
        'es_PA' => 'espanja (Panama)',
        'es_PE' => 'espanja (Peru)',
        'es_PH' => 'espanja (Filippiinit)',
        'es_PR' => 'espanja (Puerto Rico)',
        'es_PY' => 'espanja (Paraguay)',
        'es_SV' => 'espanja (El Salvador)',
        'es_US' => 'espanja (Yhdysvallat)',
        'es_UY' => 'espanja (Uruguay)',
        'es_VE' => 'espanja (Venezuela)',
        'et' => 'viro',
        'et_EE' => 'viro (Viro)',
        'eu' => 'baski',
        'eu_ES' => 'baski (Espanja)',
        'fa' => 'persia',
        'fa_AF' => 'persia (Afganistan)',
        'fa_IR' => 'persia (Iran)',
        'ff' => 'fulani',
        'ff_Adlm' => 'fulani (fulanin adlam-aakkosto)',
        'ff_Adlm_BF' => 'fulani (fulanin adlam-aakkosto, Burkina Faso)',
        'ff_Adlm_CM' => 'fulani (fulanin adlam-aakkosto, Kamerun)',
        'ff_Adlm_GH' => 'fulani (fulanin adlam-aakkosto, Ghana)',
        'ff_Adlm_GM' => 'fulani (fulanin adlam-aakkosto, Gambia)',
        'ff_Adlm_GN' => 'fulani (fulanin adlam-aakkosto, Guinea)',
        'ff_Adlm_GW' => 'fulani (fulanin adlam-aakkosto, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulani (fulanin adlam-aakkosto, Liberia)',
        'ff_Adlm_MR' => 'fulani (fulanin adlam-aakkosto, Mauritania)',
        'ff_Adlm_NE' => 'fulani (fulanin adlam-aakkosto, Niger)',
        'ff_Adlm_NG' => 'fulani (fulanin adlam-aakkosto, Nigeria)',
        'ff_Adlm_SL' => 'fulani (fulanin adlam-aakkosto, Sierra Leone)',
        'ff_Adlm_SN' => 'fulani (fulanin adlam-aakkosto, Senegal)',
        'ff_CM' => 'fulani (Kamerun)',
        'ff_GN' => 'fulani (Guinea)',
        'ff_Latn' => 'fulani (latinalainen)',
        'ff_Latn_BF' => 'fulani (latinalainen, Burkina Faso)',
        'ff_Latn_CM' => 'fulani (latinalainen, Kamerun)',
        'ff_Latn_GH' => 'fulani (latinalainen, Ghana)',
        'ff_Latn_GM' => 'fulani (latinalainen, Gambia)',
        'ff_Latn_GN' => 'fulani (latinalainen, Guinea)',
        'ff_Latn_GW' => 'fulani (latinalainen, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulani (latinalainen, Liberia)',
        'ff_Latn_MR' => 'fulani (latinalainen, Mauritania)',
        'ff_Latn_NE' => 'fulani (latinalainen, Niger)',
        'ff_Latn_NG' => 'fulani (latinalainen, Nigeria)',
        'ff_Latn_SL' => 'fulani (latinalainen, Sierra Leone)',
        'ff_Latn_SN' => 'fulani (latinalainen, Senegal)',
        'ff_MR' => 'fulani (Mauritania)',
        'ff_SN' => 'fulani (Senegal)',
        'fi' => 'suomi',
        'fi_FI' => 'suomi (Suomi)',
        'fo' => 'fääri',
        'fo_DK' => 'fääri (Tanska)',
        'fo_FO' => 'fääri (Färsaaret)',
        'fr' => 'ranska',
        'fr_BE' => 'ranska (Belgia)',
        'fr_BF' => 'ranska (Burkina Faso)',
        'fr_BI' => 'ranska (Burundi)',
        'fr_BJ' => 'ranska (Benin)',
        'fr_BL' => 'ranska (Saint-Barthélemy)',
        'fr_CA' => 'ranska (Kanada)',
        'fr_CD' => 'ranska (Kongon demokraattinen tasavalta)',
        'fr_CF' => 'ranska (Keski-Afrikan tasavalta)',
        'fr_CG' => 'ranska (Kongon tasavalta)',
        'fr_CH' => 'ranska (Sveitsi)',
        'fr_CI' => 'ranska (Norsunluurannikko)',
        'fr_CM' => 'ranska (Kamerun)',
        'fr_DJ' => 'ranska (Djibouti)',
        'fr_DZ' => 'ranska (Algeria)',
        'fr_FR' => 'ranska (Ranska)',
        'fr_GA' => 'ranska (Gabon)',
        'fr_GF' => 'ranska (Ranskan Guayana)',
        'fr_GN' => 'ranska (Guinea)',
        'fr_GP' => 'ranska (Guadeloupe)',
        'fr_GQ' => 'ranska (Päiväntasaajan Guinea)',
        'fr_HT' => 'ranska (Haiti)',
        'fr_KM' => 'ranska (Komorit)',
        'fr_LU' => 'ranska (Luxemburg)',
        'fr_MA' => 'ranska (Marokko)',
        'fr_MC' => 'ranska (Monaco)',
        'fr_MF' => 'ranska (Saint-Martin)',
        'fr_MG' => 'ranska (Madagaskar)',
        'fr_ML' => 'ranska (Mali)',
        'fr_MQ' => 'ranska (Martinique)',
        'fr_MR' => 'ranska (Mauritania)',
        'fr_MU' => 'ranska (Mauritius)',
        'fr_NC' => 'ranska (Uusi-Kaledonia)',
        'fr_NE' => 'ranska (Niger)',
        'fr_PF' => 'ranska (Ranskan Polynesia)',
        'fr_PM' => 'ranska (Saint-Pierre ja Miquelon)',
        'fr_RE' => 'ranska (Réunion)',
        'fr_RW' => 'ranska (Ruanda)',
        'fr_SC' => 'ranska (Seychellit)',
        'fr_SN' => 'ranska (Senegal)',
        'fr_SY' => 'ranska (Syyria)',
        'fr_TD' => 'ranska (Tšad)',
        'fr_TG' => 'ranska (Togo)',
        'fr_TN' => 'ranska (Tunisia)',
        'fr_VU' => 'ranska (Vanuatu)',
        'fr_WF' => 'ranska (Wallis ja Futuna)',
        'fr_YT' => 'ranska (Mayotte)',
        'fy' => 'länsifriisi',
        'fy_NL' => 'länsifriisi (Alankomaat)',
        'ga' => 'iiri',
        'ga_GB' => 'iiri (Iso-Britannia)',
        'ga_IE' => 'iiri (Irlanti)',
        'gd' => 'gaeli',
        'gd_GB' => 'gaeli (Iso-Britannia)',
        'gl' => 'galicia',
        'gl_ES' => 'galicia (Espanja)',
        'gu' => 'gudžarati',
        'gu_IN' => 'gudžarati (Intia)',
        'gv' => 'manksi',
        'gv_IM' => 'manksi (Mansaari)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'heprea',
        'he_IL' => 'heprea (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Intia)',
        'hi_Latn' => 'hindi (latinalainen)',
        'hi_Latn_IN' => 'hindi (latinalainen, Intia)',
        'hr' => 'kroatia',
        'hr_BA' => 'kroatia (Bosnia ja Hertsegovina)',
        'hr_HR' => 'kroatia (Kroatia)',
        'hu' => 'unkari',
        'hu_HU' => 'unkari (Unkari)',
        'hy' => 'armenia',
        'hy_AM' => 'armenia (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (maailma)',
        'id' => 'indonesia',
        'id_ID' => 'indonesia (Indonesia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'sichuanin-yi',
        'ii_CN' => 'sichuanin-yi (Kiina)',
        'is' => 'islanti',
        'is_IS' => 'islanti (Islanti)',
        'it' => 'italia',
        'it_CH' => 'italia (Sveitsi)',
        'it_IT' => 'italia (Italia)',
        'it_SM' => 'italia (San Marino)',
        'it_VA' => 'italia (Vatikaani)',
        'ja' => 'japani',
        'ja_JP' => 'japani (Japani)',
        'jv' => 'jaava',
        'jv_ID' => 'jaava (Indonesia)',
        'ka' => 'georgia',
        'ka_GE' => 'georgia (Georgia)',
        'ki' => 'kikuju',
        'ki_KE' => 'kikuju (Kenia)',
        'kk' => 'kazakki',
        'kk_KZ' => 'kazakki (Kazakstan)',
        'kl' => 'kalaallisut',
        'kl_GL' => 'kalaallisut (Grönlanti)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Kambodža)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Intia)',
        'ko' => 'korea',
        'ko_KP' => 'korea (Pohjois-Korea)',
        'ko_KR' => 'korea (Etelä-Korea)',
        'ks' => 'kašmiri',
        'ks_Arab' => 'kašmiri (arabialainen)',
        'ks_Arab_IN' => 'kašmiri (arabialainen, Intia)',
        'ks_Deva' => 'kašmiri (devanagari)',
        'ks_Deva_IN' => 'kašmiri (devanagari, Intia)',
        'ks_IN' => 'kašmiri (Intia)',
        'ku' => 'kurdi',
        'ku_TR' => 'kurdi (Turkki)',
        'kw' => 'korni',
        'kw_GB' => 'korni (Iso-Britannia)',
        'ky' => 'kirgiisi',
        'ky_KG' => 'kirgiisi (Kirgisia)',
        'lb' => 'luxemburg',
        'lb_LU' => 'luxemburg (Luxemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongon demokraattinen tasavalta)',
        'ln_CF' => 'lingala (Keski-Afrikan tasavalta)',
        'ln_CG' => 'lingala (Kongon tasavalta)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laos)',
        'lt' => 'liettua',
        'lt_LT' => 'liettua (Liettua)',
        'lu' => 'katanganluba',
        'lu_CD' => 'katanganluba (Kongon demokraattinen tasavalta)',
        'lv' => 'latvia',
        'lv_LV' => 'latvia (Latvia)',
        'mg' => 'malagassi',
        'mg_MG' => 'malagassi (Madagaskar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Uusi-Seelanti)',
        'mk' => 'makedonia',
        'mk_MK' => 'makedonia (Pohjois-Makedonia)',
        'ml' => 'malajalam',
        'ml_IN' => 'malajalam (Intia)',
        'mn' => 'mongoli',
        'mn_MN' => 'mongoli (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (Intia)',
        'ms' => 'malaiji',
        'ms_BN' => 'malaiji (Brunei)',
        'ms_ID' => 'malaiji (Indonesia)',
        'ms_MY' => 'malaiji (Malesia)',
        'ms_SG' => 'malaiji (Singapore)',
        'mt' => 'malta',
        'mt_MT' => 'malta (Malta)',
        'my' => 'burma',
        'my_MM' => 'burma (Myanmar [Burma])',
        'nb' => 'norjan bokmål',
        'nb_NO' => 'norjan bokmål (Norja)',
        'nb_SJ' => 'norjan bokmål (Svalbard ja Jan Mayen)',
        'nd' => 'pohjois-ndebele',
        'nd_ZW' => 'pohjois-ndebele (Zimbabwe)',
        'ne' => 'nepali',
        'ne_IN' => 'nepali (Intia)',
        'ne_NP' => 'nepali (Nepal)',
        'nl' => 'hollanti',
        'nl_AW' => 'hollanti (Aruba)',
        'nl_BE' => 'hollanti (Belgia)',
        'nl_BQ' => 'hollanti (Karibian Alankomaat)',
        'nl_CW' => 'hollanti (Curaçao)',
        'nl_NL' => 'hollanti (Alankomaat)',
        'nl_SR' => 'hollanti (Suriname)',
        'nl_SX' => 'hollanti (Sint Maarten)',
        'nn' => 'norjan nynorsk',
        'nn_NO' => 'norjan nynorsk (Norja)',
        'no' => 'norja',
        'no_NO' => 'norja (Norja)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopia)',
        'om_KE' => 'oromo (Kenia)',
        'or' => 'orija',
        'or_IN' => 'orija (Intia)',
        'os' => 'osseetti',
        'os_GE' => 'osseetti (Georgia)',
        'os_RU' => 'osseetti (Venäjä)',
        'pa' => 'pandžabi',
        'pa_Arab' => 'pandžabi (arabialainen)',
        'pa_Arab_PK' => 'pandžabi (arabialainen, Pakistan)',
        'pa_Guru' => 'pandžabi (gurmukhi)',
        'pa_Guru_IN' => 'pandžabi (gurmukhi, Intia)',
        'pa_IN' => 'pandžabi (Intia)',
        'pa_PK' => 'pandžabi (Pakistan)',
        'pl' => 'puola',
        'pl_PL' => 'puola (Puola)',
        'ps' => 'paštu',
        'ps_AF' => 'paštu (Afganistan)',
        'ps_PK' => 'paštu (Pakistan)',
        'pt' => 'portugali',
        'pt_AO' => 'portugali (Angola)',
        'pt_BR' => 'portugali (Brasilia)',
        'pt_CH' => 'portugali (Sveitsi)',
        'pt_CV' => 'portugali (Kap Verde)',
        'pt_GQ' => 'portugali (Päiväntasaajan Guinea)',
        'pt_GW' => 'portugali (Guinea-Bissau)',
        'pt_LU' => 'portugali (Luxemburg)',
        'pt_MO' => 'portugali (Macao – Kiinan erityishallintoalue)',
        'pt_MZ' => 'portugali (Mosambik)',
        'pt_PT' => 'portugali (Portugali)',
        'pt_ST' => 'portugali (São Tomé ja Príncipe)',
        'pt_TL' => 'portugali (Itä-Timor)',
        'qu' => 'ketšua',
        'qu_BO' => 'ketšua (Bolivia)',
        'qu_EC' => 'ketšua (Ecuador)',
        'qu_PE' => 'ketšua (Peru)',
        'rm' => 'retoromaani',
        'rm_CH' => 'retoromaani (Sveitsi)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'romania',
        'ro_MD' => 'romania (Moldova)',
        'ro_RO' => 'romania (Romania)',
        'ru' => 'venäjä',
        'ru_BY' => 'venäjä (Valko-Venäjä)',
        'ru_KG' => 'venäjä (Kirgisia)',
        'ru_KZ' => 'venäjä (Kazakstan)',
        'ru_MD' => 'venäjä (Moldova)',
        'ru_RU' => 'venäjä (Venäjä)',
        'ru_UA' => 'venäjä (Ukraina)',
        'rw' => 'ruanda',
        'rw_RW' => 'ruanda (Ruanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (Intia)',
        'sc' => 'sardi',
        'sc_IT' => 'sardi (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabialainen)',
        'sd_Arab_PK' => 'sindhi (arabialainen, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, Intia)',
        'sd_IN' => 'sindhi (Intia)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'pohjoissaame',
        'se_FI' => 'pohjoissaame (Suomi)',
        'se_NO' => 'pohjoissaame (Norja)',
        'se_SE' => 'pohjoissaame (Ruotsi)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Keski-Afrikan tasavalta)',
        'sh' => 'serbokroaatti',
        'sh_BA' => 'serbokroaatti (Bosnia ja Hertsegovina)',
        'si' => 'sinhala',
        'si_LK' => 'sinhala (Sri Lanka)',
        'sk' => 'slovakki',
        'sk_SK' => 'slovakki (Slovakia)',
        'sl' => 'sloveeni',
        'sl_SI' => 'sloveeni (Slovenia)',
        'sn' => 'šona',
        'sn_ZW' => 'šona (Zimbabwe)',
        'so' => 'somali',
        'so_DJ' => 'somali (Djibouti)',
        'so_ET' => 'somali (Etiopia)',
        'so_KE' => 'somali (Kenia)',
        'so_SO' => 'somali (Somalia)',
        'sq' => 'albania',
        'sq_AL' => 'albania (Albania)',
        'sq_MK' => 'albania (Pohjois-Makedonia)',
        'sr' => 'serbia',
        'sr_BA' => 'serbia (Bosnia ja Hertsegovina)',
        'sr_Cyrl' => 'serbia (kyrillinen)',
        'sr_Cyrl_BA' => 'serbia (kyrillinen, Bosnia ja Hertsegovina)',
        'sr_Cyrl_ME' => 'serbia (kyrillinen, Montenegro)',
        'sr_Cyrl_RS' => 'serbia (kyrillinen, Serbia)',
        'sr_Latn' => 'serbia (latinalainen)',
        'sr_Latn_BA' => 'serbia (latinalainen, Bosnia ja Hertsegovina)',
        'sr_Latn_ME' => 'serbia (latinalainen, Montenegro)',
        'sr_Latn_RS' => 'serbia (latinalainen, Serbia)',
        'sr_ME' => 'serbia (Montenegro)',
        'sr_RS' => 'serbia (Serbia)',
        'su' => 'sunda',
        'su_ID' => 'sunda (Indonesia)',
        'su_Latn' => 'sunda (latinalainen)',
        'su_Latn_ID' => 'sunda (latinalainen, Indonesia)',
        'sv' => 'ruotsi',
        'sv_AX' => 'ruotsi (Ahvenanmaa)',
        'sv_FI' => 'ruotsi (Suomi)',
        'sv_SE' => 'ruotsi (Ruotsi)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Kongon demokraattinen tasavalta)',
        'sw_KE' => 'swahili (Kenia)',
        'sw_TZ' => 'swahili (Tansania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamili',
        'ta_IN' => 'tamili (Intia)',
        'ta_LK' => 'tamili (Sri Lanka)',
        'ta_MY' => 'tamili (Malesia)',
        'ta_SG' => 'tamili (Singapore)',
        'te' => 'telugu',
        'te_IN' => 'telugu (Intia)',
        'tg' => 'tadžikki',
        'tg_TJ' => 'tadžikki (Tadžikistan)',
        'th' => 'thai',
        'th_TH' => 'thai (Thaimaa)',
        'ti' => 'tigrinja',
        'ti_ER' => 'tigrinja (Eritrea)',
        'ti_ET' => 'tigrinja (Etiopia)',
        'tk' => 'turkmeeni',
        'tk_TM' => 'turkmeeni (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filippiinit)',
        'to' => 'tonga',
        'to_TO' => 'tonga (Tonga)',
        'tr' => 'turkki',
        'tr_CY' => 'turkki (Kypros)',
        'tr_TR' => 'turkki (Turkki)',
        'tt' => 'tataari',
        'tt_RU' => 'tataari (Venäjä)',
        'ug' => 'uiguuri',
        'ug_CN' => 'uiguuri (Kiina)',
        'uk' => 'ukraina',
        'uk_UA' => 'ukraina (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Intia)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'uzbekki',
        'uz_AF' => 'uzbekki (Afganistan)',
        'uz_Arab' => 'uzbekki (arabialainen)',
        'uz_Arab_AF' => 'uzbekki (arabialainen, Afganistan)',
        'uz_Cyrl' => 'uzbekki (kyrillinen)',
        'uz_Cyrl_UZ' => 'uzbekki (kyrillinen, Uzbekistan)',
        'uz_Latn' => 'uzbekki (latinalainen)',
        'uz_Latn_UZ' => 'uzbekki (latinalainen, Uzbekistan)',
        'uz_UZ' => 'uzbekki (Uzbekistan)',
        'vi' => 'vietnam',
        'vi_VN' => 'vietnam (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Etelä-Afrikka)',
        'yi' => 'jiddiš',
        'yi_001' => 'jiddiš (maailma)',
        'yo' => 'joruba',
        'yo_BJ' => 'joruba (Benin)',
        'yo_NG' => 'joruba (Nigeria)',
        'zh' => 'kiina',
        'zh_CN' => 'kiina (Kiina)',
        'zh_HK' => 'kiina (Hongkong – Kiinan erityishallintoalue)',
        'zh_Hans' => 'kiina (yksinkertaistettu)',
        'zh_Hans_CN' => 'kiina (yksinkertaistettu, Kiina)',
        'zh_Hans_HK' => 'kiina (yksinkertaistettu, Hongkong – Kiinan erityishallintoalue)',
        'zh_Hans_MO' => 'kiina (yksinkertaistettu, Macao – Kiinan erityishallintoalue)',
        'zh_Hans_SG' => 'kiina (yksinkertaistettu, Singapore)',
        'zh_Hant' => 'kiina (perinteinen)',
        'zh_Hant_HK' => 'kiina (perinteinen, Hongkong – Kiinan erityishallintoalue)',
        'zh_Hant_MO' => 'kiina (perinteinen, Macao – Kiinan erityishallintoalue)',
        'zh_Hant_TW' => 'kiina (perinteinen, Taiwan)',
        'zh_MO' => 'kiina (Macao – Kiinan erityishallintoalue)',
        'zh_SG' => 'kiina (Singapore)',
        'zh_TW' => 'kiina (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Etelä-Afrikka)',
    ],
];
