<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich-staðaltími (Abidjan)',
        'Africa/Accra' => 'Greenwich-staðaltími (Accra)',
        'Africa/Addis_Ababa' => 'Austur-Afríkutími (Addis Ababa)',
        'Africa/Algiers' => 'Mið-Evróputími (Algeirsborg)',
        'Africa/Asmera' => 'Austur-Afríkutími (Asmara)',
        'Africa/Bamako' => 'Greenwich-staðaltími (Bamako)',
        'Africa/Bangui' => 'Vestur-Afríkutími (Bangui)',
        'Africa/Banjul' => 'Greenwich-staðaltími (Banjul)',
        'Africa/Bissau' => 'Greenwich-staðaltími (Bissá)',
        'Africa/Blantyre' => 'Mið-Afríkutími (Blantyre)',
        'Africa/Brazzaville' => 'Vestur-Afríkutími (Brazzaville)',
        'Africa/Bujumbura' => 'Mið-Afríkutími (Bujumbura)',
        'Africa/Cairo' => 'Austur-Evróputími (Kaíró)',
        'Africa/Casablanca' => 'Vestur-Evróputími (Casablanca)',
        'Africa/Ceuta' => 'Mið-Evróputími (Ceuta)',
        'Africa/Conakry' => 'Greenwich-staðaltími (Conakry)',
        'Africa/Dakar' => 'Greenwich-staðaltími (Dakar)',
        'Africa/Dar_es_Salaam' => 'Austur-Afríkutími (Dar es Salaam)',
        'Africa/Djibouti' => 'Austur-Afríkutími (Djibútí)',
        'Africa/Douala' => 'Vestur-Afríkutími (Douala)',
        'Africa/El_Aaiun' => 'Vestur-Evróputími (El Aaiun)',
        'Africa/Freetown' => 'Greenwich-staðaltími (Freetown)',
        'Africa/Gaborone' => 'Mið-Afríkutími (Gaborone)',
        'Africa/Harare' => 'Mið-Afríkutími (Harare)',
        'Africa/Johannesburg' => 'Suður-Afríkutími (Jóhannesarborg)',
        'Africa/Juba' => 'Mið-Afríkutími (Juba)',
        'Africa/Kampala' => 'Austur-Afríkutími (Kampala)',
        'Africa/Khartoum' => 'Mið-Afríkutími (Khartoum)',
        'Africa/Kigali' => 'Mið-Afríkutími (Kigali)',
        'Africa/Kinshasa' => 'Vestur-Afríkutími (Kinshasa)',
        'Africa/Lagos' => 'Vestur-Afríkutími (Lagos)',
        'Africa/Libreville' => 'Vestur-Afríkutími (Libreville)',
        'Africa/Lome' => 'Greenwich-staðaltími (Lome)',
        'Africa/Luanda' => 'Vestur-Afríkutími (Luanda)',
        'Africa/Lubumbashi' => 'Mið-Afríkutími (Lubumbashi)',
        'Africa/Lusaka' => 'Mið-Afríkutími (Lusaka)',
        'Africa/Malabo' => 'Vestur-Afríkutími (Malabo)',
        'Africa/Maputo' => 'Mið-Afríkutími (Maputo)',
        'Africa/Maseru' => 'Suður-Afríkutími (Maseru)',
        'Africa/Mbabane' => 'Suður-Afríkutími (Mbabane)',
        'Africa/Mogadishu' => 'Austur-Afríkutími (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich-staðaltími (Monrovia)',
        'Africa/Nairobi' => 'Austur-Afríkutími (Nairobi)',
        'Africa/Ndjamena' => 'Vestur-Afríkutími (Ndjamena)',
        'Africa/Niamey' => 'Vestur-Afríkutími (Niamey)',
        'Africa/Nouakchott' => 'Greenwich-staðaltími (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich-staðaltími (Ouagadougou)',
        'Africa/Porto-Novo' => 'Vestur-Afríkutími (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich-staðaltími (Saó Tóme)',
        'Africa/Tripoli' => 'Austur-Evróputími (Trípólí)',
        'Africa/Tunis' => 'Mið-Evróputími (Túnisborg)',
        'Africa/Windhoek' => 'Mið-Afríkutími (Windhoek)',
        'America/Adak' => 'Tími á Havaí og Aleúta (Adak)',
        'America/Anchorage' => 'Tími í Alaska (Anchorage)',
        'America/Anguilla' => 'Tími á Atlantshafssvæðinu (Angvilla)',
        'America/Antigua' => 'Tími á Atlantshafssvæðinu (Antígva)',
        'America/Araguaina' => 'Brasilíutími (Araguaina)',
        'America/Argentina/La_Rioja' => 'Argentínutími (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentínutími (Rio Gallegos)',
        'America/Argentina/Salta' => 'Argentínutími (Salta)',
        'America/Argentina/San_Juan' => 'Argentínutími (San Juan)',
        'America/Argentina/San_Luis' => 'Argentínutími (San Luis)',
        'America/Argentina/Tucuman' => 'Argentínutími (Tucuman)',
        'America/Argentina/Ushuaia' => 'Argentínutími (Ushuaia)',
        'America/Aruba' => 'Tími á Atlantshafssvæðinu (Arúba)',
        'America/Asuncion' => 'Paragvætími (Asunción)',
        'America/Bahia' => 'Brasilíutími (Bahia)',
        'America/Bahia_Banderas' => 'Tími í miðhluta Bandaríkjanna og Kanada (Bahia Banderas)',
        'America/Barbados' => 'Tími á Atlantshafssvæðinu (Barbados)',
        'America/Belem' => 'Brasilíutími (Belem)',
        'America/Belize' => 'Tími í miðhluta Bandaríkjanna og Kanada (Belís)',
        'America/Blanc-Sablon' => 'Tími á Atlantshafssvæðinu (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amasóntími (Boa Vista)',
        'America/Bogota' => 'Kólumbíutími (Bogota)',
        'America/Boise' => 'Tími í Klettafjöllum (Boise)',
        'America/Buenos_Aires' => 'Argentínutími (Buenos Aires)',
        'America/Cambridge_Bay' => 'Tími í Klettafjöllum (Cambridge Bay)',
        'America/Campo_Grande' => 'Amasóntími (Campo Grande)',
        'America/Cancun' => 'Tími í austurhluta Bandaríkjanna og Kanada (Kankún)',
        'America/Caracas' => 'Venesúelatími (Caracas)',
        'America/Catamarca' => 'Argentínutími (Catamarca)',
        'America/Cayenne' => 'Tími í Frönsku Gvæjana (Cayenne)',
        'America/Cayman' => 'Tími í austurhluta Bandaríkjanna og Kanada (Cayman-eyjar)',
        'America/Chicago' => 'Tími í miðhluta Bandaríkjanna og Kanada (Chicago)',
        'America/Chihuahua' => 'Kyrrahafstími í Mexíkó (Chihuahua)',
        'America/Coral_Harbour' => 'Tími í austurhluta Bandaríkjanna og Kanada (Atikokan)',
        'America/Cordoba' => 'Argentínutími (Cordoba)',
        'America/Costa_Rica' => 'Tími í miðhluta Bandaríkjanna og Kanada (Kostaríka)',
        'America/Creston' => 'Tími í Klettafjöllum (Creston)',
        'America/Cuiaba' => 'Amasóntími (Cuiaba)',
        'America/Curacao' => 'Tími á Atlantshafssvæðinu (Curacao)',
        'America/Danmarkshavn' => 'Greenwich-staðaltími (Danmarkshavn)',
        'America/Dawson' => 'Tími í Júkon (Dawson)',
        'America/Dawson_Creek' => 'Tími í Klettafjöllum (Dawson Creek)',
        'America/Denver' => 'Tími í Klettafjöllum (Denver)',
        'America/Detroit' => 'Tími í austurhluta Bandaríkjanna og Kanada (Detroit)',
        'America/Dominica' => 'Tími á Atlantshafssvæðinu (Dóminíka)',
        'America/Edmonton' => 'Tími í Klettafjöllum (Edmonton)',
        'America/Eirunepe' => 'Brasilía (Eirunepe)',
        'America/El_Salvador' => 'Tími í miðhluta Bandaríkjanna og Kanada (El Salvador)',
        'America/Fort_Nelson' => 'Tími í Klettafjöllum (Fort Nelson)',
        'America/Fortaleza' => 'Brasilíutími (Fortaleza)',
        'America/Glace_Bay' => 'Tími á Atlantshafssvæðinu (Glace Bay)',
        'America/Godthab' => 'Vestur-Grænlandstími (Nuuk)',
        'America/Goose_Bay' => 'Tími á Atlantshafssvæðinu (Goose Bay)',
        'America/Grand_Turk' => 'Tími í austurhluta Bandaríkjanna og Kanada (Grand Turk)',
        'America/Grenada' => 'Tími á Atlantshafssvæðinu (Grenada)',
        'America/Guadeloupe' => 'Tími á Atlantshafssvæðinu (Gvadelúp)',
        'America/Guatemala' => 'Tími í miðhluta Bandaríkjanna og Kanada (Gvatemala)',
        'America/Guayaquil' => 'Ekvadortími (Guayaquil)',
        'America/Guyana' => 'Gvæjanatími',
        'America/Halifax' => 'Tími á Atlantshafssvæðinu (Halifax)',
        'America/Havana' => 'Kúbutími (Havana)',
        'America/Hermosillo' => 'Kyrrahafstími í Mexíkó (Hermosillo)',
        'America/Indiana/Knox' => 'Tími í miðhluta Bandaríkjanna og Kanada (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Tími í austurhluta Bandaríkjanna og Kanada (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Tími í austurhluta Bandaríkjanna og Kanada (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Tími í miðhluta Bandaríkjanna og Kanada (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Tími í austurhluta Bandaríkjanna og Kanada (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Tími í austurhluta Bandaríkjanna og Kanada (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Tími í austurhluta Bandaríkjanna og Kanada (Winamac, Indiana)',
        'America/Indianapolis' => 'Tími í austurhluta Bandaríkjanna og Kanada (Indianapolis)',
        'America/Inuvik' => 'Tími í Klettafjöllum (Inuvik)',
        'America/Iqaluit' => 'Tími í austurhluta Bandaríkjanna og Kanada (Iqaluit)',
        'America/Jamaica' => 'Tími í austurhluta Bandaríkjanna og Kanada (Jamaíka)',
        'America/Jujuy' => 'Argentínutími (Jujuy)',
        'America/Juneau' => 'Tími í Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Tími í austurhluta Bandaríkjanna og Kanada (Monticello, Kentucky)',
        'America/Kralendijk' => 'Tími á Atlantshafssvæðinu (Kralendijk)',
        'America/La_Paz' => 'Bólivíutími (La Paz)',
        'America/Lima' => 'Perútími (Lima)',
        'America/Los_Angeles' => 'Tími á Kyrrahafssvæðinu (Los Angeles)',
        'America/Louisville' => 'Tími í austurhluta Bandaríkjanna og Kanada (Louisville)',
        'America/Lower_Princes' => 'Tími á Atlantshafssvæðinu (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasilíutími (Maceio)',
        'America/Managua' => 'Tími í miðhluta Bandaríkjanna og Kanada (Managua)',
        'America/Manaus' => 'Amasóntími (Manaus)',
        'America/Marigot' => 'Tími á Atlantshafssvæðinu (Marigot)',
        'America/Martinique' => 'Tími á Atlantshafssvæðinu (Martiník)',
        'America/Matamoros' => 'Tími í miðhluta Bandaríkjanna og Kanada (Matamoros)',
        'America/Mazatlan' => 'Kyrrahafstími í Mexíkó (Mazatlan)',
        'America/Mendoza' => 'Argentínutími (Mendoza)',
        'America/Menominee' => 'Tími í miðhluta Bandaríkjanna og Kanada (Menominee)',
        'America/Merida' => 'Tími í miðhluta Bandaríkjanna og Kanada (Merida)',
        'America/Metlakatla' => 'Tími í Alaska (Metlakatla)',
        'America/Mexico_City' => 'Tími í miðhluta Bandaríkjanna og Kanada (Mexíkóborg)',
        'America/Miquelon' => 'Tími á Sankti Pierre og Miquelon',
        'America/Moncton' => 'Tími á Atlantshafssvæðinu (Moncton)',
        'America/Monterrey' => 'Tími í miðhluta Bandaríkjanna og Kanada (Monterrey)',
        'America/Montevideo' => 'Úrúgvætími (Montevideo)',
        'America/Montreal' => 'Kanada (Montreal)',
        'America/Montserrat' => 'Tími á Atlantshafssvæðinu (Montserrat)',
        'America/Nassau' => 'Tími í austurhluta Bandaríkjanna og Kanada (Nassau)',
        'America/New_York' => 'Tími í austurhluta Bandaríkjanna og Kanada (New York)',
        'America/Nipigon' => 'Tími í austurhluta Bandaríkjanna og Kanada (Nipigon)',
        'America/Nome' => 'Tími í Alaska (Nome)',
        'America/Noronha' => 'Tími í Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Tími í miðhluta Bandaríkjanna og Kanada (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Tími í miðhluta Bandaríkjanna og Kanada (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Tími í miðhluta Bandaríkjanna og Kanada (New Salem, North Dakota)',
        'America/Ojinaga' => 'Tími í Klettafjöllum (Ojinaga)',
        'America/Panama' => 'Tími í austurhluta Bandaríkjanna og Kanada (Panama)',
        'America/Pangnirtung' => 'Tími í austurhluta Bandaríkjanna og Kanada (Pangnirtung)',
        'America/Paramaribo' => 'Súrinamtími (Paramaribo)',
        'America/Phoenix' => 'Tími í Klettafjöllum (Phoenix)',
        'America/Port-au-Prince' => 'Tími í austurhluta Bandaríkjanna og Kanada (Port-au-Prince)',
        'America/Port_of_Spain' => 'Tími á Atlantshafssvæðinu (Port of Spain)',
        'America/Porto_Velho' => 'Amasóntími (Porto Velho)',
        'America/Puerto_Rico' => 'Tími á Atlantshafssvæðinu (Púertó Ríkó)',
        'America/Punta_Arenas' => 'Síletími (Punta Arenas)',
        'America/Rainy_River' => 'Tími í miðhluta Bandaríkjanna og Kanada (Rainy River)',
        'America/Rankin_Inlet' => 'Tími í miðhluta Bandaríkjanna og Kanada (Rankin Inlet)',
        'America/Recife' => 'Brasilíutími (Recife)',
        'America/Regina' => 'Tími í miðhluta Bandaríkjanna og Kanada (Regina)',
        'America/Resolute' => 'Tími í miðhluta Bandaríkjanna og Kanada (Resolute)',
        'America/Rio_Branco' => 'Brasilía (Rio Branco)',
        'America/Santa_Isabel' => 'Tími í Norðvestur-Mexíkó (Santa Isabel)',
        'America/Santarem' => 'Brasilíutími (Santarem)',
        'America/Santiago' => 'Síletími (Santiago)',
        'America/Santo_Domingo' => 'Tími á Atlantshafssvæðinu (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasilíutími (Sao Paulo)',
        'America/Scoresbysund' => 'Austur-Grænlandstími (Ittoqqortoormiit)',
        'America/Sitka' => 'Tími í Alaska (Sitka)',
        'America/St_Barthelemy' => 'Tími á Atlantshafssvæðinu (Sankti Bartólómeusareyjar)',
        'America/St_Johns' => 'Tími á Nýfundnalandi (St. John’s)',
        'America/St_Kitts' => 'Tími á Atlantshafssvæðinu (Sankti Kitts)',
        'America/St_Lucia' => 'Tími á Atlantshafssvæðinu (Sankti Lúsía)',
        'America/St_Thomas' => 'Tími á Atlantshafssvæðinu (Sankti Thomas)',
        'America/St_Vincent' => 'Tími á Atlantshafssvæðinu (Sankti Vinsent)',
        'America/Swift_Current' => 'Tími í miðhluta Bandaríkjanna og Kanada (Swift Current)',
        'America/Tegucigalpa' => 'Tími í miðhluta Bandaríkjanna og Kanada (Tegucigalpa)',
        'America/Thule' => 'Tími á Atlantshafssvæðinu (Thule)',
        'America/Thunder_Bay' => 'Tími í austurhluta Bandaríkjanna og Kanada (Thunder Bay)',
        'America/Tijuana' => 'Tími á Kyrrahafssvæðinu (Tijuana)',
        'America/Toronto' => 'Tími í austurhluta Bandaríkjanna og Kanada (Toronto)',
        'America/Tortola' => 'Tími á Atlantshafssvæðinu (Tortóla)',
        'America/Vancouver' => 'Tími á Kyrrahafssvæðinu (Vancouver)',
        'America/Whitehorse' => 'Tími í Júkon (Whitehorse)',
        'America/Winnipeg' => 'Tími í miðhluta Bandaríkjanna og Kanada (Winnipeg)',
        'America/Yakutat' => 'Tími í Alaska (Yakutat)',
        'America/Yellowknife' => 'Tími í Klettafjöllum (Yellowknife)',
        'Antarctica/Casey' => 'Suðurskautslandið (Casey)',
        'Antarctica/Davis' => 'Davis-tími',
        'Antarctica/DumontDUrville' => 'Tími á Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Tími í Austur-Ástralíu (Macquarie)',
        'Antarctica/Mawson' => 'Mawson-tími',
        'Antarctica/McMurdo' => 'Tími á Nýja-Sjálandi (McMurdo)',
        'Antarctica/Palmer' => 'Síletími (Palmer)',
        'Antarctica/Rothera' => 'Rothera-tími',
        'Antarctica/Syowa' => 'Syowa-tími',
        'Antarctica/Troll' => 'Greenwich-staðaltími (Troll)',
        'Antarctica/Vostok' => 'Vostok-tími',
        'Arctic/Longyearbyen' => 'Mið-Evróputími (Longyearbyen)',
        'Asia/Aden' => 'Arabíutími (Aden)',
        'Asia/Almaty' => 'Tími í Austur-Kasakstan (Almaty)',
        'Asia/Amman' => 'Austur-Evróputími (Amman)',
        'Asia/Anadyr' => 'Tími í Anadyr',
        'Asia/Aqtau' => 'Tími í Vestur-Kasakstan (Aqtau)',
        'Asia/Aqtobe' => 'Tími í Vestur-Kasakstan (Aqtobe)',
        'Asia/Ashgabat' => 'Túrkmenistan-tími (Ashgabat)',
        'Asia/Atyrau' => 'Tími í Vestur-Kasakstan (Atyrau)',
        'Asia/Baghdad' => 'Arabíutími (Bagdad)',
        'Asia/Bahrain' => 'Arabíutími (Barein)',
        'Asia/Baku' => 'Aserbaídsjantími (Bakú)',
        'Asia/Bangkok' => 'Indókínatími (Bangkok)',
        'Asia/Barnaul' => 'Rússland (Barnaul)',
        'Asia/Beirut' => 'Austur-Evróputími (Beirút)',
        'Asia/Bishkek' => 'Kirgistan-tími (Bishkek)',
        'Asia/Brunei' => 'Brúneitími',
        'Asia/Calcutta' => 'Indlandstími (Kalkútta)',
        'Asia/Chita' => 'Tími í Yakutsk (Chita)',
        'Asia/Choibalsan' => 'Tími í Úlan Bator (Choibalsan)',
        'Asia/Colombo' => 'Indlandstími (Kólombó)',
        'Asia/Damascus' => 'Austur-Evróputími (Damaskus)',
        'Asia/Dhaka' => 'Bangladess-tími (Dakka)',
        'Asia/Dili' => 'Tími á Tímor-Leste (Dili)',
        'Asia/Dubai' => 'Staðaltími við Persaflóa (Dubai)',
        'Asia/Dushanbe' => 'Tadsjíkistan-tími (Dushanbe)',
        'Asia/Famagusta' => 'Austur-Evróputími (Famagusta)',
        'Asia/Gaza' => 'Austur-Evróputími (Gaza)',
        'Asia/Hebron' => 'Austur-Evróputími (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kong-tími',
        'Asia/Hovd' => 'Hovd-tími',
        'Asia/Irkutsk' => 'Tími í Irkutsk',
        'Asia/Jakarta' => 'Vestur-Indónesíutími (Djakarta)',
        'Asia/Jayapura' => 'Austur-Indónesíutími (Jayapura)',
        'Asia/Jerusalem' => 'Ísraelstími (Jerúsalem)',
        'Asia/Kabul' => 'Afganistantími (Kabúl)',
        'Asia/Kamchatka' => 'Tími í Petropavlovsk-Kamchatski (Kamtsjatka)',
        'Asia/Karachi' => 'Pakistantími (Karachi)',
        'Asia/Katmandu' => 'Nepaltími (Katmandú)',
        'Asia/Khandyga' => 'Tími í Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Tími í Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Malasíutími (Kúala Lúmpúr)',
        'Asia/Kuching' => 'Malasíutími (Kuching)',
        'Asia/Kuwait' => 'Arabíutími (Kúveit)',
        'Asia/Macau' => 'Kínatími (Makaó)',
        'Asia/Magadan' => 'Tími í Magadan',
        'Asia/Makassar' => 'Mið-Indónesíutími (Makassar)',
        'Asia/Manila' => 'Filippseyjatími (Manila)',
        'Asia/Muscat' => 'Staðaltími við Persaflóa (Muscat)',
        'Asia/Nicosia' => 'Austur-Evróputími (Níkósía)',
        'Asia/Novokuznetsk' => 'Tími í Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Tími í Novosibirsk',
        'Asia/Omsk' => 'Tími í Omsk',
        'Asia/Oral' => 'Tími í Vestur-Kasakstan (Oral)',
        'Asia/Phnom_Penh' => 'Indókínatími (Phnom Penh)',
        'Asia/Pontianak' => 'Vestur-Indónesíutími (Pontianak)',
        'Asia/Pyongyang' => 'Kóreutími (Pjongjang)',
        'Asia/Qatar' => 'Arabíutími (Katar)',
        'Asia/Qostanay' => 'Tími í Austur-Kasakstan (Kostanay)',
        'Asia/Qyzylorda' => 'Tími í Vestur-Kasakstan (Qyzylorda)',
        'Asia/Rangoon' => 'Mjanmar-tími (Rangún)',
        'Asia/Riyadh' => 'Arabíutími (Ríjad)',
        'Asia/Saigon' => 'Indókínatími (Ho Chi Minh-borg)',
        'Asia/Sakhalin' => 'Tími í Sakhalin',
        'Asia/Samarkand' => 'Úsbekistan-tími (Samarkand)',
        'Asia/Seoul' => 'Kóreutími (Seúl)',
        'Asia/Shanghai' => 'Kínatími (Sjanghæ)',
        'Asia/Singapore' => 'Singapúrtími',
        'Asia/Srednekolymsk' => 'Tími í Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei-tími',
        'Asia/Tashkent' => 'Úsbekistan-tími (Tashkent)',
        'Asia/Tbilisi' => 'Georgíutími (Tbilisi)',
        'Asia/Tehran' => 'Íranstími (Teheran)',
        'Asia/Thimphu' => 'Bútantími (Thimphu)',
        'Asia/Tokyo' => 'Japanstími (Tókýó)',
        'Asia/Tomsk' => 'Rússland (Tomsk)',
        'Asia/Ulaanbaatar' => 'Tími í Úlan Bator',
        'Asia/Urumqi' => 'Kína (Urumqi)',
        'Asia/Ust-Nera' => 'Tími í Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Indókínatími (Vientiane)',
        'Asia/Vladivostok' => 'Tími í Vladivostok',
        'Asia/Yakutsk' => 'Tími í Yakutsk',
        'Asia/Yekaterinburg' => 'Tími í Yekaterinburg',
        'Asia/Yerevan' => 'Armeníutími (Yerevan)',
        'Atlantic/Azores' => 'Asóreyjatími (Azoreyjar)',
        'Atlantic/Bermuda' => 'Tími á Atlantshafssvæðinu (Bermúda)',
        'Atlantic/Canary' => 'Vestur-Evróputími (Kanaríeyjar)',
        'Atlantic/Cape_Verde' => 'Grænhöfðaeyjatími (Grænhöfðaeyjar)',
        'Atlantic/Faeroe' => 'Vestur-Evróputími (Færeyjar)',
        'Atlantic/Madeira' => 'Vestur-Evróputími (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich-staðaltími (Reykjavík)',
        'Atlantic/South_Georgia' => 'Suður-Georgíutími (Suður-Georgía)',
        'Atlantic/St_Helena' => 'Greenwich-staðaltími (Sankti Helena)',
        'Atlantic/Stanley' => 'Falklandseyjatími (Stanley)',
        'Australia/Adelaide' => 'Tími í Mið-Ástralíu (Adelaide)',
        'Australia/Brisbane' => 'Tími í Austur-Ástralíu (Brisbane)',
        'Australia/Broken_Hill' => 'Tími í Mið-Ástralíu (Broken Hill)',
        'Australia/Currie' => 'Tími í Austur-Ástralíu (Currie)',
        'Australia/Darwin' => 'Tími í Mið-Ástralíu (Darwin)',
        'Australia/Eucla' => 'Tími í miðvesturhluta Ástralíu (Eucla)',
        'Australia/Hobart' => 'Tími í Austur-Ástralíu (Hobart)',
        'Australia/Lindeman' => 'Tími í Austur-Ástralíu (Lindeman)',
        'Australia/Lord_Howe' => 'Tími á Lord Howe-eyju',
        'Australia/Melbourne' => 'Tími í Austur-Ástralíu (Melbourne)',
        'Australia/Perth' => 'Tími í Vestur-Ástralíu (Perth)',
        'Australia/Sydney' => 'Tími í Austur-Ástralíu (Sydney)',
        'CST6CDT' => 'Tími í miðhluta Bandaríkjanna og Kanada',
        'EST5EDT' => 'Tími í austurhluta Bandaríkjanna og Kanada',
        'Etc/GMT' => 'Greenwich-staðaltími',
        'Etc/UTC' => 'Samræmdur alþjóðlegur tími',
        'Europe/Amsterdam' => 'Mið-Evróputími (Amsterdam)',
        'Europe/Andorra' => 'Mið-Evróputími (Andorra)',
        'Europe/Astrakhan' => 'Moskvutími (Astrakhan)',
        'Europe/Athens' => 'Austur-Evróputími (Aþena)',
        'Europe/Belgrade' => 'Mið-Evróputími (Belgrad)',
        'Europe/Berlin' => 'Mið-Evróputími (Berlín)',
        'Europe/Bratislava' => 'Mið-Evróputími (Bratislava)',
        'Europe/Brussels' => 'Mið-Evróputími (Brussel)',
        'Europe/Bucharest' => 'Austur-Evróputími (Búkarest)',
        'Europe/Budapest' => 'Mið-Evróputími (Búdapest)',
        'Europe/Busingen' => 'Mið-Evróputími (Busingen)',
        'Europe/Chisinau' => 'Austur-Evróputími (Chisinau)',
        'Europe/Copenhagen' => 'Mið-Evróputími (Kaupmannahöfn)',
        'Europe/Dublin' => 'Greenwich-staðaltími (Dublin)',
        'Europe/Gibraltar' => 'Mið-Evróputími (Gíbraltar)',
        'Europe/Guernsey' => 'Greenwich-staðaltími (Guernsey)',
        'Europe/Helsinki' => 'Austur-Evróputími (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich-staðaltími (Mön)',
        'Europe/Istanbul' => 'Tyrkland (Istanbúl)',
        'Europe/Jersey' => 'Greenwich-staðaltími (Jersey)',
        'Europe/Kaliningrad' => 'Austur-Evróputími (Kaliningrad)',
        'Europe/Kiev' => 'Austur-Evróputími (Kænugarður)',
        'Europe/Kirov' => 'Rússland (Kirov)',
        'Europe/Lisbon' => 'Vestur-Evróputími (Lissabon)',
        'Europe/Ljubljana' => 'Mið-Evróputími (Ljubljana)',
        'Europe/London' => 'Greenwich-staðaltími (Lundúnir)',
        'Europe/Luxembourg' => 'Mið-Evróputími (Lúxemborg)',
        'Europe/Madrid' => 'Mið-Evróputími (Madríd)',
        'Europe/Malta' => 'Mið-Evróputími (Malta)',
        'Europe/Mariehamn' => 'Austur-Evróputími (Maríuhöfn)',
        'Europe/Minsk' => 'Moskvutími (Minsk)',
        'Europe/Monaco' => 'Mið-Evróputími (Mónakó)',
        'Europe/Moscow' => 'Moskvutími (Moskva)',
        'Europe/Oslo' => 'Mið-Evróputími (Osló)',
        'Europe/Paris' => 'Mið-Evróputími (París)',
        'Europe/Podgorica' => 'Mið-Evróputími (Podgorica)',
        'Europe/Prague' => 'Mið-Evróputími (Prag)',
        'Europe/Riga' => 'Austur-Evróputími (Riga)',
        'Europe/Rome' => 'Mið-Evróputími (Róm)',
        'Europe/Samara' => 'Tími í Samara',
        'Europe/San_Marino' => 'Mið-Evróputími (San Marínó)',
        'Europe/Sarajevo' => 'Mið-Evróputími (Sarajevó)',
        'Europe/Saratov' => 'Moskvutími (Saratov)',
        'Europe/Simferopol' => 'Moskvutími (Simferopol)',
        'Europe/Skopje' => 'Mið-Evróputími (Skopje)',
        'Europe/Sofia' => 'Austur-Evróputími (Sófía)',
        'Europe/Stockholm' => 'Mið-Evróputími (Stokkhólmur)',
        'Europe/Tallinn' => 'Austur-Evróputími (Tallinn)',
        'Europe/Tirane' => 'Mið-Evróputími (Tírana)',
        'Europe/Ulyanovsk' => 'Moskvutími (Ulyanovsk)',
        'Europe/Uzhgorod' => 'Austur-Evróputími (Uzhgorod)',
        'Europe/Vaduz' => 'Mið-Evróputími (Vaduz)',
        'Europe/Vatican' => 'Mið-Evróputími (Vatíkanið)',
        'Europe/Vienna' => 'Mið-Evróputími (Vín)',
        'Europe/Vilnius' => 'Austur-Evróputími (Vilníus)',
        'Europe/Volgograd' => 'Tími í Volgograd',
        'Europe/Warsaw' => 'Mið-Evróputími (Varsjá)',
        'Europe/Zagreb' => 'Mið-Evróputími (Zagreb)',
        'Europe/Zaporozhye' => 'Austur-Evróputími (Zaporozhye)',
        'Europe/Zurich' => 'Mið-Evróputími (Zurich)',
        'Indian/Antananarivo' => 'Austur-Afríkutími (Antananarivo)',
        'Indian/Chagos' => 'Indlandshafstími (Chagos)',
        'Indian/Christmas' => 'Jólaeyjartími',
        'Indian/Cocos' => 'Kókoseyjatími (Kókoseyjar)',
        'Indian/Comoro' => 'Austur-Afríkutími (Comoro)',
        'Indian/Kerguelen' => 'Tími á frönsku suðurhafssvæðum og Suðurskautslandssvæði (Kerguelen)',
        'Indian/Mahe' => 'Seychelles-eyjatími (Mahe)',
        'Indian/Maldives' => 'Maldíveyja-tími (Maldíveyjar)',
        'Indian/Mauritius' => 'Máritíustími',
        'Indian/Mayotte' => 'Austur-Afríkutími (Mayotte)',
        'Indian/Reunion' => 'Réunion-tími',
        'MST7MDT' => 'Tími í Klettafjöllum',
        'PST8PDT' => 'Tími á Kyrrahafssvæðinu',
        'Pacific/Apia' => 'Tími í Apía (Apia)',
        'Pacific/Auckland' => 'Tími á Nýja-Sjálandi (Auckland)',
        'Pacific/Bougainville' => 'Tími á Papúa Nýju-Gíneu (Bougainville)',
        'Pacific/Chatham' => 'Chatham-tími',
        'Pacific/Easter' => 'Páskaeyjutími (Páskaeyja)',
        'Pacific/Efate' => 'Vanúatú-tími (Efate)',
        'Pacific/Enderbury' => 'Fönixeyjatími (Enderbury)',
        'Pacific/Fakaofo' => 'Tókelá-tími (Fakaofo)',
        'Pacific/Fiji' => 'Fídjíeyjatími',
        'Pacific/Funafuti' => 'Túvalútími (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos-tími',
        'Pacific/Gambier' => 'Gambier-tími',
        'Pacific/Guadalcanal' => 'Salómonseyjatími (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro-staðaltími (Gvam)',
        'Pacific/Honolulu' => 'Tími á Havaí og Aleúta (Honolulu)',
        'Pacific/Johnston' => 'Tími á Havaí og Aleúta (Johnston)',
        'Pacific/Kiritimati' => 'Línueyja-tími (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae-tími',
        'Pacific/Kwajalein' => 'Tími á Marshall-eyjum (Kwajalein)',
        'Pacific/Majuro' => 'Tími á Marshall-eyjum (Majuro)',
        'Pacific/Marquesas' => 'Tími á Markgreifafrúreyjum (Marquesas-eyjar)',
        'Pacific/Midway' => 'Samóa-tími (Midway)',
        'Pacific/Nauru' => 'Nárú-tími',
        'Pacific/Niue' => 'Niue-tími',
        'Pacific/Norfolk' => 'Tími á Norfolk-eyju',
        'Pacific/Noumea' => 'Tími í Nýju-Kaledóníu (Noumea)',
        'Pacific/Pago_Pago' => 'Samóa-tími (Pago Pago)',
        'Pacific/Palau' => 'Palátími',
        'Pacific/Pitcairn' => 'Pitcairn-tími',
        'Pacific/Ponape' => 'Ponape-tími (Pohnpei)',
        'Pacific/Port_Moresby' => 'Tími á Papúa Nýju-Gíneu (Port Moresby)',
        'Pacific/Rarotonga' => 'Cooks-eyjatími (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro-staðaltími (Saipan)',
        'Pacific/Tahiti' => 'Tahítí-tími',
        'Pacific/Tarawa' => 'Tími á Gilbert-eyjum (Tarawa)',
        'Pacific/Tongatapu' => 'Tongatími (Tongatapu)',
        'Pacific/Truk' => 'Chuuk-tími',
        'Pacific/Wake' => 'Tími á Wake-eyju',
        'Pacific/Wallis' => 'Tími á Wallis- og Fútúnaeyjum',
    ],
    'Meta' => [
    ],
];
