<?php

return [
    'Names' => [
        'be' => 'kviterussisk',
        'be_BY' => 'kviterussisk (Kviterussland)',
        'cv' => 'tsjuvansk',
        'gv' => 'manx',
        'kl' => 'grønlandsk [kalaallisut]',
        'mg' => 'madagassisk',
        'ne' => 'nepalsk',
        'rw' => 'kinjarwanda',
        'sc' => 'sardinsk',
    ],
];
