<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Isikhathi sase-Greenwich Mean (i-Abidjan)',
        'Africa/Accra' => 'Isikhathi sase-Greenwich Mean (i-Accra)',
        'Africa/Addis_Ababa' => 'Isikhathi saseMpumalanga Afrika (i-Addis Ababa)',
        'Africa/Algiers' => 'Isikhathi sase-Central Europe (i-Algiers)',
        'Africa/Asmera' => 'Isikhathi saseMpumalanga Afrika (i-Asmara)',
        'Africa/Bamako' => 'Isikhathi sase-Greenwich Mean (i-Bamako)',
        'Africa/Bangui' => 'Isikhathi saseNtshonalanga Afrika (i-Bangui)',
        'Africa/Banjul' => 'Isikhathi sase-Greenwich Mean (i-Banjul)',
        'Africa/Bissau' => 'Isikhathi sase-Greenwich Mean (i-Bissau)',
        'Africa/Blantyre' => 'Isikhathi sase-Central Africa (i-Blantyre)',
        'Africa/Brazzaville' => 'Isikhathi saseNtshonalanga Afrika (i-Brazzaville)',
        'Africa/Bujumbura' => 'Isikhathi sase-Central Africa (i-Bujumbura)',
        'Africa/Cairo' => 'Isikhathi sase-Eastern Europe (i-Cairo)',
        'Africa/Casablanca' => 'Isikhathi sase-Western Europe (i-Casablanca)',
        'Africa/Ceuta' => 'Isikhathi sase-Central Europe (i-Ceuta)',
        'Africa/Conakry' => 'Isikhathi sase-Greenwich Mean (i-Conakry)',
        'Africa/Dakar' => 'Isikhathi sase-Greenwich Mean (i-Dakar)',
        'Africa/Dar_es_Salaam' => 'Isikhathi saseMpumalanga Afrika (i-Dar es Salaam)',
        'Africa/Djibouti' => 'Isikhathi saseMpumalanga Afrika (i-Djibouti)',
        'Africa/Douala' => 'Isikhathi saseNtshonalanga Afrika (i-Douala)',
        'Africa/El_Aaiun' => 'Isikhathi sase-Western Europe (i-El Aaiun)',
        'Africa/Freetown' => 'Isikhathi sase-Greenwich Mean (i-Freetown)',
        'Africa/Gaborone' => 'Isikhathi sase-Central Africa (i-Gaborone)',
        'Africa/Harare' => 'Isikhathi sase-Central Africa (i-Harare)',
        'Africa/Johannesburg' => 'Isikhathi esivamile saseNingizimu Afrika (i-Johannesburg)',
        'Africa/Juba' => 'Isikhathi sase-Central Africa (iJuba)',
        'Africa/Kampala' => 'Isikhathi saseMpumalanga Afrika (i-Kampala)',
        'Africa/Khartoum' => 'Isikhathi sase-Central Africa (i-Khartoum)',
        'Africa/Kigali' => 'Isikhathi sase-Central Africa (i-Kigali)',
        'Africa/Kinshasa' => 'Isikhathi saseNtshonalanga Afrika (i-Kinshasa)',
        'Africa/Lagos' => 'Isikhathi saseNtshonalanga Afrika (i-Lagos)',
        'Africa/Libreville' => 'Isikhathi saseNtshonalanga Afrika (i-Libreville)',
        'Africa/Lome' => 'Isikhathi sase-Greenwich Mean (i-Lome)',
        'Africa/Luanda' => 'Isikhathi saseNtshonalanga Afrika (i-Luanda)',
        'Africa/Lubumbashi' => 'Isikhathi sase-Central Africa (i-Lubumbashi)',
        'Africa/Lusaka' => 'Isikhathi sase-Central Africa (iLusaka)',
        'Africa/Malabo' => 'Isikhathi saseNtshonalanga Afrika (iMalabo)',
        'Africa/Maputo' => 'Isikhathi sase-Central Africa (iMaputo)',
        'Africa/Maseru' => 'Isikhathi esivamile saseNingizimu Afrika (iMaseru)',
        'Africa/Mbabane' => 'Isikhathi esivamile saseNingizimu Afrika (iMbabane)',
        'Africa/Mogadishu' => 'Isikhathi saseMpumalanga Afrika (i-Mogadishu)',
        'Africa/Monrovia' => 'Isikhathi sase-Greenwich Mean (i-Monrovia)',
        'Africa/Nairobi' => 'Isikhathi saseMpumalanga Afrika (i-Nairobi)',
        'Africa/Ndjamena' => 'Isikhathi saseNtshonalanga Afrika (i-Ndjamena)',
        'Africa/Niamey' => 'Isikhathi saseNtshonalanga Afrika (i-Niamey)',
        'Africa/Nouakchott' => 'Isikhathi sase-Greenwich Mean (i-Nouakchott)',
        'Africa/Ouagadougou' => 'Isikhathi sase-Greenwich Mean (i-Ouagadougou)',
        'Africa/Porto-Novo' => 'Isikhathi saseNtshonalanga Afrika (i-Porto-Novo)',
        'Africa/Sao_Tome' => 'Isikhathi sase-Greenwich Mean (i-São Tomé)',
        'Africa/Tripoli' => 'Isikhathi sase-Eastern Europe (i-Tripoli)',
        'Africa/Tunis' => 'Isikhathi sase-Central Europe (i-Tunis)',
        'Africa/Windhoek' => 'Isikhathi sase-Central Africa (i-Windhoek)',
        'America/Adak' => 'Isikhathi sase-Hawaii-Aleutia (i-Adak)',
        'America/Anchorage' => 'Isikhathi sase-Alaska (i-Anchorage)',
        'America/Anguilla' => 'Isikhathi sase-Atlantic (i-Anguilla)',
        'America/Antigua' => 'Isikhathi sase-Atlantic (i-Antigua)',
        'America/Araguaina' => 'Isikhathi sase-Brasilia (i-Araguaina)',
        'America/Argentina/La_Rioja' => 'Isikhathi sase-Argentina (i-La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Isikhathi sase-Argentina (i-Rio Gallegos)',
        'America/Argentina/Salta' => 'Isikhathi sase-Argentina (i-Salta)',
        'America/Argentina/San_Juan' => 'Isikhathi sase-Argentina (i-San Juan)',
        'America/Argentina/San_Luis' => 'Isikhathi sase-Argentina (i-San Luis)',
        'America/Argentina/Tucuman' => 'Isikhathi sase-Argentina (i-Tucuman)',
        'America/Argentina/Ushuaia' => 'Isikhathi sase-Argentina (i-Ushuaia)',
        'America/Aruba' => 'Isikhathi sase-Atlantic (i-Aruba)',
        'America/Asuncion' => 'Isikhathi sase-Paraguay (i-Asunción)',
        'America/Bahia' => 'Isikhathi sase-Brasilia (i-Bahia)',
        'America/Bahia_Banderas' => 'Isikhathi sase-North American Central (i-Bahia Banderas)',
        'America/Barbados' => 'Isikhathi sase-Atlantic (i-Barbados)',
        'America/Belem' => 'Isikhathi sase-Brasilia (i-Belem)',
        'America/Belize' => 'Isikhathi sase-North American Central (i-Belize)',
        'America/Blanc-Sablon' => 'Isikhathi sase-Atlantic (i-Blanc-Sablon)',
        'America/Boa_Vista' => 'Isikhathi sase-Amazon (i-Boa Vista)',
        'America/Bogota' => 'Isikhathi sase-Colombia (i-Bogota)',
        'America/Boise' => 'Isikhathi sase-North American Mountain (i-Boise)',
        'America/Buenos_Aires' => 'Isikhathi sase-Argentina (i-Buenos Aires)',
        'America/Cambridge_Bay' => 'Isikhathi sase-North American Mountain (i-Cambridge Bay)',
        'America/Campo_Grande' => 'Isikhathi sase-Amazon (i-Campo Grande)',
        'America/Cancun' => 'Isikhathi sase-North American East (i-Cancun)',
        'America/Caracas' => 'Isikhathi sase-Venezuela (i-Caracas)',
        'America/Catamarca' => 'Isikhathi sase-Argentina (i-Catamarca)',
        'America/Cayenne' => 'Isikhathi sase-French Guiana (i-Cayenne)',
        'America/Cayman' => 'Isikhathi sase-North American East (i-Cayman)',
        'America/Chicago' => 'Isikhathi sase-North American Central (i-Chicago)',
        'America/Chihuahua' => 'Isikhathi sase-Mexican Pacific (i-Chihuahua)',
        'America/Coral_Harbour' => 'Isikhathi sase-North American East (i-Atikokan)',
        'America/Cordoba' => 'Isikhathi sase-Argentina (i-Cordoba)',
        'America/Costa_Rica' => 'Isikhathi sase-North American Central (i-Costa Rica)',
        'America/Creston' => 'Isikhathi sase-North American Mountain (i-Creston)',
        'America/Cuiaba' => 'Isikhathi sase-Amazon (i-Cuiaba)',
        'America/Curacao' => 'Isikhathi sase-Atlantic (i-Curaçao)',
        'America/Danmarkshavn' => 'Isikhathi sase-Greenwich Mean (i-Danmarkshavn)',
        'America/Dawson' => 'Yukon Time (i-Dawson)',
        'America/Dawson_Creek' => 'Isikhathi sase-North American Mountain (i-Dawson Creek)',
        'America/Denver' => 'Isikhathi sase-North American Mountain (i-Denver)',
        'America/Detroit' => 'Isikhathi sase-North American East (i-Detroit)',
        'America/Dominica' => 'Isikhathi sase-Atlantic (i-Dominica)',
        'America/Edmonton' => 'Isikhathi sase-North American Mountain (i-Edmonton)',
        'America/Eirunepe' => 'Isikhathi sase-i-Brazil (i-Eirunepe)',
        'America/El_Salvador' => 'Isikhathi sase-North American Central (i-El Salvador)',
        'America/Fort_Nelson' => 'Isikhathi sase-North American Mountain (i-Fort Nelson)',
        'America/Fortaleza' => 'Isikhathi sase-Brasilia (i-Fortaleza)',
        'America/Glace_Bay' => 'Isikhathi sase-Atlantic (i-Glace Bay)',
        'America/Godthab' => 'Isikhathi sase-West Greenland (i-Nuuk)',
        'America/Goose_Bay' => 'Isikhathi sase-Atlantic (i-Goose Bay)',
        'America/Grand_Turk' => 'Isikhathi sase-North American East (i-Grand Turk)',
        'America/Grenada' => 'Isikhathi sase-Atlantic (i-Grenada)',
        'America/Guadeloupe' => 'Isikhathi sase-Atlantic (i-Guadeloupe)',
        'America/Guatemala' => 'Isikhathi sase-North American Central (i-Guatemala)',
        'America/Guayaquil' => 'Isikhathi sase-Ecuador (i-Guayaquil)',
        'America/Guyana' => 'Isikhathi sase-Guyana (i-Guyana)',
        'America/Halifax' => 'Isikhathi sase-Atlantic (i-Halifax)',
        'America/Havana' => 'Isikhathi sase-Cuba (i-Havana)',
        'America/Hermosillo' => 'Isikhathi sase-Mexican Pacific (i-Hermosillo)',
        'America/Indiana/Knox' => 'Isikhathi sase-North American Central (i-Knox, Indiana)',
        'America/Indiana/Marengo' => 'Isikhathi sase-North American East (i-Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Isikhathi sase-North American East (i-Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Isikhathi sase-North American Central (i-Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Isikhathi sase-North American East (i-Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Isikhathi sase-North American East (i-Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Isikhathi sase-North American East (i-Winamac, Indiana)',
        'America/Indianapolis' => 'Isikhathi sase-North American East (i-Indianapolis)',
        'America/Inuvik' => 'Isikhathi sase-North American Mountain (i-Inuvik)',
        'America/Iqaluit' => 'Isikhathi sase-North American East (i-Iqaluit)',
        'America/Jamaica' => 'Isikhathi sase-North American East (i-Jamaica)',
        'America/Jujuy' => 'Isikhathi sase-Argentina (i-Jujuy)',
        'America/Juneau' => 'Isikhathi sase-Alaska (i-Juneau)',
        'America/Kentucky/Monticello' => 'Isikhathi sase-North American East (i-Monticello, Kentucky)',
        'America/Kralendijk' => 'Isikhathi sase-Atlantic (i-Kralendijk)',
        'America/La_Paz' => 'Isikhathi sase-Bolivia (i-La Paz)',
        'America/Lima' => 'Isikhathi sase-Peru (i-Lima)',
        'America/Los_Angeles' => 'Isikhathi sase-North American Pacific (i-Los Angeles)',
        'America/Louisville' => 'Isikhathi sase-North American East (i-Louisville)',
        'America/Lower_Princes' => 'Isikhathi sase-Atlantic (i-Lower Prince’s Quarter)',
        'America/Maceio' => 'Isikhathi sase-Brasilia (i-Maceio)',
        'America/Managua' => 'Isikhathi sase-North American Central (i-Managua)',
        'America/Manaus' => 'Isikhathi sase-Amazon (i-Manaus)',
        'America/Marigot' => 'Isikhathi sase-Atlantic (i-Marigot)',
        'America/Martinique' => 'Isikhathi sase-Atlantic (i-Martinique)',
        'America/Matamoros' => 'Isikhathi sase-North American Central (i-Matamoros)',
        'America/Mazatlan' => 'Isikhathi sase-Mexican Pacific (i-Mazatlan)',
        'America/Mendoza' => 'Isikhathi sase-Argentina (i-Mendoza)',
        'America/Menominee' => 'Isikhathi sase-North American Central (i-Menominee)',
        'America/Merida' => 'Isikhathi sase-North American Central (i-Merida)',
        'America/Metlakatla' => 'Isikhathi sase-Alaska (i-Metlakatla)',
        'America/Mexico_City' => 'Isikhathi sase-North American Central (i-Mexico City)',
        'America/Miquelon' => 'Isikhathi sase-Saint Pierre nase-Miquelon (i-Miquelon)',
        'America/Moncton' => 'Isikhathi sase-Atlantic (i-Moncton)',
        'America/Monterrey' => 'Isikhathi sase-North American Central (i-Monterrey)',
        'America/Montevideo' => 'Isikhathi sase-Uruguay (i-Montevideo)',
        'America/Montreal' => 'Isikhathi sase-i-Canada (Montreal)',
        'America/Montserrat' => 'Isikhathi sase-Atlantic (i-Montserrat)',
        'America/Nassau' => 'Isikhathi sase-North American East (i-Nassau)',
        'America/New_York' => 'Isikhathi sase-North American East (i-New York)',
        'America/Nipigon' => 'Isikhathi sase-North American East (i-Nipigon)',
        'America/Nome' => 'Isikhathi sase-Alaska (i-Nome)',
        'America/Noronha' => 'Isikhathi sase-Fernando de Noronha (i-Noronha)',
        'America/North_Dakota/Beulah' => 'Isikhathi sase-North American Central (i-Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Isikhathi sase-North American Central (i-Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Isikhathi sase-North American Central (i-New Salem, North Dakota)',
        'America/Ojinaga' => 'Isikhathi sase-North American Mountain (i-Ojinaga)',
        'America/Panama' => 'Isikhathi sase-North American East (i-Panama)',
        'America/Pangnirtung' => 'Isikhathi sase-North American East (i-Pangnirtung)',
        'America/Paramaribo' => 'Isikhathi sase-Suriname (i-Paramaribo)',
        'America/Phoenix' => 'Isikhathi sase-North American Mountain (i-Phoenix)',
        'America/Port-au-Prince' => 'Isikhathi sase-North American East (i-Port-au-Prince)',
        'America/Port_of_Spain' => 'Isikhathi sase-Atlantic (i-Port of Spain)',
        'America/Porto_Velho' => 'Isikhathi sase-Amazon (i-Porto Velho)',
        'America/Puerto_Rico' => 'Isikhathi sase-Atlantic (i-Puerto Rico)',
        'America/Punta_Arenas' => 'Isikhathi sase-Chile (i-Punta Arenas)',
        'America/Rainy_River' => 'Isikhathi sase-North American Central (i-Rainy River)',
        'America/Rankin_Inlet' => 'Isikhathi sase-North American Central (i-Rankin Inlet)',
        'America/Recife' => 'Isikhathi sase-Brasilia (i-Recife)',
        'America/Regina' => 'Isikhathi sase-North American Central (i-Regina)',
        'America/Resolute' => 'Isikhathi sase-North American Central (i-Resolute)',
        'America/Rio_Branco' => 'Isikhathi sase-i-Brazil (i-Rio Branco)',
        'America/Santa_Isabel' => 'Isikhathi sase-Northwest Mexico (i-Santa Isabel)',
        'America/Santarem' => 'Isikhathi sase-Brasilia (i-Santarem)',
        'America/Santiago' => 'Isikhathi sase-Chile (i-Santiago)',
        'America/Santo_Domingo' => 'Isikhathi sase-Atlantic (i-Santo Domingo)',
        'America/Sao_Paulo' => 'Isikhathi sase-Brasilia (i-Sao Paulo)',
        'America/Scoresbysund' => 'Isikhathi sase-East Greenland (i-Ittoqqortoormiit)',
        'America/Sitka' => 'Isikhathi sase-Alaska (i-Sitka)',
        'America/St_Barthelemy' => 'Isikhathi sase-Atlantic (i-St. Barthélemy)',
        'America/St_Johns' => 'Isikhathi sase-Newfoundland (i-St. John’s)',
        'America/St_Kitts' => 'Isikhathi sase-Atlantic (i-St. Kitts)',
        'America/St_Lucia' => 'Isikhathi sase-Atlantic (I-St. Lucia)',
        'America/St_Thomas' => 'Isikhathi sase-Atlantic (i-St. Thomas)',
        'America/St_Vincent' => 'Isikhathi sase-Atlantic (i-St. Vincent)',
        'America/Swift_Current' => 'Isikhathi sase-North American Central (i-Swift Current)',
        'America/Tegucigalpa' => 'Isikhathi sase-North American Central (i-Tegucigalpa)',
        'America/Thule' => 'Isikhathi sase-Atlantic (i-Thule)',
        'America/Thunder_Bay' => 'Isikhathi sase-North American East (i-Thunder Bay)',
        'America/Tijuana' => 'Isikhathi sase-North American Pacific (i-Tijuana)',
        'America/Toronto' => 'Isikhathi sase-North American East (i-Toronto)',
        'America/Tortola' => 'Isikhathi sase-Atlantic (i-Tortola)',
        'America/Vancouver' => 'Isikhathi sase-North American Pacific (i-Vancouver)',
        'America/Whitehorse' => 'Yukon Time (i-Whitehorse)',
        'America/Winnipeg' => 'Isikhathi sase-North American Central (i-Winnipeg)',
        'America/Yakutat' => 'Isikhathi sase-Alaska (i-Yakutat)',
        'America/Yellowknife' => 'Isikhathi sase-North American Mountain (i-Yellowknife)',
        'Antarctica/Casey' => 'Isikhathi sase-i-Antarctica (i-Casey)',
        'Antarctica/Davis' => 'Isikhathi sase-Davis (i-Davis)',
        'Antarctica/DumontDUrville' => 'Isikhathi sase-Dumont-d’Urville (i-Dumont d’Urville)',
        'Antarctica/Macquarie' => 'Isikhathi sase-Eastern Australia (i-Macquarie)',
        'Antarctica/Mawson' => 'Isikhathi sase-Mawson (i-Mawson)',
        'Antarctica/McMurdo' => 'Isikhathi sase-New Zealand (i-McMurdo)',
        'Antarctica/Palmer' => 'Isikhathi sase-Chile (i-Palmer)',
        'Antarctica/Rothera' => 'Isikhathi sase-Rothera (i-Rothera)',
        'Antarctica/Syowa' => 'Isikhathi sase-Syowa (i-Syowa)',
        'Antarctica/Troll' => 'Isikhathi sase-Greenwich Mean (i-Troll)',
        'Antarctica/Vostok' => 'Isikhathi sase-Vostok (i-Vostok)',
        'Arctic/Longyearbyen' => 'Isikhathi sase-Central Europe (i-Longyearbyen)',
        'Asia/Aden' => 'Isikhathi sase-Arabian (i-Aden)',
        'Asia/Almaty' => 'Isikhathi sase-Mpumalanga ne-Kazakhstan (i-Almaty)',
        'Asia/Amman' => 'Isikhathi sase-Eastern Europe (i-Amman)',
        'Asia/Anadyr' => 'esase-Anadyr Time (i-Anadyr)',
        'Asia/Aqtau' => 'Isikhathi saseNtshonalanga ne-Kazakhstan (i-Aqtau)',
        'Asia/Aqtobe' => 'Isikhathi saseNtshonalanga ne-Kazakhstan (i-Aqtobe)',
        'Asia/Ashgabat' => 'Isikhathi sase-Turkmenistan (i-Ashgabat)',
        'Asia/Atyrau' => 'Isikhathi saseNtshonalanga ne-Kazakhstan (Atyrau)',
        'Asia/Baghdad' => 'Isikhathi sase-Arabian (i-Baghdad)',
        'Asia/Bahrain' => 'Isikhathi sase-Arabian (i-Bahrain)',
        'Asia/Baku' => 'Isikhathi sase-Azerbaijan (i-Baku)',
        'Asia/Bangkok' => 'Isikhathi sase-Indochina (i-Bangkok)',
        'Asia/Barnaul' => 'Isikhathi sase-i-Russia (i-Barnaul)',
        'Asia/Beirut' => 'Isikhathi sase-Eastern Europe (i-Beirut)',
        'Asia/Bishkek' => 'Isikhathi sase-Kyrgystan (i-Bishkek)',
        'Asia/Brunei' => 'Isikhathi sase-Brunei Darussalam (i-Brunei)',
        'Asia/Calcutta' => 'Isikhathi sase-India esivamile (i-Kolkata)',
        'Asia/Chita' => 'Isikhathi sase-Yakutsk (i-Chita)',
        'Asia/Choibalsan' => 'Isikhathi sase-Ulan Bator (i-Choibalsan)',
        'Asia/Colombo' => 'Isikhathi sase-India esivamile (i-Colombo)',
        'Asia/Damascus' => 'Isikhathi sase-Eastern Europe (i-Damascus)',
        'Asia/Dhaka' => 'Isikhathi sase-Bangladesh (i-Dhaka)',
        'Asia/Dili' => 'Isikhathi sase-East Timor (i-Dili)',
        'Asia/Dubai' => 'Isikhathi esivamile sase-Gulf (i-Dubai)',
        'Asia/Dushanbe' => 'Isikhathi sase-Tajikistan (i-Dushanbe)',
        'Asia/Famagusta' => 'Isikhathi sase-Eastern Europe (Famagusta)',
        'Asia/Gaza' => 'Isikhathi sase-Eastern Europe (iGaza)',
        'Asia/Hebron' => 'Isikhathi sase-Eastern Europe (i-Hebron)',
        'Asia/Hong_Kong' => 'Isikhathi sase-Hong Kong (i-Hong Kong)',
        'Asia/Hovd' => 'Isikhathi sase-Hovd (i-Hovd)',
        'Asia/Irkutsk' => 'Isikhathi sase-Irkutsk (i-Irkutsk)',
        'Asia/Jakarta' => 'Isikhathi sase-Western Indonesia (i-Jakarta)',
        'Asia/Jayapura' => 'Isikhathi sase-Eastern Indonesia (i-Jayapura)',
        'Asia/Jerusalem' => 'Isikhathi sase-Israel (i-Jerusalem)',
        'Asia/Kabul' => 'Isikhathi sase-Afghanistan (i-Kabul)',
        'Asia/Kamchatka' => 'esase-Petropavlovsk-Kamchatski Time (i-Kamchatka)',
        'Asia/Karachi' => 'Isikhathi sase-Pakistan (i-Karachi)',
        'Asia/Katmandu' => 'Isikhathi sase-Nepal (i-Kathmandu)',
        'Asia/Khandyga' => 'Isikhathi sase-Yakutsk (i-Khandyga)',
        'Asia/Krasnoyarsk' => 'Isikhathi sase-Krasnoyarsk (i-Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Isikhathi sase-Malaysia (i-Kuala Lumpur)',
        'Asia/Kuching' => 'Isikhathi sase-Malaysia (i-Kuching)',
        'Asia/Kuwait' => 'Isikhathi sase-Arabian (i-Kuwait)',
        'Asia/Macau' => 'Isikhathi sase-China (i-Macau)',
        'Asia/Magadan' => 'Isikhathi sase-Magadan (i-Magadan)',
        'Asia/Makassar' => 'Isikhathi sase-Central Indonesia (i-Makassar)',
        'Asia/Manila' => 'Isikhathi sase-Philippine (i-Manila)',
        'Asia/Muscat' => 'Isikhathi esivamile sase-Gulf (i-Muscat)',
        'Asia/Nicosia' => 'Isikhathi sase-Eastern Europe (i-Nicosia)',
        'Asia/Novokuznetsk' => 'Isikhathi sase-Krasnoyarsk (i-Novokuznetsk)',
        'Asia/Novosibirsk' => 'Isikhathi sase-Novosibirsk (i-Novosibirsk)',
        'Asia/Omsk' => 'Isikhathi sase-Omsk (i-Omsk)',
        'Asia/Oral' => 'Isikhathi saseNtshonalanga ne-Kazakhstan (i-Oral)',
        'Asia/Phnom_Penh' => 'Isikhathi sase-Indochina (i-Phnom Penh)',
        'Asia/Pontianak' => 'Isikhathi sase-Western Indonesia (i-Pontianak)',
        'Asia/Pyongyang' => 'Isikhathi sase-Korea (i-Pyongyang)',
        'Asia/Qatar' => 'Isikhathi sase-Arabian (i-Qatar)',
        'Asia/Qostanay' => 'Isikhathi sase-Mpumalanga ne-Kazakhstan (I-Kostanay)',
        'Asia/Qyzylorda' => 'Isikhathi saseNtshonalanga ne-Kazakhstan (i-Qyzylorda)',
        'Asia/Rangoon' => 'Isikhathi sase-Myanmar (i-Rangoon)',
        'Asia/Riyadh' => 'Isikhathi sase-Arabian (i-Riyadh)',
        'Asia/Saigon' => 'Isikhathi sase-Indochina (i-Ho Chi Minh City)',
        'Asia/Sakhalin' => 'Isikhathi sase-Sakhalin (i-Sakhalin)',
        'Asia/Samarkand' => 'Isikhathi sase-Uzbekistan (i-Samarkand)',
        'Asia/Seoul' => 'Isikhathi sase-Korea (i-Seoul)',
        'Asia/Shanghai' => 'Isikhathi sase-China (i-Shanghai)',
        'Asia/Singapore' => 'Isikhathi esivamile sase-Singapore (i-Singapore)',
        'Asia/Srednekolymsk' => 'Isikhathi sase-Magadan (i-Srednekolymsk)',
        'Asia/Taipei' => 'Isikhathi sase-Taipei (i-Taipei)',
        'Asia/Tashkent' => 'Isikhathi sase-Uzbekistan (i-Tashkent)',
        'Asia/Tbilisi' => 'Isikhathi sase-Georgia (i-Tbilisi)',
        'Asia/Tehran' => 'Isikhathi sase-Iran (i-Tehran)',
        'Asia/Thimphu' => 'Isikhathi sase-Bhutan (i-Thimphu)',
        'Asia/Tokyo' => 'Isikhathi sase-Japan (i-Tokyo)',
        'Asia/Tomsk' => 'Isikhathi sase-i-Russia (i-Tomsk)',
        'Asia/Ulaanbaatar' => 'Isikhathi sase-Ulan Bator (i-Ulaanbaatar)',
        'Asia/Urumqi' => 'Isikhathi sase-i-China (i-Urumqi)',
        'Asia/Ust-Nera' => 'Isikhathi sase-Vladivostok (i-Ust-Nera)',
        'Asia/Vientiane' => 'Isikhathi sase-Indochina (i-Vientiane)',
        'Asia/Vladivostok' => 'Isikhathi sase-Vladivostok (i-Vladivostok)',
        'Asia/Yakutsk' => 'Isikhathi sase-Yakutsk (i-Yakutsk)',
        'Asia/Yekaterinburg' => 'Isikhathi sase-Yekaterinburg (i-Yekaterinburg)',
        'Asia/Yerevan' => 'Isikhathi saseArmenia (i-Yerevan)',
        'Atlantic/Azores' => 'Isikhathi sase-Azores (i-Azores)',
        'Atlantic/Bermuda' => 'Isikhathi sase-Atlantic (i-Bermuda)',
        'Atlantic/Canary' => 'Isikhathi sase-Western Europe (i-Canary)',
        'Atlantic/Cape_Verde' => 'Isikhathi sase-Cape Verde (i-Cape Verde)',
        'Atlantic/Faeroe' => 'Isikhathi sase-Western Europe (i-Faroe)',
        'Atlantic/Madeira' => 'Isikhathi sase-Western Europe (i-Madeira)',
        'Atlantic/Reykjavik' => 'Isikhathi sase-Greenwich Mean (i-Reykjavik)',
        'Atlantic/South_Georgia' => 'Isikhathi sase-South Georgia (i-South Georgia)',
        'Atlantic/St_Helena' => 'Isikhathi sase-Greenwich Mean (i-St. Helena)',
        'Atlantic/Stanley' => 'Isikhathi sase-Falkland Islands (i-Stanley)',
        'Australia/Adelaide' => 'Isikhathi sase-Central Australia (i-Adelaide)',
        'Australia/Brisbane' => 'Isikhathi sase-Eastern Australia (i-Brisbane)',
        'Australia/Broken_Hill' => 'Isikhathi sase-Central Australia (i-Broken Hill)',
        'Australia/Currie' => 'Isikhathi sase-Eastern Australia (i-Currie)',
        'Australia/Darwin' => 'Isikhathi sase-Central Australia (i-Darwin)',
        'Australia/Eucla' => 'Isikhathi sase-Australian Central West (i-Eucla)',
        'Australia/Hobart' => 'Isikhathi sase-Eastern Australia (i-Hobart)',
        'Australia/Lindeman' => 'Isikhathi sase-Eastern Australia (i-Lindeman)',
        'Australia/Lord_Howe' => 'Isikhathi sase-Lord Howe (i-Lord Howe)',
        'Australia/Melbourne' => 'Isikhathi sase-Eastern Australia (i-Melbourne)',
        'Australia/Perth' => 'Isikhathi sase-Western Australia (i-Perth)',
        'Australia/Sydney' => 'Isikhathi sase-Eastern Australia (i-Sydney)',
        'CST6CDT' => 'Isikhathi sase-North American Central',
        'EST5EDT' => 'Isikhathi sase-North American East',
        'Etc/GMT' => 'Isikhathi sase-Greenwich Mean',
        'Etc/UTC' => 'isikhathi somhlaba esididiyelwe',
        'Europe/Amsterdam' => 'Isikhathi sase-Central Europe (i-Amsterdam)',
        'Europe/Andorra' => 'Isikhathi sase-Central Europe (i-Andorra)',
        'Europe/Astrakhan' => 'Isikhathi sase-Moscow (i-Astrakhan)',
        'Europe/Athens' => 'Isikhathi sase-Eastern Europe (i-Athens)',
        'Europe/Belgrade' => 'Isikhathi sase-Central Europe (i-Belgrade)',
        'Europe/Berlin' => 'Isikhathi sase-Central Europe (i-Berlin)',
        'Europe/Bratislava' => 'Isikhathi sase-Central Europe (i-Bratislava)',
        'Europe/Brussels' => 'Isikhathi sase-Central Europe (i-Brussels)',
        'Europe/Bucharest' => 'Isikhathi sase-Eastern Europe (i-Bucharest)',
        'Europe/Budapest' => 'Isikhathi sase-Central Europe (i-Budapest)',
        'Europe/Busingen' => 'Isikhathi sase-Central Europe (i-Busingen)',
        'Europe/Chisinau' => 'Isikhathi sase-Eastern Europe (i-Chisinau)',
        'Europe/Copenhagen' => 'Isikhathi sase-Central Europe (i-Copenhagen)',
        'Europe/Dublin' => 'Isikhathi sase-Greenwich Mean (i-Dublin)',
        'Europe/Gibraltar' => 'Isikhathi sase-Central Europe (i-Gibraltar)',
        'Europe/Guernsey' => 'Isikhathi sase-Greenwich Mean (i-Guernsey)',
        'Europe/Helsinki' => 'Isikhathi sase-Eastern Europe (i-Helsinki)',
        'Europe/Isle_of_Man' => 'Isikhathi sase-Greenwich Mean (i-Isle of Man)',
        'Europe/Istanbul' => 'Isikhathi sase-i-Turkey (i-Istanbul)',
        'Europe/Jersey' => 'Isikhathi sase-Greenwich Mean (i-Jersey)',
        'Europe/Kaliningrad' => 'Isikhathi sase-Eastern Europe (i-Kaliningrad)',
        'Europe/Kiev' => 'Isikhathi sase-Eastern Europe (i-Kiev)',
        'Europe/Kirov' => 'Isikhathi sase-i-Russia (i-Kirov)',
        'Europe/Lisbon' => 'Isikhathi sase-Western Europe (i-Lisbon)',
        'Europe/Ljubljana' => 'Isikhathi sase-Central Europe (i-Ljubljana)',
        'Europe/London' => 'Isikhathi sase-Greenwich Mean (i-London)',
        'Europe/Luxembourg' => 'Isikhathi sase-Central Europe (i-Luxembourg)',
        'Europe/Madrid' => 'Isikhathi sase-Central Europe (i-Madrid)',
        'Europe/Malta' => 'Isikhathi sase-Central Europe (i-Malta)',
        'Europe/Mariehamn' => 'Isikhathi sase-Eastern Europe (i-Mariehamn)',
        'Europe/Minsk' => 'Isikhathi sase-Moscow (i-Minsk)',
        'Europe/Monaco' => 'Isikhathi sase-Central Europe (i-Monaco)',
        'Europe/Moscow' => 'Isikhathi sase-Moscow (i-Moscow)',
        'Europe/Oslo' => 'Isikhathi sase-Central Europe (i-Oslo)',
        'Europe/Paris' => 'Isikhathi sase-Central Europe (i-Paris)',
        'Europe/Podgorica' => 'Isikhathi sase-Central Europe (i-Podgorica)',
        'Europe/Prague' => 'Isikhathi sase-Central Europe (i-Prague)',
        'Europe/Riga' => 'Isikhathi sase-Eastern Europe (i-Riga)',
        'Europe/Rome' => 'Isikhathi sase-Central Europe (i-Rome)',
        'Europe/Samara' => 'esase-Samara Time (i-Samara)',
        'Europe/San_Marino' => 'Isikhathi sase-Central Europe (i-San Marino)',
        'Europe/Sarajevo' => 'Isikhathi sase-Central Europe (i-Sarajevo)',
        'Europe/Saratov' => 'Isikhathi sase-Moscow (i-Saratov)',
        'Europe/Simferopol' => 'Isikhathi sase-Moscow (i-Simferopol)',
        'Europe/Skopje' => 'Isikhathi sase-Central Europe (i-Skopje)',
        'Europe/Sofia' => 'Isikhathi sase-Eastern Europe (i-Sofia)',
        'Europe/Stockholm' => 'Isikhathi sase-Central Europe (i-Stockholm)',
        'Europe/Tallinn' => 'Isikhathi sase-Eastern Europe (i-Tallinn)',
        'Europe/Tirane' => 'Isikhathi sase-Central Europe (i-Tirane)',
        'Europe/Ulyanovsk' => 'Isikhathi sase-Moscow (i-Ulyanovsk)',
        'Europe/Uzhgorod' => 'Isikhathi sase-Eastern Europe (i-Uzhhorod)',
        'Europe/Vaduz' => 'Isikhathi sase-Central Europe (i-Vaduz)',
        'Europe/Vatican' => 'Isikhathi sase-Central Europe (i-Vatican)',
        'Europe/Vienna' => 'Isikhathi sase-Central Europe (i-Vienna)',
        'Europe/Vilnius' => 'Isikhathi sase-Eastern Europe (i-Vilnius)',
        'Europe/Volgograd' => 'Isikhathi sase-Volgograd (i-Volgograd)',
        'Europe/Warsaw' => 'Isikhathi sase-Central Europe (i-Warsaw)',
        'Europe/Zagreb' => 'Isikhathi sase-Central Europe (i-Zagreb)',
        'Europe/Zaporozhye' => 'Isikhathi sase-Eastern Europe (i-Zaporozhye)',
        'Europe/Zurich' => 'Isikhathi sase-Central Europe (i-Zurich)',
        'Indian/Antananarivo' => 'Isikhathi saseMpumalanga Afrika (i-Antananarivo)',
        'Indian/Chagos' => 'Isikhathi sase-Indian Ocean (i-Chagos)',
        'Indian/Christmas' => 'Isikhathi sase-Christmas Island (Ukhisimusi)',
        'Indian/Cocos' => 'Isikhathi sase-Cocos Islands (i-Cocos)',
        'Indian/Comoro' => 'Isikhathi saseMpumalanga Afrika (i-Comoro)',
        'Indian/Kerguelen' => 'Isikhathi sase-French Southern nase-Antarctic (i-Kerguelen)',
        'Indian/Mahe' => 'Isikhathi sase-Seychelles (iMahe)',
        'Indian/Maldives' => 'Isikhathi sase-Maldives (i-Maldives)',
        'Indian/Mauritius' => 'Isikhathi sase-Mauritius (i-Mauritius)',
        'Indian/Mayotte' => 'Isikhathi saseMpumalanga Afrika (i-Mayotte)',
        'Indian/Reunion' => 'Isikhathi sase-Reunion (i-Réunion)',
        'MST7MDT' => 'Isikhathi sase-North American Mountain',
        'PST8PDT' => 'Isikhathi sase-North American Pacific',
        'Pacific/Apia' => 'Isikhathi sase-Apia (i-Apia)',
        'Pacific/Auckland' => 'Isikhathi sase-New Zealand (i-Auckland)',
        'Pacific/Bougainville' => 'Isikhathi sase-Papua New Guinea (i-Bougainville)',
        'Pacific/Chatham' => 'Isikhathi sase-Chatham (i-Chatham)',
        'Pacific/Easter' => 'Isikhathi sase-Easter Island (i-Easter)',
        'Pacific/Efate' => 'Isikhathi sase-Vanuatu (i-Efate)',
        'Pacific/Enderbury' => 'Isikhathi sase-Phoenix Islands (i-Enderbury)',
        'Pacific/Fakaofo' => 'Isikhathi sase-Tokelau (i-Fakaofo)',
        'Pacific/Fiji' => 'Isikhathi sase-Fiji (i-Fiji)',
        'Pacific/Funafuti' => 'Isikhathi sase-Tuvalu (i-Funafuti)',
        'Pacific/Galapagos' => 'Isikhathi sase-Galapagos (i-Galapagos)',
        'Pacific/Gambier' => 'Isikhathi sase-Gambier (i-Gambier)',
        'Pacific/Guadalcanal' => 'Isikhathi sase-Solomon Islands (i-Guadalcanal)',
        'Pacific/Guam' => 'Isikhathi esivamile sase-Chamorro (i-Guam)',
        'Pacific/Honolulu' => 'Isikhathi sase-Hawaii-Aleutia (i-Honolulu)',
        'Pacific/Johnston' => 'Isikhathi sase-Hawaii-Aleutia (i-Johnston)',
        'Pacific/Kiritimati' => 'Isikhathi sase-Line Islands (i-Kiritimati)',
        'Pacific/Kosrae' => 'Isikhathi sase-Kosrae (i-Kosrae)',
        'Pacific/Kwajalein' => 'Isikhathi sase-Marshall Islands (i-Kwajalein)',
        'Pacific/Majuro' => 'Isikhathi sase-Marshall Islands (i-Majuro)',
        'Pacific/Marquesas' => 'Isikhathi sase-Marquesas (i-Marquesas)',
        'Pacific/Midway' => 'Isikhathi sase-Samoa (i-Midway)',
        'Pacific/Nauru' => 'Isikhathi sase-Nauru (i-Nauru)',
        'Pacific/Niue' => 'Isikhathi sase-Niue (i-Niue)',
        'Pacific/Norfolk' => 'Isikhathi sase-Norfolk Islands (i-Norfolk)',
        'Pacific/Noumea' => 'Isikhathi sase-New Caledonia (i-Noumea)',
        'Pacific/Pago_Pago' => 'Isikhathi sase-Samoa (i-Pago Pago)',
        'Pacific/Palau' => 'Isikhathi sase-Palau (i-Palau)',
        'Pacific/Pitcairn' => 'Isikhathi sase-Pitcairn (i-Pitcairn)',
        'Pacific/Ponape' => 'Isikhathi sase-Ponape (i-Pohnpei)',
        'Pacific/Port_Moresby' => 'Isikhathi sase-Papua New Guinea (i-Port Moresby)',
        'Pacific/Rarotonga' => 'Isikhathi sase-Cook Islands (i-Rarotonga)',
        'Pacific/Saipan' => 'Isikhathi esivamile sase-Chamorro (i-Saipan)',
        'Pacific/Tahiti' => 'Isikhathi sase-Tahiti (i-Tahiti)',
        'Pacific/Tarawa' => 'Isikhathi sase-Gilbert Islands (i-Tarawa)',
        'Pacific/Tongatapu' => 'Isikhathi sase-Tonga (i-Tongatapu)',
        'Pacific/Truk' => 'Isikhathi sase-Chuuk (i-Chuuk)',
        'Pacific/Wake' => 'Isikhathi sase-Wake Island (i-Wake)',
        'Pacific/Wallis' => 'Isikhathi sase-Wallis nase-Futuna (i-Wallis)',
    ],
    'Meta' => [
    ],
];
