<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Андоррская песета',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'дирхам ОАЭ',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Афгани (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'афгани',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'албанский лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'армянский драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'нидерландский антильский гульден',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'ангольская кванза',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Ангольская кванза (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Ангольская новая кванза (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Ангольская кванза реюстадо (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Аргентинский аустрал',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Аргентинское песо (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'аргентинский песо',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Австрийский шиллинг',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'австралийский доллар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'арубанский флорин',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Старый азербайджанский манат',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'азербайджанский манат',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Динар Боснии и Герцеговины',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'конвертируемая марка Боснии и Герцеговины',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'барбадосский доллар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'бангладешская така',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Бельгийский франк (конвертируемый)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Бельгийский франк',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Бельгийский франк (финансовый)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Лев',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'болгарский лев',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'бахрейнский динар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'бурундийский франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'бермудский доллар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'брунейский доллар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'боливийский боливиано',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Боливийское песо',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Боливийский мвдол',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Бразильский новый крузейро (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Бразильское крузадо',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Бразильский крузейро (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'бразильский реал',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Бразильское новое крузадо',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Бразильский крузейро',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'багамский доллар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'бутанский нгултрум',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Джа',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'ботсванская пула',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Белорусский рубль (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'белорусский рубль',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Белорусский рубль (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'белизский доллар',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'канадский доллар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'конголезский франк',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR евро',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'швейцарский франк',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR франк',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Условная расчетная единица Чили',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'чилийский песо',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'китайский офшорный юань',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'китайский юань',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'колумбийский песо',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Единица реальной стоимости Колумбии',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'костариканский колон',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Старый Сербский динар',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Чехословацкая твердая крона',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'кубинский конвертируемый песо',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'кубинский песо',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'эскудо Кабо-Верде',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Кипрский фунт',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'чешская крона',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Восточногерманская марка',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Немецкая марка',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'франк Джибути',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'датская крона',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'доминиканский песо',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'алжирский динар',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Эквадорский сукре',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Постоянная единица стоимости Эквадора',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Эстонская крона',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'египетский фунт',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'эритрейская накфа',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Испанская песета (А)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Испанская песета (конвертируемая)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Испанская песета',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'эфиопский быр',
        ],
        'EUR' => [
            0 => '€',
            1 => 'евро',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Финская марка',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'доллар Фиджи',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'фунт Фолклендских островов',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Французский франк',
        ],
        'GBP' => [
            0 => '£',
            1 => 'британский фунт стерлингов',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Грузинский купон',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'грузинский лари',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ганский седи (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ганский седи',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'гибралтарский фунт',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'гамбийский даласи',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'гвинейский франк',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Гвинейская сили',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Эквеле экваториальной Гвинеи',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Греческая драхма',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'гватемальский кетсаль',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Эскудо Португальской Гвинеи',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Песо Гвинеи-Бисау',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'гайанский доллар',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'гонконгский доллар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'гондурасская лемпира',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Хорватский динар',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'хорватская куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'гаитянский гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'венгерский форинт',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'индонезийская рупия',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Ирландский фунт',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Израильский фунт',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'новый израильский шекель',
        ],
        'INR' => [
            0 => '₹',
            1 => 'индийская рупия',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'иракский динар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'иранский риал',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'исландская крона',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Итальянская лира',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'ямайский доллар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'иорданский динар',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'японская иена',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'кенийский шиллинг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'киргизский сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'камбоджийский риель',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'коморский франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'северокорейская вона',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'южнокорейская вона',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'кувейтский динар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'доллар Островов Кайман',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'казахский тенге',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'лаосский кип',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'ливанский фунт',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'шри-ланкийская рупия',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'либерийский доллар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'лоти',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Литовский лит',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Литовский талон',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Конвертируемый франк Люксембурга',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Люксембургский франк',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Финансовый франк Люксембурга',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Латвийский лат',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Латвийский рубль',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'ливийский динар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'марокканский дирхам',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Марокканский франк',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'молдавский лей',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'малагасийский ариари',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Малагасийский франк',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'македонский денар',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Малийский франк',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'мьянманский кьят',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'монгольский тугрик',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'патака Макао',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'мавританская угия (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'мавританская угия',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Мальтийская лира',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Мальтийский фунт',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'маврикийская рупия',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'мальдивская руфия',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'малавийская квача',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'мексиканский песо',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Мексиканское серебряное песо (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Мексиканская пересчетная единица (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'малайзийский ринггит',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Мозамбикское эскудо',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Старый мозамбикский метикал',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'мозамбикский метикал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'доллар Намибии',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'нигерийская найра',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Никарагуанская кордоба (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'никарагуанская кордоба',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Нидерландский гульден',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'норвежская крона',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'непальская рупия',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'новозеландский доллар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'оманский риал',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'панамский бальбоа',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Перуанское инти',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'перуанский соль',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Перуанский соль (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'кина Папуа – Новой Гвинеи',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'филиппинский песо',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'пакистанская рупия',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'польский злотый',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Злотый',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Португальское эскудо',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'парагвайский гуарани',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'катарский риал',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Родезийский доллар',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Старый Румынский лей',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'румынский лей',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'сербский динар',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'российский рубль',
        ],
        'RUR' => [
            0 => 'р.',
            1 => 'Российский рубль (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'франк Руанды',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'саудовский риял',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'доллар Соломоновых Островов',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'сейшельская рупия',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Суданский динар',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'суданский фунт',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Старый суданский фунт',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'шведская крона',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'сингапурский доллар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'фунт острова Святой Елены',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Словенский толар',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Словацкая крона',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'леоне',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'сомалийский шиллинг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'суринамский доллар',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Суринамский гульден',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'южносуданский фунт',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'добра Сан-Томе и Принсипи (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'добра Сан-Томе и Принсипи',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Рубль СССР',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Сальвадорский колон',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'сирийский фунт',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'свазилендский лилангени',
        ],
        'THB' => [
            0 => '฿',
            1 => 'таиландский бат',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Таджикский рубль',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'таджикский сомони',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Туркменский манат',
        ],
        'TMT' => [
            0 => 'ТМТ',
            1 => 'новый туркменский манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'тунисский динар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'тонганская паанга',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Тиморское эскудо',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Турецкая лира (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'турецкая лира',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'доллар Тринидада и Тобаго',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'новый тайваньский доллар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'танзанийский шиллинг',
        ],
        'UAH' => [
            0 => '₴',
            1 => 'украинская гривна',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Карбованец (украинский)',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Старый угандийский шиллинг',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'угандийский шиллинг',
        ],
        'USD' => [
            0 => '$',
            1 => 'доллар США',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Доллар США следующего дня',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Доллар США текущего дня',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Уругвайский песо (индекс инфляции)',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Уругвайское старое песо (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'уругвайский песо',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'узбекский сум',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Венесуэльский боливар (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'венесуэльский боливар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'венесуэльский боливар',
        ],
        'VND' => [
            0 => '₫',
            1 => 'вьетнамский донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'вату Вануату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'самоанская тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'франк КФА BEAC',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'восточно-карибский доллар',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'ЭКЮ (единица европейской валюты)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Французский золотой франк',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Французский UIC-франк',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'франк КФА ВСЕАО',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'французский тихоокеанский франк',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'единица RINET-фондов',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Йеменский динар',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'йеменский риал',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Югославский твердый динар',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Югославский новый динар',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Югославский динар',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Южноафриканский рэнд (финансовый)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'южноафриканский рэнд',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Квача (замбийская) (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'замбийская квача',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Новый заир',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Заир',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Доллар Зимбабве',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Доллар Зимбабве (2009)',
        ],
    ],
];
