<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ग्रीनिच प्रमाण वेळ (अबिद्जान)',
        'Africa/Accra' => 'ग्रीनिच प्रमाण वेळ (अ‍ॅक्रा)',
        'Africa/Addis_Ababa' => 'पूर्व आफ्रिका वेळ (आदिस अबाबा)',
        'Africa/Algiers' => 'मध्‍य युरोपियन वेळ (अल्जिअर्स)',
        'Africa/Asmera' => 'पूर्व आफ्रिका वेळ (एस्मारा)',
        'Africa/Bamako' => 'ग्रीनिच प्रमाण वेळ (बामको)',
        'Africa/Bangui' => 'पश्चिम आफ्रिका वेळ (बांगुई)',
        'Africa/Banjul' => 'ग्रीनिच प्रमाण वेळ (बंजुल)',
        'Africa/Bissau' => 'ग्रीनिच प्रमाण वेळ (बिसाउ)',
        'Africa/Blantyre' => 'मध्‍य आफ्रिका वेळ (ब्लँटायर)',
        'Africa/Brazzaville' => 'पश्चिम आफ्रिका वेळ (ब्राझाव्हिले)',
        'Africa/Bujumbura' => 'मध्‍य आफ्रिका वेळ (बुजुंबुरा)',
        'Africa/Cairo' => 'पूर्व युरोपियन वेळ (कैरो)',
        'Africa/Casablanca' => 'पश्चिम युरोपियन वेळ (कॅसाब्लान्का)',
        'Africa/Ceuta' => 'मध्‍य युरोपियन वेळ (सेउटा)',
        'Africa/Conakry' => 'ग्रीनिच प्रमाण वेळ (कोनाक्रि)',
        'Africa/Dakar' => 'ग्रीनिच प्रमाण वेळ (डकर)',
        'Africa/Dar_es_Salaam' => 'पूर्व आफ्रिका वेळ (दार ए सलाम)',
        'Africa/Djibouti' => 'पूर्व आफ्रिका वेळ (जिबौटी)',
        'Africa/Douala' => 'पश्चिम आफ्रिका वेळ (दोउआला)',
        'Africa/El_Aaiun' => 'पश्चिम युरोपियन वेळ (एल ऐउन)',
        'Africa/Freetown' => 'ग्रीनिच प्रमाण वेळ (फ्रीटाउन)',
        'Africa/Gaborone' => 'मध्‍य आफ्रिका वेळ (गाबोरोन)',
        'Africa/Harare' => 'मध्‍य आफ्रिका वेळ (हरारे)',
        'Africa/Johannesburg' => 'दक्षिण आफ्रिका प्रमाण वेळ (जोहान्सबर्ग)',
        'Africa/Juba' => 'मध्‍य आफ्रिका वेळ (जुबा)',
        'Africa/Kampala' => 'पूर्व आफ्रिका वेळ (कंपाला)',
        'Africa/Khartoum' => 'मध्‍य आफ्रिका वेळ (खार्टुम)',
        'Africa/Kigali' => 'मध्‍य आफ्रिका वेळ (कीगाली)',
        'Africa/Kinshasa' => 'पश्चिम आफ्रिका वेळ (किन्शासा)',
        'Africa/Lagos' => 'पश्चिम आफ्रिका वेळ (लागोस)',
        'Africa/Libreville' => 'पश्चिम आफ्रिका वेळ (लिबरव्हिल)',
        'Africa/Lome' => 'ग्रीनिच प्रमाण वेळ (लोम)',
        'Africa/Luanda' => 'पश्चिम आफ्रिका वेळ (लुआंडा)',
        'Africa/Lubumbashi' => 'मध्‍य आफ्रिका वेळ (लुबंबाशी)',
        'Africa/Lusaka' => 'मध्‍य आफ्रिका वेळ (लुसाका)',
        'Africa/Malabo' => 'पश्चिम आफ्रिका वेळ (मलाबो)',
        'Africa/Maputo' => 'मध्‍य आफ्रिका वेळ (मापुटो)',
        'Africa/Maseru' => 'दक्षिण आफ्रिका प्रमाण वेळ (मसेरु)',
        'Africa/Mbabane' => 'दक्षिण आफ्रिका प्रमाण वेळ (अंबाबाने)',
        'Africa/Mogadishu' => 'पूर्व आफ्रिका वेळ (मोगादिशु)',
        'Africa/Monrovia' => 'ग्रीनिच प्रमाण वेळ (मोनरोव्हिया)',
        'Africa/Nairobi' => 'पूर्व आफ्रिका वेळ (नैरोबी)',
        'Africa/Ndjamena' => 'पश्चिम आफ्रिका वेळ (इंजामेना)',
        'Africa/Niamey' => 'पश्चिम आफ्रिका वेळ (नियामे)',
        'Africa/Nouakchott' => 'ग्रीनिच प्रमाण वेळ (नुवाकसुत)',
        'Africa/Ouagadougou' => 'ग्रीनिच प्रमाण वेळ (वागडूगू)',
        'Africa/Porto-Novo' => 'पश्चिम आफ्रिका वेळ (पोर्टो-नोव्हो)',
        'Africa/Sao_Tome' => 'ग्रीनिच प्रमाण वेळ (साओ तोमे)',
        'Africa/Tripoli' => 'पूर्व युरोपियन वेळ (त्रिपोली)',
        'Africa/Tunis' => 'मध्‍य युरोपियन वेळ (टयूनिस)',
        'Africa/Windhoek' => 'मध्‍य आफ्रिका वेळ (विंडहोएक)',
        'America/Adak' => 'हवाई-अलूशन वेळ (अडॅक)',
        'America/Anchorage' => 'अलास्का वेळ (अँकरेज)',
        'America/Anguilla' => 'अटलांटिक वेळ (अँग्विला)',
        'America/Antigua' => 'अटलांटिक वेळ (अँटिग्वा)',
        'America/Araguaina' => 'ब्राझिलिया वेळ (अरागायना)',
        'America/Argentina/La_Rioja' => 'अर्जेंटिना वेळ (ला रियोजा)',
        'America/Argentina/Rio_Gallegos' => 'अर्जेंटिना वेळ (रियो गॅलेगॉस)',
        'America/Argentina/Salta' => 'अर्जेंटिना वेळ (सॉल्ता)',
        'America/Argentina/San_Juan' => 'अर्जेंटिना वेळ (सान जुआन)',
        'America/Argentina/San_Luis' => 'अर्जेंटिना वेळ (सान ल्युइस)',
        'America/Argentina/Tucuman' => 'अर्जेंटिना वेळ (टुकुमान)',
        'America/Argentina/Ushuaia' => 'अर्जेंटिना वेळ (उस्वाइया)',
        'America/Aruba' => 'अटलांटिक वेळ (अरुबा)',
        'America/Asuncion' => 'पॅराग्वे वेळ (आसुन्सियोन)',
        'America/Bahia' => 'ब्राझिलिया वेळ (बहिया)',
        'America/Bahia_Banderas' => 'केंद्रीय वेळ (बाहिया बांदेरास)',
        'America/Barbados' => 'अटलांटिक वेळ (बार्बाडोस)',
        'America/Belem' => 'ब्राझिलिया वेळ (बेलेम)',
        'America/Belize' => 'केंद्रीय वेळ (बेलिझे)',
        'America/Blanc-Sablon' => 'अटलांटिक वेळ (ब्लांक सॅबलोन)',
        'America/Boa_Vista' => 'अ‍ॅमेझॉन वेळ (बोआ व्हिस्टा)',
        'America/Bogota' => 'कोलंबिया वेळ (बोगोटा)',
        'America/Boise' => 'पर्वतीय वेळ (बोइसी)',
        'America/Buenos_Aires' => 'अर्जेंटिना वेळ (ब्युनोस आयर्स)',
        'America/Cambridge_Bay' => 'पर्वतीय वेळ (केंब्रिज उपसागर)',
        'America/Campo_Grande' => 'अ‍ॅमेझॉन वेळ (कॅम्पो ग्रँडे)',
        'America/Cancun' => 'पौर्वात्य वेळ (कानकुन)',
        'America/Caracas' => 'व्हेनेझुएला वेळ (कराकास)',
        'America/Catamarca' => 'अर्जेंटिना वेळ (कॅटामार्का)',
        'America/Cayenne' => 'फ्रेंच गयाना वेळ (कायेने)',
        'America/Cayman' => 'पौर्वात्य वेळ (केमन)',
        'America/Chicago' => 'केंद्रीय वेळ (शिकागो)',
        'America/Chihuahua' => 'मेक्सिको पॅसिफिक वेळ (चिहुआहुआ)',
        'America/Coral_Harbour' => 'पौर्वात्य वेळ (अॅटिकोकन)',
        'America/Cordoba' => 'अर्जेंटिना वेळ (कॉर्डोबा)',
        'America/Costa_Rica' => 'केंद्रीय वेळ (कोस्टा रिका)',
        'America/Creston' => 'पर्वतीय वेळ (क्रेस्टन)',
        'America/Cuiaba' => 'अ‍ॅमेझॉन वेळ (कुयाबा)',
        'America/Curacao' => 'अटलांटिक वेळ (क्युरासाओ)',
        'America/Danmarkshavn' => 'ग्रीनिच प्रमाण वेळ (डेन्मार्कशॉन)',
        'America/Dawson' => 'युकोन वेळ (डॉसन)',
        'America/Dawson_Creek' => 'पर्वतीय वेळ (डॉसन क्रीक)',
        'America/Denver' => 'पर्वतीय वेळ (डेन्व्हर)',
        'America/Detroit' => 'पौर्वात्य वेळ (डेट्रॉइट)',
        'America/Dominica' => 'अटलांटिक वेळ (डोमिनिका)',
        'America/Edmonton' => 'पर्वतीय वेळ (एडमाँटन)',
        'America/Eirunepe' => 'एकर वेळ (यूरुनीपे)',
        'America/El_Salvador' => 'केंद्रीय वेळ (एल साल्वाडोर)',
        'America/Fort_Nelson' => 'पर्वतीय वेळ (फोर्ट नेल्सन)',
        'America/Fortaleza' => 'ब्राझिलिया वेळ (फोर्टालेझा)',
        'America/Glace_Bay' => 'अटलांटिक वेळ (ग्लेस उपसागर)',
        'America/Godthab' => 'पश्चिम ग्रीनलँड वेळ (नूक)',
        'America/Goose_Bay' => 'अटलांटिक वेळ (गूस उपसागर)',
        'America/Grand_Turk' => 'पौर्वात्य वेळ (ग्रँड टर्क)',
        'America/Grenada' => 'अटलांटिक वेळ (ग्रेनेडा)',
        'America/Guadeloupe' => 'अटलांटिक वेळ (ग्वाडेलोउपे)',
        'America/Guatemala' => 'केंद्रीय वेळ (ग्वाटेमाला)',
        'America/Guayaquil' => 'इक्वेडोर वेळ (गयाक्विल)',
        'America/Guyana' => 'गयाना वेळ',
        'America/Halifax' => 'अटलांटिक वेळ (हॅलिफॅक्स)',
        'America/Havana' => 'क्यूबा वेळ (हवाना)',
        'America/Hermosillo' => 'मेक्सिको पॅसिफिक वेळ (हर्मोसिलो)',
        'America/Indiana/Knox' => 'केंद्रीय वेळ (नॉक्स, इंडियाना)',
        'America/Indiana/Marengo' => 'पौर्वात्य वेळ (मारेंगो, इंडियाना)',
        'America/Indiana/Petersburg' => 'पौर्वात्य वेळ (पीटर्सबर्ग, इंडियाना)',
        'America/Indiana/Tell_City' => 'केंद्रीय वेळ (टेल सिटी, इंडियाना)',
        'America/Indiana/Vevay' => 'पौर्वात्य वेळ (वेवाय-इंडियाना)',
        'America/Indiana/Vincennes' => 'पौर्वात्य वेळ (विंसेनस, इंडियाना)',
        'America/Indiana/Winamac' => 'पौर्वात्य वेळ (विनमॅक, इंडियाना)',
        'America/Indianapolis' => 'पौर्वात्य वेळ (इंडियानापोलिस)',
        'America/Inuvik' => 'पर्वतीय वेळ (इनुविक)',
        'America/Iqaluit' => 'पौर्वात्य वेळ (इकालुइत)',
        'America/Jamaica' => 'पौर्वात्य वेळ (जमैका)',
        'America/Jujuy' => 'अर्जेंटिना वेळ (जुजुय)',
        'America/Juneau' => 'अलास्का वेळ (ज्यूनौ)',
        'America/Kentucky/Monticello' => 'पौर्वात्य वेळ (माँटिसेलो, केंटुकी)',
        'America/Kralendijk' => 'अटलांटिक वेळ (क्रालेंदिजिक)',
        'America/La_Paz' => 'बोलिव्हिया वेळ (ला पाझ)',
        'America/Lima' => 'पेरु वेळ (लीमा)',
        'America/Los_Angeles' => 'पॅसिफिक वेळ (लॉस एंजेलिस)',
        'America/Louisville' => 'पौर्वात्य वेळ (ल्युइसव्हिल)',
        'America/Lower_Princes' => 'अटलांटिक वेळ (लोअर प्रिन्सस क्वार्टर)',
        'America/Maceio' => 'ब्राझिलिया वेळ (मेसेइओ)',
        'America/Managua' => 'केंद्रीय वेळ (मानागुआ)',
        'America/Manaus' => 'अ‍ॅमेझॉन वेळ (मनौस)',
        'America/Marigot' => 'अटलांटिक वेळ (मेरीगोट)',
        'America/Martinique' => 'अटलांटिक वेळ (मार्टिनिक)',
        'America/Matamoros' => 'केंद्रीय वेळ (माटामोरोस)',
        'America/Mazatlan' => 'मेक्सिको पॅसिफिक वेळ (माझातलान)',
        'America/Mendoza' => 'अर्जेंटिना वेळ (मेंदोझा)',
        'America/Menominee' => 'केंद्रीय वेळ (मेनोमिनी)',
        'America/Merida' => 'केंद्रीय वेळ (मेरिडा)',
        'America/Metlakatla' => 'अलास्का वेळ (मेतलाकतला)',
        'America/Mexico_City' => 'केंद्रीय वेळ (मेक्सिको सिटी)',
        'America/Miquelon' => 'सेंट पियर आणि मिक्वेलोन वेळ',
        'America/Moncton' => 'अटलांटिक वेळ (माँकटन)',
        'America/Monterrey' => 'केंद्रीय वेळ (मॉन्टेरे)',
        'America/Montevideo' => 'उरुग्वे वेळ (मोन्टेव्हिडियो)',
        'America/Montreal' => 'कॅनडा वेळ (Montreal)',
        'America/Montserrat' => 'अटलांटिक वेळ (माँन्टसेरात)',
        'America/Nassau' => 'पौर्वात्य वेळ (नसाऊ)',
        'America/New_York' => 'पौर्वात्य वेळ (न्यूयॉर्क)',
        'America/Nipigon' => 'पौर्वात्य वेळ (निपिगोन)',
        'America/Nome' => 'अलास्का वेळ (नोम)',
        'America/Noronha' => 'फर्नांडो दी नोरोन्हा वेळ',
        'America/North_Dakota/Beulah' => 'केंद्रीय वेळ (ब्युलाह, उत्तर डकोटा)',
        'America/North_Dakota/Center' => 'केंद्रीय वेळ (मध्य, उत्तर डकोटा)',
        'America/North_Dakota/New_Salem' => 'केंद्रीय वेळ (न्यू सालेम, उत्तर डकोटा)',
        'America/Ojinaga' => 'पर्वतीय वेळ (ओजिनागा)',
        'America/Panama' => 'पौर्वात्य वेळ (पनामा)',
        'America/Pangnirtung' => 'पौर्वात्य वेळ (पँगनिरतुंग)',
        'America/Paramaribo' => 'सुरिनाम वेळ (पारमरीबो)',
        'America/Phoenix' => 'पर्वतीय वेळ (फॉनिक्स)',
        'America/Port-au-Prince' => 'पौर्वात्य वेळ (पोर्ट-औ-प्रिंस)',
        'America/Port_of_Spain' => 'अटलांटिक वेळ (पोर्ट ऑफ स्पेन)',
        'America/Porto_Velho' => 'अ‍ॅमेझॉन वेळ (पोर्टो वेल्हो)',
        'America/Puerto_Rico' => 'अटलांटिक वेळ (प्युएर्तो रिको)',
        'America/Punta_Arenas' => 'चिली वेळ (पुंता अरीनास)',
        'America/Rainy_River' => 'केंद्रीय वेळ (रेनी नदी)',
        'America/Rankin_Inlet' => 'केंद्रीय वेळ (रॅनकिन इनलेट)',
        'America/Recife' => 'ब्राझिलिया वेळ (रेसिफे)',
        'America/Regina' => 'केंद्रीय वेळ (रेजिना)',
        'America/Resolute' => 'केंद्रीय वेळ (रेजोल्यूट)',
        'America/Rio_Branco' => 'एकर वेळ (रियो ब्रांको)',
        'America/Santa_Isabel' => 'वायव्य मेक्सिको वेळ (सांता इसाबेल)',
        'America/Santarem' => 'ब्राझिलिया वेळ (सँटारेम)',
        'America/Santiago' => 'चिली वेळ (सॅन्टिएगो)',
        'America/Santo_Domingo' => 'अटलांटिक वेळ (सॅन्टो डोमिंगो)',
        'America/Sao_Paulo' => 'ब्राझिलिया वेळ (साओ पावलो)',
        'America/Scoresbysund' => 'पूर्व ग्रीनलँड वेळ (इटोकॉरटॉर्मीट)',
        'America/Sitka' => 'अलास्का वेळ (सिटका)',
        'America/St_Barthelemy' => 'अटलांटिक वेळ (सेंट बार्थेलेमी)',
        'America/St_Johns' => 'न्यू फाउंडलंड वेळ (सेंट जॉन्स)',
        'America/St_Kitts' => 'अटलांटिक वेळ (सेंट किट्स)',
        'America/St_Lucia' => 'अटलांटिक वेळ (सेंट लुसिया)',
        'America/St_Thomas' => 'अटलांटिक वेळ (सेंट थॉमस)',
        'America/St_Vincent' => 'अटलांटिक वेळ (सेंट विन्सेंट)',
        'America/Swift_Current' => 'केंद्रीय वेळ (स्विफ्ट करंट)',
        'America/Tegucigalpa' => 'केंद्रीय वेळ (टेगुसिगाल्पा)',
        'America/Thule' => 'अटलांटिक वेळ (थुले)',
        'America/Thunder_Bay' => 'पौर्वात्य वेळ (थंडर उपसागर)',
        'America/Tijuana' => 'पॅसिफिक वेळ (तिजुआना)',
        'America/Toronto' => 'पौर्वात्य वेळ (टोरोंटो)',
        'America/Tortola' => 'अटलांटिक वेळ (टोर्टोला)',
        'America/Vancouver' => 'पॅसिफिक वेळ (व्हॅनकुव्हर)',
        'America/Whitehorse' => 'युकोन वेळ (व्हाइटहॉर्स)',
        'America/Winnipeg' => 'केंद्रीय वेळ (विनीपेग)',
        'America/Yakutat' => 'अलास्का वेळ (यकुतात)',
        'America/Yellowknife' => 'पर्वतीय वेळ (यलोनाइफ)',
        'Antarctica/Casey' => 'अंटार्क्टिका वेळ (कॅसे)',
        'Antarctica/Davis' => 'डेव्हिस वेळ',
        'Antarctica/DumontDUrville' => 'ड्युमॉन्ट-ड्युर्विल वेळ',
        'Antarctica/Macquarie' => 'पूर्व ऑस्ट्रेलिया वेळ (मॅक्वायर)',
        'Antarctica/Mawson' => 'मॉसन वेळ',
        'Antarctica/McMurdo' => 'न्यूझीलंड वेळ (मॅक्मुरडो)',
        'Antarctica/Palmer' => 'चिली वेळ (पामेर)',
        'Antarctica/Rothera' => 'रोथेरा वेळ',
        'Antarctica/Syowa' => 'स्योवा वेळ',
        'Antarctica/Troll' => 'ग्रीनिच प्रमाण वेळ (ट्रोल)',
        'Antarctica/Vostok' => 'व्होस्टॉक वेळ (वोस्टोक)',
        'Arctic/Longyearbyen' => 'मध्‍य युरोपियन वेळ (लाँगइयरबीयेन)',
        'Asia/Aden' => 'अरेबियन वेळ (एडेन)',
        'Asia/Almaty' => 'पूर्व कझाकस्तान वेळ (अल्माटी)',
        'Asia/Amman' => 'पूर्व युरोपियन वेळ (अम्मान)',
        'Asia/Anadyr' => 'एनाडीयर वेळ',
        'Asia/Aqtau' => 'पश्चिम कझाकस्तान वेळ (अ‍ॅक्टौ)',
        'Asia/Aqtobe' => 'पश्चिम कझाकस्तान वेळ (अ‍ॅक्टोबे)',
        'Asia/Ashgabat' => 'तुर्कमेनिस्तान वेळ (अश्गाबात)',
        'Asia/Atyrau' => 'पश्चिम कझाकस्तान वेळ (अतिरॉ)',
        'Asia/Baghdad' => 'अरेबियन वेळ (बगदाद)',
        'Asia/Bahrain' => 'अरेबियन वेळ (बेहरीन)',
        'Asia/Baku' => 'अझरबैजान वेळ (बाकु)',
        'Asia/Bangkok' => 'इंडोचायना वेळ (बँकॉक)',
        'Asia/Barnaul' => 'रशिया वेळ (बर्नौल)',
        'Asia/Beirut' => 'पूर्व युरोपियन वेळ (बैरुत)',
        'Asia/Bishkek' => 'किरगिस्तान वेळ (बिश्केक)',
        'Asia/Brunei' => 'ब्रुनेई दारूसलाम वेळ',
        'Asia/Calcutta' => 'भारतीय प्रमाण वेळ (कोलकाता)',
        'Asia/Chita' => 'याकुत्सक वेळ (चिता)',
        'Asia/Choibalsan' => 'उलान बाटोर वेळ (चोईबाल्सन)',
        'Asia/Colombo' => 'भारतीय प्रमाण वेळ (कोलंबो)',
        'Asia/Damascus' => 'पूर्व युरोपियन वेळ (दमास्कस)',
        'Asia/Dhaka' => 'बांगलादेश वेळ (ढाका)',
        'Asia/Dili' => 'पूर्व तिमोर वेळ (डिलि)',
        'Asia/Dubai' => 'खाडी प्रमाण वेळ (दुबई)',
        'Asia/Dushanbe' => 'ताजिकिस्तान वेळ (दुशान्बे)',
        'Asia/Famagusta' => 'पूर्व युरोपियन वेळ (फॅमगुस्ता)',
        'Asia/Gaza' => 'पूर्व युरोपियन वेळ (गाझा)',
        'Asia/Hebron' => 'पूर्व युरोपियन वेळ (हेब्रॉन)',
        'Asia/Hong_Kong' => 'हाँग काँग वेळ (हाँगकाँग)',
        'Asia/Hovd' => 'होव्ह्ड वेळ (होव्ड)',
        'Asia/Irkutsk' => 'इर्कुत्सक वेळ (ईर्कुत्स्क)',
        'Asia/Jakarta' => 'पश्चिमी इंडोनेशिया वेळ (जकार्ता)',
        'Asia/Jayapura' => 'पौर्वात्य इंडोनेशिया वेळ (जयापुरा)',
        'Asia/Jerusalem' => 'इस्रायल (जेरुसलेम)',
        'Asia/Kabul' => 'अफगाणिस्तान वेळ (काबूल)',
        'Asia/Kamchatka' => 'पेट्रोपाव्हलोस्क- कामचाट्स्की वेळ (कॅमचाटका)',
        'Asia/Karachi' => 'पाकिस्तान वेळ (कराची)',
        'Asia/Katmandu' => 'नेपाळ वेळ (काठमांडू)',
        'Asia/Khandyga' => 'याकुत्सक वेळ (खंदिगा)',
        'Asia/Krasnoyarsk' => 'क्रास्नोयार्स्क वेळ',
        'Asia/Kuala_Lumpur' => 'मलेशिया वेळ (क्वालालंपूर)',
        'Asia/Kuching' => 'मलेशिया वेळ (कुचिंग)',
        'Asia/Kuwait' => 'अरेबियन वेळ (कुवेत)',
        'Asia/Macau' => 'चीनी वेळ (मकाऊ)',
        'Asia/Magadan' => 'मॅगाडन वेळ (मेगाडन)',
        'Asia/Makassar' => 'मध्‍य इंडोनेशिया वेळ (मकस्सार)',
        'Asia/Manila' => 'फिलिपाइन वेळ (मनिला)',
        'Asia/Muscat' => 'खाडी प्रमाण वेळ (मस्कत)',
        'Asia/Nicosia' => 'पूर्व युरोपियन वेळ (निकोसिया)',
        'Asia/Novokuznetsk' => 'क्रास्नोयार्स्क वेळ (नोवोकुझ्नेत्स्क)',
        'Asia/Novosibirsk' => 'नोवोसिबिर्स्क वेळ',
        'Asia/Omsk' => 'ओम्स्क वेळ',
        'Asia/Oral' => 'पश्चिम कझाकस्तान वेळ (ओरल)',
        'Asia/Phnom_Penh' => 'इंडोचायना वेळ (प्नोम पेन्ह)',
        'Asia/Pontianak' => 'पश्चिमी इंडोनेशिया वेळ (पाँटियानाक)',
        'Asia/Pyongyang' => 'कोरियन वेळ (प्योंगयांग)',
        'Asia/Qatar' => 'अरेबियन वेळ (कतार)',
        'Asia/Qostanay' => 'पूर्व कझाकस्तान वेळ (कोस्टाने)',
        'Asia/Qyzylorda' => 'पश्चिम कझाकस्तान वेळ (किझीलोर्डा)',
        'Asia/Rangoon' => 'म्यानमार वेळ (रंगून)',
        'Asia/Riyadh' => 'अरेबियन वेळ (रियाध)',
        'Asia/Saigon' => 'इंडोचायना वेळ (हो चि मिन्ह शहर)',
        'Asia/Sakhalin' => 'सखलिन वेळ (साखालिन)',
        'Asia/Samarkand' => 'उझबेकिस्तान वेळ (समरकंद)',
        'Asia/Seoul' => 'कोरियन वेळ (सेउल)',
        'Asia/Shanghai' => 'चीनी वेळ (शांघाय)',
        'Asia/Singapore' => 'सिंगापूर प्रमाण वेळ',
        'Asia/Srednekolymsk' => 'मॅगाडन वेळ (स्रेदनेकोलीम्स्क)',
        'Asia/Taipei' => 'तैपेई वेळ',
        'Asia/Tashkent' => 'उझबेकिस्तान वेळ (ताश्कंद)',
        'Asia/Tbilisi' => 'जॉर्जिया वेळ (बिलिसी)',
        'Asia/Tehran' => 'इराण वेळ (तेहरान)',
        'Asia/Thimphu' => 'भूतान वेळ (थिंफू)',
        'Asia/Tokyo' => 'जपान वेळ (टोकियो)',
        'Asia/Tomsk' => 'रशिया वेळ (तोमसक)',
        'Asia/Ulaanbaatar' => 'उलान बाटोर वेळ (उलानबातर)',
        'Asia/Urumqi' => 'चीन वेळ (उरुम्की)',
        'Asia/Ust-Nera' => 'व्लादिवोस्तोक वेळ (उस्त-नेरा)',
        'Asia/Vientiane' => 'इंडोचायना वेळ (व्हिएन्टाइन)',
        'Asia/Vladivostok' => 'व्लादिवोस्तोक वेळ (व्लादिवोस्टोक)',
        'Asia/Yakutsk' => 'याकुत्सक वेळ (यकुत्स्क)',
        'Asia/Yekaterinburg' => 'येकतरिनबर्ग वेळ (येक्तेरिनबर्ग)',
        'Asia/Yerevan' => 'आर्मेनिया वेळ (येरेवन)',
        'Atlantic/Azores' => 'अ‍ॅझोरेस वेळ (अझोरेस)',
        'Atlantic/Bermuda' => 'अटलांटिक वेळ (बर्मुडा)',
        'Atlantic/Canary' => 'पश्चिम युरोपियन वेळ (कॅनरी)',
        'Atlantic/Cape_Verde' => 'केप व्हर्डे वेळ',
        'Atlantic/Faeroe' => 'पश्चिम युरोपियन वेळ (फॅरो)',
        'Atlantic/Madeira' => 'पश्चिम युरोपियन वेळ (मडीयरा)',
        'Atlantic/Reykjavik' => 'ग्रीनिच प्रमाण वेळ (रेयक्जाविक)',
        'Atlantic/South_Georgia' => 'दक्षिण जॉर्जिया वेळ',
        'Atlantic/St_Helena' => 'ग्रीनिच प्रमाण वेळ (सेंट. हेलेना)',
        'Atlantic/Stanley' => 'फॉकलंड बेटे वेळ (स्टॅनले)',
        'Australia/Adelaide' => 'मध्य ऑस्ट्रेलिया वेळ (एडलेड)',
        'Australia/Brisbane' => 'पूर्व ऑस्ट्रेलिया वेळ (ब्रिस्बेन)',
        'Australia/Broken_Hill' => 'मध्य ऑस्ट्रेलिया वेळ (ब्रोकन हिल)',
        'Australia/Currie' => 'पूर्व ऑस्ट्रेलिया वेळ (कुह्री)',
        'Australia/Darwin' => 'मध्य ऑस्ट्रेलिया वेळ (डार्विन)',
        'Australia/Eucla' => 'ऑस्ट्रेलियन मध्य-पश्चिम वेळ (उक्ला)',
        'Australia/Hobart' => 'पूर्व ऑस्ट्रेलिया वेळ (होबार्ट)',
        'Australia/Lindeman' => 'पूर्व ऑस्ट्रेलिया वेळ (लिंडेमन)',
        'Australia/Lord_Howe' => 'लॉर्ड होवे वेळ',
        'Australia/Melbourne' => 'पूर्व ऑस्ट्रेलिया वेळ (मेलबोर्न)',
        'Australia/Perth' => 'पश्चिम ऑस्ट्रेलिया वेळ (पर्थ)',
        'Australia/Sydney' => 'पूर्व ऑस्ट्रेलिया वेळ (सिडनी)',
        'CST6CDT' => 'केंद्रीय वेळ',
        'EST5EDT' => 'पौर्वात्य वेळ',
        'Etc/GMT' => 'ग्रीनिच प्रमाण वेळ',
        'Etc/UTC' => 'समन्वित वैश्विक वेळ',
        'Europe/Amsterdam' => 'मध्‍य युरोपियन वेळ (अ‍ॅमस्टरडॅम)',
        'Europe/Andorra' => 'मध्‍य युरोपियन वेळ (अँडोरा)',
        'Europe/Astrakhan' => 'मॉस्को वेळ (आस्त्राखान)',
        'Europe/Athens' => 'पूर्व युरोपियन वेळ (अथेन्स)',
        'Europe/Belgrade' => 'मध्‍य युरोपियन वेळ (बेलग्रेड)',
        'Europe/Berlin' => 'मध्‍य युरोपियन वेळ (बर्लिन)',
        'Europe/Bratislava' => 'मध्‍य युरोपियन वेळ (ब्रातिस्लाव्हा)',
        'Europe/Brussels' => 'मध्‍य युरोपियन वेळ (ब्रुसेल्स)',
        'Europe/Bucharest' => 'पूर्व युरोपियन वेळ (बुखारेस्ट)',
        'Europe/Budapest' => 'मध्‍य युरोपियन वेळ (बुडापेस्ट)',
        'Europe/Busingen' => 'मध्‍य युरोपियन वेळ (बुसिंजेन)',
        'Europe/Chisinau' => 'पूर्व युरोपियन वेळ (चिसिनौ)',
        'Europe/Copenhagen' => 'मध्‍य युरोपियन वेळ (कोपेनहेगन)',
        'Europe/Dublin' => 'ग्रीनिच प्रमाण वेळ (डब्लिन)',
        'Europe/Gibraltar' => 'मध्‍य युरोपियन वेळ (जिब्राल्टर)',
        'Europe/Guernsey' => 'ग्रीनिच प्रमाण वेळ (ग्वेर्नसे)',
        'Europe/Helsinki' => 'पूर्व युरोपियन वेळ (हेलसिंकी)',
        'Europe/Isle_of_Man' => 'ग्रीनिच प्रमाण वेळ (आयल ऑफ मॅन)',
        'Europe/Istanbul' => 'तुर्की वेळ (इस्तंबूल)',
        'Europe/Jersey' => 'ग्रीनिच प्रमाण वेळ (जर्सी)',
        'Europe/Kaliningrad' => 'पूर्व युरोपियन वेळ (कलिनिनग्राड)',
        'Europe/Kiev' => 'पूर्व युरोपियन वेळ (कीव)',
        'Europe/Kirov' => 'रशिया वेळ (किरोव)',
        'Europe/Lisbon' => 'पश्चिम युरोपियन वेळ (लिस्बन)',
        'Europe/Ljubljana' => 'मध्‍य युरोपियन वेळ (लुब्लियाना)',
        'Europe/London' => 'ग्रीनिच प्रमाण वेळ (लंडन)',
        'Europe/Luxembourg' => 'मध्‍य युरोपियन वेळ (लक्झेंबर्ग)',
        'Europe/Madrid' => 'मध्‍य युरोपियन वेळ (माद्रिद)',
        'Europe/Malta' => 'मध्‍य युरोपियन वेळ (माल्टा)',
        'Europe/Mariehamn' => 'पूर्व युरोपियन वेळ (मरियेहामेन)',
        'Europe/Minsk' => 'मॉस्को वेळ (मिन्स्क)',
        'Europe/Monaco' => 'मध्‍य युरोपियन वेळ (मोनॅको)',
        'Europe/Moscow' => 'मॉस्को वेळ',
        'Europe/Oslo' => 'मध्‍य युरोपियन वेळ (ऑस्लो)',
        'Europe/Paris' => 'मध्‍य युरोपियन वेळ (पॅरिस)',
        'Europe/Podgorica' => 'मध्‍य युरोपियन वेळ (पॉडगोरिका)',
        'Europe/Prague' => 'मध्‍य युरोपियन वेळ (प्राग)',
        'Europe/Riga' => 'पूर्व युरोपियन वेळ (रिगा)',
        'Europe/Rome' => 'मध्‍य युरोपियन वेळ (रोम)',
        'Europe/Samara' => 'समारा वेळ',
        'Europe/San_Marino' => 'मध्‍य युरोपियन वेळ (सॅन मरिनो)',
        'Europe/Sarajevo' => 'मध्‍य युरोपियन वेळ (साराजेव्हो)',
        'Europe/Saratov' => 'मॉस्को वेळ (सारातोव)',
        'Europe/Simferopol' => 'मॉस्को वेळ (सिम्फरोपोल)',
        'Europe/Skopje' => 'मध्‍य युरोपियन वेळ (स्कॉप्जे)',
        'Europe/Sofia' => 'पूर्व युरोपियन वेळ (सोफिया)',
        'Europe/Stockholm' => 'मध्‍य युरोपियन वेळ (स्टॉकहोम)',
        'Europe/Tallinn' => 'पूर्व युरोपियन वेळ (तालिन)',
        'Europe/Tirane' => 'मध्‍य युरोपियन वेळ (टिराने)',
        'Europe/Ulyanovsk' => 'मॉस्को वेळ (उल्यानोव्स्क)',
        'Europe/Uzhgorod' => 'पूर्व युरोपियन वेळ (उझहोरोड)',
        'Europe/Vaduz' => 'मध्‍य युरोपियन वेळ (वडूझ)',
        'Europe/Vatican' => 'मध्‍य युरोपियन वेळ (व्हॅटिकन)',
        'Europe/Vienna' => 'मध्‍य युरोपियन वेळ (व्हिएन्ना)',
        'Europe/Vilnius' => 'पूर्व युरोपियन वेळ (विलनियस)',
        'Europe/Volgograd' => 'व्होल्गोग्राड वेळ',
        'Europe/Warsaw' => 'मध्‍य युरोपियन वेळ (वॉर्सा)',
        'Europe/Zagreb' => 'मध्‍य युरोपियन वेळ (झॅग्रेब)',
        'Europe/Zaporozhye' => 'पूर्व युरोपियन वेळ (झापोरोझे)',
        'Europe/Zurich' => 'मध्‍य युरोपियन वेळ (झुरिक)',
        'Indian/Antananarivo' => 'पूर्व आफ्रिका वेळ (अंटानानारिवो)',
        'Indian/Chagos' => 'हिंदमहासागर वेळ (चागोस)',
        'Indian/Christmas' => 'ख्रिसमस बेट वेळ',
        'Indian/Cocos' => 'कॉकोस बेटे वेळ (कोकोस)',
        'Indian/Comoro' => 'पूर्व आफ्रिका वेळ (कोमोरो)',
        'Indian/Kerguelen' => 'फ्रेंच दक्षिण आणि अंटार्क्टिक वेळ (करग्यूलेन)',
        'Indian/Mahe' => 'सेशेल्स वेळ (माहे)',
        'Indian/Maldives' => 'मालदिव वेळ (मालदीव)',
        'Indian/Mauritius' => 'मॉरीशस वेळ (मॉरिशस)',
        'Indian/Mayotte' => 'पूर्व आफ्रिका वेळ (मायोट्टे)',
        'Indian/Reunion' => 'रियुनियन वेळ',
        'MST7MDT' => 'पर्वतीय वेळ',
        'PST8PDT' => 'पॅसिफिक वेळ',
        'Pacific/Apia' => 'एपिया वेळ (अपिया)',
        'Pacific/Auckland' => 'न्यूझीलंड वेळ (ऑकलंड)',
        'Pacific/Bougainville' => 'पापुआ न्यू गिनी वेळ (बॉगॅनव्हिल)',
        'Pacific/Chatham' => 'चॅथम वेळ (चॅटहॅम)',
        'Pacific/Easter' => 'इस्टर बेट वेळ (ईस्टर)',
        'Pacific/Efate' => 'वानुआतु वेळ (इफेट)',
        'Pacific/Enderbury' => '‍फोनिक्स बेटे वेळ (एंडरबरी)',
        'Pacific/Fakaofo' => 'टोकेलाऊ वेळ (फाकाओफो)',
        'Pacific/Fiji' => 'फिजी वेळ',
        'Pacific/Funafuti' => 'तुवालू वेळ (फुनाफुती)',
        'Pacific/Galapagos' => 'गॅलापागोस वेळ',
        'Pacific/Gambier' => 'गॅम्बियर वेळ',
        'Pacific/Guadalcanal' => 'सोलोमॉन बेटे वेळ (ग्वाडलकनाल)',
        'Pacific/Guam' => 'चामोरो प्रमाण वेळ (गुआम)',
        'Pacific/Honolulu' => 'हवाई-अलूशन वेळ (होनोलुलू)',
        'Pacific/Johnston' => 'हवाई-अलूशन वेळ (जोहान्स्टन)',
        'Pacific/Kiritimati' => 'लाइन बेटे वेळ (किरितिमाती)',
        'Pacific/Kosrae' => 'कोस्राई वेळ (कोशाय)',
        'Pacific/Kwajalein' => 'मार्शल बेटे वेळ (क्वाजालेईन)',
        'Pacific/Majuro' => 'मार्शल बेटे वेळ (मजुरो)',
        'Pacific/Marquesas' => 'मार्क्वेसास वेळ (मारक्विसास)',
        'Pacific/Midway' => 'सामोआ वेळ (मिडवे)',
        'Pacific/Nauru' => 'नउरु वेळ',
        'Pacific/Niue' => 'न्युए वेळ',
        'Pacific/Norfolk' => 'नॉरफोक बेट वेळ',
        'Pacific/Noumea' => 'न्यू कॅलेडोनिया वेळ (नौमिआ)',
        'Pacific/Pago_Pago' => 'सामोआ वेळ (पॅगो पॅगो)',
        'Pacific/Palau' => 'पलाऊ वेळ',
        'Pacific/Pitcairn' => 'पिटकैर्न वेळ (पिटकेर्न)',
        'Pacific/Ponape' => 'पोनॅपे वेळ (पोनपेई)',
        'Pacific/Port_Moresby' => 'पापुआ न्यू गिनी वेळ (पोर्ट मोरेस्बे)',
        'Pacific/Rarotonga' => 'कुक बेटे वेळ (रारोटोंगा)',
        'Pacific/Saipan' => 'चामोरो प्रमाण वेळ (सैपान)',
        'Pacific/Tahiti' => 'ताहिती वेळ',
        'Pacific/Tarawa' => 'गिल्बर्ट बेटे वेळ (तारावा)',
        'Pacific/Tongatapu' => 'टोंगा वेळ (टोंगाटापू)',
        'Pacific/Truk' => 'चूक वेळ',
        'Pacific/Wake' => 'वेक बेट वेळ',
        'Pacific/Wallis' => 'वॉलिस आणि फुटुना वेळ (वालिस)',
    ],
    'Meta' => [
        'GmtFormat' => '[GMT]%s',
    ],
];
