<?php

return [
    'Names' => [
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Gaana)',
        'am' => 'Amarik',
        'am_ET' => 'Amarik (Ithiopia)',
        'ar' => 'Arabik',
        'ar_AE' => 'Arabik (United Arab Emirates)',
        'ar_BH' => 'Arabik (Baren)',
        'ar_DJ' => 'Arabik (Gyibuti)',
        'ar_DZ' => 'Arabik (Ɔlgyeria)',
        'ar_EG' => 'Arabik (Nisrim)',
        'ar_ER' => 'Arabik (Ɛritrea)',
        'ar_IL' => 'Arabik (Israel)',
        'ar_IQ' => 'Arabik (Irak)',
        'ar_JO' => 'Arabik (Gyɔdan)',
        'ar_KM' => 'Arabik (Kɔmɔrɔs)',
        'ar_KW' => 'Arabik (Kuwete)',
        'ar_LB' => 'Arabik (Lɛbanɔn)',
        'ar_LY' => 'Arabik (Libya)',
        'ar_MA' => 'Arabik (Moroko)',
        'ar_MR' => 'Arabik (Mɔretenia)',
        'ar_OM' => 'Arabik (Oman)',
        'ar_PS' => 'Arabik (Palestaen West Bank ne Gaza)',
        'ar_QA' => 'Arabik (Kata)',
        'ar_SA' => 'Arabik (Saudi Arabia)',
        'ar_SD' => 'Arabik (Sudan)',
        'ar_SO' => 'Arabik (Somalia)',
        'ar_SY' => 'Arabik (Siria)',
        'ar_TD' => 'Arabik (Kyad)',
        'ar_TN' => 'Arabik (Tunihyia)',
        'ar_YE' => 'Arabik (Yɛmen)',
        'be' => 'Belarus kasa',
        'be_BY' => 'Belarus kasa (Bɛlarus)',
        'bg' => 'Bɔlgeria kasa',
        'bg_BG' => 'Bɔlgeria kasa (Bɔlgeria)',
        'bn' => 'Bengali kasa',
        'bn_BD' => 'Bengali kasa (Bangladɛhye)',
        'bn_IN' => 'Bengali kasa (India)',
        'cs' => 'Kyɛk kasa',
        'cs_CZ' => 'Kyɛk kasa (Kyɛk Kurokɛse)',
        'de' => 'Gyaaman',
        'de_AT' => 'Gyaaman (Ɔstria)',
        'de_BE' => 'Gyaaman (Bɛlgyium)',
        'de_CH' => 'Gyaaman (Swetzaland)',
        'de_DE' => 'Gyaaman (Gyaaman)',
        'de_IT' => 'Gyaaman (Itali)',
        'de_LI' => 'Gyaaman (Lektenstaen)',
        'de_LU' => 'Gyaaman (Laksembɛg)',
        'el' => 'Greek kasa',
        'el_CY' => 'Greek kasa (Saeprɔs)',
        'el_GR' => 'Greek kasa (Greekman)',
        'en' => 'Borɔfo',
        'en_AE' => 'Borɔfo (United Arab Emirates)',
        'en_AG' => 'Borɔfo (Antigua ne Baabuda)',
        'en_AI' => 'Borɔfo (Anguila)',
        'en_AS' => 'Borɔfo (Amɛrika Samoa)',
        'en_AT' => 'Borɔfo (Ɔstria)',
        'en_AU' => 'Borɔfo (Ɔstrelia)',
        'en_BB' => 'Borɔfo (Baabados)',
        'en_BE' => 'Borɔfo (Bɛlgyium)',
        'en_BI' => 'Borɔfo (Burundi)',
        'en_BM' => 'Borɔfo (Bɛmuda)',
        'en_BS' => 'Borɔfo (Bahama)',
        'en_BW' => 'Borɔfo (Bɔtswana)',
        'en_BZ' => 'Borɔfo (Beliz)',
        'en_CA' => 'Borɔfo (Kanada)',
        'en_CH' => 'Borɔfo (Swetzaland)',
        'en_CK' => 'Borɔfo (Kook Nsupɔw)',
        'en_CM' => 'Borɔfo (Kamɛrun)',
        'en_CY' => 'Borɔfo (Saeprɔs)',
        'en_DE' => 'Borɔfo (Gyaaman)',
        'en_DK' => 'Borɔfo (Dɛnmak)',
        'en_DM' => 'Borɔfo (Dɔmeneka)',
        'en_ER' => 'Borɔfo (Ɛritrea)',
        'en_FI' => 'Borɔfo (Finland)',
        'en_FJ' => 'Borɔfo (Figyi)',
        'en_FK' => 'Borɔfo (Fɔlkman Aeland)',
        'en_FM' => 'Borɔfo (Maekronehyia)',
        'en_GB' => 'Borɔfo (Ahendiman Nkabom)',
        'en_GD' => 'Borɔfo (Grenada)',
        'en_GH' => 'Borɔfo (Gaana)',
        'en_GI' => 'Borɔfo (Gyebralta)',
        'en_GM' => 'Borɔfo (Gambia)',
        'en_GU' => 'Borɔfo (Guam)',
        'en_GY' => 'Borɔfo (Gayana)',
        'en_IE' => 'Borɔfo (Aereland)',
        'en_IL' => 'Borɔfo (Israel)',
        'en_IN' => 'Borɔfo (India)',
        'en_IO' => 'Borɔfo (Britenfo Hɔn Man Wɔ India Po No Mu)',
        'en_JM' => 'Borɔfo (Gyameka)',
        'en_KE' => 'Borɔfo (Kɛnya)',
        'en_KI' => 'Borɔfo (Kiribati)',
        'en_KN' => 'Borɔfo (Saint Kitts ne Nɛves)',
        'en_KY' => 'Borɔfo (Kemanfo Islands)',
        'en_LC' => 'Borɔfo (Saint Lucia)',
        'en_LR' => 'Borɔfo (Laeberia)',
        'en_LS' => 'Borɔfo (Lɛsutu)',
        'en_MG' => 'Borɔfo (Madagaska)',
        'en_MH' => 'Borɔfo (Marshall Islands)',
        'en_MP' => 'Borɔfo (Northern Mariana Islands)',
        'en_MS' => 'Borɔfo (Mantserat)',
        'en_MT' => 'Borɔfo (Mɔlta)',
        'en_MU' => 'Borɔfo (Mɔrehyeɔs)',
        'en_MV' => 'Borɔfo (Maldives)',
        'en_MW' => 'Borɔfo (Malawi)',
        'en_MY' => 'Borɔfo (Malehyia)',
        'en_NA' => 'Borɔfo (Namibia)',
        'en_NF' => 'Borɔfo (Nɔfolk Aeland)',
        'en_NG' => 'Borɔfo (Naegyeria)',
        'en_NL' => 'Borɔfo (Nɛdɛland)',
        'en_NR' => 'Borɔfo (Naworu)',
        'en_NU' => 'Borɔfo (Niyu)',
        'en_NZ' => 'Borɔfo (Ziland Foforo)',
        'en_PG' => 'Borɔfo (Papua Guinea Foforo)',
        'en_PH' => 'Borɔfo (Philippines)',
        'en_PK' => 'Borɔfo (Pakistan)',
        'en_PN' => 'Borɔfo (Pitcairn)',
        'en_PR' => 'Borɔfo (Puɛto Riko)',
        'en_PW' => 'Borɔfo (Palau)',
        'en_RW' => 'Borɔfo (Rwanda)',
        'en_SB' => 'Borɔfo (Solomon Islands)',
        'en_SC' => 'Borɔfo (Seyhyɛl)',
        'en_SD' => 'Borɔfo (Sudan)',
        'en_SE' => 'Borɔfo (Sweden)',
        'en_SG' => 'Borɔfo (Singapɔ)',
        'en_SH' => 'Borɔfo (Saint Helena)',
        'en_SI' => 'Borɔfo (Slovinia)',
        'en_SL' => 'Borɔfo (Sierra Leone)',
        'en_SZ' => 'Borɔfo (Swaziland)',
        'en_TC' => 'Borɔfo (Turks ne Caicos Islands)',
        'en_TK' => 'Borɔfo (Tokelau)',
        'en_TO' => 'Borɔfo (Tonga)',
        'en_TT' => 'Borɔfo (Trinidad ne Tobago)',
        'en_TV' => 'Borɔfo (Tuvalu)',
        'en_TZ' => 'Borɔfo (Tanzania)',
        'en_UG' => 'Borɔfo (Uganda)',
        'en_US' => 'Borɔfo (Amɛrika)',
        'en_VC' => 'Borɔfo (Saint Vincent ne Grenadines)',
        'en_VG' => 'Borɔfo (Britainfo Virgin Islands)',
        'en_VI' => 'Borɔfo (Amɛrika Virgin Islands)',
        'en_VU' => 'Borɔfo (Vanuatu)',
        'en_WS' => 'Borɔfo (Samoa)',
        'en_ZA' => 'Borɔfo (Afrika Anaafo)',
        'en_ZM' => 'Borɔfo (Zambia)',
        'en_ZW' => 'Borɔfo (Zembabwe)',
        'es' => 'Spain kasa',
        'es_AR' => 'Spain kasa (Agyɛntina)',
        'es_BO' => 'Spain kasa (Bolivia)',
        'es_BR' => 'Spain kasa (Brazil)',
        'es_BZ' => 'Spain kasa (Beliz)',
        'es_CL' => 'Spain kasa (Kyili)',
        'es_CO' => 'Spain kasa (Kolombia)',
        'es_CR' => 'Spain kasa (Kɔsta Rika)',
        'es_CU' => 'Spain kasa (Kuba)',
        'es_DO' => 'Spain kasa (Dɔmeneka Kurokɛse)',
        'es_EC' => 'Spain kasa (Ikuwadɔ)',
        'es_ES' => 'Spain kasa (Spain)',
        'es_GQ' => 'Spain kasa (Gini Ikuweta)',
        'es_GT' => 'Spain kasa (Guwatemala)',
        'es_HN' => 'Spain kasa (Hɔnduras)',
        'es_MX' => 'Spain kasa (Mɛksiko)',
        'es_NI' => 'Spain kasa (Nekaraguwa)',
        'es_PA' => 'Spain kasa (Panama)',
        'es_PE' => 'Spain kasa (Peru)',
        'es_PH' => 'Spain kasa (Philippines)',
        'es_PR' => 'Spain kasa (Puɛto Riko)',
        'es_PY' => 'Spain kasa (Paraguay)',
        'es_SV' => 'Spain kasa (Ɛl Salvadɔ)',
        'es_US' => 'Spain kasa (Amɛrika)',
        'es_UY' => 'Spain kasa (Yurugwae)',
        'es_VE' => 'Spain kasa (Venezuela)',
        'fa' => 'Pɛɛhyia kasa',
        'fa_AF' => 'Pɛɛhyia kasa (Afganistan)',
        'fa_IR' => 'Pɛɛhyia kasa (Iran)',
        'fr' => 'Frɛnkye',
        'fr_BE' => 'Frɛnkye (Bɛlgyium)',
        'fr_BF' => 'Frɛnkye (Bɔkina Faso)',
        'fr_BI' => 'Frɛnkye (Burundi)',
        'fr_BJ' => 'Frɛnkye (Bɛnin)',
        'fr_CA' => 'Frɛnkye (Kanada)',
        'fr_CD' => 'Frɛnkye (Kongo [Zair])',
        'fr_CF' => 'Frɛnkye (Afrika Finimfin Man)',
        'fr_CG' => 'Frɛnkye (Kongo)',
        'fr_CH' => 'Frɛnkye (Swetzaland)',
        'fr_CI' => 'Frɛnkye (La Côte d’Ivoire)',
        'fr_CM' => 'Frɛnkye (Kamɛrun)',
        'fr_DJ' => 'Frɛnkye (Gyibuti)',
        'fr_DZ' => 'Frɛnkye (Ɔlgyeria)',
        'fr_FR' => 'Frɛnkye (Frɛnkyeman)',
        'fr_GA' => 'Frɛnkye (Gabɔn)',
        'fr_GF' => 'Frɛnkye (Frɛnkye Gayana)',
        'fr_GN' => 'Frɛnkye (Gini)',
        'fr_GP' => 'Frɛnkye (Guwadelup)',
        'fr_GQ' => 'Frɛnkye (Gini Ikuweta)',
        'fr_HT' => 'Frɛnkye (Heiti)',
        'fr_KM' => 'Frɛnkye (Kɔmɔrɔs)',
        'fr_LU' => 'Frɛnkye (Laksembɛg)',
        'fr_MA' => 'Frɛnkye (Moroko)',
        'fr_MC' => 'Frɛnkye (Mɔnako)',
        'fr_MG' => 'Frɛnkye (Madagaska)',
        'fr_ML' => 'Frɛnkye (Mali)',
        'fr_MQ' => 'Frɛnkye (Matinik)',
        'fr_MR' => 'Frɛnkye (Mɔretenia)',
        'fr_MU' => 'Frɛnkye (Mɔrehyeɔs)',
        'fr_NC' => 'Frɛnkye (Kaledonia Foforo)',
        'fr_NE' => 'Frɛnkye (Nigyɛ)',
        'fr_PF' => 'Frɛnkye (Frɛnkye Pɔlenehyia)',
        'fr_PM' => 'Frɛnkye (Saint Pierre ne Miquelon)',
        'fr_RE' => 'Frɛnkye (Reyuniɔn)',
        'fr_RW' => 'Frɛnkye (Rwanda)',
        'fr_SC' => 'Frɛnkye (Seyhyɛl)',
        'fr_SN' => 'Frɛnkye (Senegal)',
        'fr_SY' => 'Frɛnkye (Siria)',
        'fr_TD' => 'Frɛnkye (Kyad)',
        'fr_TG' => 'Frɛnkye (Togo)',
        'fr_TN' => 'Frɛnkye (Tunihyia)',
        'fr_VU' => 'Frɛnkye (Vanuatu)',
        'fr_WF' => 'Frɛnkye (Wallis ne Futuna)',
        'fr_YT' => 'Frɛnkye (Mayɔte)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Gaana)',
        'ha_NE' => 'Hausa (Nigyɛ)',
        'ha_NG' => 'Hausa (Naegyeria)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hu' => 'Hangri kasa',
        'hu_HU' => 'Hangri kasa (Hangari)',
        'id' => 'Indonihyia kasa',
        'id_ID' => 'Indonihyia kasa (Indɔnehyia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Naegyeria)',
        'it' => 'Italy kasa',
        'it_CH' => 'Italy kasa (Swetzaland)',
        'it_IT' => 'Italy kasa (Itali)',
        'it_SM' => 'Italy kasa (San Marino)',
        'it_VA' => 'Italy kasa (Vatican Man)',
        'ja' => 'Gyapan kasa',
        'ja_JP' => 'Gyapan kasa (Gyapan)',
        'jv' => 'Gyabanis kasa',
        'jv_ID' => 'Gyabanis kasa (Indɔnehyia)',
        'km' => 'Kambodia kasa',
        'km_KH' => 'Kambodia kasa (Kambodia)',
        'ko' => 'Korea kasa',
        'ko_KP' => 'Korea kasa (Etifi Koria)',
        'ko_KR' => 'Korea kasa (Anaafo Koria)',
        'ms' => 'Malay kasa',
        'ms_BN' => 'Malay kasa (Brunae)',
        'ms_ID' => 'Malay kasa (Indɔnehyia)',
        'ms_MY' => 'Malay kasa (Malehyia)',
        'ms_SG' => 'Malay kasa (Singapɔ)',
        'my' => 'Bɛɛmis kasa',
        'my_MM' => 'Bɛɛmis kasa (Miyanma)',
        'ne' => 'Nɛpal kasa',
        'ne_IN' => 'Nɛpal kasa (India)',
        'ne_NP' => 'Nɛpal kasa (Nɛpɔl)',
        'nl' => 'Dɛɛkye',
        'nl_AW' => 'Dɛɛkye (Aruba)',
        'nl_BE' => 'Dɛɛkye (Bɛlgyium)',
        'nl_NL' => 'Dɛɛkye (Nɛdɛland)',
        'nl_SR' => 'Dɛɛkye (Suriname)',
        'pa' => 'Pungyabi kasa',
        'pa_IN' => 'Pungyabi kasa (India)',
        'pa_PK' => 'Pungyabi kasa (Pakistan)',
        'pl' => 'Pɔland kasa',
        'pl_PL' => 'Pɔland kasa (Poland)',
        'pt' => 'Pɔɔtugal kasa',
        'pt_AO' => 'Pɔɔtugal kasa (Angola)',
        'pt_BR' => 'Pɔɔtugal kasa (Brazil)',
        'pt_CH' => 'Pɔɔtugal kasa (Swetzaland)',
        'pt_CV' => 'Pɔɔtugal kasa (Kepvɛdfo Islands)',
        'pt_GQ' => 'Pɔɔtugal kasa (Gini Ikuweta)',
        'pt_GW' => 'Pɔɔtugal kasa (Gini Bisaw)',
        'pt_LU' => 'Pɔɔtugal kasa (Laksembɛg)',
        'pt_MZ' => 'Pɔɔtugal kasa (Mozambik)',
        'pt_PT' => 'Pɔɔtugal kasa (Pɔtugal)',
        'pt_ST' => 'Pɔɔtugal kasa (São Tomé and Príncipe)',
        'pt_TL' => 'Pɔɔtugal kasa (Timɔ Boka)',
        'ro' => 'Romenia kasa',
        'ro_MD' => 'Romenia kasa (Mɔldova)',
        'ro_RO' => 'Romenia kasa (Romenia)',
        'ru' => 'Rahyia kasa',
        'ru_BY' => 'Rahyia kasa (Bɛlarus)',
        'ru_KG' => 'Rahyia kasa (Kɛɛgestan)',
        'ru_KZ' => 'Rahyia kasa (Kazakstan)',
        'ru_MD' => 'Rahyia kasa (Mɔldova)',
        'ru_RU' => 'Rahyia kasa (Rɔhyea)',
        'ru_UA' => 'Rahyia kasa (Ukren)',
        'rw' => 'Rewanda kasa',
        'rw_RW' => 'Rewanda kasa (Rwanda)',
        'so' => 'Somalia kasa',
        'so_DJ' => 'Somalia kasa (Gyibuti)',
        'so_ET' => 'Somalia kasa (Ithiopia)',
        'so_KE' => 'Somalia kasa (Kɛnya)',
        'so_SO' => 'Somalia kasa (Somalia)',
        'sv' => 'Sweden kasa',
        'sv_FI' => 'Sweden kasa (Finland)',
        'sv_SE' => 'Sweden kasa (Sweden)',
        'ta' => 'Tamil kasa',
        'ta_IN' => 'Tamil kasa (India)',
        'ta_LK' => 'Tamil kasa (Sri Lanka)',
        'ta_MY' => 'Tamil kasa (Malehyia)',
        'ta_SG' => 'Tamil kasa (Singapɔ)',
        'th' => 'Taeland kasa',
        'th_TH' => 'Taeland kasa (Taeland)',
        'tr' => 'Tɛɛki kasa',
        'tr_CY' => 'Tɛɛki kasa (Saeprɔs)',
        'tr_TR' => 'Tɛɛki kasa (Tɛɛki)',
        'uk' => 'Ukren kasa',
        'uk_UA' => 'Ukren kasa (Ukren)',
        'ur' => 'Urdu kasa',
        'ur_IN' => 'Urdu kasa (India)',
        'ur_PK' => 'Urdu kasa (Pakistan)',
        'vi' => 'Viɛtnam kasa',
        'vi_VN' => 'Viɛtnam kasa (Viɛtnam)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Bɛnin)',
        'yo_NG' => 'Yoruba (Naegyeria)',
        'zh' => 'Kyaena kasa',
        'zh_CN' => 'Kyaena kasa (Kyaena)',
        'zh_SG' => 'Kyaena kasa (Singapɔ)',
        'zh_TW' => 'Kyaena kasa (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Afrika Anaafo)',
    ],
];
