<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'дырхам ААЭ',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'афганскі афгані',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'албанскі лек',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'армянскі драм',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'нідэрландскі антыльскі гульдэн',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'ангольская кванза',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'аргенцінскае песа',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'аўстралійскі долар',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'арубанскі фларын',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'азербайджанскі манат',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'канверсоўная марка Босніі і Герцагавіны',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'барбадаскі долар',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'бангладэшская така',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'балгарскі леў',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'бахрэйнскі дынар',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'бурундзійскі франк',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'бермудскі долар',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'брунейскі долар',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'балівіяна',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'бразільскі рэал',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'багамскі долар',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'бутанскі нгултрум',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'батсванская пула',
        ],
        'BYN' => [
            0 => 'Br',
            1 => 'беларускі рубель',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'беларускі рубель (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'белізскі долар',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'канадскі долар',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'кангалезскі франк',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'швейцарскі франк',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'чылійскае песа',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'афшорны кітайскі юань',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'кітайскі юань',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'калумбійскае песа',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'коста-рыканскі калон',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'кубінскае канверсоўнае песа',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'кубінскае песа',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'эскуда Каба-Вердэ',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'чэшская крона',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'джыбуційскі франк',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'дацкая крона',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'дамініканскае песа',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'алжырскі дынар',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'егіпецкі фунт',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'эрытрэйская накфа',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'эфіопскі быр',
        ],
        'EUR' => [
            0 => '€',
            1 => 'еўра',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'фіджыйскі долар',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'фунт Фалклендскіх астравоў',
        ],
        'GBP' => [
            0 => '£',
            1 => 'брытанскі фунт стэрлінгаў',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'грузінскі лары',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'ганскі седзі',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'гібралтарскі фунт',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'гамбійскі даласі',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'гвінейскі франк',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'гватэмальскі кетсаль',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'гаянскі долар',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'ганконгскі долар',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'гандураская лемпіра',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'харвацкая куна',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'гаіцянскі гурд',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'венгерскі форынт',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'інданезійская рупія',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'новы ізраільскі шэкель',
        ],
        'INR' => [
            0 => '₹',
            1 => 'індыйская рупія',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'іракскі дынар',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'іранскі рыял',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'ісландская крона',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'ямайскі долар',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'іарданскі дынар',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'японская іена',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'кенійскі шылінг',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'кіргізскі сом',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'камбаджыйскі рыель',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'каморскі франк',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'паўночнакарэйская вона',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'паўднёвакарэйская вона',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'кувейцкі дынар',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'долар Кайманавых астравоў',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'казахстанскі тэнге',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'лаоскі кіп',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'ліванскі фунт',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'шры-ланкійская рупія',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'ліберыйскі долар',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'лесоцкі лоці',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'лівійскі дынар',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'мараканскі дырхам',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'малдаўскі лей',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'малагасійскі арыяры',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'македонскі дэнар',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'м’янманскі к’ят',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'мангольскі тугрык',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'патака Макаа',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'маўрытанская ўгія (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'маўрытанская угія',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'маўрыкійская рупія',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'мальдыўская руфія',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'малавійская квача',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'мексіканскае песа',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'малайзійскі рынгіт',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'мазамбікскі метыкал',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'намібійскі долар',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'нігерыйская наіра',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'нікарагуанская кордаба',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'нарвежская крона',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'непальская рупія',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'новазеландскі долар',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'аманскі рыял',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'панамскае бальбоа',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'перуанскі соль',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'кіна Папуа-Новай Гвінеі',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'філіпінскае песа',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'пакістанская рупія',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'польскі злоты',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'парагвайскі гуарані',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'катарскі рыял',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'румынскі лей',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'сербскі дынар',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'расійскі рубель',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'руандыйскі франк',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'саудаўскі рыял',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'долар Саламонавых астравоў',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'сейшэльская рупія',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'суданскі фунт',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'шведская крона',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'сінгапурскі долар',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'фунт в-ва Святой Алены',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'сьера-леонскі леонэ',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'самалійскі шылінг',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'сурынамскі долар',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'паўднёвасуданскі фунт',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'добра Сан-Тамэ і Прынсіпі (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'добра Сан-Тамэ і Прынсіпі',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'сірыйскі фунт',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'свазілендскі лілангені',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'тайскі бат',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'таджыкскі самані',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'туркменскі манат',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'туніскі дынар',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'танганская паанга',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'турэцкая ліра',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'долар Трынідада і Табага',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'новы тайваньскі долар',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'танзанійскі шылінг',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'украінская грыўня',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'угандыйскі шылінг',
        ],
        'USD' => [
            0 => '$',
            1 => 'долар ЗША',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'уругвайскае песа',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'узбекскі сум',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'венесуальскі балівар (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'венесуэльскі балівар',
        ],
        'VND' => [
            0 => '₫',
            1 => 'в’етнамскі донг',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'вануацкі вату',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'самаанская тала',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'цэнтральнаафрыканскі франк КФА',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'усходнекарыбскі долар',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'заходнеафрыканскі франк КФА',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'французскі ціхаакіянскі франк',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'еменскі рыал',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'паўднёваафрыканскі рэнд',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'замбійская квача',
        ],
    ],
];
