<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (Südafrika)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amharisch',
        'am_ET' => 'Amharisch (Äthiopien)',
        'ar' => 'Arabisch',
        'ar_001' => 'Arabisch (Welt)',
        'ar_AE' => 'Arabisch (Vereinigte Arabische Emirate)',
        'ar_BH' => 'Arabisch (Bahrain)',
        'ar_DJ' => 'Arabisch (Dschibuti)',
        'ar_DZ' => 'Arabisch (Algerien)',
        'ar_EG' => 'Arabisch (Ägypten)',
        'ar_EH' => 'Arabisch (Westsahara)',
        'ar_ER' => 'Arabisch (Eritrea)',
        'ar_IL' => 'Arabisch (Israel)',
        'ar_IQ' => 'Arabisch (Irak)',
        'ar_JO' => 'Arabisch (Jordanien)',
        'ar_KM' => 'Arabisch (Komoren)',
        'ar_KW' => 'Arabisch (Kuwait)',
        'ar_LB' => 'Arabisch (Libanon)',
        'ar_LY' => 'Arabisch (Libyen)',
        'ar_MA' => 'Arabisch (Marokko)',
        'ar_MR' => 'Arabisch (Mauretanien)',
        'ar_OM' => 'Arabisch (Oman)',
        'ar_PS' => 'Arabisch (Palästinensische Autonomiegebiete)',
        'ar_QA' => 'Arabisch (Katar)',
        'ar_SA' => 'Arabisch (Saudi-Arabien)',
        'ar_SD' => 'Arabisch (Sudan)',
        'ar_SO' => 'Arabisch (Somalia)',
        'ar_SS' => 'Arabisch (Südsudan)',
        'ar_SY' => 'Arabisch (Syrien)',
        'ar_TD' => 'Arabisch (Tschad)',
        'ar_TN' => 'Arabisch (Tunesien)',
        'ar_YE' => 'Arabisch (Jemen)',
        'as' => 'Assamesisch',
        'as_IN' => 'Assamesisch (Indien)',
        'az' => 'Aserbaidschanisch',
        'az_AZ' => 'Aserbaidschanisch (Aserbaidschan)',
        'az_Cyrl' => 'Aserbaidschanisch (Kyrillisch)',
        'az_Cyrl_AZ' => 'Aserbaidschanisch (Kyrillisch, Aserbaidschan)',
        'az_Latn' => 'Aserbaidschanisch (Lateinisch)',
        'az_Latn_AZ' => 'Aserbaidschanisch (Lateinisch, Aserbaidschan)',
        'be' => 'Belarussisch',
        'be_BY' => 'Belarussisch (Belarus)',
        'bg' => 'Bulgarisch',
        'bg_BG' => 'Bulgarisch (Bulgarien)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengalisch',
        'bn_BD' => 'Bengalisch (Bangladesch)',
        'bn_IN' => 'Bengalisch (Indien)',
        'bo' => 'Tibetisch',
        'bo_CN' => 'Tibetisch (China)',
        'bo_IN' => 'Tibetisch (Indien)',
        'br' => 'Bretonisch',
        'br_FR' => 'Bretonisch (Frankreich)',
        'bs' => 'Bosnisch',
        'bs_BA' => 'Bosnisch (Bosnien und Herzegowina)',
        'bs_Cyrl' => 'Bosnisch (Kyrillisch)',
        'bs_Cyrl_BA' => 'Bosnisch (Kyrillisch, Bosnien und Herzegowina)',
        'bs_Latn' => 'Bosnisch (Lateinisch)',
        'bs_Latn_BA' => 'Bosnisch (Lateinisch, Bosnien und Herzegowina)',
        'ca' => 'Katalanisch',
        'ca_AD' => 'Katalanisch (Andorra)',
        'ca_ES' => 'Katalanisch (Spanien)',
        'ca_FR' => 'Katalanisch (Frankreich)',
        'ca_IT' => 'Katalanisch (Italien)',
        'ce' => 'Tschetschenisch',
        'ce_RU' => 'Tschetschenisch (Russland)',
        'cs' => 'Tschechisch',
        'cs_CZ' => 'Tschechisch (Tschechien)',
        'cv' => 'Tschuwaschisch',
        'cv_RU' => 'Tschuwaschisch (Russland)',
        'cy' => 'Walisisch',
        'cy_GB' => 'Walisisch (Vereinigtes Königreich)',
        'da' => 'Dänisch',
        'da_DK' => 'Dänisch (Dänemark)',
        'da_GL' => 'Dänisch (Grönland)',
        'de' => 'Deutsch',
        'de_AT' => 'Deutsch (Österreich)',
        'de_BE' => 'Deutsch (Belgien)',
        'de_CH' => 'Deutsch (Schweiz)',
        'de_DE' => 'Deutsch (Deutschland)',
        'de_IT' => 'Deutsch (Italien)',
        'de_LI' => 'Deutsch (Liechtenstein)',
        'de_LU' => 'Deutsch (Luxemburg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Griechisch',
        'el_CY' => 'Griechisch (Zypern)',
        'el_GR' => 'Griechisch (Griechenland)',
        'en' => 'Englisch',
        'en_001' => 'Englisch (Welt)',
        'en_150' => 'Englisch (Europa)',
        'en_AE' => 'Englisch (Vereinigte Arabische Emirate)',
        'en_AG' => 'Englisch (Antigua und Barbuda)',
        'en_AI' => 'Englisch (Anguilla)',
        'en_AS' => 'Englisch (Amerikanisch-Samoa)',
        'en_AT' => 'Englisch (Österreich)',
        'en_AU' => 'Englisch (Australien)',
        'en_BB' => 'Englisch (Barbados)',
        'en_BE' => 'Englisch (Belgien)',
        'en_BI' => 'Englisch (Burundi)',
        'en_BM' => 'Englisch (Bermuda)',
        'en_BS' => 'Englisch (Bahamas)',
        'en_BW' => 'Englisch (Botsuana)',
        'en_BZ' => 'Englisch (Belize)',
        'en_CA' => 'Englisch (Kanada)',
        'en_CC' => 'Englisch (Kokosinseln)',
        'en_CH' => 'Englisch (Schweiz)',
        'en_CK' => 'Englisch (Cookinseln)',
        'en_CM' => 'Englisch (Kamerun)',
        'en_CX' => 'Englisch (Weihnachtsinsel)',
        'en_CY' => 'Englisch (Zypern)',
        'en_DE' => 'Englisch (Deutschland)',
        'en_DK' => 'Englisch (Dänemark)',
        'en_DM' => 'Englisch (Dominica)',
        'en_ER' => 'Englisch (Eritrea)',
        'en_FI' => 'Englisch (Finnland)',
        'en_FJ' => 'Englisch (Fidschi)',
        'en_FK' => 'Englisch (Falklandinseln)',
        'en_FM' => 'Englisch (Mikronesien)',
        'en_GB' => 'Englisch (Vereinigtes Königreich)',
        'en_GD' => 'Englisch (Grenada)',
        'en_GG' => 'Englisch (Guernsey)',
        'en_GH' => 'Englisch (Ghana)',
        'en_GI' => 'Englisch (Gibraltar)',
        'en_GM' => 'Englisch (Gambia)',
        'en_GU' => 'Englisch (Guam)',
        'en_GY' => 'Englisch (Guyana)',
        'en_HK' => 'Englisch (Sonderverwaltungsregion Hongkong)',
        'en_IE' => 'Englisch (Irland)',
        'en_IL' => 'Englisch (Israel)',
        'en_IM' => 'Englisch (Isle of Man)',
        'en_IN' => 'Englisch (Indien)',
        'en_IO' => 'Englisch (Britisches Territorium im Indischen Ozean)',
        'en_JE' => 'Englisch (Jersey)',
        'en_JM' => 'Englisch (Jamaika)',
        'en_KE' => 'Englisch (Kenia)',
        'en_KI' => 'Englisch (Kiribati)',
        'en_KN' => 'Englisch (St. Kitts und Nevis)',
        'en_KY' => 'Englisch (Kaimaninseln)',
        'en_LC' => 'Englisch (St. Lucia)',
        'en_LR' => 'Englisch (Liberia)',
        'en_LS' => 'Englisch (Lesotho)',
        'en_MG' => 'Englisch (Madagaskar)',
        'en_MH' => 'Englisch (Marshallinseln)',
        'en_MO' => 'Englisch (Sonderverwaltungsregion Macau)',
        'en_MP' => 'Englisch (Nördliche Marianen)',
        'en_MS' => 'Englisch (Montserrat)',
        'en_MT' => 'Englisch (Malta)',
        'en_MU' => 'Englisch (Mauritius)',
        'en_MV' => 'Englisch (Malediven)',
        'en_MW' => 'Englisch (Malawi)',
        'en_MY' => 'Englisch (Malaysia)',
        'en_NA' => 'Englisch (Namibia)',
        'en_NF' => 'Englisch (Norfolkinsel)',
        'en_NG' => 'Englisch (Nigeria)',
        'en_NL' => 'Englisch (Niederlande)',
        'en_NR' => 'Englisch (Nauru)',
        'en_NU' => 'Englisch (Niue)',
        'en_NZ' => 'Englisch (Neuseeland)',
        'en_PG' => 'Englisch (Papua-Neuguinea)',
        'en_PH' => 'Englisch (Philippinen)',
        'en_PK' => 'Englisch (Pakistan)',
        'en_PN' => 'Englisch (Pitcairninseln)',
        'en_PR' => 'Englisch (Puerto Rico)',
        'en_PW' => 'Englisch (Palau)',
        'en_RW' => 'Englisch (Ruanda)',
        'en_SB' => 'Englisch (Salomonen)',
        'en_SC' => 'Englisch (Seychellen)',
        'en_SD' => 'Englisch (Sudan)',
        'en_SE' => 'Englisch (Schweden)',
        'en_SG' => 'Englisch (Singapur)',
        'en_SH' => 'Englisch (St. Helena)',
        'en_SI' => 'Englisch (Slowenien)',
        'en_SL' => 'Englisch (Sierra Leone)',
        'en_SS' => 'Englisch (Südsudan)',
        'en_SX' => 'Englisch (Sint Maarten)',
        'en_SZ' => 'Englisch (Eswatini)',
        'en_TC' => 'Englisch (Turks- und Caicosinseln)',
        'en_TK' => 'Englisch (Tokelau)',
        'en_TO' => 'Englisch (Tonga)',
        'en_TT' => 'Englisch (Trinidad und Tobago)',
        'en_TV' => 'Englisch (Tuvalu)',
        'en_TZ' => 'Englisch (Tansania)',
        'en_UG' => 'Englisch (Uganda)',
        'en_UM' => 'Englisch (Amerikanische Überseeinseln)',
        'en_US' => 'Englisch (Vereinigte Staaten)',
        'en_VC' => 'Englisch (St. Vincent und die Grenadinen)',
        'en_VG' => 'Englisch (Britische Jungferninseln)',
        'en_VI' => 'Englisch (Amerikanische Jungferninseln)',
        'en_VU' => 'Englisch (Vanuatu)',
        'en_WS' => 'Englisch (Samoa)',
        'en_ZA' => 'Englisch (Südafrika)',
        'en_ZM' => 'Englisch (Sambia)',
        'en_ZW' => 'Englisch (Simbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Welt)',
        'es' => 'Spanisch',
        'es_419' => 'Spanisch (Lateinamerika)',
        'es_AR' => 'Spanisch (Argentinien)',
        'es_BO' => 'Spanisch (Bolivien)',
        'es_BR' => 'Spanisch (Brasilien)',
        'es_BZ' => 'Spanisch (Belize)',
        'es_CL' => 'Spanisch (Chile)',
        'es_CO' => 'Spanisch (Kolumbien)',
        'es_CR' => 'Spanisch (Costa Rica)',
        'es_CU' => 'Spanisch (Kuba)',
        'es_DO' => 'Spanisch (Dominikanische Republik)',
        'es_EC' => 'Spanisch (Ecuador)',
        'es_ES' => 'Spanisch (Spanien)',
        'es_GQ' => 'Spanisch (Äquatorialguinea)',
        'es_GT' => 'Spanisch (Guatemala)',
        'es_HN' => 'Spanisch (Honduras)',
        'es_MX' => 'Spanisch (Mexiko)',
        'es_NI' => 'Spanisch (Nicaragua)',
        'es_PA' => 'Spanisch (Panama)',
        'es_PE' => 'Spanisch (Peru)',
        'es_PH' => 'Spanisch (Philippinen)',
        'es_PR' => 'Spanisch (Puerto Rico)',
        'es_PY' => 'Spanisch (Paraguay)',
        'es_SV' => 'Spanisch (El Salvador)',
        'es_US' => 'Spanisch (Vereinigte Staaten)',
        'es_UY' => 'Spanisch (Uruguay)',
        'es_VE' => 'Spanisch (Venezuela)',
        'et' => 'Estnisch',
        'et_EE' => 'Estnisch (Estland)',
        'eu' => 'Baskisch',
        'eu_ES' => 'Baskisch (Spanien)',
        'fa' => 'Persisch',
        'fa_AF' => 'Persisch (Afghanistan)',
        'fa_IR' => 'Persisch (Iran)',
        'ff' => 'Ful',
        'ff_Adlm' => 'Ful (Adlam)',
        'ff_Adlm_BF' => 'Ful (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Ful (Adlam, Kamerun)',
        'ff_Adlm_GH' => 'Ful (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Ful (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Ful (Adlam, Guinea)',
        'ff_Adlm_GW' => 'Ful (Adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'Ful (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Ful (Adlam, Mauretanien)',
        'ff_Adlm_NE' => 'Ful (Adlam, Niger)',
        'ff_Adlm_NG' => 'Ful (Adlam, Nigeria)',
        'ff_Adlm_SL' => 'Ful (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Ful (Adlam, Senegal)',
        'ff_CM' => 'Ful (Kamerun)',
        'ff_GN' => 'Ful (Guinea)',
        'ff_Latn' => 'Ful (Lateinisch)',
        'ff_Latn_BF' => 'Ful (Lateinisch, Burkina Faso)',
        'ff_Latn_CM' => 'Ful (Lateinisch, Kamerun)',
        'ff_Latn_GH' => 'Ful (Lateinisch, Ghana)',
        'ff_Latn_GM' => 'Ful (Lateinisch, Gambia)',
        'ff_Latn_GN' => 'Ful (Lateinisch, Guinea)',
        'ff_Latn_GW' => 'Ful (Lateinisch, Guinea-Bissau)',
        'ff_Latn_LR' => 'Ful (Lateinisch, Liberia)',
        'ff_Latn_MR' => 'Ful (Lateinisch, Mauretanien)',
        'ff_Latn_NE' => 'Ful (Lateinisch, Niger)',
        'ff_Latn_NG' => 'Ful (Lateinisch, Nigeria)',
        'ff_Latn_SL' => 'Ful (Lateinisch, Sierra Leone)',
        'ff_Latn_SN' => 'Ful (Lateinisch, Senegal)',
        'ff_MR' => 'Ful (Mauretanien)',
        'ff_SN' => 'Ful (Senegal)',
        'fi' => 'Finnisch',
        'fi_FI' => 'Finnisch (Finnland)',
        'fo' => 'Färöisch',
        'fo_DK' => 'Färöisch (Dänemark)',
        'fo_FO' => 'Färöisch (Färöer)',
        'fr' => 'Französisch',
        'fr_BE' => 'Französisch (Belgien)',
        'fr_BF' => 'Französisch (Burkina Faso)',
        'fr_BI' => 'Französisch (Burundi)',
        'fr_BJ' => 'Französisch (Benin)',
        'fr_BL' => 'Französisch (St. Barthélemy)',
        'fr_CA' => 'Französisch (Kanada)',
        'fr_CD' => 'Französisch (Kongo-Kinshasa)',
        'fr_CF' => 'Französisch (Zentralafrikanische Republik)',
        'fr_CG' => 'Französisch (Kongo-Brazzaville)',
        'fr_CH' => 'Französisch (Schweiz)',
        'fr_CI' => 'Französisch (Côte d’Ivoire)',
        'fr_CM' => 'Französisch (Kamerun)',
        'fr_DJ' => 'Französisch (Dschibuti)',
        'fr_DZ' => 'Französisch (Algerien)',
        'fr_FR' => 'Französisch (Frankreich)',
        'fr_GA' => 'Französisch (Gabun)',
        'fr_GF' => 'Französisch (Französisch-Guayana)',
        'fr_GN' => 'Französisch (Guinea)',
        'fr_GP' => 'Französisch (Guadeloupe)',
        'fr_GQ' => 'Französisch (Äquatorialguinea)',
        'fr_HT' => 'Französisch (Haiti)',
        'fr_KM' => 'Französisch (Komoren)',
        'fr_LU' => 'Französisch (Luxemburg)',
        'fr_MA' => 'Französisch (Marokko)',
        'fr_MC' => 'Französisch (Monaco)',
        'fr_MF' => 'Französisch (St. Martin)',
        'fr_MG' => 'Französisch (Madagaskar)',
        'fr_ML' => 'Französisch (Mali)',
        'fr_MQ' => 'Französisch (Martinique)',
        'fr_MR' => 'Französisch (Mauretanien)',
        'fr_MU' => 'Französisch (Mauritius)',
        'fr_NC' => 'Französisch (Neukaledonien)',
        'fr_NE' => 'Französisch (Niger)',
        'fr_PF' => 'Französisch (Französisch-Polynesien)',
        'fr_PM' => 'Französisch (St. Pierre und Miquelon)',
        'fr_RE' => 'Französisch (Réunion)',
        'fr_RW' => 'Französisch (Ruanda)',
        'fr_SC' => 'Französisch (Seychellen)',
        'fr_SN' => 'Französisch (Senegal)',
        'fr_SY' => 'Französisch (Syrien)',
        'fr_TD' => 'Französisch (Tschad)',
        'fr_TG' => 'Französisch (Togo)',
        'fr_TN' => 'Französisch (Tunesien)',
        'fr_VU' => 'Französisch (Vanuatu)',
        'fr_WF' => 'Französisch (Wallis und Futuna)',
        'fr_YT' => 'Französisch (Mayotte)',
        'fy' => 'Westfriesisch',
        'fy_NL' => 'Westfriesisch (Niederlande)',
        'ga' => 'Irisch',
        'ga_GB' => 'Irisch (Vereinigtes Königreich)',
        'ga_IE' => 'Irisch (Irland)',
        'gd' => 'Gälisch [Schottland]',
        'gd_GB' => 'Gälisch [Schottland] (Vereinigtes Königreich)',
        'gl' => 'Galicisch',
        'gl_ES' => 'Galicisch (Spanien)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (Indien)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Isle of Man)',
        'ha' => 'Haussa',
        'ha_GH' => 'Haussa (Ghana)',
        'ha_NE' => 'Haussa (Niger)',
        'ha_NG' => 'Haussa (Nigeria)',
        'he' => 'Hebräisch',
        'he_IL' => 'Hebräisch (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (Indien)',
        'hi_Latn' => 'Hindi (Lateinisch)',
        'hi_Latn_IN' => 'Hindi (Lateinisch, Indien)',
        'hr' => 'Kroatisch',
        'hr_BA' => 'Kroatisch (Bosnien und Herzegowina)',
        'hr_HR' => 'Kroatisch (Kroatien)',
        'hu' => 'Ungarisch',
        'hu_HU' => 'Ungarisch (Ungarn)',
        'hy' => 'Armenisch',
        'hy_AM' => 'Armenisch (Armenien)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Welt)',
        'id' => 'Indonesisch',
        'id_ID' => 'Indonesisch (Indonesien)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigeria)',
        'ii' => 'Yi',
        'ii_CN' => 'Yi (China)',
        'is' => 'Isländisch',
        'is_IS' => 'Isländisch (Island)',
        'it' => 'Italienisch',
        'it_CH' => 'Italienisch (Schweiz)',
        'it_IT' => 'Italienisch (Italien)',
        'it_SM' => 'Italienisch (San Marino)',
        'it_VA' => 'Italienisch (Vatikanstadt)',
        'ja' => 'Japanisch',
        'ja_JP' => 'Japanisch (Japan)',
        'jv' => 'Javanisch',
        'jv_ID' => 'Javanisch (Indonesien)',
        'ka' => 'Georgisch',
        'ka_GE' => 'Georgisch (Georgien)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenia)',
        'kk' => 'Kasachisch',
        'kk_KZ' => 'Kasachisch (Kasachstan)',
        'kl' => 'Grönländisch',
        'kl_GL' => 'Grönländisch (Grönland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Kambodscha)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (Indien)',
        'ko' => 'Koreanisch',
        'ko_KP' => 'Koreanisch (Nordkorea)',
        'ko_KR' => 'Koreanisch (Südkorea)',
        'ks' => 'Kaschmiri',
        'ks_Arab' => 'Kaschmiri (Arabisch)',
        'ks_Arab_IN' => 'Kaschmiri (Arabisch, Indien)',
        'ks_Deva' => 'Kaschmiri (Devanagari)',
        'ks_Deva_IN' => 'Kaschmiri (Devanagari, Indien)',
        'ks_IN' => 'Kaschmiri (Indien)',
        'ku' => 'Kurdisch',
        'ku_TR' => 'Kurdisch (Türkei)',
        'kw' => 'Kornisch',
        'kw_GB' => 'Kornisch (Vereinigtes Königreich)',
        'ky' => 'Kirgisisch',
        'ky_KG' => 'Kirgisisch (Kirgisistan)',
        'lb' => 'Luxemburgisch',
        'lb_LU' => 'Luxemburgisch (Luxemburg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Kongo-Kinshasa)',
        'ln_CF' => 'Lingala (Zentralafrikanische Republik)',
        'ln_CG' => 'Lingala (Kongo-Brazzaville)',
        'lo' => 'Laotisch',
        'lo_LA' => 'Laotisch (Laos)',
        'lt' => 'Litauisch',
        'lt_LT' => 'Litauisch (Litauen)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Kongo-Kinshasa)',
        'lv' => 'Lettisch',
        'lv_LV' => 'Lettisch (Lettland)',
        'mg' => 'Malagasy',
        'mg_MG' => 'Malagasy (Madagaskar)',
        'mi' => 'Māori',
        'mi_NZ' => 'Māori (Neuseeland)',
        'mk' => 'Mazedonisch',
        'mk_MK' => 'Mazedonisch (Nordmazedonien)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (Indien)',
        'mn' => 'Mongolisch',
        'mn_MN' => 'Mongolisch (Mongolei)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (Indien)',
        'ms' => 'Malaiisch',
        'ms_BN' => 'Malaiisch (Brunei Darussalam)',
        'ms_ID' => 'Malaiisch (Indonesien)',
        'ms_MY' => 'Malaiisch (Malaysia)',
        'ms_SG' => 'Malaiisch (Singapur)',
        'mt' => 'Maltesisch',
        'mt_MT' => 'Maltesisch (Malta)',
        'my' => 'Birmanisch',
        'my_MM' => 'Birmanisch (Myanmar)',
        'nb' => 'Norwegisch [Bokmål]',
        'nb_NO' => 'Norwegisch [Bokmål] (Norwegen)',
        'nb_SJ' => 'Norwegisch [Bokmål] (Spitzbergen und Jan Mayen)',
        'nd' => 'Nord-Ndebele',
        'nd_ZW' => 'Nord-Ndebele (Simbabwe)',
        'ne' => 'Nepalesisch',
        'ne_IN' => 'Nepalesisch (Indien)',
        'ne_NP' => 'Nepalesisch (Nepal)',
        'nl' => 'Niederländisch',
        'nl_AW' => 'Niederländisch (Aruba)',
        'nl_BE' => 'Niederländisch (Belgien)',
        'nl_BQ' => 'Niederländisch (Karibische Niederlande)',
        'nl_CW' => 'Niederländisch (Curaçao)',
        'nl_NL' => 'Niederländisch (Niederlande)',
        'nl_SR' => 'Niederländisch (Suriname)',
        'nl_SX' => 'Niederländisch (Sint Maarten)',
        'nn' => 'Norwegisch [Nynorsk]',
        'nn_NO' => 'Norwegisch [Nynorsk] (Norwegen)',
        'no' => 'Norwegisch',
        'no_NO' => 'Norwegisch (Norwegen)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Äthiopien)',
        'om_KE' => 'Oromo (Kenia)',
        'or' => 'Oriya',
        'or_IN' => 'Oriya (Indien)',
        'os' => 'Ossetisch',
        'os_GE' => 'Ossetisch (Georgien)',
        'os_RU' => 'Ossetisch (Russland)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Arabisch)',
        'pa_Arab_PK' => 'Punjabi (Arabisch, Pakistan)',
        'pa_Guru' => 'Punjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Punjabi (Gurmukhi, Indien)',
        'pa_IN' => 'Punjabi (Indien)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Polnisch',
        'pl_PL' => 'Polnisch (Polen)',
        'ps' => 'Paschtu',
        'ps_AF' => 'Paschtu (Afghanistan)',
        'ps_PK' => 'Paschtu (Pakistan)',
        'pt' => 'Portugiesisch',
        'pt_AO' => 'Portugiesisch (Angola)',
        'pt_BR' => 'Portugiesisch (Brasilien)',
        'pt_CH' => 'Portugiesisch (Schweiz)',
        'pt_CV' => 'Portugiesisch (Cabo Verde)',
        'pt_GQ' => 'Portugiesisch (Äquatorialguinea)',
        'pt_GW' => 'Portugiesisch (Guinea-Bissau)',
        'pt_LU' => 'Portugiesisch (Luxemburg)',
        'pt_MO' => 'Portugiesisch (Sonderverwaltungsregion Macau)',
        'pt_MZ' => 'Portugiesisch (Mosambik)',
        'pt_PT' => 'Portugiesisch (Portugal)',
        'pt_ST' => 'Portugiesisch (São Tomé und Príncipe)',
        'pt_TL' => 'Portugiesisch (Timor-Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolivien)',
        'qu_EC' => 'Quechua (Ecuador)',
        'qu_PE' => 'Quechua (Peru)',
        'rm' => 'Rätoromanisch',
        'rm_CH' => 'Rätoromanisch (Schweiz)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Rumänisch',
        'ro_MD' => 'Rumänisch (Republik Moldau)',
        'ro_RO' => 'Rumänisch (Rumänien)',
        'ru' => 'Russisch',
        'ru_BY' => 'Russisch (Belarus)',
        'ru_KG' => 'Russisch (Kirgisistan)',
        'ru_KZ' => 'Russisch (Kasachstan)',
        'ru_MD' => 'Russisch (Republik Moldau)',
        'ru_RU' => 'Russisch (Russland)',
        'ru_UA' => 'Russisch (Ukraine)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Ruanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (Indien)',
        'sc' => 'Sardisch',
        'sc_IT' => 'Sardisch (Italien)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arabisch)',
        'sd_Arab_PK' => 'Sindhi (Arabisch, Pakistan)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, Indien)',
        'sd_IN' => 'Sindhi (Indien)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Nordsamisch',
        'se_FI' => 'Nordsamisch (Finnland)',
        'se_NO' => 'Nordsamisch (Norwegen)',
        'se_SE' => 'Nordsamisch (Schweden)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Zentralafrikanische Republik)',
        'sh' => 'Serbo-Kroatisch',
        'sh_BA' => 'Serbo-Kroatisch (Bosnien und Herzegowina)',
        'si' => 'Singhalesisch',
        'si_LK' => 'Singhalesisch (Sri Lanka)',
        'sk' => 'Slowakisch',
        'sk_SK' => 'Slowakisch (Slowakei)',
        'sl' => 'Slowenisch',
        'sl_SI' => 'Slowenisch (Slowenien)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Simbabwe)',
        'so' => 'Somali',
        'so_DJ' => 'Somali (Dschibuti)',
        'so_ET' => 'Somali (Äthiopien)',
        'so_KE' => 'Somali (Kenia)',
        'so_SO' => 'Somali (Somalia)',
        'sq' => 'Albanisch',
        'sq_AL' => 'Albanisch (Albanien)',
        'sq_MK' => 'Albanisch (Nordmazedonien)',
        'sr' => 'Serbisch',
        'sr_BA' => 'Serbisch (Bosnien und Herzegowina)',
        'sr_Cyrl' => 'Serbisch (Kyrillisch)',
        'sr_Cyrl_BA' => 'Serbisch (Kyrillisch, Bosnien und Herzegowina)',
        'sr_Cyrl_ME' => 'Serbisch (Kyrillisch, Montenegro)',
        'sr_Cyrl_RS' => 'Serbisch (Kyrillisch, Serbien)',
        'sr_Latn' => 'Serbisch (Lateinisch)',
        'sr_Latn_BA' => 'Serbisch (Lateinisch, Bosnien und Herzegowina)',
        'sr_Latn_ME' => 'Serbisch (Lateinisch, Montenegro)',
        'sr_Latn_RS' => 'Serbisch (Lateinisch, Serbien)',
        'sr_ME' => 'Serbisch (Montenegro)',
        'sr_RS' => 'Serbisch (Serbien)',
        'su' => 'Sundanesisch',
        'su_ID' => 'Sundanesisch (Indonesien)',
        'su_Latn' => 'Sundanesisch (Lateinisch)',
        'su_Latn_ID' => 'Sundanesisch (Lateinisch, Indonesien)',
        'sv' => 'Schwedisch',
        'sv_AX' => 'Schwedisch (Ålandinseln)',
        'sv_FI' => 'Schwedisch (Finnland)',
        'sv_SE' => 'Schwedisch (Schweden)',
        'sw' => 'Suaheli',
        'sw_CD' => 'Suaheli (Kongo-Kinshasa)',
        'sw_KE' => 'Suaheli (Kenia)',
        'sw_TZ' => 'Suaheli (Tansania)',
        'sw_UG' => 'Suaheli (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (Indien)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Malaysia)',
        'ta_SG' => 'Tamil (Singapur)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (Indien)',
        'tg' => 'Tadschikisch',
        'tg_TJ' => 'Tadschikisch (Tadschikistan)',
        'th' => 'Thailändisch',
        'th_TH' => 'Thailändisch (Thailand)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Äthiopien)',
        'tk' => 'Turkmenisch',
        'tk_TM' => 'Turkmenisch (Turkmenistan)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (Philippinen)',
        'to' => 'Tongaisch',
        'to_TO' => 'Tongaisch (Tonga)',
        'tr' => 'Türkisch',
        'tr_CY' => 'Türkisch (Zypern)',
        'tr_TR' => 'Türkisch (Türkei)',
        'tt' => 'Tatarisch',
        'tt_RU' => 'Tatarisch (Russland)',
        'ug' => 'Uigurisch',
        'ug_CN' => 'Uigurisch (China)',
        'uk' => 'Ukrainisch',
        'uk_UA' => 'Ukrainisch (Ukraine)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (Indien)',
        'ur_PK' => 'Urdu (Pakistan)',
        'uz' => 'Usbekisch',
        'uz_AF' => 'Usbekisch (Afghanistan)',
        'uz_Arab' => 'Usbekisch (Arabisch)',
        'uz_Arab_AF' => 'Usbekisch (Arabisch, Afghanistan)',
        'uz_Cyrl' => 'Usbekisch (Kyrillisch)',
        'uz_Cyrl_UZ' => 'Usbekisch (Kyrillisch, Usbekistan)',
        'uz_Latn' => 'Usbekisch (Lateinisch)',
        'uz_Latn_UZ' => 'Usbekisch (Lateinisch, Usbekistan)',
        'uz_UZ' => 'Usbekisch (Usbekistan)',
        'vi' => 'Vietnamesisch',
        'vi_VN' => 'Vietnamesisch (Vietnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Südafrika)',
        'yi' => 'Jiddisch',
        'yi_001' => 'Jiddisch (Welt)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benin)',
        'yo_NG' => 'Yoruba (Nigeria)',
        'zh' => 'Chinesisch',
        'zh_CN' => 'Chinesisch (China)',
        'zh_HK' => 'Chinesisch (Sonderverwaltungsregion Hongkong)',
        'zh_Hans' => 'Chinesisch (Vereinfacht)',
        'zh_Hans_CN' => 'Chinesisch (Vereinfacht, China)',
        'zh_Hans_HK' => 'Chinesisch (Vereinfacht, Sonderverwaltungsregion Hongkong)',
        'zh_Hans_MO' => 'Chinesisch (Vereinfacht, Sonderverwaltungsregion Macau)',
        'zh_Hans_SG' => 'Chinesisch (Vereinfacht, Singapur)',
        'zh_Hant' => 'Chinesisch (Traditionell)',
        'zh_Hant_HK' => 'Chinesisch (Traditionell, Sonderverwaltungsregion Hongkong)',
        'zh_Hant_MO' => 'Chinesisch (Traditionell, Sonderverwaltungsregion Macau)',
        'zh_Hant_TW' => 'Chinesisch (Traditionell, Taiwan)',
        'zh_MO' => 'Chinesisch (Sonderverwaltungsregion Macau)',
        'zh_SG' => 'Chinesisch (Singapur)',
        'zh_TW' => 'Chinesisch (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Südafrika)',
    ],
];
