<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ម៉ោងនៅគ្រីនវិច (អាប៊ីដ្យាន)',
        'Africa/Accra' => 'ម៉ោងនៅគ្រីនវិច (អាក្រា)',
        'Africa/Addis_Ababa' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (អាឌីសអាបេបា)',
        'Africa/Algiers' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (អាល់ហ្សេ)',
        'Africa/Asmera' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (អាស្មារ៉ា)',
        'Africa/Bamako' => 'ម៉ោងនៅគ្រីនវិច (បាម៉ាកូ)',
        'Africa/Bangui' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (បង់ហ្គី)',
        'Africa/Banjul' => 'ម៉ោងនៅគ្រីនវិច (បង់ហ្ស៊ុល)',
        'Africa/Bissau' => 'ម៉ោងនៅគ្រីនវិច (ប៊ីស្សូ)',
        'Africa/Blantyre' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ប្លាំងទីរ៉េ)',
        'Africa/Brazzaville' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (ប្រាស្ហាវីល)',
        'Africa/Bujumbura' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ប៊ូយ៉ាំប៊ូរ៉ា)',
        'Africa/Cairo' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (គែរ)',
        'Africa/Casablanca' => 'ម៉ោង​នៅ​អឺរ៉ុប​ខាង​លិច (កាសាប្លាំងកា)',
        'Africa/Ceuta' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ឈៀតា)',
        'Africa/Conakry' => 'ម៉ោងនៅគ្រីនវិច (កូណាគ្រី)',
        'Africa/Dakar' => 'ម៉ោងនៅគ្រីនវិច (ដាកា)',
        'Africa/Dar_es_Salaam' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (ដាអ៊ីសាឡាំ)',
        'Africa/Djibouti' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (ជីប៊ូទី)',
        'Africa/Douala' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (ឌូអ៊ូឡា)',
        'Africa/El_Aaiun' => 'ម៉ោង​នៅ​អឺរ៉ុប​ខាង​លិច (អែល​អ៊ុយញៀន)',
        'Africa/Freetown' => 'ម៉ោងនៅគ្រីនវិច (ហ្វ្រីថោន)',
        'Africa/Gaborone' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ហ្គាបូរ៉ូន)',
        'Africa/Harare' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ហារ៉ារ៉េ)',
        'Africa/Johannesburg' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​ត្បូង (ជូហានណេប៊ឺហ្គ)',
        'Africa/Juba' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ជូបា)',
        'Africa/Kampala' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (កំប៉ាឡា)',
        'Africa/Khartoum' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ខាទុំ)',
        'Africa/Kigali' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (គីហ្គាលី)',
        'Africa/Kinshasa' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (គីនស្ហាសា)',
        'Africa/Lagos' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (ឡាហ្គូស)',
        'Africa/Libreville' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (លីប្រីវីល)',
        'Africa/Lome' => 'ម៉ោងនៅគ្រីនវិច (ឡូម៉េ)',
        'Africa/Luanda' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (លូអង់ដា)',
        'Africa/Lubumbashi' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (លូប៊ុមបាស៊ី)',
        'Africa/Lusaka' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (លូសាកា)',
        'Africa/Malabo' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (ម៉ាឡាបូ)',
        'Africa/Maputo' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (ម៉ាពុយតូ)',
        'Africa/Maseru' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​ត្បូង (ម៉ាសេរុយ)',
        'Africa/Mbabane' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​ត្បូង (បាបាន)',
        'Africa/Mogadishu' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (ម៉ូហ្គាឌីស្យូ)',
        'Africa/Monrovia' => 'ម៉ោងនៅគ្រីនវិច (ម៉ុងរ៉ូវីយ៉ា)',
        'Africa/Nairobi' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (ណៃរ៉ូប៊ី)',
        'Africa/Ndjamena' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (ដ្យាមេណា)',
        'Africa/Niamey' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (នីញ៉ាម៉េ)',
        'Africa/Nouakchott' => 'ម៉ោងនៅគ្រីនវិច (ណួកសុត)',
        'Africa/Ouagadougou' => 'ម៉ោងនៅគ្រីនវិច (អៅហ្គាឌូហ្គូ)',
        'Africa/Porto-Novo' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​លិច (ព័រតូណូវ៉ូ)',
        'Africa/Sao_Tome' => 'ម៉ោងនៅគ្រីនវិច (សៅតូម៉េ)',
        'Africa/Tripoli' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ទ្រីប៉ូលី)',
        'Africa/Tunis' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ទុយនីស)',
        'Africa/Windhoek' => 'ម៉ោង​នៅ​អាហ្វ្រិក​កណ្ដាល (វីនដុក)',
        'America/Adak' => 'ម៉ោង​​នៅ​ហាវៃ-អាល់ដ្យូសិន (អាដាក)',
        'America/Anchorage' => 'ម៉ោង​នៅ​អាឡាស្កា (អង់ចូរ៉ាក)',
        'America/Anguilla' => 'ម៉ោង​នៅ​អាត្លង់ទិក (អង់ហ្គីឡា)',
        'America/Antigua' => 'ម៉ោង​នៅ​អាត្លង់ទិក (អង់ទីហ្គា)',
        'America/Araguaina' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (អារ៉ាហ្គុយណា)',
        'America/Argentina/La_Rioja' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (ឡារីយ៉ូហា)',
        'America/Argentina/Rio_Gallegos' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (រីយ៉ូហ្គាឡេហ្គូស)',
        'America/Argentina/Salta' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (សាល់តា)',
        'America/Argentina/San_Juan' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (សាំងហ្សង់)',
        'America/Argentina/San_Luis' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (សាន់លូអ៊ីស)',
        'America/Argentina/Tucuman' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (ទូគូម៉ង់)',
        'America/Argentina/Ushuaia' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (អ៊ុយសូអៃ)',
        'America/Aruba' => 'ម៉ោង​នៅ​អាត្លង់ទិក (អារ៉ូបា)',
        'America/Asuncion' => 'ម៉ោង​នៅ​ប៉ារ៉ាហ្គាយ (អាសង់ស្យុង)',
        'America/Bahia' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (បាហៀ)',
        'America/Bahia_Banderas' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (បាហៀបង់ដេរ៉ាស)',
        'America/Barbados' => 'ម៉ោង​នៅ​អាត្លង់ទិក (បាបាដុស)',
        'America/Belem' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (បេឡឹម)',
        'America/Belize' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (បេលី)',
        'America/Blanc-Sablon' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ប្លង់​សាប់ឡុង)',
        'America/Boa_Vista' => 'ម៉ោង​នៅ​អាម៉ាហ្សូន (បៅ​វីស្តា)',
        'America/Bogota' => 'ម៉ោង​នៅ​កូឡុំប៊ី (បូហ្គោតា)',
        'America/Boise' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ប៊ូស៊ី)',
        'America/Buenos_Aires' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (ប៊ុយណូស៊ែ)',
        'America/Cambridge_Bay' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ខេមប្រីដបេ)',
        'America/Campo_Grande' => 'ម៉ោង​នៅ​អាម៉ាហ្សូន (ខេមប៉ូហ្គ្រង់​)',
        'America/Cancun' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ខានខុន)',
        'America/Caracas' => 'ម៉ោង​នៅ​វ៉េណេស៊ុយអេឡា (ការ៉ាកាស)',
        'America/Catamarca' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (កាតាម៉ាកា)',
        'America/Cayenne' => 'ម៉ោង​នៅ​ហ្គីយ៉ាន​បារាំង (កាយ៉េន)',
        'America/Cayman' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (កៃមែន)',
        'America/Chicago' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ស៊ីកាហ្គោ)',
        'America/Chihuahua' => 'ម៉ោង​នៅ​ប៉ាស៊ីហ្វិក​ម៉ិកស៊ិក (ជីហួហួ)',
        'America/Coral_Harbour' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (អាទីកូកាន)',
        'America/Cordoba' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (កូដូបា)',
        'America/Costa_Rica' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (កូស្តារីកា)',
        'America/Creston' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ក្រេស្តុន)',
        'America/Cuiaba' => 'ម៉ោង​នៅ​អាម៉ាហ្សូន (គុយអាបា)',
        'America/Curacao' => 'ម៉ោង​នៅ​អាត្លង់ទិក (កូរ៉ាកៅ)',
        'America/Danmarkshavn' => 'ម៉ោងនៅគ្រីនវិច (ដានម៉ាកស្ហាវិន)',
        'America/Dawson' => 'ម៉ោងនៅយូខន់ (ដាវសុន)',
        'America/Dawson_Creek' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ដាវសុន​ក្រិក)',
        'America/Denver' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ដែនវើ)',
        'America/Detroit' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ដេត្រូអ៊ីត)',
        'America/Dominica' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ដូមីនីក)',
        'America/Edmonton' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (អែតម៉ុងតុង)',
        'America/Eirunepe' => 'ម៉ោង​នៅ​ ប្រេស៊ីល (អ៊ីរ៉ុយណេភី)',
        'America/El_Salvador' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (អែលសាល់វ៉ាឌ័រ)',
        'America/Fort_Nelson' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ហ្វតណេលសាន់)',
        'America/Fortaleza' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (ហ្វ័រតាឡេហ្សារ)',
        'America/Glace_Bay' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ក្លាស​បេ)',
        'America/Godthab' => 'ម៉ោងនៅហ្គ្រីនលែនខាងលិច (នូក)',
        'America/Goose_Bay' => 'ម៉ោង​នៅ​អាត្លង់ទិក (កូសេបេ)',
        'America/Grand_Turk' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ហ្គ្រេន​ទូក)',
        'America/Grenada' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ហ្គ្រើណាដ)',
        'America/Guadeloupe' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ហ្គោដេលូប៉េ)',
        'America/Guatemala' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ក្វាតេម៉ាឡា)',
        'America/Guayaquil' => 'ម៉ោង​នៅ​អេក្វាទ័រ (ហ្គុយ៉ាគីល)',
        'America/Guyana' => 'ម៉ោង​នៅ​ហ្គីយ៉ាន',
        'America/Halifax' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ហាលីហ្វាក)',
        'America/Havana' => 'ម៉ោង​នៅ​គុយបា (ឡាហាវ៉ាន)',
        'America/Hermosillo' => 'ម៉ោង​នៅ​ប៉ាស៊ីហ្វិក​ម៉ិកស៊ិក (ហ៊ែម៉ូស៊ីឡូ)',
        'America/Indiana/Knox' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ណុក ឥណ្ឌាណា)',
        'America/Indiana/Marengo' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ម៉ារេនកូ ឥណ្ឌាណា)',
        'America/Indiana/Petersburg' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ភីធើ​ប៊ឹក ឥណ្ឌាណា)',
        'America/Indiana/Tell_City' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ទីក្រុងថែល ឥណ្ឌាណា)',
        'America/Indiana/Vevay' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (វេវ៉ៃ ឥណ្ឌាយ៉ាណា)',
        'America/Indiana/Vincennes' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (វិនសេណេស ឥណ្ឌាណា)',
        'America/Indiana/Winamac' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (វីណាម៉ាក់ ឥណ្ឌាណា)',
        'America/Indianapolis' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ឥណ្ឌាណាប៉ូលីស)',
        'America/Inuvik' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (អ៊ីនូវីក)',
        'America/Iqaluit' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (អ៊ីកាឡូអ៊ីត)',
        'America/Jamaica' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ហ្សាម៉ាអ៊ីក)',
        'America/Jujuy' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (សូសុយ)',
        'America/Juneau' => 'ម៉ោង​នៅ​អាឡាស្កា (ហ្យូនៀ)',
        'America/Kentucky/Monticello' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ម៉ងទីសេឡូ កេនទូគី)',
        'America/Kralendijk' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ក្រាលែនឌីក)',
        'America/La_Paz' => 'ម៉ោង​នៅ​បូលីវី (ឡាប៉ាស)',
        'America/Lima' => 'ម៉ោង​នៅ​ប៉េរូ (លីម៉ា)',
        'America/Los_Angeles' => 'ម៉ោងនៅប៉ាស៊ីហ្វិកអាមេរិក (ឡូអង់ហ្គិឡេស)',
        'America/Louisville' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (លូអ៊ីវីល)',
        'America/Lower_Princes' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ឡូវើ​ព្រីន​ហ្គ័រទ័រ)',
        'America/Maceio' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (ម៉ាកសេអូ)',
        'America/Managua' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ម៉ាណាហ្គា)',
        'America/Manaus' => 'ម៉ោង​នៅ​អាម៉ាហ្សូន (ម៉ាណាអ៊ូស)',
        'America/Marigot' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ម៉ារីហ្គុត)',
        'America/Martinique' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ម៉ាទីនីក)',
        'America/Matamoros' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ម៉ាតាម៉ូរ៉ូស)',
        'America/Mazatlan' => 'ម៉ោង​នៅ​ប៉ាស៊ីហ្វិក​ម៉ិកស៊ិក (ម៉ាហ្សាតឡង់)',
        'America/Mendoza' => 'ម៉ោង​នៅ​អាហ្សង់ទីន (ម៉ែនឌូហ្សា)',
        'America/Menominee' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ម៉េណូមីនី)',
        'America/Merida' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ម៉េរីដា)',
        'America/Metlakatla' => 'ម៉ោង​នៅ​អាឡាស្កា (មេត្លា កាត្លា)',
        'America/Mexico_City' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ទីក្រុងម៉ិចស៊ីកូ)',
        'America/Miquelon' => 'ម៉ោង​​​នៅសង់​ព្យែរ និង​មីគុយឡុង (មីហ្គីឡុង)',
        'America/Moncton' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ម៉ុងតុន)',
        'America/Monterrey' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ម៉ុនតេរ៉េ)',
        'America/Montevideo' => 'ម៉ោង​នៅ​អ៊ុយរូហ្គាយ (ម៉ុងតេវីដេអូ)',
        'America/Montreal' => 'ម៉ោង​នៅ​ កាណាដា (Montreal)',
        'America/Montserrat' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ម៉ុងស៊ែរ៉ាត​)',
        'America/Nassau' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ណាស្សូ)',
        'America/New_York' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ញូវយ៉ក)',
        'America/Nipigon' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (នីពីកុន)',
        'America/Nome' => 'ម៉ោង​នៅ​អាឡាស្កា (ណូម)',
        'America/Noronha' => 'ម៉ោង​នៅហ្វ៊ែណាន់ដូ​ដឺណូរ៉ូញ៉ា (ណូរ៉ុនញ៉ា)',
        'America/North_Dakota/Beulah' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ប៊ឺឡា ដាកូតា​ខាងជើង)',
        'America/North_Dakota/Center' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (សិនធឺ ដាកូតា​ខាង​ជើង)',
        'America/North_Dakota/New_Salem' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ញូវ​សាឡឹម ដាកូតា​ខាង​ជើង)',
        'America/Ojinaga' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (អូជីណាហ្កា)',
        'America/Panama' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ប៉ាណាម៉ា)',
        'America/Pangnirtung' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ប៉ាងនីទុង)',
        'America/Paramaribo' => 'ម៉ោង​នៅ​សូរីណាម (ប៉ារ៉ាម៉ារីបូ)',
        'America/Phoenix' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (ផូនីក)',
        'America/Port-au-Prince' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (ព័រអូប្រ៉ាំង)',
        'America/Port_of_Spain' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ព័រអេស្ប៉ាញ)',
        'America/Porto_Velho' => 'ម៉ោង​នៅ​អាម៉ាហ្សូន (ព័រតូ​វិលហូ)',
        'America/Puerto_Rico' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ព័រតូរីកូ)',
        'America/Punta_Arenas' => 'ម៉ោងនៅស៊ីលី (ពុនតា អារ៉េណា)',
        'America/Rainy_River' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (រ៉េនីរីវើ)',
        'America/Rankin_Inlet' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (រ៉ាន់ឃីន​អ៊ីនឡិត)',
        'America/Recife' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (រ៉េស៊ីហ្វី)',
        'America/Regina' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (រ៉េហ្គីណា)',
        'America/Resolute' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (រ៉េ​ស៊ូឡូត)',
        'America/Rio_Branco' => 'ម៉ោង​នៅ​ ប្រេស៊ីល (រីយ៉ូប្រានកូ)',
        'America/Santa_Isabel' => 'ម៉ោង​នៅ​ម៉ិកស៊ិកភាគពាយព្យ (សាន់តាអ៊ីសាប៊ែល)',
        'America/Santarem' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (សាន់តារឹម)',
        'America/Santiago' => 'ម៉ោងនៅស៊ីលី (សាន់ទីអេហ្គោ)',
        'America/Santo_Domingo' => 'ម៉ោង​នៅ​អាត្លង់ទិក (សាន់ដូម៉ាំង)',
        'America/Sao_Paulo' => 'ម៉ោង​នៅ​ប្រាស៊ីលីយ៉ា (សៅ​ប៉ូឡូ)',
        'America/Scoresbysund' => 'ម៉ោង​​នៅ​ហ្គ្រីនលែន​ខាង​កើត (អ៊ីតូគ័រតូមីត)',
        'America/Sitka' => 'ម៉ោង​នៅ​អាឡាស្កា (ស៊ីតកា)',
        'America/St_Barthelemy' => 'ម៉ោង​នៅ​អាត្លង់ទិក (សាំង​បាធីលីម៉ី)',
        'America/St_Johns' => 'ម៉ោង​​នៅញូវហ្វោនឡែន (សាំង​ចន)',
        'America/St_Kitts' => 'ម៉ោង​នៅ​អាត្លង់ទិក (សាំង​ឃីត)',
        'America/St_Lucia' => 'ម៉ោង​នៅ​អាត្លង់ទិក (សាំង​លូសៀ)',
        'America/St_Thomas' => 'ម៉ោង​នៅ​អាត្លង់ទិក (សាំង​តូម៉ាស់)',
        'America/St_Vincent' => 'ម៉ោង​នៅ​អាត្លង់ទិក (សាំង​វីនសេន)',
        'America/Swift_Current' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (ស្វីត​ខឺរិន)',
        'America/Tegucigalpa' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (តេហ្គូស៊ីហ្គាល់ប៉ា)',
        'America/Thule' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ធុឡេ)',
        'America/Thunder_Bay' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (សាន់ដឺ​បេ)',
        'America/Tijuana' => 'ម៉ោងនៅប៉ាស៊ីហ្វិកអាមេរិក (ទីយ្យូអាណា)',
        'America/Toronto' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត (តូរ៉ុនតូ)',
        'America/Tortola' => 'ម៉ោង​នៅ​អាត្លង់ទិក (តូតូឡា)',
        'America/Vancouver' => 'ម៉ោងនៅប៉ាស៊ីហ្វិកអាមេរិក (វ៉ាន់កូវើ)',
        'America/Whitehorse' => 'ម៉ោងនៅយូខន់ (វ៉ាយហស)',
        'America/Winnipeg' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល (វីនីភិក)',
        'America/Yakutat' => 'ម៉ោង​នៅ​អាឡាស្កា (យ៉ាគូតាត)',
        'America/Yellowknife' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង (យេឡូណៃ)',
        'Antarctica/Casey' => 'ម៉ោង​នៅ​ អង់តាក់ទិក (កាសី)',
        'Antarctica/Davis' => 'ម៉ោង​នៅ​ដាវីស',
        'Antarctica/DumontDUrville' => 'ម៉ោង​នៅ​ឌុយម៉ុងដឺអ៊ុយវីល',
        'Antarctica/Macquarie' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (ម៉ាកខ្វារី)',
        'Antarctica/Mawson' => 'ម៉ោង​នៅ​ម៉ៅ​សាន់ (ម៉ៅសាន់)',
        'Antarctica/McMurdo' => 'ម៉ោង​នៅ​នូវែលសេឡង់ (ម៉ាក់មុយដូ)',
        'Antarctica/Palmer' => 'ម៉ោងនៅស៊ីលី (ផាល់ម័រ)',
        'Antarctica/Rothera' => 'ម៉ោង​នៅ​រ៉ូធឺរ៉ា (រ៉ូធីរ៉ា)',
        'Antarctica/Syowa' => 'ម៉ោង​នៅ​ស៊ីអូវ៉ា (ស៊ីយ៉ូវ៉ា)',
        'Antarctica/Troll' => 'ម៉ោងនៅគ្រីនវិច (ត្រូល)',
        'Antarctica/Vostok' => 'ម៉ោង​នៅ​វ័រស្តុក (វ៉ូស្តុក)',
        'Arctic/Longyearbyen' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ឡុង​យ៉ា​ប៊ីយេន)',
        'Asia/Aden' => 'ម៉ោង​នៅ​អារ៉ាប់ (អាដែន)',
        'Asia/Almaty' => 'ម៉ោង​កាហ្សាក់ស្ថាន​​ខាង​កើត (អាល់ម៉ាទី)',
        'Asia/Amman' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (អាម៉ាន់)',
        'Asia/Anadyr' => 'ម៉ោង​នៅ​ រុស្ស៊ី (អាណាឌី)',
        'Asia/Aqtau' => 'ម៉ោង​នៅ​កាហ្សាក់ស្ថាន​ខាង​​​លិច (អាកទូ)',
        'Asia/Aqtobe' => 'ម៉ោង​នៅ​កាហ្សាក់ស្ថាន​ខាង​​​លិច (អាកទូប៊ី)',
        'Asia/Ashgabat' => 'ម៉ោង​នៅ​តួកម៉េនីស្ថាន (អាសហ្គាបាត)',
        'Asia/Atyrau' => 'ម៉ោង​នៅ​កាហ្សាក់ស្ថាន​ខាង​​​លិច (អាទីរ៉ូ)',
        'Asia/Baghdad' => 'ម៉ោង​នៅ​អារ៉ាប់ (បាកដាដ)',
        'Asia/Bahrain' => 'ម៉ោង​នៅ​អារ៉ាប់ (បារ៉ែន)',
        'Asia/Baku' => 'ម៉ោង​នៅ​អាស៊ែបៃហ្សង់ (បាគូ)',
        'Asia/Bangkok' => 'ម៉ោង​នៅ​ឥណ្ឌូចិន (បាងកក)',
        'Asia/Barnaul' => 'ម៉ោង​នៅ​ រុស្ស៊ី (បានូល)',
        'Asia/Beirut' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (បេរូត)',
        'Asia/Bishkek' => 'ម៉ោងនៅកៀហ្ស៊ីស៊ីស្ថាន (ប៊ីស្កេក)',
        'Asia/Brunei' => 'ម៉ោងនៅព្រុយណេដារូសាឡឹម',
        'Asia/Calcutta' => 'ម៉ោង​ស្តង់ដារនៅ​ឥណ្ឌា (កុលកាតា)',
        'Asia/Chita' => 'ម៉ោង​នៅ​យ៉ាគុតស្កិ៍ (ឈីតា)',
        'Asia/Choibalsan' => 'ម៉ោង​នៅ​អ៊ូឡាន​បាទូ (ឈូបាល់សាន)',
        'Asia/Colombo' => 'ម៉ោង​ស្តង់ដារនៅ​ឥណ្ឌា (កូឡុំបូ)',
        'Asia/Damascus' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ដាម៉ាស)',
        'Asia/Dhaka' => 'ម៉ោង​នៅ​បង់ក្លាដែស (ដាក្កា)',
        'Asia/Dili' => 'ម៉ោង​នៅ​​ទីម័រ​ខាង​កើត (ដេលី)',
        'Asia/Dubai' => 'ម៉ោង​ស្តង់ដា​នៅ​កាល់ (ឌុយបៃ)',
        'Asia/Dushanbe' => 'ម៉ោងនៅតាជីគីស្ថាន (ឌូស្ហាន់បេ)',
        'Asia/Famagusta' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ហ្វ៉ាម៉ាហ្គុស្តា)',
        'Asia/Gaza' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (កាសា)',
        'Asia/Hebron' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ហេបរុន)',
        'Asia/Hong_Kong' => 'ម៉ោង​នៅ​ហុងកុង',
        'Asia/Hovd' => 'ម៉ោង​នៅ​ហូវ',
        'Asia/Irkutsk' => 'ម៉ោងនៅអៀរគុតស្កិ៍',
        'Asia/Jakarta' => 'ម៉ោង​នៅ​ឥណ្ឌូណេស៊ី​​ខាង​លិច (ហ្សាការតា)',
        'Asia/Jayapura' => 'ម៉ោង​នៅ​ឥណ្ឌូណេស៊ី​​ខាង​កើត (ចាយ៉ាភូរ៉ា)',
        'Asia/Jerusalem' => 'ម៉ោង​នៅ​អ៊ីស្រាអែល (ហ្ស៊េរុយសាឡិម)',
        'Asia/Kabul' => 'ម៉ោង​នៅ​អាហ្វហ្គានីស្ថាន (កាប៊ុល)',
        'Asia/Kamchatka' => 'ម៉ោង​នៅ​ រុស្ស៊ី (កាំឆាតកា)',
        'Asia/Karachi' => 'ម៉ោង​នៅ​ប៉ាគីស្ថាន (ការ៉ាជី)',
        'Asia/Katmandu' => 'ម៉ោងនៅនេប៉ាល់ (កាត់ម៉ាន់ឌូ)',
        'Asia/Khandyga' => 'ម៉ោង​នៅ​យ៉ាគុតស្កិ៍ (ខាន់ឌីហ្គា)',
        'Asia/Krasnoyarsk' => 'ម៉ោង​នៅ​ក្រាណូយ៉ាស (ក្រាសនុយ៉ាក)',
        'Asia/Kuala_Lumpur' => 'ម៉ោង​នៅ​ម៉ាឡេស៊ី (កូឡាឡាំពួរ)',
        'Asia/Kuching' => 'ម៉ោង​នៅ​ម៉ាឡេស៊ី (ឃឺតចីង)',
        'Asia/Kuwait' => 'ម៉ោង​នៅ​អារ៉ាប់ (កូវ៉ែត)',
        'Asia/Macau' => 'ម៉ោង​នៅ​ចិន (ម៉ាកាវ)',
        'Asia/Magadan' => 'ម៉ោង​នៅ​ម៉ាហ្កាដាន (ម៉ាហ្គាដាន)',
        'Asia/Makassar' => 'ម៉ោង​នៅ​ឥណ្ឌូណេស៊ី​​​កណ្ដាល (ម៉ាកាសសារ)',
        'Asia/Manila' => 'ម៉ោង​នៅ​ហ្វីលីពីន (ម៉ានីល)',
        'Asia/Muscat' => 'ម៉ោង​ស្តង់ដា​នៅ​កាល់ (ម៉ាស្កាត)',
        'Asia/Nicosia' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (នីកូស៊ី)',
        'Asia/Novokuznetsk' => 'ម៉ោង​នៅ​ក្រាណូយ៉ាស (ណូវ៉ូឃូសណេតស្កិ៍)',
        'Asia/Novosibirsk' => 'ម៉ោង​នៅ​ណូវ៉ូស៊ីប៊ីក (ណូវ៉ូស៊ីប៊ឺក)',
        'Asia/Omsk' => 'ម៉ោង​នៅ​អូម (អូមស្កិ៍)',
        'Asia/Oral' => 'ម៉ោង​នៅ​កាហ្សាក់ស្ថាន​ខាង​​​លិច (អូរ៉ាល់)',
        'Asia/Phnom_Penh' => 'ម៉ោង​នៅ​ឥណ្ឌូចិន (ភ្នំពេញ)',
        'Asia/Pontianak' => 'ម៉ោង​នៅ​ឥណ្ឌូណេស៊ី​​ខាង​លិច (ប៉ុនទីអាណាក់)',
        'Asia/Pyongyang' => 'ម៉ោង​នៅ​កូរ៉េ (ព្យុងយ៉ាង)',
        'Asia/Qatar' => 'ម៉ោង​នៅ​អារ៉ាប់ (កាតា)',
        'Asia/Qostanay' => 'ម៉ោង​កាហ្សាក់ស្ថាន​​ខាង​កើត (កូស្ដេណេ)',
        'Asia/Qyzylorda' => 'ម៉ោង​នៅ​កាហ្សាក់ស្ថាន​ខាង​​​លិច (គីហ្ស៊ីឡូដា)',
        'Asia/Rangoon' => 'ម៉ោង​នៅ​មីយ៉ាន់ម៉ា (រ៉ង់ហ្គូន)',
        'Asia/Riyadh' => 'ម៉ោង​នៅ​អារ៉ាប់ (រីយ៉ាដ)',
        'Asia/Saigon' => 'ម៉ោង​នៅ​ឥណ្ឌូចិន (ហូជីមីញ)',
        'Asia/Sakhalin' => 'ម៉ោង​នៅ​សាក់ខាលីន (សាខាលីន)',
        'Asia/Samarkand' => 'ម៉ោង​នៅ​អ៊ូសបេគីស្ថាន (សាម៉ាកាន់)',
        'Asia/Seoul' => 'ម៉ោង​នៅ​កូរ៉េ (សេអ៊ូល)',
        'Asia/Shanghai' => 'ម៉ោង​នៅ​ចិន (សៀងហៃ)',
        'Asia/Singapore' => 'ម៉ោង​នៅ​សិង្ហបូរី',
        'Asia/Srednekolymsk' => 'ម៉ោង​នៅ​ម៉ាហ្កាដាន (ស្រីតនីកូលីម)',
        'Asia/Taipei' => 'ម៉ោង​នៅ​តៃប៉ិ',
        'Asia/Tashkent' => 'ម៉ោង​នៅ​អ៊ូសបេគីស្ថាន (តាស្កិន)',
        'Asia/Tbilisi' => 'ម៉ោង​នៅ​ហ្សកហ្ស៊ី (ប៊ីលីស៊ី)',
        'Asia/Tehran' => 'ម៉ោង​នៅ​អ៊ីរ៉ង់ (តេហេរ៉ង់)',
        'Asia/Thimphu' => 'ម៉ោងនៅប៊ូតង់ (ធីមភូ)',
        'Asia/Tokyo' => 'ម៉ោង​នៅ​ជប៉ុន (តូក្យូ)',
        'Asia/Tomsk' => 'ម៉ោង​នៅ​ រុស្ស៊ី (ថមស្កិ៍)',
        'Asia/Ulaanbaatar' => 'ម៉ោង​នៅ​អ៊ូឡាន​បាទូ (អ៊ូឡង់បាទ័រ)',
        'Asia/Urumqi' => 'ម៉ោង​នៅ​ ចិន (អ៊ូរាំហ្គី)',
        'Asia/Ust-Nera' => 'ម៉ោង​នៅ​វ៉្លាឌីវ៉ូស្តុក (អូស្តណេរ៉ា)',
        'Asia/Vientiane' => 'ម៉ោង​នៅ​ឥណ្ឌូចិន (វៀងចន្ទន៍)',
        'Asia/Vladivostok' => 'ម៉ោង​នៅ​វ៉្លាឌីវ៉ូស្តុក (វ៉្លាដីវ៉ូស្តុក)',
        'Asia/Yakutsk' => 'ម៉ោង​នៅ​យ៉ាគុតស្កិ៍',
        'Asia/Yekaterinburg' => 'ម៉ោង​នៅ​អ៊ិខាធឺរីនប៊័ក (យ៉េកាធឺរិនប៊ើក)',
        'Asia/Yerevan' => 'ម៉ោង​នៅ​អាមេនី (យ៉េរ៉េវ៉ាន់)',
        'Atlantic/Azores' => 'ម៉ោង​នៅ​អេហ្សស (អាសូរ៉េស)',
        'Atlantic/Bermuda' => 'ម៉ោង​នៅ​អាត្លង់ទិក (ប៉ឺមុយដា)',
        'Atlantic/Canary' => 'ម៉ោង​នៅ​អឺរ៉ុប​ខាង​លិច (កាណារី)',
        'Atlantic/Cape_Verde' => 'ម៉ោង​នៅ​កាប់វែរ',
        'Atlantic/Faeroe' => 'ម៉ោង​នៅ​អឺរ៉ុប​ខាង​លិច (ហ្វារ៉ូ)',
        'Atlantic/Madeira' => 'ម៉ោង​នៅ​អឺរ៉ុប​ខាង​លិច (ម៉ាដៀរ៉ា)',
        'Atlantic/Reykjavik' => 'ម៉ោងនៅគ្រីនវិច (រ៉ៃក្យាវិក)',
        'Atlantic/South_Georgia' => 'ម៉ោង​នៅ​កោះ​ហ្សកហ្ស៊ី (ហ្សកហ្ស៊ី​ខាង​ត្បូង)',
        'Atlantic/St_Helena' => 'ម៉ោងនៅគ្រីនវិច (សាំងហេឡេណា)',
        'Atlantic/Stanley' => 'ម៉ោង​នៅ​ប្រជុំកោះ​ហ្វក់ឡែន (ស្តង់លី)',
        'Australia/Adelaide' => 'ម៉ោង​នៅអូស្ត្រាលី​កណ្ដាល (អាដេឡែត)',
        'Australia/Brisbane' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (ប្រីសប៊ែន)',
        'Australia/Broken_Hill' => 'ម៉ោង​នៅអូស្ត្រាលី​កណ្ដាល (ប្រូកខិនហីល)',
        'Australia/Currie' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (ខូរៀ)',
        'Australia/Darwin' => 'ម៉ោង​នៅអូស្ត្រាលី​កណ្ដាល (ដាវីន)',
        'Australia/Eucla' => 'ម៉ោង​នៅ​​​ភាគ​ខាង​លិច​នៅ​អូស្ត្រាលី​កណ្ដាល (អ៊ុយក្លា)',
        'Australia/Hobart' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (ហូបាត)',
        'Australia/Lindeman' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (លីនឌីម៉ែន)',
        'Australia/Lord_Howe' => 'ម៉ោង​នៅ​ឡតហៅ (ឡតហូវ៉េ)',
        'Australia/Melbourne' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (ម៉េលប៊ន)',
        'Australia/Perth' => 'ម៉ោង​​​នៅ​អូស្ត្រាលី​ខាង​លិច (ភឺធ)',
        'Australia/Sydney' => 'ម៉ោង​នៅ​អូស្ត្រាលី​ខាង​កើត (ស៊ីដនី)',
        'CST6CDT' => 'ម៉ោង​​នៅ​ទ្វីបអាមេរិក​ខាង​ជើងភាគកណ្តាល',
        'EST5EDT' => 'ម៉ោងនៅទ្វីបអាមរិកខាងជើងភាគខាងកើត',
        'Etc/GMT' => 'ម៉ោងនៅគ្រីនវិច',
        'Etc/UTC' => 'ម៉ោងសកលដែលមានការសម្រួល',
        'Europe/Amsterdam' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (អាំស្ទែដាំ)',
        'Europe/Andorra' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (អង់ដូរ៉ា)',
        'Europe/Astrakhan' => 'ម៉ោង​នៅ​មូស្គូ (អាស្ត្រាខាន់)',
        'Europe/Athens' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (អាថែន)',
        'Europe/Belgrade' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (បែលក្រាដ)',
        'Europe/Berlin' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (បែរឡាំង)',
        'Europe/Bratislava' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ប្រាទីស្លាវ៉ា)',
        'Europe/Brussels' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ព្រុចសែល)',
        'Europe/Bucharest' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ប៊ុយការ៉េស)',
        'Europe/Budapest' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ប៊ុយដាប៉ែស)',
        'Europe/Busingen' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ប៊ូស៊ីងហ្គែន)',
        'Europe/Chisinau' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ជីស៊ីណូ)',
        'Europe/Copenhagen' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (កូប៉ិនហាក)',
        'Europe/Dublin' => 'ម៉ោងនៅគ្រីនវិច (ឌុយប្លាំង)',
        'Europe/Gibraltar' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ហ្ស៊ីប្រាល់តា)',
        'Europe/Guernsey' => 'ម៉ោងនៅគ្រីនវិច (ហ្គេនស៊ី)',
        'Europe/Helsinki' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ហែលស៊ិនគី)',
        'Europe/Isle_of_Man' => 'ម៉ោងនៅគ្រីនវិច (អែលអុហ្វម៉ែន)',
        'Europe/Istanbul' => 'ម៉ោង​នៅ​ តួកគី (អ៊ីស្តង់ប៊ុល)',
        'Europe/Jersey' => 'ម៉ោងនៅគ្រីនវិច (ជេស៊ី)',
        'Europe/Kaliningrad' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (កាលីនីងហ្រ្គាដ)',
        'Europe/Kiev' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (កៀវ)',
        'Europe/Kirov' => 'ម៉ោង​នៅ​ រុស្ស៊ី (គីរ៉ូវ)',
        'Europe/Lisbon' => 'ម៉ោង​នៅ​អឺរ៉ុប​ខាង​លិច (លីសបោន)',
        'Europe/Ljubljana' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ជូបហ្សាណា)',
        'Europe/London' => 'ម៉ោងនៅគ្រីនវិច (ឡុងដ៍)',
        'Europe/Luxembourg' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (លុចសំបួ)',
        'Europe/Madrid' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ម៉ាឌ្រីដ)',
        'Europe/Malta' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ម៉ាល់ត៍)',
        'Europe/Mariehamn' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ម៉ារៀហាំ)',
        'Europe/Minsk' => 'ម៉ោង​នៅ​មូស្គូ (មីនស្កិ៍)',
        'Europe/Monaco' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ម៉ូណាកូ)',
        'Europe/Moscow' => 'ម៉ោង​នៅ​មូស្គូ',
        'Europe/Oslo' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (អូស្លូ)',
        'Europe/Paris' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ប៉ារីស)',
        'Europe/Podgorica' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ប៉ូដហ្គោរីកា)',
        'Europe/Prague' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ប្រាក)',
        'Europe/Riga' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (រីហ្កា)',
        'Europe/Rome' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (រ៉ូម)',
        'Europe/Samara' => 'ម៉ោង​នៅ​ រុស្ស៊ី (សាម៉ារ៉ា)',
        'Europe/San_Marino' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (សាំងម៉ារ៉ាំង)',
        'Europe/Sarajevo' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (សារ៉ាយ៉េវ៉ូ)',
        'Europe/Saratov' => 'ម៉ោង​នៅ​មូស្គូ (សារ៉ាតាវ)',
        'Europe/Simferopol' => 'ម៉ោង​នៅ​មូស្គូ (ស៊ីមហ្វើរ៉ុប៉ូល)',
        'Europe/Skopje' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ស្កុបជេ)',
        'Europe/Sofia' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (សូហ៊្វីយ៉ា)',
        'Europe/Stockholm' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ស្តុកខុល)',
        'Europe/Tallinn' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (តាលិន)',
        'Europe/Tirane' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ទីរ៉ាណេ)',
        'Europe/Ulyanovsk' => 'ម៉ោង​នៅ​មូស្គូ (អុលយ៉ាណូវស្កិ៍)',
        'Europe/Uzhgorod' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (អ៊ុយហ្គោរ៉ូដ)',
        'Europe/Vaduz' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (វ៉ាឌូស)',
        'Europe/Vatican' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (វ៉ាទីកង់)',
        'Europe/Vienna' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (វីយែន)',
        'Europe/Vilnius' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (វីលនីញូស)',
        'Europe/Volgograd' => 'ម៉ោង​នៅ​វ៉ូហ្កោក្រាដ (វ៉ុលហ្គោហ្គ្រាដ)',
        'Europe/Warsaw' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (វ៉ាសូវី)',
        'Europe/Zagreb' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (សាគ្រែប)',
        'Europe/Zaporozhye' => 'ម៉ោង​នៅ​អឺរ៉ុប​​ខាង​កើត​ (ហ្សាប៉ូរ៉ូហ្ស៊ីយ៉េ)',
        'Europe/Zurich' => 'ម៉ោង​នៅ​អឺរ៉ុប​កណ្ដាល (ហ៊្សូរីច)',
        'Indian/Antananarivo' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (អង់តាណាណារីវ)',
        'Indian/Chagos' => 'ម៉ោង​នៅ​មហាសមុទ្រ​ឥណ្ឌា (កាហ្គោ)',
        'Indian/Christmas' => 'ម៉ោង​នៅ​កោះ​គ្រីស្មាស',
        'Indian/Cocos' => 'ម៉ោង​នៅ​ប្រជុំកោះ​កូកូស',
        'Indian/Comoro' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (កូម័រ)',
        'Indian/Kerguelen' => 'ម៉ោងនៅបារាំងខាងត្បូង និងនៅអង់តាំងទិក (ឃឺហ្គុយឡែន)',
        'Indian/Mahe' => 'ម៉ោង​នៅ​សីស្ហែល (ម៉ាហេ)',
        'Indian/Maldives' => 'ម៉ោង​នៅ​ម៉ាល់ឌីវ',
        'Indian/Mauritius' => 'ម៉ោង​នៅ​ម៉ូរីស',
        'Indian/Mayotte' => 'ម៉ោង​នៅ​អាហ្វ្រិក​ខាង​កើត (ម៉ាយុត)',
        'Indian/Reunion' => 'ម៉ោងនៅរេអ៊ុយ៉ុង',
        'MST7MDT' => 'ម៉ោង​នៅតំបន់ភ្នំនៃទ្វីប​អាមេរិក​​​ខាង​ជើង',
        'PST8PDT' => 'ម៉ោងនៅប៉ាស៊ីហ្វិកអាមេរិក',
        'Pacific/Apia' => 'ម៉ោង​នៅ​អាប្យា (អាពី)',
        'Pacific/Auckland' => 'ម៉ោង​នៅ​នូវែលសេឡង់ (អកឡែន)',
        'Pacific/Bougainville' => 'ម៉ោង​នៅប៉ាពូអាស៊ី នូវែលហ្គីណេ (បូហ្គែនវីល)',
        'Pacific/Chatham' => 'ម៉ោង​នៅ​ចាថាំ',
        'Pacific/Easter' => 'ម៉ោងនៅកោះអ៊ីស្ទ័រ',
        'Pacific/Efate' => 'ម៉ោង​នៅ​វ៉ានូទូ (អ៊ីហ្វាតេ)',
        'Pacific/Enderbury' => 'ម៉ោង​នៅ​កោះ​ផូនីក (អ៊ីនដឺប៊ូរី)',
        'Pacific/Fakaofo' => 'ម៉ោង​នៅ​តូខេឡៅ (ហ្វាកៅហ្វូ)',
        'Pacific/Fiji' => 'ម៉ោង​នៅ​ហ្វីជី',
        'Pacific/Funafuti' => 'ម៉ោង​នៅ​ទុយវ៉ាលូ (ហ៊្វូណាហ៊្វូទី)',
        'Pacific/Galapagos' => 'ម៉ោង​នៅ​កាឡាប៉ាកូស (ហ្គាឡាប៉ាហ្គោស)',
        'Pacific/Gambier' => 'ម៉ោង​នៅ​កាំបៀ (ហ្គាំបៀ)',
        'Pacific/Guadalcanal' => 'ម៉ោង​នៅ​កោះ​សូឡូម៉ុន (ហ្គាដាល់ខាណាល់)',
        'Pacific/Guam' => 'ម៉ោង​ស្តង់ដារនៅ​ចាំម៉ូរ៉ូ (ហ្គាំ)',
        'Pacific/Honolulu' => 'ម៉ោង​​នៅ​ហាវៃ-អាល់ដ្យូសិន (ហូណូលូលូ)',
        'Pacific/Johnston' => 'ម៉ោង​​នៅ​ហាវៃ-អាល់ដ្យូសិន (ចនស្តុន)',
        'Pacific/Kiritimati' => 'ម៉ោង​នៅ​កោះ​ឡាញ (គិរីទីម៉ាទិ)',
        'Pacific/Kosrae' => 'ម៉ោង​នៅ​កូស្រៃ (កូស្រែ)',
        'Pacific/Kwajalein' => 'ម៉ោង​នៅ​ម៉ាសាល (ក្វាហ្សាលៀន)',
        'Pacific/Majuro' => 'ម៉ោង​នៅ​ម៉ាសាល (ម៉ាហ្សូរ៉ូ)',
        'Pacific/Marquesas' => 'ម៉ោង​នៅ​កោះ​ម៉ាគឺសាស់ (ម៉ាហ្គីសាស)',
        'Pacific/Midway' => 'ម៉ោង​នៅ​សាម័រ (មីតវ៉េ)',
        'Pacific/Nauru' => 'ម៉ោង​នៅ​ណូរូ',
        'Pacific/Niue' => 'ម៉ោងនៅ​នីវ៉េ',
        'Pacific/Norfolk' => 'ម៉ោង​នៅ​កោះ​ណ័រហ្វក់ (ណ័រហ្វុក)',
        'Pacific/Noumea' => 'ម៉ោង​នៅណូវ៉ែលកាឡេដូនៀ (ណូមៀ)',
        'Pacific/Pago_Pago' => 'ម៉ោង​នៅ​សាម័រ (ប៉ាហ្គោ ប៉ាហ្គោ)',
        'Pacific/Palau' => 'ម៉ោង​នៅ​ផាឡៅ (ប៉ាឡៅ)',
        'Pacific/Pitcairn' => 'ម៉ោង​នៅ​ភីឃឺន (ភីតខៃរ៉ិន)',
        'Pacific/Ponape' => 'ម៉ោង​នៅ​ប៉ូណាប់ (ផុនប៉ី)',
        'Pacific/Port_Moresby' => 'ម៉ោង​នៅប៉ាពូអាស៊ី នូវែលហ្គីណេ (ព័រម៉ូរេសប៊ី)',
        'Pacific/Rarotonga' => 'ម៉ោង​នៅប្រជុំ​កោះ​ខូក (រ៉ារ៉ូតុងហ្គា)',
        'Pacific/Saipan' => 'ម៉ោង​ស្តង់ដារនៅ​ចាំម៉ូរ៉ូ (សៃប៉ាន)',
        'Pacific/Tahiti' => 'ម៉ោង​នៅ​តាហិទី (តាហីទី)',
        'Pacific/Tarawa' => 'ម៉ោង​នៅ​កោះ​កីប៊ឺត (តារ៉ាវ៉ា)',
        'Pacific/Tongatapu' => 'ម៉ោង​នៅ​តុងហ្គា (តុងហ្គាតាពូ)',
        'Pacific/Truk' => 'ម៉ោង​នៅ​ចូអុក (ឈូអុក)',
        'Pacific/Wake' => 'ម៉ោង​នៅ​កោះវេក (វ៉ាគី)',
        'Pacific/Wallis' => 'ម៉ោង​នៅ​វ៉ាលីស និងហ្វ៊ុទូណា',
    ],
    'Meta' => [
        'GmtFormat' => 'ម៉ោង​សកល %s',
    ],
];
