<?php

return [
    'Names' => [
        'ab' => 'افریکانس',
        'as' => 'اسامی',
        'ast' => 'اتریشی',
        'az' => 'آذربایجانی',
        'ckb' => 'کردی سورانی',
        'dv' => 'مالدیوی',
        'es' => 'هسپانوی',
        'fi' => 'فنلندی',
        'ga' => 'آیرلندی',
        'hr' => 'کروشیایی',
        'id' => 'اندونیزیایی',
        'is' => 'آیسلندی',
        'it' => 'ایتالوی',
        'ja' => 'جاپانی',
        'ko' => 'کوریایی',
        'ksh' => 'کلنی',
        'ky' => 'قرغزی',
        'lus' => 'میزویی',
        'mai' => 'مایتیلی',
        'mn' => 'مغلی',
        'nb' => 'نروژی کتابی',
        'ne' => 'نیپالی',
        'nl' => 'هالندی',
        'nn' => 'نروژی نو',
        'no' => 'نارویژی',
        'pl' => 'پولندی',
        'pt' => 'پرتگالی',
        'sq' => 'البانیایی',
        'srn' => 'زبان سرانان',
        'sv' => 'سویدنی',
        'sw' => 'سواحلی',
        'tg' => 'تاجکی',
        'zza' => 'زازاکی',
    ],
    'LocalizedNames' => [
        'ar_001' => 'عربی فصیح',
        'nl_BE' => 'فلمیش',
        'zh_Hans' => 'چینی ساده شده',
    ],
];
