<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibiya)',
        'af_ZA' => 'afrikaans (Cənub Afrika)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Qana)',
        'am' => 'amhar',
        'am_ET' => 'amhar (Efiopiya)',
        'ar' => 'ərəb',
        'ar_001' => 'ərəb (Dünya)',
        'ar_AE' => 'ərəb (Birləşmiş Ərəb Əmirlikləri)',
        'ar_BH' => 'ərəb (Bəhreyn)',
        'ar_DJ' => 'ərəb (Cibuti)',
        'ar_DZ' => 'ərəb (Əlcəzair)',
        'ar_EG' => 'ərəb (Misir)',
        'ar_EH' => 'ərəb (Qərbi Saxara)',
        'ar_ER' => 'ərəb (Eritreya)',
        'ar_IL' => 'ərəb (İsrail)',
        'ar_IQ' => 'ərəb (İraq)',
        'ar_JO' => 'ərəb (İordaniya)',
        'ar_KM' => 'ərəb (Komor adaları)',
        'ar_KW' => 'ərəb (Küveyt)',
        'ar_LB' => 'ərəb (Livan)',
        'ar_LY' => 'ərəb (Liviya)',
        'ar_MA' => 'ərəb (Mərakeş)',
        'ar_MR' => 'ərəb (Mavritaniya)',
        'ar_OM' => 'ərəb (Oman)',
        'ar_PS' => 'ərəb (Fələstin Əraziləri)',
        'ar_QA' => 'ərəb (Qətər)',
        'ar_SA' => 'ərəb (Səudiyyə Ərəbistanı)',
        'ar_SD' => 'ərəb (Sudan)',
        'ar_SO' => 'ərəb (Somali)',
        'ar_SS' => 'ərəb (Cənubi Sudan)',
        'ar_SY' => 'ərəb (Suriya)',
        'ar_TD' => 'ərəb (Çad)',
        'ar_TN' => 'ərəb (Tunis)',
        'ar_YE' => 'ərəb (Yəmən)',
        'as' => 'assam',
        'as_IN' => 'assam (Hindistan)',
        'az' => 'azərbaycan',
        'az_AZ' => 'azərbaycan (Azərbaycan)',
        'az_Cyrl' => 'azərbaycan (kiril)',
        'az_Cyrl_AZ' => 'azərbaycan (kiril, Azərbaycan)',
        'az_Latn' => 'azərbaycan (latın)',
        'az_Latn_AZ' => 'azərbaycan (latın, Azərbaycan)',
        'be' => 'belarus',
        'be_BY' => 'belarus (Belarus)',
        'bg' => 'bolqar',
        'bg_BG' => 'bolqar (Bolqarıstan)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'benqal',
        'bn_BD' => 'benqal (Banqladeş)',
        'bn_IN' => 'benqal (Hindistan)',
        'bo' => 'tibet',
        'bo_CN' => 'tibet (Çin)',
        'bo_IN' => 'tibet (Hindistan)',
        'br' => 'breton',
        'br_FR' => 'breton (Fransa)',
        'bs' => 'bosniya',
        'bs_BA' => 'bosniya (Bosniya və Herseqovina)',
        'bs_Cyrl' => 'bosniya (kiril)',
        'bs_Cyrl_BA' => 'bosniya (kiril, Bosniya və Herseqovina)',
        'bs_Latn' => 'bosniya (latın)',
        'bs_Latn_BA' => 'bosniya (latın, Bosniya və Herseqovina)',
        'ca' => 'katalan',
        'ca_AD' => 'katalan (Andorra)',
        'ca_ES' => 'katalan (İspaniya)',
        'ca_FR' => 'katalan (Fransa)',
        'ca_IT' => 'katalan (İtaliya)',
        'ce' => 'çeçen',
        'ce_RU' => 'çeçen (Rusiya)',
        'cs' => 'çex',
        'cs_CZ' => 'çex (Çexiya)',
        'cv' => 'çuvaş',
        'cv_RU' => 'çuvaş (Rusiya)',
        'cy' => 'uels',
        'cy_GB' => 'uels (Birləşmiş Krallıq)',
        'da' => 'danimarka',
        'da_DK' => 'danimarka (Danimarka)',
        'da_GL' => 'danimarka (Qrenlandiya)',
        'de' => 'alman',
        'de_AT' => 'alman (Avstriya)',
        'de_BE' => 'alman (Belçika)',
        'de_CH' => 'alman (İsveçrə)',
        'de_DE' => 'alman (Almaniya)',
        'de_IT' => 'alman (İtaliya)',
        'de_LI' => 'alman (Lixtenşteyn)',
        'de_LU' => 'alman (Lüksemburq)',
        'dz' => 'dzonqxa',
        'dz_BT' => 'dzonqxa (Butan)',
        'ee' => 'eve',
        'ee_GH' => 'eve (Qana)',
        'ee_TG' => 'eve (Toqo)',
        'el' => 'yunan',
        'el_CY' => 'yunan (Kipr)',
        'el_GR' => 'yunan (Yunanıstan)',
        'en' => 'ingilis',
        'en_001' => 'ingilis (Dünya)',
        'en_150' => 'ingilis (Avropa)',
        'en_AE' => 'ingilis (Birləşmiş Ərəb Əmirlikləri)',
        'en_AG' => 'ingilis (Antiqua və Barbuda)',
        'en_AI' => 'ingilis (Angilya)',
        'en_AS' => 'ingilis (Amerika Samoası)',
        'en_AT' => 'ingilis (Avstriya)',
        'en_AU' => 'ingilis (Avstraliya)',
        'en_BB' => 'ingilis (Barbados)',
        'en_BE' => 'ingilis (Belçika)',
        'en_BI' => 'ingilis (Burundi)',
        'en_BM' => 'ingilis (Bermud adaları)',
        'en_BS' => 'ingilis (Baham adaları)',
        'en_BW' => 'ingilis (Botsvana)',
        'en_BZ' => 'ingilis (Beliz)',
        'en_CA' => 'ingilis (Kanada)',
        'en_CC' => 'ingilis (Kokos [Kilinq] adaları)',
        'en_CH' => 'ingilis (İsveçrə)',
        'en_CK' => 'ingilis (Kuk adaları)',
        'en_CM' => 'ingilis (Kamerun)',
        'en_CX' => 'ingilis (Milad adası)',
        'en_CY' => 'ingilis (Kipr)',
        'en_DE' => 'ingilis (Almaniya)',
        'en_DK' => 'ingilis (Danimarka)',
        'en_DM' => 'ingilis (Dominika)',
        'en_ER' => 'ingilis (Eritreya)',
        'en_FI' => 'ingilis (Finlandiya)',
        'en_FJ' => 'ingilis (Fici)',
        'en_FK' => 'ingilis (Folklend adaları)',
        'en_FM' => 'ingilis (Mikroneziya)',
        'en_GB' => 'ingilis (Birləşmiş Krallıq)',
        'en_GD' => 'ingilis (Qrenada)',
        'en_GG' => 'ingilis (Gernsi)',
        'en_GH' => 'ingilis (Qana)',
        'en_GI' => 'ingilis (Cəbəllütariq)',
        'en_GM' => 'ingilis (Qambiya)',
        'en_GU' => 'ingilis (Quam)',
        'en_GY' => 'ingilis (Qayana)',
        'en_HK' => 'ingilis (Honq Konq Xüsusi İnzibati Rayonu Çin)',
        'en_IE' => 'ingilis (İrlandiya)',
        'en_IL' => 'ingilis (İsrail)',
        'en_IM' => 'ingilis (Men adası)',
        'en_IN' => 'ingilis (Hindistan)',
        'en_IO' => 'ingilis (Britaniyanın Hind Okeanı Ərazisi)',
        'en_JE' => 'ingilis (Cersi)',
        'en_JM' => 'ingilis (Yamayka)',
        'en_KE' => 'ingilis (Keniya)',
        'en_KI' => 'ingilis (Kiribati)',
        'en_KN' => 'ingilis (Sent-Kits və Nevis)',
        'en_KY' => 'ingilis (Kayman adaları)',
        'en_LC' => 'ingilis (Sent-Lusiya)',
        'en_LR' => 'ingilis (Liberiya)',
        'en_LS' => 'ingilis (Lesoto)',
        'en_MG' => 'ingilis (Madaqaskar)',
        'en_MH' => 'ingilis (Marşal adaları)',
        'en_MO' => 'ingilis (Makao XİR Çin)',
        'en_MP' => 'ingilis (Şimali Marian adaları)',
        'en_MS' => 'ingilis (Monserat)',
        'en_MT' => 'ingilis (Malta)',
        'en_MU' => 'ingilis (Mavriki)',
        'en_MV' => 'ingilis (Maldiv adaları)',
        'en_MW' => 'ingilis (Malavi)',
        'en_MY' => 'ingilis (Malayziya)',
        'en_NA' => 'ingilis (Namibiya)',
        'en_NF' => 'ingilis (Norfolk adası)',
        'en_NG' => 'ingilis (Nigeriya)',
        'en_NL' => 'ingilis (Niderland)',
        'en_NR' => 'ingilis (Nauru)',
        'en_NU' => 'ingilis (Niue)',
        'en_NZ' => 'ingilis (Yeni Zelandiya)',
        'en_PG' => 'ingilis (Papua-Yeni Qvineya)',
        'en_PH' => 'ingilis (Filippin)',
        'en_PK' => 'ingilis (Pakistan)',
        'en_PN' => 'ingilis (Pitkern adaları)',
        'en_PR' => 'ingilis (Puerto Riko)',
        'en_PW' => 'ingilis (Palau)',
        'en_RW' => 'ingilis (Ruanda)',
        'en_SB' => 'ingilis (Solomon adaları)',
        'en_SC' => 'ingilis (Seyşel adaları)',
        'en_SD' => 'ingilis (Sudan)',
        'en_SE' => 'ingilis (İsveç)',
        'en_SG' => 'ingilis (Sinqapur)',
        'en_SH' => 'ingilis (Müqəddəs Yelena)',
        'en_SI' => 'ingilis (Sloveniya)',
        'en_SL' => 'ingilis (Syerra-Leone)',
        'en_SS' => 'ingilis (Cənubi Sudan)',
        'en_SX' => 'ingilis (Sint-Marten)',
        'en_SZ' => 'ingilis (Esvatini)',
        'en_TC' => 'ingilis (Törks və Kaykos adaları)',
        'en_TK' => 'ingilis (Tokelau)',
        'en_TO' => 'ingilis (Tonqa)',
        'en_TT' => 'ingilis (Trinidad və Tobaqo)',
        'en_TV' => 'ingilis (Tuvalu)',
        'en_TZ' => 'ingilis (Tanzaniya)',
        'en_UG' => 'ingilis (Uqanda)',
        'en_UM' => 'ingilis (ABŞ-a bağlı kiçik adacıqlar)',
        'en_US' => 'ingilis (Amerika Birləşmiş Ştatları)',
        'en_VC' => 'ingilis (Sent-Vinsent və Qrenadinlər)',
        'en_VG' => 'ingilis (Britaniyanın Virgin adaları)',
        'en_VI' => 'ingilis (ABŞ Virgin adaları)',
        'en_VU' => 'ingilis (Vanuatu)',
        'en_WS' => 'ingilis (Samoa)',
        'en_ZA' => 'ingilis (Cənub Afrika)',
        'en_ZM' => 'ingilis (Zambiya)',
        'en_ZW' => 'ingilis (Zimbabve)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Dünya)',
        'es' => 'ispan',
        'es_419' => 'ispan (Latın Amerikası)',
        'es_AR' => 'ispan (Argentina)',
        'es_BO' => 'ispan (Boliviya)',
        'es_BR' => 'ispan (Braziliya)',
        'es_BZ' => 'ispan (Beliz)',
        'es_CL' => 'ispan (Çili)',
        'es_CO' => 'ispan (Kolumbiya)',
        'es_CR' => 'ispan (Kosta Rika)',
        'es_CU' => 'ispan (Kuba)',
        'es_DO' => 'ispan (Dominikan Respublikası)',
        'es_EC' => 'ispan (Ekvador)',
        'es_ES' => 'ispan (İspaniya)',
        'es_GQ' => 'ispan (Ekvatorial Qvineya)',
        'es_GT' => 'ispan (Qvatemala)',
        'es_HN' => 'ispan (Honduras)',
        'es_MX' => 'ispan (Meksika)',
        'es_NI' => 'ispan (Nikaraqua)',
        'es_PA' => 'ispan (Panama)',
        'es_PE' => 'ispan (Peru)',
        'es_PH' => 'ispan (Filippin)',
        'es_PR' => 'ispan (Puerto Riko)',
        'es_PY' => 'ispan (Paraqvay)',
        'es_SV' => 'ispan (Salvador)',
        'es_US' => 'ispan (Amerika Birləşmiş Ştatları)',
        'es_UY' => 'ispan (Uruqvay)',
        'es_VE' => 'ispan (Venesuela)',
        'et' => 'eston',
        'et_EE' => 'eston (Estoniya)',
        'eu' => 'bask',
        'eu_ES' => 'bask (İspaniya)',
        'fa' => 'fars',
        'fa_AF' => 'fars (Əfqanıstan)',
        'fa_IR' => 'fars (İran)',
        'ff' => 'fula',
        'ff_Adlm' => 'fula (adlam)',
        'ff_Adlm_BF' => 'fula (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fula (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fula (adlam, Qana)',
        'ff_Adlm_GM' => 'fula (adlam, Qambiya)',
        'ff_Adlm_GN' => 'fula (adlam, Qvineya)',
        'ff_Adlm_GW' => 'fula (adlam, Qvineya-Bisau)',
        'ff_Adlm_LR' => 'fula (adlam, Liberiya)',
        'ff_Adlm_MR' => 'fula (adlam, Mavritaniya)',
        'ff_Adlm_NE' => 'fula (adlam, Niger)',
        'ff_Adlm_NG' => 'fula (adlam, Nigeriya)',
        'ff_Adlm_SL' => 'fula (adlam, Syerra-Leone)',
        'ff_Adlm_SN' => 'fula (adlam, Seneqal)',
        'ff_CM' => 'fula (Kamerun)',
        'ff_GN' => 'fula (Qvineya)',
        'ff_Latn' => 'fula (latın)',
        'ff_Latn_BF' => 'fula (latın, Burkina Faso)',
        'ff_Latn_CM' => 'fula (latın, Kamerun)',
        'ff_Latn_GH' => 'fula (latın, Qana)',
        'ff_Latn_GM' => 'fula (latın, Qambiya)',
        'ff_Latn_GN' => 'fula (latın, Qvineya)',
        'ff_Latn_GW' => 'fula (latın, Qvineya-Bisau)',
        'ff_Latn_LR' => 'fula (latın, Liberiya)',
        'ff_Latn_MR' => 'fula (latın, Mavritaniya)',
        'ff_Latn_NE' => 'fula (latın, Niger)',
        'ff_Latn_NG' => 'fula (latın, Nigeriya)',
        'ff_Latn_SL' => 'fula (latın, Syerra-Leone)',
        'ff_Latn_SN' => 'fula (latın, Seneqal)',
        'ff_MR' => 'fula (Mavritaniya)',
        'ff_SN' => 'fula (Seneqal)',
        'fi' => 'fin',
        'fi_FI' => 'fin (Finlandiya)',
        'fo' => 'farer',
        'fo_DK' => 'farer (Danimarka)',
        'fo_FO' => 'farer (Farer adaları)',
        'fr' => 'fransız',
        'fr_BE' => 'fransız (Belçika)',
        'fr_BF' => 'fransız (Burkina Faso)',
        'fr_BI' => 'fransız (Burundi)',
        'fr_BJ' => 'fransız (Benin)',
        'fr_BL' => 'fransız (Sent-Bartelemi)',
        'fr_CA' => 'fransız (Kanada)',
        'fr_CD' => 'fransız (Konqo - Kinşasa)',
        'fr_CF' => 'fransız (Mərkəzi Afrika Respublikası)',
        'fr_CG' => 'fransız (Konqo - Brazzavil)',
        'fr_CH' => 'fransız (İsveçrə)',
        'fr_CI' => 'fransız (Kotd’ivuar)',
        'fr_CM' => 'fransız (Kamerun)',
        'fr_DJ' => 'fransız (Cibuti)',
        'fr_DZ' => 'fransız (Əlcəzair)',
        'fr_FR' => 'fransız (Fransa)',
        'fr_GA' => 'fransız (Qabon)',
        'fr_GF' => 'fransız (Fransa Qvianası)',
        'fr_GN' => 'fransız (Qvineya)',
        'fr_GP' => 'fransız (Qvadelupa)',
        'fr_GQ' => 'fransız (Ekvatorial Qvineya)',
        'fr_HT' => 'fransız (Haiti)',
        'fr_KM' => 'fransız (Komor adaları)',
        'fr_LU' => 'fransız (Lüksemburq)',
        'fr_MA' => 'fransız (Mərakeş)',
        'fr_MC' => 'fransız (Monako)',
        'fr_MF' => 'fransız (Sent Martin)',
        'fr_MG' => 'fransız (Madaqaskar)',
        'fr_ML' => 'fransız (Mali)',
        'fr_MQ' => 'fransız (Martinik)',
        'fr_MR' => 'fransız (Mavritaniya)',
        'fr_MU' => 'fransız (Mavriki)',
        'fr_NC' => 'fransız (Yeni Kaledoniya)',
        'fr_NE' => 'fransız (Niger)',
        'fr_PF' => 'fransız (Fransa Polineziyası)',
        'fr_PM' => 'fransız (Müqəddəs Pyer və Mikelon)',
        'fr_RE' => 'fransız (Reyunyon)',
        'fr_RW' => 'fransız (Ruanda)',
        'fr_SC' => 'fransız (Seyşel adaları)',
        'fr_SN' => 'fransız (Seneqal)',
        'fr_SY' => 'fransız (Suriya)',
        'fr_TD' => 'fransız (Çad)',
        'fr_TG' => 'fransız (Toqo)',
        'fr_TN' => 'fransız (Tunis)',
        'fr_VU' => 'fransız (Vanuatu)',
        'fr_WF' => 'fransız (Uollis və Futuna)',
        'fr_YT' => 'fransız (Mayot)',
        'fy' => 'qərbi friz',
        'fy_NL' => 'qərbi friz (Niderland)',
        'ga' => 'irland',
        'ga_GB' => 'irland (Birləşmiş Krallıq)',
        'ga_IE' => 'irland (İrlandiya)',
        'gd' => 'Şotlandiya keltcəsi',
        'gd_GB' => 'Şotlandiya keltcəsi (Birləşmiş Krallıq)',
        'gl' => 'qalisiya',
        'gl_ES' => 'qalisiya (İspaniya)',
        'gu' => 'qucarat',
        'gu_IN' => 'qucarat (Hindistan)',
        'gv' => 'manks',
        'gv_IM' => 'manks (Men adası)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Qana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeriya)',
        'he' => 'ivrit',
        'he_IL' => 'ivrit (İsrail)',
        'hi' => 'hind',
        'hi_IN' => 'hind (Hindistan)',
        'hi_Latn' => 'hind (latın)',
        'hi_Latn_IN' => 'hind (latın, Hindistan)',
        'hr' => 'xorvat',
        'hr_BA' => 'xorvat (Bosniya və Herseqovina)',
        'hr_HR' => 'xorvat (Xorvatiya)',
        'hu' => 'macar',
        'hu_HU' => 'macar (Macarıstan)',
        'hy' => 'erməni',
        'hy_AM' => 'erməni (Ermənistan)',
        'ia' => 'interlinqua',
        'ia_001' => 'interlinqua (Dünya)',
        'id' => 'indoneziya',
        'id_ID' => 'indoneziya (İndoneziya)',
        'ig' => 'iqbo',
        'ig_NG' => 'iqbo (Nigeriya)',
        'ii' => 'siçuan yi',
        'ii_CN' => 'siçuan yi (Çin)',
        'is' => 'island',
        'is_IS' => 'island (İslandiya)',
        'it' => 'italyan',
        'it_CH' => 'italyan (İsveçrə)',
        'it_IT' => 'italyan (İtaliya)',
        'it_SM' => 'italyan (San-Marino)',
        'it_VA' => 'italyan (Vatikan)',
        'ja' => 'yapon',
        'ja_JP' => 'yapon (Yaponiya)',
        'jv' => 'yava',
        'jv_ID' => 'yava (İndoneziya)',
        'ka' => 'gürcü',
        'ka_GE' => 'gürcü (Gürcüstan)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Keniya)',
        'kk' => 'qazax',
        'kk_KZ' => 'qazax (Qazaxıstan)',
        'kl' => 'kalaallisut',
        'kl_GL' => 'kalaallisut (Qrenlandiya)',
        'km' => 'kxmer',
        'km_KH' => 'kxmer (Kamboca)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Hindistan)',
        'ko' => 'koreya',
        'ko_KP' => 'koreya (Şimali Koreya)',
        'ko_KR' => 'koreya (Cənubi Koreya)',
        'ks' => 'kəşmir',
        'ks_Arab' => 'kəşmir (ərəb)',
        'ks_Arab_IN' => 'kəşmir (ərəb, Hindistan)',
        'ks_Deva' => 'kəşmir (devanaqari)',
        'ks_Deva_IN' => 'kəşmir (devanaqari, Hindistan)',
        'ks_IN' => 'kəşmir (Hindistan)',
        'ku' => 'kürd',
        'ku_TR' => 'kürd (Türkiyə)',
        'kw' => 'korn',
        'kw_GB' => 'korn (Birləşmiş Krallıq)',
        'ky' => 'qırğız',
        'ky_KG' => 'qırğız (Qırğızıstan)',
        'lb' => 'lüksemburq',
        'lb_LU' => 'lüksemburq (Lüksemburq)',
        'lg' => 'qanda',
        'lg_UG' => 'qanda (Uqanda)',
        'ln' => 'linqala',
        'ln_AO' => 'linqala (Anqola)',
        'ln_CD' => 'linqala (Konqo - Kinşasa)',
        'ln_CF' => 'linqala (Mərkəzi Afrika Respublikası)',
        'ln_CG' => 'linqala (Konqo - Brazzavil)',
        'lo' => 'laos',
        'lo_LA' => 'laos (Laos)',
        'lt' => 'litva',
        'lt_LT' => 'litva (Litva)',
        'lu' => 'luba-katanqa',
        'lu_CD' => 'luba-katanqa (Konqo - Kinşasa)',
        'lv' => 'latış',
        'lv_LV' => 'latış (Latviya)',
        'mg' => 'malaqas',
        'mg_MG' => 'malaqas (Madaqaskar)',
        'mi' => 'māori',
        'mi_NZ' => 'māori (Yeni Zelandiya)',
        'mk' => 'makedon',
        'mk_MK' => 'makedon (Şimali Makedoniya)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (Hindistan)',
        'mn' => 'monqol',
        'mn_MN' => 'monqol (Monqolustan)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (Hindistan)',
        'ms' => 'malay',
        'ms_BN' => 'malay (Bruney)',
        'ms_ID' => 'malay (İndoneziya)',
        'ms_MY' => 'malay (Malayziya)',
        'ms_SG' => 'malay (Sinqapur)',
        'mt' => 'malta',
        'mt_MT' => 'malta (Malta)',
        'my' => 'birman',
        'my_MM' => 'birman (Myanma)',
        'nb' => 'bokmal norveç',
        'nb_NO' => 'bokmal norveç (Norveç)',
        'nb_SJ' => 'bokmal norveç (Svalbard və Yan-Mayen)',
        'nd' => 'şimali ndebele',
        'nd_ZW' => 'şimali ndebele (Zimbabve)',
        'ne' => 'nepal',
        'ne_IN' => 'nepal (Hindistan)',
        'ne_NP' => 'nepal (Nepal)',
        'nl' => 'holland',
        'nl_AW' => 'holland (Aruba)',
        'nl_BE' => 'holland (Belçika)',
        'nl_BQ' => 'holland (Karib Niderlandı)',
        'nl_CW' => 'holland (Kurasao)',
        'nl_NL' => 'holland (Niderland)',
        'nl_SR' => 'holland (Surinam)',
        'nl_SX' => 'holland (Sint-Marten)',
        'nn' => 'nünorsk norveç',
        'nn_NO' => 'nünorsk norveç (Norveç)',
        'no' => 'norveç',
        'no_NO' => 'norveç (Norveç)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Efiopiya)',
        'om_KE' => 'oromo (Keniya)',
        'or' => 'odiya',
        'or_IN' => 'odiya (Hindistan)',
        'os' => 'osetin',
        'os_GE' => 'osetin (Gürcüstan)',
        'os_RU' => 'osetin (Rusiya)',
        'pa' => 'pəncab',
        'pa_Arab' => 'pəncab (ərəb)',
        'pa_Arab_PK' => 'pəncab (ərəb, Pakistan)',
        'pa_Guru' => 'pəncab (qurmuxi)',
        'pa_Guru_IN' => 'pəncab (qurmuxi, Hindistan)',
        'pa_IN' => 'pəncab (Hindistan)',
        'pa_PK' => 'pəncab (Pakistan)',
        'pl' => 'polyak',
        'pl_PL' => 'polyak (Polşa)',
        'ps' => 'puştu',
        'ps_AF' => 'puştu (Əfqanıstan)',
        'ps_PK' => 'puştu (Pakistan)',
        'pt' => 'portuqal',
        'pt_AO' => 'portuqal (Anqola)',
        'pt_BR' => 'portuqal (Braziliya)',
        'pt_CH' => 'portuqal (İsveçrə)',
        'pt_CV' => 'portuqal (Kabo-Verde)',
        'pt_GQ' => 'portuqal (Ekvatorial Qvineya)',
        'pt_GW' => 'portuqal (Qvineya-Bisau)',
        'pt_LU' => 'portuqal (Lüksemburq)',
        'pt_MO' => 'portuqal (Makao XİR Çin)',
        'pt_MZ' => 'portuqal (Mozambik)',
        'pt_PT' => 'portuqal (Portuqaliya)',
        'pt_ST' => 'portuqal (San-Tome və Prinsipi)',
        'pt_TL' => 'portuqal (Şərqi Timor)',
        'qu' => 'keçua',
        'qu_BO' => 'keçua (Boliviya)',
        'qu_EC' => 'keçua (Ekvador)',
        'qu_PE' => 'keçua (Peru)',
        'rm' => 'romanş',
        'rm_CH' => 'romanş (İsveçrə)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumın',
        'ro_MD' => 'rumın (Moldova)',
        'ro_RO' => 'rumın (Rumıniya)',
        'ru' => 'rus',
        'ru_BY' => 'rus (Belarus)',
        'ru_KG' => 'rus (Qırğızıstan)',
        'ru_KZ' => 'rus (Qazaxıstan)',
        'ru_MD' => 'rus (Moldova)',
        'ru_RU' => 'rus (Rusiya)',
        'ru_UA' => 'rus (Ukrayna)',
        'rw' => 'kinyarvanda',
        'rw_RW' => 'kinyarvanda (Ruanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (Hindistan)',
        'sc' => 'sardin',
        'sc_IT' => 'sardin (İtaliya)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (ərəb)',
        'sd_Arab_PK' => 'sindhi (ərəb, Pakistan)',
        'sd_Deva' => 'sindhi (devanaqari)',
        'sd_Deva_IN' => 'sindhi (devanaqari, Hindistan)',
        'sd_IN' => 'sindhi (Hindistan)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'şimali sami',
        'se_FI' => 'şimali sami (Finlandiya)',
        'se_NO' => 'şimali sami (Norveç)',
        'se_SE' => 'şimali sami (İsveç)',
        'sg' => 'sanqo',
        'sg_CF' => 'sanqo (Mərkəzi Afrika Respublikası)',
        'sh' => 'serb-xorvat',
        'sh_BA' => 'serb-xorvat (Bosniya və Herseqovina)',
        'si' => 'sinhala',
        'si_LK' => 'sinhala (Şri-Lanka)',
        'sk' => 'slovak',
        'sk_SK' => 'slovak (Slovakiya)',
        'sl' => 'sloven',
        'sl_SI' => 'sloven (Sloveniya)',
        'sn' => 'şona',
        'sn_ZW' => 'şona (Zimbabve)',
        'so' => 'somali',
        'so_DJ' => 'somali (Cibuti)',
        'so_ET' => 'somali (Efiopiya)',
        'so_KE' => 'somali (Keniya)',
        'so_SO' => 'somali (Somali)',
        'sq' => 'alban',
        'sq_AL' => 'alban (Albaniya)',
        'sq_MK' => 'alban (Şimali Makedoniya)',
        'sr' => 'serb',
        'sr_BA' => 'serb (Bosniya və Herseqovina)',
        'sr_Cyrl' => 'serb (kiril)',
        'sr_Cyrl_BA' => 'serb (kiril, Bosniya və Herseqovina)',
        'sr_Cyrl_ME' => 'serb (kiril, Monteneqro)',
        'sr_Cyrl_RS' => 'serb (kiril, Serbiya)',
        'sr_Latn' => 'serb (latın)',
        'sr_Latn_BA' => 'serb (latın, Bosniya və Herseqovina)',
        'sr_Latn_ME' => 'serb (latın, Monteneqro)',
        'sr_Latn_RS' => 'serb (latın, Serbiya)',
        'sr_ME' => 'serb (Monteneqro)',
        'sr_RS' => 'serb (Serbiya)',
        'su' => 'sundan',
        'su_ID' => 'sundan (İndoneziya)',
        'su_Latn' => 'sundan (latın)',
        'su_Latn_ID' => 'sundan (latın, İndoneziya)',
        'sv' => 'isveç',
        'sv_AX' => 'isveç (Aland adaları)',
        'sv_FI' => 'isveç (Finlandiya)',
        'sv_SE' => 'isveç (İsveç)',
        'sw' => 'suahili',
        'sw_CD' => 'suahili (Konqo - Kinşasa)',
        'sw_KE' => 'suahili (Keniya)',
        'sw_TZ' => 'suahili (Tanzaniya)',
        'sw_UG' => 'suahili (Uqanda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (Hindistan)',
        'ta_LK' => 'tamil (Şri-Lanka)',
        'ta_MY' => 'tamil (Malayziya)',
        'ta_SG' => 'tamil (Sinqapur)',
        'te' => 'teluqu',
        'te_IN' => 'teluqu (Hindistan)',
        'tg' => 'tacik',
        'tg_TJ' => 'tacik (Tacikistan)',
        'th' => 'tay',
        'th_TH' => 'tay (Tailand)',
        'ti' => 'tiqrin',
        'ti_ER' => 'tiqrin (Eritreya)',
        'ti_ET' => 'tiqrin (Efiopiya)',
        'tk' => 'türkmən',
        'tk_TM' => 'türkmən (Türkmənistan)',
        'tl' => 'taqaloq',
        'tl_PH' => 'taqaloq (Filippin)',
        'to' => 'tonqa',
        'to_TO' => 'tonqa (Tonqa)',
        'tr' => 'türk',
        'tr_CY' => 'türk (Kipr)',
        'tr_TR' => 'türk (Türkiyə)',
        'tt' => 'tatar',
        'tt_RU' => 'tatar (Rusiya)',
        'ug' => 'uyğur',
        'ug_CN' => 'uyğur (Çin)',
        'uk' => 'ukrayna',
        'uk_UA' => 'ukrayna (Ukrayna)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Hindistan)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'özbək',
        'uz_AF' => 'özbək (Əfqanıstan)',
        'uz_Arab' => 'özbək (ərəb)',
        'uz_Arab_AF' => 'özbək (ərəb, Əfqanıstan)',
        'uz_Cyrl' => 'özbək (kiril)',
        'uz_Cyrl_UZ' => 'özbək (kiril, Özbəkistan)',
        'uz_Latn' => 'özbək (latın)',
        'uz_Latn_UZ' => 'özbək (latın, Özbəkistan)',
        'uz_UZ' => 'özbək (Özbəkistan)',
        'vi' => 'vyetnam',
        'vi_VN' => 'vyetnam (Vyetnam)',
        'wo' => 'volof',
        'wo_SN' => 'volof (Seneqal)',
        'xh' => 'xosa',
        'xh_ZA' => 'xosa (Cənub Afrika)',
        'yi' => 'idiş',
        'yi_001' => 'idiş (Dünya)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeriya)',
        'zh' => 'çin',
        'zh_CN' => 'çin (Çin)',
        'zh_HK' => 'çin (Honq Konq Xüsusi İnzibati Rayonu Çin)',
        'zh_Hans' => 'çin (sadələşmiş)',
        'zh_Hans_CN' => 'çin (sadələşmiş, Çin)',
        'zh_Hans_HK' => 'çin (sadələşmiş, Honq Konq Xüsusi İnzibati Rayonu Çin)',
        'zh_Hans_MO' => 'çin (sadələşmiş, Makao XİR Çin)',
        'zh_Hans_SG' => 'çin (sadələşmiş, Sinqapur)',
        'zh_Hant' => 'çin (ənənəvi)',
        'zh_Hant_HK' => 'çin (ənənəvi, Honq Konq Xüsusi İnzibati Rayonu Çin)',
        'zh_Hant_MO' => 'çin (ənənəvi, Makao XİR Çin)',
        'zh_Hant_TW' => 'çin (ənənəvi, Tayvan)',
        'zh_MO' => 'çin (Makao XİR Çin)',
        'zh_SG' => 'çin (Sinqapur)',
        'zh_TW' => 'çin (Tayvan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Cənub Afrika)',
    ],
];
