<?php

return [
    'Names' => [
        'Africa/Djibouti' => 'hora de África oriental (Yibutí)',
        'Asia/Pyongyang' => 'hora de Corea (Pionyang)',
        'Europe/Astrakhan' => 'hora de Moscú (Astrakhan)',
        'Europe/Kirov' => 'hora de Rusia (Kirov)',
        'Europe/Ulyanovsk' => 'hora de Moscú (Ulyanovsk)',
        'Indian/Chagos' => 'hora del Océano Índico (Chagos)',
        'Pacific/Enderbury' => 'hora de las islas Fénix (Enderbury)',
        'Pacific/Guam' => 'hora de Chamorro (Guam)',
        'Pacific/Honolulu' => 'hora de Hawái-Aleutianas (Honolulu)',
        'Pacific/Marquesas' => 'hora de las islas Marquesas',
        'Pacific/Saipan' => 'hora de Chamorro (Saipán)',
    ],
    'Meta' => [
    ],
];
