<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abcázio',
        'ace' => 'achém',
        'ach' => 'acoli',
        'ada' => 'adangme',
        'ady' => 'adigue',
        'ae' => 'avéstico',
        'af' => 'africâner',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'acadiano',
        'ale' => 'aleúte',
        'alt' => 'altai meridional',
        'am' => 'amárico',
        'an' => 'aragonês',
        'ang' => 'inglês arcaico',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'árabe',
        'arc' => 'aramaico',
        'arn' => 'mapudungun',
        'arp' => 'arapaho',
        'ars' => 'árabe négede',
        'arw' => 'arauaqui',
        'as' => 'assamês',
        'asa' => 'asu',
        'ast' => 'asturiano',
        'atj' => 'atikamekw',
        'av' => 'avárico',
        'awa' => 'awadhi',
        'ay' => 'aimará',
        'az' => 'azerbaijano',
        'ba' => 'bashkir',
        'bal' => 'balúchi',
        'ban' => 'balinês',
        'bas' => 'basa',
        'bax' => 'bamum',
        'bbj' => 'ghomala’',
        'be' => 'bielorrusso',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bfd' => 'bafut',
        'bg' => 'búlgaro',
        'bgn' => 'balúchi ocidental',
        'bho' => 'bhojpuri',
        'bi' => 'bislamá',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'bm' => 'bambara',
        'bn' => 'bengali',
        'bo' => 'tibetano',
        'br' => 'bretão',
        'bra' => 'braj',
        'brx' => 'bodo',
        'bs' => 'bósnio',
        'bss' => 'akoose',
        'bua' => 'buriato',
        'bug' => 'buginês',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumba',
        'ca' => 'catalão',
        'cad' => 'caddo',
        'car' => 'caribe',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'checheno',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'chibcha',
        'chg' => 'chagatai',
        'chk' => 'chuukese',
        'chm' => 'mari',
        'chn' => 'jargão Chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cheroqui',
        'chy' => 'cheiene',
        'ckb' => 'curdo central',
        'clc' => 'chilcotin',
        'co' => 'corso',
        'cop' => 'copta',
        'cr' => 'cree',
        'crg' => 'michif',
        'crh' => 'tártara da Crimeia',
        'crj' => 'cree do sudeste',
        'crk' => 'cree das planícies',
        'crl' => 'cree do nordeste',
        'crm' => 'moose cree',
        'crr' => 'algonquiano Carolina',
        'crs' => 'crioulo francês seichelense',
        'cs' => 'tcheco',
        'csb' => 'kashubian',
        'csw' => 'cree swampy',
        'cu' => 'eslavo eclesiástico',
        'cv' => 'tchuvache',
        'cy' => 'galês',
        'da' => 'dinamarquês',
        'dak' => 'dacota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'alemão',
        'del' => 'delaware',
        'den' => 'slave',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'baixo sorábio',
        'dua' => 'duala',
        'dum' => 'holandês médio',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dyu' => 'diúla',
        'dz' => 'dzonga',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efique',
        'egy' => 'egípcio arcaico',
        'eka' => 'ekajuk',
        'el' => 'grego',
        'elx' => 'elamite',
        'en' => 'inglês',
        'enm' => 'inglês médio',
        'eo' => 'esperanto',
        'es' => 'espanhol',
        'et' => 'estoniano',
        'eu' => 'basco',
        'ewo' => 'ewondo',
        'fa' => 'persa',
        'fan' => 'fangue',
        'fat' => 'fanti',
        'ff' => 'fula',
        'fi' => 'finlandês',
        'fil' => 'filipino',
        'fj' => 'fijiano',
        'fo' => 'feroês',
        'fon' => 'fom',
        'fr' => 'francês',
        'frc' => 'francês cajun',
        'frm' => 'francês médio',
        'fro' => 'francês arcaico',
        'frr' => 'frísio setentrional',
        'frs' => 'frisão oriental',
        'fur' => 'friulano',
        'fy' => 'frísio ocidental',
        'ga' => 'irlandês',
        'gaa' => 'ga',
        'gag' => 'gagauz',
        'gan' => 'gan',
        'gay' => 'gayo',
        'gba' => 'gbaia',
        'gd' => 'gaélico escocês',
        'gez' => 'geez',
        'gil' => 'gilbertês',
        'gl' => 'galego',
        'gmh' => 'alto alemão médio',
        'gn' => 'guarani',
        'goh' => 'alemão arcaico alto',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gótico',
        'grb' => 'grebo',
        'grc' => 'grego arcaico',
        'gsw' => 'alemão (Suíça)',
        'gu' => 'guzerate',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwichʼin',
        'ha' => 'hauçá',
        'hai' => 'haida',
        'hak' => 'hacá',
        'haw' => 'havaiano',
        'hax' => 'haida do sul',
        'he' => 'hebraico',
        'hi' => 'híndi',
        'hil' => 'hiligaynon',
        'hit' => 'hitita',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'croata',
        'hsb' => 'alto sorábio',
        'hsn' => 'xiang',
        'ht' => 'haitiano',
        'hu' => 'húngaro',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armênio',
        'hz' => 'herero',
        'ia' => 'interlíngua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonésio',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ik' => 'inupiaque',
        'ikt' => 'inuktitut canadense ocidental',
        'ilo' => 'ilocano',
        'inh' => 'inguche',
        'io' => 'ido',
        'is' => 'islandês',
        'it' => 'italiano',
        'iu' => 'inuktitut',
        'ja' => 'japonês',
        'jbo' => 'lojban',
        'jgo' => 'nguemba',
        'jmc' => 'machame',
        'jpr' => 'judaico-persa',
        'jrb' => 'judaico-arábico',
        'jv' => 'javanês',
        'ka' => 'georgiano',
        'kaa' => 'kara-kalpak',
        'kab' => 'kabyle',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardiano',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'maconde',
        'kea' => 'crioulo cabo-verdiano',
        'kfo' => 'koro',
        'kg' => 'congolês',
        'kgp' => 'caingangue',
        'kha' => 'khasi',
        'kho' => 'khotanês',
        'khq' => 'koyra chiini',
        'ki' => 'quicuio',
        'kj' => 'cuanhama',
        'kk' => 'cazaque',
        'kkj' => 'kako',
        'kl' => 'groenlandês',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'quimbundo',
        'kn' => 'canarim',
        'ko' => 'coreano',
        'koi' => 'komi-permyak',
        'kok' => 'concani',
        'kos' => 'kosraean',
        'kpe' => 'kpelle',
        'kr' => 'canúri',
        'krc' => 'karachay-balkar',
        'krl' => 'carélio',
        'kru' => 'kurukh',
        'ks' => 'caxemira',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'curdo',
        'kum' => 'kumyk',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'córnico',
        'kwk' => 'kwakʼwala',
        'ky' => 'quirguiz',
        'la' => 'latim',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxemburguês',
        'lez' => 'lezgui',
        'lg' => 'luganda',
        'li' => 'limburguês',
        'lil' => 'lillooet',
        'lkt' => 'lacota',
        'ln' => 'lingala',
        'lo' => 'laosiano',
        'lol' => 'mongo',
        'lou' => 'crioulo da Louisiana',
        'loz' => 'lozi',
        'lrc' => 'luri setentrional',
        'lsm' => 'saamia',
        'lt' => 'lituano',
        'lu' => 'luba-catanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'lushai',
        'luy' => 'luyia',
        'lv' => 'letão',
        'mad' => 'madurês',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'man' => 'mandinga',
        'mas' => 'massai',
        'mde' => 'maba',
        'mdf' => 'mocsa',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malgaxe',
        'mga' => 'irlandês médio',
        'mgh' => 'macua',
        'mgo' => 'meta’',
        'mh' => 'marshalês',
        'mi' => 'maori',
        'mic' => 'miquemaque',
        'min' => 'minangkabau',
        'mk' => 'macedônio',
        'ml' => 'malaiala',
        'mn' => 'mongol',
        'mnc' => 'manchu',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'moicano',
        'mos' => 'mossi',
        'mr' => 'marati',
        'ms' => 'malaio',
        'mt' => 'maltês',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandês',
        'mwr' => 'marwari',
        'my' => 'birmanês',
        'mye' => 'myene',
        'myv' => 'erzya',
        'mzn' => 'mazandarani',
        'na' => 'nauruano',
        'nan' => 'min nan',
        'nap' => 'napolitano',
        'naq' => 'nama',
        'nb' => 'bokmål norueguês',
        'nd' => 'ndebele do norte',
        'nds' => 'baixo alemão',
        'ne' => 'nepalês',
        'new' => 'newari',
        'ng' => 'dongo',
        'nia' => 'nias',
        'niu' => 'niueano',
        'nl' => 'holandês',
        'nmg' => 'kwasio',
        'nn' => 'nynorsk norueguês',
        'nnh' => 'ngiemboon',
        'no' => 'norueguês',
        'nog' => 'nogai',
        'non' => 'nórdico arcaico',
        'nqo' => 'n’ko',
        'nr' => 'ndebele do sul',
        'nso' => 'soto setentrional',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'nwc' => 'newari clássico',
        'ny' => 'nianja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'occitânico',
        'oj' => 'ojibwa',
        'ojb' => 'ojibwa do noroeste',
        'ojc' => 'ojibwa central',
        'ojs' => 'oji-cree',
        'ojw' => 'ojibwa ocidental',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'oriá',
        'os' => 'osseto',
        'osa' => 'osage',
        'ota' => 'turco otomano',
        'pa' => 'panjabi',
        'pag' => 'pangasinã',
        'pal' => 'pálavi',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palauano',
        'pcm' => 'pidgin nigeriano',
        'peo' => 'persa arcaico',
        'phn' => 'fenício',
        'pi' => 'páli',
        'pis' => 'pijin',
        'pl' => 'polonês',
        'pon' => 'pohnpeiano',
        'pqm' => 'malecite–passamaquoddy',
        'prg' => 'prussiano',
        'pro' => 'provençal arcaico',
        'ps' => 'pashto',
        'pt' => 'português',
        'qu' => 'quíchua',
        'quc' => 'quiché',
        'raj' => 'rajastani',
        'rap' => 'rapanui',
        'rar' => 'rarotongano',
        'rhg' => 'ruainga',
        'rm' => 'romanche',
        'rn' => 'rundi',
        'ro' => 'romeno',
        'rof' => 'rombo',
        'rom' => 'romani',
        'ru' => 'russo',
        'rup' => 'aromeno',
        'rw' => 'quiniaruanda',
        'rwk' => 'rwa',
        'sa' => 'sânscrito',
        'sad' => 'sandawe',
        'sah' => 'sakha',
        'sam' => 'aramaico samaritano',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardo',
        'scn' => 'siciliano',
        'sco' => 'scots',
        'sd' => 'sindi',
        'sdh' => 'curdo meridional',
        'se' => 'sami setentrional',
        'see' => 'seneca',
        'seh' => 'sena',
        'sel' => 'selkup',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'irlandês arcaico',
        'sh' => 'servo-croata',
        'shi' => 'tachelhit',
        'shn' => 'shan',
        'shu' => 'árabe chadiano',
        'si' => 'cingalês',
        'sid' => 'sidamo',
        'sk' => 'eslovaco',
        'sl' => 'esloveno',
        'slh' => 'lushootseed do sul',
        'sm' => 'samoano',
        'sma' => 'sami meridional',
        'smj' => 'sami de Lule',
        'smn' => 'lapão de Inari',
        'sms' => 'sami de Skolt',
        'sn' => 'xona',
        'snk' => 'soninquê',
        'so' => 'somali',
        'sog' => 'sogdiano',
        'sq' => 'albanês',
        'sr' => 'sérvio',
        'srn' => 'surinamês',
        'srr' => 'serere',
        'ss' => 'suázi',
        'ssy' => 'saho',
        'st' => 'soto do sul',
        'str' => 'salish do estreito norte',
        'su' => 'sundanês',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumério',
        'sv' => 'sueco',
        'sw' => 'suaíli',
        'swb' => 'comoriano',
        'syc' => 'siríaco clássico',
        'syr' => 'siríaco',
        'ta' => 'tâmil',
        'tce' => 'tutchone do sul',
        'te' => 'télugo',
        'tem' => 'timne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tétum',
        'tg' => 'tadjique',
        'tgx' => 'tagish',
        'th' => 'tailandês',
        'tht' => 'tahltan',
        'ti' => 'tigrínia',
        'tig' => 'tigré',
        'tiv' => 'tiv',
        'tk' => 'turcomeno',
        'tkl' => 'toquelauano',
        'tl' => 'tagalo',
        'tlh' => 'klingon',
        'tli' => 'tlinguite',
        'tmh' => 'tamaxeque',
        'tn' => 'tswana',
        'to' => 'tonganês',
        'tog' => 'tonganês de Nyasa',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turco',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsi' => 'tsimshiano',
        'tt' => 'tártaro',
        'ttm' => 'tutchone setentrional',
        'tum' => 'tumbuka',
        'tvl' => 'tuvaluano',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'taitiano',
        'tyv' => 'tuviniano',
        'tzm' => 'tamazight do Atlas Central',
        'udm' => 'udmurte',
        'ug' => 'uigur',
        'uga' => 'ugarítico',
        'uk' => 'ucraniano',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbeque',
        'vai' => 'vai',
        've' => 'venda',
        'vi' => 'vietnamita',
        'vo' => 'volapuque',
        'vot' => 'vótico',
        'vun' => 'vunjo',
        'wa' => 'valão',
        'wae' => 'walser',
        'wal' => 'wolaytta',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'uolofe',
        'wuu' => 'wu',
        'xal' => 'kalmyk',
        'xh' => 'xhosa',
        'xog' => 'lusoga',
        'yao' => 'yao',
        'yap' => 'yapese',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'iídiche',
        'yo' => 'iorubá',
        'yrl' => 'nheengatu',
        'yue' => 'cantonês',
        'za' => 'zhuang',
        'zap' => 'zapoteco',
        'zbl' => 'símbolos blis',
        'zen' => 'zenaga',
        'zgh' => 'tamazirte marroqino padrão',
        'zh' => 'chinês',
        'zu' => 'zulu',
        'zun' => 'zunhi',
        'zza' => 'zazaki',
    ],
    'LocalizedNames' => [
        'ar_001' => 'árabe moderno',
        'az_Arab' => 'azeri sul',
        'de_CH' => 'alto alemão (Suíça)',
        'fa_AF' => 'dari',
        'nds_NL' => 'baixo saxão',
        'nl_BE' => 'flamengo',
        'ro_MD' => 'moldávio',
        'sw_CD' => 'suaíli do Congo',
        'zh_Hans' => 'chinês simplificado',
        'zh_Hant' => 'chinês tradicional',
    ],
];
