<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Diami ti Awon Orílẹ́ède Arabu',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afugánì Afuganísítàànì',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Lẹ́ẹ̀kì Àlìbáníà',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Dírààmù Àmẹ́níà',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Gílídà Netherlands Antillean',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'kíwánsà Angola',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Pẹ́sò Agẹntínà',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Dọla ti Orílẹ́ède Ástràlìá',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Fuloríìnì Àrúbà',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Mánààtì Àsàbáíjáì',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Àmi Yíyípadà Bosnia-Herzegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Dọ́là Bábádọ̀ọ̀sì',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Tákà Báńgíládẹ̀ẹ̀ṣì',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Owó Lẹ́fì Bọ̀lìgéríà',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Dina ti Orílẹ́ède Báránì',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Faransi Bùùrúndì',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Dọ́là Bẹ̀múdà',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Dọ́là Bùrùnéì',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bọlifiánò Bọ̀lífíà',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Owó ti Orílẹ̀-èdè Brazil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Dọ́là Bàhámà',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Ìngọ́tírọ̀mù Bútàànì',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Pula Bọ̀tìsúwánà',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Rọ́bù Bẹ̀lárùùsì',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Dọ́là Bẹ̀lísè',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Dọ́là Kánádà',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Firanki Kongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Faransí Síwíìsì',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Pẹ́sò Ṣílè',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Yúànì Sháínà',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Reminibi ti Orílẹ́ède ṣáínà',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Pẹ́sò Kòlóḿbíà',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Kólọ́ọ̀nì Kosita Ríkà',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Pẹ́sò Yíyípadà Kúbà',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Pẹ́sò Kúbà',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Èsìkúdò Kapú Faadì',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Koruna Ṣẹ́ẹ̀kì',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Faransi Dibouti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Kírónì Dáníṣì',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Pẹ́sò Dòníníkà',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Dina ti Orílẹ́ède Àlùgèríánì',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'pọọn ti Orílẹ́ède Egipiti',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Nakifasì Eritira',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Báà Etópíà',
        ],
        'EUR' => [
            0 => '€',
            1 => 'owó Yúrò',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Dọ́là Fíjì',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Pọ́n-ùn Erékùsù Falkland',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Pọ́n-ùn ti Orilẹ̀-èdè Gẹ̀ẹ́sì',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Lárì Jọ́jíà',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'ṣidi ti Orílẹ́ède Gana',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'sídì Gana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Pọ́n-ùn Gibúrátà',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Dalasi Gamibia',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Fírànkì Gínì',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Faransi ti Orílẹ́ède Gini',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Kúẹ́tísààlì Guatimílà',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Dọ́là Gùyánà',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Dọ́là Hong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Lẹmipírà Ọ́ńdúrà',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kúnà Kúróṣíà',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Gọ́dì Àítì',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Fọ́ríǹtì Họ̀ngérí',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Rúpìyá Indonésíà',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Ṣékélì Tuntun Ísírẹ̀ẹ̀lì',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Rupi ti Orílẹ́ède Indina',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Dínárì Ìráákì',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Rial Iranian',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Kòrónà Icelandic',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Dọ́là Jàmáíkà',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Dínárì Jọ́dàànì',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Yeni ti Orílẹ́ède Japani',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Ṣiili Kenya',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Sómú Kirijísítàànì',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Ráyò Kàm̀bọ́díà',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Faransi Komori',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Wọ́ọ̀nù Àríwá Kòríà',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Wọ́ọ̀nù Gúúsù Kòríà',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Dínárì Kuwaiti',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Dọ́là Erékùsù Cayman',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Tẹngé Kasakísítàànì',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Kíììpù Làótì',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Pọ́n-ùn Lebanese',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Rúpìì Siri Láńkà',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Dọla Liberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Loti ti Orílẹ́ède Lesoto',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Dínà Líbíyà',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Dírámì Morokò',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Owó Léhù Moldovan',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Faransi Malagasi',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Dẹ́nà Masidóníà',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Kíyàtì Myanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Túgúrììkì Mòǹgólíà',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Pàtákà Màkáò',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Ouguiya ti Orílẹ́ède Maritania (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Ouguiya ti Orílẹ́ède Maritania',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Rupi Maritusi',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Rúfìyá Mọ̀lìdífà',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Kásà Màláwì',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Pẹ́sò Mẹ́síkò',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Ríngìtì Màléṣíà',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Metika ti Orílẹ́ède Mosamibiki',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mẹ́tíkààlì Mòsáḿbíìkì',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Dọla Namibíà',
        ],
        'NGN' => [
            0 => '₦',
            1 => 'Náírà Nàìjíríà',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Kọ̀dóbà Naikarágúà',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'kórónì Nọ́wè',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Rúpìì Nẹ̵́pààlì',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Dọ́là New Zealand',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Ráyò Omani',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Bálíbóà Pànámà',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Sólì Pèrúù',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Kínà Papua Guinea Tuntun',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'Písò Fílípìnì',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Rúpìì Pakisitánì',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Sílọ̀tì Pọ́líṣì',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Gúáránì Párágúwè',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Ráyò Kàtárì',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Léhù Ròméníà',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Dínárì Sàbíà',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'Owó ruble ti ilẹ̀ Rọ́ṣíà',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Faransi Ruwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Riya ti Orílẹ́ède Saudi',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Dọ́là Erékùsù Sọ́lómọ́nì',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Rúpì Sayiselesi',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Pọ́n-ùn Sùdáànì',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Pọọun ti Orílẹ́ède Sudani',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Kòrónà Súwídìn',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Dọ́là Síngápọ̀',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Pọ́n-un Elena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Líónì Sira Líonì',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Ṣílè Somali',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Dọ́là Súrínámì',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Pọ́n-un Gúúsù Sùdáànì',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Dobira ti Orílẹ́ède Sao tome Ati Pirisipe (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Dọbíra Sao tome àti Pirisipi',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Pọ́n-ùn Sírìà',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Lilangeni Suwasi',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'Báàtì Tháì',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Sómónì Tajikístàànì',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Mánààtì Tọkimẹnístàànì',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Dínà Tuniṣíà',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Pàángà Tóńgà',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Lírà Tọ́kì',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Dọ́là Trinidad & Tobago',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Dọ́là Tàìwánì Tuntun',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Sile Tansania',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ọrifiníyà Yukiréníà',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ṣile Uganda',
        ],
        'USD' => [
            0 => '$',
            1 => 'Dọ́là',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Pẹ́sò Úrúgúwè',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Sómú Usibẹkísítàànì',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Bọ̀lífà Fẹnẹsuẹ́là',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Dáhùn Vietnamese',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Fátù Vanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Tálà Sàmóà',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Firanki àárín Afíríkà',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Dọ́là Ilà Oòrùn Karíbíà',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Faransì ìwọ̀-oorùn Afíríkà',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'Fírànkì CFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Ráyò Yẹ́mẹ̀nì',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Rándì Gúúsù Afíríkà',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Kawaṣa ti Orílẹ́ède Saabia (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Kàwasà Sámbíà',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Dọla ti Orílẹ́ède Siibabuwe',
        ],
    ],
];
