<?php

return [
    'Names' => [
        'ak' => 'Kiakan',
        'ak_GH' => 'Kiakan (Ghana)',
        'ar_JO' => 'Kiarabu (Yordani)',
        'ar_LB' => 'Kiarabu (Lebanoni)',
        'ar_MA' => 'Kiarabu (Moroko)',
        'ar_OM' => 'Kiarabu (Omani)',
        'ar_QA' => 'Kiarabu (Katari)',
        'ar_SD' => 'Kiarabu (Sudani)',
        'ar_TD' => 'Kiarabu (Chadi)',
        'az' => 'Kiazabajani',
        'az_AZ' => 'Kiazabajani (Azabajani)',
        'az_Cyrl' => 'Kiazabajani (Kisiriliki)',
        'az_Cyrl_AZ' => 'Kiazabajani (Kisiriliki, Azabajani)',
        'az_Latn' => 'Kiazabajani (Kilatini)',
        'az_Latn_AZ' => 'Kiazabajani (Kilatini, Azabajani)',
        'de_LI' => 'Kijerumani (Lishenteni)',
        'de_LU' => 'Kijerumani (Lasembagi)',
        'en_CX' => 'Kiingereza (Kisiwa cha Christmas)',
        'en_NG' => 'Kiingereza (Nijeria)',
        'en_PR' => 'Kiingereza (Puetoriko)',
        'en_SD' => 'Kiingereza (Sudani)',
        'es_PR' => 'Kihispania (Puetoriko)',
        'fa_AF' => 'Kiajemi (Afuganistani)',
        'ff_Adlm_NE' => 'Kifulani (Kiadlamu, Nijeri)',
        'ff_Adlm_NG' => 'Kifulani (Kiadlamu, Nijeria)',
        'ff_Latn_NE' => 'Kifulani (Kilatini, Nijeri)',
        'ff_Latn_NG' => 'Kifulani (Kilatini, Nijeria)',
        'fr_BJ' => 'Kifaransa (Benini)',
        'fr_CI' => 'Kifaransa (Kodivaa)',
        'fr_LU' => 'Kifaransa (Lasembagi)',
        'fr_MA' => 'Kifaransa (Moroko)',
        'fr_NE' => 'Kifaransa (Nijeri)',
        'fr_TD' => 'Kifaransa (Chadi)',
        'gv' => 'Kimanksi',
        'gv_IM' => 'Kimanksi (Kisiwa cha Man)',
        'ha_NE' => 'Kihausa (Nijeri)',
        'ha_NG' => 'Kihausa (Nijeria)',
        'hr_HR' => 'Kikorasia (Kroeshia)',
        'ig_NG' => 'Kiigbo (Nijeria)',
        'ky' => 'Kikirigizi',
        'ky_KG' => 'Kikirigizi (Kirigizistani)',
        'lb_LU' => 'Kilasembagi (Lasembagi)',
        'lv_LV' => 'Kilatvia (Lativia)',
        'mk' => 'Kimasedonia',
        'mk_MK' => 'Kimasedonia (Masedonia ya Kaskazini)',
        'my_MM' => 'Kiburma (Myama)',
        'nb_NO' => 'Kinorwe cha Bokmal (Norwe)',
        'ne_NP' => 'Kinepali (Nepali)',
        'nn_NO' => 'Kinorwe cha Nynorsk (Norwe)',
        'no_NO' => 'Kinorwe (Norwe)',
        'ps_AF' => 'Kipashto (Afuganistani)',
        'pt_LU' => 'Kireno (Lasembagi)',
        'pt_ST' => 'Kireno (Sao Tome na Prinsipe)',
        'pt_TL' => 'Kireno (Timori ya Mashariki)',
        'se_NO' => 'Kisami cha Kaskazini (Norwe)',
        'uz_AF' => 'Kiuzbeki (Afuganistani)',
        'uz_Arab_AF' => 'Kiuzbeki (Kiarabu, Afuganistani)',
        'yi' => 'Kiyidi',
        'yi_001' => 'Kiyidi (Dunia)',
        'yo_BJ' => 'Kiyoruba (Benini)',
        'yo_NG' => 'Kiyoruba (Nijeria)',
    ],
];
