<?php

return [
    'Names' => [
        'BR' => 'Brazil',
        'CN' => 'China',
        'DE' => 'Germany',
        'ET' => 'Itoophiyaa',
        'FR' => 'France',
        'GB' => 'United Kingdom',
        'IN' => 'India',
        'IT' => 'Italy',
        'JP' => 'Japan',
        'KE' => 'Keeniyaa',
        'RU' => 'Russia',
        'US' => 'United States',
    ],
];
