<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намибия)',
        'af_ZA' => 'африкаанс (Көньяк Африка)',
        'am' => 'амхар',
        'am_ET' => 'амхар (Эфиопия)',
        'ar' => 'гарәп',
        'ar_AE' => 'гарәп (Берләшкән Гарәп Әмирлекләре)',
        'ar_BH' => 'гарәп (Бәхрәйн)',
        'ar_DJ' => 'гарәп (Җибүти)',
        'ar_DZ' => 'гарәп (Алжир)',
        'ar_EG' => 'гарәп (Мисыр)',
        'ar_ER' => 'гарәп (Эритрея)',
        'ar_IL' => 'гарәп (Израиль)',
        'ar_IQ' => 'гарәп (Гыйрак)',
        'ar_JO' => 'гарәп (Иордания)',
        'ar_KM' => 'гарәп (Комор утраулары)',
        'ar_KW' => 'гарәп (Күвәйт)',
        'ar_LB' => 'гарәп (Ливан)',
        'ar_LY' => 'гарәп (Ливия)',
        'ar_MA' => 'гарәп (Марокко)',
        'ar_MR' => 'гарәп (Мавритания)',
        'ar_OM' => 'гарәп (Оман)',
        'ar_QA' => 'гарәп (Катар)',
        'ar_SA' => 'гарәп (Согуд Гарәбстаны)',
        'ar_SD' => 'гарәп (Судан)',
        'ar_SO' => 'гарәп (Сомали)',
        'ar_SS' => 'гарәп (Көньяк Судан)',
        'ar_SY' => 'гарәп (Сүрия)',
        'ar_TD' => 'гарәп (Чад)',
        'ar_TN' => 'гарәп (Тунис)',
        'ar_YE' => 'гарәп (Йәмән)',
        'as' => 'ассам',
        'as_IN' => 'ассам (Индия)',
        'az' => 'әзәрбайҗан',
        'az_AZ' => 'әзәрбайҗан (Әзәрбайҗан)',
        'az_Cyrl' => 'әзәрбайҗан (кирилл)',
        'az_Cyrl_AZ' => 'әзәрбайҗан (кирилл, Әзәрбайҗан)',
        'az_Latn' => 'әзәрбайҗан (латин)',
        'az_Latn_AZ' => 'әзәрбайҗан (латин, Әзәрбайҗан)',
        'be' => 'белорус',
        'be_BY' => 'белорус (Беларусь)',
        'bg' => 'болгар',
        'bg_BG' => 'болгар (Болгария)',
        'bn' => 'бенгали',
        'bn_BD' => 'бенгали (Бангладеш)',
        'bn_IN' => 'бенгали (Индия)',
        'bo' => 'тибет',
        'bo_CN' => 'тибет (Кытай)',
        'bo_IN' => 'тибет (Индия)',
        'br' => 'бретон',
        'br_FR' => 'бретон (Франция)',
        'bs' => 'босния',
        'bs_BA' => 'босния (Босния һәм Герцеговина)',
        'bs_Cyrl' => 'босния (кирилл)',
        'bs_Cyrl_BA' => 'босния (кирилл, Босния һәм Герцеговина)',
        'bs_Latn' => 'босния (латин)',
        'bs_Latn_BA' => 'босния (латин, Босния һәм Герцеговина)',
        'ca' => 'каталан',
        'ca_AD' => 'каталан (Андорра)',
        'ca_ES' => 'каталан (Испания)',
        'ca_FR' => 'каталан (Франция)',
        'ca_IT' => 'каталан (Италия)',
        'cs' => 'чех',
        'cs_CZ' => 'чех (Чехия Республикасы)',
        'cy' => 'уэльс',
        'cy_GB' => 'уэльс (Берләшкән Корольлек)',
        'da' => 'дания',
        'da_DK' => 'дания (Дания)',
        'da_GL' => 'дания (Гренландия)',
        'de' => 'алман',
        'de_AT' => 'алман (Австрия)',
        'de_BE' => 'алман (Бельгия)',
        'de_CH' => 'алман (Швейцария)',
        'de_DE' => 'алман (Германия)',
        'de_IT' => 'алман (Италия)',
        'de_LI' => 'алман (Лихтенштейн)',
        'de_LU' => 'алман (Люксембург)',
        'dz' => 'дзонг-кха',
        'dz_BT' => 'дзонг-кха (Бутан)',
        'el' => 'грек',
        'el_CY' => 'грек (Кипр)',
        'el_GR' => 'грек (Греция)',
        'en' => 'инглиз',
        'en_AE' => 'инглиз (Берләшкән Гарәп Әмирлекләре)',
        'en_AG' => 'инглиз (Антигуа һәм Барбуда)',
        'en_AI' => 'инглиз (Ангилья)',
        'en_AS' => 'инглиз (Америка Самоасы)',
        'en_AT' => 'инглиз (Австрия)',
        'en_AU' => 'инглиз (Австралия)',
        'en_BB' => 'инглиз (Барбадос)',
        'en_BE' => 'инглиз (Бельгия)',
        'en_BI' => 'инглиз (Бурунди)',
        'en_BM' => 'инглиз (Бермуд утраулары)',
        'en_BS' => 'инглиз (Багам утраулары)',
        'en_BW' => 'инглиз (Ботсвана)',
        'en_BZ' => 'инглиз (Белиз)',
        'en_CA' => 'инглиз (Канада)',
        'en_CC' => 'инглиз (Кокос [Килинг] утраулары)',
        'en_CH' => 'инглиз (Швейцария)',
        'en_CK' => 'инглиз (Кук утраулары)',
        'en_CM' => 'инглиз (Камерун)',
        'en_CX' => 'инглиз (Раштуа утравы)',
        'en_CY' => 'инглиз (Кипр)',
        'en_DE' => 'инглиз (Германия)',
        'en_DK' => 'инглиз (Дания)',
        'en_DM' => 'инглиз (Доминика)',
        'en_ER' => 'инглиз (Эритрея)',
        'en_FI' => 'инглиз (Финляндия)',
        'en_FJ' => 'инглиз (Фиджи)',
        'en_FK' => 'инглиз (Фолкленд утраулары)',
        'en_FM' => 'инглиз (Микронезия)',
        'en_GB' => 'инглиз (Берләшкән Корольлек)',
        'en_GD' => 'инглиз (Гренада)',
        'en_GG' => 'инглиз (Гернси)',
        'en_GH' => 'инглиз (Гана)',
        'en_GI' => 'инглиз (Гибралтар)',
        'en_GM' => 'инглиз (Гамбия)',
        'en_GU' => 'инглиз (Гуам)',
        'en_GY' => 'инглиз (Гайана)',
        'en_HK' => 'инглиз (Гонконг Махсус Идарәле Төбәге)',
        'en_IE' => 'инглиз (Ирландия)',
        'en_IL' => 'инглиз (Израиль)',
        'en_IM' => 'инглиз (Мэн утравы)',
        'en_IN' => 'инглиз (Индия)',
        'en_IO' => 'инглиз (Британиянең Һинд Океанындагы Территориясе)',
        'en_JE' => 'инглиз (Джерси)',
        'en_JM' => 'инглиз (Ямайка)',
        'en_KE' => 'инглиз (Кения)',
        'en_KI' => 'инглиз (Кирибати)',
        'en_KN' => 'инглиз (Сент-Китс һәм Невис)',
        'en_KY' => 'инглиз (Кайман утраулары)',
        'en_LC' => 'инглиз (Сент-Люсия)',
        'en_LR' => 'инглиз (Либерия)',
        'en_LS' => 'инглиз (Лесото)',
        'en_MG' => 'инглиз (Мадагаскар)',
        'en_MH' => 'инглиз (Маршалл утраулары)',
        'en_MO' => 'инглиз (Макао Махсус Идарәле Төбәге)',
        'en_MP' => 'инглиз (Төньяк Мариана утраулары)',
        'en_MS' => 'инглиз (Монтсеррат)',
        'en_MT' => 'инглиз (Мальта)',
        'en_MU' => 'инглиз (Маврикий)',
        'en_MV' => 'инглиз (Мальдив утраулары)',
        'en_MW' => 'инглиз (Малави)',
        'en_MY' => 'инглиз (Малайзия)',
        'en_NA' => 'инглиз (Намибия)',
        'en_NF' => 'инглиз (Норфолк утравы)',
        'en_NG' => 'инглиз (Нигерия)',
        'en_NL' => 'инглиз (Нидерланд)',
        'en_NR' => 'инглиз (Науру)',
        'en_NU' => 'инглиз (Ниуэ)',
        'en_NZ' => 'инглиз (Яңа Зеландия)',
        'en_PG' => 'инглиз (Папуа - Яңа Гвинея)',
        'en_PH' => 'инглиз (Филиппин)',
        'en_PK' => 'инглиз (Пакистан)',
        'en_PN' => 'инглиз (Питкэрн утраулары)',
        'en_PR' => 'инглиз (Пуэрто-Рико)',
        'en_PW' => 'инглиз (Палау)',
        'en_RW' => 'инглиз (Руанда)',
        'en_SB' => 'инглиз (Сөләйман утраулары)',
        'en_SC' => 'инглиз (Сейшел утраулары)',
        'en_SD' => 'инглиз (Судан)',
        'en_SE' => 'инглиз (Швеция)',
        'en_SG' => 'инглиз (Сингапур)',
        'en_SI' => 'инглиз (Словения)',
        'en_SL' => 'инглиз (Сьерра-Леоне)',
        'en_SS' => 'инглиз (Көньяк Судан)',
        'en_SX' => 'инглиз (Синт-Мартен)',
        'en_SZ' => 'инглиз (Свазиленд)',
        'en_TC' => 'инглиз (Теркс һәм Кайкос утраулары)',
        'en_TK' => 'инглиз (Токелау)',
        'en_TO' => 'инглиз (Тонга)',
        'en_TT' => 'инглиз (Тринидад һәм Тобаго)',
        'en_TV' => 'инглиз (Тувалу)',
        'en_TZ' => 'инглиз (Танзания)',
        'en_UG' => 'инглиз (Уганда)',
        'en_UM' => 'инглиз (АКШ Кече Читтәге утраулары)',
        'en_US' => 'инглиз (АКШ)',
        'en_VC' => 'инглиз (Сент-Винсент һәм Гренадин)',
        'en_VG' => 'инглиз (Британия Виргин утраулары)',
        'en_VI' => 'инглиз (АКШ Виргин утраулары)',
        'en_VU' => 'инглиз (Вануату)',
        'en_WS' => 'инглиз (Самоа)',
        'en_ZA' => 'инглиз (Көньяк Африка)',
        'en_ZM' => 'инглиз (Замбия)',
        'en_ZW' => 'инглиз (Зимбабве)',
        'eo' => 'эсперанто',
        'es' => 'испан',
        'es_AR' => 'испан (Аргентина)',
        'es_BO' => 'испан (Боливия)',
        'es_BR' => 'испан (Бразилия)',
        'es_BZ' => 'испан (Белиз)',
        'es_CL' => 'испан (Чили)',
        'es_CO' => 'испан (Колумбия)',
        'es_CR' => 'испан (Коста-Рика)',
        'es_CU' => 'испан (Куба)',
        'es_DO' => 'испан (Доминикана Республикасы)',
        'es_EC' => 'испан (Эквадор)',
        'es_ES' => 'испан (Испания)',
        'es_GQ' => 'испан (Экваториаль Гвинея)',
        'es_GT' => 'испан (Гватемала)',
        'es_HN' => 'испан (Гондурас)',
        'es_MX' => 'испан (Мексика)',
        'es_NI' => 'испан (Никарагуа)',
        'es_PA' => 'испан (Панама)',
        'es_PE' => 'испан (Перу)',
        'es_PH' => 'испан (Филиппин)',
        'es_PR' => 'испан (Пуэрто-Рико)',
        'es_PY' => 'испан (Парагвай)',
        'es_SV' => 'испан (Сальвадор)',
        'es_US' => 'испан (АКШ)',
        'es_UY' => 'испан (Уругвай)',
        'es_VE' => 'испан (Венесуэла)',
        'et' => 'эстон',
        'et_EE' => 'эстон (Эстония)',
        'eu' => 'баск',
        'eu_ES' => 'баск (Испания)',
        'fa' => 'фарсы',
        'fa_AF' => 'фарсы (Әфганстан)',
        'fa_IR' => 'фарсы (Иран)',
        'ff' => 'фула',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвинея)',
        'ff_Latn' => 'фула (латин)',
        'ff_Latn_BF' => 'фула (латин, Буркина-Фасо)',
        'ff_Latn_CM' => 'фула (латин, Камерун)',
        'ff_Latn_GH' => 'фула (латин, Гана)',
        'ff_Latn_GM' => 'фула (латин, Гамбия)',
        'ff_Latn_GN' => 'фула (латин, Гвинея)',
        'ff_Latn_GW' => 'фула (латин, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фула (латин, Либерия)',
        'ff_Latn_MR' => 'фула (латин, Мавритания)',
        'ff_Latn_NE' => 'фула (латин, Нигер)',
        'ff_Latn_NG' => 'фула (латин, Нигерия)',
        'ff_Latn_SL' => 'фула (латин, Сьерра-Леоне)',
        'ff_Latn_SN' => 'фула (латин, Сенегал)',
        'ff_MR' => 'фула (Мавритания)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фин',
        'fi_FI' => 'фин (Финляндия)',
        'fo' => 'фарер',
        'fo_DK' => 'фарер (Дания)',
        'fo_FO' => 'фарер (Фарер утраулары)',
        'fr' => 'француз',
        'fr_BE' => 'француз (Бельгия)',
        'fr_BF' => 'француз (Буркина-Фасо)',
        'fr_BI' => 'француз (Бурунди)',
        'fr_BJ' => 'француз (Бенин)',
        'fr_BL' => 'француз (Сен-Бартельми)',
        'fr_CA' => 'француз (Канада)',
        'fr_CD' => 'француз (Конго [КДР])',
        'fr_CF' => 'француз (Үзәк Африка Республикасы)',
        'fr_CH' => 'француз (Швейцария)',
        'fr_CI' => 'француз (Кот-д’Ивуар)',
        'fr_CM' => 'француз (Камерун)',
        'fr_DJ' => 'француз (Җибүти)',
        'fr_DZ' => 'француз (Алжир)',
        'fr_FR' => 'француз (Франция)',
        'fr_GA' => 'француз (Габон)',
        'fr_GF' => 'француз (Француз Гвианасы)',
        'fr_GN' => 'француз (Гвинея)',
        'fr_GP' => 'француз (Гваделупа)',
        'fr_GQ' => 'француз (Экваториаль Гвинея)',
        'fr_HT' => 'француз (Гаити)',
        'fr_KM' => 'француз (Комор утраулары)',
        'fr_LU' => 'француз (Люксембург)',
        'fr_MA' => 'француз (Марокко)',
        'fr_MC' => 'француз (Монако)',
        'fr_MF' => 'француз (Сент-Мартин)',
        'fr_MG' => 'француз (Мадагаскар)',
        'fr_ML' => 'француз (Мали)',
        'fr_MQ' => 'француз (Мартиника)',
        'fr_MR' => 'француз (Мавритания)',
        'fr_MU' => 'француз (Маврикий)',
        'fr_NC' => 'француз (Яңа Каледония)',
        'fr_NE' => 'француз (Нигер)',
        'fr_PF' => 'француз (Француз Полинезиясе)',
        'fr_PM' => 'француз (Сен-Пьер һәм Микелон)',
        'fr_RE' => 'француз (Реюньон)',
        'fr_RW' => 'француз (Руанда)',
        'fr_SC' => 'француз (Сейшел утраулары)',
        'fr_SN' => 'француз (Сенегал)',
        'fr_SY' => 'француз (Сүрия)',
        'fr_TD' => 'француз (Чад)',
        'fr_TG' => 'француз (Того)',
        'fr_TN' => 'француз (Тунис)',
        'fr_VU' => 'француз (Вануату)',
        'fr_WF' => 'француз (Уоллис һәм Футуна)',
        'fr_YT' => 'француз (Майотта)',
        'ga' => 'ирланд',
        'ga_GB' => 'ирланд (Берләшкән Корольлек)',
        'ga_IE' => 'ирланд (Ирландия)',
        'gd' => 'шотланд гэль',
        'gd_GB' => 'шотланд гэль (Берләшкән Корольлек)',
        'gl' => 'галисия',
        'gl_ES' => 'галисия (Испания)',
        'gu' => 'гуҗарати',
        'gu_IN' => 'гуҗарати (Индия)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигерия)',
        'he' => 'яһүд',
        'he_IL' => 'яһүд (Израиль)',
        'hi' => 'һинд',
        'hi_IN' => 'һинд (Индия)',
        'hi_Latn' => 'һинд (латин)',
        'hi_Latn_IN' => 'һинд (латин, Индия)',
        'hr' => 'хорват',
        'hr_BA' => 'хорват (Босния һәм Герцеговина)',
        'hr_HR' => 'хорват (Хорватия)',
        'hu' => 'венгр',
        'hu_HU' => 'венгр (Венгрия)',
        'hy' => 'әрмән',
        'hy_AM' => 'әрмән (Әрмәнстан)',
        'id' => 'индонезия',
        'id_ID' => 'индонезия (Индонезия)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерия)',
        'is' => 'исланд',
        'is_IS' => 'исланд (Исландия)',
        'it' => 'итальян',
        'it_CH' => 'итальян (Швейцария)',
        'it_IT' => 'итальян (Италия)',
        'it_SM' => 'итальян (Сан-Марино)',
        'ja' => 'япон',
        'ja_JP' => 'япон (Япония)',
        'ka' => 'грузин',
        'ka_GE' => 'грузин (Грузия)',
        'kk' => 'казакъ',
        'kk_KZ' => 'казакъ (Казахстан)',
        'km' => 'кхмер',
        'km_KH' => 'кхмер (Камбоджа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Индия)',
        'ko' => 'корея',
        'ko_KP' => 'корея (Төньяк Корея)',
        'ks' => 'кашмири',
        'ks_Arab' => 'кашмири (гарәп)',
        'ks_Arab_IN' => 'кашмири (гарәп, Индия)',
        'ks_IN' => 'кашмири (Индия)',
        'ku' => 'көрд',
        'ku_TR' => 'көрд (Төркия)',
        'ky' => 'кыргыз',
        'ky_KG' => 'кыргыз (Кыргызстан)',
        'lb' => 'люксембург',
        'lb_LU' => 'люксембург (Люксембург)',
        'lo' => 'лаос',
        'lo_LA' => 'лаос (Лаос)',
        'lt' => 'литва',
        'lt_LT' => 'литва (Литва)',
        'lv' => 'латыш',
        'lv_LV' => 'латыш (Латвия)',
        'mg' => 'малагаси',
        'mg_MG' => 'малагаси (Мадагаскар)',
        'mi' => 'маори',
        'mi_NZ' => 'маори (Яңа Зеландия)',
        'mk' => 'македон',
        'mk_MK' => 'македон (Төньяк Македония)',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (Индия)',
        'mn' => 'монгол',
        'mn_MN' => 'монгол (Монголия)',
        'mr' => 'маратхи',
        'mr_IN' => 'маратхи (Индия)',
        'ms' => 'малай',
        'ms_BN' => 'малай (Бруней)',
        'ms_ID' => 'малай (Индонезия)',
        'ms_MY' => 'малай (Малайзия)',
        'ms_SG' => 'малай (Сингапур)',
        'mt' => 'мальта',
        'mt_MT' => 'мальта (Мальта)',
        'my' => 'бирма',
        'ne' => 'непали',
        'ne_IN' => 'непали (Индия)',
        'ne_NP' => 'непали (Непал)',
        'nl' => 'голланд',
        'nl_AW' => 'голланд (Аруба)',
        'nl_BE' => 'голланд (Бельгия)',
        'nl_CW' => 'голланд (Кюрасао)',
        'nl_NL' => 'голланд (Нидерланд)',
        'nl_SR' => 'голланд (Суринам)',
        'nl_SX' => 'голланд (Синт-Мартен)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Эфиопия)',
        'om_KE' => 'оромо (Кения)',
        'or' => 'ория',
        'or_IN' => 'ория (Индия)',
        'pa' => 'пәнҗаби',
        'pa_Arab' => 'пәнҗаби (гарәп)',
        'pa_Arab_PK' => 'пәнҗаби (гарәп, Пакистан)',
        'pa_IN' => 'пәнҗаби (Индия)',
        'pa_PK' => 'пәнҗаби (Пакистан)',
        'pl' => 'поляк',
        'pl_PL' => 'поляк (Польша)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Әфганстан)',
        'ps_PK' => 'пушту (Пакистан)',
        'pt' => 'португал',
        'pt_AO' => 'португал (Ангола)',
        'pt_BR' => 'португал (Бразилия)',
        'pt_CH' => 'португал (Швейцария)',
        'pt_CV' => 'португал (Кабо-Верде)',
        'pt_GQ' => 'португал (Экваториаль Гвинея)',
        'pt_GW' => 'португал (Гвинея-Бисау)',
        'pt_LU' => 'португал (Люксембург)',
        'pt_MO' => 'португал (Макао Махсус Идарәле Төбәге)',
        'pt_MZ' => 'португал (Мозамбик)',
        'pt_PT' => 'португал (Португалия)',
        'pt_ST' => 'португал (Сан-Томе һәм Принсипи)',
        'pt_TL' => 'португал (Тимор-Лесте)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливия)',
        'qu_EC' => 'кечуа (Эквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'ретороман',
        'rm_CH' => 'ретороман (Швейцария)',
        'ro' => 'румын',
        'ro_MD' => 'румын (Молдова)',
        'ro_RO' => 'румын (Румыния)',
        'ru' => 'рус',
        'ru_BY' => 'рус (Беларусь)',
        'ru_KG' => 'рус (Кыргызстан)',
        'ru_KZ' => 'рус (Казахстан)',
        'ru_MD' => 'рус (Молдова)',
        'ru_RU' => 'рус (Россия)',
        'ru_UA' => 'рус (Украина)',
        'rw' => 'руанда',
        'rw_RW' => 'руанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Индия)',
        'sd' => 'синдһи',
        'sd_Arab' => 'синдһи (гарәп)',
        'sd_Arab_PK' => 'синдһи (гарәп, Пакистан)',
        'sd_IN' => 'синдһи (Индия)',
        'sd_PK' => 'синдһи (Пакистан)',
        'se' => 'төньяк саам',
        'se_FI' => 'төньяк саам (Финляндия)',
        'se_NO' => 'төньяк саам (Норвегия)',
        'se_SE' => 'төньяк саам (Швеция)',
        'si' => 'сингал',
        'si_LK' => 'сингал (Шри-Ланка)',
        'sk' => 'словак',
        'sk_SK' => 'словак (Словакия)',
        'sl' => 'словен',
        'sl_SI' => 'словен (Словения)',
        'so' => 'сомали',
        'so_DJ' => 'сомали (Җибүти)',
        'so_ET' => 'сомали (Эфиопия)',
        'so_KE' => 'сомали (Кения)',
        'so_SO' => 'сомали (Сомали)',
        'sq' => 'албан',
        'sq_AL' => 'албан (Албания)',
        'sq_MK' => 'албан (Төньяк Македония)',
        'sr' => 'серб',
        'sr_BA' => 'серб (Босния һәм Герцеговина)',
        'sr_Cyrl' => 'серб (кирилл)',
        'sr_Cyrl_BA' => 'серб (кирилл, Босния һәм Герцеговина)',
        'sr_Cyrl_ME' => 'серб (кирилл, Черногория)',
        'sr_Cyrl_RS' => 'серб (кирилл, Сербия)',
        'sr_Latn' => 'серб (латин)',
        'sr_Latn_BA' => 'серб (латин, Босния һәм Герцеговина)',
        'sr_Latn_ME' => 'серб (латин, Черногория)',
        'sr_Latn_RS' => 'серб (латин, Сербия)',
        'sr_ME' => 'серб (Черногория)',
        'sr_RS' => 'серб (Сербия)',
        'sv' => 'швед',
        'sv_AX' => 'швед (Аланд утраулары)',
        'sv_FI' => 'швед (Финляндия)',
        'sv_SE' => 'швед (Швеция)',
        'ta' => 'тамил',
        'ta_IN' => 'тамил (Индия)',
        'ta_LK' => 'тамил (Шри-Ланка)',
        'ta_MY' => 'тамил (Малайзия)',
        'ta_SG' => 'тамил (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Индия)',
        'tg' => 'таҗик',
        'tg_TJ' => 'таҗик (Таҗикстан)',
        'th' => 'тай',
        'th_TH' => 'тай (Тайланд)',
        'ti' => 'тигринья',
        'ti_ER' => 'тигринья (Эритрея)',
        'ti_ET' => 'тигринья (Эфиопия)',
        'tk' => 'төрекмән',
        'tk_TM' => 'төрекмән (Төркмәнстан)',
        'to' => 'тонга',
        'to_TO' => 'тонга (Тонга)',
        'tr' => 'төрек',
        'tr_CY' => 'төрек (Кипр)',
        'tr_TR' => 'төрек (Төркия)',
        'tt' => 'татар',
        'tt_RU' => 'татар (Россия)',
        'ug' => 'уйгыр',
        'ug_CN' => 'уйгыр (Кытай)',
        'uk' => 'украин',
        'uk_UA' => 'украин (Украина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Индия)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'үзбәк',
        'uz_AF' => 'үзбәк (Әфганстан)',
        'uz_Arab' => 'үзбәк (гарәп)',
        'uz_Arab_AF' => 'үзбәк (гарәп, Әфганстан)',
        'uz_Cyrl' => 'үзбәк (кирилл)',
        'uz_Cyrl_UZ' => 'үзбәк (кирилл, Үзбәкстан)',
        'uz_Latn' => 'үзбәк (латин)',
        'uz_Latn_UZ' => 'үзбәк (латин, Үзбәкстан)',
        'uz_UZ' => 'үзбәк (Үзбәкстан)',
        'vi' => 'вьетнам',
        'vi_VN' => 'вьетнам (Вьетнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенин)',
        'yo_NG' => 'йоруба (Нигерия)',
        'zh' => 'кытай',
        'zh_CN' => 'кытай (Кытай)',
        'zh_HK' => 'кытай (Гонконг Махсус Идарәле Төбәге)',
        'zh_Hans' => 'кытай (гадиләштерелгән)',
        'zh_Hans_CN' => 'кытай (гадиләштерелгән, Кытай)',
        'zh_Hans_HK' => 'кытай (гадиләштерелгән, Гонконг Махсус Идарәле Төбәге)',
        'zh_Hans_MO' => 'кытай (гадиләштерелгән, Макао Махсус Идарәле Төбәге)',
        'zh_Hans_SG' => 'кытай (гадиләштерелгән, Сингапур)',
        'zh_Hant' => 'кытай (традицион)',
        'zh_Hant_HK' => 'кытай (традицион, Гонконг Махсус Идарәле Төбәге)',
        'zh_Hant_MO' => 'кытай (традицион, Макао Махсус Идарәле Төбәге)',
        'zh_Hant_TW' => 'кытай (традицион, Тайвань)',
        'zh_MO' => 'кытай (Макао Махсус Идарәле Төбәге)',
        'zh_SG' => 'кытай (Сингапур)',
        'zh_TW' => 'кытай (Тайвань)',
    ],
];
