<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'Біріккен Араб Әмірліктерінің дирхамы',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Ауғанстан афганиі',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Албания легі',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Армения драмы',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Нидерланд антиль гульдені',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Ангола кванзасы',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Аргентина песосы',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'Аустралия доллары',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Аруба флорині',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Әзірбайжан манаты',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Босния және Герцеговина айырбасталмалы маркасы',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Барбадос доллары',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Бангладеш такасы',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Болгария леві',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Бахрейн динары',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Бурунди франкі',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Бермуд доллары',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Бруней доллары',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Боливия боливианосы',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Бразилия реалы',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Багам доллары',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Бутан нгултрумы',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Ботсвана пуласы',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Беларусь рублі',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Беларусь рублі (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Белиз доллары',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Канада доллары',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Конго франкі',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Швейцария франкі',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Чили песосы',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Қытай юані (офшор)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Қытай юані',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Колумбия песосы',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Коста-Рика колоны',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Куба айырбасталмалы песосы',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Куба песосы',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Кабо-Верде эскудосы',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Чехия кронасы',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Джибути франкі',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Дат кроны',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Доминикан песосы',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Алжир динары',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Мысыр фунты',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Эритрея накфасы',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Эфиопия быры',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Еуро',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Фиджи доллары',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Фолкленд аралдарының фунты',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Британдық фунт',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Грузия лариі',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Гана седиі',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Гибралтар фунты',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Гамбия даласиі',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Гвинея франкі',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Гватемала кетсалі',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Гайана доллары',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Гонконг доллары',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Гондурас лемпирасы',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Хорватия кунасы',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Гаити гурды',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Венгрия форинті',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Индонезия рупиясы',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Израиль жаңа шекелі',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Үндістан рупиясы',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Ирак динары',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Иран риалы',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Исландия кронасы',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Ямайка доллары',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Иордания динары',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Жапония иенасы',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Кения шиллингі',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Қырғызстан сомы',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Камбоджа риелі',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Комор аралдары франкі',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Солтүстік Корея воны',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Оңтүстік Корея воны',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Кувейт динары',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Кайман аралдары доллары',
        ],
        'KZT' => [
            0 => '₸',
            1 => 'Қазақстан теңгесі',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Лаос кипі',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Ливан фунты',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Шри-Ланка рупиясы',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Либерия доллары',
        ],
        'LSL' => [
            0 => 'ЛСЛ',
            1 => 'Лесото лотиі',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Литва литы',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Латвия латы',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Ливия динары',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Марокко дирхамы',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Молдова лейі',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Малагаси ариариі',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Македония динары',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Мьянма кьяты',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Моңғолия тугригі',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Макао патакасы',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Мавритания угиясы (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Мавритания угиясы',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Маврикий рупиясы',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Мальдив руфиясы',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Малави квачасы',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Мексика песосы',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Малайзия ринггиті',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Мозамбик метикалы',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Намибия доллары',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Нигерия найрасы',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Никарагуа кордобасы',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Норвегия кроны',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Непал рупиясы',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Жаңа Зеландия доллары',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Оман риалы',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Панама бальбоасы',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Перу солі',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Папуа - Жаңа Гвинея кинасы',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Филиппин песосы',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Пәкістан рупиясы',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Польша злотасы',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Парагвай гуараниі',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Катар риалы',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Румыния лейі',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Сербия динары',
        ],
        'RUB' => [
            0 => '₽',
            1 => 'Ресей рублі',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Руанда франкі',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Сауд Арабиясының риалы',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Соломон аралдары доллары',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Сейшель рупиясы',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Судан фунты',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Швеция кроны',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Сингапур доллары',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Әулие Елена аралы фунты',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Сьерра-Леоне леонесі',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Сомали шиллингі',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Суринам доллары',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Оңтүстік Судан фунты',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Сант-Томе мен Принсипи добрасы (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Сант-Томе мен Принсипи добрасы',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Сирия фунты',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Свазиленд лилангениі',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Тай баты',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Тәжікстан сомониі',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Түрікменстан манаты',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Тунис динары',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Тонга паангасы',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Түрік лирасы',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Тринидад және Тобаго доллары',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Жаңа Тайвань доллары',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Танзания шиллингі',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Украина гривнасы',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Уганда шиллингі',
        ],
        'USD' => [
            0 => '$',
            1 => 'АҚШ доллары',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Уругвай песосы',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Өзбекстан сомы',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Венесуэла боливары (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Венесуэла боливары',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Вьетнам донгі',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Вануату ватуы',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Самоа таласы',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Орталық Африканың КФА франкі',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Шығыс Кариб доллары',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'Батыс Африканың КФА франкі',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'КФП франкі',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Йемен риалы',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Оңтүстік Африка рэнді',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Замбия квачасы',
        ],
    ],
];
