<?php

return [
    'Names' => [
        'ak_GH' => '阿坎文（加納）',
        'am_ET' => '阿姆哈拉文（埃塞俄比亞）',
        'ar_AE' => '阿拉伯文（阿拉伯聯合酋長國）',
        'ar_DJ' => '阿拉伯文（吉布提）',
        'ar_ER' => '阿拉伯文（厄立特里亞）',
        'ar_KM' => '阿拉伯文（科摩羅）',
        'ar_MR' => '阿拉伯文（毛里塔尼亞）',
        'ar_PS' => '阿拉伯文（巴勒斯坦領土）',
        'ar_QA' => '阿拉伯文（卡塔爾）',
        'ar_SA' => '阿拉伯文（沙地阿拉伯）',
        'ar_SO' => '阿拉伯文（索馬里）',
        'ar_TD' => '阿拉伯文（乍得）',
        'ar_YE' => '阿拉伯文（也門）',
        'az' => '阿塞拜疆文',
        'az_AZ' => '阿塞拜疆文（亞塞拜疆）',
        'az_Cyrl' => '阿塞拜疆文（西里爾文）',
        'az_Cyrl_AZ' => '阿塞拜疆文（西里爾文，亞塞拜疆）',
        'az_Latn' => '阿塞拜疆文（拉丁字母）',
        'az_Latn_AZ' => '阿塞拜疆文（拉丁字母，亞塞拜疆）',
        'bm_ML' => '班巴拉文（馬里）',
        'br' => '布里多尼文',
        'br_FR' => '布里多尼文（法國）',
        'bs' => '波斯尼亞文',
        'bs_BA' => '波斯尼亞文（波斯尼亞和黑塞哥維那）',
        'bs_Cyrl' => '波斯尼亞文（西里爾文）',
        'bs_Cyrl_BA' => '波斯尼亞文（西里爾文，波斯尼亞和黑塞哥維那）',
        'bs_Latn' => '波斯尼亞文（拉丁字母）',
        'bs_Latn_BA' => '波斯尼亞文（拉丁字母，波斯尼亞和黑塞哥維那）',
        'ca' => '加泰隆尼亞文',
        'ca_AD' => '加泰隆尼亞文（安道爾）',
        'ca_ES' => '加泰隆尼亞文（西班牙）',
        'ca_FR' => '加泰隆尼亞文（法國）',
        'ca_IT' => '加泰隆尼亞文（意大利）',
        'de_IT' => '德文（意大利）',
        'de_LI' => '德文（列支敦士登）',
        'ee_GH' => '埃維文（加納）',
        'el_CY' => '希臘文（塞浦路斯）',
        'en_AE' => '英文（阿拉伯聯合酋長國）',
        'en_AG' => '英文（安提瓜和巴布達）',
        'en_BB' => '英文（巴巴多斯）',
        'en_BI' => '英文（布隆迪）',
        'en_BW' => '英文（博茨瓦納）',
        'en_BZ' => '英文（伯利茲）',
        'en_CC' => '英文（科科斯 [基林] 群島）',
        'en_CY' => '英文（塞浦路斯）',
        'en_ER' => '英文（厄立特里亞）',
        'en_GD' => '英文（格林納達）',
        'en_GH' => '英文（加納）',
        'en_GM' => '英文（岡比亞）',
        'en_GY' => '英文（圭亞那）',
        'en_IM' => '英文（馬恩島）',
        'en_KE' => '英文（肯尼亞）',
        'en_KN' => '英文（聖基茨和尼維斯）',
        'en_LC' => '英文（聖盧西亞）',
        'en_LR' => '英文（利比里亞）',
        'en_LS' => '英文（萊索托）',
        'en_MS' => '英文（蒙特塞拉特）',
        'en_MT' => '英文（馬耳他）',
        'en_MU' => '英文（毛里裘斯）',
        'en_MV' => '英文（馬爾代夫）',
        'en_MW' => '英文（馬拉維）',
        'en_NG' => '英文（尼日利亞）',
        'en_NR' => '英文（瑙魯）',
        'en_PG' => '英文（巴布亞新畿內亞）',
        'en_PN' => '英文（皮特凱恩島）',
        'en_RW' => '英文（盧旺達）',
        'en_SB' => '英文（所羅門群島）',
        'en_SC' => '英文（塞舌爾）',
        'en_SI' => '英文（斯洛文尼亞）',
        'en_SL' => '英文（塞拉利昂）',
        'en_SZ' => '英文（斯威士蘭）',
        'en_TC' => '英文（特克斯和凱科斯群島）',
        'en_TO' => '英文（湯加）',
        'en_TT' => '英文（千里達和多巴哥）',
        'en_TV' => '英文（圖瓦盧）',
        'en_TZ' => '英文（坦桑尼亞）',
        'en_VC' => '英文（聖文森特和格林納丁斯）',
        'en_VG' => '英文（英屬維爾京群島）',
        'en_VI' => '英文（美屬維爾京群島）',
        'en_VU' => '英文（瓦努阿圖）',
        'en_ZM' => '英文（贊比亞）',
        'en_ZW' => '英文（津巴布韋）',
        'eo' => '世界語',
        'eo_001' => '世界語（世界）',
        'es_BZ' => '西班牙文（伯利茲）',
        'es_CR' => '西班牙文（哥斯達黎加）',
        'es_DO' => '西班牙文（多米尼加共和國）',
        'es_EC' => '西班牙文（厄瓜多爾）',
        'es_GT' => '西班牙文（危地馬拉）',
        'es_HN' => '西班牙文（洪都拉斯）',
        'ff_Adlm_BF' => '富拉文（富拉文，布基納法索）',
        'ff_Adlm_GH' => '富拉文（富拉文，加納）',
        'ff_Adlm_GM' => '富拉文（富拉文，岡比亞）',
        'ff_Adlm_GW' => '富拉文（富拉文，幾內亞比紹）',
        'ff_Adlm_LR' => '富拉文（富拉文，利比里亞）',
        'ff_Adlm_MR' => '富拉文（富拉文，毛里塔尼亞）',
        'ff_Adlm_NE' => '富拉文（富拉文，尼日爾）',
        'ff_Adlm_NG' => '富拉文（富拉文，尼日利亞）',
        'ff_Adlm_SL' => '富拉文（富拉文，塞拉利昂）',
        'ff_Latn' => '富拉文（拉丁字母）',
        'ff_Latn_BF' => '富拉文（拉丁字母，布基納法索）',
        'ff_Latn_CM' => '富拉文（拉丁字母，喀麥隆）',
        'ff_Latn_GH' => '富拉文（拉丁字母，加納）',
        'ff_Latn_GM' => '富拉文（拉丁字母，岡比亞）',
        'ff_Latn_GN' => '富拉文（拉丁字母，幾內亞）',
        'ff_Latn_GW' => '富拉文（拉丁字母，幾內亞比紹）',
        'ff_Latn_LR' => '富拉文（拉丁字母，利比里亞）',
        'ff_Latn_MR' => '富拉文（拉丁字母，毛里塔尼亞）',
        'ff_Latn_NE' => '富拉文（拉丁字母，尼日爾）',
        'ff_Latn_NG' => '富拉文（拉丁字母，尼日利亞）',
        'ff_Latn_SL' => '富拉文（拉丁字母，塞拉利昂）',
        'ff_Latn_SN' => '富拉文（拉丁字母，塞內加爾）',
        'ff_MR' => '富拉文（毛里塔尼亞）',
        'fr_BF' => '法文（布基納法索）',
        'fr_BI' => '法文（布隆迪）',
        'fr_BJ' => '法文（貝寧）',
        'fr_BL' => '法文（聖巴泰勒米）',
        'fr_CI' => '法文（科特迪瓦）',
        'fr_DJ' => '法文（吉布提）',
        'fr_GA' => '法文（加蓬）',
        'fr_KM' => '法文（科摩羅）',
        'fr_ML' => '法文（馬里）',
        'fr_MR' => '法文（毛里塔尼亞）',
        'fr_MU' => '法文（毛里裘斯）',
        'fr_NE' => '法文（尼日爾）',
        'fr_PF' => '法文（法屬波利尼西亞）',
        'fr_RW' => '法文（盧旺達）',
        'fr_SC' => '法文（塞舌爾）',
        'fr_TD' => '法文（乍得）',
        'fr_VU' => '法文（瓦努阿圖）',
        'fr_YT' => '法文（馬約特）',
        'gl' => '加里西亞文',
        'gl_ES' => '加里西亞文（西班牙）',
        'gv_IM' => '曼島文（馬恩島）',
        'ha_GH' => '豪撒文（加納）',
        'ha_NE' => '豪撒文（尼日爾）',
        'ha_NG' => '豪撒文（尼日利亞）',
        'hi_Latn' => '印地文（拉丁字母）',
        'hi_Latn_IN' => '印地文（拉丁字母，印度）',
        'hr' => '克羅地亞文',
        'hr_BA' => '克羅地亞文（波斯尼亞和黑塞哥維那）',
        'hr_HR' => '克羅地亞文（克羅地亞）',
        'ig' => '伊博文',
        'ig_NG' => '伊博文（尼日利亞）',
        'it' => '意大利文',
        'it_CH' => '意大利文（瑞士）',
        'it_IT' => '意大利文（意大利）',
        'it_SM' => '意大利文（聖馬力諾）',
        'it_VA' => '意大利文（梵蒂岡）',
        'ka' => '格魯吉亞文',
        'ka_GE' => '格魯吉亞文（格魯吉亞）',
        'ki_KE' => '吉庫尤文（肯尼亞）',
        'kn' => '坎納達文',
        'kn_IN' => '坎納達文（印度）',
        'lo' => '老撾文',
        'lo_LA' => '老撾文（老撾）',
        'mg' => '馬拉加斯文',
        'mg_MG' => '馬拉加斯文（馬達加斯加）',
        'ml' => '馬拉雅拉姆文',
        'ml_IN' => '馬拉雅拉姆文（印度）',
        'mt' => '馬耳他文',
        'mt_MT' => '馬耳他文（馬耳他）',
        'nb_SJ' => '巴克摩挪威文（斯瓦爾巴特群島及揚馬延島）',
        'nd_ZW' => '北地畢列文（津巴布韋）',
        'nl_AW' => '荷蘭文（阿魯巴）',
        'nl_SR' => '荷蘭文（蘇里南）',
        'om_ET' => '奧羅莫文（埃塞俄比亞）',
        'om_KE' => '奧羅莫文（肯尼亞）',
        'or' => '奧里雅文',
        'or_IN' => '奧里雅文（印度）',
        'os_GE' => '奧塞提文（格魯吉亞）',
        'pa_Guru' => '旁遮普文（古木基文）',
        'pa_Guru_IN' => '旁遮普文（古木基文，印度）',
        'pt_CV' => '葡萄牙文（佛得角）',
        'pt_GW' => '葡萄牙文（幾內亞比紹）',
        'pt_MZ' => '葡萄牙文（莫桑比克）',
        'pt_ST' => '葡萄牙文（聖多美和普林西比）',
        'qu_EC' => '蓋楚瓦文（厄瓜多爾）',
        'rn_BI' => '隆迪文（布隆迪）',
        'rw' => '盧旺達文',
        'rw_RW' => '盧旺達文（盧旺達）',
        'sc_IT' => '撒丁文（意大利）',
        'sh_BA' => '塞爾維亞克羅埃西亞文（波斯尼亞和黑塞哥維那）',
        'sl' => '斯洛文尼亞文',
        'sl_SI' => '斯洛文尼亞文（斯洛文尼亞）',
        'sn' => '修納文',
        'sn_ZW' => '修納文（津巴布韋）',
        'so' => '索馬里文',
        'so_DJ' => '索馬里文（吉布提）',
        'so_ET' => '索馬里文（埃塞俄比亞）',
        'so_KE' => '索馬里文（肯尼亞）',
        'so_SO' => '索馬里文（索馬里）',
        'sr_BA' => '塞爾維亞文（波斯尼亞和黑塞哥維那）',
        'sr_Cyrl' => '塞爾維亞文（西里爾文）',
        'sr_Cyrl_BA' => '塞爾維亞文（西里爾文，波斯尼亞和黑塞哥維那）',
        'sr_Cyrl_ME' => '塞爾維亞文（西里爾文，黑山）',
        'sr_Cyrl_RS' => '塞爾維亞文（西里爾文，塞爾維亞）',
        'sr_Latn' => '塞爾維亞文（拉丁字母）',
        'sr_Latn_BA' => '塞爾維亞文（拉丁字母，波斯尼亞和黑塞哥維那）',
        'sr_Latn_ME' => '塞爾維亞文（拉丁字母，黑山）',
        'sr_Latn_RS' => '塞爾維亞文（拉丁字母，塞爾維亞）',
        'sr_ME' => '塞爾維亞文（黑山）',
        'su_Latn' => '巽他文（拉丁字母）',
        'su_Latn_ID' => '巽他文（拉丁字母，印尼）',
        'sw_KE' => '史瓦希里文（肯尼亞）',
        'sw_TZ' => '史瓦希里文（坦桑尼亞）',
        'ta' => '泰米爾文',
        'ta_IN' => '泰米爾文（印度）',
        'ta_LK' => '泰米爾文（斯里蘭卡）',
        'ta_MY' => '泰米爾文（馬來西亞）',
        'ta_SG' => '泰米爾文（新加坡）',
        'ti_ER' => '提格利尼亞文（厄立特里亞）',
        'ti_ET' => '提格利尼亞文（埃塞俄比亞）',
        'to' => '湯加文',
        'to_TO' => '湯加文（湯加）',
        'tr_CY' => '土耳其文（塞浦路斯）',
        'ur' => '烏爾都文',
        'ur_IN' => '烏爾都文（印度）',
        'ur_PK' => '烏爾都文（巴基斯坦）',
        'uz_Cyrl' => '烏茲別克文（西里爾文）',
        'uz_Cyrl_UZ' => '烏茲別克文（西里爾文，烏茲別克）',
        'uz_Latn' => '烏茲別克文（拉丁字母）',
        'uz_Latn_UZ' => '烏茲別克文（拉丁字母，烏茲別克）',
        'yo_BJ' => '約魯巴文（貝寧）',
        'yo_NG' => '約魯巴文（尼日利亞）',
        'zh_Hans' => '中文（簡體字）',
        'zh_Hans_CN' => '中文（簡體字，中國）',
        'zh_Hans_HK' => '中文（簡體字，中國香港特別行政區）',
        'zh_Hans_MO' => '中文（簡體字，中國澳門特別行政區）',
        'zh_Hans_SG' => '中文（簡體字，新加坡）',
        'zh_Hant' => '中文（繁體字）',
        'zh_Hant_HK' => '中文（繁體字，中國香港特別行政區）',
        'zh_Hant_MO' => '中文（繁體字，中國澳門特別行政區）',
        'zh_Hant_TW' => '中文（繁體字，台灣）',
    ],
];
