<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Elfenbeinskysten (Abidjan)',
        'Africa/Addis_Ababa' => 'austafrikansk tid (Addis Ababa)',
        'Africa/Algiers' => 'sentraleuropeisk tid (Algiers)',
        'Africa/Asmera' => 'austafrikansk tid (Asmara)',
        'Africa/Bangui' => 'vestafrikansk tid (Bangui)',
        'Africa/Brazzaville' => 'vestafrikansk tid (Brazzaville)',
        'Africa/Cairo' => 'austeuropeisk tid (Cairo)',
        'Africa/Casablanca' => 'vesteuropeisk tid (Casablanca)',
        'Africa/Ceuta' => 'sentraleuropeisk tid (Ceuta)',
        'Africa/Dar_es_Salaam' => 'austafrikansk tid (Dar es Salaam)',
        'Africa/Djibouti' => 'austafrikansk tid (Djibouti)',
        'Africa/Douala' => 'vestafrikansk tid (Douala)',
        'Africa/El_Aaiun' => 'vesteuropeisk tid (El Aaiun)',
        'Africa/Kampala' => 'austafrikansk tid (Kampala)',
        'Africa/Kinshasa' => 'vestafrikansk tid (Kinshasa)',
        'Africa/Lagos' => 'vestafrikansk tid (Lagos)',
        'Africa/Libreville' => 'vestafrikansk tid (Libreville)',
        'Africa/Luanda' => 'vestafrikansk tid (Luanda)',
        'Africa/Lubumbashi' => 'Kongo-Kinshasa (Lubumbashi)',
        'Africa/Malabo' => 'vestafrikansk tid (Malabo)',
        'Africa/Mogadishu' => 'austafrikansk tid (Mogadishu)',
        'Africa/Nairobi' => 'austafrikansk tid (Nairobi)',
        'Africa/Ndjamena' => 'vestafrikansk tid (Ndjamena)',
        'Africa/Niamey' => 'vestafrikansk tid (Niamey)',
        'Africa/Porto-Novo' => 'vestafrikansk tid (Porto-Novo)',
        'Africa/Tripoli' => 'austeuropeisk tid (Tripoli)',
        'Africa/Tunis' => 'sentraleuropeisk tid (Tunis)',
        'America/Adak' => 'tidssone for Hawaii og Aleutene (Adak)',
        'America/Anchorage' => 'alaskisk tid (Anchorage)',
        'America/Anguilla' => 'tidssone for den nordamerikanske atlanterhavskysten (Anguilla)',
        'America/Antigua' => 'tidssone for den nordamerikanske atlanterhavskysten (Antigua)',
        'America/Araguaina' => 'tidssone for Brasilia (Araguaina)',
        'America/Argentina/La_Rioja' => 'argentinsk tid (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'argentinsk tid (Rio Gallegos)',
        'America/Argentina/Salta' => 'argentinsk tid (Salta)',
        'America/Argentina/San_Juan' => 'argentinsk tid (San Juan)',
        'America/Argentina/San_Luis' => 'argentinsk tid (San Luis)',
        'America/Argentina/Tucuman' => 'argentinsk tid (Tucuman)',
        'America/Argentina/Ushuaia' => 'argentinsk tid (Ushuaia)',
        'America/Aruba' => 'tidssone for den nordamerikanske atlanterhavskysten (Aruba)',
        'America/Asuncion' => 'paraguayansk tid (Asuncion)',
        'America/Bahia' => 'tidssone for Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'tidssone for sentrale Nord-Amerika (Bahia Banderas)',
        'America/Barbados' => 'tidssone for den nordamerikanske atlanterhavskysten (Barbados)',
        'America/Belem' => 'tidssone for Brasilia (Belem)',
        'America/Belize' => 'tidssone for sentrale Nord-Amerika (Belize)',
        'America/Blanc-Sablon' => 'tidssone for den nordamerikanske atlanterhavskysten (Blanc-Sablon)',
        'America/Boa_Vista' => 'tidssone for Amazonas (Boa Vista)',
        'America/Bogota' => 'kolombiansk tid (Bogota)',
        'America/Boise' => 'tidssone for Rocky Mountains (USA) (Boise)',
        'America/Buenos_Aires' => 'argentinsk tid (Buenos Aires)',
        'America/Cambridge_Bay' => 'tidssone for Rocky Mountains (USA) (Cambridge Bay)',
        'America/Campo_Grande' => 'tidssone for Amazonas (Campo Grande)',
        'America/Cancun' => 'tidssone for den nordamerikanske austkysten (Cancun)',
        'America/Catamarca' => 'argentinsk tid (Catamarca)',
        'America/Cayman' => 'tidssone for den nordamerikanske austkysten (Caymanøyane)',
        'America/Chicago' => 'tidssone for sentrale Nord-Amerika (Chicago)',
        'America/Chihuahua' => 'tidssone for den meksikanske stillehavskysten (Chihuahua)',
        'America/Coral_Harbour' => 'tidssone for den nordamerikanske austkysten (Atikokan)',
        'America/Cordoba' => 'argentinsk tid (Cordoba)',
        'America/Costa_Rica' => 'tidssone for sentrale Nord-Amerika (Costa Rica)',
        'America/Creston' => 'tidssone for Rocky Mountains (USA) (Creston)',
        'America/Cuiaba' => 'tidssone for Amazonas (Cuiaba)',
        'America/Curacao' => 'tidssone for den nordamerikanske atlanterhavskysten (Curacao)',
        'America/Dawson_Creek' => 'tidssone for Rocky Mountains (USA) (Dawson Creek)',
        'America/Denver' => 'tidssone for Rocky Mountains (USA) (Denver)',
        'America/Detroit' => 'tidssone for den nordamerikanske austkysten (Detroit)',
        'America/Dominica' => 'tidssone for den nordamerikanske atlanterhavskysten (Dominica)',
        'America/Edmonton' => 'tidssone for Rocky Mountains (USA) (Edmonton)',
        'America/El_Salvador' => 'tidssone for sentrale Nord-Amerika (El Salvador)',
        'America/Fort_Nelson' => 'tidssone for Rocky Mountains (USA) (Fort Nelson)',
        'America/Fortaleza' => 'tidssone for Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'tidssone for den nordamerikanske atlanterhavskysten (Glace Bay)',
        'America/Godthab' => 'vestgrønlandsk tid (Nuuk)',
        'America/Goose_Bay' => 'tidssone for den nordamerikanske atlanterhavskysten (Goose Bay)',
        'America/Grand_Turk' => 'tidssone for den nordamerikanske austkysten (Grand Turk)',
        'America/Grenada' => 'tidssone for den nordamerikanske atlanterhavskysten (Grenada)',
        'America/Guadeloupe' => 'tidssone for den nordamerikanske atlanterhavskysten (Guadeloupe)',
        'America/Guatemala' => 'tidssone for sentrale Nord-Amerika (Guatemala)',
        'America/Halifax' => 'tidssone for den nordamerikanske atlanterhavskysten (Halifax)',
        'America/Havana' => 'kubansk tid (Havana)',
        'America/Hermosillo' => 'tidssone for den meksikanske stillehavskysten (Hermosillo)',
        'America/Indiana/Knox' => 'tidssone for sentrale Nord-Amerika (Knox, Indiana)',
        'America/Indiana/Marengo' => 'tidssone for den nordamerikanske austkysten (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'tidssone for den nordamerikanske austkysten (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'tidssone for sentrale Nord-Amerika (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'tidssone for den nordamerikanske austkysten (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'tidssone for den nordamerikanske austkysten (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'tidssone for den nordamerikanske austkysten (Winamac, Indiana)',
        'America/Indianapolis' => 'tidssone for den nordamerikanske austkysten (Indianapolis)',
        'America/Inuvik' => 'tidssone for Rocky Mountains (USA) (Inuvik)',
        'America/Iqaluit' => 'tidssone for den nordamerikanske austkysten (Iqaluit)',
        'America/Jamaica' => 'tidssone for den nordamerikanske austkysten (Jamaica)',
        'America/Jujuy' => 'argentinsk tid (Jujuy)',
        'America/Juneau' => 'alaskisk tid (Juneau)',
        'America/Kentucky/Monticello' => 'tidssone for den nordamerikanske austkysten (Monticello, Kentucky)',
        'America/Kralendijk' => 'tidssone for den nordamerikanske atlanterhavskysten (Kralendijk)',
        'America/Lima' => 'peruansk tid (Lima)',
        'America/Los_Angeles' => 'tidssone for den nordamerikanske stillehavskysten (Los Angeles)',
        'America/Louisville' => 'tidssone for den nordamerikanske austkysten (Louisville)',
        'America/Lower_Princes' => 'tidssone for den nordamerikanske atlanterhavskysten (Lower Prince’s Quarter)',
        'America/Maceio' => 'tidssone for Brasilia (Maceio)',
        'America/Managua' => 'tidssone for sentrale Nord-Amerika (Managua)',
        'America/Manaus' => 'tidssone for Amazonas (Manaus)',
        'America/Marigot' => 'tidssone for den nordamerikanske atlanterhavskysten (Marigot)',
        'America/Martinique' => 'tidssone for den nordamerikanske atlanterhavskysten (Martinique)',
        'America/Matamoros' => 'tidssone for sentrale Nord-Amerika (Matamoros)',
        'America/Mazatlan' => 'tidssone for den meksikanske stillehavskysten (Mazatlan)',
        'America/Mendoza' => 'argentinsk tid (Mendoza)',
        'America/Menominee' => 'tidssone for sentrale Nord-Amerika (Menominee)',
        'America/Merida' => 'tidssone for sentrale Nord-Amerika (Merida)',
        'America/Metlakatla' => 'alaskisk tid (Metlakatla)',
        'America/Mexico_City' => 'tidssone for sentrale Nord-Amerika (Mexico City)',
        'America/Miquelon' => 'tidssone for Saint-Pierre-et-Miquelon',
        'America/Moncton' => 'tidssone for den nordamerikanske atlanterhavskysten (Moncton)',
        'America/Monterrey' => 'tidssone for sentrale Nord-Amerika (Monterrey)',
        'America/Montevideo' => 'uruguayansk tid (Montevideo)',
        'America/Montserrat' => 'tidssone for den nordamerikanske atlanterhavskysten (Montserrat)',
        'America/Nassau' => 'tidssone for den nordamerikanske austkysten (Nassau)',
        'America/New_York' => 'tidssone for den nordamerikanske austkysten (New York)',
        'America/Nipigon' => 'tidssone for den nordamerikanske austkysten (Nipigon)',
        'America/Nome' => 'alaskisk tid (Nome)',
        'America/Noronha' => 'tidssone for Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'tidssone for sentrale Nord-Amerika (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'tidssone for sentrale Nord-Amerika (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'tidssone for sentrale Nord-Amerika (New Salem, North Dakota)',
        'America/Ojinaga' => 'tidssone for Rocky Mountains (USA) (Ojinaga)',
        'America/Panama' => 'tidssone for den nordamerikanske austkysten (Panama)',
        'America/Pangnirtung' => 'tidssone for den nordamerikanske austkysten (Pangnirtung)',
        'America/Phoenix' => 'tidssone for Rocky Mountains (USA) (Phoenix)',
        'America/Port-au-Prince' => 'tidssone for den nordamerikanske austkysten (Port-au-Prince)',
        'America/Port_of_Spain' => 'tidssone for den nordamerikanske atlanterhavskysten (Port of Spain)',
        'America/Porto_Velho' => 'tidssone for Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'tidssone for den nordamerikanske atlanterhavskysten (Puerto Rico)',
        'America/Punta_Arenas' => 'chilensk tid (Punta Arenas)',
        'America/Rainy_River' => 'tidssone for sentrale Nord-Amerika (Rainy River)',
        'America/Rankin_Inlet' => 'tidssone for sentrale Nord-Amerika (Rankin Inlet)',
        'America/Recife' => 'tidssone for Brasilia (Recife)',
        'America/Regina' => 'tidssone for sentrale Nord-Amerika (Regina)',
        'America/Resolute' => 'tidssone for sentrale Nord-Amerika (Resolute)',
        'America/Santa_Isabel' => 'tidssone for nordvestlege Mexico (Santa Isabel)',
        'America/Santarem' => 'tidssone for Brasilia (Santarem)',
        'America/Santiago' => 'chilensk tid (Santiago)',
        'America/Santo_Domingo' => 'tidssone for den nordamerikanske atlanterhavskysten (Santo Domingo)',
        'America/Sao_Paulo' => 'tidssone for Brasilia (Sao Paulo)',
        'America/Scoresbysund' => 'austgrønlandsk tid (Ittoqqortoormiit)',
        'America/Sitka' => 'alaskisk tid (Sitka)',
        'America/St_Barthelemy' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Barthelemy)',
        'America/St_Johns' => 'tidssone for Newfoundland (St. John’s)',
        'America/St_Kitts' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Kitts)',
        'America/St_Lucia' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Lucia)',
        'America/St_Thomas' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Thomas)',
        'America/St_Vincent' => 'tidssone for den nordamerikanske atlanterhavskysten (St. Vincent)',
        'America/Swift_Current' => 'tidssone for sentrale Nord-Amerika (Swift Current)',
        'America/Tegucigalpa' => 'tidssone for sentrale Nord-Amerika (Tegucigalpa)',
        'America/Thule' => 'tidssone for den nordamerikanske atlanterhavskysten (Thule)',
        'America/Thunder_Bay' => 'tidssone for den nordamerikanske austkysten (Thunder Bay)',
        'America/Tijuana' => 'tidssone for den nordamerikanske stillehavskysten (Tijuana)',
        'America/Toronto' => 'tidssone for den nordamerikanske austkysten (Toronto)',
        'America/Tortola' => 'tidssone for den nordamerikanske atlanterhavskysten (Tortola)',
        'America/Vancouver' => 'tidssone for den nordamerikanske stillehavskysten (Vancouver)',
        'America/Winnipeg' => 'tidssone for sentrale Nord-Amerika (Winnipeg)',
        'America/Yakutat' => 'alaskisk tid (Yakutat)',
        'America/Yellowknife' => 'tidssone for Rocky Mountains (USA) (Yellowknife)',
        'Antarctica/DumontDUrville' => 'tidssone for Dumont-d’Urville',
        'Antarctica/Macquarie' => 'austaustralsk tid (Macquarie)',
        'Antarctica/McMurdo' => 'nyzealandsk tid (McMurdo)',
        'Antarctica/Palmer' => 'chilensk tid (Palmer)',
        'Antarctica/Troll' => 'Troll',
        'Arctic/Longyearbyen' => 'sentraleuropeisk tid (Longyearbyen)',
        'Asia/Aden' => 'arabisk tid (Aden)',
        'Asia/Almaty' => 'austkasakhstansk tid (Almaty)',
        'Asia/Amman' => 'austeuropeisk tid (Amman)',
        'Asia/Ashgabat' => 'turkmensk tid (Asjgabat)',
        'Asia/Baghdad' => 'arabisk tid (Baghdad)',
        'Asia/Bahrain' => 'arabisk tid (Bahrain)',
        'Asia/Baku' => 'aserbajdsjansk tid (Baku)',
        'Asia/Beirut' => 'austeuropeisk tid (Beirut)',
        'Asia/Chita' => 'tidssone for Jakutsk (Chita)',
        'Asia/Choibalsan' => 'tidssone for Ulan Bator (Tsjojbalsan)',
        'Asia/Damascus' => 'austeuropeisk tid (Damascus)',
        'Asia/Dhaka' => 'bangladeshisk tid (Dhaka)',
        'Asia/Dili' => 'austtimoresisk tid (Dili)',
        'Asia/Dubai' => 'Dei sameinte arabiske emirata (Dubai)',
        'Asia/Famagusta' => 'austeuropeisk tid (Famagusta)',
        'Asia/Gaza' => 'austeuropeisk tid (Gaza)',
        'Asia/Hebron' => 'austeuropeisk tid (Hebron)',
        'Asia/Hong_Kong' => 'hongkongkinesisk tid (Hong Kong)',
        'Asia/Hovd' => 'tidssone for Khovd',
        'Asia/Irkutsk' => 'tidssone for Irkutsk',
        'Asia/Jayapura' => 'austindonesisk tid (Jayapura)',
        'Asia/Jerusalem' => 'israelsk tid (Jerusalem)',
        'Asia/Karachi' => 'pakistansk tid (Karachi)',
        'Asia/Khandyga' => 'tidssone for Jakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'tidssone for Krasnojarsk (Krasnoyarsk)',
        'Asia/Kuwait' => 'arabisk tid (Kuwait)',
        'Asia/Macau' => 'kinesisk tid (Macao)',
        'Asia/Magadan' => 'tidssone for Magadan',
        'Asia/Manila' => 'filippinsk tid (Manila)',
        'Asia/Nicosia' => 'austeuropeisk tid (Nicosia)',
        'Asia/Novokuznetsk' => 'tidssone for Krasnojarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'tidssone for Novosibirsk',
        'Asia/Omsk' => 'tidssone for Omsk',
        'Asia/Pyongyang' => 'koreansk tid (Pyongyang)',
        'Asia/Qatar' => 'arabisk tid (Qatar)',
        'Asia/Qostanay' => 'austkasakhstansk tid (Qostanay)',
        'Asia/Riyadh' => 'arabisk tid (Riyadh)',
        'Asia/Sakhalin' => 'tidssone for Sakhalin',
        'Asia/Samarkand' => 'usbekisk tid (Samarkand)',
        'Asia/Seoul' => 'koreansk tid (Seoul)',
        'Asia/Shanghai' => 'kinesisk tid (Shanghai)',
        'Asia/Srednekolymsk' => 'tidssone for Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'tidssone for Taipei',
        'Asia/Tashkent' => 'usbekisk tid (Tashkent)',
        'Asia/Tbilisi' => 'georgisk tid (Tbilisi)',
        'Asia/Tehran' => 'iransk tid (Tehran)',
        'Asia/Tokyo' => 'japansk tid (Tokyo)',
        'Asia/Ulaanbaatar' => 'tidssone for Ulan Bator (Ulaanbaatar)',
        'Asia/Ust-Nera' => 'tidssone for Vladivostok (Ust-Nera)',
        'Asia/Vladivostok' => 'tidssone for Vladivostok',
        'Asia/Yakutsk' => 'tidssone for Jakutsk (Yakutsk)',
        'Asia/Yekaterinburg' => 'tidssone for Jekaterinburg (Yekaterinburg)',
        'Asia/Yerevan' => 'armensk tid (Yerevan)',
        'Atlantic/Azores' => 'asorisk tid (Asorane)',
        'Atlantic/Bermuda' => 'tidssone for den nordamerikanske atlanterhavskysten (Bermuda)',
        'Atlantic/Canary' => 'vesteuropeisk tid (Kanariøyane)',
        'Atlantic/Cape_Verde' => 'kappverdisk tid (Cape Verde)',
        'Atlantic/Faeroe' => 'vesteuropeisk tid (Færøyane)',
        'Atlantic/Madeira' => 'vesteuropeisk tid (Madeira)',
        'Atlantic/South_Georgia' => 'Sør-Georgia og Sør-Sandwichøyane (South Georgia)',
        'Atlantic/St_Helena' => 'Saint Helena (St. Helena)',
        'Atlantic/Stanley' => 'tidssone for Falklandsøyane (Stanley)',
        'Australia/Adelaide' => 'sentralaustralsk tid (Adelaide)',
        'Australia/Brisbane' => 'austaustralsk tid (Brisbane)',
        'Australia/Broken_Hill' => 'sentralaustralsk tid (Broken Hill)',
        'Australia/Currie' => 'austaustralsk tid (Currie)',
        'Australia/Darwin' => 'sentralaustralsk tid (Darwin)',
        'Australia/Eucla' => 'vest-sentralaustralsk tid (Eucla)',
        'Australia/Hobart' => 'austaustralsk tid (Hobart)',
        'Australia/Lindeman' => 'austaustralsk tid (Lindeman)',
        'Australia/Lord_Howe' => 'tidssone for Lord Howe-øya',
        'Australia/Melbourne' => 'austaustralsk tid (Melbourne)',
        'Australia/Perth' => 'vestaustralsk tid (Perth)',
        'Australia/Sydney' => 'austaustralsk tid (Sydney)',
        'CST6CDT' => 'tidssone for sentrale Nord-Amerika',
        'EST5EDT' => 'tidssone for den nordamerikanske austkysten',
        'Europe/Amsterdam' => 'sentraleuropeisk tid (Amsterdam)',
        'Europe/Andorra' => 'sentraleuropeisk tid (Andorra)',
        'Europe/Astrakhan' => 'tidssone for Moskva (Astrakhan)',
        'Europe/Athens' => 'austeuropeisk tid (Athens)',
        'Europe/Belgrade' => 'sentraleuropeisk tid (Belgrade)',
        'Europe/Berlin' => 'sentraleuropeisk tid (Berlin)',
        'Europe/Bratislava' => 'sentraleuropeisk tid (Bratislava)',
        'Europe/Brussels' => 'sentraleuropeisk tid (Brussels)',
        'Europe/Bucharest' => 'austeuropeisk tid (Bucharest)',
        'Europe/Budapest' => 'sentraleuropeisk tid (Budapest)',
        'Europe/Busingen' => 'sentraleuropeisk tid (Busingen)',
        'Europe/Chisinau' => 'austeuropeisk tid (Chisinau)',
        'Europe/Copenhagen' => 'sentraleuropeisk tid (Copenhagen)',
        'Europe/Gibraltar' => 'sentraleuropeisk tid (Gibraltar)',
        'Europe/Helsinki' => 'austeuropeisk tid (Helsinki)',
        'Europe/Kaliningrad' => 'austeuropeisk tid (Kaliningrad)',
        'Europe/Kiev' => 'austeuropeisk tid (Kyiv)',
        'Europe/Lisbon' => 'vesteuropeisk tid (Lisbon)',
        'Europe/Ljubljana' => 'sentraleuropeisk tid (Ljubljana)',
        'Europe/Luxembourg' => 'sentraleuropeisk tid (Luxembourg)',
        'Europe/Madrid' => 'sentraleuropeisk tid (Madrid)',
        'Europe/Malta' => 'sentraleuropeisk tid (Malta)',
        'Europe/Mariehamn' => 'austeuropeisk tid (Mariehamn)',
        'Europe/Minsk' => 'tidssone for Moskva (Minsk)',
        'Europe/Monaco' => 'sentraleuropeisk tid (Monaco)',
        'Europe/Moscow' => 'tidssone for Moskva (Moscow)',
        'Europe/Oslo' => 'sentraleuropeisk tid (Oslo)',
        'Europe/Paris' => 'sentraleuropeisk tid (Paris)',
        'Europe/Podgorica' => 'sentraleuropeisk tid (Podgorica)',
        'Europe/Prague' => 'sentraleuropeisk tid (Prague)',
        'Europe/Riga' => 'austeuropeisk tid (Riga)',
        'Europe/Rome' => 'sentraleuropeisk tid (Rome)',
        'Europe/San_Marino' => 'sentraleuropeisk tid (San Marino)',
        'Europe/Sarajevo' => 'sentraleuropeisk tid (Sarajevo)',
        'Europe/Saratov' => 'tidssone for Moskva (Saratov)',
        'Europe/Simferopol' => 'tidssone for Moskva (Simferopol)',
        'Europe/Skopje' => 'sentraleuropeisk tid (Skopje)',
        'Europe/Sofia' => 'austeuropeisk tid (Sofia)',
        'Europe/Stockholm' => 'sentraleuropeisk tid (Stockholm)',
        'Europe/Tallinn' => 'austeuropeisk tid (Tallinn)',
        'Europe/Tirane' => 'sentraleuropeisk tid (Tirane)',
        'Europe/Ulyanovsk' => 'tidssone for Moskva (Ulyanovsk)',
        'Europe/Uzhgorod' => 'austeuropeisk tid (Uzhgorod)',
        'Europe/Vaduz' => 'sentraleuropeisk tid (Vaduz)',
        'Europe/Vatican' => 'sentraleuropeisk tid (Vatican)',
        'Europe/Vienna' => 'sentraleuropeisk tid (Vienna)',
        'Europe/Vilnius' => 'austeuropeisk tid (Vilnius)',
        'Europe/Volgograd' => 'tidssone for Volgograd',
        'Europe/Warsaw' => 'sentraleuropeisk tid (Warsaw)',
        'Europe/Zagreb' => 'sentraleuropeisk tid (Zagreb)',
        'Europe/Zaporozhye' => 'austeuropeisk tid (Zaporozhye)',
        'Europe/Zurich' => 'sentraleuropeisk tid (Zurich)',
        'Indian/Antananarivo' => 'austafrikansk tid (Antananarivo)',
        'Indian/Cocos' => 'tidssone for Kokosøyane',
        'Indian/Comoro' => 'austafrikansk tid (Komorane)',
        'Indian/Kerguelen' => 'tidssone for Dei franske sørterritoria (Kerguelen)',
        'Indian/Mahe' => 'Seychellane (Mahe)',
        'Indian/Maldives' => 'Maldivane (Maldivane)',
        'Indian/Mauritius' => 'mauritisk tid (Mauritius)',
        'Indian/Mayotte' => 'austafrikansk tid (Mayotte)',
        'MST7MDT' => 'tidssone for Rocky Mountains (USA)',
        'PST8PDT' => 'tidssone for den nordamerikanske stillehavskysten',
        'Pacific/Apia' => 'tidssone for Apia',
        'Pacific/Auckland' => 'nyzealandsk tid (Auckland)',
        'Pacific/Chatham' => 'tidssone for Chatham',
        'Pacific/Easter' => 'tidssone for Påskeøya (Easter)',
        'Pacific/Efate' => 'vanuatisk tid (Efate)',
        'Pacific/Enderbury' => 'tidssone for Phoenixøyane (Enderbury)',
        'Pacific/Fiji' => 'fijiansk tid',
        'Pacific/Galapagos' => 'tidssone for Galápagosøyane',
        'Pacific/Guadalcanal' => 'Salomonøyane (Guadalcanal)',
        'Pacific/Honolulu' => 'tidssone for Hawaii og Aleutene (Honolulu)',
        'Pacific/Johnston' => 'tidssone for Hawaii og Aleutene (Johnston)',
        'Pacific/Kiritimati' => 'tidssone for Lineøyane (Kiritimati)',
        'Pacific/Kwajalein' => 'Marshalløyane (Kwajalein)',
        'Pacific/Majuro' => 'Marshalløyane (Majuro)',
        'Pacific/Marquesas' => 'tidssone for Marquesasøyane',
        'Pacific/Midway' => 'samoansk tid (Midway)',
        'Pacific/Norfolk' => 'tidssone for Norfolkøya',
        'Pacific/Noumea' => 'kaledonsk tid (Noumea)',
        'Pacific/Pago_Pago' => 'samoansk tid (Pago Pago)',
        'Pacific/Pitcairn' => 'Pitcairn (Pitcairn)',
        'Pacific/Rarotonga' => 'tidssone for Cookøyane (Rarotonga)',
        'Pacific/Saipan' => 'Nord-Marianane (Saipan)',
        'Pacific/Tarawa' => 'tidssone for Gilbertøyane (Tarawa)',
        'Pacific/Tongatapu' => 'tongansk tid (Tongatapu)',
        'Pacific/Truk' => 'tidssone for Chuukøyane',
        'Pacific/Wake' => 'USAs ytre småøyar (Wake)',
        'Pacific/Wallis' => 'tidssone for Wallis- og Futunaøyane',
    ],
    'Meta' => [
    ],
];
