<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Afak' => 'Afaka',
        'Aghb' => 'Kaukasisch-Albanisch',
        'Arab' => 'Arabisch',
        'Aran' => 'Nastaliq',
        'Armn' => 'Armenisch',
        'Avst' => 'Avestisch',
        'Bali' => 'Balinesisch',
        'Bamu' => 'Bamun',
        'Bass' => 'Bassa',
        'Batk' => 'Battakisch',
        'Beng' => 'Bengalisch',
        'Blis' => 'Bliss-Symbole',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'Braille',
        'Bugi' => 'Buginesisch',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'UCAS',
        'Cari' => 'Karisch',
        'Cher' => 'Cherokee',
        'Cirt' => 'Cirth',
        'Copt' => 'Koptisch',
        'Cprt' => 'Zypriotisch',
        'Cyrl' => 'Kyrillisch',
        'Cyrs' => 'Altkirchenslawisch',
        'Deva' => 'Devanagari',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Duployanisch',
        'Egyd' => 'Ägyptisch - Demotisch',
        'Egyh' => 'Ägyptisch - Hieratisch',
        'Egyp' => 'Ägyptische Hieroglyphen',
        'Elba' => 'Elbasanisch',
        'Ethi' => 'Äthiopisch',
        'Geok' => 'Khutsuri',
        'Geor' => 'Georgisch',
        'Glag' => 'Glagolitisch',
        'Goth' => 'Gotisch',
        'Gran' => 'Grantha',
        'Grek' => 'Griechisch',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han mit Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Chinesisch',
        'Hano' => 'Hanunoo',
        'Hans' => 'Vereinfacht',
        'Hant' => 'Traditionell',
        'Hebr' => 'Hebräisch',
        'Hira' => 'Hiragana',
        'Hluw' => 'Hieroglyphen-Luwisch',
        'Hmng' => 'Pahawh Hmong',
        'Hrkt' => 'Japanische Silbenschrift',
        'Hung' => 'Altungarisch',
        'Inds' => 'Indus-Schrift',
        'Ital' => 'Altitalisch',
        'Jamo' => 'Jamo',
        'Java' => 'Javanesisch',
        'Jpan' => 'Japanisch',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Khmer',
        'Khoj' => 'Khojki',
        'Knda' => 'Kannada',
        'Kore' => 'Koreanisch',
        'Kpel' => 'Kpelle',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Laotisch',
        'Latf' => 'Lateinisch - Fraktur-Variante',
        'Latg' => 'Lateinisch - Gälische Variante',
        'Latn' => 'Lateinisch',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Linear A',
        'Linb' => 'Linear B',
        'Lisu' => 'Fraser',
        'Loma' => 'Loma',
        'Lyci' => 'Lykisch',
        'Lydi' => 'Lydisch',
        'Mahj' => 'Mahajani',
        'Mand' => 'Mandäisch',
        'Mani' => 'Manichäisch',
        'Maya' => 'Maya-Hieroglyphen',
        'Mend' => 'Mende',
        'Merc' => 'Meroitisch kursiv',
        'Mero' => 'Meroitisch',
        'Mlym' => 'Malayalam',
        'Mong' => 'Mongolisch',
        'Moon' => 'Moon',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei-Mayek',
        'Mymr' => 'Birmanisch',
        'Narb' => 'Altnordarabisch',
        'Nbat' => 'Nabatäisch',
        'Nkgb' => 'Geba',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Frauenschrift',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orchon-Runen',
        'Orya' => 'Oriya',
        'Osma' => 'Osmanisch',
        'Palm' => 'Palmyrenisch',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Altpermisch',
        'Phag' => 'Phags-pa',
        'Phli' => 'Buch-Pahlavi',
        'Phlp' => 'Psalter-Pahlavi',
        'Phlv' => 'Pahlavi',
        'Phnx' => 'Phönizisch',
        'Plrd' => 'Pollard Phonetisch',
        'Prti' => 'Parthisch',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi Rohingya',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runenschrift',
        'Samr' => 'Samaritanisch',
        'Sara' => 'Sarati',
        'Sarb' => 'Altsüdarabisch',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'Gebärdensprache',
        'Shaw' => 'Shaw-Alphabet',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Khudawadi',
        'Sinh' => 'Singhalesisch',
        'Sora' => 'Sora Sompeng',
        'Sund' => 'Sundanesisch',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Syrisch',
        'Syre' => 'Syrisch - Estrangelo-Variante',
        'Syrj' => 'Westsyrisch',
        'Syrn' => 'Ostsyrisch',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'Tai Lue',
        'Taml' => 'Tamilisch',
        'Tang' => 'Xixia',
        'Tavt' => 'Tai-Viet',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagalog',
        'Thaa' => 'Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Tibetisch',
        'Tirh' => 'Tirhuta',
        'Ugar' => 'Ugaritisch',
        'Vaii' => 'Vai',
        'Visp' => 'Sichtbare Sprache',
        'Wara' => 'Varang Kshiti',
        'Wole' => 'Woleaianisch',
        'Xpeo' => 'Altpersisch',
        'Xsux' => 'Sumerisch-akkadische Keilschrift',
        'Yiii' => 'Yi',
        'Zinh' => 'Geerbter Schriftwert',
        'Zmth' => 'Mathematische Notation',
        'Zsye' => 'Emoji',
        'Zsym' => 'Symbole',
        'Zxxx' => 'Schriftlos',
        'Zyyy' => 'Verbreitet',
    ],
];
