<?php

return [
    'Names' => [
        'AD' => 'Андорра',
        'AE' => 'Бирлашган Араб Амирликлари',
        'AF' => 'Афғонистон',
        'AG' => 'Антигуа ва Барбуда',
        'AI' => 'Ангилья',
        'AL' => 'Албания',
        'AM' => 'Арманистон',
        'AO' => 'Ангола',
        'AQ' => 'Антарктида',
        'AR' => 'Аргентина',
        'AS' => 'Америка Самоаси',
        'AT' => 'Австрия',
        'AU' => 'Австралия',
        'AW' => 'Аруба',
        'AX' => 'Аланд ороллари',
        'AZ' => 'Озарбайжон',
        'BA' => 'Босния ва Герцеговина',
        'BB' => 'Барбадос',
        'BD' => 'Бангладеш',
        'BE' => 'Бельгия',
        'BF' => 'Буркина-Фасо',
        'BG' => 'Болгария',
        'BH' => 'Баҳрайн',
        'BI' => 'Бурунди',
        'BJ' => 'Бенин',
        'BL' => 'Сен-Бартелеми',
        'BM' => 'Бермуда',
        'BN' => 'Бруней',
        'BO' => 'Боливия',
        'BQ' => 'Бонейр, Синт-Эстатиус ва Саба',
        'BR' => 'Бразилия',
        'BS' => 'Багама ороллари',
        'BT' => 'Бутан',
        'BV' => 'Буве ороли',
        'BW' => 'Ботсванна',
        'BY' => 'Беларус',
        'BZ' => 'Белиз',
        'CA' => 'Канада',
        'CC' => 'Кокос (Килинг) ороллари',
        'CD' => 'Конго-Киншаса',
        'CF' => 'Марказий Африка Республикаси',
        'CG' => 'Конго Браззавиль',
        'CH' => 'Швейцария',
        'CI' => 'Кот-д’Ивуар',
        'CK' => 'Кук ороллари',
        'CL' => 'Чили',
        'CM' => 'Камерун',
        'CN' => 'Хитой',
        'CO' => 'Колумбия',
        'CR' => 'Коста-Рика',
        'CU' => 'Куба',
        'CV' => 'Кабо-Верде',
        'CW' => 'Кюрасао',
        'CX' => 'Рождество ороли',
        'CY' => 'Кипр',
        'CZ' => 'Чехия',
        'DE' => 'Германия',
        'DJ' => 'Жибути',
        'DK' => 'Дания',
        'DM' => 'Доминика',
        'DO' => 'Доминикан Республикаси',
        'DZ' => 'Жазоир',
        'EC' => 'Эквадор',
        'EE' => 'Эстония',
        'EG' => 'Миср',
        'EH' => 'Ғарбий Саҳрои Кабир',
        'ER' => 'Эритрея',
        'ES' => 'Испания',
        'ET' => 'Эфиопия',
        'FI' => 'Финляндия',
        'FJ' => 'Фижи',
        'FK' => 'Фолкленд ороллари',
        'FM' => 'Микронезия',
        'FO' => 'Фарер ороллари',
        'FR' => 'Франция',
        'GA' => 'Габон',
        'GB' => 'Буюк Британия',
        'GD' => 'Гренада',
        'GE' => 'Грузия',
        'GF' => 'Француз Гвианаси',
        'GG' => 'Гернси',
        'GH' => 'Гана',
        'GI' => 'Гибралтар',
        'GL' => 'Гренландия',
        'GM' => 'Гамбия',
        'GN' => 'Гвинея',
        'GP' => 'Гваделупе',
        'GQ' => 'Экваториал Гвинея',
        'GR' => 'Греция',
        'GS' => 'Жанубий Георгия ва Жанубий Сендвич ороллари',
        'GT' => 'Гватемала',
        'GU' => 'Гуам',
        'GW' => 'Гвинея-Бисау',
        'GY' => 'Гаяна',
        'HK' => 'Гонконг (Хитой ММҲ)',
        'HM' => 'Херд ва Макдоналд ороллари',
        'HN' => 'Гондурас',
        'HR' => 'Хорватия',
        'HT' => 'Гаити',
        'HU' => 'Венгрия',
        'ID' => 'Индонезия',
        'IE' => 'Ирландия',
        'IL' => 'Исроил',
        'IM' => 'Мэн ороли',
        'IN' => 'Ҳиндистон',
        'IO' => 'Британиянинг Ҳинд океанидаги ҳудуди',
        'IQ' => 'Ироқ',
        'IR' => 'Эрон',
        'IS' => 'Исландия',
        'IT' => 'Италия',
        'JE' => 'Жерси',
        'JM' => 'Ямайка',
        'JO' => 'Иордания',
        'JP' => 'Япония',
        'KE' => 'Кения',
        'KG' => 'Қирғизистон',
        'KH' => 'Камбоджа',
        'KI' => 'Кирибати',
        'KM' => 'Комор ороллари',
        'KN' => 'Сент-Китс ва Невис',
        'KP' => 'Шимолий Корея',
        'KR' => 'Жанубий Корея',
        'KW' => 'Қувайт',
        'KY' => 'Кайман ороллари',
        'KZ' => 'Қозоғистон',
        'LA' => 'Лаос',
        'LB' => 'Ливан',
        'LC' => 'Сент-Люсия',
        'LI' => 'Лихтенштейн',
        'LK' => 'Шри-Ланка',
        'LR' => 'Либерия',
        'LS' => 'Лесото',
        'LT' => 'Литва',
        'LU' => 'Люксембург',
        'LV' => 'Латвия',
        'LY' => 'Ливия',
        'MA' => 'Марокаш',
        'MC' => 'Монако',
        'MD' => 'Молдова',
        'ME' => 'Черногория',
        'MF' => 'Сент-Мартин',
        'MG' => 'Мадагаскар',
        'MH' => 'Маршал ороллари',
        'MK' => 'Шимолий Македония',
        'ML' => 'Мали',
        'MM' => 'Мьянма (Бирма)',
        'MN' => 'Монголия',
        'MO' => 'Макао (Хитой ММҲ)',
        'MP' => 'Шимолий Марианна ороллари',
        'MQ' => 'Мартиника',
        'MR' => 'Мавритания',
        'MS' => 'Монтсеррат',
        'MT' => 'Мальта',
        'MU' => 'Маврикий',
        'MV' => 'Мальдив ороллари',
        'MW' => 'Малави',
        'MX' => 'Мексика',
        'MY' => 'Малайзия',
        'MZ' => 'Мозамбик',
        'NA' => 'Намибия',
        'NC' => 'Янги Каледония',
        'NE' => 'Нигер',
        'NF' => 'Норфолк ороллари',
        'NG' => 'Нигерия',
        'NI' => 'Никарагуа',
        'NL' => 'Нидерландия',
        'NO' => 'Норвегия',
        'NP' => 'Непал',
        'NR' => 'Науру',
        'NU' => 'Ниуэ',
        'NZ' => 'Янги Зеландия',
        'OM' => 'Уммон',
        'PA' => 'Панама',
        'PE' => 'Перу',
        'PF' => 'Француз Полинезияси',
        'PG' => 'Папуа - Янги Гвинея',
        'PH' => 'Филиппин',
        'PK' => 'Покистон',
        'PL' => 'Польша',
        'PM' => 'Сент-Пьер ва Микелон',
        'PN' => 'Питкэрн ороллари',
        'PR' => 'Пуэрто-Рико',
        'PS' => 'Фаластин ҳудуди',
        'PT' => 'Португалия',
        'PW' => 'Палау',
        'PY' => 'Парагвай',
        'QA' => 'Қатар',
        'RE' => 'Реюнион',
        'RO' => 'Руминия',
        'RS' => 'Сербия',
        'RU' => 'Россия',
        'RW' => 'Руанда',
        'SA' => 'Саудия Арабистони',
        'SB' => 'Соломон ороллари',
        'SC' => 'Сейшел ороллари',
        'SD' => 'Судан',
        'SE' => 'Швеция',
        'SG' => 'Сингапур',
        'SH' => 'Муқаддас Елена ороли',
        'SI' => 'Словения',
        'SJ' => 'Свалбард ва Ян-Майен',
        'SK' => 'Словакия',
        'SL' => 'Сьерра-Леоне',
        'SM' => 'Сан-Марино',
        'SN' => 'Сенегал',
        'SO' => 'Сомали',
        'SR' => 'Суринам',
        'SS' => 'Жанубий Судан',
        'ST' => 'Сан-Томе ва Принсипи',
        'SV' => 'Салвадор',
        'SX' => 'Синт-Мартен',
        'SY' => 'Сурия',
        'SZ' => 'Свазиленд',
        'TC' => 'Туркс ва Кайкос ороллари',
        'TD' => 'Чад',
        'TF' => 'Француз жанубий ҳудудлари',
        'TG' => 'Того',
        'TH' => 'Таиланд',
        'TJ' => 'Тожикистон',
        'TK' => 'Токелау',
        'TL' => 'Тимор-Лесте',
        'TM' => 'Туркманистон',
        'TN' => 'Тунис',
        'TO' => 'Тонга',
        'TR' => 'Туркия',
        'TT' => 'Тринидад ва Тобаго',
        'TV' => 'Тувалу',
        'TW' => 'Тайван',
        'TZ' => 'Танзания',
        'UA' => 'Украина',
        'UG' => 'Уганда',
        'UM' => 'АҚШ ёндош ороллари',
        'US' => 'Америка Қўшма Штатлари',
        'UY' => 'Уругвай',
        'UZ' => 'Ўзбекистон',
        'VA' => 'Ватикан',
        'VC' => 'Сент-Винсент ва Гренадин',
        'VE' => 'Венесуэла',
        'VG' => 'Британия Виргин ороллари',
        'VI' => 'АҚШ Виргин ороллари',
        'VN' => 'Вьетнам',
        'VU' => 'Вануату',
        'WF' => 'Уоллис ва Футуна',
        'WS' => 'Самоа',
        'YE' => 'Яман',
        'YT' => 'Майотта',
        'ZA' => 'Жанубий Африка Республикаси',
        'ZM' => 'Замбия',
        'ZW' => 'Зимбабве',
    ],
];
