<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Mkpụrụ Okwu Arabic',
        'Aran' => 'Nastalik',
        'Armn' => 'Mkpụrụ ọkwụ Armenịan',
        'Beng' => 'Mkpụrụ ọkwụ Bangla',
        'Bopo' => 'Mkpụrụ ọkwụ Bopomofo',
        'Brai' => 'Braịlle',
        'Cakm' => 'Chakma',
        'Cans' => 'Unified Canadian Aboriginal Syllabics',
        'Cher' => 'Cherọkee',
        'Cyrl' => 'Mkpụrụ Okwu Cyrillic',
        'Deva' => 'Mkpụrụ ọkwụ Devangarị',
        'Ethi' => 'Mkpụrụ ọkwụ Etọpịa',
        'Geor' => 'Mkpụrụ ọkwụ Geọjịan',
        'Grek' => 'Mkpụrụ ọkwụ grịk',
        'Gujr' => 'Mkpụrụ ọkwụ Gụjaratị',
        'Guru' => 'Mkpụrụ ọkwụ Gụrmụkị',
        'Hanb' => 'Han na Bopomofo',
        'Hang' => 'Mkpụrụ ọkwụ Hangụl',
        'Hani' => 'Mkpụrụ ọkwụ Han',
        'Hans' => 'Nke dị mfe',
        'Hant' => 'Izugbe',
        'Hebr' => 'Mkpụrụ ọkwụ Hebrew',
        'Hira' => 'Mkpụrụ okwụ Hịragana',
        'Hrkt' => 'mkpụrụ ọkwụ Japanịsị',
        'Jamo' => 'Jamọ',
        'Jpan' => 'Japanese',
        'Kana' => 'Katakana',
        'Khmr' => 'Khmer',
        'Knda' => 'Kannaada',
        'Kore' => 'Korea',
        'Laoo' => 'Laọ',
        'Latn' => 'Latin',
        'Mlym' => 'Malayala',
        'Mong' => 'Mọngọlịan',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Myanmar',
        'Nkoo' => 'Nkoọ',
        'Olck' => 'Ochiki',
        'Orya' => 'Ọdịa',
        'Rohg' => 'Hanifi',
        'Sinh' => 'Sinhala',
        'Sund' => 'Sundanisị',
        'Syrc' => 'Syriak',
        'Taml' => 'Tamịl',
        'Telu' => 'Telụgụ',
        'Tfng' => 'Tifinag',
        'Thaa' => 'Taa',
        'Tibt' => 'Tịbeta',
        'Vaii' => 'Vai',
        'Yiii' => 'Yị',
        'Zmth' => 'Mkpụrụ ọkwụ Mgbakọ',
        'Zsye' => 'Emojị',
        'Zsym' => 'Akara',
        'Zxxx' => 'Edeghị ede',
        'Zyyy' => 'kọmọn',
    ],
];
