<?php

return [
    'Names' => [
        'af' => 'afrikaani',
        'af_NA' => 'afrikaani (Namiibia)',
        'af_ZA' => 'afrikaani (Lõuna-Aafrika Vabariik)',
        'ak' => 'akani',
        'ak_GH' => 'akani (Ghana)',
        'am' => 'amhara',
        'am_ET' => 'amhara (Etioopia)',
        'ar' => 'araabia',
        'ar_001' => 'araabia (maailm)',
        'ar_AE' => 'araabia (Araabia Ühendemiraadid)',
        'ar_BH' => 'araabia (Bahrein)',
        'ar_DJ' => 'araabia (Djibouti)',
        'ar_DZ' => 'araabia (Alžeeria)',
        'ar_EG' => 'araabia (Egiptus)',
        'ar_EH' => 'araabia (Lääne-Sahara)',
        'ar_ER' => 'araabia (Eritrea)',
        'ar_IL' => 'araabia (Iisrael)',
        'ar_IQ' => 'araabia (Iraak)',
        'ar_JO' => 'araabia (Jordaania)',
        'ar_KM' => 'araabia (Komoorid)',
        'ar_KW' => 'araabia (Kuveit)',
        'ar_LB' => 'araabia (Liibanon)',
        'ar_LY' => 'araabia (Liibüa)',
        'ar_MA' => 'araabia (Maroko)',
        'ar_MR' => 'araabia (Mauritaania)',
        'ar_OM' => 'araabia (Omaan)',
        'ar_PS' => 'araabia (Palestiina alad)',
        'ar_QA' => 'araabia (Katar)',
        'ar_SA' => 'araabia (Saudi Araabia)',
        'ar_SD' => 'araabia (Sudaan)',
        'ar_SO' => 'araabia (Somaalia)',
        'ar_SS' => 'araabia (Lõuna-Sudaan)',
        'ar_SY' => 'araabia (Süüria)',
        'ar_TD' => 'araabia (Tšaad)',
        'ar_TN' => 'araabia (Tuneesia)',
        'ar_YE' => 'araabia (Jeemen)',
        'as' => 'assami',
        'as_IN' => 'assami (India)',
        'az' => 'aserbaidžaani',
        'az_AZ' => 'aserbaidžaani (Aserbaidžaan)',
        'az_Cyrl' => 'aserbaidžaani (kirillitsa)',
        'az_Cyrl_AZ' => 'aserbaidžaani (kirillitsa, Aserbaidžaan)',
        'az_Latn' => 'aserbaidžaani (ladina)',
        'az_Latn_AZ' => 'aserbaidžaani (ladina, Aserbaidžaan)',
        'be' => 'valgevene',
        'be_BY' => 'valgevene (Valgevene)',
        'bg' => 'bulgaaria',
        'bg_BG' => 'bulgaaria (Bulgaaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengali',
        'bn_BD' => 'bengali (Bangladesh)',
        'bn_IN' => 'bengali (India)',
        'bo' => 'tiibeti',
        'bo_CN' => 'tiibeti (Hiina)',
        'bo_IN' => 'tiibeti (India)',
        'br' => 'bretooni',
        'br_FR' => 'bretooni (Prantsusmaa)',
        'bs' => 'bosnia',
        'bs_BA' => 'bosnia (Bosnia ja Hertsegoviina)',
        'bs_Cyrl' => 'bosnia (kirillitsa)',
        'bs_Cyrl_BA' => 'bosnia (kirillitsa, Bosnia ja Hertsegoviina)',
        'bs_Latn' => 'bosnia (ladina)',
        'bs_Latn_BA' => 'bosnia (ladina, Bosnia ja Hertsegoviina)',
        'ca' => 'katalaani',
        'ca_AD' => 'katalaani (Andorra)',
        'ca_ES' => 'katalaani (Hispaania)',
        'ca_FR' => 'katalaani (Prantsusmaa)',
        'ca_IT' => 'katalaani (Itaalia)',
        'ce' => 'tšetšeeni',
        'ce_RU' => 'tšetšeeni (Venemaa)',
        'cs' => 'tšehhi',
        'cs_CZ' => 'tšehhi (Tšehhi)',
        'cv' => 'tšuvaši',
        'cv_RU' => 'tšuvaši (Venemaa)',
        'cy' => 'kõmri',
        'cy_GB' => 'kõmri (Ühendkuningriik)',
        'da' => 'taani',
        'da_DK' => 'taani (Taani)',
        'da_GL' => 'taani (Gröönimaa)',
        'de' => 'saksa',
        'de_AT' => 'saksa (Austria)',
        'de_BE' => 'saksa (Belgia)',
        'de_CH' => 'saksa (Šveits)',
        'de_DE' => 'saksa (Saksamaa)',
        'de_IT' => 'saksa (Itaalia)',
        'de_LI' => 'saksa (Liechtenstein)',
        'de_LU' => 'saksa (Luksemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'eve',
        'ee_GH' => 'eve (Ghana)',
        'ee_TG' => 'eve (Togo)',
        'el' => 'kreeka',
        'el_CY' => 'kreeka (Küpros)',
        'el_GR' => 'kreeka (Kreeka)',
        'en' => 'inglise',
        'en_001' => 'inglise (maailm)',
        'en_150' => 'inglise (Euroopa)',
        'en_AE' => 'inglise (Araabia Ühendemiraadid)',
        'en_AG' => 'inglise (Antigua ja Barbuda)',
        'en_AI' => 'inglise (Anguilla)',
        'en_AS' => 'inglise (Ameerika Samoa)',
        'en_AT' => 'inglise (Austria)',
        'en_AU' => 'inglise (Austraalia)',
        'en_BB' => 'inglise (Barbados)',
        'en_BE' => 'inglise (Belgia)',
        'en_BI' => 'inglise (Burundi)',
        'en_BM' => 'inglise (Bermuda)',
        'en_BS' => 'inglise (Bahama)',
        'en_BW' => 'inglise (Botswana)',
        'en_BZ' => 'inglise (Belize)',
        'en_CA' => 'inglise (Kanada)',
        'en_CC' => 'inglise (Kookossaared)',
        'en_CH' => 'inglise (Šveits)',
        'en_CK' => 'inglise (Cooki saared)',
        'en_CM' => 'inglise (Kamerun)',
        'en_CX' => 'inglise (Jõulusaar)',
        'en_CY' => 'inglise (Küpros)',
        'en_DE' => 'inglise (Saksamaa)',
        'en_DK' => 'inglise (Taani)',
        'en_DM' => 'inglise (Dominica)',
        'en_ER' => 'inglise (Eritrea)',
        'en_FI' => 'inglise (Soome)',
        'en_FJ' => 'inglise (Fidži)',
        'en_FK' => 'inglise (Falklandi saared)',
        'en_FM' => 'inglise (Mikroneesia)',
        'en_GB' => 'inglise (Ühendkuningriik)',
        'en_GD' => 'inglise (Grenada)',
        'en_GG' => 'inglise (Guernsey)',
        'en_GH' => 'inglise (Ghana)',
        'en_GI' => 'inglise (Gibraltar)',
        'en_GM' => 'inglise (Gambia)',
        'en_GU' => 'inglise (Guam)',
        'en_GY' => 'inglise (Guyana)',
        'en_HK' => 'inglise (Hongkongi erihalduspiirkond)',
        'en_IE' => 'inglise (Iirimaa)',
        'en_IL' => 'inglise (Iisrael)',
        'en_IM' => 'inglise (Mani saar)',
        'en_IN' => 'inglise (India)',
        'en_IO' => 'inglise (Briti India ookeani ala)',
        'en_JE' => 'inglise (Jersey)',
        'en_JM' => 'inglise (Jamaica)',
        'en_KE' => 'inglise (Keenia)',
        'en_KI' => 'inglise (Kiribati)',
        'en_KN' => 'inglise (Saint Kitts ja Nevis)',
        'en_KY' => 'inglise (Kaimanisaared)',
        'en_LC' => 'inglise (Saint Lucia)',
        'en_LR' => 'inglise (Libeeria)',
        'en_LS' => 'inglise (Lesotho)',
        'en_MG' => 'inglise (Madagaskar)',
        'en_MH' => 'inglise (Marshalli Saared)',
        'en_MO' => 'inglise (Macau erihalduspiirkond)',
        'en_MP' => 'inglise (Põhja-Mariaanid)',
        'en_MS' => 'inglise (Montserrat)',
        'en_MT' => 'inglise (Malta)',
        'en_MU' => 'inglise (Mauritius)',
        'en_MV' => 'inglise (Maldiivid)',
        'en_MW' => 'inglise (Malawi)',
        'en_MY' => 'inglise (Malaisia)',
        'en_NA' => 'inglise (Namiibia)',
        'en_NF' => 'inglise (Norfolk)',
        'en_NG' => 'inglise (Nigeeria)',
        'en_NL' => 'inglise (Holland)',
        'en_NR' => 'inglise (Nauru)',
        'en_NU' => 'inglise (Niue)',
        'en_NZ' => 'inglise (Uus-Meremaa)',
        'en_PG' => 'inglise (Paapua Uus-Guinea)',
        'en_PH' => 'inglise (Filipiinid)',
        'en_PK' => 'inglise (Pakistan)',
        'en_PN' => 'inglise (Pitcairni saared)',
        'en_PR' => 'inglise (Puerto Rico)',
        'en_PW' => 'inglise (Belau)',
        'en_RW' => 'inglise (Rwanda)',
        'en_SB' => 'inglise (Saalomoni Saared)',
        'en_SC' => 'inglise (Seišellid)',
        'en_SD' => 'inglise (Sudaan)',
        'en_SE' => 'inglise (Rootsi)',
        'en_SG' => 'inglise (Singapur)',
        'en_SH' => 'inglise (Saint Helena)',
        'en_SI' => 'inglise (Sloveenia)',
        'en_SL' => 'inglise (Sierra Leone)',
        'en_SS' => 'inglise (Lõuna-Sudaan)',
        'en_SX' => 'inglise (Sint Maarten)',
        'en_SZ' => 'inglise (Svaasimaa)',
        'en_TC' => 'inglise (Turks ja Caicos)',
        'en_TK' => 'inglise (Tokelau)',
        'en_TO' => 'inglise (Tonga)',
        'en_TT' => 'inglise (Trinidad ja Tobago)',
        'en_TV' => 'inglise (Tuvalu)',
        'en_TZ' => 'inglise (Tansaania)',
        'en_UG' => 'inglise (Uganda)',
        'en_UM' => 'inglise (Ühendriikide hajasaared)',
        'en_US' => 'inglise (Ameerika Ühendriigid)',
        'en_VC' => 'inglise (Saint Vincent ja Grenadiinid)',
        'en_VG' => 'inglise (Briti Neitsisaared)',
        'en_VI' => 'inglise (USA Neitsisaared)',
        'en_VU' => 'inglise (Vanuatu)',
        'en_WS' => 'inglise (Samoa)',
        'en_ZA' => 'inglise (Lõuna-Aafrika Vabariik)',
        'en_ZM' => 'inglise (Sambia)',
        'en_ZW' => 'inglise (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (maailm)',
        'es' => 'hispaania',
        'es_419' => 'hispaania (Ladina-Ameerika)',
        'es_AR' => 'hispaania (Argentina)',
        'es_BO' => 'hispaania (Boliivia)',
        'es_BR' => 'hispaania (Brasiilia)',
        'es_BZ' => 'hispaania (Belize)',
        'es_CL' => 'hispaania (Tšiili)',
        'es_CO' => 'hispaania (Colombia)',
        'es_CR' => 'hispaania (Costa Rica)',
        'es_CU' => 'hispaania (Kuuba)',
        'es_DO' => 'hispaania (Dominikaani Vabariik)',
        'es_EC' => 'hispaania (Ecuador)',
        'es_ES' => 'hispaania (Hispaania)',
        'es_GQ' => 'hispaania (Ekvatoriaal-Guinea)',
        'es_GT' => 'hispaania (Guatemala)',
        'es_HN' => 'hispaania (Honduras)',
        'es_MX' => 'hispaania (Mehhiko)',
        'es_NI' => 'hispaania (Nicaragua)',
        'es_PA' => 'hispaania (Panama)',
        'es_PE' => 'hispaania (Peruu)',
        'es_PH' => 'hispaania (Filipiinid)',
        'es_PR' => 'hispaania (Puerto Rico)',
        'es_PY' => 'hispaania (Paraguay)',
        'es_SV' => 'hispaania (El Salvador)',
        'es_US' => 'hispaania (Ameerika Ühendriigid)',
        'es_UY' => 'hispaania (Uruguay)',
        'es_VE' => 'hispaania (Venezuela)',
        'et' => 'eesti',
        'et_EE' => 'eesti (Eesti)',
        'eu' => 'baski',
        'eu_ES' => 'baski (Hispaania)',
        'fa' => 'pärsia',
        'fa_AF' => 'pärsia (Afganistan)',
        'fa_IR' => 'pärsia (Iraan)',
        'ff' => 'fula',
        'ff_Adlm' => 'fula (adlami)',
        'ff_Adlm_BF' => 'fula (adlami, Burkina Faso)',
        'ff_Adlm_CM' => 'fula (adlami, Kamerun)',
        'ff_Adlm_GH' => 'fula (adlami, Ghana)',
        'ff_Adlm_GM' => 'fula (adlami, Gambia)',
        'ff_Adlm_GN' => 'fula (adlami, Guinea)',
        'ff_Adlm_GW' => 'fula (adlami, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fula (adlami, Libeeria)',
        'ff_Adlm_MR' => 'fula (adlami, Mauritaania)',
        'ff_Adlm_NE' => 'fula (adlami, Niger)',
        'ff_Adlm_NG' => 'fula (adlami, Nigeeria)',
        'ff_Adlm_SL' => 'fula (adlami, Sierra Leone)',
        'ff_Adlm_SN' => 'fula (adlami, Senegal)',
        'ff_CM' => 'fula (Kamerun)',
        'ff_GN' => 'fula (Guinea)',
        'ff_Latn' => 'fula (ladina)',
        'ff_Latn_BF' => 'fula (ladina, Burkina Faso)',
        'ff_Latn_CM' => 'fula (ladina, Kamerun)',
        'ff_Latn_GH' => 'fula (ladina, Ghana)',
        'ff_Latn_GM' => 'fula (ladina, Gambia)',
        'ff_Latn_GN' => 'fula (ladina, Guinea)',
        'ff_Latn_GW' => 'fula (ladina, Guinea-Bissau)',
        'ff_Latn_LR' => 'fula (ladina, Libeeria)',
        'ff_Latn_MR' => 'fula (ladina, Mauritaania)',
        'ff_Latn_NE' => 'fula (ladina, Niger)',
        'ff_Latn_NG' => 'fula (ladina, Nigeeria)',
        'ff_Latn_SL' => 'fula (ladina, Sierra Leone)',
        'ff_Latn_SN' => 'fula (ladina, Senegal)',
        'ff_MR' => 'fula (Mauritaania)',
        'ff_SN' => 'fula (Senegal)',
        'fi' => 'soome',
        'fi_FI' => 'soome (Soome)',
        'fo' => 'fääri',
        'fo_DK' => 'fääri (Taani)',
        'fo_FO' => 'fääri (Fääri saared)',
        'fr' => 'prantsuse',
        'fr_BE' => 'prantsuse (Belgia)',
        'fr_BF' => 'prantsuse (Burkina Faso)',
        'fr_BI' => 'prantsuse (Burundi)',
        'fr_BJ' => 'prantsuse (Benin)',
        'fr_BL' => 'prantsuse (Saint-Barthélemy)',
        'fr_CA' => 'prantsuse (Kanada)',
        'fr_CD' => 'prantsuse (Kongo DV)',
        'fr_CF' => 'prantsuse (Kesk-Aafrika Vabariik)',
        'fr_CG' => 'prantsuse (Kongo Vabariik)',
        'fr_CH' => 'prantsuse (Šveits)',
        'fr_CI' => 'prantsuse (Côte d’Ivoire)',
        'fr_CM' => 'prantsuse (Kamerun)',
        'fr_DJ' => 'prantsuse (Djibouti)',
        'fr_DZ' => 'prantsuse (Alžeeria)',
        'fr_FR' => 'prantsuse (Prantsusmaa)',
        'fr_GA' => 'prantsuse (Gabon)',
        'fr_GF' => 'prantsuse (Prantsuse Guajaana)',
        'fr_GN' => 'prantsuse (Guinea)',
        'fr_GP' => 'prantsuse (Guadeloupe)',
        'fr_GQ' => 'prantsuse (Ekvatoriaal-Guinea)',
        'fr_HT' => 'prantsuse (Haiti)',
        'fr_KM' => 'prantsuse (Komoorid)',
        'fr_LU' => 'prantsuse (Luksemburg)',
        'fr_MA' => 'prantsuse (Maroko)',
        'fr_MC' => 'prantsuse (Monaco)',
        'fr_MF' => 'prantsuse (Saint-Martin)',
        'fr_MG' => 'prantsuse (Madagaskar)',
        'fr_ML' => 'prantsuse (Mali)',
        'fr_MQ' => 'prantsuse (Martinique)',
        'fr_MR' => 'prantsuse (Mauritaania)',
        'fr_MU' => 'prantsuse (Mauritius)',
        'fr_NC' => 'prantsuse (Uus-Kaledoonia)',
        'fr_NE' => 'prantsuse (Niger)',
        'fr_PF' => 'prantsuse (Prantsuse Polüneesia)',
        'fr_PM' => 'prantsuse (Saint-Pierre ja Miquelon)',
        'fr_RE' => 'prantsuse (Réunion)',
        'fr_RW' => 'prantsuse (Rwanda)',
        'fr_SC' => 'prantsuse (Seišellid)',
        'fr_SN' => 'prantsuse (Senegal)',
        'fr_SY' => 'prantsuse (Süüria)',
        'fr_TD' => 'prantsuse (Tšaad)',
        'fr_TG' => 'prantsuse (Togo)',
        'fr_TN' => 'prantsuse (Tuneesia)',
        'fr_VU' => 'prantsuse (Vanuatu)',
        'fr_WF' => 'prantsuse (Wallis ja Futuna)',
        'fr_YT' => 'prantsuse (Mayotte)',
        'fy' => 'läänefriisi',
        'fy_NL' => 'läänefriisi (Holland)',
        'ga' => 'iiri',
        'ga_GB' => 'iiri (Ühendkuningriik)',
        'ga_IE' => 'iiri (Iirimaa)',
        'gd' => 'gaeli',
        'gd_GB' => 'gaeli (Ühendkuningriik)',
        'gl' => 'galeegi',
        'gl_ES' => 'galeegi (Hispaania)',
        'gu' => 'gudžarati',
        'gu_IN' => 'gudžarati (India)',
        'gv' => 'mänksi',
        'gv_IM' => 'mänksi (Mani saar)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeeria)',
        'he' => 'heebrea',
        'he_IL' => 'heebrea (Iisrael)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (ladina)',
        'hi_Latn_IN' => 'hindi (ladina, India)',
        'hr' => 'horvaadi',
        'hr_BA' => 'horvaadi (Bosnia ja Hertsegoviina)',
        'hr_HR' => 'horvaadi (Horvaatia)',
        'hu' => 'ungari',
        'hu_HU' => 'ungari (Ungari)',
        'hy' => 'armeenia',
        'hy_AM' => 'armeenia (Armeenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (maailm)',
        'id' => 'indoneesia',
        'id_ID' => 'indoneesia (Indoneesia)',
        'ig' => 'ibo',
        'ig_NG' => 'ibo (Nigeeria)',
        'ii' => 'nuosu',
        'ii_CN' => 'nuosu (Hiina)',
        'is' => 'islandi',
        'is_IS' => 'islandi (Island)',
        'it' => 'itaalia',
        'it_CH' => 'itaalia (Šveits)',
        'it_IT' => 'itaalia (Itaalia)',
        'it_SM' => 'itaalia (San Marino)',
        'it_VA' => 'itaalia (Vatikan)',
        'ja' => 'jaapani',
        'ja_JP' => 'jaapani (Jaapan)',
        'jv' => 'jaava',
        'jv_ID' => 'jaava (Indoneesia)',
        'ka' => 'gruusia',
        'ka_GE' => 'gruusia (Gruusia)',
        'ki' => 'kikuju',
        'ki_KE' => 'kikuju (Keenia)',
        'kk' => 'kasahhi',
        'kk_KZ' => 'kasahhi (Kasahstan)',
        'kl' => 'grööni',
        'kl_GL' => 'grööni (Gröönimaa)',
        'km' => 'khmeeri',
        'km_KH' => 'khmeeri (Kambodža)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'korea',
        'ko_KP' => 'korea (Põhja-Korea)',
        'ko_KR' => 'korea (Lõuna-Korea)',
        'ks' => 'kašmiiri',
        'ks_Arab' => 'kašmiiri (araabia)',
        'ks_Arab_IN' => 'kašmiiri (araabia, India)',
        'ks_Deva' => 'kašmiiri (devanaagari)',
        'ks_Deva_IN' => 'kašmiiri (devanaagari, India)',
        'ks_IN' => 'kašmiiri (India)',
        'ku' => 'kurdi',
        'ku_TR' => 'kurdi (Türgi)',
        'kw' => 'korni',
        'kw_GB' => 'korni (Ühendkuningriik)',
        'ky' => 'kirgiisi',
        'ky_KG' => 'kirgiisi (Kõrgõzstan)',
        'lb' => 'letseburgi',
        'lb_LU' => 'letseburgi (Luksemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo DV)',
        'ln_CF' => 'lingala (Kesk-Aafrika Vabariik)',
        'ln_CG' => 'lingala (Kongo Vabariik)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laos)',
        'lt' => 'leedu',
        'lt_LT' => 'leedu (Leedu)',
        'lu' => 'Katanga luba',
        'lu_CD' => 'Katanga luba (Kongo DV)',
        'lv' => 'läti',
        'lv_LV' => 'läti (Läti)',
        'mg' => 'malagassi',
        'mg_MG' => 'malagassi (Madagaskar)',
        'mi' => 'maoori',
        'mi_NZ' => 'maoori (Uus-Meremaa)',
        'mk' => 'makedoonia',
        'mk_MK' => 'makedoonia (Põhja-Makedoonia)',
        'ml' => 'malajalami',
        'ml_IN' => 'malajalami (India)',
        'mn' => 'mongoli',
        'mn_MN' => 'mongoli (Mongoolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malai',
        'ms_BN' => 'malai (Brunei)',
        'ms_ID' => 'malai (Indoneesia)',
        'ms_MY' => 'malai (Malaisia)',
        'ms_SG' => 'malai (Singapur)',
        'mt' => 'malta',
        'mt_MT' => 'malta (Malta)',
        'my' => 'birma',
        'my_MM' => 'birma (Myanmar [Birma])',
        'nb' => 'norra bokmål',
        'nb_NO' => 'norra bokmål (Norra)',
        'nb_SJ' => 'norra bokmål (Svalbard ja Jan Mayen)',
        'nd' => 'põhjandebele',
        'nd_ZW' => 'põhjandebele (Zimbabwe)',
        'ne' => 'nepali',
        'ne_IN' => 'nepali (India)',
        'ne_NP' => 'nepali (Nepal)',
        'nl' => 'hollandi',
        'nl_AW' => 'hollandi (Aruba)',
        'nl_BE' => 'hollandi (Belgia)',
        'nl_BQ' => 'hollandi (Hollandi Kariibi mere saared)',
        'nl_CW' => 'hollandi (Curaçao)',
        'nl_NL' => 'hollandi (Holland)',
        'nl_SR' => 'hollandi (Suriname)',
        'nl_SX' => 'hollandi (Sint Maarten)',
        'nn' => 'uusnorra',
        'nn_NO' => 'uusnorra (Norra)',
        'no' => 'norra',
        'no_NO' => 'norra (Norra)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etioopia)',
        'om_KE' => 'oromo (Keenia)',
        'or' => 'oria',
        'or_IN' => 'oria (India)',
        'os' => 'osseedi',
        'os_GE' => 'osseedi (Gruusia)',
        'os_RU' => 'osseedi (Venemaa)',
        'pa' => 'pandžabi',
        'pa_Arab' => 'pandžabi (araabia)',
        'pa_Arab_PK' => 'pandžabi (araabia, Pakistan)',
        'pa_Guru' => 'pandžabi (gurmukhi)',
        'pa_Guru_IN' => 'pandžabi (gurmukhi, India)',
        'pa_IN' => 'pandžabi (India)',
        'pa_PK' => 'pandžabi (Pakistan)',
        'pl' => 'poola',
        'pl_PL' => 'poola (Poola)',
        'ps' => 'puštu',
        'ps_AF' => 'puštu (Afganistan)',
        'ps_PK' => 'puštu (Pakistan)',
        'pt' => 'portugali',
        'pt_AO' => 'portugali (Angola)',
        'pt_BR' => 'portugali (Brasiilia)',
        'pt_CH' => 'portugali (Šveits)',
        'pt_CV' => 'portugali (Roheneemesaared)',
        'pt_GQ' => 'portugali (Ekvatoriaal-Guinea)',
        'pt_GW' => 'portugali (Guinea-Bissau)',
        'pt_LU' => 'portugali (Luksemburg)',
        'pt_MO' => 'portugali (Macau erihalduspiirkond)',
        'pt_MZ' => 'portugali (Mosambiik)',
        'pt_PT' => 'portugali (Portugal)',
        'pt_ST' => 'portugali (São Tomé ja Príncipe)',
        'pt_TL' => 'portugali (Ida-Timor)',
        'qu' => 'ketšua',
        'qu_BO' => 'ketšua (Boliivia)',
        'qu_EC' => 'ketšua (Ecuador)',
        'qu_PE' => 'ketšua (Peruu)',
        'rm' => 'romanši',
        'rm_CH' => 'romanši (Šveits)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumeenia',
        'ro_MD' => 'rumeenia (Moldova)',
        'ro_RO' => 'rumeenia (Rumeenia)',
        'ru' => 'vene',
        'ru_BY' => 'vene (Valgevene)',
        'ru_KG' => 'vene (Kõrgõzstan)',
        'ru_KZ' => 'vene (Kasahstan)',
        'ru_MD' => 'vene (Moldova)',
        'ru_RU' => 'vene (Venemaa)',
        'ru_UA' => 'vene (Ukraina)',
        'rw' => 'ruanda',
        'rw_RW' => 'ruanda (Rwanda)',
        'sa' => 'sanskriti',
        'sa_IN' => 'sanskriti (India)',
        'sc' => 'sardi',
        'sc_IT' => 'sardi (Itaalia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (araabia)',
        'sd_Arab_PK' => 'sindhi (araabia, Pakistan)',
        'sd_Deva' => 'sindhi (devanaagari)',
        'sd_Deva_IN' => 'sindhi (devanaagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'põhjasaami',
        'se_FI' => 'põhjasaami (Soome)',
        'se_NO' => 'põhjasaami (Norra)',
        'se_SE' => 'põhjasaami (Rootsi)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Kesk-Aafrika Vabariik)',
        'sh' => 'serbia-horvaadi',
        'sh_BA' => 'serbia-horvaadi (Bosnia ja Hertsegoviina)',
        'si' => 'singali',
        'si_LK' => 'singali (Sri Lanka)',
        'sk' => 'slovaki',
        'sk_SK' => 'slovaki (Slovakkia)',
        'sl' => 'sloveeni',
        'sl_SI' => 'sloveeni (Sloveenia)',
        'sn' => 'šona',
        'sn_ZW' => 'šona (Zimbabwe)',
        'so' => 'somaali',
        'so_DJ' => 'somaali (Djibouti)',
        'so_ET' => 'somaali (Etioopia)',
        'so_KE' => 'somaali (Keenia)',
        'so_SO' => 'somaali (Somaalia)',
        'sq' => 'albaania',
        'sq_AL' => 'albaania (Albaania)',
        'sq_MK' => 'albaania (Põhja-Makedoonia)',
        'sr' => 'serbia',
        'sr_BA' => 'serbia (Bosnia ja Hertsegoviina)',
        'sr_Cyrl' => 'serbia (kirillitsa)',
        'sr_Cyrl_BA' => 'serbia (kirillitsa, Bosnia ja Hertsegoviina)',
        'sr_Cyrl_ME' => 'serbia (kirillitsa, Montenegro)',
        'sr_Cyrl_RS' => 'serbia (kirillitsa, Serbia)',
        'sr_Latn' => 'serbia (ladina)',
        'sr_Latn_BA' => 'serbia (ladina, Bosnia ja Hertsegoviina)',
        'sr_Latn_ME' => 'serbia (ladina, Montenegro)',
        'sr_Latn_RS' => 'serbia (ladina, Serbia)',
        'sr_ME' => 'serbia (Montenegro)',
        'sr_RS' => 'serbia (Serbia)',
        'su' => 'sunda',
        'su_ID' => 'sunda (Indoneesia)',
        'su_Latn' => 'sunda (ladina)',
        'su_Latn_ID' => 'sunda (ladina, Indoneesia)',
        'sv' => 'rootsi',
        'sv_AX' => 'rootsi (Ahvenamaa)',
        'sv_FI' => 'rootsi (Soome)',
        'sv_SE' => 'rootsi (Rootsi)',
        'sw' => 'suahiili',
        'sw_CD' => 'suahiili (Kongo DV)',
        'sw_KE' => 'suahiili (Keenia)',
        'sw_TZ' => 'suahiili (Tansaania)',
        'sw_UG' => 'suahiili (Uganda)',
        'ta' => 'tamili',
        'ta_IN' => 'tamili (India)',
        'ta_LK' => 'tamili (Sri Lanka)',
        'ta_MY' => 'tamili (Malaisia)',
        'ta_SG' => 'tamili (Singapur)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tadžiki',
        'tg_TJ' => 'tadžiki (Tadžikistan)',
        'th' => 'tai',
        'th_TH' => 'tai (Tai)',
        'ti' => 'tigrinja',
        'ti_ER' => 'tigrinja (Eritrea)',
        'ti_ET' => 'tigrinja (Etioopia)',
        'tk' => 'türkmeeni',
        'tk_TM' => 'türkmeeni (Türkmenistan)',
        'tl' => 'tagalogi',
        'tl_PH' => 'tagalogi (Filipiinid)',
        'to' => 'tonga',
        'to_TO' => 'tonga (Tonga)',
        'tr' => 'türgi',
        'tr_CY' => 'türgi (Küpros)',
        'tr_TR' => 'türgi (Türgi)',
        'tt' => 'tatari',
        'tt_RU' => 'tatari (Venemaa)',
        'ug' => 'uiguuri',
        'ug_CN' => 'uiguuri (Hiina)',
        'uk' => 'ukraina',
        'uk_UA' => 'ukraina (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'usbeki',
        'uz_AF' => 'usbeki (Afganistan)',
        'uz_Arab' => 'usbeki (araabia)',
        'uz_Arab_AF' => 'usbeki (araabia, Afganistan)',
        'uz_Cyrl' => 'usbeki (kirillitsa)',
        'uz_Cyrl_UZ' => 'usbeki (kirillitsa, Usbekistan)',
        'uz_Latn' => 'usbeki (ladina)',
        'uz_Latn_UZ' => 'usbeki (ladina, Usbekistan)',
        'uz_UZ' => 'usbeki (Usbekistan)',
        'vi' => 'vietnami',
        'vi_VN' => 'vietnami (Vietnam)',
        'wo' => 'volofi',
        'wo_SN' => 'volofi (Senegal)',
        'xh' => 'koosa',
        'xh_ZA' => 'koosa (Lõuna-Aafrika Vabariik)',
        'yi' => 'jidiši',
        'yi_001' => 'jidiši (maailm)',
        'yo' => 'joruba',
        'yo_BJ' => 'joruba (Benin)',
        'yo_NG' => 'joruba (Nigeeria)',
        'zh' => 'hiina',
        'zh_CN' => 'hiina (Hiina)',
        'zh_HK' => 'hiina (Hongkongi erihalduspiirkond)',
        'zh_Hans' => 'hiina (lihtsustatud)',
        'zh_Hans_CN' => 'hiina (lihtsustatud, Hiina)',
        'zh_Hans_HK' => 'hiina (lihtsustatud, Hongkongi erihalduspiirkond)',
        'zh_Hans_MO' => 'hiina (lihtsustatud, Macau erihalduspiirkond)',
        'zh_Hans_SG' => 'hiina (lihtsustatud, Singapur)',
        'zh_Hant' => 'hiina (traditsiooniline)',
        'zh_Hant_HK' => 'hiina (traditsiooniline, Hongkongi erihalduspiirkond)',
        'zh_Hant_MO' => 'hiina (traditsiooniline, Macau erihalduspiirkond)',
        'zh_Hant_TW' => 'hiina (traditsiooniline, Taiwan)',
        'zh_MO' => 'hiina (Macau erihalduspiirkond)',
        'zh_SG' => 'hiina (Singapur)',
        'zh_TW' => 'hiina (Taiwan)',
        'zu' => 'suulu',
        'zu_ZA' => 'suulu (Lõuna-Aafrika Vabariik)',
    ],
];
