<?php

return [
    'Names' => [
        'af' => 'אפריקאנס',
        'af_NA' => 'אפריקאנס (נמיביה)',
        'af_ZA' => 'אפריקאנס (דרום אפריקה)',
        'ak' => 'אקאן',
        'ak_GH' => 'אקאן (גאנה)',
        'am' => 'אמהרית',
        'am_ET' => 'אמהרית (אתיופיה)',
        'ar' => 'ערבית',
        'ar_001' => 'ערבית (העולם)',
        'ar_AE' => 'ערבית (איחוד האמירויות הערביות)',
        'ar_BH' => 'ערבית (בחריין)',
        'ar_DJ' => 'ערבית (ג׳יבוטי)',
        'ar_DZ' => 'ערבית (אלג׳יריה)',
        'ar_EG' => 'ערבית (מצרים)',
        'ar_EH' => 'ערבית (סהרה המערבית)',
        'ar_ER' => 'ערבית (אריתריאה)',
        'ar_IL' => 'ערבית (ישראל)',
        'ar_IQ' => 'ערבית (עיראק)',
        'ar_JO' => 'ערבית (ירדן)',
        'ar_KM' => 'ערבית (קומורו)',
        'ar_KW' => 'ערבית (כווית)',
        'ar_LB' => 'ערבית (לבנון)',
        'ar_LY' => 'ערבית (לוב)',
        'ar_MA' => 'ערבית (מרוקו)',
        'ar_MR' => 'ערבית (מאוריטניה)',
        'ar_OM' => 'ערבית (עומאן)',
        'ar_PS' => 'ערבית (השטחים הפלסטיניים)',
        'ar_QA' => 'ערבית (קטאר)',
        'ar_SA' => 'ערבית (ערב הסעודית)',
        'ar_SD' => 'ערבית (סודן)',
        'ar_SO' => 'ערבית (סומליה)',
        'ar_SS' => 'ערבית (דרום סודן)',
        'ar_SY' => 'ערבית (סוריה)',
        'ar_TD' => 'ערבית (צ׳אד)',
        'ar_TN' => 'ערבית (תוניסיה)',
        'ar_YE' => 'ערבית (תימן)',
        'as' => 'אסאמית',
        'as_IN' => 'אסאמית (הודו)',
        'az' => 'אזרית',
        'az_AZ' => 'אזרית (אזרבייג׳ן)',
        'az_Cyrl' => 'אזרית (קירילי)',
        'az_Cyrl_AZ' => 'אזרית (קירילי, אזרבייג׳ן)',
        'az_Latn' => 'אזרית (לטיני)',
        'az_Latn_AZ' => 'אזרית (לטיני, אזרבייג׳ן)',
        'be' => 'בלארוסית',
        'be_BY' => 'בלארוסית (בלארוס)',
        'bg' => 'בולגרית',
        'bg_BG' => 'בולגרית (בולגריה)',
        'bm' => 'במבארה',
        'bm_ML' => 'במבארה (מאלי)',
        'bn' => 'בנגלית',
        'bn_BD' => 'בנגלית (בנגלדש)',
        'bn_IN' => 'בנגלית (הודו)',
        'bo' => 'טיבטית',
        'bo_CN' => 'טיבטית (סין)',
        'bo_IN' => 'טיבטית (הודו)',
        'br' => 'ברטונית',
        'br_FR' => 'ברטונית (צרפת)',
        'bs' => 'בוסנית',
        'bs_BA' => 'בוסנית (בוסניה והרצגובינה)',
        'bs_Cyrl' => 'בוסנית (קירילי)',
        'bs_Cyrl_BA' => 'בוסנית (קירילי, בוסניה והרצגובינה)',
        'bs_Latn' => 'בוסנית (לטיני)',
        'bs_Latn_BA' => 'בוסנית (לטיני, בוסניה והרצגובינה)',
        'ca' => 'קטלאנית',
        'ca_AD' => 'קטלאנית (אנדורה)',
        'ca_ES' => 'קטלאנית (ספרד)',
        'ca_FR' => 'קטלאנית (צרפת)',
        'ca_IT' => 'קטלאנית (איטליה)',
        'ce' => 'צ׳צ׳נית',
        'ce_RU' => 'צ׳צ׳נית (רוסיה)',
        'cs' => 'צ׳כית',
        'cs_CZ' => 'צ׳כית (צ׳כיה)',
        'cv' => 'צ׳ובאש',
        'cv_RU' => 'צ׳ובאש (רוסיה)',
        'cy' => 'וולשית',
        'cy_GB' => 'וולשית (בריטניה)',
        'da' => 'דנית',
        'da_DK' => 'דנית (דנמרק)',
        'da_GL' => 'דנית (גרינלנד)',
        'de' => 'גרמנית',
        'de_AT' => 'גרמנית (אוסטריה)',
        'de_BE' => 'גרמנית (בלגיה)',
        'de_CH' => 'גרמנית (שווייץ)',
        'de_DE' => 'גרמנית (גרמניה)',
        'de_IT' => 'גרמנית (איטליה)',
        'de_LI' => 'גרמנית (ליכטנשטיין)',
        'de_LU' => 'גרמנית (לוקסמבורג)',
        'dz' => 'דזונקה',
        'dz_BT' => 'דזונקה (בהוטן)',
        'ee' => 'אווה',
        'ee_GH' => 'אווה (גאנה)',
        'ee_TG' => 'אווה (טוגו)',
        'el' => 'יוונית',
        'el_CY' => 'יוונית (קפריסין)',
        'el_GR' => 'יוונית (יוון)',
        'en' => 'אנגלית',
        'en_001' => 'אנגלית (העולם)',
        'en_150' => 'אנגלית (אירופה)',
        'en_AE' => 'אנגלית (איחוד האמירויות הערביות)',
        'en_AG' => 'אנגלית (אנטיגואה וברבודה)',
        'en_AI' => 'אנגלית (אנגווילה)',
        'en_AS' => 'אנגלית (סמואה האמריקנית)',
        'en_AT' => 'אנגלית (אוסטריה)',
        'en_AU' => 'אנגלית (אוסטרליה)',
        'en_BB' => 'אנגלית (ברבדוס)',
        'en_BE' => 'אנגלית (בלגיה)',
        'en_BI' => 'אנגלית (בורונדי)',
        'en_BM' => 'אנגלית (ברמודה)',
        'en_BS' => 'אנגלית (איי בהאמה)',
        'en_BW' => 'אנגלית (בוטסואנה)',
        'en_BZ' => 'אנגלית (בליז)',
        'en_CA' => 'אנגלית (קנדה)',
        'en_CC' => 'אנגלית (איי קוקוס [קילינג])',
        'en_CH' => 'אנגלית (שווייץ)',
        'en_CK' => 'אנגלית (איי קוק)',
        'en_CM' => 'אנגלית (קמרון)',
        'en_CX' => 'אנגלית (אי חג המולד)',
        'en_CY' => 'אנגלית (קפריסין)',
        'en_DE' => 'אנגלית (גרמניה)',
        'en_DK' => 'אנגלית (דנמרק)',
        'en_DM' => 'אנגלית (דומיניקה)',
        'en_ER' => 'אנגלית (אריתריאה)',
        'en_FI' => 'אנגלית (פינלנד)',
        'en_FJ' => 'אנגלית (פיג׳י)',
        'en_FK' => 'אנגלית (איי פוקלנד)',
        'en_FM' => 'אנגלית (מיקרונזיה)',
        'en_GB' => 'אנגלית (בריטניה)',
        'en_GD' => 'אנגלית (גרנדה)',
        'en_GG' => 'אנגלית (גרנזי)',
        'en_GH' => 'אנגלית (גאנה)',
        'en_GI' => 'אנגלית (גיברלטר)',
        'en_GM' => 'אנגלית (גמביה)',
        'en_GU' => 'אנגלית (גואם)',
        'en_GY' => 'אנגלית (גיאנה)',
        'en_HK' => 'אנגלית (הונג קונג [אזור מנהלי מיוחד של סין])',
        'en_IE' => 'אנגלית (אירלנד)',
        'en_IL' => 'אנגלית (ישראל)',
        'en_IM' => 'אנגלית (האי מאן)',
        'en_IN' => 'אנגלית (הודו)',
        'en_IO' => 'אנגלית (הטריטוריה הבריטית באוקיינוס ההודי)',
        'en_JE' => 'אנגלית (ג׳רזי)',
        'en_JM' => 'אנגלית (ג׳מייקה)',
        'en_KE' => 'אנגלית (קניה)',
        'en_KI' => 'אנגלית (קיריבאטי)',
        'en_KN' => 'אנגלית (סנט קיטס ונוויס)',
        'en_KY' => 'אנגלית (איי קיימן)',
        'en_LC' => 'אנגלית (סנט לוסיה)',
        'en_LR' => 'אנגלית (ליבריה)',
        'en_LS' => 'אנגלית (לסוטו)',
        'en_MG' => 'אנגלית (מדגסקר)',
        'en_MH' => 'אנגלית (איי מרשל)',
        'en_MO' => 'אנגלית (מקאו [אזור מנהלי מיוחד של סין])',
        'en_MP' => 'אנגלית (איי מריאנה הצפוניים)',
        'en_MS' => 'אנגלית (מונסראט)',
        'en_MT' => 'אנגלית (מלטה)',
        'en_MU' => 'אנגלית (מאוריציוס)',
        'en_MV' => 'אנגלית (האיים המלדיביים)',
        'en_MW' => 'אנגלית (מלאווי)',
        'en_MY' => 'אנגלית (מלזיה)',
        'en_NA' => 'אנגלית (נמיביה)',
        'en_NF' => 'אנגלית (האי נורפוק)',
        'en_NG' => 'אנגלית (ניגריה)',
        'en_NL' => 'אנגלית (הולנד)',
        'en_NR' => 'אנגלית (נאורו)',
        'en_NU' => 'אנגלית (ניווה)',
        'en_NZ' => 'אנגלית (ניו זילנד)',
        'en_PG' => 'אנגלית (פפואה גינאה החדשה)',
        'en_PH' => 'אנגלית (הפיליפינים)',
        'en_PK' => 'אנגלית (פקיסטן)',
        'en_PN' => 'אנגלית (איי פיטקרן)',
        'en_PR' => 'אנגלית (פוארטו ריקו)',
        'en_PW' => 'אנגלית (פלאו)',
        'en_RW' => 'אנגלית (רואנדה)',
        'en_SB' => 'אנגלית (איי שלמה)',
        'en_SC' => 'אנגלית (איי סיישל)',
        'en_SD' => 'אנגלית (סודן)',
        'en_SE' => 'אנגלית (שוודיה)',
        'en_SG' => 'אנגלית (סינגפור)',
        'en_SH' => 'אנגלית (סנט הלנה)',
        'en_SI' => 'אנגלית (סלובניה)',
        'en_SL' => 'אנגלית (סיירה לאון)',
        'en_SS' => 'אנגלית (דרום סודן)',
        'en_SX' => 'אנגלית (סנט מארטן)',
        'en_SZ' => 'אנגלית (אסוואטיני)',
        'en_TC' => 'אנגלית (איי טרקס וקייקוס)',
        'en_TK' => 'אנגלית (טוקלאו)',
        'en_TO' => 'אנגלית (טונגה)',
        'en_TT' => 'אנגלית (טרינידד וטובגו)',
        'en_TV' => 'אנגלית (טובאלו)',
        'en_TZ' => 'אנגלית (טנזניה)',
        'en_UG' => 'אנגלית (אוגנדה)',
        'en_UM' => 'אנגלית (האיים המרוחקים הקטנים של ארה״ב)',
        'en_US' => 'אנגלית (ארצות הברית)',
        'en_VC' => 'אנגלית (סנט וינסנט והגרנדינים)',
        'en_VG' => 'אנגלית (איי הבתולה הבריטיים)',
        'en_VI' => 'אנגלית (איי הבתולה של ארצות הברית)',
        'en_VU' => 'אנגלית (ונואטו)',
        'en_WS' => 'אנגלית (סמואה)',
        'en_ZA' => 'אנגלית (דרום אפריקה)',
        'en_ZM' => 'אנגלית (זמביה)',
        'en_ZW' => 'אנגלית (זימבבואה)',
        'eo' => 'אספרנטו',
        'eo_001' => 'אספרנטו (העולם)',
        'es' => 'ספרדית',
        'es_419' => 'ספרדית (אמריקה הלטינית)',
        'es_AR' => 'ספרדית (ארגנטינה)',
        'es_BO' => 'ספרדית (בוליביה)',
        'es_BR' => 'ספרדית (ברזיל)',
        'es_BZ' => 'ספרדית (בליז)',
        'es_CL' => 'ספרדית (צ׳ילה)',
        'es_CO' => 'ספרדית (קולומביה)',
        'es_CR' => 'ספרדית (קוסטה ריקה)',
        'es_CU' => 'ספרדית (קובה)',
        'es_DO' => 'ספרדית (הרפובליקה הדומיניקנית)',
        'es_EC' => 'ספרדית (אקוודור)',
        'es_ES' => 'ספרדית (ספרד)',
        'es_GQ' => 'ספרדית (גינאה המשוונית)',
        'es_GT' => 'ספרדית (גואטמלה)',
        'es_HN' => 'ספרדית (הונדורס)',
        'es_MX' => 'ספרדית (מקסיקו)',
        'es_NI' => 'ספרדית (ניקרגואה)',
        'es_PA' => 'ספרדית (פנמה)',
        'es_PE' => 'ספרדית (פרו)',
        'es_PH' => 'ספרדית (הפיליפינים)',
        'es_PR' => 'ספרדית (פוארטו ריקו)',
        'es_PY' => 'ספרדית (פרגוואי)',
        'es_SV' => 'ספרדית (אל סלבדור)',
        'es_US' => 'ספרדית (ארצות הברית)',
        'es_UY' => 'ספרדית (אורוגוואי)',
        'es_VE' => 'ספרדית (ונצואלה)',
        'et' => 'אסטונית',
        'et_EE' => 'אסטונית (אסטוניה)',
        'eu' => 'בסקית',
        'eu_ES' => 'בסקית (ספרד)',
        'fa' => 'פרסית',
        'fa_AF' => 'פרסית (אפגניסטן)',
        'fa_IR' => 'פרסית (איראן)',
        'ff' => 'פולה',
        'ff_Adlm' => 'פולה (אדלם)',
        'ff_Adlm_BF' => 'פולה (אדלם, בורקינה פאסו)',
        'ff_Adlm_CM' => 'פולה (אדלם, קמרון)',
        'ff_Adlm_GH' => 'פולה (אדלם, גאנה)',
        'ff_Adlm_GM' => 'פולה (אדלם, גמביה)',
        'ff_Adlm_GN' => 'פולה (אדלם, גינאה)',
        'ff_Adlm_GW' => 'פולה (אדלם, גינאה-ביסאו)',
        'ff_Adlm_LR' => 'פולה (אדלם, ליבריה)',
        'ff_Adlm_MR' => 'פולה (אדלם, מאוריטניה)',
        'ff_Adlm_NE' => 'פולה (אדלם, ניז׳ר)',
        'ff_Adlm_NG' => 'פולה (אדלם, ניגריה)',
        'ff_Adlm_SL' => 'פולה (אדלם, סיירה לאון)',
        'ff_Adlm_SN' => 'פולה (אדלם, סנגל)',
        'ff_CM' => 'פולה (קמרון)',
        'ff_GN' => 'פולה (גינאה)',
        'ff_Latn' => 'פולה (לטיני)',
        'ff_Latn_BF' => 'פולה (לטיני, בורקינה פאסו)',
        'ff_Latn_CM' => 'פולה (לטיני, קמרון)',
        'ff_Latn_GH' => 'פולה (לטיני, גאנה)',
        'ff_Latn_GM' => 'פולה (לטיני, גמביה)',
        'ff_Latn_GN' => 'פולה (לטיני, גינאה)',
        'ff_Latn_GW' => 'פולה (לטיני, גינאה-ביסאו)',
        'ff_Latn_LR' => 'פולה (לטיני, ליבריה)',
        'ff_Latn_MR' => 'פולה (לטיני, מאוריטניה)',
        'ff_Latn_NE' => 'פולה (לטיני, ניז׳ר)',
        'ff_Latn_NG' => 'פולה (לטיני, ניגריה)',
        'ff_Latn_SL' => 'פולה (לטיני, סיירה לאון)',
        'ff_Latn_SN' => 'פולה (לטיני, סנגל)',
        'ff_MR' => 'פולה (מאוריטניה)',
        'ff_SN' => 'פולה (סנגל)',
        'fi' => 'פינית',
        'fi_FI' => 'פינית (פינלנד)',
        'fo' => 'פארואזית',
        'fo_DK' => 'פארואזית (דנמרק)',
        'fo_FO' => 'פארואזית (איי פארו)',
        'fr' => 'צרפתית',
        'fr_BE' => 'צרפתית (בלגיה)',
        'fr_BF' => 'צרפתית (בורקינה פאסו)',
        'fr_BI' => 'צרפתית (בורונדי)',
        'fr_BJ' => 'צרפתית (בנין)',
        'fr_BL' => 'צרפתית (סנט ברתולומיאו)',
        'fr_CA' => 'צרפתית (קנדה)',
        'fr_CD' => 'צרפתית (קונגו - קינשאסה)',
        'fr_CF' => 'צרפתית (הרפובליקה המרכז-אפריקאית)',
        'fr_CG' => 'צרפתית (קונגו - ברזאויל)',
        'fr_CH' => 'צרפתית (שווייץ)',
        'fr_CI' => 'צרפתית (חוף השנהב)',
        'fr_CM' => 'צרפתית (קמרון)',
        'fr_DJ' => 'צרפתית (ג׳יבוטי)',
        'fr_DZ' => 'צרפתית (אלג׳יריה)',
        'fr_FR' => 'צרפתית (צרפת)',
        'fr_GA' => 'צרפתית (גבון)',
        'fr_GF' => 'צרפתית (גיאנה הצרפתית)',
        'fr_GN' => 'צרפתית (גינאה)',
        'fr_GP' => 'צרפתית (גוואדלופ)',
        'fr_GQ' => 'צרפתית (גינאה המשוונית)',
        'fr_HT' => 'צרפתית (האיטי)',
        'fr_KM' => 'צרפתית (קומורו)',
        'fr_LU' => 'צרפתית (לוקסמבורג)',
        'fr_MA' => 'צרפתית (מרוקו)',
        'fr_MC' => 'צרפתית (מונקו)',
        'fr_MF' => 'צרפתית (סן מרטן)',
        'fr_MG' => 'צרפתית (מדגסקר)',
        'fr_ML' => 'צרפתית (מאלי)',
        'fr_MQ' => 'צרפתית (מרטיניק)',
        'fr_MR' => 'צרפתית (מאוריטניה)',
        'fr_MU' => 'צרפתית (מאוריציוס)',
        'fr_NC' => 'צרפתית (קלדוניה החדשה)',
        'fr_NE' => 'צרפתית (ניז׳ר)',
        'fr_PF' => 'צרפתית (פולינזיה הצרפתית)',
        'fr_PM' => 'צרפתית (סנט פייר ומיקלון)',
        'fr_RE' => 'צרפתית (ראוניון)',
        'fr_RW' => 'צרפתית (רואנדה)',
        'fr_SC' => 'צרפתית (איי סיישל)',
        'fr_SN' => 'צרפתית (סנגל)',
        'fr_SY' => 'צרפתית (סוריה)',
        'fr_TD' => 'צרפתית (צ׳אד)',
        'fr_TG' => 'צרפתית (טוגו)',
        'fr_TN' => 'צרפתית (תוניסיה)',
        'fr_VU' => 'צרפתית (ונואטו)',
        'fr_WF' => 'צרפתית (איי ווליס ופוטונה)',
        'fr_YT' => 'צרפתית (מאיוט)',
        'fy' => 'פריזית מערבית',
        'fy_NL' => 'פריזית מערבית (הולנד)',
        'ga' => 'אירית',
        'ga_GB' => 'אירית (בריטניה)',
        'ga_IE' => 'אירית (אירלנד)',
        'gd' => 'גאלית סקוטית',
        'gd_GB' => 'גאלית סקוטית (בריטניה)',
        'gl' => 'גליציאנית',
        'gl_ES' => 'גליציאנית (ספרד)',
        'gu' => 'גוג׳ארטי',
        'gu_IN' => 'גוג׳ארטי (הודו)',
        'gv' => 'מאנית',
        'gv_IM' => 'מאנית (האי מאן)',
        'ha' => 'האוסה',
        'ha_GH' => 'האוסה (גאנה)',
        'ha_NE' => 'האוסה (ניז׳ר)',
        'ha_NG' => 'האוסה (ניגריה)',
        'he' => 'עברית',
        'he_IL' => 'עברית (ישראל)',
        'hi' => 'הינדי',
        'hi_IN' => 'הינדי (הודו)',
        'hi_Latn' => 'הינדי (לטיני)',
        'hi_Latn_IN' => 'הינדי (לטיני, הודו)',
        'hr' => 'קרואטית',
        'hr_BA' => 'קרואטית (בוסניה והרצגובינה)',
        'hr_HR' => 'קרואטית (קרואטיה)',
        'hu' => 'הונגרית',
        'hu_HU' => 'הונגרית (הונגריה)',
        'hy' => 'ארמנית',
        'hy_AM' => 'ארמנית (ארמניה)',
        'ia' => '‏אינטרלינגואה',
        'ia_001' => '‏אינטרלינגואה (העולם)',
        'id' => 'אינדונזית',
        'id_ID' => 'אינדונזית (אינדונזיה)',
        'ig' => 'איגבו',
        'ig_NG' => 'איגבו (ניגריה)',
        'ii' => 'סצ׳ואן יי',
        'ii_CN' => 'סצ׳ואן יי (סין)',
        'is' => 'איסלנדית',
        'is_IS' => 'איסלנדית (איסלנד)',
        'it' => 'איטלקית',
        'it_CH' => 'איטלקית (שווייץ)',
        'it_IT' => 'איטלקית (איטליה)',
        'it_SM' => 'איטלקית (סן מרינו)',
        'it_VA' => 'איטלקית (הוותיקן)',
        'ja' => 'יפנית',
        'ja_JP' => 'יפנית (יפן)',
        'jv' => 'יאוואית',
        'jv_ID' => 'יאוואית (אינדונזיה)',
        'ka' => 'גאורגית',
        'ka_GE' => 'גאורגית (גאורגיה)',
        'ki' => 'קיקויו',
        'ki_KE' => 'קיקויו (קניה)',
        'kk' => 'קזחית',
        'kk_KZ' => 'קזחית (קזחסטן)',
        'kl' => 'גרינלנדית',
        'kl_GL' => 'גרינלנדית (גרינלנד)',
        'km' => 'חמרית',
        'km_KH' => 'חמרית (קמבודיה)',
        'kn' => 'קנאדה',
        'kn_IN' => 'קנאדה (הודו)',
        'ko' => 'קוריאנית',
        'ko_KP' => 'קוריאנית (קוריאה הצפונית)',
        'ko_KR' => 'קוריאנית (קוריאה הדרומית)',
        'ks' => 'קשמירית',
        'ks_Arab' => 'קשמירית (ערבי)',
        'ks_Arab_IN' => 'קשמירית (ערבי, הודו)',
        'ks_Deva' => 'קשמירית (דוואנגרי)',
        'ks_Deva_IN' => 'קשמירית (דוואנגרי, הודו)',
        'ks_IN' => 'קשמירית (הודו)',
        'ku' => 'כורדית',
        'ku_TR' => 'כורדית (טורקיה)',
        'kw' => 'קורנית',
        'kw_GB' => 'קורנית (בריטניה)',
        'ky' => 'קירגיזית',
        'ky_KG' => 'קירגיזית (קירגיזסטן)',
        'lb' => 'לוקסמבורגית',
        'lb_LU' => 'לוקסמבורגית (לוקסמבורג)',
        'lg' => 'גאנדה',
        'lg_UG' => 'גאנדה (אוגנדה)',
        'ln' => 'לינגלה',
        'ln_AO' => 'לינגלה (אנגולה)',
        'ln_CD' => 'לינגלה (קונגו - קינשאסה)',
        'ln_CF' => 'לינגלה (הרפובליקה המרכז-אפריקאית)',
        'ln_CG' => 'לינגלה (קונגו - ברזאויל)',
        'lo' => 'לאו',
        'lo_LA' => 'לאו (לאוס)',
        'lt' => 'ליטאית',
        'lt_LT' => 'ליטאית (ליטא)',
        'lu' => 'לובה-קטנגה',
        'lu_CD' => 'לובה-קטנגה (קונגו - קינשאסה)',
        'lv' => 'לטבית',
        'lv_LV' => 'לטבית (לטביה)',
        'mg' => 'מלגשית',
        'mg_MG' => 'מלגשית (מדגסקר)',
        'mi' => 'מאורית',
        'mi_NZ' => 'מאורית (ניו זילנד)',
        'mk' => 'מקדונית',
        'mk_MK' => 'מקדונית (מקדוניה הצפונית)',
        'ml' => 'מליאלאם',
        'ml_IN' => 'מליאלאם (הודו)',
        'mn' => 'מונגולית',
        'mn_MN' => 'מונגולית (מונגוליה)',
        'mr' => 'מראטהית',
        'mr_IN' => 'מראטהית (הודו)',
        'ms' => 'מלאית',
        'ms_BN' => 'מלאית (ברוניי)',
        'ms_ID' => 'מלאית (אינדונזיה)',
        'ms_MY' => 'מלאית (מלזיה)',
        'ms_SG' => 'מלאית (סינגפור)',
        'mt' => 'מלטית',
        'mt_MT' => 'מלטית (מלטה)',
        'my' => 'בורמזית',
        'my_MM' => 'בורמזית (מיאנמר [בורמה])',
        'nb' => 'נורווגית ספרותית',
        'nb_NO' => 'נורווגית ספרותית (נורווגיה)',
        'nb_SJ' => 'נורווגית ספרותית (סבאלברד ויאן מאיין)',
        'nd' => 'נדבלה צפונית',
        'nd_ZW' => 'נדבלה צפונית (זימבבואה)',
        'ne' => 'נפאלית',
        'ne_IN' => 'נפאלית (הודו)',
        'ne_NP' => 'נפאלית (נפאל)',
        'nl' => 'הולנדית',
        'nl_AW' => 'הולנדית (ארובה)',
        'nl_BE' => 'הולנדית (בלגיה)',
        'nl_BQ' => 'הולנדית (האיים הקריביים ההולנדיים)',
        'nl_CW' => 'הולנדית (קוראסאו)',
        'nl_NL' => 'הולנדית (הולנד)',
        'nl_SR' => 'הולנדית (סורינאם)',
        'nl_SX' => 'הולנדית (סנט מארטן)',
        'nn' => 'נורווגית חדשה',
        'nn_NO' => 'נורווגית חדשה (נורווגיה)',
        'no' => 'נורווגית',
        'no_NO' => 'נורווגית (נורווגיה)',
        'om' => 'אורומו',
        'om_ET' => 'אורומו (אתיופיה)',
        'om_KE' => 'אורומו (קניה)',
        'or' => 'אורייה',
        'or_IN' => 'אורייה (הודו)',
        'os' => 'אוסטית',
        'os_GE' => 'אוסטית (גאורגיה)',
        'os_RU' => 'אוסטית (רוסיה)',
        'pa' => 'פנג׳אבי',
        'pa_Arab' => 'פנג׳אבי (ערבי)',
        'pa_Arab_PK' => 'פנג׳אבי (ערבי, פקיסטן)',
        'pa_Guru' => 'פנג׳אבי (גורמוקי)',
        'pa_Guru_IN' => 'פנג׳אבי (גורמוקי, הודו)',
        'pa_IN' => 'פנג׳אבי (הודו)',
        'pa_PK' => 'פנג׳אבי (פקיסטן)',
        'pl' => 'פולנית',
        'pl_PL' => 'פולנית (פולין)',
        'ps' => 'פאשטו',
        'ps_AF' => 'פאשטו (אפגניסטן)',
        'ps_PK' => 'פאשטו (פקיסטן)',
        'pt' => 'פורטוגזית',
        'pt_AO' => 'פורטוגזית (אנגולה)',
        'pt_BR' => 'פורטוגזית (ברזיל)',
        'pt_CH' => 'פורטוגזית (שווייץ)',
        'pt_CV' => 'פורטוגזית (כף ורדה)',
        'pt_GQ' => 'פורטוגזית (גינאה המשוונית)',
        'pt_GW' => 'פורטוגזית (גינאה-ביסאו)',
        'pt_LU' => 'פורטוגזית (לוקסמבורג)',
        'pt_MO' => 'פורטוגזית (מקאו [אזור מנהלי מיוחד של סין])',
        'pt_MZ' => 'פורטוגזית (מוזמביק)',
        'pt_PT' => 'פורטוגזית (פורטוגל)',
        'pt_ST' => 'פורטוגזית (סאו טומה ופרינסיפה)',
        'pt_TL' => 'פורטוגזית (טימור-לסטה)',
        'qu' => 'קצ׳ואה',
        'qu_BO' => 'קצ׳ואה (בוליביה)',
        'qu_EC' => 'קצ׳ואה (אקוודור)',
        'qu_PE' => 'קצ׳ואה (פרו)',
        'rm' => 'רומאנש',
        'rm_CH' => 'רומאנש (שווייץ)',
        'rn' => 'קירונדי',
        'rn_BI' => 'קירונדי (בורונדי)',
        'ro' => 'רומנית',
        'ro_MD' => 'רומנית (מולדובה)',
        'ro_RO' => 'רומנית (רומניה)',
        'ru' => 'רוסית',
        'ru_BY' => 'רוסית (בלארוס)',
        'ru_KG' => 'רוסית (קירגיזסטן)',
        'ru_KZ' => 'רוסית (קזחסטן)',
        'ru_MD' => 'רוסית (מולדובה)',
        'ru_RU' => 'רוסית (רוסיה)',
        'ru_UA' => 'רוסית (אוקראינה)',
        'rw' => 'קנירואנדית',
        'rw_RW' => 'קנירואנדית (רואנדה)',
        'sa' => 'סנסקריט',
        'sa_IN' => 'סנסקריט (הודו)',
        'sc' => 'סרדינית',
        'sc_IT' => 'סרדינית (איטליה)',
        'sd' => 'סינדהית',
        'sd_Arab' => 'סינדהית (ערבי)',
        'sd_Arab_PK' => 'סינדהית (ערבי, פקיסטן)',
        'sd_Deva' => 'סינדהית (דוואנגרי)',
        'sd_Deva_IN' => 'סינדהית (דוואנגרי, הודו)',
        'sd_IN' => 'סינדהית (הודו)',
        'sd_PK' => 'סינדהית (פקיסטן)',
        'se' => 'סמי צפונית',
        'se_FI' => 'סמי צפונית (פינלנד)',
        'se_NO' => 'סמי צפונית (נורווגיה)',
        'se_SE' => 'סמי צפונית (שוודיה)',
        'sg' => 'סנגו',
        'sg_CF' => 'סנגו (הרפובליקה המרכז-אפריקאית)',
        'sh' => 'סרבו-קרואטית',
        'sh_BA' => 'סרבו-קרואטית (בוסניה והרצגובינה)',
        'si' => 'סינהלה',
        'si_LK' => 'סינהלה (סרי לנקה)',
        'sk' => 'סלובקית',
        'sk_SK' => 'סלובקית (סלובקיה)',
        'sl' => 'סלובנית',
        'sl_SI' => 'סלובנית (סלובניה)',
        'sn' => 'שונה',
        'sn_ZW' => 'שונה (זימבבואה)',
        'so' => 'סומלית',
        'so_DJ' => 'סומלית (ג׳יבוטי)',
        'so_ET' => 'סומלית (אתיופיה)',
        'so_KE' => 'סומלית (קניה)',
        'so_SO' => 'סומלית (סומליה)',
        'sq' => 'אלבנית',
        'sq_AL' => 'אלבנית (אלבניה)',
        'sq_MK' => 'אלבנית (מקדוניה הצפונית)',
        'sr' => 'סרבית',
        'sr_BA' => 'סרבית (בוסניה והרצגובינה)',
        'sr_Cyrl' => 'סרבית (קירילי)',
        'sr_Cyrl_BA' => 'סרבית (קירילי, בוסניה והרצגובינה)',
        'sr_Cyrl_ME' => 'סרבית (קירילי, מונטנגרו)',
        'sr_Cyrl_RS' => 'סרבית (קירילי, סרביה)',
        'sr_Latn' => 'סרבית (לטיני)',
        'sr_Latn_BA' => 'סרבית (לטיני, בוסניה והרצגובינה)',
        'sr_Latn_ME' => 'סרבית (לטיני, מונטנגרו)',
        'sr_Latn_RS' => 'סרבית (לטיני, סרביה)',
        'sr_ME' => 'סרבית (מונטנגרו)',
        'sr_RS' => 'סרבית (סרביה)',
        'su' => 'סונדנזית',
        'su_ID' => 'סונדנזית (אינדונזיה)',
        'su_Latn' => 'סונדנזית (לטיני)',
        'su_Latn_ID' => 'סונדנזית (לטיני, אינדונזיה)',
        'sv' => 'שוודית',
        'sv_AX' => 'שוודית (איי אולנד)',
        'sv_FI' => 'שוודית (פינלנד)',
        'sv_SE' => 'שוודית (שוודיה)',
        'sw' => 'סווהילי',
        'sw_CD' => 'סווהילי (קונגו - קינשאסה)',
        'sw_KE' => 'סווהילי (קניה)',
        'sw_TZ' => 'סווהילי (טנזניה)',
        'sw_UG' => 'סווהילי (אוגנדה)',
        'ta' => 'טמילית',
        'ta_IN' => 'טמילית (הודו)',
        'ta_LK' => 'טמילית (סרי לנקה)',
        'ta_MY' => 'טמילית (מלזיה)',
        'ta_SG' => 'טמילית (סינגפור)',
        'te' => 'טלוגו',
        'te_IN' => 'טלוגו (הודו)',
        'tg' => 'טג׳יקית',
        'tg_TJ' => 'טג׳יקית (טג׳יקיסטן)',
        'th' => 'תאית',
        'th_TH' => 'תאית (תאילנד)',
        'ti' => 'תיגרינית',
        'ti_ER' => 'תיגרינית (אריתריאה)',
        'ti_ET' => 'תיגרינית (אתיופיה)',
        'tk' => 'טורקמנית',
        'tk_TM' => 'טורקמנית (טורקמניסטן)',
        'tl' => 'טאגאלוג',
        'tl_PH' => 'טאגאלוג (הפיליפינים)',
        'to' => 'טונגאית',
        'to_TO' => 'טונגאית (טונגה)',
        'tr' => 'טורקית',
        'tr_CY' => 'טורקית (קפריסין)',
        'tr_TR' => 'טורקית (טורקיה)',
        'tt' => 'טטרית',
        'tt_RU' => 'טטרית (רוסיה)',
        'ug' => 'אויגורית',
        'ug_CN' => 'אויגורית (סין)',
        'uk' => 'אוקראינית',
        'uk_UA' => 'אוקראינית (אוקראינה)',
        'ur' => 'אורדו',
        'ur_IN' => 'אורדו (הודו)',
        'ur_PK' => 'אורדו (פקיסטן)',
        'uz' => 'אוזבקית',
        'uz_AF' => 'אוזבקית (אפגניסטן)',
        'uz_Arab' => 'אוזבקית (ערבי)',
        'uz_Arab_AF' => 'אוזבקית (ערבי, אפגניסטן)',
        'uz_Cyrl' => 'אוזבקית (קירילי)',
        'uz_Cyrl_UZ' => 'אוזבקית (קירילי, אוזבקיסטן)',
        'uz_Latn' => 'אוזבקית (לטיני)',
        'uz_Latn_UZ' => 'אוזבקית (לטיני, אוזבקיסטן)',
        'uz_UZ' => 'אוזבקית (אוזבקיסטן)',
        'vi' => 'וייטנאמית',
        'vi_VN' => 'וייטנאמית (וייטנאם)',
        'wo' => 'וולוף',
        'wo_SN' => 'וולוף (סנגל)',
        'xh' => 'קוסה',
        'xh_ZA' => 'קוסה (דרום אפריקה)',
        'yi' => 'יידיש',
        'yi_001' => 'יידיש (העולם)',
        'yo' => 'יורובה',
        'yo_BJ' => 'יורובה (בנין)',
        'yo_NG' => 'יורובה (ניגריה)',
        'zh' => 'סינית',
        'zh_CN' => 'סינית (סין)',
        'zh_HK' => 'סינית (הונג קונג [אזור מנהלי מיוחד של סין])',
        'zh_Hans' => 'סינית (פשוט)',
        'zh_Hans_CN' => 'סינית (פשוט, סין)',
        'zh_Hans_HK' => 'סינית (פשוט, הונג קונג [אזור מנהלי מיוחד של סין])',
        'zh_Hans_MO' => 'סינית (פשוט, מקאו [אזור מנהלי מיוחד של סין])',
        'zh_Hans_SG' => 'סינית (פשוט, סינגפור)',
        'zh_Hant' => 'סינית (מסורתי)',
        'zh_Hant_HK' => 'סינית (מסורתי, הונג קונג [אזור מנהלי מיוחד של סין])',
        'zh_Hant_MO' => 'סינית (מסורתי, מקאו [אזור מנהלי מיוחד של סין])',
        'zh_Hant_TW' => 'סינית (מסורתי, טייוואן)',
        'zh_MO' => 'סינית (מקאו [אזור מנהלי מיוחד של סין])',
        'zh_SG' => 'סינית (סינגפור)',
        'zh_TW' => 'סינית (טייוואן)',
        'zu' => 'זולו',
        'zu_ZA' => 'זולו (דרום אפריקה)',
    ],
];
