<?php

return [
    'Names' => [
        'af' => 'lea fakaʻafilikana',
        'af_NA' => 'lea fakaʻafilikana (Namipia)',
        'af_ZA' => 'lea fakaʻafilikana (ʻAfilika tonga)',
        'ak' => 'lea fakaʻakani',
        'ak_GH' => 'lea fakaʻakani (Kana)',
        'am' => 'lea fakaʻameliki',
        'am_ET' => 'lea fakaʻameliki (ʻĪtiōpia)',
        'ar' => 'lea fakaʻalepea',
        'ar_001' => 'lea fakaʻalepea (Māmani)',
        'ar_AE' => 'lea fakaʻalepea (ʻAlepea Fakatahataha)',
        'ar_BH' => 'lea fakaʻalepea (Paleini)',
        'ar_DJ' => 'lea fakaʻalepea (Siputi)',
        'ar_DZ' => 'lea fakaʻalepea (ʻAlisilia)',
        'ar_EG' => 'lea fakaʻalepea (ʻIsipite)',
        'ar_EH' => 'lea fakaʻalepea (Sahala fakahihifo)',
        'ar_ER' => 'lea fakaʻalepea (ʻElitulia)',
        'ar_IL' => 'lea fakaʻalepea (ʻIsileli)',
        'ar_IQ' => 'lea fakaʻalepea (ʻIlaaki)',
        'ar_JO' => 'lea fakaʻalepea (Soatane)',
        'ar_KM' => 'lea fakaʻalepea (Komolosi)',
        'ar_KW' => 'lea fakaʻalepea (Kueiti)',
        'ar_LB' => 'lea fakaʻalepea (Lepanoni)',
        'ar_LY' => 'lea fakaʻalepea (Līpia)',
        'ar_MA' => 'lea fakaʻalepea (Moloko)',
        'ar_MR' => 'lea fakaʻalepea (Maulitenia)',
        'ar_OM' => 'lea fakaʻalepea (ʻOmani)',
        'ar_PS' => 'lea fakaʻalepea (Potu Palesitaine)',
        'ar_QA' => 'lea fakaʻalepea (Katā)',
        'ar_SA' => 'lea fakaʻalepea (Saute ʻAlepea)',
        'ar_SD' => 'lea fakaʻalepea (Sūteni)',
        'ar_SO' => 'lea fakaʻalepea (Sōmalia)',
        'ar_SS' => 'lea fakaʻalepea (Sūtani fakatonga)',
        'ar_SY' => 'lea fakaʻalepea (Sīlia)',
        'ar_TD' => 'lea fakaʻalepea (Sāti)',
        'ar_TN' => 'lea fakaʻalepea (Tunīsia)',
        'ar_YE' => 'lea fakaʻalepea (Iemeni)',
        'as' => 'lea fakaʻasamia',
        'as_IN' => 'lea fakaʻasamia (ʻInitia)',
        'az' => 'lea fakaʻasapaisani',
        'az_AZ' => 'lea fakaʻasapaisani (ʻAsapaisani)',
        'az_Cyrl' => 'lea fakaʻasapaisani (tohinima fakalūsia)',
        'az_Cyrl_AZ' => 'lea fakaʻasapaisani (tohinima fakalūsia, ʻAsapaisani)',
        'az_Latn' => 'lea fakaʻasapaisani (tohinima fakalatina)',
        'az_Latn_AZ' => 'lea fakaʻasapaisani (tohinima fakalatina, ʻAsapaisani)',
        'be' => 'lea fakapelalusi',
        'be_BY' => 'lea fakapelalusi (Pelalusi)',
        'bg' => 'lea fakapulukalia',
        'bg_BG' => 'lea fakapulukalia (Pulukalia)',
        'bm' => 'lea fakapamipala',
        'bm_ML' => 'lea fakapamipala (Māli)',
        'bn' => 'lea fakapāngilā',
        'bn_BD' => 'lea fakapāngilā (Pengilātesi)',
        'bn_IN' => 'lea fakapāngilā (ʻInitia)',
        'bo' => 'lea fakatipeti',
        'bo_CN' => 'lea fakatipeti (Siaina)',
        'bo_IN' => 'lea fakatipeti (ʻInitia)',
        'br' => 'lea fakapeletoni',
        'br_FR' => 'lea fakapeletoni (Falanisē)',
        'bs' => 'lea fakaposinia',
        'bs_BA' => 'lea fakaposinia (Posinia mo Hesikōvina)',
        'bs_Cyrl' => 'lea fakaposinia (tohinima fakalūsia)',
        'bs_Cyrl_BA' => 'lea fakaposinia (tohinima fakalūsia, Posinia mo Hesikōvina)',
        'bs_Latn' => 'lea fakaposinia (tohinima fakalatina)',
        'bs_Latn_BA' => 'lea fakaposinia (tohinima fakalatina, Posinia mo Hesikōvina)',
        'ca' => 'lea fakakatalani',
        'ca_AD' => 'lea fakakatalani (ʻAnitola)',
        'ca_ES' => 'lea fakakatalani (Sipeini)',
        'ca_FR' => 'lea fakakatalani (Falanisē)',
        'ca_IT' => 'lea fakakatalani (ʻĪtali)',
        'ce' => 'lea fakasese',
        'ce_RU' => 'lea fakasese (Lūsia)',
        'cs' => 'lea fakaseki',
        'cs_CZ' => 'lea fakaseki (Sēkia)',
        'cv' => 'lea fakasuvasa',
        'cv_RU' => 'lea fakasuvasa (Lūsia)',
        'cy' => 'lea fakauēlesi',
        'cy_GB' => 'lea fakauēlesi (Pilitānia)',
        'da' => 'lea fakatenimaʻake',
        'da_DK' => 'lea fakatenimaʻake (Tenimaʻake)',
        'da_GL' => 'lea fakatenimaʻake (Kulinilani)',
        'de' => 'lea fakasiamane',
        'de_AT' => 'lea fakasiamane (ʻAositulia)',
        'de_BE' => 'lea fakasiamane (Pelesiume)',
        'de_CH' => 'lea fakasiamane (Suisilani)',
        'de_DE' => 'lea fakasiamane (Siamane)',
        'de_IT' => 'lea fakasiamane (ʻĪtali)',
        'de_LI' => 'lea fakasiamane (Likitenisiteini)',
        'de_LU' => 'lea fakasiamane (Lakisimipeki)',
        'dz' => 'lea fakatisōngika',
        'dz_BT' => 'lea fakatisōngika (Pūtani)',
        'ee' => 'lea fakaʻeue',
        'ee_GH' => 'lea fakaʻeue (Kana)',
        'ee_TG' => 'lea fakaʻeue (Toko)',
        'el' => 'lea fakakalisi',
        'el_CY' => 'lea fakakalisi (Saipalesi)',
        'el_GR' => 'lea fakakalisi (Kalisi)',
        'en' => 'lea fakapālangi',
        'en_001' => 'lea fakapālangi (Māmani)',
        'en_150' => 'lea fakapālangi (ʻEulope)',
        'en_AE' => 'lea fakapālangi (ʻAlepea Fakatahataha)',
        'en_AG' => 'lea fakapālangi (Anitikua mo Palaputa)',
        'en_AI' => 'lea fakapālangi (Anikuila)',
        'en_AS' => 'lea fakapālangi (Haʻamoa ʻAmelika)',
        'en_AT' => 'lea fakapālangi (ʻAositulia)',
        'en_AU' => 'lea fakapālangi (ʻAositelēlia)',
        'en_BB' => 'lea fakapālangi (Pāpeitosi)',
        'en_BE' => 'lea fakapālangi (Pelesiume)',
        'en_BI' => 'lea fakapālangi (Puluniti)',
        'en_BM' => 'lea fakapālangi (Pēmuta)',
        'en_BS' => 'lea fakapālangi (Pahama)',
        'en_BW' => 'lea fakapālangi (Potisiuana)',
        'en_BZ' => 'lea fakapālangi (Pelise)',
        'en_CA' => 'lea fakapālangi (Kānata)',
        'en_CC' => 'lea fakapālangi (ʻOtumotu Koko)',
        'en_CH' => 'lea fakapālangi (Suisilani)',
        'en_CK' => 'lea fakapālangi (ʻOtumotu Kuki)',
        'en_CM' => 'lea fakapālangi (Kameluni)',
        'en_CX' => 'lea fakapālangi (Motu Kilisimasi)',
        'en_CY' => 'lea fakapālangi (Saipalesi)',
        'en_DE' => 'lea fakapālangi (Siamane)',
        'en_DK' => 'lea fakapālangi (Tenimaʻake)',
        'en_DM' => 'lea fakapālangi (Tominika)',
        'en_ER' => 'lea fakapālangi (ʻElitulia)',
        'en_FI' => 'lea fakapālangi (Finilani)',
        'en_FJ' => 'lea fakapālangi (Fisi)',
        'en_FK' => 'lea fakapālangi (ʻOtumotu Fokulani)',
        'en_FM' => 'lea fakapālangi (Mikolonīsia)',
        'en_GB' => 'lea fakapālangi (Pilitānia)',
        'en_GD' => 'lea fakapālangi (Kelenatā)',
        'en_GG' => 'lea fakapālangi (Kuenisī)',
        'en_GH' => 'lea fakapālangi (Kana)',
        'en_GI' => 'lea fakapālangi (Sipalālitā)',
        'en_GM' => 'lea fakapālangi (Kamipia)',
        'en_GU' => 'lea fakapālangi (Kuamu)',
        'en_GY' => 'lea fakapālangi (Kuiana)',
        'en_HK' => 'lea fakapālangi (Hongi Kongi SAR Siaina)',
        'en_IE' => 'lea fakapālangi (ʻAealani)',
        'en_IL' => 'lea fakapālangi (ʻIsileli)',
        'en_IM' => 'lea fakapālangi (Motu Mani)',
        'en_IN' => 'lea fakapālangi (ʻInitia)',
        'en_IO' => 'lea fakapālangi (Potu fonua moana ʻInitia fakapilitānia)',
        'en_JE' => 'lea fakapālangi (Selusī)',
        'en_JM' => 'lea fakapālangi (Samaika)',
        'en_KE' => 'lea fakapālangi (Keniā)',
        'en_KI' => 'lea fakapālangi (Kilipasi)',
        'en_KN' => 'lea fakapālangi (Sā Kitisi mo Nevisi)',
        'en_KY' => 'lea fakapālangi (ʻOtumotu Keimeni)',
        'en_LC' => 'lea fakapālangi (Sā Lūsia)',
        'en_LR' => 'lea fakapālangi (Laipelia)',
        'en_LS' => 'lea fakapālangi (Lesoto)',
        'en_MG' => 'lea fakapālangi (Matakasika)',
        'en_MH' => 'lea fakapālangi (ʻOtumotu Māsolo)',
        'en_MO' => 'lea fakapālangi (Makau SAR Siaina)',
        'en_MP' => 'lea fakapālangi (ʻOtumotu Maliana tokelau)',
        'en_MS' => 'lea fakapālangi (Moʻungaselati)',
        'en_MT' => 'lea fakapālangi (Malita)',
        'en_MU' => 'lea fakapālangi (Maulitiusi)',
        'en_MV' => 'lea fakapālangi (Malativisi)',
        'en_MW' => 'lea fakapālangi (Malaui)',
        'en_MY' => 'lea fakapālangi (Malēsia)',
        'en_NA' => 'lea fakapālangi (Namipia)',
        'en_NF' => 'lea fakapālangi (Motu Nōfoliki)',
        'en_NG' => 'lea fakapālangi (Naisilia)',
        'en_NL' => 'lea fakapālangi (Hōlani)',
        'en_NR' => 'lea fakapālangi (Naulu)',
        'en_NU' => 'lea fakapālangi (Niuē)',
        'en_NZ' => 'lea fakapālangi (Nuʻusila)',
        'en_PG' => 'lea fakapālangi (Papuaniukini)',
        'en_PH' => 'lea fakapālangi (Filipaini)',
        'en_PK' => 'lea fakapālangi (Pākisitani)',
        'en_PN' => 'lea fakapālangi (ʻOtumotu Pitikeni)',
        'en_PR' => 'lea fakapālangi (Puēto Liko)',
        'en_PW' => 'lea fakapālangi (Palau)',
        'en_RW' => 'lea fakapālangi (Luanitā)',
        'en_SB' => 'lea fakapālangi (ʻOtumotu Solomone)',
        'en_SC' => 'lea fakapālangi (ʻOtumotu Seiseli)',
        'en_SD' => 'lea fakapālangi (Sūteni)',
        'en_SE' => 'lea fakapālangi (Suēteni)',
        'en_SG' => 'lea fakapālangi (Singapoa)',
        'en_SH' => 'lea fakapālangi (Sā Helena)',
        'en_SI' => 'lea fakapālangi (Silōvenia)',
        'en_SL' => 'lea fakapālangi (Siela Leone)',
        'en_SS' => 'lea fakapālangi (Sūtani fakatonga)',
        'en_SX' => 'lea fakapālangi (Sā Mātini [fakahōlani])',
        'en_SZ' => 'lea fakapālangi (ʻEsuatini)',
        'en_TC' => 'lea fakapālangi (ʻOtumotu Tuki mo Kaikosi)',
        'en_TK' => 'lea fakapālangi (Tokelau)',
        'en_TO' => 'lea fakapālangi (Tonga)',
        'en_TT' => 'lea fakapālangi (Tilinitati mo Topako)',
        'en_TV' => 'lea fakapālangi (Tūvalu)',
        'en_TZ' => 'lea fakapālangi (Tenisānia)',
        'en_UG' => 'lea fakapālangi (ʻIukanitā)',
        'en_UM' => 'lea fakapālangi (ʻOtumotu siʻi ʻo ʻAmelika)',
        'en_US' => 'lea fakapālangi (Puleʻanga fakatahataha ʻAmelika)',
        'en_VC' => 'lea fakapālangi (Sā Viniseni mo Kulenatini)',
        'en_VG' => 'lea fakapālangi (ʻOtumotu Vilikini fakapilitānia)',
        'en_VI' => 'lea fakapālangi (ʻOtumotu Vilikini fakaʻamelika)',
        'en_VU' => 'lea fakapālangi (Vanuatu)',
        'en_WS' => 'lea fakapālangi (Haʻamoa)',
        'en_ZA' => 'lea fakapālangi (ʻAfilika tonga)',
        'en_ZM' => 'lea fakapālangi (Semipia)',
        'en_ZW' => 'lea fakapālangi (Simipapuei)',
        'eo' => 'lea fakaʻesipulanito',
        'eo_001' => 'lea fakaʻesipulanito (Māmani)',
        'es' => 'lea fakasipēnisi',
        'es_419' => 'lea fakasipēnisi (ʻAmelika fakalatina)',
        'es_AR' => 'lea fakasipēnisi (ʻAsenitina)',
        'es_BO' => 'lea fakasipēnisi (Polīvia)',
        'es_BR' => 'lea fakasipēnisi (Palāsili)',
        'es_BZ' => 'lea fakasipēnisi (Pelise)',
        'es_CL' => 'lea fakasipēnisi (Sili)',
        'es_CO' => 'lea fakasipēnisi (Kolomipia)',
        'es_CR' => 'lea fakasipēnisi (Kosita Lika)',
        'es_CU' => 'lea fakasipēnisi (Kiupa)',
        'es_DO' => 'lea fakasipēnisi (Lepupelika Tominika)',
        'es_EC' => 'lea fakasipēnisi (ʻEkuetoa)',
        'es_ES' => 'lea fakasipēnisi (Sipeini)',
        'es_GQ' => 'lea fakasipēnisi (ʻEkueta Kini)',
        'es_GT' => 'lea fakasipēnisi (Kuatamala)',
        'es_HN' => 'lea fakasipēnisi (Honitulasi)',
        'es_MX' => 'lea fakasipēnisi (Mekisikou)',
        'es_NI' => 'lea fakasipēnisi (Nikalakua)',
        'es_PA' => 'lea fakasipēnisi (Panamā)',
        'es_PE' => 'lea fakasipēnisi (Pelū)',
        'es_PH' => 'lea fakasipēnisi (Filipaini)',
        'es_PR' => 'lea fakasipēnisi (Puēto Liko)',
        'es_PY' => 'lea fakasipēnisi (Palakuai)',
        'es_SV' => 'lea fakasipēnisi (ʻEle Salavatoa)',
        'es_US' => 'lea fakasipēnisi (Puleʻanga fakatahataha ʻAmelika)',
        'es_UY' => 'lea fakasipēnisi (ʻUlukuai)',
        'es_VE' => 'lea fakasipēnisi (Venesuela)',
        'et' => 'lea fakaʻesitōnia',
        'et_EE' => 'lea fakaʻesitōnia (ʻEsitōnia)',
        'eu' => 'lea fakapāsiki',
        'eu_ES' => 'lea fakapāsiki (Sipeini)',
        'fa' => 'lea fakapēsia',
        'fa_AF' => 'lea fakapēsia (ʻAfikānisitani)',
        'fa_IR' => 'lea fakapēsia (ʻIlaani)',
        'ff' => 'lea fakafulā',
        'ff_Adlm' => 'lea fakafulā (tohinima fakaʻatilami)',
        'ff_Adlm_BF' => 'lea fakafulā (tohinima fakaʻatilami, Pekano Faso)',
        'ff_Adlm_CM' => 'lea fakafulā (tohinima fakaʻatilami, Kameluni)',
        'ff_Adlm_GH' => 'lea fakafulā (tohinima fakaʻatilami, Kana)',
        'ff_Adlm_GM' => 'lea fakafulā (tohinima fakaʻatilami, Kamipia)',
        'ff_Adlm_GN' => 'lea fakafulā (tohinima fakaʻatilami, Kini)',
        'ff_Adlm_GW' => 'lea fakafulā (tohinima fakaʻatilami, Kini-Pisau)',
        'ff_Adlm_LR' => 'lea fakafulā (tohinima fakaʻatilami, Laipelia)',
        'ff_Adlm_MR' => 'lea fakafulā (tohinima fakaʻatilami, Maulitenia)',
        'ff_Adlm_NE' => 'lea fakafulā (tohinima fakaʻatilami, Nisia)',
        'ff_Adlm_NG' => 'lea fakafulā (tohinima fakaʻatilami, Naisilia)',
        'ff_Adlm_SL' => 'lea fakafulā (tohinima fakaʻatilami, Siela Leone)',
        'ff_Adlm_SN' => 'lea fakafulā (tohinima fakaʻatilami, Senekalo)',
        'ff_CM' => 'lea fakafulā (Kameluni)',
        'ff_GN' => 'lea fakafulā (Kini)',
        'ff_Latn' => 'lea fakafulā (tohinima fakalatina)',
        'ff_Latn_BF' => 'lea fakafulā (tohinima fakalatina, Pekano Faso)',
        'ff_Latn_CM' => 'lea fakafulā (tohinima fakalatina, Kameluni)',
        'ff_Latn_GH' => 'lea fakafulā (tohinima fakalatina, Kana)',
        'ff_Latn_GM' => 'lea fakafulā (tohinima fakalatina, Kamipia)',
        'ff_Latn_GN' => 'lea fakafulā (tohinima fakalatina, Kini)',
        'ff_Latn_GW' => 'lea fakafulā (tohinima fakalatina, Kini-Pisau)',
        'ff_Latn_LR' => 'lea fakafulā (tohinima fakalatina, Laipelia)',
        'ff_Latn_MR' => 'lea fakafulā (tohinima fakalatina, Maulitenia)',
        'ff_Latn_NE' => 'lea fakafulā (tohinima fakalatina, Nisia)',
        'ff_Latn_NG' => 'lea fakafulā (tohinima fakalatina, Naisilia)',
        'ff_Latn_SL' => 'lea fakafulā (tohinima fakalatina, Siela Leone)',
        'ff_Latn_SN' => 'lea fakafulā (tohinima fakalatina, Senekalo)',
        'ff_MR' => 'lea fakafulā (Maulitenia)',
        'ff_SN' => 'lea fakafulā (Senekalo)',
        'fi' => 'lea fakafinilani',
        'fi_FI' => 'lea fakafinilani (Finilani)',
        'fo' => 'lea fakafaloe',
        'fo_DK' => 'lea fakafaloe (Tenimaʻake)',
        'fo_FO' => 'lea fakafaloe (ʻOtumotu Faloe)',
        'fr' => 'lea fakafalanisē',
        'fr_BE' => 'lea fakafalanisē (Pelesiume)',
        'fr_BF' => 'lea fakafalanisē (Pekano Faso)',
        'fr_BI' => 'lea fakafalanisē (Puluniti)',
        'fr_BJ' => 'lea fakafalanisē (Penini)',
        'fr_BL' => 'lea fakafalanisē (Sā Patēlemi)',
        'fr_CA' => 'lea fakafalanisē (Kānata)',
        'fr_CD' => 'lea fakafalanisē (Kongo - Kinisasa)',
        'fr_CF' => 'lea fakafalanisē (Lepupelika ʻAfilika Lotoloto)',
        'fr_CG' => 'lea fakafalanisē (Kongo - Palasavila)',
        'fr_CH' => 'lea fakafalanisē (Suisilani)',
        'fr_CI' => 'lea fakafalanisē (Matafonua ʻAivolī)',
        'fr_CM' => 'lea fakafalanisē (Kameluni)',
        'fr_DJ' => 'lea fakafalanisē (Siputi)',
        'fr_DZ' => 'lea fakafalanisē (ʻAlisilia)',
        'fr_FR' => 'lea fakafalanisē (Falanisē)',
        'fr_GA' => 'lea fakafalanisē (Kaponi)',
        'fr_GF' => 'lea fakafalanisē (Kuiana fakafalanisē)',
        'fr_GN' => 'lea fakafalanisē (Kini)',
        'fr_GP' => 'lea fakafalanisē (Kuatalupe)',
        'fr_GQ' => 'lea fakafalanisē (ʻEkueta Kini)',
        'fr_HT' => 'lea fakafalanisē (Haiti)',
        'fr_KM' => 'lea fakafalanisē (Komolosi)',
        'fr_LU' => 'lea fakafalanisē (Lakisimipeki)',
        'fr_MA' => 'lea fakafalanisē (Moloko)',
        'fr_MC' => 'lea fakafalanisē (Monako)',
        'fr_MF' => 'lea fakafalanisē (Sā Mātini [fakafalanisē])',
        'fr_MG' => 'lea fakafalanisē (Matakasika)',
        'fr_ML' => 'lea fakafalanisē (Māli)',
        'fr_MQ' => 'lea fakafalanisē (Mātiniki)',
        'fr_MR' => 'lea fakafalanisē (Maulitenia)',
        'fr_MU' => 'lea fakafalanisē (Maulitiusi)',
        'fr_NC' => 'lea fakafalanisē (Niu Kaletōnia)',
        'fr_NE' => 'lea fakafalanisē (Nisia)',
        'fr_PF' => 'lea fakafalanisē (Polinisia fakafalanisē)',
        'fr_PM' => 'lea fakafalanisē (Sā Piea mo Mikeloni)',
        'fr_RE' => 'lea fakafalanisē (Lēunioni)',
        'fr_RW' => 'lea fakafalanisē (Luanitā)',
        'fr_SC' => 'lea fakafalanisē (ʻOtumotu Seiseli)',
        'fr_SN' => 'lea fakafalanisē (Senekalo)',
        'fr_SY' => 'lea fakafalanisē (Sīlia)',
        'fr_TD' => 'lea fakafalanisē (Sāti)',
        'fr_TG' => 'lea fakafalanisē (Toko)',
        'fr_TN' => 'lea fakafalanisē (Tunīsia)',
        'fr_VU' => 'lea fakafalanisē (Vanuatu)',
        'fr_WF' => 'lea fakafalanisē (ʻUvea mo Futuna)',
        'fr_YT' => 'lea fakafalanisē (Maiote)',
        'fy' => 'lea fakafilisia-hihifo',
        'fy_NL' => 'lea fakafilisia-hihifo (Hōlani)',
        'ga' => 'lea fakaʻaelani',
        'ga_GB' => 'lea fakaʻaelani (Pilitānia)',
        'ga_IE' => 'lea fakaʻaelani (ʻAealani)',
        'gd' => 'lea fakakaeliki',
        'gd_GB' => 'lea fakakaeliki (Pilitānia)',
        'gl' => 'lea fakakalisia',
        'gl_ES' => 'lea fakakalisia (Sipeini)',
        'gu' => 'lea fakakutalati',
        'gu_IN' => 'lea fakakutalati (ʻInitia)',
        'gv' => 'lea fakamangikī',
        'gv_IM' => 'lea fakamangikī (Motu Mani)',
        'ha' => 'lea fakahausa',
        'ha_GH' => 'lea fakahausa (Kana)',
        'ha_NE' => 'lea fakahausa (Nisia)',
        'ha_NG' => 'lea fakahausa (Naisilia)',
        'he' => 'lea fakahepelū',
        'he_IL' => 'lea fakahepelū (ʻIsileli)',
        'hi' => 'lea fakahinitī',
        'hi_IN' => 'lea fakahinitī (ʻInitia)',
        'hi_Latn' => 'lea fakahinitī (tohinima fakalatina)',
        'hi_Latn_IN' => 'lea fakahinitī (tohinima fakalatina, ʻInitia)',
        'hr' => 'lea fakakuloisia',
        'hr_BA' => 'lea fakakuloisia (Posinia mo Hesikōvina)',
        'hr_HR' => 'lea fakakuloisia (Kuloisia)',
        'hu' => 'lea fakahungakalia',
        'hu_HU' => 'lea fakahungakalia (Hungakalia)',
        'hy' => 'lea fakaʻāmenia',
        'hy_AM' => 'lea fakaʻāmenia (ʻĀmenia)',
        'ia' => 'lea fakavahaʻalea',
        'ia_001' => 'lea fakavahaʻalea (Māmani)',
        'id' => 'lea fakaʻinitōnesia',
        'id_ID' => 'lea fakaʻinitōnesia (ʻInitonēsia)',
        'ig' => 'lea fakaʻikipō',
        'ig_NG' => 'lea fakaʻikipō (Naisilia)',
        'ii' => 'lea fakasisiuani-ī',
        'ii_CN' => 'lea fakasisiuani-ī (Siaina)',
        'is' => 'lea fakaʻaisilani',
        'is_IS' => 'lea fakaʻaisilani (ʻAisilani)',
        'it' => 'lea fakaʻītali',
        'it_CH' => 'lea fakaʻītali (Suisilani)',
        'it_IT' => 'lea fakaʻītali (ʻĪtali)',
        'it_SM' => 'lea fakaʻītali (Sā Malino)',
        'it_VA' => 'lea fakaʻītali (Kolo Vatikani)',
        'ja' => 'lea fakasiapani',
        'ja_JP' => 'lea fakasiapani (Siapani)',
        'jv' => 'lea fakasava',
        'jv_ID' => 'lea fakasava (ʻInitonēsia)',
        'ka' => 'lea fakaseōsia',
        'ka_GE' => 'lea fakaseōsia (Seōsia)',
        'ki' => 'lea fakakikuiu',
        'ki_KE' => 'lea fakakikuiu (Keniā)',
        'kk' => 'lea fakakasaki',
        'kk_KZ' => 'lea fakakasaki (Kasakitani)',
        'kl' => 'lea fakakalaʻalisuti',
        'kl_GL' => 'lea fakakalaʻalisuti (Kulinilani)',
        'km' => 'lea fakakamipōtia',
        'km_KH' => 'lea fakakamipōtia (Kamipōtia)',
        'kn' => 'lea fakakanata',
        'kn_IN' => 'lea fakakanata (ʻInitia)',
        'ko' => 'lea fakakōlea',
        'ko_KP' => 'lea fakakōlea (Kōlea tokelau)',
        'ko_KR' => 'lea fakakōlea (Kōlea tonga)',
        'ks' => 'lea fakakāsimila',
        'ks_Arab' => 'lea fakakāsimila (tohinima fakaʻalepea)',
        'ks_Arab_IN' => 'lea fakakāsimila (tohinima fakaʻalepea, ʻInitia)',
        'ks_Deva' => 'lea fakakāsimila (tohinima fakaʻinitia-tevanākalī)',
        'ks_Deva_IN' => 'lea fakakāsimila (tohinima fakaʻinitia-tevanākalī, ʻInitia)',
        'ks_IN' => 'lea fakakāsimila (ʻInitia)',
        'ku' => 'lea fakakulitī',
        'ku_TR' => 'lea fakakulitī (Toake)',
        'kw' => 'lea fakakoniuali',
        'kw_GB' => 'lea fakakoniuali (Pilitānia)',
        'ky' => 'lea fakakīsisi',
        'ky_KG' => 'lea fakakīsisi (Kīkisitani)',
        'lb' => 'lea fakalakisimipeki',
        'lb_LU' => 'lea fakalakisimipeki (Lakisimipeki)',
        'lg' => 'lea fakakanita',
        'lg_UG' => 'lea fakakanita (ʻIukanitā)',
        'ln' => 'lea lingikala',
        'ln_AO' => 'lea lingikala (ʻAngikola)',
        'ln_CD' => 'lea lingikala (Kongo - Kinisasa)',
        'ln_CF' => 'lea lingikala (Lepupelika ʻAfilika Lotoloto)',
        'ln_CG' => 'lea lingikala (Kongo - Palasavila)',
        'lo' => 'lea fakalau',
        'lo_LA' => 'lea fakalau (Lau)',
        'lt' => 'lea fakalituania',
        'lt_LT' => 'lea fakalituania (Lituania)',
        'lu' => 'lea fakalupa-katanga',
        'lu_CD' => 'lea fakalupa-katanga (Kongo - Kinisasa)',
        'lv' => 'lea fakalativia',
        'lv_LV' => 'lea fakalativia (Lativia)',
        'mg' => 'lea fakamalakasi',
        'mg_MG' => 'lea fakamalakasi (Matakasika)',
        'mi' => 'lea fakamauli',
        'mi_NZ' => 'lea fakamauli (Nuʻusila)',
        'mk' => 'lea fakamasitōnia',
        'mk_MK' => 'lea fakamasitōnia (Masetōnia fakatokelau)',
        'ml' => 'lea fakaʻinitia-malāialami',
        'ml_IN' => 'lea fakaʻinitia-malāialami (ʻInitia)',
        'mn' => 'lea fakamongokōlia',
        'mn_MN' => 'lea fakamongokōlia (Mongokōlia)',
        'mr' => 'lea fakamalati',
        'mr_IN' => 'lea fakamalati (ʻInitia)',
        'ms' => 'lea fakamalei',
        'ms_BN' => 'lea fakamalei (Pulunei)',
        'ms_ID' => 'lea fakamalei (ʻInitonēsia)',
        'ms_MY' => 'lea fakamalei (Malēsia)',
        'ms_SG' => 'lea fakamalei (Singapoa)',
        'mt' => 'lea fakamalita',
        'mt_MT' => 'lea fakamalita (Malita)',
        'my' => 'lea fakapema',
        'my_MM' => 'lea fakapema (Mianimā [Pema])',
        'nb' => 'lea fakanouaē-pokimali',
        'nb_NO' => 'lea fakanouaē-pokimali (Noauē)',
        'nb_SJ' => 'lea fakanouaē-pokimali (Sivolopāti mo Sani Maieni)',
        'nd' => 'lea fakanetepele-tokelau',
        'nd_ZW' => 'lea fakanetepele-tokelau (Simipapuei)',
        'ne' => 'lea fakanepali',
        'ne_IN' => 'lea fakanepali (ʻInitia)',
        'ne_NP' => 'lea fakanepali (Nepali)',
        'nl' => 'lea fakahōlani',
        'nl_AW' => 'lea fakahōlani (ʻAlupa)',
        'nl_BE' => 'lea fakahōlani (Pelesiume)',
        'nl_BQ' => 'lea fakahōlani (Kalipiane fakahōlani)',
        'nl_CW' => 'lea fakahōlani (Kulasao)',
        'nl_NL' => 'lea fakahōlani (Hōlani)',
        'nl_SR' => 'lea fakahōlani (Suliname)',
        'nl_SX' => 'lea fakahōlani (Sā Mātini [fakahōlani])',
        'nn' => 'lea fakanoauē-ninosiki',
        'nn_NO' => 'lea fakanoauē-ninosiki (Noauē)',
        'no' => 'lea fakanouaē',
        'no_NO' => 'lea fakanouaē (Noauē)',
        'om' => 'lea fakaʻolomo',
        'om_ET' => 'lea fakaʻolomo (ʻĪtiōpia)',
        'om_KE' => 'lea fakaʻolomo (Keniā)',
        'or' => 'lea fakaʻotia',
        'or_IN' => 'lea fakaʻotia (ʻInitia)',
        'os' => 'lea fakaʻosetiki',
        'os_GE' => 'lea fakaʻosetiki (Seōsia)',
        'os_RU' => 'lea fakaʻosetiki (Lūsia)',
        'pa' => 'lea fakapūnusapi',
        'pa_Arab' => 'lea fakapūnusapi (tohinima fakaʻalepea)',
        'pa_Arab_PK' => 'lea fakapūnusapi (tohinima fakaʻalepea, Pākisitani)',
        'pa_Guru' => 'lea fakapūnusapi (tohinima fakakūmuki)',
        'pa_Guru_IN' => 'lea fakapūnusapi (tohinima fakakūmuki, ʻInitia)',
        'pa_IN' => 'lea fakapūnusapi (ʻInitia)',
        'pa_PK' => 'lea fakapūnusapi (Pākisitani)',
        'pl' => 'lea fakapolani',
        'pl_PL' => 'lea fakapolani (Polani)',
        'ps' => 'lea fakapasitō',
        'ps_AF' => 'lea fakapasitō (ʻAfikānisitani)',
        'ps_PK' => 'lea fakapasitō (Pākisitani)',
        'pt' => 'lea fakapotukali',
        'pt_AO' => 'lea fakapotukali (ʻAngikola)',
        'pt_BR' => 'lea fakapotukali (Palāsili)',
        'pt_CH' => 'lea fakapotukali (Suisilani)',
        'pt_CV' => 'lea fakapotukali (Muiʻi Vēte)',
        'pt_GQ' => 'lea fakapotukali (ʻEkueta Kini)',
        'pt_GW' => 'lea fakapotukali (Kini-Pisau)',
        'pt_LU' => 'lea fakapotukali (Lakisimipeki)',
        'pt_MO' => 'lea fakapotukali (Makau SAR Siaina)',
        'pt_MZ' => 'lea fakapotukali (Mosēmipiki)',
        'pt_PT' => 'lea fakapotukali (Potukali)',
        'pt_ST' => 'lea fakapotukali (Sao Tomē mo Pilinisipe)',
        'pt_TL' => 'lea fakapotukali (Timoa fakahahake)',
        'qu' => 'lea fakakuetisa',
        'qu_BO' => 'lea fakakuetisa (Polīvia)',
        'qu_EC' => 'lea fakakuetisa (ʻEkuetoa)',
        'qu_PE' => 'lea fakakuetisa (Pelū)',
        'rm' => 'lea fakalaito-lomēnia',
        'rm_CH' => 'lea fakalaito-lomēnia (Suisilani)',
        'rn' => 'lea fakaluaniti',
        'rn_BI' => 'lea fakaluaniti (Puluniti)',
        'ro' => 'lea fakalōmenia',
        'ro_MD' => 'lea fakalōmenia (Molotova)',
        'ro_RO' => 'lea fakalōmenia (Lomēnia)',
        'ru' => 'lea fakalūsia',
        'ru_BY' => 'lea fakalūsia (Pelalusi)',
        'ru_KG' => 'lea fakalūsia (Kīkisitani)',
        'ru_KZ' => 'lea fakalūsia (Kasakitani)',
        'ru_MD' => 'lea fakalūsia (Molotova)',
        'ru_RU' => 'lea fakalūsia (Lūsia)',
        'ru_UA' => 'lea fakalūsia (ʻŪkalaʻine)',
        'rw' => 'lea fakakiniāuanita',
        'rw_RW' => 'lea fakakiniāuanita (Luanitā)',
        'sa' => 'lea fakasanisukuliti',
        'sa_IN' => 'lea fakasanisukuliti (ʻInitia)',
        'sc' => 'lea fakasaletīnia',
        'sc_IT' => 'lea fakasaletīnia (ʻĪtali)',
        'sd' => 'lea fakasīniti',
        'sd_Arab' => 'lea fakasīniti (tohinima fakaʻalepea)',
        'sd_Arab_PK' => 'lea fakasīniti (tohinima fakaʻalepea, Pākisitani)',
        'sd_Deva' => 'lea fakasīniti (tohinima fakaʻinitia-tevanākalī)',
        'sd_Deva_IN' => 'lea fakasīniti (tohinima fakaʻinitia-tevanākalī, ʻInitia)',
        'sd_IN' => 'lea fakasīniti (ʻInitia)',
        'sd_PK' => 'lea fakasīniti (Pākisitani)',
        'se' => 'lea fakasami-tokelau',
        'se_FI' => 'lea fakasami-tokelau (Finilani)',
        'se_NO' => 'lea fakasami-tokelau (Noauē)',
        'se_SE' => 'lea fakasami-tokelau (Suēteni)',
        'sg' => 'lea fakasangikō',
        'sg_CF' => 'lea fakasangikō (Lepupelika ʻAfilika Lotoloto)',
        'sh' => 'lea fakakuloisia-sēpia',
        'sh_BA' => 'lea fakakuloisia-sēpia (Posinia mo Hesikōvina)',
        'si' => 'lea fakasingihala',
        'si_LK' => 'lea fakasingihala (Sīlangikā)',
        'sk' => 'lea fakasolāvaki',
        'sk_SK' => 'lea fakasolāvaki (Silōvakia)',
        'sl' => 'lea fakasolovenia',
        'sl_SI' => 'lea fakasolovenia (Silōvenia)',
        'sn' => 'lea fakasiona',
        'sn_ZW' => 'lea fakasiona (Simipapuei)',
        'so' => 'lea fakasomali',
        'so_DJ' => 'lea fakasomali (Siputi)',
        'so_ET' => 'lea fakasomali (ʻĪtiōpia)',
        'so_KE' => 'lea fakasomali (Keniā)',
        'so_SO' => 'lea fakasomali (Sōmalia)',
        'sq' => 'lea fakaʻalapēnia',
        'sq_AL' => 'lea fakaʻalapēnia (ʻAlipania)',
        'sq_MK' => 'lea fakaʻalapēnia (Masetōnia fakatokelau)',
        'sr' => 'lea fakasēpia',
        'sr_BA' => 'lea fakasēpia (Posinia mo Hesikōvina)',
        'sr_Cyrl' => 'lea fakasēpia (tohinima fakalūsia)',
        'sr_Cyrl_BA' => 'lea fakasēpia (tohinima fakalūsia, Posinia mo Hesikōvina)',
        'sr_Cyrl_ME' => 'lea fakasēpia (tohinima fakalūsia, Monitenikalo)',
        'sr_Cyrl_RS' => 'lea fakasēpia (tohinima fakalūsia, Sēpia)',
        'sr_Latn' => 'lea fakasēpia (tohinima fakalatina)',
        'sr_Latn_BA' => 'lea fakasēpia (tohinima fakalatina, Posinia mo Hesikōvina)',
        'sr_Latn_ME' => 'lea fakasēpia (tohinima fakalatina, Monitenikalo)',
        'sr_Latn_RS' => 'lea fakasēpia (tohinima fakalatina, Sēpia)',
        'sr_ME' => 'lea fakasēpia (Monitenikalo)',
        'sr_RS' => 'lea fakasēpia (Sēpia)',
        'su' => 'lea fakasunitā',
        'su_ID' => 'lea fakasunitā (ʻInitonēsia)',
        'su_Latn' => 'lea fakasunitā (tohinima fakalatina)',
        'su_Latn_ID' => 'lea fakasunitā (tohinima fakalatina, ʻInitonēsia)',
        'sv' => 'lea fakasuēteni',
        'sv_AX' => 'lea fakasuēteni (ʻOtumotu ʻAlani)',
        'sv_FI' => 'lea fakasuēteni (Finilani)',
        'sv_SE' => 'lea fakasuēteni (Suēteni)',
        'sw' => 'lea fakasuahili',
        'sw_CD' => 'lea fakasuahili (Kongo - Kinisasa)',
        'sw_KE' => 'lea fakasuahili (Keniā)',
        'sw_TZ' => 'lea fakasuahili (Tenisānia)',
        'sw_UG' => 'lea fakasuahili (ʻIukanitā)',
        'ta' => 'lea fakatamili',
        'ta_IN' => 'lea fakatamili (ʻInitia)',
        'ta_LK' => 'lea fakatamili (Sīlangikā)',
        'ta_MY' => 'lea fakatamili (Malēsia)',
        'ta_SG' => 'lea fakatamili (Singapoa)',
        'te' => 'lea fakaʻinitia-teluku',
        'te_IN' => 'lea fakaʻinitia-teluku (ʻInitia)',
        'tg' => 'lea fakatāsiki',
        'tg_TJ' => 'lea fakatāsiki (Tasikitani)',
        'th' => 'lea fakatailani',
        'th_TH' => 'lea fakatailani (Tailani)',
        'ti' => 'lea fakatikilinia',
        'ti_ER' => 'lea fakatikilinia (ʻElitulia)',
        'ti_ET' => 'lea fakatikilinia (ʻĪtiōpia)',
        'tk' => 'lea fakatēkimeni',
        'tk_TM' => 'lea fakatēkimeni (Tūkimenisitani)',
        'tl' => 'lea fakatakāloka',
        'tl_PH' => 'lea fakatakāloka (Filipaini)',
        'to' => 'lea fakatonga',
        'to_TO' => 'lea fakatonga (Tonga)',
        'tr' => 'lea fakatoake',
        'tr_CY' => 'lea fakatoake (Saipalesi)',
        'tr_TR' => 'lea fakatoake (Toake)',
        'tt' => 'lea fakatatale',
        'tt_RU' => 'lea fakatatale (Lūsia)',
        'ug' => 'lea fakaʻuikūli',
        'ug_CN' => 'lea fakaʻuikūli (Siaina)',
        'uk' => 'lea fakaʻūkalaʻine',
        'uk_UA' => 'lea fakaʻūkalaʻine (ʻŪkalaʻine)',
        'ur' => 'lea fakaʻūtū',
        'ur_IN' => 'lea fakaʻūtū (ʻInitia)',
        'ur_PK' => 'lea fakaʻūtū (Pākisitani)',
        'uz' => 'lea fakaʻusipeki',
        'uz_AF' => 'lea fakaʻusipeki (ʻAfikānisitani)',
        'uz_Arab' => 'lea fakaʻusipeki (tohinima fakaʻalepea)',
        'uz_Arab_AF' => 'lea fakaʻusipeki (tohinima fakaʻalepea, ʻAfikānisitani)',
        'uz_Cyrl' => 'lea fakaʻusipeki (tohinima fakalūsia)',
        'uz_Cyrl_UZ' => 'lea fakaʻusipeki (tohinima fakalūsia, ʻUsipekitani)',
        'uz_Latn' => 'lea fakaʻusipeki (tohinima fakalatina)',
        'uz_Latn_UZ' => 'lea fakaʻusipeki (tohinima fakalatina, ʻUsipekitani)',
        'uz_UZ' => 'lea fakaʻusipeki (ʻUsipekitani)',
        'vi' => 'lea fakavietinami',
        'vi_VN' => 'lea fakavietinami (Vietinami)',
        'wo' => 'lea fakaʻuolofo',
        'wo_SN' => 'lea fakaʻuolofo (Senekalo)',
        'xh' => 'lea fakatōsa',
        'xh_ZA' => 'lea fakatōsa (ʻAfilika tonga)',
        'yi' => 'lea fakaītisi',
        'yi_001' => 'lea fakaītisi (Māmani)',
        'yo' => 'lea fakaʻiōlupa',
        'yo_BJ' => 'lea fakaʻiōlupa (Penini)',
        'yo_NG' => 'lea fakaʻiōlupa (Naisilia)',
        'zh' => 'lea fakasiaina',
        'zh_CN' => 'lea fakasiaina (Siaina)',
        'zh_HK' => 'lea fakasiaina (Hongi Kongi SAR Siaina)',
        'zh_Hans' => 'lea fakasiaina (tohinima fakasiaina-fakafaingofua)',
        'zh_Hans_CN' => 'lea fakasiaina (tohinima fakasiaina-fakafaingofua, Siaina)',
        'zh_Hans_HK' => 'lea fakasiaina (tohinima fakasiaina-fakafaingofua, Hongi Kongi SAR Siaina)',
        'zh_Hans_MO' => 'lea fakasiaina (tohinima fakasiaina-fakafaingofua, Makau SAR Siaina)',
        'zh_Hans_SG' => 'lea fakasiaina (tohinima fakasiaina-fakafaingofua, Singapoa)',
        'zh_Hant' => 'lea fakasiaina (tohinima fakasiaina-tukufakaholo)',
        'zh_Hant_HK' => 'lea fakasiaina (tohinima fakasiaina-tukufakaholo, Hongi Kongi SAR Siaina)',
        'zh_Hant_MO' => 'lea fakasiaina (tohinima fakasiaina-tukufakaholo, Makau SAR Siaina)',
        'zh_Hant_TW' => 'lea fakasiaina (tohinima fakasiaina-tukufakaholo, Taiuani)',
        'zh_MO' => 'lea fakasiaina (Makau SAR Siaina)',
        'zh_SG' => 'lea fakasiaina (Singapoa)',
        'zh_TW' => 'lea fakasiaina (Taiuani)',
        'zu' => 'lea fakasulu',
        'zu_ZA' => 'lea fakasulu (ʻAfilika tonga)',
    ],
];
