<?php

return [
    'Names' => [
        'America/Miquelon' => 'Saint-Pierre-et-Miquelon Time',
        'America/St_Barthelemy' => 'Atlantic Time (Saint-Barthélemy)',
        'America/St_Johns' => 'Newfoundland Time (Saint John’s)',
        'America/St_Kitts' => 'Atlantic Time (Saint Kitts)',
        'America/St_Lucia' => 'Atlantic Time (Saint Lucia)',
        'America/St_Thomas' => 'Atlantic Time (Saint Thomas)',
        'America/St_Vincent' => 'Atlantic Time (Saint Vincent)',
        'Asia/Aqtau' => 'West Kazakhstan Time (Aktau)',
        'Asia/Rangoon' => 'Myanmar Time (Rangoon)',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (Saint Helena)',
        'Indian/Kerguelen' => 'French Southern and Antarctic Time (Kerguelen)',
        'Pacific/Wallis' => 'Wallis and Futuna Time',
    ],
    'Meta' => [
    ],
];
