<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'I-Dirham yase-UAE',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'I-Afghani yase-Afghanistan',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'I-Lek yase-Albania',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'I-Dram yase Armenia',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Netherlands Antillean Guilder',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'I-Kwanza yase-Angola',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'IPeso yase-Argentina',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'IDola yase-Australia',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Aruban Florin',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'I-Manat yase-Azerbeijan',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'I-Convertible Mark yaseBosnia-Herzegovina',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadian Dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'I-Taka yaseBangladesh',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'I-Lev yaseBulgaria',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'I-Dinar yaseBahrain',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'I-Franc yaseBurundi',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermudan Dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'IDola yaseBrunei',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'I-Boliviano yaseBolivia',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'I-Real yaseBrazil',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamian Dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'I-Ngultrum yaseBhutan',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'I-Pula yaseBotswana',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'I-Ruble yaseBelarus',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belize Dollar',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'Canadian Dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'I-Franc yaseCongo',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'I-Franc yaseSwitzerland',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'I-Peso yaseChile',
        ],
        'CNH' => [
            0 => 'I-CNH',
            1 => 'I-Chinese Yuan (offshore)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'I-Yuan yaseTshayina',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'I-Peso yaseColombia',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Costa Rican Colón',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Cuban Convertible Peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Cuban Peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Cape Verdean Escudo',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'I-Koruna yaseCzech',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'I-Franc yaseDjibouti',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'I-Krone yaseDenmark',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominican Peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'I-Dinar yase-Algeria',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'IPonti yase-Egypt',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'I-Nakfa yase-Eritria',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'I-Birr yase-Ethopia',
        ],
        'EUR' => [
            0 => '€',
            1 => 'I-Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'IDola yaseFiji',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Iponti yaseFalkland Islands',
        ],
        'GBP' => [
            0 => '£',
            1 => 'IPonti yaseBritane',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'I-Lari yaseGeorgia',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'I-Cedi yaseGhana',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'IPonti yaseGilbraltar',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'I-Dalasi yaseGambia',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'I-Franc yaseGuinea',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemalan Quetzal',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'IDola yaseGuyana',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'IDola yaseHong Kong',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Honduran Lempira',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'I-Kuna yaseCrotia',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haitian Gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'I-Forint yaseHungay',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'I-Rupiah yase-Indonesia',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'I-New Shekel yase-Israel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'I-Rupee yase-Indiya',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'I-Dinar yase-Iraq',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'I-Rial yase-Iran',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'I-Króna yase-Iceland',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaican Dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'I-Dinar yaseJordan',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'I-Yen yaseJapan',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'I-Shilling yaseKenya',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'I-Som yaseKyrgystan',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'I-Riel yaseCambodia',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'I-Franc yaseComoros',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'I-Won yaseNorth Korea',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'I-Won yaseSouth Korea',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'I-Dinar yaseKuwait',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Cayman Islands Dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'I-Tenge yaseKhazakhstan',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'I-Kip yaseLaos',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'IPonti yaseLebanon',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'I-Rupee yaseSri Lanka',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'IDola yaseLiberia',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'I-Loti yaseLesotho',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libyan Dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Moroccan Dirham',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovan Leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'I-Ariary yaseMadagascar',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Macedonian Denar',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'I-Kyat yaseMyanmar',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'I-Tugrik yaseMongolia',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'I-Pataca yaseMacao',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'I-Ouguiya yaseMauritania',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'I-Rupee yaseMauritius',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'I-Rufiyaa yaseMaldives',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'I-Kwacha yaseMalawi',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Mexican Peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'I-Ringgit yaseMalysia',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'I-Metical yaseMozambique',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'IDola yaseNamibia',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'I-Naira yaseNigeria',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nicaraguan Córdoba',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'I-Krone yaseNorway',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'I-Rupee yaseNepal',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'IDola yaseNew Zealand',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'I-Rial yase-Oman',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamanian Balboa',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'I-Sol yasePeruvia',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'I-Kina yasePapua New Guinea',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'I-Peso yasePhilippines',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'I-Rupee yasePakistan',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polish Zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'I-Guarani yaseParaguay',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'I-Riyal yaseQatar',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'I-Leu yaseRomania',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'I-Dinar yaseSerbia',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'I-Ruble yaseRashiya',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'I-Franc yaseRwanda',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'I-Riyal yaseSaudi',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'IDola yaseSolomon Islands',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'I-Rupee yaseSeychelles',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudanese Pound',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'I-Krona yaseSweden',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'IDola yaseSingapore',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'IPonti yaseSt. Helena',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'I-Loeone yaseSierra Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'I-Shilling yaseSomalia',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'IDola yaseSuriname',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'IPonti yaseSouth Sudan',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'I-Dobra yaseSão Tomé & Príncipe',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'IPonti yaseSiriya',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'I-Lilangeni yase-Eswatini',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'I-Baht yaseThailand',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'I-Somoni yaseTajikistan',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'I-Manat yaseTurkmenistan',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunisian Dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'I-Paʻanga yaseTonga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'I-Lira yaseTurkey',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad & Tobago Dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'IDola yaseNew Taiwan',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'I-Shilling yaseTanzania',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'I-Hryvnia yase-Ukraine',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'I-Shilling yase-Uganda',
        ],
        'USD' => [
            0 => '$',
            1 => 'US Dollar',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'I-Peso yase-Uruguay',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'I-Som yase-Uzbekistan',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'I-Bolívar yaseVenezuela',
        ],
        'VND' => [
            0 => '₫',
            1 => 'I-Dong yaseVietnam',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'I-Vatu yaseVanuatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'I-Tala yaseSamoa',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'Central African CFA Franc',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'East Caribbean Dollar',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'West African CFA Franc',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'I-Franc yaseCFP',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'I-Rial yaseYemen',
        ],
        'ZAR' => [
            0 => 'R',
            1 => 'IRandi yaseMzantsi Afrika',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'I-Kwacha yaseZambi',
        ],
    ],
];
